# coding: utf8
from __future__ import unicode_literals


LOOKUP = {
    "'ndranghete": "'ndrangheta",
    "'ndrine": "'ndrina",
    "a-storica": "a-storico",
    "a-storiche": "a-storico",
    "a-storici": "a-storico",
    "abati": "abate",
    "abbacchi": "abbacchiare",
    "abbacchia": "abbacchiare",
    "abbacchiai": "abbacchiare",
    "abbacchiammo": "abbacchiare",
    "abbacchiamo": "abbacchiare",
    "abbacchian": "abbacchiare",
    "abbacchiando": "abbacchiare",
    "abbacchiano": "abbacchiare",
    "abbacchiante": "abbacchiare",
    "abbacchianti": "abbacchiare",
    "abbacchiar": "abbacchiare",
    "abbacchiaron": "abbacchiare",
    "abbacchiarono": "abbacchiare",
    "abbacchiasse": "abbacchiare",
    "abbacchiasser": "abbacchiare",
    "abbacchiassero": "abbacchiare",
    "abbacchiassi": "abbacchiare",
    "abbacchiassimo": "abbacchiare",
    "abbacchiaste": "abbacchiare",
    "abbacchiasti": "abbacchiare",
    "abbacchiata": "abbacchiare",
    "abbacchiate": "abbacchiare",
    "abbacchiati": "abbacchiare",
    "abbacchiato": "abbacchiare",
    "abbacchiava": "abbacchiare",
    "abbacchiavamo": "abbacchiare",
    "abbacchiavan": "abbacchiare",
    "abbacchiavano": "abbacchiare",
    "abbacchiavate": "abbacchiare",
    "abbacchiavi": "abbacchiare",
    "abbacchiavo": "abbacchiare",
    "abbacchierai": "abbacchiare",
    "abbacchieran": "abbacchiare",
    "abbacchieranno": "abbacchiare",
    "abbacchierebbe": "abbacchiare",
    "abbacchierebber": "abbacchiare",
    "abbacchierebbero": "abbacchiare",
    "abbacchierei": "abbacchiare",
    "abbacchieremmo": "abbacchiare",
    "abbacchieremo": "abbacchiare",
    "abbacchiereste": "abbacchiare",
    "abbacchieresti": "abbacchiare",
    "abbacchierete": "abbacchiare",
    "abbacchierà": "abbacchiare",
    "abbacchierò": "abbacchiare",
    "abbacchin": "abbacchiare",
    "abbacchino": "abbacchiare",
    "abbacchio": "abbacchiare",
    "abbacchiò": "abbacchiare",
    "abbacina": "abbacinare",
    "abbacinai": "abbacinare",
    "abbacinammo": "abbacinare",
    "abbacinan": "abbacinare",
    "abbacinando": "abbacinare",
    "abbacinano": "abbacinare",
    "abbacinante": "abbacinare",
    "abbacinanti": "abbacinare",
    "abbacinar": "abbacinare",
    "abbacinaron": "abbacinare",
    "abbacinarono": "abbacinare",
    "abbacinasse": "abbacinare",
    "abbacinasser": "abbacinare",
    "abbacinassero": "abbacinare",
    "abbacinassi": "abbacinare",
    "abbacinassimo": "abbacinare",
    "abbacinaste": "abbacinare",
    "abbacinasti": "abbacinare",
    "abbacinata": "abbacinare",
    "abbacinate": "abbacinare",
    "abbacinati": "abbacinare",
    "abbacinato": "abbacinare",
    "abbacinava": "abbacinare",
    "abbacinavamo": "abbacinare",
    "abbacinavan": "abbacinare",
    "abbacinavano": "abbacinare",
    "abbacinavate": "abbacinare",
    "abbacinavi": "abbacinare",
    "abbacinavo": "abbacinare",
    "abbacinerai": "abbacinare",
    "abbacineran": "abbacinare",
    "abbacineranno": "abbacinare",
    "abbacinerebbe": "abbacinare",
    "abbacinerebber": "abbacinare",
    "abbacinerebbero": "abbacinare",
    "abbacinerei": "abbacinare",
    "abbacineremmo": "abbacinare",
    "abbacineremo": "abbacinare",
    "abbacinereste": "abbacinare",
    "abbacineresti": "abbacinare",
    "abbacinerete": "abbacinare",
    "abbacinerà": "abbacinare",
    "abbacinerò": "abbacinare",
    "abbacini": "abbacinare",
    "abbaciniamo": "abbacinare",
    "abbaciniate": "abbacinare",
    "abbacinin": "abbacinare",
    "abbacinino": "abbacinare",
    "abbacino": "abbacinare",
    "abbacinò": "abbacinare",
    "abbagli": "abbaglio",
    "abbaglia": "abbagliare",
    "abbagliai": "abbagliare",
    "abbagliammo": "abbagliare",
    "abbagliamo": "abbagliare",
    "abbaglian": "abbagliare",
    "abbagliando": "abbagliare",
    "abbagliano": "abbagliare",
    "abbagliante": "abbagliare",
    "abbaglianti": "abbagliare",
    "abbagliar": "abbagliare",
    "abbagliaron": "abbagliare",
    "abbagliarono": "abbagliare",
    "abbagliasse": "abbagliare",
    "abbagliasser": "abbagliare",
    "abbagliassero": "abbagliare",
    "abbagliassi": "abbagliare",
    "abbagliassimo": "abbagliare",
    "abbagliaste": "abbagliare",
    "abbagliasti": "abbagliare",
    "abbagliata": "abbagliare",
    "abbagliate": "abbagliare",
    "abbagliati": "abbagliare",
    "abbagliato": "abbagliare",
    "abbagliava": "abbagliare",
    "abbagliavamo": "abbagliare",
    "abbagliavan": "abbagliare",
    "abbagliavano": "abbagliare",
    "abbagliavate": "abbagliare",
    "abbagliavi": "abbagliare",
    "abbagliavo": "abbagliare",
    "abbaglierai": "abbagliare",
    "abbaglieran": "abbagliare",
    "abbaglieranno": "abbagliare",
    "abbaglierebbe": "abbagliare",
    "abbaglierebber": "abbagliare",
    "abbaglierebbero": "abbagliare",
    "abbaglierei": "abbagliare",
    "abbaglieremmo": "abbagliare",
    "abbaglieremo": "abbagliare",
    "abbagliereste": "abbagliare",
    "abbaglieresti": "abbagliare",
    "abbaglierete": "abbagliare",
    "abbaglierà": "abbagliare",
    "abbaglierò": "abbagliare",
    "abbaglin": "abbagliare",
    "abbaglino": "abbagliare",
    "abbaglio": "abbagliare",
    "abbagliò": "abbagliare",
    "abbai": "abbaiare",
    "abbaia": "abbaiare",
    "abbaiai": "abbaiare",
    "abbaiammo": "abbaiare",
    "abbaiamo": "abbaiare",
    "abbaian": "abbaiare",
    "abbaiando": "abbaiare",
    "abbaiano": "abbaiare",
    "abbaiante": "abbaiare",
    "abbaianti": "abbaiare",
    "abbaiar": "abbaiare",
    "abbaiaron": "abbaiare",
    "abbaiarono": "abbaiare",
    "abbaiasse": "abbaiare",
    "abbaiasser": "abbaiare",
    "abbaiassero": "abbaiare",
    "abbaiassi": "abbaiare",
    "abbaiassimo": "abbaiare",
    "abbaiaste": "abbaiare",
    "abbaiasti": "abbaiare",
    "abbaiata": "abbaiare",
    "abbaiate": "abbaiare",
    "abbaiati": "abbaiare",
    "abbaiato": "abbaiare",
    "abbaiava": "abbaiare",
    "abbaiavamo": "abbaiare",
    "abbaiavan": "abbaiare",
    "abbaiavano": "abbaiare",
    "abbaiavate": "abbaiare",
    "abbaiavi": "abbaiare",
    "abbaiavo": "abbaiare",
    "abbaierai": "abbaiare",
    "abbaieran": "abbaiare",
    "abbaieranno": "abbaiare",
    "abbaierebbe": "abbaiare",
    "abbaierebber": "abbaiare",
    "abbaierebbero": "abbaiare",
    "abbaierei": "abbaiare",
    "abbaieremmo": "abbaiare",
    "abbaieremo": "abbaiare",
    "abbaiereste": "abbaiare",
    "abbaieresti": "abbaiare",
    "abbaierete": "abbaiare",
    "abbaierà": "abbaiare",
    "abbaierò": "abbaiare",
    "abbain": "abbaiare",
    "abbaini": "abbaino",
    "abbaino": "abbaiare",
    "abbaio": "abbaiare",
    "abbaiò": "abbaiare",
    "abbandona": "abbandonare",
    "abbandonai": "abbandonare",
    "abbandonammo": "abbandonare",
    "abbandonan": "abbandonare",
    "abbandonando": "abbandonare",
    "abbandonano": "abbandonare",
    "abbandonante": "abbandonare",
    "abbandonanti": "abbandonare",
    "abbandonar": "abbandonare",
    "abbandonaron": "abbandonare",
    "abbandonarono": "abbandonare",
    "abbandonasse": "abbandonare",
    "abbandonasser": "abbandonare",
    "abbandonassero": "abbandonare",
    "abbandonassi": "abbandonare",
    "abbandonassimo": "abbandonare",
    "abbandonaste": "abbandonare",
    "abbandonasti": "abbandonare",
    "abbandonata": "abbandonato",
    "abbandonate": "abbandonato",
    "abbandonati": "abbandonato",
    "abbandonato": "abbandonare",
    "abbandonava": "abbandonare",
    "abbandonavamo": "abbandonare",
    "abbandonavan": "abbandonare",
    "abbandonavano": "abbandonare",
    "abbandonavate": "abbandonare",
    "abbandonavi": "abbandonare",
    "abbandonavo": "abbandonare",
    "abbandonerai": "abbandonare",
    "abbandoneran": "abbandonare",
    "abbandoneranno": "abbandonare",
    "abbandonerebbe": "abbandonare",
    "abbandonerebber": "abbandonare",
    "abbandonerebbero": "abbandonare",
    "abbandonerei": "abbandonare",
    "abbandoneremmo": "abbandonare",
    "abbandoneremo": "abbandonare",
    "abbandonereste": "abbandonare",
    "abbandoneresti": "abbandonare",
    "abbandonerete": "abbandonare",
    "abbandonerà": "abbandonare",
    "abbandonerò": "abbandonare",
    "abbandoni": "abbandono",
    "abbandoniamo": "abbandonare",
    "abbandoniate": "abbandonare",
    "abbandonin": "abbandonare",
    "abbandonino": "abbandonare",
    "abbandono": "abbandonare",
    "abbandonò": "abbandonare",
    "abbarbagli": "abbarbagliare",
    "abbarbaglia": "abbarbagliare",
    "abbarbagliai": "abbarbagliare",
    "abbarbagliammo": "abbarbagliare",
    "abbarbagliamo": "abbarbagliare",
    "abbarbaglian": "abbarbagliare",
    "abbarbagliando": "abbarbagliare",
    "abbarbagliano": "abbarbagliare",
    "abbarbagliante": "abbarbagliare",
    "abbarbaglianti": "abbarbagliare",
    "abbarbagliar": "abbarbagliare",
    "abbarbagliaron": "abbarbagliare",
    "abbarbagliarono": "abbarbagliare",
    "abbarbagliasse": "abbarbagliare",
    "abbarbagliasser": "abbarbagliare",
    "abbarbagliassero": "abbarbagliare",
    "abbarbagliassi": "abbarbagliare",
    "abbarbagliassimo": "abbarbagliare",
    "abbarbagliaste": "abbarbagliare",
    "abbarbagliasti": "abbarbagliare",
    "abbarbagliata": "abbarbagliare",
    "abbarbagliate": "abbarbagliare",
    "abbarbagliati": "abbarbagliare",
    "abbarbagliato": "abbarbagliare",
    "abbarbagliava": "abbarbagliare",
    "abbarbagliavamo": "abbarbagliare",
    "abbarbagliavan": "abbarbagliare",
    "abbarbagliavano": "abbarbagliare",
    "abbarbagliavate": "abbarbagliare",
    "abbarbagliavi": "abbarbagliare",
    "abbarbagliavo": "abbarbagliare",
    "abbarbaglierai": "abbarbagliare",
    "abbarbaglieran": "abbarbagliare",
    "abbarbaglieranno": "abbarbagliare",
    "abbarbaglierebbe": "abbarbagliare",
    "abbarbaglierebber": "abbarbagliare",
    "abbarbaglierebbero": "abbarbagliare",
    "abbarbaglierei": "abbarbagliare",
    "abbarbaglieremmo": "abbarbagliare",
    "abbarbaglieremo": "abbarbagliare",
    "abbarbagliereste": "abbarbagliare",
    "abbarbaglieresti": "abbarbagliare",
    "abbarbaglierete": "abbarbagliare",
    "abbarbaglierà": "abbarbagliare",
    "abbarbaglierò": "abbarbagliare",
    "abbarbaglin": "abbarbagliare",
    "abbarbaglino": "abbarbagliare",
    "abbarbaglio": "abbarbagliare",
    "abbarbagliò": "abbarbagliare",
    "abbarbica": "abbarbicare",
    "abbarbicai": "abbarbicare",
    "abbarbicammo": "abbarbicare",
    "abbarbican": "abbarbicare",
    "abbarbicando": "abbarbicare",
    "abbarbicano": "abbarbicare",
    "abbarbicante": "abbarbicare",
    "abbarbicanti": "abbarbicare",
    "abbarbicar": "abbarbicare",
    "abbarbicaron": "abbarbicare",
    "abbarbicarono": "abbarbicare",
    "abbarbicasse": "abbarbicare",
    "abbarbicasser": "abbarbicare",
    "abbarbicassero": "abbarbicare",
    "abbarbicassi": "abbarbicare",
    "abbarbicassimo": "abbarbicare",
    "abbarbicaste": "abbarbicare",
    "abbarbicasti": "abbarbicare",
    "abbarbicata": "abbarbicare",
    "abbarbicate": "abbarbicare",
    "abbarbicati": "abbarbicare",
    "abbarbicato": "abbarbicare",
    "abbarbicava": "abbarbicare",
    "abbarbicavamo": "abbarbicare",
    "abbarbicavan": "abbarbicare",
    "abbarbicavano": "abbarbicare",
    "abbarbicavate": "abbarbicare",
    "abbarbicavi": "abbarbicare",
    "abbarbicavo": "abbarbicare",
    "abbarbicherai": "abbarbicare",
    "abbarbicheran": "abbarbicare",
    "abbarbicheranno": "abbarbicare",
    "abbarbicherebbe": "abbarbicare",
    "abbarbicherebber": "abbarbicare",
    "abbarbicherebbero": "abbarbicare",
    "abbarbicherei": "abbarbicare",
    "abbarbicheremmo": "abbarbicare",
    "abbarbicheremo": "abbarbicare",
    "abbarbichereste": "abbarbicare",
    "abbarbicheresti": "abbarbicare",
    "abbarbicherete": "abbarbicare",
    "abbarbicherà": "abbarbicare",
    "abbarbicherò": "abbarbicare",
    "abbarbichi": "abbarbicare",
    "abbarbichiamo": "abbarbicare",
    "abbarbichiate": "abbarbicare",
    "abbarbichin": "abbarbicare",
    "abbarbichino": "abbarbicare",
    "abbarbico": "abbarbicare",
    "abbarbicò": "abbarbicare",
    "abbaruffa": "abbaruffare",
    "abbaruffai": "abbaruffare",
    "abbaruffammo": "abbaruffare",
    "abbaruffan": "abbaruffare",
    "abbaruffando": "abbaruffare",
    "abbaruffano": "abbaruffare",
    "abbaruffante": "abbaruffare",
    "abbaruffanti": "abbaruffare",
    "abbaruffar": "abbaruffare",
    "abbaruffaron": "abbaruffare",
    "abbaruffarono": "abbaruffare",
    "abbaruffasse": "abbaruffare",
    "abbaruffasser": "abbaruffare",
    "abbaruffassero": "abbaruffare",
    "abbaruffassi": "abbaruffare",
    "abbaruffassimo": "abbaruffare",
    "abbaruffaste": "abbaruffare",
    "abbaruffasti": "abbaruffare",
    "abbaruffata": "abbaruffare",
    "abbaruffate": "abbaruffare",
    "abbaruffati": "abbaruffare",
    "abbaruffato": "abbaruffare",
    "abbaruffava": "abbaruffare",
    "abbaruffavamo": "abbaruffare",
    "abbaruffavan": "abbaruffare",
    "abbaruffavano": "abbaruffare",
    "abbaruffavate": "abbaruffare",
    "abbaruffavi": "abbaruffare",
    "abbaruffavo": "abbaruffare",
    "abbarufferai": "abbaruffare",
    "abbarufferan": "abbaruffare",
    "abbarufferanno": "abbaruffare",
    "abbarufferebbe": "abbaruffare",
    "abbarufferebber": "abbaruffare",
    "abbarufferebbero": "abbaruffare",
    "abbarufferei": "abbaruffare",
    "abbarufferemmo": "abbaruffare",
    "abbarufferemo": "abbaruffare",
    "abbaruffereste": "abbaruffare",
    "abbarufferesti": "abbaruffare",
    "abbarufferete": "abbaruffare",
    "abbarufferà": "abbaruffare",
    "abbarufferò": "abbaruffare",
    "abbaruffi": "abbaruffare",
    "abbaruffiamo": "abbaruffare",
    "abbaruffiate": "abbaruffare",
    "abbaruffin": "abbaruffare",
    "abbaruffino": "abbaruffare",
    "abbaruffo": "abbaruffare",
    "abbaruffò": "abbaruffare",
    "abbassa": "abbassare",
    "abbassai": "abbassare",
    "abbassamenti": "abbassamento",
    "abbassammo": "abbassare",
    "abbassan": "abbassare",
    "abbassando": "abbassare",
    "abbassano": "abbassare",
    "abbassante": "abbassare",
    "abbassanti": "abbassare",
    "abbassar": "abbassare",
    "abbassaron": "abbassare",
    "abbassarono": "abbassare",
    "abbassasse": "abbassare",
    "abbassasser": "abbassare",
    "abbassassero": "abbassare",
    "abbassassi": "abbassare",
    "abbassassimo": "abbassare",
    "abbassaste": "abbassare",
    "abbassasti": "abbassare",
    "abbassata": "abbassare",
    "abbassate": "abbassare",
    "abbassati": "abbassare",
    "abbassato": "abbassare",
    "abbassava": "abbassare",
    "abbassavamo": "abbassare",
    "abbassavan": "abbassare",
    "abbassavano": "abbassare",
    "abbassavate": "abbassare",
    "abbassavi": "abbassare",
    "abbassavo": "abbassare",
    "abbasserai": "abbassare",
    "abbasseran": "abbassare",
    "abbasseranno": "abbassare",
    "abbasserebbe": "abbassare",
    "abbasserebber": "abbassare",
    "abbasserebbero": "abbassare",
    "abbasserei": "abbassare",
    "abbasseremmo": "abbassare",
    "abbasseremo": "abbassare",
    "abbassereste": "abbassare",
    "abbasseresti": "abbassare",
    "abbasserete": "abbassare",
    "abbasserà": "abbassare",
    "abbasserò": "abbassare",
    "abbassi": "abbassare",
    "abbassiamo": "abbassare",
    "abbassiate": "abbassare",
    "abbassin": "abbassare",
    "abbassino": "abbassare",
    "abbasso": "abbassare",
    "abbassò": "abbassare",
    "abbatta": "abbattere",
    "abbattan": "abbattere",
    "abbattano": "abbattere",
    "abbatte": "abbattere",
    "abbattei": "abbattere",
    "abbattemmo": "abbattere",
    "abbattendo": "abbattere",
    "abbattente": "abbattere",
    "abbattenti": "abbattere",
    "abbatter": "abbattere",
    "abbatterai": "abbattere",
    "abbatteran": "abbattere",
    "abbatteranno": "abbattere",
    "abbatterebbe": "abbattere",
    "abbatterebber": "abbattere",
    "abbatterebbero": "abbattere",
    "abbatterei": "abbattere",
    "abbatteremmo": "abbattere",
    "abbatteremo": "abbattere",
    "abbattereste": "abbattere",
    "abbatteresti": "abbattere",
    "abbatterete": "abbattere",
    "abbatteron": "abbattere",
    "abbatterono": "abbattere",
    "abbatterà": "abbattere",
    "abbatterò": "abbattere",
    "abbattesse": "abbattere",
    "abbattesser": "abbattere",
    "abbattessero": "abbattere",
    "abbattessi": "abbattere",
    "abbattessimo": "abbattere",
    "abbatteste": "abbattere",
    "abbattesti": "abbattere",
    "abbattete": "abbattere",
    "abbatteva": "abbattere",
    "abbattevamo": "abbattere",
    "abbattevan": "abbattere",
    "abbattevano": "abbattere",
    "abbattevate": "abbattere",
    "abbattevi": "abbattere",
    "abbattevo": "abbattere",
    "abbatti": "abbattere",
    "abbattiamo": "abbattere",
    "abbattiate": "abbattere",
    "abbattimenti": "abbattimento",
    "abbatto": "abbattere",
    "abbatton": "abbattere",
    "abbattono": "abbattere",
    "abbattuta": "abbattuto",
    "abbattute": "abbattuto",
    "abbattuti": "abbattuto",
    "abbattuto": "abbattere",
    "abbattè": "abbattere",
    "abbazie": "abbazia",
    "abbellendo": "abbellire",
    "abbellente": "abbellire",
    "abbellenti": "abbellire",
    "abbelliamo": "abbellire",
    "abbelliate": "abbellire",
    "abbellii": "abbellire",
    "abbellimenti": "abbellimento",
    "abbellimmo": "abbellire",
    "abbellir": "abbellire",
    "abbellirai": "abbellire",
    "abbelliran": "abbellire",
    "abbelliranno": "abbellire",
    "abbellirebbe": "abbellire",
    "abbellirebber": "abbellire",
    "abbellirebbero": "abbellire",
    "abbellirei": "abbellire",
    "abbelliremmo": "abbellire",
    "abbelliremo": "abbellire",
    "abbellireste": "abbellire",
    "abbelliresti": "abbellire",
    "abbellirete": "abbellire",
    "abbelliron": "abbellire",
    "abbellirono": "abbellire",
    "abbellirà": "abbellire",
    "abbellirò": "abbellire",
    "abbellisca": "abbellire",
    "abbelliscan": "abbellire",
    "abbelliscano": "abbellire",
    "abbellisce": "abbellire",
    "abbellisci": "abbellire",
    "abbellisco": "abbellire",
    "abbelliscon": "abbellire",
    "abbelliscono": "abbellire",
    "abbellisse": "abbellire",
    "abbellisser": "abbellire",
    "abbellissero": "abbellire",
    "abbellissi": "abbellire",
    "abbellissimo": "abbellire",
    "abbelliste": "abbellire",
    "abbellisti": "abbellire",
    "abbellita": "abbellire",
    "abbellite": "abbellire",
    "abbelliti": "abbellire",
    "abbellito": "abbellire",
    "abbelliva": "abbellire",
    "abbellivamo": "abbellire",
    "abbellivan": "abbellire",
    "abbellivano": "abbellire",
    "abbellivate": "abbellire",
    "abbellivi": "abbellire",
    "abbellivo": "abbellire",
    "abbellì": "abbellire",
    "abbevera": "abbeverare",
    "abbeverai": "abbeverare",
    "abbeverammo": "abbeverare",
    "abbeveran": "abbeverare",
    "abbeverando": "abbeverare",
    "abbeverano": "abbeverare",
    "abbeverante": "abbeverare",
    "abbeveranti": "abbeverare",
    "abbeverar": "abbeverare",
    "abbeveraron": "abbeverare",
    "abbeverarono": "abbeverare",
    "abbeverasse": "abbeverare",
    "abbeverasser": "abbeverare",
    "abbeverassero": "abbeverare",
    "abbeverassi": "abbeverare",
    "abbeverassimo": "abbeverare",
    "abbeveraste": "abbeverare",
    "abbeverasti": "abbeverare",
    "abbeverata": "abbeverare",
    "abbeverate": "abbeverare",
    "abbeverati": "abbeverare",
    "abbeverato": "abbeverare",
    "abbeverava": "abbeverare",
    "abbeveravamo": "abbeverare",
    "abbeveravan": "abbeverare",
    "abbeveravano": "abbeverare",
    "abbeveravate": "abbeverare",
    "abbeveravi": "abbeverare",
    "abbeveravo": "abbeverare",
    "abbevererai": "abbeverare",
    "abbevereran": "abbeverare",
    "abbevereranno": "abbeverare",
    "abbevererebbe": "abbeverare",
    "abbevererebber": "abbeverare",
    "abbevererebbero": "abbeverare",
    "abbevererei": "abbeverare",
    "abbevereremmo": "abbeverare",
    "abbevereremo": "abbeverare",
    "abbeverereste": "abbeverare",
    "abbevereresti": "abbeverare",
    "abbevererete": "abbeverare",
    "abbevererà": "abbeverare",
    "abbevererò": "abbeverare",
    "abbeveri": "abbeverare",
    "abbeveriamo": "abbeverare",
    "abbeveriate": "abbeverare",
    "abbeverin": "abbeverare",
    "abbeverino": "abbeverare",
    "abbevero": "abbeverare",
    "abbeverò": "abbeverare",
    "abbi": "avere",
    "abbia": "avere",
    "abbiamo": "avere",
    "abbian": "avere",
    "abbiano": "avere",
    "abbiate": "avere",
    "abbica": "abbicare",
    "abbicai": "abbicare",
    "abbicammo": "abbicare",
    "abbican": "abbicare",
    "abbicando": "abbicare",
    "abbicano": "abbicare",
    "abbicante": "abbicare",
    "abbicanti": "abbicare",
    "abbicar": "abbicare",
    "abbicaron": "abbicare",
    "abbicarono": "abbicare",
    "abbicasse": "abbicare",
    "abbicasser": "abbicare",
    "abbicassero": "abbicare",
    "abbicassi": "abbicare",
    "abbicassimo": "abbicare",
    "abbicaste": "abbicare",
    "abbicasti": "abbicare",
    "abbicata": "abbicare",
    "abbicate": "abbicare",
    "abbicati": "abbicare",
    "abbicato": "abbicare",
    "abbicava": "abbicare",
    "abbicavamo": "abbicare",
    "abbicavan": "abbicare",
    "abbicavano": "abbicare",
    "abbicavate": "abbicare",
    "abbicavi": "abbicare",
    "abbicavo": "abbicare",
    "abbicherai": "abbicare",
    "abbicheran": "abbicare",
    "abbicheranno": "abbicare",
    "abbicherebbe": "abbicare",
    "abbicherebber": "abbicare",
    "abbicherebbero": "abbicare",
    "abbicherei": "abbicare",
    "abbicheremmo": "abbicare",
    "abbicheremo": "abbicare",
    "abbichereste": "abbicare",
    "abbicheresti": "abbicare",
    "abbicherete": "abbicare",
    "abbicherà": "abbicare",
    "abbicherò": "abbicare",
    "abbichi": "abbicare",
    "abbichiamo": "abbicare",
    "abbichiate": "abbicare",
    "abbichin": "abbicare",
    "abbichino": "abbicare",
    "abbico": "abbicare",
    "abbicò": "abbicare",
    "abbienti": "abbiente",
    "abbigli": "abbigliare",
    "abbiglia": "abbigliare",
    "abbigliai": "abbigliare",
    "abbigliamenti": "abbigliamento",
    "abbigliammo": "abbigliare",
    "abbigliamo": "abbigliare",
    "abbiglian": "abbigliare",
    "abbigliando": "abbigliare",
    "abbigliano": "abbigliare",
    "abbigliante": "abbigliare",
    "abbiglianti": "abbigliare",
    "abbigliar": "abbigliare",
    "abbigliaron": "abbigliare",
    "abbigliarono": "abbigliare",
    "abbigliasse": "abbigliare",
    "abbigliasser": "abbigliare",
    "abbigliassero": "abbigliare",
    "abbigliassi": "abbigliare",
    "abbigliassimo": "abbigliare",
    "abbigliaste": "abbigliare",
    "abbigliasti": "abbigliare",
    "abbigliata": "abbigliare",
    "abbigliate": "abbigliare",
    "abbigliati": "abbigliare",
    "abbigliato": "abbigliare",
    "abbigliava": "abbigliare",
    "abbigliavamo": "abbigliare",
    "abbigliavan": "abbigliare",
    "abbigliavano": "abbigliare",
    "abbigliavate": "abbigliare",
    "abbigliavi": "abbigliare",
    "abbigliavo": "abbigliare",
    "abbiglierai": "abbigliare",
    "abbiglieran": "abbigliare",
    "abbiglieranno": "abbigliare",
    "abbiglierebbe": "abbigliare",
    "abbiglierebber": "abbigliare",
    "abbiglierebbero": "abbigliare",
    "abbiglierei": "abbigliare",
    "abbiglieremmo": "abbigliare",
    "abbiglieremo": "abbigliare",
    "abbigliereste": "abbigliare",
    "abbiglieresti": "abbigliare",
    "abbiglierete": "abbigliare",
    "abbiglierà": "abbigliare",
    "abbiglierò": "abbigliare",
    "abbiglin": "abbigliare",
    "abbiglino": "abbigliare",
    "abbiglio": "abbigliare",
    "abbigliò": "abbigliare",
    "abbina": "abbinare",
    "abbinabili": "abbinabile",
    "abbinai": "abbinare",
    "abbinamenti": "abbinamento",
    "abbinammo": "abbinare",
    "abbinan": "abbinare",
    "abbinando": "abbinare",
    "abbinano": "abbinare",
    "abbinante": "abbinare",
    "abbinanti": "abbinare",
    "abbinar": "abbinare",
    "abbinaron": "abbinare",
    "abbinarono": "abbinare",
    "abbinasse": "abbinare",
    "abbinasser": "abbinare",
    "abbinassero": "abbinare",
    "abbinassi": "abbinare",
    "abbinassimo": "abbinare",
    "abbinaste": "abbinare",
    "abbinasti": "abbinare",
    "abbinata": "abbinare",
    "abbinate": "abbinare",
    "abbinati": "abbinare",
    "abbinato": "abbinare",
    "abbinava": "abbinare",
    "abbinavamo": "abbinare",
    "abbinavan": "abbinare",
    "abbinavano": "abbinare",
    "abbinavate": "abbinare",
    "abbinavi": "abbinare",
    "abbinavo": "abbinare",
    "abbindola": "abbindolare",
    "abbindolai": "abbindolare",
    "abbindolammo": "abbindolare",
    "abbindolan": "abbindolare",
    "abbindolando": "abbindolare",
    "abbindolano": "abbindolare",
    "abbindolante": "abbindolare",
    "abbindolanti": "abbindolare",
    "abbindolar": "abbindolare",
    "abbindolaron": "abbindolare",
    "abbindolarono": "abbindolare",
    "abbindolasse": "abbindolare",
    "abbindolasser": "abbindolare",
    "abbindolassero": "abbindolare",
    "abbindolassi": "abbindolare",
    "abbindolassimo": "abbindolare",
    "abbindolaste": "abbindolare",
    "abbindolasti": "abbindolare",
    "abbindolata": "abbindolare",
    "abbindolate": "abbindolare",
    "abbindolati": "abbindolare",
    "abbindolato": "abbindolare",
    "abbindolava": "abbindolare",
    "abbindolavamo": "abbindolare",
    "abbindolavan": "abbindolare",
    "abbindolavano": "abbindolare",
    "abbindolavate": "abbindolare",
    "abbindolavi": "abbindolare",
    "abbindolavo": "abbindolare",
    "abbindolerai": "abbindolare",
    "abbindoleran": "abbindolare",
    "abbindoleranno": "abbindolare",
    "abbindolerebbe": "abbindolare",
    "abbindolerebber": "abbindolare",
    "abbindolerebbero": "abbindolare",
    "abbindolerei": "abbindolare",
    "abbindoleremmo": "abbindolare",
    "abbindoleremo": "abbindolare",
    "abbindolereste": "abbindolare",
    "abbindoleresti": "abbindolare",
    "abbindolerete": "abbindolare",
    "abbindolerà": "abbindolare",
    "abbindolerò": "abbindolare",
    "abbindoli": "abbindolare",
    "abbindoliamo": "abbindolare",
    "abbindoliate": "abbindolare",
    "abbindolin": "abbindolare",
    "abbindolino": "abbindolare",
    "abbindolo": "abbindolare",
    "abbindolò": "abbindolare",
    "abbinerai": "abbinare",
    "abbineran": "abbinare",
    "abbineranno": "abbinare",
    "abbinerebbe": "abbinare",
    "abbinerebber": "abbinare",
    "abbinerebbero": "abbinare",
    "abbinerei": "abbinare",
    "abbineremmo": "abbinare",
    "abbineremo": "abbinare",
    "abbinereste": "abbinare",
    "abbineresti": "abbinare",
    "abbinerete": "abbinare",
    "abbinerà": "abbinare",
    "abbinerò": "abbinare",
    "abbini": "abbinare",
    "abbiniamo": "abbinare",
    "abbiniate": "abbinare",
    "abbinin": "abbinare",
    "abbinino": "abbinare",
    "abbino": "abbinare",
    "abbinò": "abbinare",
    "abbioscerai": "abbiosciare",
    "abbiosceran": "abbiosciare",
    "abbiosceranno": "abbiosciare",
    "abbioscerebbe": "abbiosciare",
    "abbioscerebber": "abbiosciare",
    "abbioscerebbero": "abbiosciare",
    "abbioscerei": "abbiosciare",
    "abbiosceremmo": "abbiosciare",
    "abbiosceremo": "abbiosciare",
    "abbioscereste": "abbiosciare",
    "abbiosceresti": "abbiosciare",
    "abbioscerete": "abbiosciare",
    "abbioscerà": "abbiosciare",
    "abbioscerò": "abbiosciare",
    "abbiosci": "abbiosciare",
    "abbioscia": "abbiosciare",
    "abbiosciai": "abbiosciare",
    "abbiosciammo": "abbiosciare",
    "abbiosciamo": "abbiosciare",
    "abbioscian": "abbiosciare",
    "abbiosciando": "abbiosciare",
    "abbiosciano": "abbiosciare",
    "abbiosciante": "abbiosciare",
    "abbioscianti": "abbiosciare",
    "abbiosciar": "abbiosciare",
    "abbiosciaron": "abbiosciare",
    "abbiosciarono": "abbiosciare",
    "abbiosciasse": "abbiosciare",
    "abbiosciasser": "abbiosciare",
    "abbiosciassero": "abbiosciare",
    "abbiosciassi": "abbiosciare",
    "abbiosciassimo": "abbiosciare",
    "abbiosciaste": "abbiosciare",
    "abbiosciasti": "abbiosciare",
    "abbiosciata": "abbiosciare",
    "abbiosciate": "abbiosciare",
    "abbiosciati": "abbiosciare",
    "abbiosciato": "abbiosciare",
    "abbiosciava": "abbiosciare",
    "abbiosciavamo": "abbiosciare",
    "abbiosciavan": "abbiosciare",
    "abbiosciavano": "abbiosciare",
    "abbiosciavate": "abbiosciare",
    "abbiosciavi": "abbiosciare",
    "abbiosciavo": "abbiosciare",
    "abbioscin": "abbiosciare",
    "abbioscino": "abbiosciare",
    "abbioscio": "abbiosciare",
    "abbiosciò": "abbiosciare",
    "abbisogna": "abbisognare",
    "abbisognai": "abbisognare",
    "abbisognammo": "abbisognare",
    "abbisognan": "abbisognare",
    "abbisognando": "abbisognare",
    "abbisognano": "abbisognare",
    "abbisognante": "abbisognare",
    "abbisognanti": "abbisognare",
    "abbisognar": "abbisognare",
    "abbisognaron": "abbisognare",
    "abbisognarono": "abbisognare",
    "abbisognasse": "abbisognare",
    "abbisognasser": "abbisognare",
    "abbisognassero": "abbisognare",
    "abbisognassi": "abbisognare",
    "abbisognassimo": "abbisognare",
    "abbisognaste": "abbisognare",
    "abbisognasti": "abbisognare",
    "abbisognata": "abbisognare",
    "abbisognate": "abbisognare",
    "abbisognati": "abbisognare",
    "abbisognato": "abbisognare",
    "abbisognava": "abbisognare",
    "abbisognavamo": "abbisognare",
    "abbisognavan": "abbisognare",
    "abbisognavano": "abbisognare",
    "abbisognavate": "abbisognare",
    "abbisognavi": "abbisognare",
    "abbisognavo": "abbisognare",
    "abbisognerai": "abbisognare",
    "abbisogneran": "abbisognare",
    "abbisogneranno": "abbisognare",
    "abbisognerebbe": "abbisognare",
    "abbisognerebber": "abbisognare",
    "abbisognerebbero": "abbisognare",
    "abbisognerei": "abbisognare",
    "abbisogneremmo": "abbisognare",
    "abbisogneremo": "abbisognare",
    "abbisognereste": "abbisognare",
    "abbisogneresti": "abbisognare",
    "abbisognerete": "abbisognare",
    "abbisognerà": "abbisognare",
    "abbisognerò": "abbisognare",
    "abbisogni": "abbisognare",
    "abbisogniamo": "abbisognare",
    "abbisogniate": "abbisognare",
    "abbisognin": "abbisognare",
    "abbisognino": "abbisognare",
    "abbisogno": "abbisognare",
    "abbisognò": "abbisognare",
    "abbocca": "abboccare",
    "abboccai": "abboccare",
    "abboccamenti": "abboccamento",
    "abboccammo": "abboccare",
    "abboccan": "abboccare",
    "abboccando": "abboccare",
    "abboccano": "abboccare",
    "abboccante": "abboccare",
    "abboccanti": "abboccare",
    "abboccar": "abboccare",
    "abboccaron": "abboccare",
    "abboccarono": "abboccare",
    "abboccasse": "abboccare",
    "abboccasser": "abboccare",
    "abboccassero": "abboccare",
    "abboccassi": "abboccare",
    "abboccassimo": "abboccare",
    "abboccaste": "abboccare",
    "abboccasti": "abboccare",
    "abboccata": "abboccare",
    "abboccate": "abboccare",
    "abboccati": "abboccare",
    "abboccato": "abboccare",
    "abboccava": "abboccare",
    "abboccavamo": "abboccare",
    "abboccavan": "abboccare",
    "abboccavano": "abboccare",
    "abboccavate": "abboccare",
    "abboccavi": "abboccare",
    "abboccavo": "abboccare",
    "abboccherai": "abboccare",
    "abboccheran": "abboccare",
    "abboccheranno": "abboccare",
    "abboccherebbe": "abboccare",
    "abboccherebber": "abboccare",
    "abboccherebbero": "abboccare",
    "abboccherei": "abboccare",
    "abboccheremmo": "abboccare",
    "abboccheremo": "abboccare",
    "abbocchereste": "abboccare",
    "abboccheresti": "abboccare",
    "abboccherete": "abboccare",
    "abboccherà": "abboccare",
    "abboccherò": "abboccare",
    "abbocchi": "abboccare",
    "abbocchiamo": "abboccare",
    "abbocchiate": "abboccare",
    "abbocchin": "abboccare",
    "abbocchino": "abboccare",
    "abbocco": "abboccare",
    "abboccò": "abboccare",
    "abboffa": "abboffare",
    "abboffai": "abboffare",
    "abboffammo": "abboffare",
    "abboffan": "abboffare",
    "abboffando": "abboffare",
    "abboffano": "abboffare",
    "abboffar": "abboffare",
    "abboffaron": "abboffare",
    "abboffarono": "abboffare",
    "abboffasse": "abboffare",
    "abboffasser": "abboffare",
    "abboffassero": "abboffare",
    "abboffassi": "abboffare",
    "abboffassimo": "abboffare",
    "abboffaste": "abboffare",
    "abboffasti": "abboffare",
    "abboffata": "abboffare",
    "abboffate": "abboffare",
    "abboffati": "abboffare",
    "abboffato": "abboffare",
    "abboffava": "abboffare",
    "abboffavamo": "abboffare",
    "abboffavan": "abboffare",
    "abboffavano": "abboffare",
    "abboffavate": "abboffare",
    "abboffavi": "abboffare",
    "abboffavo": "abboffare",
    "abbofferai": "abboffare",
    "abbofferan": "abboffare",
    "abbofferanno": "abboffare",
    "abbofferebbe": "abboffare",
    "abbofferebber": "abboffare",
    "abbofferebbero": "abboffare",
    "abbofferei": "abboffare",
    "abbofferemmo": "abboffare",
    "abbofferemo": "abboffare",
    "abboffereste": "abboffare",
    "abbofferesti": "abboffare",
    "abbofferete": "abboffare",
    "abbofferà": "abboffare",
    "abbofferò": "abboffare",
    "abboffi": "abboffare",
    "abboffiamo": "abboffare",
    "abboffiate": "abboffare",
    "abboffin": "abboffare",
    "abboffino": "abboffare",
    "abboffo": "abboffare",
    "abboffò": "abboffare",
    "abbona": "abbonare",
    "abbonaccerai": "abbonacciare",
    "abbonacceran": "abbonacciare",
    "abbonacceranno": "abbonacciare",
    "abbonaccerebbe": "abbonacciare",
    "abbonaccerebber": "abbonacciare",
    "abbonaccerebbero": "abbonacciare",
    "abbonaccerei": "abbonacciare",
    "abbonacceremmo": "abbonacciare",
    "abbonacceremo": "abbonacciare",
    "abbonaccereste": "abbonacciare",
    "abbonacceresti": "abbonacciare",
    "abbonaccerete": "abbonacciare",
    "abbonaccerà": "abbonacciare",
    "abbonaccerò": "abbonacciare",
    "abbonacci": "abbonacciare",
    "abbonaccia": "abbonacciare",
    "abbonacciai": "abbonacciare",
    "abbonacciammo": "abbonacciare",
    "abbonacciamo": "abbonacciare",
    "abbonaccian": "abbonacciare",
    "abbonacciando": "abbonacciare",
    "abbonacciano": "abbonacciare",
    "abbonacciante": "abbonacciare",
    "abbonaccianti": "abbonacciare",
    "abbonacciar": "abbonacciare",
    "abbonacciaron": "abbonacciare",
    "abbonacciarono": "abbonacciare",
    "abbonacciasse": "abbonacciare",
    "abbonacciasser": "abbonacciare",
    "abbonacciassero": "abbonacciare",
    "abbonacciassi": "abbonacciare",
    "abbonacciassimo": "abbonacciare",
    "abbonacciaste": "abbonacciare",
    "abbonacciasti": "abbonacciare",
    "abbonacciata": "abbonacciare",
    "abbonacciate": "abbonacciare",
    "abbonacciati": "abbonacciare",
    "abbonacciato": "abbonacciare",
    "abbonacciava": "abbonacciare",
    "abbonacciavamo": "abbonacciare",
    "abbonacciavan": "abbonacciare",
    "abbonacciavano": "abbonacciare",
    "abbonacciavate": "abbonacciare",
    "abbonacciavi": "abbonacciare",
    "abbonacciavo": "abbonacciare",
    "abbonaccin": "abbonacciare",
    "abbonaccino": "abbonacciare",
    "abbonaccio": "abbonacciare",
    "abbonacciò": "abbonacciare",
    "abbonai": "abbonare",
    "abbonamenti": "abbonamento",
    "abbonammo": "abbonare",
    "abbonan": "abbonare",
    "abbonando": "abbonare",
    "abbonano": "abbonare",
    "abbonante": "abbonare",
    "abbonanti": "abbonare",
    "abbonar": "abbonare",
    "abbonaron": "abbonare",
    "abbonarono": "abbonare",
    "abbonasse": "abbonare",
    "abbonasser": "abbonare",
    "abbonassero": "abbonare",
    "abbonassi": "abbonare",
    "abbonassimo": "abbonare",
    "abbonaste": "abbonare",
    "abbonasti": "abbonare",
    "abbonata": "abbonato",
    "abbonate": "abbonato",
    "abbonati": "abbonato",
    "abbonato": "abbonare",
    "abbonava": "abbonare",
    "abbonavamo": "abbonare",
    "abbonavan": "abbonare",
    "abbonavano": "abbonare",
    "abbonavate": "abbonare",
    "abbonavi": "abbonare",
    "abbonavo": "abbonare",
    "abbonda": "abbondare",
    "abbondai": "abbondare",
    "abbondammo": "abbondare",
    "abbondan": "abbondare",
    "abbondando": "abbondare",
    "abbondano": "abbondare",
    "abbondante": "abbondare",
    "abbondanti": "abbondare",
    "abbondanze": "abbondanza",
    "abbondar": "abbondare",
    "abbondaron": "abbondare",
    "abbondarono": "abbondare",
    "abbondasse": "abbondare",
    "abbondasser": "abbondare",
    "abbondassero": "abbondare",
    "abbondassi": "abbondare",
    "abbondassimo": "abbondare",
    "abbondaste": "abbondare",
    "abbondasti": "abbondare",
    "abbondata": "abbondare",
    "abbondate": "abbondare",
    "abbondati": "abbondare",
    "abbondato": "abbondare",
    "abbondava": "abbondare",
    "abbondavamo": "abbondare",
    "abbondavan": "abbondare",
    "abbondavano": "abbondare",
    "abbondavate": "abbondare",
    "abbondavi": "abbondare",
    "abbondavo": "abbondare",
    "abbonderai": "abbondare",
    "abbonderan": "abbondare",
    "abbonderanno": "abbondare",
    "abbonderebbe": "abbondare",
    "abbonderebber": "abbondare",
    "abbonderebbero": "abbondare",
    "abbonderei": "abbondare",
    "abbonderemmo": "abbondare",
    "abbonderemo": "abbondare",
    "abbondereste": "abbondare",
    "abbonderesti": "abbondare",
    "abbonderete": "abbondare",
    "abbonderà": "abbondare",
    "abbonderò": "abbondare",
    "abbondi": "abbondare",
    "abbondiamo": "abbondare",
    "abbondiate": "abbondare",
    "abbondin": "abbondare",
    "abbondino": "abbondare",
    "abbondo": "abbondare",
    "abbondò": "abbondare",
    "abbonerai": "abbonare",
    "abboneran": "abbonare",
    "abboneranno": "abbonare",
    "abbonerebbe": "abbonare",
    "abbonerebber": "abbonare",
    "abbonerebbero": "abbonare",
    "abbonerei": "abbonare",
    "abboneremmo": "abbonare",
    "abboneremo": "abbonare",
    "abbonereste": "abbonare",
    "abboneresti": "abbonare",
    "abbonerete": "abbonare",
    "abbonerà": "abbonare",
    "abbonerò": "abbonare",
    "abboni": "abbonare",
    "abboniamo": "abbonare",
    "abboniate": "abbonare",
    "abbonin": "abbonare",
    "abbonino": "abbonare",
    "abbono": "abbonare",
    "abbonò": "abbonare",
    "abborda": "abbordare",
    "abbordabili": "abbordabile",
    "abbordaggi": "abbordaggio",
    "abbordai": "abbordare",
    "abbordammo": "abbordare",
    "abbordan": "abbordare",
    "abbordando": "abbordare",
    "abbordano": "abbordare",
    "abbordante": "abbordare",
    "abbordanti": "abbordare",
    "abbordar": "abbordare",
    "abbordaron": "abbordare",
    "abbordarono": "abbordare",
    "abbordasse": "abbordare",
    "abbordasser": "abbordare",
    "abbordassero": "abbordare",
    "abbordassi": "abbordare",
    "abbordassimo": "abbordare",
    "abbordaste": "abbordare",
    "abbordasti": "abbordare",
    "abbordata": "abbordare",
    "abbordate": "abbordare",
    "abbordati": "abbordare",
    "abbordato": "abbordare",
    "abbordava": "abbordare",
    "abbordavamo": "abbordare",
    "abbordavan": "abbordare",
    "abbordavano": "abbordare",
    "abbordavate": "abbordare",
    "abbordavi": "abbordare",
    "abbordavo": "abbordare",
    "abborderai": "abbordare",
    "abborderan": "abbordare",
    "abborderanno": "abbordare",
    "abborderebbe": "abbordare",
    "abborderebber": "abbordare",
    "abborderebbero": "abbordare",
    "abborderei": "abbordare",
    "abborderemmo": "abbordare",
    "abborderemo": "abbordare",
    "abbordereste": "abbordare",
    "abborderesti": "abbordare",
    "abborderete": "abbordare",
    "abborderà": "abbordare",
    "abborderò": "abbordare",
    "abbordi": "abbordare",
    "abbordiamo": "abbordare",
    "abbordiate": "abbordare",
    "abbordin": "abbordare",
    "abbordino": "abbordare",
    "abbordo": "abbordare",
    "abbordò": "abbordare",
    "abborraccerai": "abborracciare",
    "abborracceran": "abborracciare",
    "abborracceranno": "abborracciare",
    "abborraccerebbe": "abborracciare",
    "abborraccerebber": "abborracciare",
    "abborraccerebbero": "abborracciare",
    "abborraccerei": "abborracciare",
    "abborracceremmo": "abborracciare",
    "abborracceremo": "abborracciare",
    "abborraccereste": "abborracciare",
    "abborracceresti": "abborracciare",
    "abborraccerete": "abborracciare",
    "abborraccerà": "abborracciare",
    "abborraccerò": "abborracciare",
    "abborracci": "abborracciare",
    "abborraccia": "abborracciare",
    "abborracciai": "abborracciare",
    "abborracciammo": "abborracciare",
    "abborracciamo": "abborracciare",
    "abborraccian": "abborracciare",
    "abborracciando": "abborracciare",
    "abborracciano": "abborracciare",
    "abborracciante": "abborracciare",
    "abborraccianti": "abborracciare",
    "abborracciar": "abborracciare",
    "abborracciaron": "abborracciare",
    "abborracciarono": "abborracciare",
    "abborracciasse": "abborracciare",
    "abborracciasser": "abborracciare",
    "abborracciassero": "abborracciare",
    "abborracciassi": "abborracciare",
    "abborracciassimo": "abborracciare",
    "abborracciaste": "abborracciare",
    "abborracciasti": "abborracciare",
    "abborracciata": "abborracciare",
    "abborracciate": "abborracciare",
    "abborracciati": "abborracciare",
    "abborracciato": "abborracciare",
    "abborracciava": "abborracciare",
    "abborracciavamo": "abborracciare",
    "abborracciavan": "abborracciare",
    "abborracciavano": "abborracciare",
    "abborracciavate": "abborracciare",
    "abborracciavi": "abborracciare",
    "abborracciavo": "abborracciare",
    "abborraccin": "abborracciare",
    "abborraccino": "abborracciare",
    "abborraccio": "abborracciare",
    "abborracciò": "abborracciare",
    "abbotta": "abbottare",
    "abbottai": "abbottare",
    "abbottammo": "abbottare",
    "abbottan": "abbottare",
    "abbottando": "abbottare",
    "abbottano": "abbottare",
    "abbottante": "abbottare",
    "abbottanti": "abbottare",
    "abbottar": "abbottare",
    "abbottaron": "abbottare",
    "abbottarono": "abbottare",
    "abbottasse": "abbottare",
    "abbottasser": "abbottare",
    "abbottassero": "abbottare",
    "abbottassi": "abbottare",
    "abbottassimo": "abbottare",
    "abbottaste": "abbottare",
    "abbottasti": "abbottare",
    "abbottata": "abbottare",
    "abbottate": "abbottare",
    "abbottati": "abbottare",
    "abbottato": "abbottare",
    "abbottava": "abbottare",
    "abbottavamo": "abbottare",
    "abbottavan": "abbottare",
    "abbottavano": "abbottare",
    "abbottavate": "abbottare",
    "abbottavi": "abbottare",
    "abbottavo": "abbottare",
    "abbotterai": "abbottare",
    "abbotteran": "abbottare",
    "abbotteranno": "abbottare",
    "abbotterebbe": "abbottare",
    "abbotterebber": "abbottare",
    "abbotterebbero": "abbottare",
    "abbotterei": "abbottare",
    "abbotteremmo": "abbottare",
    "abbotteremo": "abbottare",
    "abbottereste": "abbottare",
    "abbotteresti": "abbottare",
    "abbotterete": "abbottare",
    "abbotterà": "abbottare",
    "abbotterò": "abbottare",
    "abbotti": "abbottare",
    "abbottiamo": "abbottare",
    "abbottiate": "abbottare",
    "abbottin": "abbottare",
    "abbottino": "abbottare",
    "abbotto": "abbottare",
    "abbottona": "abbottonare",
    "abbottonai": "abbottonare",
    "abbottonammo": "abbottonare",
    "abbottonan": "abbottonare",
    "abbottonando": "abbottonare",
    "abbottonano": "abbottonare",
    "abbottonante": "abbottonare",
    "abbottonanti": "abbottonare",
    "abbottonar": "abbottonare",
    "abbottonaron": "abbottonare",
    "abbottonarono": "abbottonare",
    "abbottonasse": "abbottonare",
    "abbottonasser": "abbottonare",
    "abbottonassero": "abbottonare",
    "abbottonassi": "abbottonare",
    "abbottonassimo": "abbottonare",
    "abbottonaste": "abbottonare",
    "abbottonasti": "abbottonare",
    "abbottonata": "abbottonato",
    "abbottonate": "abbottonato",
    "abbottonati": "abbottonato",
    "abbottonato": "abbottonare",
    "abbottonava": "abbottonare",
    "abbottonavamo": "abbottonare",
    "abbottonavan": "abbottonare",
    "abbottonavano": "abbottonare",
    "abbottonavate": "abbottonare",
    "abbottonavi": "abbottonare",
    "abbottonavo": "abbottonare",
    "abbottonerai": "abbottonare",
    "abbottoneran": "abbottonare",
    "abbottoneranno": "abbottonare",
    "abbottonerebbe": "abbottonare",
    "abbottonerebber": "abbottonare",
    "abbottonerebbero": "abbottonare",
    "abbottonerei": "abbottonare",
    "abbottoneremmo": "abbottonare",
    "abbottoneremo": "abbottonare",
    "abbottonereste": "abbottonare",
    "abbottoneresti": "abbottonare",
    "abbottonerete": "abbottonare",
    "abbottonerà": "abbottonare",
    "abbottonerò": "abbottonare",
    "abbottoni": "abbottonare",
    "abbottoniamo": "abbottonare",
    "abbottoniate": "abbottonare",
    "abbottonin": "abbottonare",
    "abbottonino": "abbottonare",
    "abbottono": "abbottonare",
    "abbottonò": "abbottonare",
    "abbottò": "abbottare",
    "abbozza": "abbozzare",
    "abbozzai": "abbozzare",
    "abbozzammo": "abbozzare",
    "abbozzan": "abbozzare",
    "abbozzando": "abbozzare",
    "abbozzano": "abbozzare",
    "abbozzante": "abbozzare",
    "abbozzanti": "abbozzare",
    "abbozzar": "abbozzare",
    "abbozzaron": "abbozzare",
    "abbozzarono": "abbozzare",
    "abbozzasse": "abbozzare",
    "abbozzasser": "abbozzare",
    "abbozzassero": "abbozzare",
    "abbozzassi": "abbozzare",
    "abbozzassimo": "abbozzare",
    "abbozzaste": "abbozzare",
    "abbozzasti": "abbozzare",
    "abbozzata": "abbozzato",
    "abbozzate": "abbozzato",
    "abbozzati": "abbozzato",
    "abbozzato": "abbozzare",
    "abbozzava": "abbozzare",
    "abbozzavamo": "abbozzare",
    "abbozzavan": "abbozzare",
    "abbozzavano": "abbozzare",
    "abbozzavate": "abbozzare",
    "abbozzavi": "abbozzare",
    "abbozzavo": "abbozzare",
    "abbozzerai": "abbozzare",
    "abbozzeran": "abbozzare",
    "abbozzeranno": "abbozzare",
    "abbozzerebbe": "abbozzare",
    "abbozzerebber": "abbozzare",
    "abbozzerebbero": "abbozzare",
    "abbozzerei": "abbozzare",
    "abbozzeremmo": "abbozzare",
    "abbozzeremo": "abbozzare",
    "abbozzereste": "abbozzare",
    "abbozzeresti": "abbozzare",
    "abbozzerete": "abbozzare",
    "abbozzerà": "abbozzare",
    "abbozzerò": "abbozzare",
    "abbozzi": "abbozzo",
    "abbozziamo": "abbozzare",
    "abbozziate": "abbozzare",
    "abbozzin": "abbozzare",
    "abbozzino": "abbozzare",
    "abbozzo": "abbozzare",
    "abbozzò": "abbozzare",
    "abbraccerai": "abbracciare",
    "abbracceran": "abbracciare",
    "abbracceranno": "abbracciare",
    "abbraccerebbe": "abbracciare",
    "abbraccerebber": "abbracciare",
    "abbraccerebbero": "abbracciare",
    "abbraccerei": "abbracciare",
    "abbracceremmo": "abbracciare",
    "abbracceremo": "abbracciare",
    "abbraccereste": "abbracciare",
    "abbracceresti": "abbracciare",
    "abbraccerete": "abbracciare",
    "abbraccerà": "abbracciare",
    "abbraccerò": "abbracciare",
    "abbracci": "abbraccio",
    "abbraccia": "abbracciare",
    "abbracciai": "abbracciare",
    "abbracciammo": "abbracciare",
    "abbracciamo": "abbracciare",
    "abbraccian": "abbracciare",
    "abbracciando": "abbracciare",
    "abbracciano": "abbracciare",
    "abbracciante": "abbracciare",
    "abbraccianti": "abbracciare",
    "abbracciar": "abbracciare",
    "abbracciaron": "abbracciare",
    "abbracciarono": "abbracciare",
    "abbracciasse": "abbracciare",
    "abbracciasser": "abbracciare",
    "abbracciassero": "abbracciare",
    "abbracciassi": "abbracciare",
    "abbracciassimo": "abbracciare",
    "abbracciaste": "abbracciare",
    "abbracciasti": "abbracciare",
    "abbracciata": "abbracciare",
    "abbracciate": "abbracciare",
    "abbracciati": "abbracciare",
    "abbracciato": "abbracciare",
    "abbracciava": "abbracciare",
    "abbracciavamo": "abbracciare",
    "abbracciavan": "abbracciare",
    "abbracciavano": "abbracciare",
    "abbracciavate": "abbracciare",
    "abbracciavi": "abbracciare",
    "abbracciavo": "abbracciare",
    "abbraccin": "abbracciare",
    "abbraccino": "abbracciare",
    "abbraccio": "abbracciare",
    "abbracciò": "abbracciare",
    "abbranca": "abbrancare",
    "abbrancai": "abbrancare",
    "abbrancammo": "abbrancare",
    "abbrancan": "abbrancare",
    "abbrancando": "abbrancare",
    "abbrancano": "abbrancare",
    "abbrancante": "abbrancare",
    "abbrancanti": "abbrancare",
    "abbrancar": "abbrancare",
    "abbrancaron": "abbrancare",
    "abbrancarono": "abbrancare",
    "abbrancasse": "abbrancare",
    "abbrancasser": "abbrancare",
    "abbrancassero": "abbrancare",
    "abbrancassi": "abbrancare",
    "abbrancassimo": "abbrancare",
    "abbrancaste": "abbrancare",
    "abbrancasti": "abbrancare",
    "abbrancata": "abbrancare",
    "abbrancate": "abbrancare",
    "abbrancati": "abbrancare",
    "abbrancato": "abbrancare",
    "abbrancava": "abbrancare",
    "abbrancavamo": "abbrancare",
    "abbrancavan": "abbrancare",
    "abbrancavano": "abbrancare",
    "abbrancavate": "abbrancare",
    "abbrancavi": "abbrancare",
    "abbrancavo": "abbrancare",
    "abbrancherai": "abbrancare",
    "abbrancheran": "abbrancare",
    "abbrancheranno": "abbrancare",
    "abbrancherebbe": "abbrancare",
    "abbrancherebber": "abbrancare",
    "abbrancherebbero": "abbrancare",
    "abbrancherei": "abbrancare",
    "abbrancheremmo": "abbrancare",
    "abbrancheremo": "abbrancare",
    "abbranchereste": "abbrancare",
    "abbrancheresti": "abbrancare",
    "abbrancherete": "abbrancare",
    "abbrancherà": "abbrancare",
    "abbrancherò": "abbrancare",
    "abbranchi": "abbrancare",
    "abbranchiamo": "abbrancare",
    "abbranchiate": "abbrancare",
    "abbranchin": "abbrancare",
    "abbranchino": "abbrancare",
    "abbranco": "abbrancare",
    "abbrancò": "abbrancare",
    "abbrevi": "abbreviare",
    "abbrevia": "abbreviare",
    "abbreviabili": "abbreviabile",
    "abbreviai": "abbreviare",
    "abbreviammo": "abbreviare",
    "abbreviamo": "abbreviare",
    "abbrevian": "abbreviare",
    "abbreviando": "abbreviare",
    "abbreviano": "abbreviare",
    "abbreviante": "abbreviare",
    "abbrevianti": "abbreviare",
    "abbreviar": "abbreviare",
    "abbreviaron": "abbreviare",
    "abbreviarono": "abbreviare",
    "abbreviasse": "abbreviare",
    "abbreviasser": "abbreviare",
    "abbreviassero": "abbreviare",
    "abbreviassi": "abbreviare",
    "abbreviassimo": "abbreviare",
    "abbreviaste": "abbreviare",
    "abbreviasti": "abbreviare",
    "abbreviata": "abbreviare",
    "abbreviate": "abbreviare",
    "abbreviati": "abbreviare",
    "abbreviato": "abbreviare",
    "abbreviava": "abbreviare",
    "abbreviavamo": "abbreviare",
    "abbreviavan": "abbreviare",
    "abbreviavano": "abbreviare",
    "abbreviavate": "abbreviare",
    "abbreviavi": "abbreviare",
    "abbreviavo": "abbreviare",
    "abbreviazioni": "abbreviazione",
    "abbrevierai": "abbreviare",
    "abbrevieran": "abbreviare",
    "abbrevieranno": "abbreviare",
    "abbrevierebbe": "abbreviare",
    "abbrevierebber": "abbreviare",
    "abbrevierebbero": "abbreviare",
    "abbrevierei": "abbreviare",
    "abbrevieremmo": "abbreviare",
    "abbrevieremo": "abbreviare",
    "abbreviereste": "abbreviare",
    "abbrevieresti": "abbreviare",
    "abbrevierete": "abbreviare",
    "abbrevierà": "abbreviare",
    "abbrevierò": "abbreviare",
    "abbrevin": "abbreviare",
    "abbrevino": "abbreviare",
    "abbrevio": "abbreviare",
    "abbreviò": "abbreviare",
    "abbronza": "abbronzare",
    "abbronzai": "abbronzare",
    "abbronzammo": "abbronzare",
    "abbronzan": "abbronzare",
    "abbronzando": "abbronzare",
    "abbronzano": "abbronzare",
    "abbronzante": "abbronzare",
    "abbronzanti": "abbronzare",
    "abbronzar": "abbronzare",
    "abbronzaron": "abbronzare",
    "abbronzarono": "abbronzare",
    "abbronzasse": "abbronzare",
    "abbronzasser": "abbronzare",
    "abbronzassero": "abbronzare",
    "abbronzassi": "abbronzare",
    "abbronzassimo": "abbronzare",
    "abbronzaste": "abbronzare",
    "abbronzasti": "abbronzare",
    "abbronzata": "abbronzare",
    "abbronzate": "abbronzare",
    "abbronzati": "abbronzare",
    "abbronzato": "abbronzare",
    "abbronzature": "abbronzatura",
    "abbronzava": "abbronzare",
    "abbronzavamo": "abbronzare",
    "abbronzavan": "abbronzare",
    "abbronzavano": "abbronzare",
    "abbronzavate": "abbronzare",
    "abbronzavi": "abbronzare",
    "abbronzavo": "abbronzare",
    "abbronzerai": "abbronzare",
    "abbronzeran": "abbronzare",
    "abbronzeranno": "abbronzare",
    "abbronzerebbe": "abbronzare",
    "abbronzerebber": "abbronzare",
    "abbronzerebbero": "abbronzare",
    "abbronzerei": "abbronzare",
    "abbronzeremmo": "abbronzare",
    "abbronzeremo": "abbronzare",
    "abbronzereste": "abbronzare",
    "abbronzeresti": "abbronzare",
    "abbronzerete": "abbronzare",
    "abbronzerà": "abbronzare",
    "abbronzerò": "abbronzare",
    "abbronzi": "abbronzare",
    "abbronziamo": "abbronzare",
    "abbronziate": "abbronzare",
    "abbronzin": "abbronzare",
    "abbronzino": "abbronzare",
    "abbronzo": "abbronzare",
    "abbronzò": "abbronzare",
    "abbruna": "abbrunare",
    "abbrunai": "abbrunare",
    "abbrunammo": "abbrunare",
    "abbrunan": "abbrunare",
    "abbrunando": "abbrunare",
    "abbrunano": "abbrunare",
    "abbrunante": "abbrunare",
    "abbrunanti": "abbrunare",
    "abbrunar": "abbrunare",
    "abbrunaron": "abbrunare",
    "abbrunarono": "abbrunare",
    "abbrunasse": "abbrunare",
    "abbrunasser": "abbrunare",
    "abbrunassero": "abbrunare",
    "abbrunassi": "abbrunare",
    "abbrunassimo": "abbrunare",
    "abbrunaste": "abbrunare",
    "abbrunasti": "abbrunare",
    "abbrunata": "abbrunare",
    "abbrunate": "abbrunare",
    "abbrunati": "abbrunare",
    "abbrunato": "abbrunare",
    "abbrunava": "abbrunare",
    "abbrunavamo": "abbrunare",
    "abbrunavan": "abbrunare",
    "abbrunavano": "abbrunare",
    "abbrunavate": "abbrunare",
    "abbrunavi": "abbrunare",
    "abbrunavo": "abbrunare",
    "abbrunerai": "abbrunare",
    "abbruneran": "abbrunare",
    "abbruneranno": "abbrunare",
    "abbrunerebbe": "abbrunare",
    "abbrunerebber": "abbrunare",
    "abbrunerebbero": "abbrunare",
    "abbrunerei": "abbrunare",
    "abbruneremmo": "abbrunare",
    "abbruneremo": "abbrunare",
    "abbrunereste": "abbrunare",
    "abbruneresti": "abbrunare",
    "abbrunerete": "abbrunare",
    "abbrunerà": "abbrunare",
    "abbrunerò": "abbrunare",
    "abbruni": "abbrunare",
    "abbruniamo": "abbrunare",
    "abbruniate": "abbrunare",
    "abbrunin": "abbrunare",
    "abbrunino": "abbrunare",
    "abbruno": "abbrunare",
    "abbrunò": "abbrunare",
    "abbrustolendo": "abbrustolire",
    "abbrustolente": "abbrustolire",
    "abbrustolenti": "abbrustolire",
    "abbrustoliamo": "abbrustolire",
    "abbrustoliate": "abbrustolire",
    "abbrustolii": "abbrustolire",
    "abbrustolimmo": "abbrustolire",
    "abbrustolir": "abbrustolire",
    "abbrustolirai": "abbrustolire",
    "abbrustoliran": "abbrustolire",
    "abbrustoliranno": "abbrustolire",
    "abbrustolirebbe": "abbrustolire",
    "abbrustolirebber": "abbrustolire",
    "abbrustolirebbero": "abbrustolire",
    "abbrustolirei": "abbrustolire",
    "abbrustoliremmo": "abbrustolire",
    "abbrustoliremo": "abbrustolire",
    "abbrustolireste": "abbrustolire",
    "abbrustoliresti": "abbrustolire",
    "abbrustolirete": "abbrustolire",
    "abbrustoliron": "abbrustolire",
    "abbrustolirono": "abbrustolire",
    "abbrustolirà": "abbrustolire",
    "abbrustolirò": "abbrustolire",
    "abbrustolisca": "abbrustolire",
    "abbrustoliscan": "abbrustolire",
    "abbrustoliscano": "abbrustolire",
    "abbrustolisce": "abbrustolire",
    "abbrustolisci": "abbrustolire",
    "abbrustolisco": "abbrustolire",
    "abbrustoliscon": "abbrustolire",
    "abbrustoliscono": "abbrustolire",
    "abbrustolisse": "abbrustolire",
    "abbrustolisser": "abbrustolire",
    "abbrustolissero": "abbrustolire",
    "abbrustolissi": "abbrustolire",
    "abbrustolissimo": "abbrustolire",
    "abbrustoliste": "abbrustolire",
    "abbrustolisti": "abbrustolire",
    "abbrustolita": "abbrustolire",
    "abbrustolite": "abbrustolire",
    "abbrustoliti": "abbrustolire",
    "abbrustolito": "abbrustolire",
    "abbrustoliva": "abbrustolire",
    "abbrustolivamo": "abbrustolire",
    "abbrustolivan": "abbrustolire",
    "abbrustolivano": "abbrustolire",
    "abbrustolivate": "abbrustolire",
    "abbrustolivi": "abbrustolire",
    "abbrustolivo": "abbrustolire",
    "abbrustolì": "abbrustolire",
    "abbruta": "abbrutire",
    "abbrutan": "abbrutire",
    "abbrutano": "abbrutire",
    "abbrute": "abbrutire",
    "abbrutendo": "abbrutire",
    "abbrutente": "abbrutire",
    "abbrutenti": "abbrutire",
    "abbruti": "abbrutire",
    "abbrutiamo": "abbrutire",
    "abbrutiate": "abbrutire",
    "abbrutii": "abbrutire",
    "abbrutimmo": "abbrutire",
    "abbrutir": "abbrutire",
    "abbrutirai": "abbrutire",
    "abbrutiran": "abbrutire",
    "abbrutiranno": "abbrutire",
    "abbrutirebbe": "abbrutire",
    "abbrutirebber": "abbrutire",
    "abbrutirebbero": "abbrutire",
    "abbrutirei": "abbrutire",
    "abbrutiremmo": "abbrutire",
    "abbrutiremo": "abbrutire",
    "abbrutireste": "abbrutire",
    "abbrutiresti": "abbrutire",
    "abbrutirete": "abbrutire",
    "abbrutiron": "abbrutire",
    "abbrutirono": "abbrutire",
    "abbrutirà": "abbrutire",
    "abbrutirò": "abbrutire",
    "abbrutisse": "abbrutire",
    "abbrutisser": "abbrutire",
    "abbrutissero": "abbrutire",
    "abbrutissi": "abbrutire",
    "abbrutissimo": "abbrutire",
    "abbrutiste": "abbrutire",
    "abbrutisti": "abbrutire",
    "abbrutita": "abbrutire",
    "abbrutite": "abbrutire",
    "abbrutiti": "abbrutire",
    "abbrutito": "abbrutire",
    "abbrutiva": "abbrutire",
    "abbrutivamo": "abbrutire",
    "abbrutivan": "abbrutire",
    "abbrutivano": "abbrutire",
    "abbrutivate": "abbrutire",
    "abbrutivi": "abbrutire",
    "abbrutivo": "abbrutire",
    "abbruto": "abbrutire",
    "abbruton": "abbrutire",
    "abbrutono": "abbrutire",
    "abbruttendo": "abbruttire",
    "abbruttente": "abbruttire",
    "abbruttenti": "abbruttire",
    "abbruttiamo": "abbruttire",
    "abbruttiate": "abbruttire",
    "abbruttii": "abbruttire",
    "abbruttimmo": "abbruttire",
    "abbruttir": "abbruttire",
    "abbruttirai": "abbruttire",
    "abbruttiran": "abbruttire",
    "abbruttiranno": "abbruttire",
    "abbruttirebbe": "abbruttire",
    "abbruttirebber": "abbruttire",
    "abbruttirebbero": "abbruttire",
    "abbruttirei": "abbruttire",
    "abbruttiremmo": "abbruttire",
    "abbruttiremo": "abbruttire",
    "abbruttireste": "abbruttire",
    "abbruttiresti": "abbruttire",
    "abbruttirete": "abbruttire",
    "abbruttiron": "abbruttire",
    "abbruttirono": "abbruttire",
    "abbruttirà": "abbruttire",
    "abbruttirò": "abbruttire",
    "abbruttisca": "abbruttire",
    "abbruttiscan": "abbruttire",
    "abbruttiscano": "abbruttire",
    "abbruttisce": "abbruttire",
    "abbruttisci": "abbruttire",
    "abbruttisco": "abbruttire",
    "abbruttiscon": "abbruttire",
    "abbruttiscono": "abbruttire",
    "abbruttisse": "abbruttire",
    "abbruttisser": "abbruttire",
    "abbruttissero": "abbruttire",
    "abbruttissi": "abbruttire",
    "abbruttissimo": "abbruttire",
    "abbruttiste": "abbruttire",
    "abbruttisti": "abbruttire",
    "abbruttita": "abbruttire",
    "abbruttite": "abbruttire",
    "abbruttiti": "abbruttire",
    "abbruttito": "abbruttire",
    "abbruttiva": "abbruttire",
    "abbruttivamo": "abbruttire",
    "abbruttivan": "abbruttire",
    "abbruttivano": "abbruttire",
    "abbruttivate": "abbruttire",
    "abbruttivi": "abbruttire",
    "abbruttivo": "abbruttire",
    "abbruttì": "abbruttire",
    "abbrutì": "abbrutire",
    "abbuffa": "abbuffare",
    "abbuffai": "abbuffare",
    "abbuffammo": "abbuffare",
    "abbuffan": "abbuffare",
    "abbuffando": "abbuffare",
    "abbuffano": "abbuffare",
    "abbuffar": "abbuffare",
    "abbuffaron": "abbuffare",
    "abbuffarono": "abbuffare",
    "abbuffasse": "abbuffare",
    "abbuffasser": "abbuffare",
    "abbuffassero": "abbuffare",
    "abbuffassi": "abbuffare",
    "abbuffassimo": "abbuffare",
    "abbuffaste": "abbuffare",
    "abbuffasti": "abbuffare",
    "abbuffata": "abbuffare",
    "abbuffate": "abbuffata",
    "abbuffati": "abbuffare",
    "abbuffato": "abbuffare",
    "abbuffava": "abbuffare",
    "abbuffavamo": "abbuffare",
    "abbuffavan": "abbuffare",
    "abbuffavano": "abbuffare",
    "abbuffavate": "abbuffare",
    "abbuffavi": "abbuffare",
    "abbuffavo": "abbuffare",
    "abbufferai": "abbuffare",
    "abbufferan": "abbuffare",
    "abbufferanno": "abbuffare",
    "abbufferebbe": "abbuffare",
    "abbufferebber": "abbuffare",
    "abbufferebbero": "abbuffare",
    "abbufferei": "abbuffare",
    "abbufferemmo": "abbuffare",
    "abbufferemo": "abbuffare",
    "abbuffereste": "abbuffare",
    "abbufferesti": "abbuffare",
    "abbufferete": "abbuffare",
    "abbufferà": "abbuffare",
    "abbufferò": "abbuffare",
    "abbuffi": "abbuffare",
    "abbuffiamo": "abbuffare",
    "abbuffiate": "abbuffare",
    "abbuffin": "abbuffare",
    "abbuffino": "abbuffare",
    "abbuffo": "abbuffare",
    "abbuffò": "abbuffare",
    "abbui": "abbuiare",
    "abbuia": "abbuiare",
    "abbuiai": "abbuiare",
    "abbuiammo": "abbuiare",
    "abbuiamo": "abbuiare",
    "abbuian": "abbuiare",
    "abbuiando": "abbuiare",
    "abbuiano": "abbuiare",
    "abbuiante": "abbuiare",
    "abbuianti": "abbuiare",
    "abbuiar": "abbuiare",
    "abbuiaron": "abbuiare",
    "abbuiarono": "abbuiare",
    "abbuiasse": "abbuiare",
    "abbuiasser": "abbuiare",
    "abbuiassero": "abbuiare",
    "abbuiassi": "abbuiare",
    "abbuiassimo": "abbuiare",
    "abbuiaste": "abbuiare",
    "abbuiasti": "abbuiare",
    "abbuiata": "abbuiare",
    "abbuiate": "abbuiare",
    "abbuiati": "abbuiare",
    "abbuiato": "abbuiare",
    "abbuiava": "abbuiare",
    "abbuiavamo": "abbuiare",
    "abbuiavan": "abbuiare",
    "abbuiavano": "abbuiare",
    "abbuiavate": "abbuiare",
    "abbuiavi": "abbuiare",
    "abbuiavo": "abbuiare",
    "abbuierai": "abbuiare",
    "abbuieran": "abbuiare",
    "abbuieranno": "abbuiare",
    "abbuierebbe": "abbuiare",
    "abbuierebber": "abbuiare",
    "abbuierebbero": "abbuiare",
    "abbuierei": "abbuiare",
    "abbuieremmo": "abbuiare",
    "abbuieremo": "abbuiare",
    "abbuiereste": "abbuiare",
    "abbuieresti": "abbuiare",
    "abbuierete": "abbuiare",
    "abbuierà": "abbuiare",
    "abbuierò": "abbuiare",
    "abbuin": "abbuiare",
    "abbuino": "abbuiare",
    "abbuio": "abbuiare",
    "abbuiò": "abbuiare",
    "abbuona": "abbuonare",
    "abbuonai": "abbuonare",
    "abbuonammo": "abbuonare",
    "abbuonan": "abbuonare",
    "abbuonando": "abbuonare",
    "abbuonano": "abbuonare",
    "abbuonante": "abbuonare",
    "abbuonanti": "abbuonare",
    "abbuonar": "abbuonare",
    "abbuonaron": "abbuonare",
    "abbuonarono": "abbuonare",
    "abbuonasse": "abbuonare",
    "abbuonasser": "abbuonare",
    "abbuonassero": "abbuonare",
    "abbuonassi": "abbuonare",
    "abbuonassimo": "abbuonare",
    "abbuonaste": "abbuonare",
    "abbuonasti": "abbuonare",
    "abbuonata": "abbuonare",
    "abbuonate": "abbuonare",
    "abbuonati": "abbuonare",
    "abbuonato": "abbuonare",
    "abbuonava": "abbuonare",
    "abbuonavamo": "abbuonare",
    "abbuonavan": "abbuonare",
    "abbuonavano": "abbuonare",
    "abbuonavate": "abbuonare",
    "abbuonavi": "abbuonare",
    "abbuonavo": "abbuonare",
    "abbuonerai": "abbuonare",
    "abbuoneran": "abbuonare",
    "abbuoneranno": "abbuonare",
    "abbuonerebbe": "abbuonare",
    "abbuonerebber": "abbuonare",
    "abbuonerebbero": "abbuonare",
    "abbuonerei": "abbuonare",
    "abbuoneremmo": "abbuonare",
    "abbuoneremo": "abbuonare",
    "abbuonereste": "abbuonare",
    "abbuoneresti": "abbuonare",
    "abbuonerete": "abbuonare",
    "abbuonerà": "abbuonare",
    "abbuonerò": "abbuonare",
    "abbuoni": "abbuono",
    "abbuoniamo": "abbuonare",
    "abbuoniate": "abbuonare",
    "abbuonin": "abbuonare",
    "abbuonino": "abbuonare",
    "abbuono": "abbuonare",
    "abbuonò": "abbuonare",
    "abburatta": "abburattare",
    "abburattai": "abburattare",
    "abburattammo": "abburattare",
    "abburattan": "abburattare",
    "abburattando": "abburattare",
    "abburattano": "abburattare",
    "abburattante": "abburattare",
    "abburattanti": "abburattare",
    "abburattar": "abburattare",
    "abburattaron": "abburattare",
    "abburattarono": "abburattare",
    "abburattasse": "abburattare",
    "abburattasser": "abburattare",
    "abburattassero": "abburattare",
    "abburattassi": "abburattare",
    "abburattassimo": "abburattare",
    "abburattaste": "abburattare",
    "abburattasti": "abburattare",
    "abburattata": "abburattare",
    "abburattate": "abburattare",
    "abburattati": "abburattare",
    "abburattato": "abburattare",
    "abburattava": "abburattare",
    "abburattavamo": "abburattare",
    "abburattavan": "abburattare",
    "abburattavano": "abburattare",
    "abburattavate": "abburattare",
    "abburattavi": "abburattare",
    "abburattavo": "abburattare",
    "abburatterai": "abburattare",
    "abburatteran": "abburattare",
    "abburatteranno": "abburattare",
    "abburatterebbe": "abburattare",
    "abburatterebber": "abburattare",
    "abburatterebbero": "abburattare",
    "abburatterei": "abburattare",
    "abburatteremmo": "abburattare",
    "abburatteremo": "abburattare",
    "abburattereste": "abburattare",
    "abburatteresti": "abburattare",
    "abburatterete": "abburattare",
    "abburatterà": "abburattare",
    "abburatterò": "abburattare",
    "abburatti": "abburattare",
    "abburattiamo": "abburattare",
    "abburattiate": "abburattare",
    "abburattin": "abburattare",
    "abburattino": "abburattare",
    "abburatto": "abburattare",
    "abburattò": "abburattare",
    "abdica": "abdicare",
    "abdicai": "abdicare",
    "abdicammo": "abdicare",
    "abdican": "abdicare",
    "abdicando": "abdicare",
    "abdicano": "abdicare",
    "abdicante": "abdicare",
    "abdicanti": "abdicare",
    "abdicar": "abdicare",
    "abdicaron": "abdicare",
    "abdicarono": "abdicare",
    "abdicasse": "abdicare",
    "abdicasser": "abdicare",
    "abdicassero": "abdicare",
    "abdicassi": "abdicare",
    "abdicassimo": "abdicare",
    "abdicaste": "abdicare",
    "abdicasti": "abdicare",
    "abdicata": "abdicare",
    "abdicate": "abdicare",
    "abdicati": "abdicare",
    "abdicato": "abdicare",
    "abdicava": "abdicare",
    "abdicavamo": "abdicare",
    "abdicavan": "abdicare",
    "abdicavano": "abdicare",
    "abdicavate": "abdicare",
    "abdicavi": "abdicare",
    "abdicavo": "abdicare",
    "abdicazioni": "abdicazione",
    "abdicherai": "abdicare",
    "abdicheran": "abdicare",
    "abdicheranno": "abdicare",
    "abdicherebbe": "abdicare",
    "abdicherebber": "abdicare",
    "abdicherebbero": "abdicare",
    "abdicherei": "abdicare",
    "abdicheremmo": "abdicare",
    "abdicheremo": "abdicare",
    "abdichereste": "abdicare",
    "abdicheresti": "abdicare",
    "abdicherete": "abdicare",
    "abdicherà": "abdicare",
    "abdicherò": "abdicare",
    "abdichi": "abdicare",
    "abdichiamo": "abdicare",
    "abdichiate": "abdicare",
    "abdichin": "abdicare",
    "abdichino": "abdicare",
    "abdico": "abdicare",
    "abdicò": "abdicare",
    "aberra": "aberrare",
    "aberrai": "aberrare",
    "aberrammo": "aberrare",
    "aberran": "aberrare",
    "aberrando": "aberrare",
    "aberrano": "aberrare",
    "aberrante": "aberrare",
    "aberranti": "aberrare",
    "aberrar": "aberrare",
    "aberraron": "aberrare",
    "aberrarono": "aberrare",
    "aberrasse": "aberrare",
    "aberrasser": "aberrare",
    "aberrassero": "aberrare",
    "aberrassi": "aberrare",
    "aberrassimo": "aberrare",
    "aberraste": "aberrare",
    "aberrasti": "aberrare",
    "aberrata": "aberrare",
    "aberrate": "aberrare",
    "aberrati": "aberrare",
    "aberrato": "aberrare",
    "aberrava": "aberrare",
    "aberravamo": "aberrare",
    "aberravan": "aberrare",
    "aberravano": "aberrare",
    "aberravate": "aberrare",
    "aberravi": "aberrare",
    "aberravo": "aberrare",
    "aberrazioni": "aberrazione",
    "aberrerai": "aberrare",
    "aberreran": "aberrare",
    "aberreranno": "aberrare",
    "aberrerebbe": "aberrare",
    "aberrerebber": "aberrare",
    "aberrerebbero": "aberrare",
    "aberrerei": "aberrare",
    "aberreremmo": "aberrare",
    "aberreremo": "aberrare",
    "aberrereste": "aberrare",
    "aberreresti": "aberrare",
    "aberrerete": "aberrare",
    "aberrerà": "aberrare",
    "aberrerò": "aberrare",
    "aberri": "aberrare",
    "aberriamo": "aberrare",
    "aberriate": "aberrare",
    "aberrin": "aberrare",
    "aberrino": "aberrare",
    "aberro": "aberrare",
    "aberrò": "aberrare",
    "abeti": "abete",
    "abietta": "abietto",
    "abiette": "abietto",
    "abietti": "abietto",
    "abiezioni": "abiezione",
    "abili": "abile",
    "abilita": "abilitare",
    "abilitai": "abilitare",
    "abilitammo": "abilitare",
    "abilitan": "abilitare",
    "abilitando": "abilitare",
    "abilitano": "abilitare",
    "abilitante": "abilitare",
    "abilitanti": "abilitare",
    "abilitar": "abilitare",
    "abilitaron": "abilitare",
    "abilitarono": "abilitare",
    "abilitasse": "abilitare",
    "abilitasser": "abilitare",
    "abilitassero": "abilitare",
    "abilitassi": "abilitare",
    "abilitassimo": "abilitare",
    "abilitaste": "abilitare",
    "abilitasti": "abilitare",
    "abilitata": "abilitato",
    "abilitate": "abilitato",
    "abilitati": "abilitato",
    "abilitato": "abilitare",
    "abilitava": "abilitare",
    "abilitavamo": "abilitare",
    "abilitavan": "abilitare",
    "abilitavano": "abilitare",
    "abilitavate": "abilitare",
    "abilitavi": "abilitare",
    "abilitavo": "abilitare",
    "abilitazioni": "abilitazione",
    "abiliterai": "abilitare",
    "abiliteran": "abilitare",
    "abiliteranno": "abilitare",
    "abiliterebbe": "abilitare",
    "abiliterebber": "abilitare",
    "abiliterebbero": "abilitare",
    "abiliterei": "abilitare",
    "abiliteremmo": "abilitare",
    "abiliteremo": "abilitare",
    "abilitereste": "abilitare",
    "abiliteresti": "abilitare",
    "abiliterete": "abilitare",
    "abiliterà": "abilitare",
    "abiliterò": "abilitare",
    "abiliti": "abilitare",
    "abilitiamo": "abilitare",
    "abilitiate": "abilitare",
    "abilitin": "abilitare",
    "abilitino": "abilitare",
    "abilito": "abilitare",
    "abilitò": "abilitare",
    "abissali": "abissale",
    "abissi": "abisso",
    "abita": "abitare",
    "abitabili": "abitabile",
    "abitacoli": "abitacolo",
    "abitai": "abitare",
    "abitammo": "abitare",
    "abitan": "abitare",
    "abitando": "abitare",
    "abitano": "abitare",
    "abitante": "abitare",
    "abitanti": "abitare",
    "abitar": "abitare",
    "abitaron": "abitare",
    "abitarono": "abitare",
    "abitasse": "abitare",
    "abitasser": "abitare",
    "abitassero": "abitare",
    "abitassi": "abitare",
    "abitassimo": "abitare",
    "abitaste": "abitare",
    "abitasti": "abitare",
    "abitata": "abitato",
    "abitate": "abitato",
    "abitati": "abitato",
    "abitativa": "abitativo",
    "abitative": "abitativo",
    "abitativi": "abitativo",
    "abitato": "abitare",
    "abitatori": "abitatore",
    "abitava": "abitare",
    "abitavamo": "abitare",
    "abitavan": "abitare",
    "abitavano": "abitare",
    "abitavate": "abitare",
    "abitavi": "abitare",
    "abitavo": "abitare",
    "abitazioni": "abitazione",
    "abiterai": "abitare",
    "abiteran": "abitare",
    "abiteranno": "abitare",
    "abiterebbe": "abitare",
    "abiterebber": "abitare",
    "abiterebbero": "abitare",
    "abiterei": "abitare",
    "abiteremmo": "abitare",
    "abiteremo": "abitare",
    "abitereste": "abitare",
    "abiteresti": "abitare",
    "abiterete": "abitare",
    "abiterà": "abitare",
    "abiterò": "abitare",
    "abiti": "abito",
    "abitiamo": "abitare",
    "abitiate": "abitare",
    "abitin": "abitare",
    "abitini": "abitino",
    "abitino": "abitare",
    "abito": "abitare",
    "abitua": "abituare",
    "abituai": "abituare",
    "abituali": "abituale",
    "abituammo": "abituare",
    "abituan": "abituare",
    "abituando": "abituare",
    "abituano": "abituare",
    "abituante": "abituare",
    "abituanti": "abituare",
    "abituar": "abituare",
    "abituaron": "abituare",
    "abituarono": "abituare",
    "abituasse": "abituare",
    "abituasser": "abituare",
    "abituassero": "abituare",
    "abituassi": "abituare",
    "abituassimo": "abituare",
    "abituaste": "abituare",
    "abituasti": "abituare",
    "abituata": "abituato",
    "abituate": "abituato",
    "abituati": "abituato",
    "abituato": "abituare",
    "abituava": "abituare",
    "abituavamo": "abituare",
    "abituavan": "abituare",
    "abituavano": "abituare",
    "abituavate": "abituare",
    "abituavi": "abituare",
    "abituavo": "abituare",
    "abitucci": "abituccio",
    "abitudinari": "abitudinario",
    "abitudinaria": "abitudinario",
    "abitudinarie": "abitudinario",
    "abitudini": "abitudine",
    "abituerai": "abituare",
    "abitueran": "abituare",
    "abitueranno": "abituare",
    "abituerebbe": "abituare",
    "abituerebber": "abituare",
    "abituerebbero": "abituare",
    "abituerei": "abituare",
    "abitueremmo": "abituare",
    "abitueremo": "abituare",
    "abituereste": "abituare",
    "abitueresti": "abituare",
    "abituerete": "abituare",
    "abituerà": "abituare",
    "abituerò": "abituare",
    "abitui": "abituare",
    "abituiamo": "abituare",
    "abituiate": "abituare",
    "abituin": "abituare",
    "abituino": "abituare",
    "abituo": "abituare",
    "abituò": "abituare",
    "abitò": "abitare",
    "abiura": "abiurare",
    "abiurai": "abiurare",
    "abiurammo": "abiurare",
    "abiuran": "abiurare",
    "abiurando": "abiurare",
    "abiurano": "abiurare",
    "abiurante": "abiurare",
    "abiuranti": "abiurare",
    "abiurar": "abiurare",
    "abiuraron": "abiurare",
    "abiurarono": "abiurare",
    "abiurasse": "abiurare",
    "abiurasser": "abiurare",
    "abiurassero": "abiurare",
    "abiurassi": "abiurare",
    "abiurassimo": "abiurare",
    "abiuraste": "abiurare",
    "abiurasti": "abiurare",
    "abiurata": "abiurare",
    "abiurate": "abiurare",
    "abiurati": "abiurare",
    "abiurato": "abiurare",
    "abiurava": "abiurare",
    "abiuravamo": "abiurare",
    "abiuravan": "abiurare",
    "abiuravano": "abiurare",
    "abiuravate": "abiurare",
    "abiuravi": "abiurare",
    "abiuravo": "abiurare",
    "abiure": "abiura",
    "abiurerai": "abiurare",
    "abiureran": "abiurare",
    "abiureranno": "abiurare",
    "abiurerebbe": "abiurare",
    "abiurerebber": "abiurare",
    "abiurerebbero": "abiurare",
    "abiurerei": "abiurare",
    "abiureremmo": "abiurare",
    "abiureremo": "abiurare",
    "abiurereste": "abiurare",
    "abiureresti": "abiurare",
    "abiurerete": "abiurare",
    "abiurerà": "abiurare",
    "abiurerò": "abiurare",
    "abiuri": "abiurare",
    "abiuriamo": "abiurare",
    "abiuriate": "abiurare",
    "abiurin": "abiurare",
    "abiurino": "abiurare",
    "abiuro": "abiurare",
    "abiurò": "abiurare",
    "abnegazioni": "abnegazione",
    "abnormi": "abnorme",
    "abolendo": "abolire",
    "abolente": "abolire",
    "abolenti": "abolire",
    "aboliamo": "abolire",
    "aboliate": "abolire",
    "abolii": "abolire",
    "abolimmo": "abolire",
    "abolir": "abolire",
    "abolirai": "abolire",
    "aboliran": "abolire",
    "aboliranno": "abolire",
    "abolirebbe": "abolire",
    "abolirebber": "abolire",
    "abolirebbero": "abolire",
    "abolirei": "abolire",
    "aboliremmo": "abolire",
    "aboliremo": "abolire",
    "abolireste": "abolire",
    "aboliresti": "abolire",
    "abolirete": "abolire",
    "aboliron": "abolire",
    "abolirono": "abolire",
    "abolirà": "abolire",
    "abolirò": "abolire",
    "abolisca": "abolire",
    "aboliscan": "abolire",
    "aboliscano": "abolire",
    "abolisce": "abolire",
    "abolisci": "abolire",
    "abolisco": "abolire",
    "aboliscon": "abolire",
    "aboliscono": "abolire",
    "abolisse": "abolire",
    "abolisser": "abolire",
    "abolissero": "abolire",
    "abolissi": "abolire",
    "abolissimo": "abolire",
    "aboliste": "abolire",
    "abolisti": "abolire",
    "abolita": "abolire",
    "abolite": "abolire",
    "aboliti": "abolire",
    "abolito": "abolire",
    "aboliva": "abolire",
    "abolivamo": "abolire",
    "abolivan": "abolire",
    "abolivano": "abolire",
    "abolivate": "abolire",
    "abolivi": "abolire",
    "abolivo": "abolire",
    "abolizioni": "abolizione",
    "abolì": "abolire",
    "abomina": "abominare",
    "abominai": "abominare",
    "abominammo": "abominare",
    "abominan": "abominare",
    "abominando": "abominare",
    "abominano": "abominare",
    "abominante": "abominare",
    "abominanti": "abominare",
    "abominar": "abominare",
    "abominaron": "abominare",
    "abominarono": "abominare",
    "abominasse": "abominare",
    "abominasser": "abominare",
    "abominassero": "abominare",
    "abominassi": "abominare",
    "abominassimo": "abominare",
    "abominaste": "abominare",
    "abominasti": "abominare",
    "abominata": "abominare",
    "abominate": "abominare",
    "abominati": "abominare",
    "abominato": "abominare",
    "abominava": "abominare",
    "abominavamo": "abominare",
    "abominavan": "abominare",
    "abominavano": "abominare",
    "abominavate": "abominare",
    "abominavi": "abominare",
    "abominavo": "abominare",
    "abominerai": "abominare",
    "abomineran": "abominare",
    "abomineranno": "abominare",
    "abominerebbe": "abominare",
    "abominerebber": "abominare",
    "abominerebbero": "abominare",
    "abominerei": "abominare",
    "abomineremmo": "abominare",
    "abomineremo": "abominare",
    "abominereste": "abominare",
    "abomineresti": "abominare",
    "abominerete": "abominare",
    "abominerà": "abominare",
    "abominerò": "abominare",
    "abominevoli": "abominevole",
    "abomini": "abominare",
    "abominiamo": "abominare",
    "abominiate": "abominare",
    "abominin": "abominare",
    "abominino": "abominare",
    "abomino": "abominare",
    "abominò": "abominare",
    "aborigeni": "aborigeno",
    "aborre": "aborrire",
    "aborrendo": "aborrire",
    "aborrente": "aborrire",
    "aborrenti": "aborrire",
    "aborri": "aborrire",
    "aborriamo": "aborrire",
    "aborriate": "aborrire",
    "aborrii": "aborrire",
    "aborrimmo": "aborrire",
    "aborrir": "aborrire",
    "aborrirai": "aborrire",
    "aborriran": "aborrire",
    "aborriranno": "aborrire",
    "aborrirebbe": "aborrire",
    "aborrirebber": "aborrire",
    "aborrirebbero": "aborrire",
    "aborrirei": "aborrire",
    "aborriremmo": "aborrire",
    "aborriremo": "aborrire",
    "aborrireste": "aborrire",
    "aborriresti": "aborrire",
    "aborrirete": "aborrire",
    "aborriron": "aborrire",
    "aborrirono": "aborrire",
    "aborrirà": "aborrire",
    "aborrirò": "aborrire",
    "aborrisca": "aborrire",
    "aborriscan": "aborrire",
    "aborriscano": "aborrire",
    "aborriscon": "aborrire",
    "aborriscono": "aborrire",
    "aborrisse": "aborrire",
    "aborrisser": "aborrire",
    "aborrissero": "aborrire",
    "aborrissi": "aborrire",
    "aborrissimo": "aborrire",
    "aborriste": "aborrire",
    "aborristi": "aborrire",
    "aborrita": "aborrire",
    "aborrite": "aborrire",
    "aborriti": "aborrire",
    "aborrito": "aborrire",
    "aborriva": "aborrire",
    "aborrivamo": "aborrire",
    "aborrivan": "aborrire",
    "aborrivano": "aborrire",
    "aborrivate": "aborrire",
    "aborrivi": "aborrire",
    "aborrivo": "aborrire",
    "aborro": "aborrire",
    "aborrì": "aborrire",
    "abortendo": "abortire",
    "abortente": "abortire",
    "abortenti": "abortire",
    "aborti": "aborto",
    "abortiamo": "abortire",
    "abortiate": "abortire",
    "abortii": "abortire",
    "abortimmo": "abortire",
    "abortir": "abortire",
    "abortirai": "abortire",
    "abortiran": "abortire",
    "abortiranno": "abortire",
    "abortirebbe": "abortire",
    "abortirebber": "abortire",
    "abortirebbero": "abortire",
    "abortirei": "abortire",
    "abortiremmo": "abortire",
    "abortiremo": "abortire",
    "abortireste": "abortire",
    "abortiresti": "abortire",
    "abortirete": "abortire",
    "abortiron": "abortire",
    "abortirono": "abortire",
    "abortirà": "abortire",
    "abortirò": "abortire",
    "abortisca": "abortire",
    "abortiscan": "abortire",
    "abortiscano": "abortire",
    "abortisce": "abortire",
    "abortisci": "abortire",
    "abortisco": "abortire",
    "abortiscon": "abortire",
    "abortiscono": "abortire",
    "abortisse": "abortire",
    "abortisser": "abortire",
    "abortissero": "abortire",
    "abortissi": "abortire",
    "abortissimo": "abortire",
    "abortiste": "abortire",
    "abortisti": "abortista",
    "abortistica": "abortistico",
    "abortistiche": "abortistico",
    "abortistici": "abortistico",
    "abortita": "abortire",
    "abortite": "abortire",
    "abortiti": "abortire",
    "abortito": "abortire",
    "abortiva": "abortivo",
    "abortivamo": "abortire",
    "abortivan": "abortire",
    "abortivano": "abortire",
    "abortivate": "abortire",
    "abortive": "abortivo",
    "abortivi": "abortivo",
    "abortivo": "abortire",
    "abortì": "abortire",
    "abrasioni": "abrasione",
    "abrasiva": "abrasivo",
    "abrasive": "abrasivo",
    "abrasivi": "abrasivo",
    "abroga": "abrogare",
    "abrogabili": "abrogabile",
    "abrogai": "abrogare",
    "abrogammo": "abrogare",
    "abrogan": "abrogare",
    "abrogando": "abrogare",
    "abrogano": "abrogare",
    "abrogante": "abrogare",
    "abroganti": "abrogare",
    "abrogar": "abrogare",
    "abrogaron": "abrogare",
    "abrogarono": "abrogare",
    "abrogasse": "abrogare",
    "abrogasser": "abrogare",
    "abrogassero": "abrogare",
    "abrogassi": "abrogare",
    "abrogassimo": "abrogare",
    "abrogaste": "abrogare",
    "abrogasti": "abrogare",
    "abrogata": "abrogare",
    "abrogate": "abrogare",
    "abrogati": "abrogare",
    "abrogativa": "abrogativo",
    "abrogative": "abrogativo",
    "abrogativi": "abrogativo",
    "abrogato": "abrogare",
    "abrogava": "abrogare",
    "abrogavamo": "abrogare",
    "abrogavan": "abrogare",
    "abrogavano": "abrogare",
    "abrogavate": "abrogare",
    "abrogavi": "abrogare",
    "abrogavo": "abrogare",
    "abrogazioni": "abrogazione",
    "abrogherai": "abrogare",
    "abrogheran": "abrogare",
    "abrogheranno": "abrogare",
    "abrogherebbe": "abrogare",
    "abrogherebber": "abrogare",
    "abrogherebbero": "abrogare",
    "abrogherei": "abrogare",
    "abrogheremmo": "abrogare",
    "abrogheremo": "abrogare",
    "abroghereste": "abrogare",
    "abrogheresti": "abrogare",
    "abrogherete": "abrogare",
    "abrogherà": "abrogare",
    "abrogherò": "abrogare",
    "abroghi": "abrogare",
    "abroghiamo": "abrogare",
    "abroghiate": "abrogare",
    "abroghin": "abrogare",
    "abroghino": "abrogare",
    "abrogo": "abrogare",
    "abrogò": "abrogare",
    "abruzzesi": "abruzzese",
    "abulica": "abulico",
    "abuliche": "abulico",
    "abulici": "abulico",
    "abulie": "abulia",
    "abusa": "abusare",
    "abusai": "abusare",
    "abusammo": "abusare",
    "abusan": "abusare",
    "abusando": "abusare",
    "abusano": "abusare",
    "abusante": "abusare",
    "abusanti": "abusare",
    "abusar": "abusare",
    "abusaron": "abusare",
    "abusarono": "abusare",
    "abusasse": "abusare",
    "abusasser": "abusare",
    "abusassero": "abusare",
    "abusassi": "abusare",
    "abusassimo": "abusare",
    "abusaste": "abusare",
    "abusasti": "abusare",
    "abusata": "abusato",
    "abusate": "abusato",
    "abusati": "abusato",
    "abusato": "abusare",
    "abusava": "abusare",
    "abusavamo": "abusare",
    "abusavan": "abusare",
    "abusavano": "abusare",
    "abusavate": "abusare",
    "abusavi": "abusare",
    "abusavo": "abusare",
    "abuserai": "abusare",
    "abuseran": "abusare",
    "abuseranno": "abusare",
    "abuserebbe": "abusare",
    "abuserebber": "abusare",
    "abuserebbero": "abusare",
    "abuserei": "abusare",
    "abuseremmo": "abusare",
    "abuseremo": "abusare",
    "abusereste": "abusare",
    "abuseresti": "abusare",
    "abuserete": "abusare",
    "abuserà": "abusare",
    "abuserò": "abusare",
    "abusi": "abuso",
    "abusiamo": "abusare",
    "abusiate": "abusare",
    "abusin": "abusare",
    "abusino": "abusare",
    "abusiva": "abusivo",
    "abusive": "abusivo",
    "abusivi": "abusivo",
    "abusivismi": "abusivismo",
    "abuso": "abusare",
    "abusò": "abusare",
    "acacie": "acacia",
    "acari": "acaro",
    "accada": "accadere",
    "accadan": "accadere",
    "accadano": "accadere",
    "accadde": "accadere",
    "accadder": "accadere",
    "accaddero": "accadere",
    "accaddi": "accadere",
    "accade": "accadere",
    "accademica": "accademico",
    "accademiche": "accademico",
    "accademici": "accademico",
    "accademie": "accademia",
    "accademmo": "accadere",
    "accadendo": "accadere",
    "accadente": "accadere",
    "accadenti": "accadere",
    "accader": "accadere",
    "accadesse": "accadere",
    "accadesser": "accadere",
    "accadessero": "accadere",
    "accadessi": "accadere",
    "accadessimo": "accadere",
    "accadeste": "accadere",
    "accadesti": "accadere",
    "accadete": "accadere",
    "accadeva": "accadere",
    "accadevamo": "accadere",
    "accadevan": "accadere",
    "accadevano": "accadere",
    "accadevate": "accadere",
    "accadevi": "accadere",
    "accadevo": "accadere",
    "accadi": "accadere",
    "accadiamo": "accadere",
    "accadiate": "accadere",
    "accadimenti": "accadimento",
    "accado": "accadere",
    "accadon": "accadere",
    "accadono": "accadere",
    "accadrai": "accadere",
    "accadran": "accadere",
    "accadranno": "accadere",
    "accadrebbe": "accadere",
    "accadrebber": "accadere",
    "accadrebbero": "accadere",
    "accadrei": "accadere",
    "accadremmo": "accadere",
    "accadremo": "accadere",
    "accadreste": "accadere",
    "accadresti": "accadere",
    "accadrete": "accadere",
    "accadrà": "accadere",
    "accadrò": "accadere",
    "accaduta": "accaduto",
    "accadute": "accaduto",
    "accaduti": "accaduto",
    "accaduto": "accadere",
    "accalappi": "accalappiare",
    "accalappia": "accalappiare",
    "accalappiai": "accalappiare",
    "accalappiammo": "accalappiare",
    "accalappiamo": "accalappiare",
    "accalappian": "accalappiare",
    "accalappiando": "accalappiare",
    "accalappiano": "accalappiare",
    "accalappiante": "accalappiare",
    "accalappianti": "accalappiare",
    "accalappiar": "accalappiare",
    "accalappiaron": "accalappiare",
    "accalappiarono": "accalappiare",
    "accalappiasse": "accalappiare",
    "accalappiasser": "accalappiare",
    "accalappiassero": "accalappiare",
    "accalappiassi": "accalappiare",
    "accalappiassimo": "accalappiare",
    "accalappiaste": "accalappiare",
    "accalappiasti": "accalappiare",
    "accalappiata": "accalappiare",
    "accalappiate": "accalappiare",
    "accalappiati": "accalappiare",
    "accalappiato": "accalappiare",
    "accalappiava": "accalappiare",
    "accalappiavamo": "accalappiare",
    "accalappiavan": "accalappiare",
    "accalappiavano": "accalappiare",
    "accalappiavate": "accalappiare",
    "accalappiavi": "accalappiare",
    "accalappiavo": "accalappiare",
    "accalappierai": "accalappiare",
    "accalappieran": "accalappiare",
    "accalappieranno": "accalappiare",
    "accalappierebbe": "accalappiare",
    "accalappierebber": "accalappiare",
    "accalappierebbero": "accalappiare",
    "accalappierei": "accalappiare",
    "accalappieremmo": "accalappiare",
    "accalappieremo": "accalappiare",
    "accalappiereste": "accalappiare",
    "accalappieresti": "accalappiare",
    "accalappierete": "accalappiare",
    "accalappierà": "accalappiare",
    "accalappierò": "accalappiare",
    "accalappin": "accalappiare",
    "accalappino": "accalappiare",
    "accalappio": "accalappiare",
    "accalappiò": "accalappiare",
    "accalca": "accalcare",
    "accalcai": "accalcare",
    "accalcammo": "accalcare",
    "accalcan": "accalcare",
    "accalcando": "accalcare",
    "accalcano": "accalcare",
    "accalcante": "accalcare",
    "accalcanti": "accalcare",
    "accalcar": "accalcare",
    "accalcaron": "accalcare",
    "accalcarono": "accalcare",
    "accalcasse": "accalcare",
    "accalcasser": "accalcare",
    "accalcassero": "accalcare",
    "accalcassi": "accalcare",
    "accalcassimo": "accalcare",
    "accalcaste": "accalcare",
    "accalcasti": "accalcare",
    "accalcata": "accalcare",
    "accalcate": "accalcare",
    "accalcati": "accalcare",
    "accalcato": "accalcare",
    "accalcava": "accalcare",
    "accalcavamo": "accalcare",
    "accalcavan": "accalcare",
    "accalcavano": "accalcare",
    "accalcavate": "accalcare",
    "accalcavi": "accalcare",
    "accalcavo": "accalcare",
    "accalcherai": "accalcare",
    "accalcheran": "accalcare",
    "accalcheranno": "accalcare",
    "accalcherebbe": "accalcare",
    "accalcherebber": "accalcare",
    "accalcherebbero": "accalcare",
    "accalcherei": "accalcare",
    "accalcheremmo": "accalcare",
    "accalcheremo": "accalcare",
    "accalchereste": "accalcare",
    "accalcheresti": "accalcare",
    "accalcherete": "accalcare",
    "accalcherà": "accalcare",
    "accalcherò": "accalcare",
    "accalchi": "accalcare",
    "accalchiamo": "accalcare",
    "accalchiate": "accalcare",
    "accalchin": "accalcare",
    "accalchino": "accalcare",
    "accalco": "accalcare",
    "accalcò": "accalcare",
    "accalda": "accaldare",
    "accaldai": "accaldare",
    "accaldammo": "accaldare",
    "accaldan": "accaldare",
    "accaldando": "accaldare",
    "accaldano": "accaldare",
    "accaldar": "accaldare",
    "accaldaron": "accaldare",
    "accaldarono": "accaldare",
    "accaldasse": "accaldare",
    "accaldasser": "accaldare",
    "accaldassero": "accaldare",
    "accaldassi": "accaldare",
    "accaldassimo": "accaldare",
    "accaldaste": "accaldare",
    "accaldasti": "accaldare",
    "accaldata": "accaldato",
    "accaldate": "accaldato",
    "accaldati": "accaldato",
    "accaldato": "accaldare",
    "accaldava": "accaldare",
    "accaldavamo": "accaldare",
    "accaldavan": "accaldare",
    "accaldavano": "accaldare",
    "accaldavate": "accaldare",
    "accaldavi": "accaldare",
    "accaldavo": "accaldare",
    "accalderai": "accaldare",
    "accalderan": "accaldare",
    "accalderanno": "accaldare",
    "accalderebbe": "accaldare",
    "accalderebber": "accaldare",
    "accalderebbero": "accaldare",
    "accalderei": "accaldare",
    "accalderemmo": "accaldare",
    "accalderemo": "accaldare",
    "accaldereste": "accaldare",
    "accalderesti": "accaldare",
    "accalderete": "accaldare",
    "accalderà": "accaldare",
    "accalderò": "accaldare",
    "accaldi": "accaldare",
    "accaldiamo": "accaldare",
    "accaldiate": "accaldare",
    "accaldin": "accaldare",
    "accaldino": "accaldare",
    "accaldo": "accaldare",
    "accaldò": "accaldare",
    "accalora": "accalorare",
    "accalorai": "accalorare",
    "accalorammo": "accalorare",
    "accaloran": "accalorare",
    "accalorando": "accalorare",
    "accalorano": "accalorare",
    "accalorante": "accalorare",
    "accaloranti": "accalorare",
    "accalorar": "accalorare",
    "accaloraron": "accalorare",
    "accalorarono": "accalorare",
    "accalorasse": "accalorare",
    "accalorasser": "accalorare",
    "accalorassero": "accalorare",
    "accalorassi": "accalorare",
    "accalorassimo": "accalorare",
    "accaloraste": "accalorare",
    "accalorasti": "accalorare",
    "accalorata": "accalorare",
    "accalorate": "accalorare",
    "accalorati": "accalorare",
    "accalorato": "accalorare",
    "accalorava": "accalorare",
    "accaloravamo": "accalorare",
    "accaloravan": "accalorare",
    "accaloravano": "accalorare",
    "accaloravate": "accalorare",
    "accaloravi": "accalorare",
    "accaloravo": "accalorare",
    "accalorerai": "accalorare",
    "accaloreran": "accalorare",
    "accaloreranno": "accalorare",
    "accalorerebbe": "accalorare",
    "accalorerebber": "accalorare",
    "accalorerebbero": "accalorare",
    "accalorerei": "accalorare",
    "accaloreremmo": "accalorare",
    "accaloreremo": "accalorare",
    "accalorereste": "accalorare",
    "accaloreresti": "accalorare",
    "accalorerete": "accalorare",
    "accalorerà": "accalorare",
    "accalorerò": "accalorare",
    "accalori": "accalorare",
    "accaloriamo": "accalorare",
    "accaloriate": "accalorare",
    "accalorin": "accalorare",
    "accalorino": "accalorare",
    "accaloro": "accalorare",
    "accalorò": "accalorare",
    "accampa": "accampare",
    "accampai": "accampare",
    "accampamenti": "accampamento",
    "accampammo": "accampare",
    "accampan": "accampare",
    "accampando": "accampare",
    "accampano": "accampare",
    "accampante": "accampare",
    "accampanti": "accampare",
    "accampar": "accampare",
    "accamparon": "accampare",
    "accamparono": "accampare",
    "accampasse": "accampare",
    "accampasser": "accampare",
    "accampassero": "accampare",
    "accampassi": "accampare",
    "accampassimo": "accampare",
    "accampaste": "accampare",
    "accampasti": "accampare",
    "accampata": "accampare",
    "accampate": "accampare",
    "accampati": "accampare",
    "accampato": "accampare",
    "accampava": "accampare",
    "accampavamo": "accampare",
    "accampavan": "accampare",
    "accampavano": "accampare",
    "accampavate": "accampare",
    "accampavi": "accampare",
    "accampavo": "accampare",
    "accamperai": "accampare",
    "accamperan": "accampare",
    "accamperanno": "accampare",
    "accamperebbe": "accampare",
    "accamperebber": "accampare",
    "accamperebbero": "accampare",
    "accamperei": "accampare",
    "accamperemmo": "accampare",
    "accamperemo": "accampare",
    "accampereste": "accampare",
    "accamperesti": "accampare",
    "accamperete": "accampare",
    "accamperà": "accampare",
    "accamperò": "accampare",
    "accampi": "accampare",
    "accampiamo": "accampare",
    "accampiate": "accampare",
    "accampin": "accampare",
    "accampino": "accampare",
    "accampo": "accampare",
    "accampò": "accampare",
    "accana": "accanare",
    "accanai": "accanare",
    "accanammo": "accanare",
    "accanan": "accanare",
    "accanando": "accanare",
    "accanano": "accanare",
    "accanante": "accanare",
    "accananti": "accanare",
    "accanar": "accanare",
    "accanaron": "accanare",
    "accanarono": "accanare",
    "accanasse": "accanare",
    "accanasser": "accanare",
    "accanassero": "accanare",
    "accanassi": "accanare",
    "accanassimo": "accanare",
    "accanaste": "accanare",
    "accanasti": "accanare",
    "accanata": "accanare",
    "accanate": "accanare",
    "accanati": "accanare",
    "accanato": "accanare",
    "accanava": "accanare",
    "accanavamo": "accanare",
    "accanavan": "accanare",
    "accanavano": "accanare",
    "accanavate": "accanare",
    "accanavi": "accanare",
    "accanavo": "accanare",
    "accanendo": "accanire",
    "accanerai": "accanare",
    "accaneran": "accanare",
    "accaneranno": "accanare",
    "accanerebbe": "accanare",
    "accanerebber": "accanare",
    "accanerebbero": "accanare",
    "accanerei": "accanare",
    "accaneremmo": "accanare",
    "accaneremo": "accanare",
    "accanereste": "accanare",
    "accaneresti": "accanare",
    "accanerete": "accanare",
    "accanerà": "accanare",
    "accanerò": "accanare",
    "accani": "accanare",
    "accaniamo": "accanire",
    "accaniate": "accanire",
    "accanii": "accanire",
    "accanimenti": "accanimento",
    "accanimmo": "accanire",
    "accanin": "accanare",
    "accanino": "accanare",
    "accanir": "accanire",
    "accanirai": "accanire",
    "accaniran": "accanire",
    "accaniranno": "accanire",
    "accanirebbe": "accanire",
    "accanirebber": "accanire",
    "accanirebbero": "accanire",
    "accanirei": "accanire",
    "accaniremmo": "accanire",
    "accaniremo": "accanire",
    "accanireste": "accanire",
    "accaniresti": "accanire",
    "accanirete": "accanire",
    "accaniron": "accanire",
    "accanirono": "accanire",
    "accanirà": "accanire",
    "accanirò": "accanire",
    "accanisca": "accanire",
    "accaniscan": "accanire",
    "accaniscano": "accanire",
    "accanisce": "accanire",
    "accanisci": "accanire",
    "accanisco": "accanire",
    "accaniscon": "accanire",
    "accaniscono": "accanire",
    "accanisse": "accanire",
    "accanisser": "accanire",
    "accanissero": "accanire",
    "accanissi": "accanire",
    "accanissimo": "accanire",
    "accaniste": "accanire",
    "accanisti": "accanire",
    "accanita": "accanito",
    "accanite": "accanito",
    "accaniti": "accanito",
    "accanito": "accanire",
    "accaniva": "accanire",
    "accanivamo": "accanire",
    "accanivan": "accanire",
    "accanivano": "accanire",
    "accanivate": "accanire",
    "accanivi": "accanire",
    "accanivo": "accanire",
    "accano": "accanare",
    "accantona": "accantonare",
    "accantonai": "accantonare",
    "accantonamenti": "accantonamento",
    "accantonammo": "accantonare",
    "accantonan": "accantonare",
    "accantonando": "accantonare",
    "accantonano": "accantonare",
    "accantonante": "accantonare",
    "accantonanti": "accantonare",
    "accantonar": "accantonare",
    "accantonaron": "accantonare",
    "accantonarono": "accantonare",
    "accantonasse": "accantonare",
    "accantonasser": "accantonare",
    "accantonassero": "accantonare",
    "accantonassi": "accantonare",
    "accantonassimo": "accantonare",
    "accantonaste": "accantonare",
    "accantonasti": "accantonare",
    "accantonata": "accantonare",
    "accantonate": "accantonare",
    "accantonati": "accantonare",
    "accantonato": "accantonare",
    "accantonava": "accantonare",
    "accantonavamo": "accantonare",
    "accantonavan": "accantonare",
    "accantonavano": "accantonare",
    "accantonavate": "accantonare",
    "accantonavi": "accantonare",
    "accantonavo": "accantonare",
    "accantonerai": "accantonare",
    "accantoneran": "accantonare",
    "accantoneranno": "accantonare",
    "accantonerebbe": "accantonare",
    "accantonerebber": "accantonare",
    "accantonerebbero": "accantonare",
    "accantonerei": "accantonare",
    "accantoneremmo": "accantonare",
    "accantoneremo": "accantonare",
    "accantonereste": "accantonare",
    "accantoneresti": "accantonare",
    "accantonerete": "accantonare",
    "accantonerà": "accantonare",
    "accantonerò": "accantonare",
    "accantoni": "accantonare",
    "accantoniamo": "accantonare",
    "accantoniate": "accantonare",
    "accantonin": "accantonare",
    "accantonino": "accantonare",
    "accantono": "accantonare",
    "accantonò": "accantonare",
    "accanì": "accanire",
    "accanò": "accanare",
    "accaparra": "accaparrare",
    "accaparrabili": "accaparrabile",
    "accaparrai": "accaparrare",
    "accaparramenti": "accaparramento",
    "accaparrammo": "accaparrare",
    "accaparran": "accaparrare",
    "accaparrando": "accaparrare",
    "accaparrano": "accaparrare",
    "accaparrante": "accaparrare",
    "accaparranti": "accaparrare",
    "accaparrar": "accaparrare",
    "accaparraron": "accaparrare",
    "accaparrarono": "accaparrare",
    "accaparrasse": "accaparrare",
    "accaparrasser": "accaparrare",
    "accaparrassero": "accaparrare",
    "accaparrassi": "accaparrare",
    "accaparrassimo": "accaparrare",
    "accaparraste": "accaparrare",
    "accaparrasti": "accaparrare",
    "accaparrata": "accaparrare",
    "accaparrate": "accaparrare",
    "accaparrati": "accaparrare",
    "accaparrato": "accaparrare",
    "accaparrava": "accaparrare",
    "accaparravamo": "accaparrare",
    "accaparravan": "accaparrare",
    "accaparravano": "accaparrare",
    "accaparravate": "accaparrare",
    "accaparravi": "accaparrare",
    "accaparravo": "accaparrare",
    "accaparrerai": "accaparrare",
    "accaparreran": "accaparrare",
    "accaparreranno": "accaparrare",
    "accaparrerebbe": "accaparrare",
    "accaparrerebber": "accaparrare",
    "accaparrerebbero": "accaparrare",
    "accaparrerei": "accaparrare",
    "accaparreremmo": "accaparrare",
    "accaparreremo": "accaparrare",
    "accaparrereste": "accaparrare",
    "accaparreresti": "accaparrare",
    "accaparrerete": "accaparrare",
    "accaparrerà": "accaparrare",
    "accaparrerò": "accaparrare",
    "accaparri": "accaparrare",
    "accaparriamo": "accaparrare",
    "accaparriate": "accaparrare",
    "accaparrin": "accaparrare",
    "accaparrino": "accaparrare",
    "accaparro": "accaparrare",
    "accaparrò": "accaparrare",
    "accapigli": "accapigliare",
    "accapiglia": "accapigliare",
    "accapigliai": "accapigliare",
    "accapigliammo": "accapigliare",
    "accapigliamo": "accapigliare",
    "accapiglian": "accapigliare",
    "accapigliando": "accapigliare",
    "accapigliano": "accapigliare",
    "accapigliar": "accapigliare",
    "accapigliaron": "accapigliare",
    "accapigliarono": "accapigliare",
    "accapigliasse": "accapigliare",
    "accapigliasser": "accapigliare",
    "accapigliassero": "accapigliare",
    "accapigliassi": "accapigliare",
    "accapigliassimo": "accapigliare",
    "accapigliaste": "accapigliare",
    "accapigliasti": "accapigliare",
    "accapigliata": "accapigliare",
    "accapigliate": "accapigliare",
    "accapigliati": "accapigliare",
    "accapigliato": "accapigliare",
    "accapigliava": "accapigliare",
    "accapigliavamo": "accapigliare",
    "accapigliavan": "accapigliare",
    "accapigliavano": "accapigliare",
    "accapigliavate": "accapigliare",
    "accapigliavi": "accapigliare",
    "accapigliavo": "accapigliare",
    "accapiglierai": "accapigliare",
    "accapiglieran": "accapigliare",
    "accapiglieranno": "accapigliare",
    "accapiglierebbe": "accapigliare",
    "accapiglierebber": "accapigliare",
    "accapiglierebbero": "accapigliare",
    "accapiglierei": "accapigliare",
    "accapiglieremmo": "accapigliare",
    "accapiglieremo": "accapigliare",
    "accapigliereste": "accapigliare",
    "accapiglieresti": "accapigliare",
    "accapiglierete": "accapigliare",
    "accapiglierà": "accapigliare",
    "accapiglierò": "accapigliare",
    "accapiglin": "accapigliare",
    "accapiglino": "accapigliare",
    "accapiglio": "accapigliare",
    "accapigliò": "accapigliare",
    "accappatoi": "accappatoio",
    "accappona": "accapponare",
    "accapponai": "accapponare",
    "accapponammo": "accapponare",
    "accapponan": "accapponare",
    "accapponando": "accapponare",
    "accapponano": "accapponare",
    "accapponante": "accapponare",
    "accapponanti": "accapponare",
    "accapponar": "accapponare",
    "accapponaron": "accapponare",
    "accapponarono": "accapponare",
    "accapponasse": "accapponare",
    "accapponasser": "accapponare",
    "accapponassero": "accapponare",
    "accapponassi": "accapponare",
    "accapponassimo": "accapponare",
    "accapponaste": "accapponare",
    "accapponasti": "accapponare",
    "accapponata": "accapponare",
    "accapponate": "accapponare",
    "accapponati": "accapponare",
    "accapponato": "accapponare",
    "accapponava": "accapponare",
    "accapponavamo": "accapponare",
    "accapponavan": "accapponare",
    "accapponavano": "accapponare",
    "accapponavate": "accapponare",
    "accapponavi": "accapponare",
    "accapponavo": "accapponare",
    "accapponerai": "accapponare",
    "accapponeran": "accapponare",
    "accapponeranno": "accapponare",
    "accapponerebbe": "accapponare",
    "accapponerebber": "accapponare",
    "accapponerebbero": "accapponare",
    "accapponerei": "accapponare",
    "accapponeremmo": "accapponare",
    "accapponeremo": "accapponare",
    "accapponereste": "accapponare",
    "accapponeresti": "accapponare",
    "accapponerete": "accapponare",
    "accapponerà": "accapponare",
    "accapponerò": "accapponare",
    "accapponi": "accapponare",
    "accapponiamo": "accapponare",
    "accapponiate": "accapponare",
    "accapponin": "accapponare",
    "accapponino": "accapponare",
    "accappono": "accapponare",
    "accapponò": "accapponare",
    "accarezza": "accarezzare",
    "accarezzai": "accarezzare",
    "accarezzammo": "accarezzare",
    "accarezzan": "accarezzare",
    "accarezzando": "accarezzare",
    "accarezzano": "accarezzare",
    "accarezzante": "accarezzare",
    "accarezzanti": "accarezzare",
    "accarezzar": "accarezzare",
    "accarezzaron": "accarezzare",
    "accarezzarono": "accarezzare",
    "accarezzasse": "accarezzare",
    "accarezzasser": "accarezzare",
    "accarezzassero": "accarezzare",
    "accarezzassi": "accarezzare",
    "accarezzassimo": "accarezzare",
    "accarezzaste": "accarezzare",
    "accarezzasti": "accarezzare",
    "accarezzata": "accarezzare",
    "accarezzate": "accarezzare",
    "accarezzati": "accarezzare",
    "accarezzato": "accarezzare",
    "accarezzava": "accarezzare",
    "accarezzavamo": "accarezzare",
    "accarezzavan": "accarezzare",
    "accarezzavano": "accarezzare",
    "accarezzavate": "accarezzare",
    "accarezzavi": "accarezzare",
    "accarezzavo": "accarezzare",
    "accarezzerai": "accarezzare",
    "accarezzeran": "accarezzare",
    "accarezzeranno": "accarezzare",
    "accarezzerebbe": "accarezzare",
    "accarezzerebber": "accarezzare",
    "accarezzerebbero": "accarezzare",
    "accarezzerei": "accarezzare",
    "accarezzeremmo": "accarezzare",
    "accarezzeremo": "accarezzare",
    "accarezzereste": "accarezzare",
    "accarezzeresti": "accarezzare",
    "accarezzerete": "accarezzare",
    "accarezzerà": "accarezzare",
    "accarezzerò": "accarezzare",
    "accarezzi": "accarezzare",
    "accarezziamo": "accarezzare",
    "accarezziate": "accarezzare",
    "accarezzin": "accarezzare",
    "accarezzino": "accarezzare",
    "accarezzo": "accarezzare",
    "accarezzò": "accarezzare",
    "accartoccerai": "accartocciare",
    "accartocceran": "accartocciare",
    "accartocceranno": "accartocciare",
    "accartoccerebbe": "accartocciare",
    "accartoccerebber": "accartocciare",
    "accartoccerebbero": "accartocciare",
    "accartoccerei": "accartocciare",
    "accartocceremmo": "accartocciare",
    "accartocceremo": "accartocciare",
    "accartoccereste": "accartocciare",
    "accartocceresti": "accartocciare",
    "accartoccerete": "accartocciare",
    "accartoccerà": "accartocciare",
    "accartoccerò": "accartocciare",
    "accartocci": "accartocciare",
    "accartoccia": "accartocciare",
    "accartocciai": "accartocciare",
    "accartocciammo": "accartocciare",
    "accartocciamo": "accartocciare",
    "accartoccian": "accartocciare",
    "accartocciando": "accartocciare",
    "accartocciano": "accartocciare",
    "accartocciante": "accartocciare",
    "accartoccianti": "accartocciare",
    "accartocciar": "accartocciare",
    "accartocciaron": "accartocciare",
    "accartocciarono": "accartocciare",
    "accartocciasse": "accartocciare",
    "accartocciasser": "accartocciare",
    "accartocciassero": "accartocciare",
    "accartocciassi": "accartocciare",
    "accartocciassimo": "accartocciare",
    "accartocciaste": "accartocciare",
    "accartocciasti": "accartocciare",
    "accartocciata": "accartocciato",
    "accartocciate": "accartocciato",
    "accartocciati": "accartocciato",
    "accartocciato": "accartocciare",
    "accartocciava": "accartocciare",
    "accartocciavamo": "accartocciare",
    "accartocciavan": "accartocciare",
    "accartocciavano": "accartocciare",
    "accartocciavate": "accartocciare",
    "accartocciavi": "accartocciare",
    "accartocciavo": "accartocciare",
    "accartoccin": "accartocciare",
    "accartoccino": "accartocciare",
    "accartoccio": "accartocciare",
    "accartocciò": "accartocciare",
    "accasa": "accasare",
    "accasai": "accasare",
    "accasammo": "accasare",
    "accasan": "accasare",
    "accasando": "accasare",
    "accasano": "accasare",
    "accasante": "accasare",
    "accasanti": "accasare",
    "accasar": "accasare",
    "accasaron": "accasare",
    "accasarono": "accasare",
    "accasasse": "accasare",
    "accasasser": "accasare",
    "accasassero": "accasare",
    "accasassi": "accasare",
    "accasassimo": "accasare",
    "accasaste": "accasare",
    "accasasti": "accasare",
    "accasata": "accasato",
    "accasate": "accasato",
    "accasati": "accasato",
    "accasato": "accasare",
    "accasava": "accasare",
    "accasavamo": "accasare",
    "accasavan": "accasare",
    "accasavano": "accasare",
    "accasavate": "accasare",
    "accasavi": "accasare",
    "accasavo": "accasare",
    "accascerai": "accasciare",
    "accasceran": "accasciare",
    "accasceranno": "accasciare",
    "accascerebbe": "accasciare",
    "accascerebber": "accasciare",
    "accascerebbero": "accasciare",
    "accascerei": "accasciare",
    "accasceremmo": "accasciare",
    "accasceremo": "accasciare",
    "accascereste": "accasciare",
    "accasceresti": "accasciare",
    "accascerete": "accasciare",
    "accascerà": "accasciare",
    "accascerò": "accasciare",
    "accasci": "accasciare",
    "accascia": "accasciare",
    "accasciai": "accasciare",
    "accasciammo": "accasciare",
    "accasciamo": "accasciare",
    "accascian": "accasciare",
    "accasciando": "accasciare",
    "accasciano": "accasciare",
    "accasciante": "accasciare",
    "accascianti": "accasciare",
    "accasciar": "accasciare",
    "accasciaron": "accasciare",
    "accasciarono": "accasciare",
    "accasciasse": "accasciare",
    "accasciasser": "accasciare",
    "accasciassero": "accasciare",
    "accasciassi": "accasciare",
    "accasciassimo": "accasciare",
    "accasciaste": "accasciare",
    "accasciasti": "accasciare",
    "accasciata": "accasciato",
    "accasciate": "accasciato",
    "accasciati": "accasciato",
    "accasciato": "accasciare",
    "accasciava": "accasciare",
    "accasciavamo": "accasciare",
    "accasciavan": "accasciare",
    "accasciavano": "accasciare",
    "accasciavate": "accasciare",
    "accasciavi": "accasciare",
    "accasciavo": "accasciare",
    "accascin": "accasciare",
    "accascino": "accasciare",
    "accascio": "accasciare",
    "accasciò": "accasciare",
    "accaserai": "accasare",
    "accaseran": "accasare",
    "accaseranno": "accasare",
    "accaserebbe": "accasare",
    "accaserebber": "accasare",
    "accaserebbero": "accasare",
    "accaserei": "accasare",
    "accaseremmo": "accasare",
    "accaseremo": "accasare",
    "accasereste": "accasare",
    "accaseresti": "accasare",
    "accaserete": "accasare",
    "accaserma": "accasermare",
    "accasermai": "accasermare",
    "accasermammo": "accasermare",
    "accaserman": "accasermare",
    "accasermando": "accasermare",
    "accasermano": "accasermare",
    "accasermante": "accasermare",
    "accasermanti": "accasermare",
    "accasermar": "accasermare",
    "accasermaron": "accasermare",
    "accasermarono": "accasermare",
    "accasermasse": "accasermare",
    "accasermasser": "accasermare",
    "accasermassero": "accasermare",
    "accasermassi": "accasermare",
    "accasermassimo": "accasermare",
    "accasermaste": "accasermare",
    "accasermasti": "accasermare",
    "accasermata": "accasermare",
    "accasermate": "accasermare",
    "accasermati": "accasermare",
    "accasermato": "accasermare",
    "accasermava": "accasermare",
    "accasermavamo": "accasermare",
    "accasermavan": "accasermare",
    "accasermavano": "accasermare",
    "accasermavate": "accasermare",
    "accasermavi": "accasermare",
    "accasermavo": "accasermare",
    "accasermerai": "accasermare",
    "accasermeran": "accasermare",
    "accasermeranno": "accasermare",
    "accasermerebbe": "accasermare",
    "accasermerebber": "accasermare",
    "accasermerebbero": "accasermare",
    "accasermerei": "accasermare",
    "accasermeremmo": "accasermare",
    "accasermeremo": "accasermare",
    "accasermereste": "accasermare",
    "accasermeresti": "accasermare",
    "accasermerete": "accasermare",
    "accasermerà": "accasermare",
    "accasermerò": "accasermare",
    "accasermi": "accasermare",
    "accasermiamo": "accasermare",
    "accasermiate": "accasermare",
    "accasermin": "accasermare",
    "accasermino": "accasermare",
    "accasermo": "accasermare",
    "accasermò": "accasermare",
    "accaserà": "accasare",
    "accaserò": "accasare",
    "accasi": "accasare",
    "accasiamo": "accasare",
    "accasiate": "accasare",
    "accasin": "accasare",
    "accasino": "accasare",
    "accaso": "accasare",
    "accasò": "accasare",
    "accatasta": "accatastare",
    "accatastai": "accatastare",
    "accatastammo": "accatastare",
    "accatastan": "accatastare",
    "accatastando": "accatastare",
    "accatastano": "accatastare",
    "accatastante": "accatastare",
    "accatastanti": "accatastare",
    "accatastar": "accatastare",
    "accatastaron": "accatastare",
    "accatastarono": "accatastare",
    "accatastasse": "accatastare",
    "accatastasser": "accatastare",
    "accatastassero": "accatastare",
    "accatastassi": "accatastare",
    "accatastassimo": "accatastare",
    "accatastaste": "accatastare",
    "accatastasti": "accatastare",
    "accatastata": "accatastare",
    "accatastate": "accatastare",
    "accatastati": "accatastare",
    "accatastato": "accatastare",
    "accatastava": "accatastare",
    "accatastavamo": "accatastare",
    "accatastavan": "accatastare",
    "accatastavano": "accatastare",
    "accatastavate": "accatastare",
    "accatastavi": "accatastare",
    "accatastavo": "accatastare",
    "accatasterai": "accatastare",
    "accatasteran": "accatastare",
    "accatasteranno": "accatastare",
    "accatasterebbe": "accatastare",
    "accatasterebber": "accatastare",
    "accatasterebbero": "accatastare",
    "accatasterei": "accatastare",
    "accatasteremmo": "accatastare",
    "accatasteremo": "accatastare",
    "accatastereste": "accatastare",
    "accatasteresti": "accatastare",
    "accatasterete": "accatastare",
    "accatasterà": "accatastare",
    "accatasterò": "accatastare",
    "accatasti": "accatastare",
    "accatastiamo": "accatastare",
    "accatastiate": "accatastare",
    "accatastin": "accatastare",
    "accatastino": "accatastare",
    "accatasto": "accatastare",
    "accatastò": "accatastare",
    "accatta": "accattare",
    "accattai": "accattare",
    "accattammo": "accattare",
    "accattan": "accattare",
    "accattando": "accattare",
    "accattano": "accattare",
    "accattante": "accattare",
    "accattanti": "accattare",
    "accattar": "accattare",
    "accattaron": "accattare",
    "accattarono": "accattare",
    "accattasse": "accattare",
    "accattasser": "accattare",
    "accattassero": "accattare",
    "accattassi": "accattare",
    "accattassimo": "accattare",
    "accattaste": "accattare",
    "accattasti": "accattare",
    "accattata": "accattare",
    "accattate": "accattare",
    "accattati": "accattare",
    "accattato": "accattare",
    "accattava": "accattare",
    "accattavamo": "accattare",
    "accattavan": "accattare",
    "accattavano": "accattare",
    "accattavate": "accattare",
    "accattavi": "accattare",
    "accattavo": "accattare",
    "accatterai": "accattare",
    "accatteran": "accattare",
    "accatteranno": "accattare",
    "accatterebbe": "accattare",
    "accatterebber": "accattare",
    "accatterebbero": "accattare",
    "accatterei": "accattare",
    "accatteremmo": "accattare",
    "accatteremo": "accattare",
    "accattereste": "accattare",
    "accatteresti": "accattare",
    "accatterete": "accattare",
    "accatterà": "accattare",
    "accatterò": "accattare",
    "accatti": "accattare",
    "accattiamo": "accattare",
    "accattiate": "accattare",
    "accattin": "accattare",
    "accattino": "accattare",
    "accattiva": "accattivare",
    "accattivai": "accattivare",
    "accattivammo": "accattivare",
    "accattivan": "accattivare",
    "accattivando": "accattivare",
    "accattivano": "accattivare",
    "accattivante": "accattivare",
    "accattivanti": "accattivare",
    "accattivar": "accattivare",
    "accattivaron": "accattivare",
    "accattivarono": "accattivare",
    "accattivasse": "accattivare",
    "accattivasser": "accattivare",
    "accattivassero": "accattivare",
    "accattivassi": "accattivare",
    "accattivassimo": "accattivare",
    "accattivaste": "accattivare",
    "accattivasti": "accattivare",
    "accattivata": "accattivare",
    "accattivate": "accattivare",
    "accattivati": "accattivare",
    "accattivato": "accattivare",
    "accattivava": "accattivare",
    "accattivavamo": "accattivare",
    "accattivavan": "accattivare",
    "accattivavano": "accattivare",
    "accattivavate": "accattivare",
    "accattivavi": "accattivare",
    "accattivavo": "accattivare",
    "accattiverai": "accattivare",
    "accattiveran": "accattivare",
    "accattiveranno": "accattivare",
    "accattiverebbe": "accattivare",
    "accattiverebber": "accattivare",
    "accattiverebbero": "accattivare",
    "accattiverei": "accattivare",
    "accattiveremmo": "accattivare",
    "accattiveremo": "accattivare",
    "accattivereste": "accattivare",
    "accattiveresti": "accattivare",
    "accattiverete": "accattivare",
    "accattiverà": "accattivare",
    "accattiverò": "accattivare",
    "accattivi": "accattivare",
    "accattiviamo": "accattivare",
    "accattiviate": "accattivare",
    "accattivin": "accattivare",
    "accattivino": "accattivare",
    "accattivo": "accattivare",
    "accattivò": "accattivare",
    "accatto": "accattare",
    "accattona": "accattonare",
    "accattonaggi": "accattonaggio",
    "accattonai": "accattonare",
    "accattonammo": "accattonare",
    "accattonan": "accattonare",
    "accattonando": "accattonare",
    "accattonano": "accattonare",
    "accattonante": "accattonare",
    "accattonanti": "accattonare",
    "accattonar": "accattonare",
    "accattonaron": "accattonare",
    "accattonarono": "accattonare",
    "accattonasse": "accattonare",
    "accattonasser": "accattonare",
    "accattonassero": "accattonare",
    "accattonassi": "accattonare",
    "accattonassimo": "accattonare",
    "accattonaste": "accattonare",
    "accattonasti": "accattonare",
    "accattonata": "accattonare",
    "accattonate": "accattonare",
    "accattonati": "accattonare",
    "accattonato": "accattonare",
    "accattonava": "accattonare",
    "accattonavamo": "accattonare",
    "accattonavan": "accattonare",
    "accattonavano": "accattonare",
    "accattonavate": "accattonare",
    "accattonavi": "accattonare",
    "accattonavo": "accattonare",
    "accattonerai": "accattonare",
    "accattoneran": "accattonare",
    "accattoneranno": "accattonare",
    "accattonerebbe": "accattonare",
    "accattonerebber": "accattonare",
    "accattonerebbero": "accattonare",
    "accattonerei": "accattonare",
    "accattoneremmo": "accattonare",
    "accattoneremo": "accattonare",
    "accattonereste": "accattonare",
    "accattoneresti": "accattonare",
    "accattonerete": "accattonare",
    "accattonerà": "accattonare",
    "accattonerò": "accattonare",
    "accattoni": "accattone",
    "accattoniamo": "accattonare",
    "accattoniate": "accattonare",
    "accattonin": "accattonare",
    "accattonino": "accattonare",
    "accattono": "accattonare",
    "accattonò": "accattonare",
    "accattò": "accattare",
    "accavalla": "accavallare",
    "accavallai": "accavallare",
    "accavallamenti": "accavallamento",
    "accavallammo": "accavallare",
    "accavallan": "accavallare",
    "accavallando": "accavallare",
    "accavallano": "accavallare",
    "accavallante": "accavallare",
    "accavallanti": "accavallare",
    "accavallar": "accavallare",
    "accavallaron": "accavallare",
    "accavallarono": "accavallare",
    "accavallasse": "accavallare",
    "accavallasser": "accavallare",
    "accavallassero": "accavallare",
    "accavallassi": "accavallare",
    "accavallassimo": "accavallare",
    "accavallaste": "accavallare",
    "accavallasti": "accavallare",
    "accavallata": "accavallare",
    "accavallate": "accavallare",
    "accavallati": "accavallare",
    "accavallato": "accavallare",
    "accavallava": "accavallare",
    "accavallavamo": "accavallare",
    "accavallavan": "accavallare",
    "accavallavano": "accavallare",
    "accavallavate": "accavallare",
    "accavallavi": "accavallare",
    "accavallavo": "accavallare",
    "accavallerai": "accavallare",
    "accavalleran": "accavallare",
    "accavalleranno": "accavallare",
    "accavallerebbe": "accavallare",
    "accavallerebber": "accavallare",
    "accavallerebbero": "accavallare",
    "accavallerei": "accavallare",
    "accavalleremmo": "accavallare",
    "accavalleremo": "accavallare",
    "accavallereste": "accavallare",
    "accavalleresti": "accavallare",
    "accavallerete": "accavallare",
    "accavallerà": "accavallare",
    "accavallerò": "accavallare",
    "accavalli": "accavallare",
    "accavalliamo": "accavallare",
    "accavalliate": "accavallare",
    "accavallin": "accavallare",
    "accavallino": "accavallare",
    "accavallo": "accavallare",
    "accavallò": "accavallare",
    "acceca": "accecare",
    "accecai": "accecare",
    "accecammo": "accecare",
    "accecan": "accecare",
    "accecando": "accecare",
    "accecano": "accecare",
    "accecante": "accecare",
    "accecanti": "accecare",
    "accecar": "accecare",
    "accecaron": "accecare",
    "accecarono": "accecare",
    "accecasse": "accecare",
    "accecasser": "accecare",
    "accecassero": "accecare",
    "accecassi": "accecare",
    "accecassimo": "accecare",
    "accecaste": "accecare",
    "accecasti": "accecare",
    "accecata": "accecare",
    "accecate": "accecare",
    "accecati": "accecare",
    "accecato": "accecare",
    "accecava": "accecare",
    "accecavamo": "accecare",
    "accecavan": "accecare",
    "accecavano": "accecare",
    "accecavate": "accecare",
    "accecavi": "accecare",
    "accecavo": "accecare",
    "accecherai": "accecare",
    "accecheran": "accecare",
    "accecheranno": "accecare",
    "accecherebbe": "accecare",
    "accecherebber": "accecare",
    "accecherebbero": "accecare",
    "accecherei": "accecare",
    "accecheremmo": "accecare",
    "accecheremo": "accecare",
    "accechereste": "accecare",
    "accecheresti": "accecare",
    "accecherete": "accecare",
    "accecherà": "accecare",
    "accecherò": "accecare",
    "accechi": "accecare",
    "accechiamo": "accecare",
    "accechiate": "accecare",
    "accechin": "accecare",
    "accechino": "accecare",
    "acceco": "accecare",
    "accecò": "accecare",
    "acceda": "accedere",
    "accedan": "accedere",
    "accedano": "accedere",
    "accede": "accedere",
    "accedemmo": "accedere",
    "accedendo": "accedere",
    "accedente": "accedere",
    "accedenti": "accedere",
    "acceder": "accedere",
    "accederai": "accedere",
    "accederan": "accedere",
    "accederanno": "accedere",
    "accederebbe": "accedere",
    "accederebber": "accedere",
    "accederebbero": "accedere",
    "accederei": "accedere",
    "accederemmo": "accedere",
    "accederemo": "accedere",
    "accedereste": "accedere",
    "accederesti": "accedere",
    "accederete": "accedere",
    "accederà": "accedere",
    "accederò": "accedere",
    "accedesse": "accedere",
    "accedesser": "accedere",
    "accedessero": "accedere",
    "accedessi": "accedere",
    "accedessimo": "accedere",
    "accedeste": "accedere",
    "accedesti": "accedere",
    "accedete": "accedere",
    "accedette": "accedere",
    "accedetter": "accedere",
    "accedettero": "accedere",
    "accedetti": "accedere",
    "accedeva": "accedere",
    "accedevamo": "accedere",
    "accedevan": "accedere",
    "accedevano": "accedere",
    "accedevate": "accedere",
    "accedevi": "accedere",
    "accedevo": "accedere",
    "accedi": "accedere",
    "accediamo": "accedere",
    "accediate": "accedere",
    "accedo": "accedere",
    "accedon": "accedere",
    "accedono": "accedere",
    "acceduta": "accedere",
    "accedute": "accedere",
    "acceduti": "accedere",
    "acceduto": "accedere",
    "accelera": "accelerare",
    "accelerai": "accelerare",
    "accelerammo": "accelerare",
    "acceleran": "accelerare",
    "accelerando": "accelerare",
    "accelerano": "accelerare",
    "accelerante": "accelerare",
    "acceleranti": "accelerare",
    "accelerar": "accelerare",
    "acceleraron": "accelerare",
    "accelerarono": "accelerare",
    "accelerasse": "accelerare",
    "accelerasser": "accelerare",
    "accelerassero": "accelerare",
    "accelerassi": "accelerare",
    "accelerassimo": "accelerare",
    "acceleraste": "accelerare",
    "accelerasti": "accelerare",
    "accelerata": "accelerato",
    "accelerate": "accelerato",
    "accelerati": "accelerato",
    "accelerato": "accelerare",
    "acceleratori": "acceleratore",
    "accelerava": "accelerare",
    "acceleravamo": "accelerare",
    "acceleravan": "accelerare",
    "acceleravano": "accelerare",
    "acceleravate": "accelerare",
    "acceleravi": "accelerare",
    "acceleravo": "accelerare",
    "accelerazioni": "accelerazione",
    "accelererai": "accelerare",
    "accelereran": "accelerare",
    "accelereranno": "accelerare",
    "accelererebbe": "accelerare",
    "accelererebber": "accelerare",
    "accelererebbero": "accelerare",
    "accelererei": "accelerare",
    "accelereremmo": "accelerare",
    "accelereremo": "accelerare",
    "accelerereste": "accelerare",
    "accelereresti": "accelerare",
    "accelererete": "accelerare",
    "accelererà": "accelerare",
    "accelererò": "accelerare",
    "acceleri": "accelerare",
    "acceleriamo": "accelerare",
    "acceleriate": "accelerare",
    "accelerin": "accelerare",
    "accelerino": "accelerare",
    "accelero": "accelerare",
    "accelerò": "accelerare",
    "accellera": "accellerare",
    "accellerai": "accellerare",
    "accellerammo": "accellerare",
    "accelleran": "accellerare",
    "accellerando": "accellerare",
    "accellerano": "accellerare",
    "accellerante": "accellerare",
    "accelleranti": "accellerare",
    "accellerar": "accellerare",
    "accelleraron": "accellerare",
    "accellerarono": "accellerare",
    "accellerasse": "accellerare",
    "accellerasser": "accellerare",
    "accellerassero": "accellerare",
    "accellerassi": "accellerare",
    "accellerassimo": "accellerare",
    "accelleraste": "accellerare",
    "accellerasti": "accellerare",
    "accellerata": "accellerare",
    "accellerate": "accellerare",
    "accellerati": "accellerare",
    "accellerato": "accellerare",
    "accellerava": "accellerare",
    "accelleravamo": "accellerare",
    "accelleravan": "accellerare",
    "accelleravano": "accellerare",
    "accelleravate": "accellerare",
    "accelleravi": "accellerare",
    "accelleravo": "accellerare",
    "accellererai": "accellerare",
    "accellereran": "accellerare",
    "accellereranno": "accellerare",
    "accellererebbe": "accellerare",
    "accellererebber": "accellerare",
    "accellererebbero": "accellerare",
    "accellererei": "accellerare",
    "accellereremmo": "accellerare",
    "accellereremo": "accellerare",
    "accellerereste": "accellerare",
    "accellereresti": "accellerare",
    "accellererete": "accellerare",
    "accellererà": "accellerare",
    "accellererò": "accellerare",
    "accelleri": "accellerare",
    "accelleriamo": "accellerare",
    "accelleriate": "accellerare",
    "accellerin": "accellerare",
    "accellerino": "accellerare",
    "accellero": "accellerare",
    "accellerò": "accellerare",
    "accenda": "accendere",
    "accendan": "accendere",
    "accendano": "accendere",
    "accende": "accendere",
    "accendemmo": "accendere",
    "accendendo": "accendere",
    "accendente": "accendere",
    "accendenti": "accendere",
    "accender": "accendere",
    "accenderai": "accendere",
    "accenderan": "accendere",
    "accenderanno": "accendere",
    "accenderebbe": "accendere",
    "accenderebber": "accendere",
    "accenderebbero": "accendere",
    "accenderei": "accendere",
    "accenderemmo": "accendere",
    "accenderemo": "accendere",
    "accendereste": "accendere",
    "accenderesti": "accendere",
    "accenderete": "accendere",
    "accenderà": "accendere",
    "accenderò": "accendere",
    "accendesse": "accendere",
    "accendesser": "accendere",
    "accendessero": "accendere",
    "accendessi": "accendere",
    "accendessimo": "accendere",
    "accendeste": "accendere",
    "accendesti": "accendere",
    "accendete": "accendere",
    "accendeva": "accendere",
    "accendevamo": "accendere",
    "accendevan": "accendere",
    "accendevano": "accendere",
    "accendevate": "accendere",
    "accendevi": "accendere",
    "accendevo": "accendere",
    "accendi": "accendere",
    "accendiamo": "accendere",
    "accendiate": "accendere",
    "accendini": "accendino",
    "accendo": "accendere",
    "accendon": "accendere",
    "accendono": "accendere",
    "accenna": "accennare",
    "accennai": "accennare",
    "accennammo": "accennare",
    "accennan": "accennare",
    "accennando": "accennare",
    "accennano": "accennare",
    "accennante": "accennare",
    "accennanti": "accennare",
    "accennar": "accennare",
    "accennaron": "accennare",
    "accennarono": "accennare",
    "accennasse": "accennare",
    "accennasser": "accennare",
    "accennassero": "accennare",
    "accennassi": "accennare",
    "accennassimo": "accennare",
    "accennaste": "accennare",
    "accennasti": "accennare",
    "accennata": "accennare",
    "accennate": "accennare",
    "accennati": "accennare",
    "accennato": "accennare",
    "accennava": "accennare",
    "accennavamo": "accennare",
    "accennavan": "accennare",
    "accennavano": "accennare",
    "accennavate": "accennare",
    "accennavi": "accennare",
    "accennavo": "accennare",
    "accennerai": "accennare",
    "accenneran": "accennare",
    "accenneranno": "accennare",
    "accennerebbe": "accennare",
    "accennerebber": "accennare",
    "accennerebbero": "accennare",
    "accennerei": "accennare",
    "accenneremmo": "accennare",
    "accenneremo": "accennare",
    "accennereste": "accennare",
    "accenneresti": "accennare",
    "accennerete": "accennare",
    "accennerà": "accennare",
    "accennerò": "accennare",
    "accenni": "accenno",
    "accenniamo": "accennare",
    "accenniate": "accennare",
    "accennin": "accennare",
    "accennino": "accennare",
    "accenno": "accennare",
    "accennò": "accennare",
    "accensioni": "accensione",
    "accenta": "accentare",
    "accentai": "accentare",
    "accentammo": "accentare",
    "accentan": "accentare",
    "accentando": "accentare",
    "accentano": "accentare",
    "accentante": "accentare",
    "accentanti": "accentare",
    "accentar": "accentare",
    "accentaron": "accentare",
    "accentarono": "accentare",
    "accentasse": "accentare",
    "accentasser": "accentare",
    "accentassero": "accentare",
    "accentassi": "accentare",
    "accentassimo": "accentare",
    "accentaste": "accentare",
    "accentasti": "accentare",
    "accentata": "accentare",
    "accentate": "accentare",
    "accentati": "accentare",
    "accentato": "accentare",
    "accentava": "accentare",
    "accentavamo": "accentare",
    "accentavan": "accentare",
    "accentavano": "accentare",
    "accentavate": "accentare",
    "accentavi": "accentare",
    "accentavo": "accentare",
    "accenterai": "accentare",
    "accenteran": "accentare",
    "accenteranno": "accentare",
    "accenterebbe": "accentare",
    "accenterebber": "accentare",
    "accenterebbero": "accentare",
    "accenterei": "accentare",
    "accenteremmo": "accentare",
    "accenteremo": "accentare",
    "accentereste": "accentare",
    "accenteresti": "accentare",
    "accenterete": "accentare",
    "accenterà": "accentare",
    "accenterò": "accentare",
    "accenti": "accento",
    "accentiamo": "accentare",
    "accentiate": "accentare",
    "accentin": "accentare",
    "accentino": "accentare",
    "accento": "accentare",
    "accentra": "accentrare",
    "accentrai": "accentrare",
    "accentrammo": "accentrare",
    "accentran": "accentrare",
    "accentrando": "accentrare",
    "accentrano": "accentrare",
    "accentrante": "accentrare",
    "accentranti": "accentrare",
    "accentrar": "accentrare",
    "accentraron": "accentrare",
    "accentrarono": "accentrare",
    "accentrasse": "accentrare",
    "accentrasser": "accentrare",
    "accentrassero": "accentrare",
    "accentrassi": "accentrare",
    "accentrassimo": "accentrare",
    "accentraste": "accentrare",
    "accentrasti": "accentrare",
    "accentrata": "accentrare",
    "accentrate": "accentrare",
    "accentrati": "accentrare",
    "accentrato": "accentrare",
    "accentratori": "accentratore",
    "accentratrice": "accentratore",
    "accentratrici": "accentratore",
    "accentrava": "accentrare",
    "accentravamo": "accentrare",
    "accentravan": "accentrare",
    "accentravano": "accentrare",
    "accentravate": "accentrare",
    "accentravi": "accentrare",
    "accentravo": "accentrare",
    "accentrerai": "accentrare",
    "accentreran": "accentrare",
    "accentreranno": "accentrare",
    "accentrerebbe": "accentrare",
    "accentrerebber": "accentrare",
    "accentrerebbero": "accentrare",
    "accentrerei": "accentrare",
    "accentreremmo": "accentrare",
    "accentreremo": "accentrare",
    "accentrereste": "accentrare",
    "accentreresti": "accentrare",
    "accentrerete": "accentrare",
    "accentrerà": "accentrare",
    "accentrerò": "accentrare",
    "accentri": "accentrare",
    "accentriamo": "accentrare",
    "accentriate": "accentrare",
    "accentrin": "accentrare",
    "accentrino": "accentrare",
    "accentro": "accentrare",
    "accentrò": "accentrare",
    "accentua": "accentuare",
    "accentuai": "accentuare",
    "accentuammo": "accentuare",
    "accentuan": "accentuare",
    "accentuando": "accentuare",
    "accentuano": "accentuare",
    "accentuante": "accentuare",
    "accentuanti": "accentuare",
    "accentuar": "accentuare",
    "accentuaron": "accentuare",
    "accentuarono": "accentuare",
    "accentuasse": "accentuare",
    "accentuasser": "accentuare",
    "accentuassero": "accentuare",
    "accentuassi": "accentuare",
    "accentuassimo": "accentuare",
    "accentuaste": "accentuare",
    "accentuasti": "accentuare",
    "accentuata": "accentuato",
    "accentuate": "accentuato",
    "accentuati": "accentuato",
    "accentuato": "accentuare",
    "accentuava": "accentuare",
    "accentuavamo": "accentuare",
    "accentuavan": "accentuare",
    "accentuavano": "accentuare",
    "accentuavate": "accentuare",
    "accentuavi": "accentuare",
    "accentuavo": "accentuare",
    "accentuazioni": "accentuazione",
    "accentuerai": "accentuare",
    "accentueran": "accentuare",
    "accentueranno": "accentuare",
    "accentuerebbe": "accentuare",
    "accentuerebber": "accentuare",
    "accentuerebbero": "accentuare",
    "accentuerei": "accentuare",
    "accentueremmo": "accentuare",
    "accentueremo": "accentuare",
    "accentuereste": "accentuare",
    "accentueresti": "accentuare",
    "accentuerete": "accentuare",
    "accentuerà": "accentuare",
    "accentuerò": "accentuare",
    "accentui": "accentuare",
    "accentuiamo": "accentuare",
    "accentuiate": "accentuare",
    "accentuin": "accentuare",
    "accentuino": "accentuare",
    "accentuo": "accentuare",
    "accentuò": "accentuare",
    "accentò": "accentare",
    "accerchi": "accerchiare",
    "accerchia": "accerchiare",
    "accerchiai": "accerchiare",
    "accerchiamenti": "accerchiamento",
    "accerchiammo": "accerchiare",
    "accerchiamo": "accerchiare",
    "accerchian": "accerchiare",
    "accerchiando": "accerchiare",
    "accerchiano": "accerchiare",
    "accerchiante": "accerchiare",
    "accerchianti": "accerchiare",
    "accerchiar": "accerchiare",
    "accerchiaron": "accerchiare",
    "accerchiarono": "accerchiare",
    "accerchiasse": "accerchiare",
    "accerchiasser": "accerchiare",
    "accerchiassero": "accerchiare",
    "accerchiassi": "accerchiare",
    "accerchiassimo": "accerchiare",
    "accerchiaste": "accerchiare",
    "accerchiasti": "accerchiare",
    "accerchiata": "accerchiare",
    "accerchiate": "accerchiare",
    "accerchiati": "accerchiare",
    "accerchiato": "accerchiare",
    "accerchiava": "accerchiare",
    "accerchiavamo": "accerchiare",
    "accerchiavan": "accerchiare",
    "accerchiavano": "accerchiare",
    "accerchiavate": "accerchiare",
    "accerchiavi": "accerchiare",
    "accerchiavo": "accerchiare",
    "accerchierai": "accerchiare",
    "accerchieran": "accerchiare",
    "accerchieranno": "accerchiare",
    "accerchierebbe": "accerchiare",
    "accerchierebber": "accerchiare",
    "accerchierebbero": "accerchiare",
    "accerchierei": "accerchiare",
    "accerchieremmo": "accerchiare",
    "accerchieremo": "accerchiare",
    "accerchiereste": "accerchiare",
    "accerchieresti": "accerchiare",
    "accerchierete": "accerchiare",
    "accerchierà": "accerchiare",
    "accerchierò": "accerchiare",
    "accerchin": "accerchiare",
    "accerchino": "accerchiare",
    "accerchio": "accerchiare",
    "accerchiò": "accerchiare",
    "accerta": "accertare",
    "accertabili": "accertabile",
    "accertai": "accertare",
    "accertamenti": "accertamento",
    "accertammo": "accertare",
    "accertan": "accertare",
    "accertando": "accertare",
    "accertano": "accertare",
    "accertante": "accertare",
    "accertanti": "accertare",
    "accertar": "accertare",
    "accertaron": "accertare",
    "accertarono": "accertare",
    "accertasse": "accertare",
    "accertasser": "accertare",
    "accertassero": "accertare",
    "accertassi": "accertare",
    "accertassimo": "accertare",
    "accertaste": "accertare",
    "accertasti": "accertare",
    "accertata": "accertare",
    "accertate": "accertare",
    "accertati": "accertare",
    "accertato": "accertare",
    "accertava": "accertare",
    "accertavamo": "accertare",
    "accertavan": "accertare",
    "accertavano": "accertare",
    "accertavate": "accertare",
    "accertavi": "accertare",
    "accertavo": "accertare",
    "accerterai": "accertare",
    "accerteran": "accertare",
    "accerteranno": "accertare",
    "accerterebbe": "accertare",
    "accerterebber": "accertare",
    "accerterebbero": "accertare",
    "accerterei": "accertare",
    "accerteremmo": "accertare",
    "accerteremo": "accertare",
    "accertereste": "accertare",
    "accerteresti": "accertare",
    "accerterete": "accertare",
    "accerterà": "accertare",
    "accerterò": "accertare",
    "accerti": "accertare",
    "accertiamo": "accertare",
    "accertiate": "accertare",
    "accertin": "accertare",
    "accertino": "accertare",
    "accerto": "accertare",
    "accertò": "accertare",
    "accesa": "acceso",
    "accese": "acceso",
    "acceser": "accendere",
    "accesero": "accendere",
    "accesi": "acceso",
    "acceso": "accendere",
    "accessi": "accesso",
    "accessibili": "accessibile",
    "accessori": "accessorio",
    "accessoria": "accessorio",
    "accessoriata": "accessoriato",
    "accessoriate": "accessoriato",
    "accessoriati": "accessoriato",
    "accessorie": "accessorio",
    "accesè": "accendere",
    "accetta": "accetto",
    "accettabili": "accettabile",
    "accettai": "accettare",
    "accettammo": "accettare",
    "accettan": "accettare",
    "accettando": "accettare",
    "accettano": "accettare",
    "accettante": "accettare",
    "accettanti": "accettare",
    "accettar": "accettare",
    "accettaron": "accettare",
    "accettarono": "accettare",
    "accettasse": "accettare",
    "accettasser": "accettare",
    "accettassero": "accettare",
    "accettassi": "accettare",
    "accettassimo": "accettare",
    "accettaste": "accettare",
    "accettasti": "accettare",
    "accettata": "accettare",
    "accettate": "accettare",
    "accettati": "accettare",
    "accettato": "accettare",
    "accettava": "accettare",
    "accettavamo": "accettare",
    "accettavan": "accettare",
    "accettavano": "accettare",
    "accettavate": "accettare",
    "accettavi": "accettare",
    "accettavo": "accettare",
    "accettazioni": "accettazione",
    "accette": "accetto",
    "accetterai": "accettare",
    "accetteran": "accettare",
    "accetteranno": "accettare",
    "accetterebbe": "accettare",
    "accetterebber": "accettare",
    "accetterebbero": "accettare",
    "accetterei": "accettare",
    "accetteremmo": "accettare",
    "accetteremo": "accettare",
    "accettereste": "accettare",
    "accetteresti": "accettare",
    "accetterete": "accettare",
    "accetterà": "accettare",
    "accetterò": "accettare",
    "accetti": "accetto",
    "accettiamo": "accettare",
    "accettiate": "accettare",
    "accettin": "accettare",
    "accettino": "accettare",
    "accetto": "accettare",
    "accettò": "accettare",
    "accezioni": "accezione",
    "acchiappa": "acchiappare",
    "acchiappai": "acchiappare",
    "acchiappammo": "acchiappare",
    "acchiappan": "acchiappare",
    "acchiappando": "acchiappare",
    "acchiappano": "acchiappare",
    "acchiappante": "acchiappare",
    "acchiappanti": "acchiappare",
    "acchiappar": "acchiappare",
    "acchiapparon": "acchiappare",
    "acchiapparono": "acchiappare",
    "acchiappasse": "acchiappare",
    "acchiappasser": "acchiappare",
    "acchiappassero": "acchiappare",
    "acchiappassi": "acchiappare",
    "acchiappassimo": "acchiappare",
    "acchiappaste": "acchiappare",
    "acchiappasti": "acchiappare",
    "acchiappata": "acchiappare",
    "acchiappate": "acchiappare",
    "acchiappati": "acchiappare",
    "acchiappato": "acchiappare",
    "acchiappava": "acchiappare",
    "acchiappavamo": "acchiappare",
    "acchiappavan": "acchiappare",
    "acchiappavano": "acchiappare",
    "acchiappavate": "acchiappare",
    "acchiappavi": "acchiappare",
    "acchiappavo": "acchiappare",
    "acchiapperai": "acchiappare",
    "acchiapperan": "acchiappare",
    "acchiapperanno": "acchiappare",
    "acchiapperebbe": "acchiappare",
    "acchiapperebber": "acchiappare",
    "acchiapperebbero": "acchiappare",
    "acchiapperei": "acchiappare",
    "acchiapperemmo": "acchiappare",
    "acchiapperemo": "acchiappare",
    "acchiappereste": "acchiappare",
    "acchiapperesti": "acchiappare",
    "acchiapperete": "acchiappare",
    "acchiapperà": "acchiappare",
    "acchiapperò": "acchiappare",
    "acchiappi": "acchiappare",
    "acchiappiamo": "acchiappare",
    "acchiappiate": "acchiappare",
    "acchiappin": "acchiappare",
    "acchiappino": "acchiappare",
    "acchiappo": "acchiappare",
    "acchiappò": "acchiappare",
    "acchita": "acchitare",
    "acchitai": "acchitare",
    "acchitammo": "acchitare",
    "acchitan": "acchitare",
    "acchitando": "acchitare",
    "acchitano": "acchitare",
    "acchitante": "acchitare",
    "acchitanti": "acchitare",
    "acchitar": "acchitare",
    "acchitaron": "acchitare",
    "acchitarono": "acchitare",
    "acchitasse": "acchitare",
    "acchitasser": "acchitare",
    "acchitassero": "acchitare",
    "acchitassi": "acchitare",
    "acchitassimo": "acchitare",
    "acchitaste": "acchitare",
    "acchitasti": "acchitare",
    "acchitata": "acchitare",
    "acchitate": "acchitare",
    "acchitati": "acchitare",
    "acchitato": "acchitare",
    "acchitava": "acchitare",
    "acchitavamo": "acchitare",
    "acchitavan": "acchitare",
    "acchitavano": "acchitare",
    "acchitavate": "acchitare",
    "acchitavi": "acchitare",
    "acchitavo": "acchitare",
    "acchiterai": "acchitare",
    "acchiteran": "acchitare",
    "acchiteranno": "acchitare",
    "acchiterebbe": "acchitare",
    "acchiterebber": "acchitare",
    "acchiterebbero": "acchitare",
    "acchiterei": "acchitare",
    "acchiteremmo": "acchitare",
    "acchiteremo": "acchitare",
    "acchitereste": "acchitare",
    "acchiteresti": "acchitare",
    "acchiterete": "acchitare",
    "acchiterà": "acchitare",
    "acchiterò": "acchitare",
    "acchiti": "acchitare",
    "acchitiamo": "acchitare",
    "acchitiate": "acchitare",
    "acchitin": "acchitare",
    "acchitino": "acchitare",
    "acchito": "acchitare",
    "acchitò": "acchitare",
    "acciacca": "acciaccare",
    "acciaccai": "acciaccare",
    "acciaccammo": "acciaccare",
    "acciaccan": "acciaccare",
    "acciaccando": "acciaccare",
    "acciaccano": "acciaccare",
    "acciaccante": "acciaccare",
    "acciaccanti": "acciaccare",
    "acciaccar": "acciaccare",
    "acciaccaron": "acciaccare",
    "acciaccarono": "acciaccare",
    "acciaccasse": "acciaccare",
    "acciaccasser": "acciaccare",
    "acciaccassero": "acciaccare",
    "acciaccassi": "acciaccare",
    "acciaccassimo": "acciaccare",
    "acciaccaste": "acciaccare",
    "acciaccasti": "acciaccare",
    "acciaccata": "acciaccato",
    "acciaccate": "acciaccato",
    "acciaccati": "acciaccato",
    "acciaccato": "acciaccare",
    "acciaccava": "acciaccare",
    "acciaccavamo": "acciaccare",
    "acciaccavan": "acciaccare",
    "acciaccavano": "acciaccare",
    "acciaccavate": "acciaccare",
    "acciaccavi": "acciaccare",
    "acciaccavo": "acciaccare",
    "acciaccherai": "acciaccare",
    "acciaccheran": "acciaccare",
    "acciaccheranno": "acciaccare",
    "acciaccherebbe": "acciaccare",
    "acciaccherebber": "acciaccare",
    "acciaccherebbero": "acciaccare",
    "acciaccherei": "acciaccare",
    "acciaccheremmo": "acciaccare",
    "acciaccheremo": "acciaccare",
    "acciacchereste": "acciaccare",
    "acciaccheresti": "acciaccare",
    "acciaccherete": "acciaccare",
    "acciaccherà": "acciaccare",
    "acciaccherò": "acciaccare",
    "acciacchi": "acciacco",
    "acciacchiamo": "acciaccare",
    "acciacchiate": "acciaccare",
    "acciacchin": "acciaccare",
    "acciacchino": "acciaccare",
    "acciacco": "acciaccare",
    "acciaccò": "acciaccare",
    "acciai": "acciaio",
    "acciaia": "acciaiare",
    "acciaiai": "acciaiare",
    "acciaiammo": "acciaiare",
    "acciaiamo": "acciaiare",
    "acciaian": "acciaiare",
    "acciaiando": "acciaiare",
    "acciaiano": "acciaiare",
    "acciaiante": "acciaiare",
    "acciaianti": "acciaiare",
    "acciaiar": "acciaiare",
    "acciaiaron": "acciaiare",
    "acciaiarono": "acciaiare",
    "acciaiasse": "acciaiare",
    "acciaiasser": "acciaiare",
    "acciaiassero": "acciaiare",
    "acciaiassi": "acciaiare",
    "acciaiassimo": "acciaiare",
    "acciaiaste": "acciaiare",
    "acciaiasti": "acciaiare",
    "acciaiata": "acciaiare",
    "acciaiate": "acciaiare",
    "acciaiati": "acciaiare",
    "acciaiato": "acciaiare",
    "acciaiava": "acciaiare",
    "acciaiavamo": "acciaiare",
    "acciaiavan": "acciaiare",
    "acciaiavano": "acciaiare",
    "acciaiavate": "acciaiare",
    "acciaiavi": "acciaiare",
    "acciaiavo": "acciaiare",
    "acciaierai": "acciaiare",
    "acciaieran": "acciaiare",
    "acciaieranno": "acciaiare",
    "acciaierebbe": "acciaiare",
    "acciaierebber": "acciaiare",
    "acciaierebbero": "acciaiare",
    "acciaierei": "acciaiare",
    "acciaieremmo": "acciaiare",
    "acciaieremo": "acciaiare",
    "acciaiereste": "acciaiare",
    "acciaieresti": "acciaiare",
    "acciaierete": "acciaiare",
    "acciaierie": "acciaieria",
    "acciaierà": "acciaiare",
    "acciaierò": "acciaiare",
    "acciain": "acciaiare",
    "acciaino": "acciaiare",
    "acciaio": "acciaiare",
    "acciaiò": "acciaiare",
    "acciambella": "acciambellare",
    "acciambellai": "acciambellare",
    "acciambellammo": "acciambellare",
    "acciambellan": "acciambellare",
    "acciambellando": "acciambellare",
    "acciambellano": "acciambellare",
    "acciambellante": "acciambellare",
    "acciambellanti": "acciambellare",
    "acciambellar": "acciambellare",
    "acciambellaron": "acciambellare",
    "acciambellarono": "acciambellare",
    "acciambellasse": "acciambellare",
    "acciambellasser": "acciambellare",
    "acciambellassero": "acciambellare",
    "acciambellassi": "acciambellare",
    "acciambellassimo": "acciambellare",
    "acciambellaste": "acciambellare",
    "acciambellasti": "acciambellare",
    "acciambellata": "acciambellare",
    "acciambellate": "acciambellare",
    "acciambellati": "acciambellare",
    "acciambellato": "acciambellare",
    "acciambellava": "acciambellare",
    "acciambellavamo": "acciambellare",
    "acciambellavan": "acciambellare",
    "acciambellavano": "acciambellare",
    "acciambellavate": "acciambellare",
    "acciambellavi": "acciambellare",
    "acciambellavo": "acciambellare",
    "acciambellerai": "acciambellare",
    "acciambelleran": "acciambellare",
    "acciambelleranno": "acciambellare",
    "acciambellerebbe": "acciambellare",
    "acciambellerebber": "acciambellare",
    "acciambellerebbero": "acciambellare",
    "acciambellerei": "acciambellare",
    "acciambelleremmo": "acciambellare",
    "acciambelleremo": "acciambellare",
    "acciambellereste": "acciambellare",
    "acciambelleresti": "acciambellare",
    "acciambellerete": "acciambellare",
    "acciambellerà": "acciambellare",
    "acciambellerò": "acciambellare",
    "acciambelli": "acciambellare",
    "acciambelliamo": "acciambellare",
    "acciambelliate": "acciambellare",
    "acciambellin": "acciambellare",
    "acciambellino": "acciambellare",
    "acciambello": "acciambellare",
    "acciambellò": "acciambellare",
    "accidentali": "accidentale",
    "accidentata": "accidentato",
    "accidentate": "accidentato",
    "accidentati": "accidentato",
    "accidenti": "accidente",
    "accidiosa": "accidioso",
    "accidiose": "accidioso",
    "accidiosi": "accidioso",
    "accigli": "accigliare",
    "acciglia": "accigliare",
    "accigliai": "accigliare",
    "accigliammo": "accigliare",
    "accigliamo": "accigliare",
    "acciglian": "accigliare",
    "accigliando": "accigliare",
    "accigliano": "accigliare",
    "accigliar": "accigliare",
    "accigliaron": "accigliare",
    "accigliarono": "accigliare",
    "accigliasse": "accigliare",
    "accigliasser": "accigliare",
    "accigliassero": "accigliare",
    "accigliassi": "accigliare",
    "accigliassimo": "accigliare",
    "accigliaste": "accigliare",
    "accigliasti": "accigliare",
    "accigliata": "accigliato",
    "accigliate": "accigliato",
    "accigliati": "accigliato",
    "accigliato": "accigliare",
    "accigliava": "accigliare",
    "accigliavamo": "accigliare",
    "accigliavan": "accigliare",
    "accigliavano": "accigliare",
    "accigliavate": "accigliare",
    "accigliavi": "accigliare",
    "accigliavo": "accigliare",
    "acciglierai": "accigliare",
    "acciglieran": "accigliare",
    "acciglieranno": "accigliare",
    "acciglierebbe": "accigliare",
    "acciglierebber": "accigliare",
    "acciglierebbero": "accigliare",
    "acciglierei": "accigliare",
    "acciglieremmo": "accigliare",
    "acciglieremo": "accigliare",
    "accigliereste": "accigliare",
    "acciglieresti": "accigliare",
    "acciglierete": "accigliare",
    "acciglierà": "accigliare",
    "acciglierò": "accigliare",
    "acciglin": "accigliare",
    "acciglino": "accigliare",
    "acciglio": "accigliare",
    "accigliò": "accigliare",
    "accinga": "accingere",
    "accingan": "accingere",
    "accingano": "accingere",
    "accinge": "accingere",
    "accingemmo": "accingere",
    "accingendo": "accingere",
    "accingente": "accingere",
    "accingenti": "accingere",
    "accinger": "accingere",
    "accingerai": "accingere",
    "accingeran": "accingere",
    "accingeranno": "accingere",
    "accingerebbe": "accingere",
    "accingerebber": "accingere",
    "accingerebbero": "accingere",
    "accingerei": "accingere",
    "accingeremmo": "accingere",
    "accingeremo": "accingere",
    "accingereste": "accingere",
    "accingeresti": "accingere",
    "accingerete": "accingere",
    "accingerà": "accingere",
    "accingerò": "accingere",
    "accingesse": "accingere",
    "accingesser": "accingere",
    "accingessero": "accingere",
    "accingessi": "accingere",
    "accingessimo": "accingere",
    "accingeste": "accingere",
    "accingesti": "accingere",
    "accingete": "accingere",
    "accingeva": "accingere",
    "accingevamo": "accingere",
    "accingevan": "accingere",
    "accingevano": "accingere",
    "accingevate": "accingere",
    "accingevi": "accingere",
    "accingevo": "accingere",
    "accingi": "accingere",
    "accingiamo": "accingere",
    "accingiate": "accingere",
    "accingo": "accingere",
    "accingon": "accingere",
    "accingono": "accingere",
    "accinse": "accingere",
    "accinser": "accingere",
    "accinsero": "accingere",
    "accinsi": "accingere",
    "accinta": "accingere",
    "accinte": "accingere",
    "accinti": "accingere",
    "accinto": "accingere",
    "acciottola": "acciottolare",
    "acciottolai": "acciottolare",
    "acciottolammo": "acciottolare",
    "acciottolan": "acciottolare",
    "acciottolando": "acciottolare",
    "acciottolano": "acciottolare",
    "acciottolante": "acciottolare",
    "acciottolanti": "acciottolare",
    "acciottolar": "acciottolare",
    "acciottolaron": "acciottolare",
    "acciottolarono": "acciottolare",
    "acciottolasse": "acciottolare",
    "acciottolasser": "acciottolare",
    "acciottolassero": "acciottolare",
    "acciottolassi": "acciottolare",
    "acciottolassimo": "acciottolare",
    "acciottolaste": "acciottolare",
    "acciottolasti": "acciottolare",
    "acciottolata": "acciottolato",
    "acciottolate": "acciottolato",
    "acciottolati": "acciottolato",
    "acciottolato": "acciottolare",
    "acciottolava": "acciottolare",
    "acciottolavamo": "acciottolare",
    "acciottolavan": "acciottolare",
    "acciottolavano": "acciottolare",
    "acciottolavate": "acciottolare",
    "acciottolavi": "acciottolare",
    "acciottolavo": "acciottolare",
    "acciottolerai": "acciottolare",
    "acciottoleran": "acciottolare",
    "acciottoleranno": "acciottolare",
    "acciottolerebbe": "acciottolare",
    "acciottolerebber": "acciottolare",
    "acciottolerebbero": "acciottolare",
    "acciottolerei": "acciottolare",
    "acciottoleremmo": "acciottolare",
    "acciottoleremo": "acciottolare",
    "acciottolereste": "acciottolare",
    "acciottoleresti": "acciottolare",
    "acciottolerete": "acciottolare",
    "acciottolerà": "acciottolare",
    "acciottolerò": "acciottolare",
    "acciottoli": "acciottolare",
    "acciottoliamo": "acciottolare",
    "acciottoliate": "acciottolare",
    "acciottolin": "acciottolare",
    "acciottolino": "acciottolare",
    "acciottolo": "acciottolare",
    "acciottolò": "acciottolare",
    "acciuffa": "acciuffare",
    "acciuffai": "acciuffare",
    "acciuffammo": "acciuffare",
    "acciuffan": "acciuffare",
    "acciuffando": "acciuffare",
    "acciuffano": "acciuffare",
    "acciuffante": "acciuffare",
    "acciuffanti": "acciuffare",
    "acciuffar": "acciuffare",
    "acciuffaron": "acciuffare",
    "acciuffarono": "acciuffare",
    "acciuffasse": "acciuffare",
    "acciuffasser": "acciuffare",
    "acciuffassero": "acciuffare",
    "acciuffassi": "acciuffare",
    "acciuffassimo": "acciuffare",
    "acciuffaste": "acciuffare",
    "acciuffasti": "acciuffare",
    "acciuffata": "acciuffare",
    "acciuffate": "acciuffare",
    "acciuffati": "acciuffare",
    "acciuffato": "acciuffare",
    "acciuffava": "acciuffare",
    "acciuffavamo": "acciuffare",
    "acciuffavan": "acciuffare",
    "acciuffavano": "acciuffare",
    "acciuffavate": "acciuffare",
    "acciuffavi": "acciuffare",
    "acciuffavo": "acciuffare",
    "acciufferai": "acciuffare",
    "acciufferan": "acciuffare",
    "acciufferanno": "acciuffare",
    "acciufferebbe": "acciuffare",
    "acciufferebber": "acciuffare",
    "acciufferebbero": "acciuffare",
    "acciufferei": "acciuffare",
    "acciufferemmo": "acciuffare",
    "acciufferemo": "acciuffare",
    "acciuffereste": "acciuffare",
    "acciufferesti": "acciuffare",
    "acciufferete": "acciuffare",
    "acciufferà": "acciuffare",
    "acciufferò": "acciuffare",
    "acciuffi": "acciuffare",
    "acciuffiamo": "acciuffare",
    "acciuffiate": "acciuffare",
    "acciuffin": "acciuffare",
    "acciuffino": "acciuffare",
    "acciuffo": "acciuffare",
    "acciuffò": "acciuffare",
    "acciughe": "acciuga",
    "acclama": "acclamare",
    "acclamai": "acclamare",
    "acclamammo": "acclamare",
    "acclaman": "acclamare",
    "acclamando": "acclamare",
    "acclamano": "acclamare",
    "acclamante": "acclamare",
    "acclamanti": "acclamare",
    "acclamar": "acclamare",
    "acclamaron": "acclamare",
    "acclamarono": "acclamare",
    "acclamasse": "acclamare",
    "acclamasser": "acclamare",
    "acclamassero": "acclamare",
    "acclamassi": "acclamare",
    "acclamassimo": "acclamare",
    "acclamaste": "acclamare",
    "acclamasti": "acclamare",
    "acclamata": "acclamare",
    "acclamate": "acclamare",
    "acclamati": "acclamare",
    "acclamato": "acclamare",
    "acclamava": "acclamare",
    "acclamavamo": "acclamare",
    "acclamavan": "acclamare",
    "acclamavano": "acclamare",
    "acclamavate": "acclamare",
    "acclamavi": "acclamare",
    "acclamavo": "acclamare",
    "acclamazioni": "acclamazione",
    "acclamerai": "acclamare",
    "acclameran": "acclamare",
    "acclameranno": "acclamare",
    "acclamerebbe": "acclamare",
    "acclamerebber": "acclamare",
    "acclamerebbero": "acclamare",
    "acclamerei": "acclamare",
    "acclameremmo": "acclamare",
    "acclameremo": "acclamare",
    "acclamereste": "acclamare",
    "acclameresti": "acclamare",
    "acclamerete": "acclamare",
    "acclamerà": "acclamare",
    "acclamerò": "acclamare",
    "acclami": "acclamare",
    "acclamiamo": "acclamare",
    "acclamiate": "acclamare",
    "acclamin": "acclamare",
    "acclamino": "acclamare",
    "acclamo": "acclamare",
    "acclamò": "acclamare",
    "acclima": "acclimare",
    "acclimai": "acclimare",
    "acclimammo": "acclimare",
    "accliman": "acclimare",
    "acclimando": "acclimare",
    "acclimano": "acclimare",
    "acclimante": "acclimare",
    "acclimanti": "acclimare",
    "acclimar": "acclimare",
    "acclimaron": "acclimare",
    "acclimarono": "acclimare",
    "acclimasse": "acclimare",
    "acclimasser": "acclimare",
    "acclimassero": "acclimare",
    "acclimassi": "acclimare",
    "acclimassimo": "acclimare",
    "acclimaste": "acclimare",
    "acclimasti": "acclimare",
    "acclimata": "acclimatare",
    "acclimatai": "acclimatare",
    "acclimatammo": "acclimatare",
    "acclimatan": "acclimatare",
    "acclimatando": "acclimatare",
    "acclimatano": "acclimatare",
    "acclimatante": "acclimatare",
    "acclimatanti": "acclimatare",
    "acclimatar": "acclimatare",
    "acclimataron": "acclimatare",
    "acclimatarono": "acclimatare",
    "acclimatasse": "acclimatare",
    "acclimatasser": "acclimatare",
    "acclimatassero": "acclimatare",
    "acclimatassi": "acclimatare",
    "acclimatassimo": "acclimatare",
    "acclimataste": "acclimatare",
    "acclimatasti": "acclimatare",
    "acclimatata": "acclimatare",
    "acclimatate": "acclimatare",
    "acclimatati": "acclimatare",
    "acclimatato": "acclimatare",
    "acclimatava": "acclimatare",
    "acclimatavamo": "acclimatare",
    "acclimatavan": "acclimatare",
    "acclimatavano": "acclimatare",
    "acclimatavate": "acclimatare",
    "acclimatavi": "acclimatare",
    "acclimatavo": "acclimatare",
    "acclimate": "acclimare",
    "acclimaterai": "acclimatare",
    "acclimateran": "acclimatare",
    "acclimateranno": "acclimatare",
    "acclimaterebbe": "acclimatare",
    "acclimaterebber": "acclimatare",
    "acclimaterebbero": "acclimatare",
    "acclimaterei": "acclimatare",
    "acclimateremmo": "acclimatare",
    "acclimateremo": "acclimatare",
    "acclimatereste": "acclimatare",
    "acclimateresti": "acclimatare",
    "acclimaterete": "acclimatare",
    "acclimaterà": "acclimatare",
    "acclimaterò": "acclimatare",
    "acclimati": "acclimatare",
    "acclimatiamo": "acclimatare",
    "acclimatiate": "acclimatare",
    "acclimatin": "acclimatare",
    "acclimatino": "acclimatare",
    "acclimato": "acclimatare",
    "acclimatò": "acclimatare",
    "acclimava": "acclimare",
    "acclimavamo": "acclimare",
    "acclimavan": "acclimare",
    "acclimavano": "acclimare",
    "acclimavate": "acclimare",
    "acclimavi": "acclimare",
    "acclimavo": "acclimare",
    "acclimerai": "acclimare",
    "acclimeran": "acclimare",
    "acclimeranno": "acclimare",
    "acclimerebbe": "acclimare",
    "acclimerebber": "acclimare",
    "acclimerebbero": "acclimare",
    "acclimerei": "acclimare",
    "acclimeremmo": "acclimare",
    "acclimeremo": "acclimare",
    "acclimereste": "acclimare",
    "acclimeresti": "acclimare",
    "acclimerete": "acclimare",
    "acclimerà": "acclimare",
    "acclimerò": "acclimare",
    "acclimi": "acclimare",
    "acclimiamo": "acclimare",
    "acclimiate": "acclimare",
    "acclimin": "acclimare",
    "acclimino": "acclimare",
    "acclimo": "acclimare",
    "acclimò": "acclimare",
    "accluda": "accludere",
    "accludan": "accludere",
    "accludano": "accludere",
    "acclude": "accludere",
    "accludemmo": "accludere",
    "accludendo": "accludere",
    "accludente": "accludere",
    "accludenti": "accludere",
    "accluder": "accludere",
    "accluderai": "accludere",
    "accluderan": "accludere",
    "accluderanno": "accludere",
    "accluderebbe": "accludere",
    "accluderebber": "accludere",
    "accluderebbero": "accludere",
    "accluderei": "accludere",
    "accluderemmo": "accludere",
    "accluderemo": "accludere",
    "accludereste": "accludere",
    "accluderesti": "accludere",
    "accluderete": "accludere",
    "accluderà": "accludere",
    "accluderò": "accludere",
    "accludesse": "accludere",
    "accludesser": "accludere",
    "accludessero": "accludere",
    "accludessi": "accludere",
    "accludessimo": "accludere",
    "accludeste": "accludere",
    "accludesti": "accludere",
    "accludete": "accludere",
    "accludeva": "accludere",
    "accludevamo": "accludere",
    "accludevan": "accludere",
    "accludevano": "accludere",
    "accludevate": "accludere",
    "accludevi": "accludere",
    "accludevo": "accludere",
    "accludi": "accludere",
    "accludiamo": "accludere",
    "accludiate": "accludere",
    "accludo": "accludere",
    "accludon": "accludere",
    "accludono": "accludere",
    "acclusa": "accluso",
    "accluse": "accluso",
    "accluser": "accludere",
    "acclusero": "accludere",
    "acclusi": "accluso",
    "accluso": "accludere",
    "accoccola": "accoccolare",
    "accoccolai": "accoccolare",
    "accoccolammo": "accoccolare",
    "accoccolan": "accoccolare",
    "accoccolando": "accoccolare",
    "accoccolano": "accoccolare",
    "accoccolar": "accoccolare",
    "accoccolaron": "accoccolare",
    "accoccolarono": "accoccolare",
    "accoccolasse": "accoccolare",
    "accoccolasser": "accoccolare",
    "accoccolassero": "accoccolare",
    "accoccolassi": "accoccolare",
    "accoccolassimo": "accoccolare",
    "accoccolaste": "accoccolare",
    "accoccolasti": "accoccolare",
    "accoccolata": "accoccolare",
    "accoccolate": "accoccolare",
    "accoccolati": "accoccolare",
    "accoccolato": "accoccolare",
    "accoccolava": "accoccolare",
    "accoccolavamo": "accoccolare",
    "accoccolavan": "accoccolare",
    "accoccolavano": "accoccolare",
    "accoccolavate": "accoccolare",
    "accoccolavi": "accoccolare",
    "accoccolavo": "accoccolare",
    "accoccolerai": "accoccolare",
    "accoccoleran": "accoccolare",
    "accoccoleranno": "accoccolare",
    "accoccolerebbe": "accoccolare",
    "accoccolerebber": "accoccolare",
    "accoccolerebbero": "accoccolare",
    "accoccolerei": "accoccolare",
    "accoccoleremmo": "accoccolare",
    "accoccoleremo": "accoccolare",
    "accoccolereste": "accoccolare",
    "accoccoleresti": "accoccolare",
    "accoccolerete": "accoccolare",
    "accoccolerà": "accoccolare",
    "accoccolerò": "accoccolare",
    "accoccoli": "accoccolare",
    "accoccoliamo": "accoccolare",
    "accoccoliate": "accoccolare",
    "accoccolin": "accoccolare",
    "accoccolino": "accoccolare",
    "accoccolo": "accoccolare",
    "accoccolò": "accoccolare",
    "accoda": "accodare",
    "accodai": "accodare",
    "accodammo": "accodare",
    "accodan": "accodare",
    "accodando": "accodare",
    "accodano": "accodare",
    "accodante": "accodare",
    "accodanti": "accodare",
    "accodar": "accodare",
    "accodaron": "accodare",
    "accodarono": "accodare",
    "accodasse": "accodare",
    "accodasser": "accodare",
    "accodassero": "accodare",
    "accodassi": "accodare",
    "accodassimo": "accodare",
    "accodaste": "accodare",
    "accodasti": "accodare",
    "accodata": "accodare",
    "accodate": "accodare",
    "accodati": "accodare",
    "accodato": "accodare",
    "accodava": "accodare",
    "accodavamo": "accodare",
    "accodavan": "accodare",
    "accodavano": "accodare",
    "accodavate": "accodare",
    "accodavi": "accodare",
    "accodavo": "accodare",
    "accoderai": "accodare",
    "accoderan": "accodare",
    "accoderanno": "accodare",
    "accoderebbe": "accodare",
    "accoderebber": "accodare",
    "accoderebbero": "accodare",
    "accoderei": "accodare",
    "accoderemmo": "accodare",
    "accoderemo": "accodare",
    "accodereste": "accodare",
    "accoderesti": "accodare",
    "accoderete": "accodare",
    "accoderà": "accodare",
    "accoderò": "accodare",
    "accodi": "accodare",
    "accodiamo": "accodare",
    "accodiate": "accodare",
    "accodin": "accodare",
    "accodino": "accodare",
    "accodo": "accodare",
    "accodò": "accodare",
    "accogli": "accogliere",
    "accogliamo": "accogliere",
    "accogliate": "accogliere",
    "accoglibili": "accoglibile",
    "accoglie": "accogliere",
    "accogliemmo": "accogliere",
    "accogliendo": "accogliere",
    "accogliente": "accogliere",
    "accoglienti": "accogliere",
    "accoglienze": "accoglienza",
    "accoglier": "accogliere",
    "accoglierai": "accogliere",
    "accoglieran": "accogliere",
    "accoglieranno": "accogliere",
    "accoglierebbe": "accogliere",
    "accoglierebber": "accogliere",
    "accoglierebbero": "accogliere",
    "accoglierei": "accogliere",
    "accoglieremmo": "accogliere",
    "accoglieremo": "accogliere",
    "accogliereste": "accogliere",
    "accoglieresti": "accogliere",
    "accoglierete": "accogliere",
    "accoglierà": "accogliere",
    "accoglierò": "accogliere",
    "accogliesse": "accogliere",
    "accogliesser": "accogliere",
    "accogliessero": "accogliere",
    "accogliessi": "accogliere",
    "accogliessimo": "accogliere",
    "accoglieste": "accogliere",
    "accogliesti": "accogliere",
    "accogliete": "accogliere",
    "accoglieva": "accogliere",
    "accoglievamo": "accogliere",
    "accoglievan": "accogliere",
    "accoglievano": "accogliere",
    "accoglievate": "accogliere",
    "accoglievi": "accogliere",
    "accoglievo": "accogliere",
    "accoglimenti": "accoglimento",
    "accolga": "accogliere",
    "accolgan": "accogliere",
    "accolgano": "accogliere",
    "accolgo": "accogliere",
    "accolgon": "accogliere",
    "accolgono": "accogliere",
    "accoliti": "accolito",
    "accolla": "accollare",
    "accollai": "accollare",
    "accollammo": "accollare",
    "accollan": "accollare",
    "accollando": "accollare",
    "accollano": "accollare",
    "accollante": "accollare",
    "accollanti": "accollare",
    "accollar": "accollare",
    "accollaron": "accollare",
    "accollarono": "accollare",
    "accollasse": "accollare",
    "accollasser": "accollare",
    "accollassero": "accollare",
    "accollassi": "accollare",
    "accollassimo": "accollare",
    "accollaste": "accollare",
    "accollasti": "accollare",
    "accollata": "accollato",
    "accollate": "accollato",
    "accollati": "accollato",
    "accollato": "accollare",
    "accollava": "accollare",
    "accollavamo": "accollare",
    "accollavan": "accollare",
    "accollavano": "accollare",
    "accollavate": "accollare",
    "accollavi": "accollare",
    "accollavo": "accollare",
    "accollerai": "accollare",
    "accolleran": "accollare",
    "accolleranno": "accollare",
    "accollerebbe": "accollare",
    "accollerebber": "accollare",
    "accollerebbero": "accollare",
    "accollerei": "accollare",
    "accolleremmo": "accollare",
    "accolleremo": "accollare",
    "accollereste": "accollare",
    "accolleresti": "accollare",
    "accollerete": "accollare",
    "accollerà": "accollare",
    "accollerò": "accollare",
    "accolli": "accollare",
    "accolliamo": "accollare",
    "accolliate": "accollare",
    "accollin": "accollare",
    "accollino": "accollare",
    "accollo": "accollare",
    "accollò": "accollare",
    "accolse": "accogliere",
    "accolser": "accogliere",
    "accolsero": "accogliere",
    "accolsi": "accogliere",
    "accolta": "accogliere",
    "accolte": "accogliere",
    "accoltella": "accoltellare",
    "accoltellai": "accoltellare",
    "accoltellamenti": "accoltellamento",
    "accoltellammo": "accoltellare",
    "accoltellan": "accoltellare",
    "accoltellando": "accoltellare",
    "accoltellano": "accoltellare",
    "accoltellante": "accoltellare",
    "accoltellanti": "accoltellare",
    "accoltellar": "accoltellare",
    "accoltellaron": "accoltellare",
    "accoltellarono": "accoltellare",
    "accoltellasse": "accoltellare",
    "accoltellasser": "accoltellare",
    "accoltellassero": "accoltellare",
    "accoltellassi": "accoltellare",
    "accoltellassimo": "accoltellare",
    "accoltellaste": "accoltellare",
    "accoltellasti": "accoltellare",
    "accoltellata": "accoltellare",
    "accoltellate": "accoltellare",
    "accoltellati": "accoltellare",
    "accoltellato": "accoltellare",
    "accoltellatori": "accoltellatore",
    "accoltellava": "accoltellare",
    "accoltellavamo": "accoltellare",
    "accoltellavan": "accoltellare",
    "accoltellavano": "accoltellare",
    "accoltellavate": "accoltellare",
    "accoltellavi": "accoltellare",
    "accoltellavo": "accoltellare",
    "accoltellerai": "accoltellare",
    "accoltelleran": "accoltellare",
    "accoltelleranno": "accoltellare",
    "accoltellerebbe": "accoltellare",
    "accoltellerebber": "accoltellare",
    "accoltellerebbero": "accoltellare",
    "accoltellerei": "accoltellare",
    "accoltelleremmo": "accoltellare",
    "accoltelleremo": "accoltellare",
    "accoltellereste": "accoltellare",
    "accoltelleresti": "accoltellare",
    "accoltellerete": "accoltellare",
    "accoltellerà": "accoltellare",
    "accoltellerò": "accoltellare",
    "accoltelli": "accoltellare",
    "accoltelliamo": "accoltellare",
    "accoltelliate": "accoltellare",
    "accoltellin": "accoltellare",
    "accoltellino": "accoltellare",
    "accoltello": "accoltellare",
    "accoltellò": "accoltellare",
    "accolti": "accogliere",
    "accolto": "accogliere",
    "accomanda": "accomandare",
    "accomandai": "accomandare",
    "accomandammo": "accomandare",
    "accomandan": "accomandare",
    "accomandando": "accomandare",
    "accomandano": "accomandare",
    "accomandante": "accomandare",
    "accomandanti": "accomandare",
    "accomandar": "accomandare",
    "accomandaron": "accomandare",
    "accomandarono": "accomandare",
    "accomandasse": "accomandare",
    "accomandasser": "accomandare",
    "accomandassero": "accomandare",
    "accomandassi": "accomandare",
    "accomandassimo": "accomandare",
    "accomandaste": "accomandare",
    "accomandasti": "accomandare",
    "accomandata": "accomandare",
    "accomandate": "accomandare",
    "accomandati": "accomandare",
    "accomandato": "accomandare",
    "accomandava": "accomandare",
    "accomandavamo": "accomandare",
    "accomandavan": "accomandare",
    "accomandavano": "accomandare",
    "accomandavate": "accomandare",
    "accomandavi": "accomandare",
    "accomandavo": "accomandare",
    "accomanderai": "accomandare",
    "accomanderan": "accomandare",
    "accomanderanno": "accomandare",
    "accomanderebbe": "accomandare",
    "accomanderebber": "accomandare",
    "accomanderebbero": "accomandare",
    "accomanderei": "accomandare",
    "accomanderemmo": "accomandare",
    "accomanderemo": "accomandare",
    "accomandereste": "accomandare",
    "accomanderesti": "accomandare",
    "accomanderete": "accomandare",
    "accomanderà": "accomandare",
    "accomanderò": "accomandare",
    "accomandi": "accomandare",
    "accomandiamo": "accomandare",
    "accomandiate": "accomandare",
    "accomandin": "accomandare",
    "accomandino": "accomandare",
    "accomando": "accomandare",
    "accomandò": "accomandare",
    "accomiata": "accomiatare",
    "accomiatai": "accomiatare",
    "accomiatammo": "accomiatare",
    "accomiatan": "accomiatare",
    "accomiatando": "accomiatare",
    "accomiatano": "accomiatare",
    "accomiatante": "accomiatare",
    "accomiatanti": "accomiatare",
    "accomiatar": "accomiatare",
    "accomiataron": "accomiatare",
    "accomiatarono": "accomiatare",
    "accomiatasse": "accomiatare",
    "accomiatasser": "accomiatare",
    "accomiatassero": "accomiatare",
    "accomiatassi": "accomiatare",
    "accomiatassimo": "accomiatare",
    "accomiataste": "accomiatare",
    "accomiatasti": "accomiatare",
    "accomiatata": "accomiatare",
    "accomiatate": "accomiatare",
    "accomiatati": "accomiatare",
    "accomiatato": "accomiatare",
    "accomiatava": "accomiatare",
    "accomiatavamo": "accomiatare",
    "accomiatavan": "accomiatare",
    "accomiatavano": "accomiatare",
    "accomiatavate": "accomiatare",
    "accomiatavi": "accomiatare",
    "accomiatavo": "accomiatare",
    "accomiaterai": "accomiatare",
    "accomiateran": "accomiatare",
    "accomiateranno": "accomiatare",
    "accomiaterebbe": "accomiatare",
    "accomiaterebber": "accomiatare",
    "accomiaterebbero": "accomiatare",
    "accomiaterei": "accomiatare",
    "accomiateremmo": "accomiatare",
    "accomiateremo": "accomiatare",
    "accomiatereste": "accomiatare",
    "accomiateresti": "accomiatare",
    "accomiaterete": "accomiatare",
    "accomiaterà": "accomiatare",
    "accomiaterò": "accomiatare",
    "accomiati": "accomiatare",
    "accomiatiamo": "accomiatare",
    "accomiatiate": "accomiatare",
    "accomiatin": "accomiatare",
    "accomiatino": "accomiatare",
    "accomiato": "accomiatare",
    "accomiatò": "accomiatare",
    "accomoda": "accomodare",
    "accomodai": "accomodare",
    "accomodamenti": "accomodamento",
    "accomodammo": "accomodare",
    "accomodan": "accomodare",
    "accomodando": "accomodare",
    "accomodano": "accomodare",
    "accomodante": "accomodare",
    "accomodanti": "accomodare",
    "accomodar": "accomodare",
    "accomodaron": "accomodare",
    "accomodarono": "accomodare",
    "accomodasse": "accomodare",
    "accomodasser": "accomodare",
    "accomodassero": "accomodare",
    "accomodassi": "accomodare",
    "accomodassimo": "accomodare",
    "accomodaste": "accomodare",
    "accomodasti": "accomodare",
    "accomodata": "accomodare",
    "accomodate": "accomodare",
    "accomodati": "accomodare",
    "accomodato": "accomodare",
    "accomodava": "accomodare",
    "accomodavamo": "accomodare",
    "accomodavan": "accomodare",
    "accomodavano": "accomodare",
    "accomodavate": "accomodare",
    "accomodavi": "accomodare",
    "accomodavo": "accomodare",
    "accomoderai": "accomodare",
    "accomoderan": "accomodare",
    "accomoderanno": "accomodare",
    "accomoderebbe": "accomodare",
    "accomoderebber": "accomodare",
    "accomoderebbero": "accomodare",
    "accomoderei": "accomodare",
    "accomoderemmo": "accomodare",
    "accomoderemo": "accomodare",
    "accomodereste": "accomodare",
    "accomoderesti": "accomodare",
    "accomoderete": "accomodare",
    "accomoderà": "accomodare",
    "accomoderò": "accomodare",
    "accomodi": "accomodare",
    "accomodiamo": "accomodare",
    "accomodiate": "accomodare",
    "accomodin": "accomodare",
    "accomodino": "accomodare",
    "accomodo": "accomodare",
    "accomodò": "accomodare",
    "accompagna": "accompagnare",
    "accompagnai": "accompagnare",
    "accompagnamenti": "accompagnamento",
    "accompagnammo": "accompagnare",
    "accompagnan": "accompagnare",
    "accompagnando": "accompagnare",
    "accompagnano": "accompagnare",
    "accompagnante": "accompagnare",
    "accompagnanti": "accompagnare",
    "accompagnar": "accompagnare",
    "accompagnaron": "accompagnare",
    "accompagnarono": "accompagnare",
    "accompagnasse": "accompagnare",
    "accompagnasser": "accompagnare",
    "accompagnassero": "accompagnare",
    "accompagnassi": "accompagnare",
    "accompagnassimo": "accompagnare",
    "accompagnaste": "accompagnare",
    "accompagnasti": "accompagnare",
    "accompagnata": "accompagnare",
    "accompagnate": "accompagnare",
    "accompagnati": "accompagnare",
    "accompagnato": "accompagnare",
    "accompagnatori": "accompagnatore",
    "accompagnatrici": "accompagnatrice",
    "accompagnava": "accompagnare",
    "accompagnavamo": "accompagnare",
    "accompagnavan": "accompagnare",
    "accompagnavano": "accompagnare",
    "accompagnavate": "accompagnare",
    "accompagnavi": "accompagnare",
    "accompagnavo": "accompagnare",
    "accompagnerai": "accompagnare",
    "accompagneran": "accompagnare",
    "accompagneranno": "accompagnare",
    "accompagnerebbe": "accompagnare",
    "accompagnerebber": "accompagnare",
    "accompagnerebbero": "accompagnare",
    "accompagnerei": "accompagnare",
    "accompagneremmo": "accompagnare",
    "accompagneremo": "accompagnare",
    "accompagnereste": "accompagnare",
    "accompagneresti": "accompagnare",
    "accompagnerete": "accompagnare",
    "accompagnerà": "accompagnare",
    "accompagnerò": "accompagnare",
    "accompagni": "accompagnare",
    "accompagniamo": "accompagnare",
    "accompagniate": "accompagnare",
    "accompagnin": "accompagnare",
    "accompagnino": "accompagnare",
    "accompagno": "accompagnare",
    "accompagnò": "accompagnare",
    "accomuna": "accomunare",
    "accomunai": "accomunare",
    "accomunammo": "accomunare",
    "accomunan": "accomunare",
    "accomunando": "accomunare",
    "accomunano": "accomunare",
    "accomunante": "accomunare",
    "accomunanti": "accomunare",
    "accomunar": "accomunare",
    "accomunaron": "accomunare",
    "accomunarono": "accomunare",
    "accomunasse": "accomunare",
    "accomunasser": "accomunare",
    "accomunassero": "accomunare",
    "accomunassi": "accomunare",
    "accomunassimo": "accomunare",
    "accomunaste": "accomunare",
    "accomunasti": "accomunare",
    "accomunata": "accomunare",
    "accomunate": "accomunare",
    "accomunati": "accomunare",
    "accomunato": "accomunare",
    "accomunava": "accomunare",
    "accomunavamo": "accomunare",
    "accomunavan": "accomunare",
    "accomunavano": "accomunare",
    "accomunavate": "accomunare",
    "accomunavi": "accomunare",
    "accomunavo": "accomunare",
    "accomunerai": "accomunare",
    "accomuneran": "accomunare",
    "accomuneranno": "accomunare",
    "accomunerebbe": "accomunare",
    "accomunerebber": "accomunare",
    "accomunerebbero": "accomunare",
    "accomunerei": "accomunare",
    "accomuneremmo": "accomunare",
    "accomuneremo": "accomunare",
    "accomunereste": "accomunare",
    "accomuneresti": "accomunare",
    "accomunerete": "accomunare",
    "accomunerà": "accomunare",
    "accomunerò": "accomunare",
    "accomuni": "accomunare",
    "accomuniamo": "accomunare",
    "accomuniate": "accomunare",
    "accomunin": "accomunare",
    "accomunino": "accomunare",
    "accomuno": "accomunare",
    "accomunò": "accomunare",
    "acconce": "acconcio",
    "acconcerai": "acconciare",
    "acconceran": "acconciare",
    "acconceranno": "acconciare",
    "acconcerebbe": "acconciare",
    "acconcerebber": "acconciare",
    "acconcerebbero": "acconciare",
    "acconcerei": "acconciare",
    "acconceremmo": "acconciare",
    "acconceremo": "acconciare",
    "acconcereste": "acconciare",
    "acconceresti": "acconciare",
    "acconcerete": "acconciare",
    "acconcerà": "acconciare",
    "acconcerò": "acconciare",
    "acconci": "acconcio",
    "acconcia": "acconcio",
    "acconciai": "acconciare",
    "acconciammo": "acconciare",
    "acconciamo": "acconciare",
    "acconcian": "acconciare",
    "acconciando": "acconciare",
    "acconciano": "acconciare",
    "acconciante": "acconciare",
    "acconcianti": "acconciare",
    "acconciar": "acconciare",
    "acconciaron": "acconciare",
    "acconciarono": "acconciare",
    "acconciasse": "acconciare",
    "acconciasser": "acconciare",
    "acconciassero": "acconciare",
    "acconciassi": "acconciare",
    "acconciassimo": "acconciare",
    "acconciaste": "acconciare",
    "acconciasti": "acconciare",
    "acconciata": "acconciare",
    "acconciate": "acconciare",
    "acconciati": "acconciare",
    "acconciato": "acconciare",
    "acconciature": "acconciatura",
    "acconciava": "acconciare",
    "acconciavamo": "acconciare",
    "acconciavan": "acconciare",
    "acconciavano": "acconciare",
    "acconciavate": "acconciare",
    "acconciavi": "acconciare",
    "acconciavo": "acconciare",
    "acconcin": "acconciare",
    "acconcino": "acconciare",
    "acconcio": "acconciare",
    "acconciò": "acconciare",
    "accondiscenda": "accondiscendere",
    "accondiscendan": "accondiscendere",
    "accondiscendano": "accondiscendere",
    "accondiscende": "accondiscendere",
    "accondiscendemmo": "accondiscendere",
    "accondiscendendo": "accondiscendere",
    "accondiscendente": "accondiscendere",
    "accondiscendenti": "accondiscendere",
    "accondiscendenze": "accondiscendenza",
    "accondiscender": "accondiscendere",
    "accondiscenderai": "accondiscendere",
    "accondiscenderan": "accondiscendere",
    "accondiscenderanno": "accondiscendere",
    "accondiscenderebbe": "accondiscendere",
    "accondiscenderebber": "accondiscendere",
    "accondiscenderebbero": "accondiscendere",
    "accondiscenderei": "accondiscendere",
    "accondiscenderemmo": "accondiscendere",
    "accondiscenderemo": "accondiscendere",
    "accondiscendereste": "accondiscendere",
    "accondiscenderesti": "accondiscendere",
    "accondiscenderete": "accondiscendere",
    "accondiscenderà": "accondiscendere",
    "accondiscenderò": "accondiscendere",
    "accondiscendesse": "accondiscendere",
    "accondiscendesser": "accondiscendere",
    "accondiscendessero": "accondiscendere",
    "accondiscendessi": "accondiscendere",
    "accondiscendessimo": "accondiscendere",
    "accondiscendeste": "accondiscendere",
    "accondiscendesti": "accondiscendere",
    "accondiscendete": "accondiscendere",
    "accondiscendeva": "accondiscendere",
    "accondiscendevamo": "accondiscendere",
    "accondiscendevan": "accondiscendere",
    "accondiscendevano": "accondiscendere",
    "accondiscendevate": "accondiscendere",
    "accondiscendevi": "accondiscendere",
    "accondiscendevo": "accondiscendere",
    "accondiscendi": "accondiscendere",
    "accondiscendiamo": "accondiscendere",
    "accondiscendiate": "accondiscendere",
    "accondiscendo": "accondiscendere",
    "accondiscendon": "accondiscendere",
    "accondiscendono": "accondiscendere",
    "accondiscesa": "accondiscendere",
    "accondiscese": "accondiscendere",
    "accondisceser": "accondiscendere",
    "accondiscesero": "accondiscendere",
    "accondiscesi": "accondiscendere",
    "accondisceso": "accondiscendere",
    "accondiscesè": "accondiscendere",
    "acconsenta": "acconsentire",
    "acconsentan": "acconsentire",
    "acconsentano": "acconsentire",
    "acconsente": "acconsentire",
    "acconsentendo": "acconsentire",
    "acconsenti": "acconsentire",
    "acconsentiamo": "acconsentire",
    "acconsentiate": "acconsentire",
    "acconsentii": "acconsentire",
    "acconsentimmo": "acconsentire",
    "acconsentir": "acconsentire",
    "acconsentirai": "acconsentire",
    "acconsentiran": "acconsentire",
    "acconsentiranno": "acconsentire",
    "acconsentirebbe": "acconsentire",
    "acconsentirebber": "acconsentire",
    "acconsentirebbero": "acconsentire",
    "acconsentirei": "acconsentire",
    "acconsentiremmo": "acconsentire",
    "acconsentiremo": "acconsentire",
    "acconsentireste": "acconsentire",
    "acconsentiresti": "acconsentire",
    "acconsentirete": "acconsentire",
    "acconsentiron": "acconsentire",
    "acconsentirono": "acconsentire",
    "acconsentirà": "acconsentire",
    "acconsentirò": "acconsentire",
    "acconsentisse": "acconsentire",
    "acconsentisser": "acconsentire",
    "acconsentissero": "acconsentire",
    "acconsentissi": "acconsentire",
    "acconsentissimo": "acconsentire",
    "acconsentiste": "acconsentire",
    "acconsentisti": "acconsentire",
    "acconsentita": "acconsentire",
    "acconsentite": "acconsentire",
    "acconsentiti": "acconsentire",
    "acconsentito": "acconsentire",
    "acconsentiva": "acconsentire",
    "acconsentivamo": "acconsentire",
    "acconsentivan": "acconsentire",
    "acconsentivano": "acconsentire",
    "acconsentivate": "acconsentire",
    "acconsentivi": "acconsentire",
    "acconsentivo": "acconsentire",
    "acconsento": "acconsentire",
    "acconsenton": "acconsentire",
    "acconsentono": "acconsentire",
    "acconsentì": "acconsentire",
    "acconsenziente": "acconsentire",
    "acconsenzienti": "acconsentire",
    "accontenta": "accontentare",
    "accontentai": "accontentare",
    "accontentammo": "accontentare",
    "accontentan": "accontentare",
    "accontentando": "accontentare",
    "accontentano": "accontentare",
    "accontentante": "accontentare",
    "accontentanti": "accontentare",
    "accontentar": "accontentare",
    "accontentaron": "accontentare",
    "accontentarono": "accontentare",
    "accontentasse": "accontentare",
    "accontentasser": "accontentare",
    "accontentassero": "accontentare",
    "accontentassi": "accontentare",
    "accontentassimo": "accontentare",
    "accontentaste": "accontentare",
    "accontentasti": "accontentare",
    "accontentata": "accontentare",
    "accontentate": "accontentare",
    "accontentati": "accontentare",
    "accontentato": "accontentare",
    "accontentava": "accontentare",
    "accontentavamo": "accontentare",
    "accontentavan": "accontentare",
    "accontentavano": "accontentare",
    "accontentavate": "accontentare",
    "accontentavi": "accontentare",
    "accontentavo": "accontentare",
    "accontenterai": "accontentare",
    "accontenteran": "accontentare",
    "accontenteranno": "accontentare",
    "accontenterebbe": "accontentare",
    "accontenterebber": "accontentare",
    "accontenterebbero": "accontentare",
    "accontenterei": "accontentare",
    "accontenteremmo": "accontentare",
    "accontenteremo": "accontentare",
    "accontentereste": "accontentare",
    "accontenteresti": "accontentare",
    "accontenterete": "accontentare",
    "accontenterà": "accontentare",
    "accontenterò": "accontentare",
    "accontenti": "accontentare",
    "accontentiamo": "accontentare",
    "accontentiate": "accontentare",
    "accontentin": "accontentare",
    "accontentino": "accontentare",
    "accontento": "accontentare",
    "accontentò": "accontentare",
    "acconti": "acconto",
    "accoppa": "accoppare",
    "accoppai": "accoppare",
    "accoppammo": "accoppare",
    "accoppan": "accoppare",
    "accoppando": "accoppare",
    "accoppano": "accoppare",
    "accoppante": "accoppare",
    "accoppanti": "accoppare",
    "accoppar": "accoppare",
    "accopparon": "accoppare",
    "accopparono": "accoppare",
    "accoppasse": "accoppare",
    "accoppasser": "accoppare",
    "accoppassero": "accoppare",
    "accoppassi": "accoppare",
    "accoppassimo": "accoppare",
    "accoppaste": "accoppare",
    "accoppasti": "accoppare",
    "accoppata": "accoppare",
    "accoppate": "accoppare",
    "accoppati": "accoppare",
    "accoppato": "accoppare",
    "accoppava": "accoppare",
    "accoppavamo": "accoppare",
    "accoppavan": "accoppare",
    "accoppavano": "accoppare",
    "accoppavate": "accoppare",
    "accoppavi": "accoppare",
    "accoppavo": "accoppare",
    "accopperai": "accoppare",
    "accopperan": "accoppare",
    "accopperanno": "accoppare",
    "accopperebbe": "accoppare",
    "accopperebber": "accoppare",
    "accopperebbero": "accoppare",
    "accopperei": "accoppare",
    "accopperemmo": "accoppare",
    "accopperemo": "accoppare",
    "accoppereste": "accoppare",
    "accopperesti": "accoppare",
    "accopperete": "accoppare",
    "accopperà": "accoppare",
    "accopperò": "accoppare",
    "accoppi": "accoppiare",
    "accoppia": "accoppiare",
    "accoppiai": "accoppiare",
    "accoppiamenti": "accoppiamento",
    "accoppiammo": "accoppiare",
    "accoppiamo": "accoppiare",
    "accoppian": "accoppiare",
    "accoppiando": "accoppiare",
    "accoppiano": "accoppiare",
    "accoppiante": "accoppiare",
    "accoppianti": "accoppiare",
    "accoppiar": "accoppiare",
    "accoppiaron": "accoppiare",
    "accoppiarono": "accoppiare",
    "accoppiasse": "accoppiare",
    "accoppiasser": "accoppiare",
    "accoppiassero": "accoppiare",
    "accoppiassi": "accoppiare",
    "accoppiassimo": "accoppiare",
    "accoppiaste": "accoppiare",
    "accoppiasti": "accoppiare",
    "accoppiata": "accoppiare",
    "accoppiate": "accoppiata",
    "accoppiati": "accoppiare",
    "accoppiato": "accoppiare",
    "accoppiava": "accoppiare",
    "accoppiavamo": "accoppiare",
    "accoppiavan": "accoppiare",
    "accoppiavano": "accoppiare",
    "accoppiavate": "accoppiare",
    "accoppiavi": "accoppiare",
    "accoppiavo": "accoppiare",
    "accoppierai": "accoppiare",
    "accoppieran": "accoppiare",
    "accoppieranno": "accoppiare",
    "accoppierebbe": "accoppiare",
    "accoppierebber": "accoppiare",
    "accoppierebbero": "accoppiare",
    "accoppierei": "accoppiare",
    "accoppieremmo": "accoppiare",
    "accoppieremo": "accoppiare",
    "accoppiereste": "accoppiare",
    "accoppieresti": "accoppiare",
    "accoppierete": "accoppiare",
    "accoppierà": "accoppiare",
    "accoppierò": "accoppiare",
    "accoppin": "accoppiare",
    "accoppino": "accoppiare",
    "accoppio": "accoppiare",
    "accoppiò": "accoppiare",
    "accoppo": "accoppare",
    "accoppò": "accoppare",
    "accora": "accorare",
    "accorai": "accorare",
    "accorammo": "accorare",
    "accoran": "accorare",
    "accorando": "accorare",
    "accorano": "accorare",
    "accorante": "accorare",
    "accoranti": "accorare",
    "accorar": "accorare",
    "accoraron": "accorare",
    "accorarono": "accorare",
    "accorasse": "accorare",
    "accorasser": "accorare",
    "accorassero": "accorare",
    "accorassi": "accorare",
    "accorassimo": "accorare",
    "accoraste": "accorare",
    "accorasti": "accorare",
    "accorata": "accorato",
    "accorate": "accorato",
    "accorati": "accorato",
    "accorato": "accorare",
    "accorava": "accorare",
    "accoravamo": "accorare",
    "accoravan": "accorare",
    "accoravano": "accorare",
    "accoravate": "accorare",
    "accoravi": "accorare",
    "accoravo": "accorare",
    "accorcerai": "accorciare",
    "accorceran": "accorciare",
    "accorceranno": "accorciare",
    "accorcerebbe": "accorciare",
    "accorcerebber": "accorciare",
    "accorcerebbero": "accorciare",
    "accorcerei": "accorciare",
    "accorceremmo": "accorciare",
    "accorceremo": "accorciare",
    "accorcereste": "accorciare",
    "accorceresti": "accorciare",
    "accorcerete": "accorciare",
    "accorcerà": "accorciare",
    "accorcerò": "accorciare",
    "accorci": "accorciare",
    "accorcia": "accorciare",
    "accorciai": "accorciare",
    "accorciamenti": "accorciamento",
    "accorciammo": "accorciare",
    "accorciamo": "accorciare",
    "accorcian": "accorciare",
    "accorciando": "accorciare",
    "accorciano": "accorciare",
    "accorciante": "accorciare",
    "accorcianti": "accorciare",
    "accorciar": "accorciare",
    "accorciaron": "accorciare",
    "accorciarono": "accorciare",
    "accorciasse": "accorciare",
    "accorciasser": "accorciare",
    "accorciassero": "accorciare",
    "accorciassi": "accorciare",
    "accorciassimo": "accorciare",
    "accorciaste": "accorciare",
    "accorciasti": "accorciare",
    "accorciata": "accorciato",
    "accorciate": "accorciato",
    "accorciati": "accorciato",
    "accorciato": "accorciare",
    "accorciava": "accorciare",
    "accorciavamo": "accorciare",
    "accorciavan": "accorciare",
    "accorciavano": "accorciare",
    "accorciavate": "accorciare",
    "accorciavi": "accorciare",
    "accorciavo": "accorciare",
    "accorcin": "accorciare",
    "accorcino": "accorciare",
    "accorcio": "accorciare",
    "accorciò": "accorciare",
    "accorda": "accordare",
    "accordai": "accordare",
    "accordammo": "accordare",
    "accordan": "accordare",
    "accordando": "accordare",
    "accordano": "accordare",
    "accordante": "accordare",
    "accordanti": "accordare",
    "accordar": "accordare",
    "accordaron": "accordare",
    "accordarono": "accordare",
    "accordasse": "accordare",
    "accordasser": "accordare",
    "accordassero": "accordare",
    "accordassi": "accordare",
    "accordassimo": "accordare",
    "accordaste": "accordare",
    "accordasti": "accordare",
    "accordata": "accordato",
    "accordate": "accordato",
    "accordati": "accordato",
    "accordato": "accordare",
    "accordava": "accordare",
    "accordavamo": "accordare",
    "accordavan": "accordare",
    "accordavano": "accordare",
    "accordavate": "accordare",
    "accordavi": "accordare",
    "accordavo": "accordare",
    "accorderai": "accordare",
    "accorderan": "accordare",
    "accorderanno": "accordare",
    "accorderebbe": "accordare",
    "accorderebber": "accordare",
    "accorderebbero": "accordare",
    "accorderei": "accordare",
    "accorderemmo": "accordare",
    "accorderemo": "accordare",
    "accordereste": "accordare",
    "accorderesti": "accordare",
    "accorderete": "accordare",
    "accorderà": "accordare",
    "accorderò": "accordare",
    "accordi": "accordo",
    "accordiamo": "accordare",
    "accordiate": "accordare",
    "accordin": "accordare",
    "accordino": "accordare",
    "accordo": "accordare",
    "accordò": "accordare",
    "accorerai": "accorare",
    "accoreran": "accorare",
    "accoreranno": "accorare",
    "accorerebbe": "accorare",
    "accorerebber": "accorare",
    "accorerebbero": "accorare",
    "accorerei": "accorare",
    "accoreremmo": "accorare",
    "accoreremo": "accorare",
    "accorereste": "accorare",
    "accoreresti": "accorare",
    "accorerete": "accorare",
    "accorerà": "accorare",
    "accorerò": "accorare",
    "accorga": "accorgere",
    "accorgan": "accorgere",
    "accorgano": "accorgere",
    "accorge": "accorgere",
    "accorgemmo": "accorgere",
    "accorgendo": "accorgere",
    "accorger": "accorgere",
    "accorgerai": "accorgere",
    "accorgeran": "accorgere",
    "accorgeranno": "accorgere",
    "accorgerebbe": "accorgere",
    "accorgerebber": "accorgere",
    "accorgerebbero": "accorgere",
    "accorgerei": "accorgere",
    "accorgeremmo": "accorgere",
    "accorgeremo": "accorgere",
    "accorgereste": "accorgere",
    "accorgeresti": "accorgere",
    "accorgerete": "accorgere",
    "accorgerà": "accorgere",
    "accorgerò": "accorgere",
    "accorgesse": "accorgere",
    "accorgesser": "accorgere",
    "accorgessero": "accorgere",
    "accorgessi": "accorgere",
    "accorgessimo": "accorgere",
    "accorgeste": "accorgere",
    "accorgesti": "accorgere",
    "accorgete": "accorgere",
    "accorgeva": "accorgere",
    "accorgevamo": "accorgere",
    "accorgevan": "accorgere",
    "accorgevano": "accorgere",
    "accorgevate": "accorgere",
    "accorgevi": "accorgere",
    "accorgevo": "accorgere",
    "accorgi": "accorgere",
    "accorgiamo": "accorgere",
    "accorgiate": "accorgere",
    "accorgimenti": "accorgimento",
    "accorgo": "accorgere",
    "accorgon": "accorgere",
    "accorgono": "accorgere",
    "accori": "accorare",
    "accoriamo": "accorare",
    "accoriate": "accorare",
    "accorin": "accorare",
    "accorino": "accorare",
    "accoro": "accorare",
    "accorpa": "accorpare",
    "accorpai": "accorpare",
    "accorpamenti": "accorpamento",
    "accorpammo": "accorpare",
    "accorpan": "accorpare",
    "accorpando": "accorpare",
    "accorpano": "accorpare",
    "accorpante": "accorpare",
    "accorpanti": "accorpare",
    "accorpar": "accorpare",
    "accorparon": "accorpare",
    "accorparono": "accorpare",
    "accorpasse": "accorpare",
    "accorpasser": "accorpare",
    "accorpassero": "accorpare",
    "accorpassi": "accorpare",
    "accorpassimo": "accorpare",
    "accorpaste": "accorpare",
    "accorpasti": "accorpare",
    "accorpata": "accorpare",
    "accorpate": "accorpare",
    "accorpati": "accorpare",
    "accorpato": "accorpare",
    "accorpava": "accorpare",
    "accorpavamo": "accorpare",
    "accorpavan": "accorpare",
    "accorpavano": "accorpare",
    "accorpavate": "accorpare",
    "accorpavi": "accorpare",
    "accorpavo": "accorpare",
    "accorperai": "accorpare",
    "accorperan": "accorpare",
    "accorperanno": "accorpare",
    "accorperebbe": "accorpare",
    "accorperebber": "accorpare",
    "accorperebbero": "accorpare",
    "accorperei": "accorpare",
    "accorperemmo": "accorpare",
    "accorperemo": "accorpare",
    "accorpereste": "accorpare",
    "accorperesti": "accorpare",
    "accorperete": "accorpare",
    "accorperà": "accorpare",
    "accorperò": "accorpare",
    "accorpi": "accorpare",
    "accorpiamo": "accorpare",
    "accorpiate": "accorpare",
    "accorpin": "accorpare",
    "accorpino": "accorpare",
    "accorpo": "accorpare",
    "accorpò": "accorpare",
    "accorra": "accorrere",
    "accorran": "accorrere",
    "accorrano": "accorrere",
    "accorre": "accorrere",
    "accorremmo": "accorrere",
    "accorrendo": "accorrere",
    "accorrente": "accorrere",
    "accorrenti": "accorrere",
    "accorrer": "accorrere",
    "accorrerai": "accorrere",
    "accorreran": "accorrere",
    "accorreranno": "accorrere",
    "accorrerebbe": "accorrere",
    "accorrerebber": "accorrere",
    "accorrerebbero": "accorrere",
    "accorrerei": "accorrere",
    "accorreremmo": "accorrere",
    "accorreremo": "accorrere",
    "accorrereste": "accorrere",
    "accorreresti": "accorrere",
    "accorrerete": "accorrere",
    "accorrerà": "accorrere",
    "accorrerò": "accorrere",
    "accorresse": "accorrere",
    "accorresser": "accorrere",
    "accorressero": "accorrere",
    "accorressi": "accorrere",
    "accorressimo": "accorrere",
    "accorreste": "accorrere",
    "accorresti": "accorrere",
    "accorrete": "accorrere",
    "accorreva": "accorrere",
    "accorrevamo": "accorrere",
    "accorrevan": "accorrere",
    "accorrevano": "accorrere",
    "accorrevate": "accorrere",
    "accorrevi": "accorrere",
    "accorrevo": "accorrere",
    "accorri": "accorrere",
    "accorriamo": "accorrere",
    "accorriate": "accorrere",
    "accorro": "accorrere",
    "accorron": "accorrere",
    "accorrono": "accorrere",
    "accorsa": "accorso",
    "accorse": "accorso",
    "accorser": "accorrere",
    "accorsero": "accorrere",
    "accorsi": "accorso",
    "accorso": "accorrere",
    "accorta": "accorto",
    "accorte": "accorto",
    "accortezze": "accortezza",
    "accorti": "accorto",
    "accorto": "accorgere",
    "accorò": "accorare",
    "accoscerai": "accosciare",
    "accosceran": "accosciare",
    "accosceranno": "accosciare",
    "accoscerebbe": "accosciare",
    "accoscerebber": "accosciare",
    "accoscerebbero": "accosciare",
    "accoscerei": "accosciare",
    "accosceremmo": "accosciare",
    "accosceremo": "accosciare",
    "accoscereste": "accosciare",
    "accosceresti": "accosciare",
    "accoscerete": "accosciare",
    "accoscerà": "accosciare",
    "accoscerò": "accosciare",
    "accosci": "accosciare",
    "accoscia": "accosciare",
    "accosciai": "accosciare",
    "accosciammo": "accosciare",
    "accosciamo": "accosciare",
    "accoscian": "accosciare",
    "accosciando": "accosciare",
    "accosciano": "accosciare",
    "accosciar": "accosciare",
    "accosciaron": "accosciare",
    "accosciarono": "accosciare",
    "accosciasse": "accosciare",
    "accosciasser": "accosciare",
    "accosciassero": "accosciare",
    "accosciassi": "accosciare",
    "accosciassimo": "accosciare",
    "accosciaste": "accosciare",
    "accosciasti": "accosciare",
    "accosciata": "accosciare",
    "accosciate": "accosciare",
    "accosciati": "accosciare",
    "accosciato": "accosciare",
    "accosciava": "accosciare",
    "accosciavamo": "accosciare",
    "accosciavan": "accosciare",
    "accosciavano": "accosciare",
    "accosciavate": "accosciare",
    "accosciavi": "accosciare",
    "accosciavo": "accosciare",
    "accoscin": "accosciare",
    "accoscino": "accosciare",
    "accoscio": "accosciare",
    "accosciò": "accosciare",
    "accosta": "accostare",
    "accostabili": "accostabile",
    "accostai": "accostare",
    "accostamenti": "accostamento",
    "accostammo": "accostare",
    "accostan": "accostare",
    "accostando": "accostare",
    "accostano": "accostare",
    "accostante": "accostare",
    "accostanti": "accostare",
    "accostar": "accostare",
    "accostaron": "accostare",
    "accostarono": "accostare",
    "accostasse": "accostare",
    "accostasser": "accostare",
    "accostassero": "accostare",
    "accostassi": "accostare",
    "accostassimo": "accostare",
    "accostaste": "accostare",
    "accostasti": "accostare",
    "accostata": "accostare",
    "accostate": "accostare",
    "accostati": "accostare",
    "accostato": "accostare",
    "accostava": "accostare",
    "accostavamo": "accostare",
    "accostavan": "accostare",
    "accostavano": "accostare",
    "accostavate": "accostare",
    "accostavi": "accostare",
    "accostavo": "accostare",
    "accosterai": "accostare",
    "accosteran": "accostare",
    "accosteranno": "accostare",
    "accosterebbe": "accostare",
    "accosterebber": "accostare",
    "accosterebbero": "accostare",
    "accosterei": "accostare",
    "accosteremmo": "accostare",
    "accosteremo": "accostare",
    "accostereste": "accostare",
    "accosteresti": "accostare",
    "accosterete": "accostare",
    "accosterà": "accostare",
    "accosterò": "accostare",
    "accosti": "accostare",
    "accostiamo": "accostare",
    "accostiate": "accostare",
    "accostin": "accostare",
    "accostino": "accostare",
    "accosto": "accostare",
    "accostuma": "accostumare",
    "accostumai": "accostumare",
    "accostumammo": "accostumare",
    "accostuman": "accostumare",
    "accostumando": "accostumare",
    "accostumano": "accostumare",
    "accostumante": "accostumare",
    "accostumanti": "accostumare",
    "accostumar": "accostumare",
    "accostumaron": "accostumare",
    "accostumarono": "accostumare",
    "accostumasse": "accostumare",
    "accostumasser": "accostumare",
    "accostumassero": "accostumare",
    "accostumassi": "accostumare",
    "accostumassimo": "accostumare",
    "accostumaste": "accostumare",
    "accostumasti": "accostumare",
    "accostumata": "accostumare",
    "accostumate": "accostumare",
    "accostumati": "accostumare",
    "accostumato": "accostumare",
    "accostumava": "accostumare",
    "accostumavamo": "accostumare",
    "accostumavan": "accostumare",
    "accostumavano": "accostumare",
    "accostumavate": "accostumare",
    "accostumavi": "accostumare",
    "accostumavo": "accostumare",
    "accostumerai": "accostumare",
    "accostumeran": "accostumare",
    "accostumeranno": "accostumare",
    "accostumerebbe": "accostumare",
    "accostumerebber": "accostumare",
    "accostumerebbero": "accostumare",
    "accostumerei": "accostumare",
    "accostumeremmo": "accostumare",
    "accostumeremo": "accostumare",
    "accostumereste": "accostumare",
    "accostumeresti": "accostumare",
    "accostumerete": "accostumare",
    "accostumerà": "accostumare",
    "accostumerò": "accostumare",
    "accostumi": "accostumare",
    "accostumiamo": "accostumare",
    "accostumiate": "accostumare",
    "accostumin": "accostumare",
    "accostumino": "accostumare",
    "accostumo": "accostumare",
    "accostumò": "accostumare",
    "accostò": "accostare",
    "accovaccerai": "accovacciare",
    "accovacceran": "accovacciare",
    "accovacceranno": "accovacciare",
    "accovaccerebbe": "accovacciare",
    "accovaccerebber": "accovacciare",
    "accovaccerebbero": "accovacciare",
    "accovaccerei": "accovacciare",
    "accovacceremmo": "accovacciare",
    "accovacceremo": "accovacciare",
    "accovaccereste": "accovacciare",
    "accovacceresti": "accovacciare",
    "accovaccerete": "accovacciare",
    "accovaccerà": "accovacciare",
    "accovaccerò": "accovacciare",
    "accovacci": "accovacciare",
    "accovaccia": "accovacciare",
    "accovacciai": "accovacciare",
    "accovacciammo": "accovacciare",
    "accovacciamo": "accovacciare",
    "accovaccian": "accovacciare",
    "accovacciando": "accovacciare",
    "accovacciano": "accovacciare",
    "accovacciar": "accovacciare",
    "accovacciaron": "accovacciare",
    "accovacciarono": "accovacciare",
    "accovacciasse": "accovacciare",
    "accovacciasser": "accovacciare",
    "accovacciassero": "accovacciare",
    "accovacciassi": "accovacciare",
    "accovacciassimo": "accovacciare",
    "accovacciaste": "accovacciare",
    "accovacciasti": "accovacciare",
    "accovacciata": "accovacciare",
    "accovacciate": "accovacciare",
    "accovacciati": "accovacciare",
    "accovacciato": "accovacciare",
    "accovacciava": "accovacciare",
    "accovacciavamo": "accovacciare",
    "accovacciavan": "accovacciare",
    "accovacciavano": "accovacciare",
    "accovacciavate": "accovacciare",
    "accovacciavi": "accovacciare",
    "accovacciavo": "accovacciare",
    "accovaccin": "accovacciare",
    "accovaccino": "accovacciare",
    "accovaccio": "accovacciare",
    "accovacciò": "accovacciare",
    "accozza": "accozzare",
    "accozzaglie": "accozzaglia",
    "accozzai": "accozzare",
    "accozzammo": "accozzare",
    "accozzan": "accozzare",
    "accozzando": "accozzare",
    "accozzano": "accozzare",
    "accozzante": "accozzare",
    "accozzanti": "accozzare",
    "accozzar": "accozzare",
    "accozzaron": "accozzare",
    "accozzarono": "accozzare",
    "accozzasse": "accozzare",
    "accozzasser": "accozzare",
    "accozzassero": "accozzare",
    "accozzassi": "accozzare",
    "accozzassimo": "accozzare",
    "accozzaste": "accozzare",
    "accozzasti": "accozzare",
    "accozzata": "accozzare",
    "accozzate": "accozzare",
    "accozzati": "accozzare",
    "accozzato": "accozzare",
    "accozzava": "accozzare",
    "accozzavamo": "accozzare",
    "accozzavan": "accozzare",
    "accozzavano": "accozzare",
    "accozzavate": "accozzare",
    "accozzavi": "accozzare",
    "accozzavo": "accozzare",
    "accozzerai": "accozzare",
    "accozzeran": "accozzare",
    "accozzeranno": "accozzare",
    "accozzerebbe": "accozzare",
    "accozzerebber": "accozzare",
    "accozzerebbero": "accozzare",
    "accozzerei": "accozzare",
    "accozzeremmo": "accozzare",
    "accozzeremo": "accozzare",
    "accozzereste": "accozzare",
    "accozzeresti": "accozzare",
    "accozzerete": "accozzare",
    "accozzerà": "accozzare",
    "accozzerò": "accozzare",
    "accozzi": "accozzare",
    "accozziamo": "accozzare",
    "accozziate": "accozzare",
    "accozzin": "accozzare",
    "accozzino": "accozzare",
    "accozzo": "accozzare",
    "accozzò": "accozzare",
    "accrebbe": "accrescere",
    "accrebber": "accrescere",
    "accrebbero": "accrescere",
    "accredita": "accreditare",
    "accreditai": "accreditare",
    "accreditamenti": "accreditamento",
    "accreditammo": "accreditare",
    "accreditan": "accreditare",
    "accreditando": "accreditare",
    "accreditano": "accreditare",
    "accreditante": "accreditare",
    "accreditanti": "accreditare",
    "accreditar": "accreditare",
    "accreditaron": "accreditare",
    "accreditarono": "accreditare",
    "accreditasse": "accreditare",
    "accreditasser": "accreditare",
    "accreditassero": "accreditare",
    "accreditassi": "accreditare",
    "accreditassimo": "accreditare",
    "accreditaste": "accreditare",
    "accreditasti": "accreditare",
    "accreditata": "accreditato",
    "accreditate": "accreditato",
    "accreditati": "accreditato",
    "accreditato": "accreditare",
    "accreditava": "accreditare",
    "accreditavamo": "accreditare",
    "accreditavan": "accreditare",
    "accreditavano": "accreditare",
    "accreditavate": "accreditare",
    "accreditavi": "accreditare",
    "accreditavo": "accreditare",
    "accrediterai": "accreditare",
    "accrediteran": "accreditare",
    "accrediteranno": "accreditare",
    "accrediterebbe": "accreditare",
    "accrediterebber": "accreditare",
    "accrediterebbero": "accreditare",
    "accrediterei": "accreditare",
    "accrediteremmo": "accreditare",
    "accrediteremo": "accreditare",
    "accreditereste": "accreditare",
    "accrediteresti": "accreditare",
    "accrediterete": "accreditare",
    "accrediterà": "accreditare",
    "accrediterò": "accreditare",
    "accrediti": "accredito",
    "accreditiamo": "accreditare",
    "accreditiate": "accreditare",
    "accreditin": "accreditare",
    "accreditino": "accreditare",
    "accredito": "accreditare",
    "accreditò": "accreditare",
    "accresca": "accrescere",
    "accrescan": "accrescere",
    "accrescano": "accrescere",
    "accresce": "accrescere",
    "accrescei": "accrescere",
    "accrescemmo": "accrescere",
    "accrescendo": "accrescere",
    "accrescente": "accrescere",
    "accrescenti": "accrescere",
    "accrescer": "accrescere",
    "accrescerai": "accrescere",
    "accresceran": "accrescere",
    "accresceranno": "accrescere",
    "accrescerebbe": "accrescere",
    "accrescerebber": "accrescere",
    "accrescerebbero": "accrescere",
    "accrescerei": "accrescere",
    "accresceremmo": "accrescere",
    "accresceremo": "accrescere",
    "accrescereste": "accrescere",
    "accresceresti": "accrescere",
    "accrescerete": "accrescere",
    "accrescerà": "accrescere",
    "accrescerò": "accrescere",
    "accrescesse": "accrescere",
    "accrescesser": "accrescere",
    "accrescessero": "accrescere",
    "accrescessi": "accrescere",
    "accrescessimo": "accrescere",
    "accresceste": "accrescere",
    "accrescesti": "accrescere",
    "accrescete": "accrescere",
    "accresceva": "accrescere",
    "accrescevamo": "accrescere",
    "accrescevan": "accrescere",
    "accrescevano": "accrescere",
    "accrescevate": "accrescere",
    "accrescevi": "accrescere",
    "accrescevo": "accrescere",
    "accresci": "accrescere",
    "accresciamo": "accrescere",
    "accresciate": "accrescere",
    "accrescimenti": "accrescimento",
    "accrescitiva": "accrescitivo",
    "accrescitive": "accrescitivo",
    "accrescitivi": "accrescitivo",
    "accresciuta": "accrescere",
    "accresciute": "accrescere",
    "accresciuti": "accrescere",
    "accresciuto": "accrescere",
    "accresco": "accrescere",
    "accrescon": "accrescere",
    "accrescono": "accrescere",
    "accuccerai": "accucciare",
    "accucceran": "accucciare",
    "accucceranno": "accucciare",
    "accuccerebbe": "accucciare",
    "accuccerebber": "accucciare",
    "accuccerebbero": "accucciare",
    "accuccerei": "accucciare",
    "accucceremmo": "accucciare",
    "accucceremo": "accucciare",
    "accuccereste": "accucciare",
    "accucceresti": "accucciare",
    "accuccerete": "accucciare",
    "accuccerà": "accucciare",
    "accuccerò": "accucciare",
    "accucci": "accucciare",
    "accuccia": "accucciare",
    "accucciai": "accucciare",
    "accucciammo": "accucciare",
    "accucciamo": "accucciare",
    "accuccian": "accucciare",
    "accucciando": "accucciare",
    "accucciano": "accucciare",
    "accucciar": "accucciare",
    "accucciaron": "accucciare",
    "accucciarono": "accucciare",
    "accucciasse": "accucciare",
    "accucciasser": "accucciare",
    "accucciassero": "accucciare",
    "accucciassi": "accucciare",
    "accucciassimo": "accucciare",
    "accucciaste": "accucciare",
    "accucciasti": "accucciare",
    "accucciata": "accucciare",
    "accucciate": "accucciare",
    "accucciati": "accucciare",
    "accucciato": "accucciare",
    "accucciava": "accucciare",
    "accucciavamo": "accucciare",
    "accucciavan": "accucciare",
    "accucciavano": "accucciare",
    "accucciavate": "accucciare",
    "accucciavi": "accucciare",
    "accucciavo": "accucciare",
    "accuccin": "accucciare",
    "accuccino": "accucciare",
    "accuccio": "accucciare",
    "accucciò": "accucciare",
    "accudendo": "accudire",
    "accudente": "accudire",
    "accudenti": "accudire",
    "accudiamo": "accudire",
    "accudiate": "accudire",
    "accudii": "accudire",
    "accudimmo": "accudire",
    "accudir": "accudire",
    "accudirai": "accudire",
    "accudiran": "accudire",
    "accudiranno": "accudire",
    "accudirebbe": "accudire",
    "accudirebber": "accudire",
    "accudirebbero": "accudire",
    "accudirei": "accudire",
    "accudiremmo": "accudire",
    "accudiremo": "accudire",
    "accudireste": "accudire",
    "accudiresti": "accudire",
    "accudirete": "accudire",
    "accudiron": "accudire",
    "accudirono": "accudire",
    "accudirà": "accudire",
    "accudirò": "accudire",
    "accudisca": "accudire",
    "accudiscan": "accudire",
    "accudiscano": "accudire",
    "accudisce": "accudire",
    "accudisci": "accudire",
    "accudisco": "accudire",
    "accudiscon": "accudire",
    "accudiscono": "accudire",
    "accudisse": "accudire",
    "accudisser": "accudire",
    "accudissero": "accudire",
    "accudissi": "accudire",
    "accudissimo": "accudire",
    "accudiste": "accudire",
    "accudisti": "accudire",
    "accudita": "accudire",
    "accudite": "accudire",
    "accuditi": "accudire",
    "accudito": "accudire",
    "accudiva": "accudire",
    "accudivamo": "accudire",
    "accudivan": "accudire",
    "accudivano": "accudire",
    "accudivate": "accudire",
    "accudivi": "accudire",
    "accudivo": "accudire",
    "accudì": "accudire",
    "accula": "acculare",
    "acculai": "acculare",
    "acculammo": "acculare",
    "acculan": "acculare",
    "acculando": "acculare",
    "acculano": "acculare",
    "acculante": "acculare",
    "acculanti": "acculare",
    "accular": "acculare",
    "accularon": "acculare",
    "accularono": "acculare",
    "acculasse": "acculare",
    "acculasser": "acculare",
    "acculassero": "acculare",
    "acculassi": "acculare",
    "acculassimo": "acculare",
    "acculaste": "acculare",
    "acculasti": "acculare",
    "acculata": "acculare",
    "acculate": "acculare",
    "acculati": "acculare",
    "acculato": "acculare",
    "acculava": "acculare",
    "acculavamo": "acculare",
    "acculavan": "acculare",
    "acculavano": "acculare",
    "acculavate": "acculare",
    "acculavi": "acculare",
    "acculavo": "acculare",
    "acculerai": "acculare",
    "acculeran": "acculare",
    "acculeranno": "acculare",
    "acculerebbe": "acculare",
    "acculerebber": "acculare",
    "acculerebbero": "acculare",
    "acculerei": "acculare",
    "acculeremmo": "acculare",
    "acculeremo": "acculare",
    "acculereste": "acculare",
    "acculeresti": "acculare",
    "acculerete": "acculare",
    "acculerà": "acculare",
    "acculerò": "acculare",
    "acculi": "acculare",
    "acculiamo": "acculare",
    "acculiate": "acculare",
    "acculin": "acculare",
    "acculino": "acculare",
    "acculo": "acculare",
    "acculò": "acculare",
    "accumula": "accumulare",
    "accumulai": "accumulare",
    "accumulammo": "accumulare",
    "accumulan": "accumulare",
    "accumulando": "accumulare",
    "accumulano": "accumulare",
    "accumulante": "accumulare",
    "accumulanti": "accumulare",
    "accumular": "accumulare",
    "accumularon": "accumulare",
    "accumularono": "accumulare",
    "accumulasse": "accumulare",
    "accumulasser": "accumulare",
    "accumulassero": "accumulare",
    "accumulassi": "accumulare",
    "accumulassimo": "accumulare",
    "accumulaste": "accumulare",
    "accumulasti": "accumulare",
    "accumulata": "accumulare",
    "accumulate": "accumulare",
    "accumulati": "accumulare",
    "accumulato": "accumulare",
    "accumulatori": "accumulatore",
    "accumulava": "accumulare",
    "accumulavamo": "accumulare",
    "accumulavan": "accumulare",
    "accumulavano": "accumulare",
    "accumulavate": "accumulare",
    "accumulavi": "accumulare",
    "accumulavo": "accumulare",
    "accumulazioni": "accumulazione",
    "accumulerai": "accumulare",
    "accumuleran": "accumulare",
    "accumuleranno": "accumulare",
    "accumulerebbe": "accumulare",
    "accumulerebber": "accumulare",
    "accumulerebbero": "accumulare",
    "accumulerei": "accumulare",
    "accumuleremmo": "accumulare",
    "accumuleremo": "accumulare",
    "accumulereste": "accumulare",
    "accumuleresti": "accumulare",
    "accumulerete": "accumulare",
    "accumulerà": "accumulare",
    "accumulerò": "accumulare",
    "accumuli": "accumulo",
    "accumuliamo": "accumulare",
    "accumuliate": "accumulare",
    "accumulin": "accumulare",
    "accumulino": "accumulare",
    "accumulo": "accumulare",
    "accumulò": "accumulare",
    "accurata": "accurato",
    "accurate": "accurato",
    "accuratezze": "accuratezza",
    "accurati": "accurato",
    "accusa": "accusare",
    "accusai": "accusare",
    "accusammo": "accusare",
    "accusan": "accusare",
    "accusando": "accusare",
    "accusano": "accusare",
    "accusante": "accusare",
    "accusanti": "accusare",
    "accusar": "accusare",
    "accusaron": "accusare",
    "accusarono": "accusare",
    "accusasse": "accusare",
    "accusasser": "accusare",
    "accusassero": "accusare",
    "accusassi": "accusare",
    "accusassimo": "accusare",
    "accusaste": "accusare",
    "accusasti": "accusare",
    "accusata": "accusato",
    "accusate": "accusato",
    "accusati": "accusato",
    "accusato": "accusare",
    "accusatori": "accusatorio",
    "accusatoria": "accusatorio",
    "accusatorie": "accusatorio",
    "accusatrici": "accusatrice",
    "accusava": "accusare",
    "accusavamo": "accusare",
    "accusavan": "accusare",
    "accusavano": "accusare",
    "accusavate": "accusare",
    "accusavi": "accusare",
    "accusavo": "accusare",
    "accuse": "accusa",
    "accuserai": "accusare",
    "accuseran": "accusare",
    "accuseranno": "accusare",
    "accuserebbe": "accusare",
    "accuserebber": "accusare",
    "accuserebbero": "accusare",
    "accuserei": "accusare",
    "accuseremmo": "accusare",
    "accuseremo": "accusare",
    "accusereste": "accusare",
    "accuseresti": "accusare",
    "accuserete": "accusare",
    "accuserà": "accusare",
    "accuserò": "accusare",
    "accusi": "accusare",
    "accusiamo": "accusare",
    "accusiate": "accusare",
    "accusin": "accusare",
    "accusino": "accusare",
    "accuso": "accusare",
    "accusò": "accusare",
    "acefala": "acefalo",
    "acefale": "acefalo",
    "acefali": "acefalo",
    "acerba": "acerbo",
    "acerbe": "acerbo",
    "acerbi": "acerbo",
    "acerrima": "acerrimo",
    "acerrime": "acerrimo",
    "acerrimi": "acerrimo",
    "acetica": "acetico",
    "acetiche": "acetico",
    "acetici": "acetico",
    "acetosa": "acetoso",
    "acetose": "acetoso",
    "acetosi": "acetoso",
    "achmatoviana": "achmatoviano",
    "achmatoviane": "achmatoviano",
    "achmatoviani": "achmatoviano",
    "acida": "acido",
    "acide": "acido",
    "acidi": "acido",
    "acidifica": "acidificare",
    "acidificai": "acidificare",
    "acidificammo": "acidificare",
    "acidifican": "acidificare",
    "acidificando": "acidificare",
    "acidificano": "acidificare",
    "acidificante": "acidificare",
    "acidificanti": "acidificare",
    "acidificar": "acidificare",
    "acidificaron": "acidificare",
    "acidificarono": "acidificare",
    "acidificasse": "acidificare",
    "acidificasser": "acidificare",
    "acidificassero": "acidificare",
    "acidificassi": "acidificare",
    "acidificassimo": "acidificare",
    "acidificaste": "acidificare",
    "acidificasti": "acidificare",
    "acidificata": "acidificare",
    "acidificate": "acidificare",
    "acidificati": "acidificare",
    "acidificato": "acidificare",
    "acidificava": "acidificare",
    "acidificavamo": "acidificare",
    "acidificavan": "acidificare",
    "acidificavano": "acidificare",
    "acidificavate": "acidificare",
    "acidificavi": "acidificare",
    "acidificavo": "acidificare",
    "acidificherai": "acidificare",
    "acidificheran": "acidificare",
    "acidificheranno": "acidificare",
    "acidificherebbe": "acidificare",
    "acidificherebber": "acidificare",
    "acidificherebbero": "acidificare",
    "acidificherei": "acidificare",
    "acidificheremmo": "acidificare",
    "acidificheremo": "acidificare",
    "acidifichereste": "acidificare",
    "acidificheresti": "acidificare",
    "acidificherete": "acidificare",
    "acidificherà": "acidificare",
    "acidificherò": "acidificare",
    "acidifichi": "acidificare",
    "acidifichiamo": "acidificare",
    "acidifichiate": "acidificare",
    "acidifichin": "acidificare",
    "acidifichino": "acidificare",
    "acidifico": "acidificare",
    "acidificò": "acidificare",
    "acidula": "acidulo",
    "acidule": "acidulo",
    "aciduli": "acidulo",
    "acini": "acino",
    "ackhinxana": "ackhinxano",
    "ackhinxane": "ackhinxano",
    "ackhinxani": "ackhinxano",
    "acmi": "acme",
    "aconfessionali": "aconfessionale",
    "acquarelli": "acquarello",
    "acquari": "acquario",
    "acquartiera": "acquartierare",
    "acquartierai": "acquartierare",
    "acquartierammo": "acquartierare",
    "acquartieran": "acquartierare",
    "acquartierando": "acquartierare",
    "acquartierano": "acquartierare",
    "acquartierante": "acquartierare",
    "acquartieranti": "acquartierare",
    "acquartierar": "acquartierare",
    "acquartieraron": "acquartierare",
    "acquartierarono": "acquartierare",
    "acquartierasse": "acquartierare",
    "acquartierasser": "acquartierare",
    "acquartierassero": "acquartierare",
    "acquartierassi": "acquartierare",
    "acquartierassimo": "acquartierare",
    "acquartieraste": "acquartierare",
    "acquartierasti": "acquartierare",
    "acquartierata": "acquartierare",
    "acquartierate": "acquartierare",
    "acquartierati": "acquartierare",
    "acquartierato": "acquartierare",
    "acquartierava": "acquartierare",
    "acquartieravamo": "acquartierare",
    "acquartieravan": "acquartierare",
    "acquartieravano": "acquartierare",
    "acquartieravate": "acquartierare",
    "acquartieravi": "acquartierare",
    "acquartieravo": "acquartierare",
    "acquartiererai": "acquartierare",
    "acquartiereran": "acquartierare",
    "acquartiereranno": "acquartierare",
    "acquartiererebbe": "acquartierare",
    "acquartiererebber": "acquartierare",
    "acquartiererebbero": "acquartierare",
    "acquartiererei": "acquartierare",
    "acquartiereremmo": "acquartierare",
    "acquartiereremo": "acquartierare",
    "acquartierereste": "acquartierare",
    "acquartiereresti": "acquartierare",
    "acquartiererete": "acquartierare",
    "acquartiererà": "acquartierare",
    "acquartiererò": "acquartierare",
    "acquartieri": "acquartierare",
    "acquartieriamo": "acquartierare",
    "acquartieriate": "acquartierare",
    "acquartierin": "acquartierare",
    "acquartierino": "acquartierare",
    "acquartiero": "acquartierare",
    "acquartierò": "acquartierare",
    "acquatica": "acquatico",
    "acquatiche": "acquatico",
    "acquatici": "acquatico",
    "acquatta": "acquattare",
    "acquattai": "acquattare",
    "acquattammo": "acquattare",
    "acquattan": "acquattare",
    "acquattando": "acquattare",
    "acquattano": "acquattare",
    "acquattante": "acquattare",
    "acquattanti": "acquattare",
    "acquattar": "acquattare",
    "acquattaron": "acquattare",
    "acquattarono": "acquattare",
    "acquattasse": "acquattare",
    "acquattasser": "acquattare",
    "acquattassero": "acquattare",
    "acquattassi": "acquattare",
    "acquattassimo": "acquattare",
    "acquattaste": "acquattare",
    "acquattasti": "acquattare",
    "acquattata": "acquattare",
    "acquattate": "acquattare",
    "acquattati": "acquattare",
    "acquattato": "acquattare",
    "acquattava": "acquattare",
    "acquattavamo": "acquattare",
    "acquattavan": "acquattare",
    "acquattavano": "acquattare",
    "acquattavate": "acquattare",
    "acquattavi": "acquattare",
    "acquattavo": "acquattare",
    "acquatterai": "acquattare",
    "acquatteran": "acquattare",
    "acquatteranno": "acquattare",
    "acquatterebbe": "acquattare",
    "acquatterebber": "acquattare",
    "acquatterebbero": "acquattare",
    "acquatterei": "acquattare",
    "acquatteremmo": "acquattare",
    "acquatteremo": "acquattare",
    "acquattereste": "acquattare",
    "acquatteresti": "acquattare",
    "acquatterete": "acquattare",
    "acquatterà": "acquattare",
    "acquatterò": "acquattare",
    "acquatti": "acquattare",
    "acquattiamo": "acquattare",
    "acquattiate": "acquattare",
    "acquattin": "acquattare",
    "acquattino": "acquattare",
    "acquatto": "acquattare",
    "acquattò": "acquattare",
    "acquazzoni": "acquazzone",
    "acque": "acqua",
    "acquea": "acqueo",
    "acquedotti": "acquedotto",
    "acquedottistica": "acquedottistico",
    "acquedottistiche": "acquedottistico",
    "acquedottistici": "acquedottistico",
    "acquee": "acqueo",
    "acquei": "acqueo",
    "acquerella": "acquerellare",
    "acquerellai": "acquerellare",
    "acquerellammo": "acquerellare",
    "acquerellan": "acquerellare",
    "acquerellando": "acquerellare",
    "acquerellano": "acquerellare",
    "acquerellante": "acquerellare",
    "acquerellanti": "acquerellare",
    "acquerellar": "acquerellare",
    "acquerellaron": "acquerellare",
    "acquerellarono": "acquerellare",
    "acquerellasse": "acquerellare",
    "acquerellasser": "acquerellare",
    "acquerellassero": "acquerellare",
    "acquerellassi": "acquerellare",
    "acquerellassimo": "acquerellare",
    "acquerellaste": "acquerellare",
    "acquerellasti": "acquerellare",
    "acquerellata": "acquerellare",
    "acquerellate": "acquerellare",
    "acquerellati": "acquerellare",
    "acquerellato": "acquerellare",
    "acquerellava": "acquerellare",
    "acquerellavamo": "acquerellare",
    "acquerellavan": "acquerellare",
    "acquerellavano": "acquerellare",
    "acquerellavate": "acquerellare",
    "acquerellavi": "acquerellare",
    "acquerellavo": "acquerellare",
    "acquerellerai": "acquerellare",
    "acquerelleran": "acquerellare",
    "acquerelleranno": "acquerellare",
    "acquerellerebbe": "acquerellare",
    "acquerellerebber": "acquerellare",
    "acquerellerebbero": "acquerellare",
    "acquerellerei": "acquerellare",
    "acquerelleremmo": "acquerellare",
    "acquerelleremo": "acquerellare",
    "acquerellereste": "acquerellare",
    "acquerelleresti": "acquerellare",
    "acquerellerete": "acquerellare",
    "acquerellerà": "acquerellare",
    "acquerellerò": "acquerellare",
    "acquerelli": "acquerello",
    "acquerelliamo": "acquerellare",
    "acquerelliate": "acquerellare",
    "acquerellin": "acquerellare",
    "acquerellino": "acquerellare",
    "acquerello": "acquerellare",
    "acquerellò": "acquerellare",
    "acquiescenti": "acquiescente",
    "acquiescenze": "acquiescenza",
    "acquieta": "acquietare",
    "acquietai": "acquietare",
    "acquietammo": "acquietare",
    "acquietan": "acquietare",
    "acquietando": "acquietare",
    "acquietano": "acquietare",
    "acquietante": "acquietare",
    "acquietanti": "acquietare",
    "acquietar": "acquietare",
    "acquietaron": "acquietare",
    "acquietarono": "acquietare",
    "acquietasse": "acquietare",
    "acquietasser": "acquietare",
    "acquietassero": "acquietare",
    "acquietassi": "acquietare",
    "acquietassimo": "acquietare",
    "acquietaste": "acquietare",
    "acquietasti": "acquietare",
    "acquietata": "acquietare",
    "acquietate": "acquietare",
    "acquietati": "acquietare",
    "acquietato": "acquietare",
    "acquietava": "acquietare",
    "acquietavamo": "acquietare",
    "acquietavan": "acquietare",
    "acquietavano": "acquietare",
    "acquietavate": "acquietare",
    "acquietavi": "acquietare",
    "acquietavo": "acquietare",
    "acquieterai": "acquietare",
    "acquieteran": "acquietare",
    "acquieteranno": "acquietare",
    "acquieterebbe": "acquietare",
    "acquieterebber": "acquietare",
    "acquieterebbero": "acquietare",
    "acquieterei": "acquietare",
    "acquieteremmo": "acquietare",
    "acquieteremo": "acquietare",
    "acquietereste": "acquietare",
    "acquieteresti": "acquietare",
    "acquieterete": "acquietare",
    "acquieterà": "acquietare",
    "acquieterò": "acquietare",
    "acquieti": "acquietare",
    "acquietiamo": "acquietare",
    "acquietiate": "acquietare",
    "acquietin": "acquietare",
    "acquietino": "acquietare",
    "acquieto": "acquietare",
    "acquietò": "acquietare",
    "acquifera": "acquifero",
    "acquifere": "acquifero",
    "acquiferi": "acquifero",
    "acquirenti": "acquirente",
    "acquisendo": "acquisire",
    "acquisente": "acquisire",
    "acquisenti": "acquisire",
    "acquisiamo": "acquisire",
    "acquisiate": "acquisire",
    "acquisii": "acquisire",
    "acquisimmo": "acquisire",
    "acquisir": "acquisire",
    "acquisirai": "acquisire",
    "acquisiran": "acquisire",
    "acquisiranno": "acquisire",
    "acquisirebbe": "acquisire",
    "acquisirebber": "acquisire",
    "acquisirebbero": "acquisire",
    "acquisirei": "acquisire",
    "acquisiremmo": "acquisire",
    "acquisiremo": "acquisire",
    "acquisireste": "acquisire",
    "acquisiresti": "acquisire",
    "acquisirete": "acquisire",
    "acquisiron": "acquisire",
    "acquisirono": "acquisire",
    "acquisirà": "acquisire",
    "acquisirò": "acquisire",
    "acquisisca": "acquisire",
    "acquisiscan": "acquisire",
    "acquisiscano": "acquisire",
    "acquisisce": "acquisire",
    "acquisisci": "acquisire",
    "acquisisco": "acquisire",
    "acquisiscon": "acquisire",
    "acquisiscono": "acquisire",
    "acquisisse": "acquisire",
    "acquisisser": "acquisire",
    "acquisissero": "acquisire",
    "acquisissi": "acquisire",
    "acquisissimo": "acquisire",
    "acquisiste": "acquisire",
    "acquisisti": "acquisire",
    "acquisita": "acquisito",
    "acquisite": "acquisito",
    "acquisiti": "acquisito",
    "acquisito": "acquisire",
    "acquisiva": "acquisire",
    "acquisivamo": "acquisire",
    "acquisivan": "acquisire",
    "acquisivano": "acquisire",
    "acquisivate": "acquisire",
    "acquisivi": "acquisire",
    "acquisivo": "acquisire",
    "acquisizioni": "acquisizione",
    "acquista": "acquistare",
    "acquistai": "acquistare",
    "acquistammo": "acquistare",
    "acquistan": "acquistare",
    "acquistando": "acquistare",
    "acquistano": "acquistare",
    "acquistante": "acquistare",
    "acquistanti": "acquistare",
    "acquistar": "acquistare",
    "acquistaron": "acquistare",
    "acquistarono": "acquistare",
    "acquistasse": "acquistare",
    "acquistasser": "acquistare",
    "acquistassero": "acquistare",
    "acquistassi": "acquistare",
    "acquistassimo": "acquistare",
    "acquistaste": "acquistare",
    "acquistasti": "acquistare",
    "acquistata": "acquistare",
    "acquistate": "acquistare",
    "acquistati": "acquistare",
    "acquistato": "acquistare",
    "acquistava": "acquistare",
    "acquistavamo": "acquistare",
    "acquistavan": "acquistare",
    "acquistavano": "acquistare",
    "acquistavate": "acquistare",
    "acquistavi": "acquistare",
    "acquistavo": "acquistare",
    "acquisterai": "acquistare",
    "acquisteran": "acquistare",
    "acquisteranno": "acquistare",
    "acquisterebbe": "acquistare",
    "acquisterebber": "acquistare",
    "acquisterebbero": "acquistare",
    "acquisterei": "acquistare",
    "acquisteremmo": "acquistare",
    "acquisteremo": "acquistare",
    "acquistereste": "acquistare",
    "acquisteresti": "acquistare",
    "acquisterete": "acquistare",
    "acquisterà": "acquistare",
    "acquisterò": "acquistare",
    "acquisti": "acquisto",
    "acquistiamo": "acquistare",
    "acquistiate": "acquistare",
    "acquistin": "acquistare",
    "acquistino": "acquistare",
    "acquisto": "acquistare",
    "acquistò": "acquistare",
    "acquisì": "acquisire",
    "acquitrini": "acquitrino",
    "acquosa": "acquoso",
    "acquose": "acquoso",
    "acquosi": "acquoso",
    "acredini": "acredine",
    "acri": "acre",
    "acrilica": "acrilico",
    "acriliche": "acrilico",
    "acrilici": "acrilico",
    "acrimonie": "acrimonia",
    "acritica": "acritico",
    "acritiche": "acritico",
    "acritici": "acritico",
    "acrobati": "acrobata",
    "acrobatica": "acrobatico",
    "acrobatiche": "acrobatico",
    "acrobatici": "acrobatico",
    "acrobazie": "acrobazia",
    "acronimi": "acronimo",
    "acuendo": "acuire",
    "acuente": "acuire",
    "acuenti": "acuire",
    "acuiamo": "acuire",
    "acuiate": "acuire",
    "acuii": "acuire",
    "acuimmo": "acuire",
    "acuir": "acuire",
    "acuirai": "acuire",
    "acuiran": "acuire",
    "acuiranno": "acuire",
    "acuirebbe": "acuire",
    "acuirebber": "acuire",
    "acuirebbero": "acuire",
    "acuirei": "acuire",
    "acuiremmo": "acuire",
    "acuiremo": "acuire",
    "acuireste": "acuire",
    "acuiresti": "acuire",
    "acuirete": "acuire",
    "acuiron": "acuire",
    "acuirono": "acuire",
    "acuirà": "acuire",
    "acuirò": "acuire",
    "acuisca": "acuire",
    "acuiscan": "acuire",
    "acuiscano": "acuire",
    "acuisce": "acuire",
    "acuisci": "acuire",
    "acuisco": "acuire",
    "acuiscon": "acuire",
    "acuiscono": "acuire",
    "acuisse": "acuire",
    "acuisser": "acuire",
    "acuissero": "acuire",
    "acuissi": "acuire",
    "acuissimo": "acuire",
    "acuiste": "acuire",
    "acuisti": "acuire",
    "acuita": "acuire",
    "acuite": "acuire",
    "acuiti": "acuire",
    "acuito": "acuire",
    "acuiva": "acuire",
    "acuivamo": "acuire",
    "acuivan": "acuire",
    "acuivano": "acuire",
    "acuivate": "acuire",
    "acuivi": "acuire",
    "acuivo": "acuire",
    "acumina": "acuminare",
    "acuminai": "acuminare",
    "acuminammo": "acuminare",
    "acuminan": "acuminare",
    "acuminando": "acuminare",
    "acuminano": "acuminare",
    "acuminante": "acuminare",
    "acuminanti": "acuminare",
    "acuminar": "acuminare",
    "acuminaron": "acuminare",
    "acuminarono": "acuminare",
    "acuminasse": "acuminare",
    "acuminasser": "acuminare",
    "acuminassero": "acuminare",
    "acuminassi": "acuminare",
    "acuminassimo": "acuminare",
    "acuminaste": "acuminare",
    "acuminasti": "acuminare",
    "acuminata": "acuminato",
    "acuminate": "acuminato",
    "acuminati": "acuminato",
    "acuminato": "acuminare",
    "acuminava": "acuminare",
    "acuminavamo": "acuminare",
    "acuminavan": "acuminare",
    "acuminavano": "acuminare",
    "acuminavate": "acuminare",
    "acuminavi": "acuminare",
    "acuminavo": "acuminare",
    "acuminerai": "acuminare",
    "acumineran": "acuminare",
    "acumineranno": "acuminare",
    "acuminerebbe": "acuminare",
    "acuminerebber": "acuminare",
    "acuminerebbero": "acuminare",
    "acuminerei": "acuminare",
    "acumineremmo": "acuminare",
    "acumineremo": "acuminare",
    "acuminereste": "acuminare",
    "acumineresti": "acuminare",
    "acuminerete": "acuminare",
    "acuminerà": "acuminare",
    "acuminerò": "acuminare",
    "acumini": "acuminare",
    "acuminiamo": "acuminare",
    "acuminiate": "acuminare",
    "acuminin": "acuminare",
    "acuminino": "acuminare",
    "acumino": "acuminare",
    "acuminò": "acuminare",
    "acustica": "acustico",
    "acustiche": "acustico",
    "acustici": "acustico",
    "acuta": "acuto",
    "acute": "acuto",
    "acutezze": "acutezza",
    "acuti": "acuto",
    "acutizza": "acutizzare",
    "acutizzai": "acutizzare",
    "acutizzammo": "acutizzare",
    "acutizzan": "acutizzare",
    "acutizzando": "acutizzare",
    "acutizzano": "acutizzare",
    "acutizzante": "acutizzare",
    "acutizzanti": "acutizzare",
    "acutizzar": "acutizzare",
    "acutizzaron": "acutizzare",
    "acutizzarono": "acutizzare",
    "acutizzasse": "acutizzare",
    "acutizzasser": "acutizzare",
    "acutizzassero": "acutizzare",
    "acutizzassi": "acutizzare",
    "acutizzassimo": "acutizzare",
    "acutizzaste": "acutizzare",
    "acutizzasti": "acutizzare",
    "acutizzata": "acutizzare",
    "acutizzate": "acutizzare",
    "acutizzati": "acutizzare",
    "acutizzato": "acutizzare",
    "acutizzava": "acutizzare",
    "acutizzavamo": "acutizzare",
    "acutizzavan": "acutizzare",
    "acutizzavano": "acutizzare",
    "acutizzavate": "acutizzare",
    "acutizzavi": "acutizzare",
    "acutizzavo": "acutizzare",
    "acutizzerai": "acutizzare",
    "acutizzeran": "acutizzare",
    "acutizzeranno": "acutizzare",
    "acutizzerebbe": "acutizzare",
    "acutizzerebber": "acutizzare",
    "acutizzerebbero": "acutizzare",
    "acutizzerei": "acutizzare",
    "acutizzeremmo": "acutizzare",
    "acutizzeremo": "acutizzare",
    "acutizzereste": "acutizzare",
    "acutizzeresti": "acutizzare",
    "acutizzerete": "acutizzare",
    "acutizzerà": "acutizzare",
    "acutizzerò": "acutizzare",
    "acutizzi": "acutizzare",
    "acutizziamo": "acutizzare",
    "acutizziate": "acutizzare",
    "acutizzin": "acutizzare",
    "acutizzino": "acutizzare",
    "acutizzo": "acutizzare",
    "acutizzò": "acutizzare",
    "acuì": "acuire",
    "adagerai": "adagiare",
    "adageran": "adagiare",
    "adageranno": "adagiare",
    "adagerebbe": "adagiare",
    "adagerebber": "adagiare",
    "adagerebbero": "adagiare",
    "adagerei": "adagiare",
    "adageremmo": "adagiare",
    "adageremo": "adagiare",
    "adagereste": "adagiare",
    "adageresti": "adagiare",
    "adagerete": "adagiare",
    "adagerà": "adagiare",
    "adagerò": "adagiare",
    "adagi": "adagio",
    "adagia": "adagiare",
    "adagiai": "adagiare",
    "adagiammo": "adagiare",
    "adagiamo": "adagiare",
    "adagian": "adagiare",
    "adagiando": "adagiare",
    "adagiano": "adagiare",
    "adagiante": "adagiare",
    "adagianti": "adagiare",
    "adagiar": "adagiare",
    "adagiaron": "adagiare",
    "adagiarono": "adagiare",
    "adagiasse": "adagiare",
    "adagiasser": "adagiare",
    "adagiassero": "adagiare",
    "adagiassi": "adagiare",
    "adagiassimo": "adagiare",
    "adagiaste": "adagiare",
    "adagiasti": "adagiare",
    "adagiata": "adagiare",
    "adagiate": "adagiare",
    "adagiati": "adagiare",
    "adagiato": "adagiare",
    "adagiava": "adagiare",
    "adagiavamo": "adagiare",
    "adagiavan": "adagiare",
    "adagiavano": "adagiare",
    "adagiavate": "adagiare",
    "adagiavi": "adagiare",
    "adagiavo": "adagiare",
    "adagin": "adagiare",
    "adagino": "adagiare",
    "adagio": "adagiare",
    "adagiò": "adagiare",
    "adamantina": "adamantino",
    "adamantine": "adamantino",
    "adamantini": "adamantino",
    "adamitica": "adamitico",
    "adamitiche": "adamitico",
    "adamitici": "adamitico",
    "adatta": "adatto",
    "adattabili": "adattabile",
    "adattai": "adattare",
    "adattamenti": "adattamento",
    "adattammo": "adattare",
    "adattan": "adattare",
    "adattando": "adattare",
    "adattano": "adattare",
    "adattante": "adattare",
    "adattanti": "adattare",
    "adattar": "adattare",
    "adattaron": "adattare",
    "adattarono": "adattare",
    "adattasse": "adattare",
    "adattasser": "adattare",
    "adattassero": "adattare",
    "adattassi": "adattare",
    "adattassimo": "adattare",
    "adattaste": "adattare",
    "adattasti": "adattare",
    "adattata": "adattare",
    "adattate": "adattare",
    "adattati": "adattare",
    "adattato": "adattare",
    "adattatori": "adattatore",
    "adattava": "adattare",
    "adattavamo": "adattare",
    "adattavan": "adattare",
    "adattavano": "adattare",
    "adattavate": "adattare",
    "adattavi": "adattare",
    "adattavo": "adattare",
    "adatte": "adatto",
    "adatterai": "adattare",
    "adatteran": "adattare",
    "adatteranno": "adattare",
    "adatterebbe": "adattare",
    "adatterebber": "adattare",
    "adatterebbero": "adattare",
    "adatterei": "adattare",
    "adatteremmo": "adattare",
    "adatteremo": "adattare",
    "adattereste": "adattare",
    "adatteresti": "adattare",
    "adatterete": "adattare",
    "adatterà": "adattare",
    "adatterò": "adattare",
    "adatti": "adatto",
    "adattiamo": "adattare",
    "adattiate": "adattare",
    "adattin": "adattare",
    "adattino": "adattare",
    "adatto": "adattare",
    "adattò": "adattare",
    "addebita": "addebitare",
    "addebitabili": "addebitabile",
    "addebitai": "addebitare",
    "addebitammo": "addebitare",
    "addebitan": "addebitare",
    "addebitando": "addebitare",
    "addebitano": "addebitare",
    "addebitante": "addebitare",
    "addebitanti": "addebitare",
    "addebitar": "addebitare",
    "addebitaron": "addebitare",
    "addebitarono": "addebitare",
    "addebitasse": "addebitare",
    "addebitasser": "addebitare",
    "addebitassero": "addebitare",
    "addebitassi": "addebitare",
    "addebitassimo": "addebitare",
    "addebitaste": "addebitare",
    "addebitasti": "addebitare",
    "addebitata": "addebitare",
    "addebitate": "addebitare",
    "addebitati": "addebitare",
    "addebitato": "addebitare",
    "addebitava": "addebitare",
    "addebitavamo": "addebitare",
    "addebitavan": "addebitare",
    "addebitavano": "addebitare",
    "addebitavate": "addebitare",
    "addebitavi": "addebitare",
    "addebitavo": "addebitare",
    "addebiterai": "addebitare",
    "addebiteran": "addebitare",
    "addebiteranno": "addebitare",
    "addebiterebbe": "addebitare",
    "addebiterebber": "addebitare",
    "addebiterebbero": "addebitare",
    "addebiterei": "addebitare",
    "addebiteremmo": "addebitare",
    "addebiteremo": "addebitare",
    "addebitereste": "addebitare",
    "addebiteresti": "addebitare",
    "addebiterete": "addebitare",
    "addebiterà": "addebitare",
    "addebiterò": "addebitare",
    "addebiti": "addebito",
    "addebitiamo": "addebitare",
    "addebitiate": "addebitare",
    "addebitin": "addebitare",
    "addebitino": "addebitare",
    "addebito": "addebitare",
    "addebitò": "addebitare",
    "addensa": "addensare",
    "addensai": "addensare",
    "addensamenti": "addensamento",
    "addensammo": "addensare",
    "addensan": "addensare",
    "addensando": "addensare",
    "addensano": "addensare",
    "addensante": "addensare",
    "addensanti": "addensare",
    "addensar": "addensare",
    "addensaron": "addensare",
    "addensarono": "addensare",
    "addensasse": "addensare",
    "addensasser": "addensare",
    "addensassero": "addensare",
    "addensassi": "addensare",
    "addensassimo": "addensare",
    "addensaste": "addensare",
    "addensasti": "addensare",
    "addensata": "addensare",
    "addensate": "addensare",
    "addensati": "addensare",
    "addensato": "addensare",
    "addensava": "addensare",
    "addensavamo": "addensare",
    "addensavan": "addensare",
    "addensavano": "addensare",
    "addensavate": "addensare",
    "addensavi": "addensare",
    "addensavo": "addensare",
    "addenserai": "addensare",
    "addenseran": "addensare",
    "addenseranno": "addensare",
    "addenserebbe": "addensare",
    "addenserebber": "addensare",
    "addenserebbero": "addensare",
    "addenserei": "addensare",
    "addenseremmo": "addensare",
    "addenseremo": "addensare",
    "addensereste": "addensare",
    "addenseresti": "addensare",
    "addenserete": "addensare",
    "addenserà": "addensare",
    "addenserò": "addensare",
    "addensi": "addensare",
    "addensiamo": "addensare",
    "addensiate": "addensare",
    "addensin": "addensare",
    "addensino": "addensare",
    "addenso": "addensare",
    "addensò": "addensare",
    "addenta": "addentare",
    "addentabili": "addentabile",
    "addentai": "addentare",
    "addentammo": "addentare",
    "addentan": "addentare",
    "addentando": "addentare",
    "addentano": "addentare",
    "addentante": "addentare",
    "addentanti": "addentare",
    "addentar": "addentare",
    "addentaron": "addentare",
    "addentarono": "addentare",
    "addentasse": "addentare",
    "addentasser": "addentare",
    "addentassero": "addentare",
    "addentassi": "addentare",
    "addentassimo": "addentare",
    "addentaste": "addentare",
    "addentasti": "addentare",
    "addentata": "addentare",
    "addentate": "addentare",
    "addentati": "addentare",
    "addentato": "addentare",
    "addentava": "addentare",
    "addentavamo": "addentare",
    "addentavan": "addentare",
    "addentavano": "addentare",
    "addentavate": "addentare",
    "addentavi": "addentare",
    "addentavo": "addentare",
    "addentella": "addentellare",
    "addentellai": "addentellare",
    "addentellammo": "addentellare",
    "addentellan": "addentellare",
    "addentellando": "addentellare",
    "addentellano": "addentellare",
    "addentellante": "addentellare",
    "addentellanti": "addentellare",
    "addentellar": "addentellare",
    "addentellaron": "addentellare",
    "addentellarono": "addentellare",
    "addentellasse": "addentellare",
    "addentellasser": "addentellare",
    "addentellassero": "addentellare",
    "addentellassi": "addentellare",
    "addentellassimo": "addentellare",
    "addentellaste": "addentellare",
    "addentellasti": "addentellare",
    "addentellata": "addentellare",
    "addentellate": "addentellare",
    "addentellati": "addentellare",
    "addentellato": "addentellare",
    "addentellava": "addentellare",
    "addentellavamo": "addentellare",
    "addentellavan": "addentellare",
    "addentellavano": "addentellare",
    "addentellavate": "addentellare",
    "addentellavi": "addentellare",
    "addentellavo": "addentellare",
    "addentellerai": "addentellare",
    "addentelleran": "addentellare",
    "addentelleranno": "addentellare",
    "addentellerebbe": "addentellare",
    "addentellerebber": "addentellare",
    "addentellerebbero": "addentellare",
    "addentellerei": "addentellare",
    "addentelleremmo": "addentellare",
    "addentelleremo": "addentellare",
    "addentellereste": "addentellare",
    "addentelleresti": "addentellare",
    "addentellerete": "addentellare",
    "addentellerà": "addentellare",
    "addentellerò": "addentellare",
    "addentelli": "addentellare",
    "addentelliamo": "addentellare",
    "addentelliate": "addentellare",
    "addentellin": "addentellare",
    "addentellino": "addentellare",
    "addentello": "addentellare",
    "addentellò": "addentellare",
    "addenterai": "addentare",
    "addenteran": "addentare",
    "addenteranno": "addentare",
    "addenterebbe": "addentare",
    "addenterebber": "addentare",
    "addenterebbero": "addentare",
    "addenterei": "addentare",
    "addenteremmo": "addentare",
    "addenteremo": "addentare",
    "addentereste": "addentare",
    "addenteresti": "addentare",
    "addenterete": "addentare",
    "addenterà": "addentare",
    "addenterò": "addentare",
    "addenti": "addentare",
    "addentiamo": "addentare",
    "addentiate": "addentare",
    "addentin": "addentare",
    "addentino": "addentare",
    "addento": "addentare",
    "addentra": "addentrare",
    "addentrai": "addentrare",
    "addentrammo": "addentrare",
    "addentran": "addentrare",
    "addentrando": "addentrare",
    "addentrano": "addentrare",
    "addentrante": "addentrare",
    "addentranti": "addentrare",
    "addentrar": "addentrare",
    "addentraron": "addentrare",
    "addentrarono": "addentrare",
    "addentrasse": "addentrare",
    "addentrasser": "addentrare",
    "addentrassero": "addentrare",
    "addentrassi": "addentrare",
    "addentrassimo": "addentrare",
    "addentraste": "addentrare",
    "addentrasti": "addentrare",
    "addentrata": "addentrare",
    "addentrate": "addentrare",
    "addentrati": "addentrare",
    "addentrato": "addentrare",
    "addentrava": "addentrare",
    "addentravamo": "addentrare",
    "addentravan": "addentrare",
    "addentravano": "addentrare",
    "addentravate": "addentrare",
    "addentravi": "addentrare",
    "addentravo": "addentrare",
    "addentrerai": "addentrare",
    "addentreran": "addentrare",
    "addentreranno": "addentrare",
    "addentrerebbe": "addentrare",
    "addentrerebber": "addentrare",
    "addentrerebbero": "addentrare",
    "addentrerei": "addentrare",
    "addentreremmo": "addentrare",
    "addentreremo": "addentrare",
    "addentrereste": "addentrare",
    "addentreresti": "addentrare",
    "addentrerete": "addentrare",
    "addentrerà": "addentrare",
    "addentrerò": "addentrare",
    "addentri": "addentrare",
    "addentriamo": "addentrare",
    "addentriate": "addentrare",
    "addentrin": "addentrare",
    "addentrino": "addentrare",
    "addentro": "addentrare",
    "addentrò": "addentrare",
    "addentò": "addentare",
    "addestra": "addestrare",
    "addestrai": "addestrare",
    "addestramenti": "addestramento",
    "addestrammo": "addestrare",
    "addestran": "addestrare",
    "addestrando": "addestrare",
    "addestrano": "addestrare",
    "addestrante": "addestrare",
    "addestranti": "addestrare",
    "addestrar": "addestrare",
    "addestraron": "addestrare",
    "addestrarono": "addestrare",
    "addestrasse": "addestrare",
    "addestrasser": "addestrare",
    "addestrassero": "addestrare",
    "addestrassi": "addestrare",
    "addestrassimo": "addestrare",
    "addestraste": "addestrare",
    "addestrasti": "addestrare",
    "addestrata": "addestrare",
    "addestrate": "addestrare",
    "addestrati": "addestrare",
    "addestrativa": "addestrativo",
    "addestrative": "addestrativo",
    "addestrativi": "addestrativo",
    "addestrato": "addestrare",
    "addestratori": "addestratore",
    "addestrava": "addestrare",
    "addestravamo": "addestrare",
    "addestravan": "addestrare",
    "addestravano": "addestrare",
    "addestravate": "addestrare",
    "addestravi": "addestrare",
    "addestravo": "addestrare",
    "addestrerai": "addestrare",
    "addestreran": "addestrare",
    "addestreranno": "addestrare",
    "addestrerebbe": "addestrare",
    "addestrerebber": "addestrare",
    "addestrerebbero": "addestrare",
    "addestrerei": "addestrare",
    "addestreremmo": "addestrare",
    "addestreremo": "addestrare",
    "addestrereste": "addestrare",
    "addestreresti": "addestrare",
    "addestrerete": "addestrare",
    "addestrerà": "addestrare",
    "addestrerò": "addestrare",
    "addestri": "addestrare",
    "addestriamo": "addestrare",
    "addestriate": "addestrare",
    "addestrin": "addestrare",
    "addestrino": "addestrare",
    "addestro": "addestrare",
    "addestrò": "addestrare",
    "addetta": "addire",
    "addette": "addire",
    "addetti": "addire",
    "addetto": "addire",
    "addica": "addire",
    "addican": "addire",
    "addicano": "addire",
    "addice": "addire",
    "addicemmo": "addire",
    "addicendo": "addire",
    "addicente": "addire",
    "addicenti": "addire",
    "addicesse": "addire",
    "addicesser": "addire",
    "addicessero": "addire",
    "addicessi": "addire",
    "addicessimo": "addire",
    "addiceste": "addire",
    "addicesti": "addire",
    "addiceva": "addire",
    "addicevamo": "addire",
    "addicevan": "addire",
    "addicevano": "addire",
    "addicevate": "addire",
    "addicevi": "addire",
    "addicevo": "addire",
    "addici": "addire",
    "addiciamo": "addire",
    "addiciate": "addire",
    "addico": "addire",
    "addicon": "addire",
    "addicono": "addire",
    "addii": "addio",
    "addir": "addire",
    "addirai": "addire",
    "addiran": "addire",
    "addiranno": "addire",
    "addirebbe": "addire",
    "addirebber": "addire",
    "addirebbero": "addire",
    "addirei": "addire",
    "addiremmo": "addire",
    "addiremo": "addire",
    "addireste": "addire",
    "addiresti": "addire",
    "addirete": "addire",
    "addirà": "addire",
    "addirò": "addire",
    "addisse": "addire",
    "addisser": "addire",
    "addissero": "addire",
    "addissi": "addire",
    "addita": "additare",
    "additai": "additare",
    "additammo": "additare",
    "additan": "additare",
    "additando": "additare",
    "additano": "additare",
    "additante": "additare",
    "additanti": "additare",
    "additar": "additare",
    "additaron": "additare",
    "additarono": "additare",
    "additasse": "additare",
    "additasser": "additare",
    "additassero": "additare",
    "additassi": "additare",
    "additassimo": "additare",
    "additaste": "additare",
    "additasti": "additare",
    "additata": "additare",
    "additate": "additare",
    "additati": "additare",
    "additato": "additare",
    "additava": "additare",
    "additavamo": "additare",
    "additavan": "additare",
    "additavano": "additare",
    "additavate": "additare",
    "additavi": "additare",
    "additavo": "additare",
    "addite": "addire",
    "additerai": "additare",
    "additeran": "additare",
    "additeranno": "additare",
    "additerebbe": "additare",
    "additerebber": "additare",
    "additerebbero": "additare",
    "additerei": "additare",
    "additeremmo": "additare",
    "additeremo": "additare",
    "additereste": "additare",
    "additeresti": "additare",
    "additerete": "additare",
    "additerà": "additare",
    "additerò": "additare",
    "additi": "additare",
    "additiamo": "additare",
    "additiate": "additare",
    "additin": "additare",
    "additino": "additare",
    "additiva": "additivo",
    "additive": "additivo",
    "additivi": "additivo",
    "addito": "additare",
    "additò": "additare",
    "addivenendo": "addivenire",
    "addivenente": "addivenire",
    "addivenenti": "addivenire",
    "addivenga": "addivenire",
    "addivengan": "addivenire",
    "addivengano": "addivenire",
    "addivengo": "addivenire",
    "addivengon": "addivenire",
    "addivengono": "addivenire",
    "addiveniamo": "addivenire",
    "addiveniate": "addivenire",
    "addivenimmo": "addivenire",
    "addivenir": "addivenire",
    "addivenisse": "addivenire",
    "addivenisser": "addivenire",
    "addivenissero": "addivenire",
    "addivenissi": "addivenire",
    "addivenissimo": "addivenire",
    "addiveniste": "addivenire",
    "addivenisti": "addivenire",
    "addivenite": "addivenire",
    "addiveniva": "addivenire",
    "addivenivamo": "addivenire",
    "addivenivan": "addivenire",
    "addivenivano": "addivenire",
    "addivenivate": "addivenire",
    "addivenivi": "addivenire",
    "addivenivo": "addivenire",
    "addivenne": "addivenire",
    "addivenner": "addivenire",
    "addivennero": "addivenire",
    "addivenni": "addivenire",
    "addivenuta": "addivenire",
    "addivenute": "addivenire",
    "addivenuti": "addivenire",
    "addivenuto": "addivenire",
    "addiverrai": "addivenire",
    "addiverran": "addivenire",
    "addiverranno": "addivenire",
    "addiverrebbe": "addivenire",
    "addiverrebber": "addivenire",
    "addiverrebbero": "addivenire",
    "addiverrei": "addivenire",
    "addiverremmo": "addivenire",
    "addiverremo": "addivenire",
    "addiverreste": "addivenire",
    "addiverresti": "addivenire",
    "addiverrete": "addivenire",
    "addiverrà": "addivenire",
    "addiverrò": "addivenire",
    "addiviene": "addivenire",
    "addivieni": "addivenire",
    "addiziona": "addizionare",
    "addizionai": "addizionare",
    "addizionali": "addizionale",
    "addizionammo": "addizionare",
    "addizionan": "addizionare",
    "addizionando": "addizionare",
    "addizionano": "addizionare",
    "addizionante": "addizionare",
    "addizionanti": "addizionare",
    "addizionar": "addizionare",
    "addizionaron": "addizionare",
    "addizionarono": "addizionare",
    "addizionasse": "addizionare",
    "addizionasser": "addizionare",
    "addizionassero": "addizionare",
    "addizionassi": "addizionare",
    "addizionassimo": "addizionare",
    "addizionaste": "addizionare",
    "addizionasti": "addizionare",
    "addizionata": "addizionare",
    "addizionate": "addizionare",
    "addizionati": "addizionare",
    "addizionato": "addizionare",
    "addizionava": "addizionare",
    "addizionavamo": "addizionare",
    "addizionavan": "addizionare",
    "addizionavano": "addizionare",
    "addizionavate": "addizionare",
    "addizionavi": "addizionare",
    "addizionavo": "addizionare",
    "addizionerai": "addizionare",
    "addizioneran": "addizionare",
    "addizioneranno": "addizionare",
    "addizionerebbe": "addizionare",
    "addizionerebber": "addizionare",
    "addizionerebbero": "addizionare",
    "addizionerei": "addizionare",
    "addizioneremmo": "addizionare",
    "addizioneremo": "addizionare",
    "addizionereste": "addizionare",
    "addizioneresti": "addizionare",
    "addizionerete": "addizionare",
    "addizionerà": "addizionare",
    "addizionerò": "addizionare",
    "addizioni": "addizione",
    "addizioniamo": "addizionare",
    "addizioniate": "addizionare",
    "addizionin": "addizionare",
    "addizionino": "addizionare",
    "addiziono": "addizionare",
    "addizionò": "addizionare",
    "addobba": "addobbare",
    "addobbai": "addobbare",
    "addobbammo": "addobbare",
    "addobban": "addobbare",
    "addobbando": "addobbare",
    "addobbano": "addobbare",
    "addobbante": "addobbare",
    "addobbanti": "addobbare",
    "addobbar": "addobbare",
    "addobbaron": "addobbare",
    "addobbarono": "addobbare",
    "addobbasse": "addobbare",
    "addobbasser": "addobbare",
    "addobbassero": "addobbare",
    "addobbassi": "addobbare",
    "addobbassimo": "addobbare",
    "addobbaste": "addobbare",
    "addobbasti": "addobbare",
    "addobbata": "addobbare",
    "addobbate": "addobbare",
    "addobbati": "addobbare",
    "addobbato": "addobbare",
    "addobbava": "addobbare",
    "addobbavamo": "addobbare",
    "addobbavan": "addobbare",
    "addobbavano": "addobbare",
    "addobbavate": "addobbare",
    "addobbavi": "addobbare",
    "addobbavo": "addobbare",
    "addobberai": "addobbare",
    "addobberan": "addobbare",
    "addobberanno": "addobbare",
    "addobberebbe": "addobbare",
    "addobberebber": "addobbare",
    "addobberebbero": "addobbare",
    "addobberei": "addobbare",
    "addobberemmo": "addobbare",
    "addobberemo": "addobbare",
    "addobbereste": "addobbare",
    "addobberesti": "addobbare",
    "addobberete": "addobbare",
    "addobberà": "addobbare",
    "addobberò": "addobbare",
    "addobbi": "addobbo",
    "addobbiamo": "addobbare",
    "addobbiate": "addobbare",
    "addobbin": "addobbare",
    "addobbino": "addobbare",
    "addobbo": "addobbare",
    "addobbò": "addobbare",
    "addolcendo": "addolcire",
    "addolcente": "addolcire",
    "addolcenti": "addolcire",
    "addolciamo": "addolcire",
    "addolciate": "addolcire",
    "addolcibili": "addolcibile",
    "addolcii": "addolcire",
    "addolcimmo": "addolcire",
    "addolcir": "addolcire",
    "addolcirai": "addolcire",
    "addolciran": "addolcire",
    "addolciranno": "addolcire",
    "addolcirebbe": "addolcire",
    "addolcirebber": "addolcire",
    "addolcirebbero": "addolcire",
    "addolcirei": "addolcire",
    "addolciremmo": "addolcire",
    "addolciremo": "addolcire",
    "addolcireste": "addolcire",
    "addolciresti": "addolcire",
    "addolcirete": "addolcire",
    "addolciron": "addolcire",
    "addolcirono": "addolcire",
    "addolcirà": "addolcire",
    "addolcirò": "addolcire",
    "addolcisca": "addolcire",
    "addolciscan": "addolcire",
    "addolciscano": "addolcire",
    "addolcisce": "addolcire",
    "addolcisci": "addolcire",
    "addolcisco": "addolcire",
    "addolciscon": "addolcire",
    "addolciscono": "addolcire",
    "addolcisse": "addolcire",
    "addolcisser": "addolcire",
    "addolcissero": "addolcire",
    "addolcissi": "addolcire",
    "addolcissimo": "addolcire",
    "addolciste": "addolcire",
    "addolcisti": "addolcire",
    "addolcita": "addolcire",
    "addolcite": "addolcire",
    "addolciti": "addolcire",
    "addolcito": "addolcire",
    "addolciva": "addolcire",
    "addolcivamo": "addolcire",
    "addolcivan": "addolcire",
    "addolcivano": "addolcire",
    "addolcivate": "addolcire",
    "addolcivi": "addolcire",
    "addolcivo": "addolcire",
    "addolcì": "addolcire",
    "addolora": "addolorare",
    "addolorai": "addolorare",
    "addolorammo": "addolorare",
    "addoloran": "addolorare",
    "addolorando": "addolorare",
    "addolorano": "addolorare",
    "addolorante": "addolorare",
    "addoloranti": "addolorare",
    "addolorar": "addolorare",
    "addoloraron": "addolorare",
    "addolorarono": "addolorare",
    "addolorasse": "addolorare",
    "addolorasser": "addolorare",
    "addolorassero": "addolorare",
    "addolorassi": "addolorare",
    "addolorassimo": "addolorare",
    "addoloraste": "addolorare",
    "addolorasti": "addolorare",
    "addolorata": "addolorato",
    "addolorate": "addolorato",
    "addolorati": "addolorato",
    "addolorato": "addolorare",
    "addolorava": "addolorare",
    "addoloravamo": "addolorare",
    "addoloravan": "addolorare",
    "addoloravano": "addolorare",
    "addoloravate": "addolorare",
    "addoloravi": "addolorare",
    "addoloravo": "addolorare",
    "addolorerai": "addolorare",
    "addoloreran": "addolorare",
    "addoloreranno": "addolorare",
    "addolorerebbe": "addolorare",
    "addolorerebber": "addolorare",
    "addolorerebbero": "addolorare",
    "addolorerei": "addolorare",
    "addoloreremmo": "addolorare",
    "addoloreremo": "addolorare",
    "addolorereste": "addolorare",
    "addoloreresti": "addolorare",
    "addolorerete": "addolorare",
    "addolorerà": "addolorare",
    "addolorerò": "addolorare",
    "addolori": "addolorare",
    "addoloriamo": "addolorare",
    "addoloriate": "addolorare",
    "addolorin": "addolorare",
    "addolorino": "addolorare",
    "addoloro": "addolorare",
    "addolorò": "addolorare",
    "addomestica": "addomesticare",
    "addomesticai": "addomesticare",
    "addomesticammo": "addomesticare",
    "addomestican": "addomesticare",
    "addomesticando": "addomesticare",
    "addomesticano": "addomesticare",
    "addomesticante": "addomesticare",
    "addomesticanti": "addomesticare",
    "addomesticar": "addomesticare",
    "addomesticaron": "addomesticare",
    "addomesticarono": "addomesticare",
    "addomesticasse": "addomesticare",
    "addomesticasser": "addomesticare",
    "addomesticassero": "addomesticare",
    "addomesticassi": "addomesticare",
    "addomesticassimo": "addomesticare",
    "addomesticaste": "addomesticare",
    "addomesticasti": "addomesticare",
    "addomesticata": "addomesticato",
    "addomesticate": "addomesticato",
    "addomesticati": "addomesticato",
    "addomesticato": "addomesticare",
    "addomesticava": "addomesticare",
    "addomesticavamo": "addomesticare",
    "addomesticavan": "addomesticare",
    "addomesticavano": "addomesticare",
    "addomesticavate": "addomesticare",
    "addomesticavi": "addomesticare",
    "addomesticavo": "addomesticare",
    "addomesticherai": "addomesticare",
    "addomesticheran": "addomesticare",
    "addomesticheranno": "addomesticare",
    "addomesticherebbe": "addomesticare",
    "addomesticherebber": "addomesticare",
    "addomesticherebbero": "addomesticare",
    "addomesticherei": "addomesticare",
    "addomesticheremmo": "addomesticare",
    "addomesticheremo": "addomesticare",
    "addomestichereste": "addomesticare",
    "addomesticheresti": "addomesticare",
    "addomesticherete": "addomesticare",
    "addomesticherà": "addomesticare",
    "addomesticherò": "addomesticare",
    "addomestichi": "addomesticare",
    "addomestichiamo": "addomesticare",
    "addomestichiate": "addomesticare",
    "addomestichin": "addomesticare",
    "addomestichino": "addomesticare",
    "addomestico": "addomesticare",
    "addomesticò": "addomesticare",
    "addominali": "addominale",
    "addorma": "addormire",
    "addorman": "addormire",
    "addormano": "addormire",
    "addorme": "addormire",
    "addormendo": "addormire",
    "addormenta": "addormentare",
    "addormentai": "addormentare",
    "addormentammo": "addormentare",
    "addormentan": "addormentare",
    "addormentando": "addormentare",
    "addormentano": "addormentare",
    "addormentante": "addormentare",
    "addormentanti": "addormentare",
    "addormentar": "addormentare",
    "addormentaron": "addormentare",
    "addormentarono": "addormentare",
    "addormentasse": "addormentare",
    "addormentasser": "addormentare",
    "addormentassero": "addormentare",
    "addormentassi": "addormentare",
    "addormentassimo": "addormentare",
    "addormentaste": "addormentare",
    "addormentasti": "addormentare",
    "addormentata": "addormentato",
    "addormentate": "addormentato",
    "addormentati": "addormentato",
    "addormentato": "addormentare",
    "addormentava": "addormentare",
    "addormentavamo": "addormentare",
    "addormentavan": "addormentare",
    "addormentavano": "addormentare",
    "addormentavate": "addormentare",
    "addormentavi": "addormentare",
    "addormentavo": "addormentare",
    "addormente": "addormire",
    "addormenterai": "addormentare",
    "addormenteran": "addormentare",
    "addormenteranno": "addormentare",
    "addormenterebbe": "addormentare",
    "addormenterebber": "addormentare",
    "addormenterebbero": "addormentare",
    "addormenterei": "addormentare",
    "addormenteremmo": "addormentare",
    "addormenteremo": "addormentare",
    "addormentereste": "addormentare",
    "addormenteresti": "addormentare",
    "addormenterete": "addormentare",
    "addormenterà": "addormentare",
    "addormenterò": "addormentare",
    "addormenti": "addormire",
    "addormentiamo": "addormentare",
    "addormentiate": "addormentare",
    "addormentin": "addormentare",
    "addormentino": "addormentare",
    "addormento": "addormentare",
    "addormentò": "addormentare",
    "addormi": "addormire",
    "addormiamo": "addormire",
    "addormiate": "addormire",
    "addormii": "addormire",
    "addormimmo": "addormire",
    "addormir": "addormire",
    "addormirai": "addormire",
    "addormiran": "addormire",
    "addormiranno": "addormire",
    "addormirebbe": "addormire",
    "addormirebber": "addormire",
    "addormirebbero": "addormire",
    "addormirei": "addormire",
    "addormiremmo": "addormire",
    "addormiremo": "addormire",
    "addormireste": "addormire",
    "addormiresti": "addormire",
    "addormirete": "addormire",
    "addormiron": "addormire",
    "addormirono": "addormire",
    "addormirà": "addormire",
    "addormirò": "addormire",
    "addormisse": "addormire",
    "addormisser": "addormire",
    "addormissero": "addormire",
    "addormissi": "addormire",
    "addormissimo": "addormire",
    "addormiste": "addormire",
    "addormisti": "addormire",
    "addormita": "addormire",
    "addormite": "addormire",
    "addormiti": "addormire",
    "addormito": "addormire",
    "addormiva": "addormire",
    "addormivamo": "addormire",
    "addormivan": "addormire",
    "addormivano": "addormire",
    "addormivate": "addormire",
    "addormivi": "addormire",
    "addormivo": "addormire",
    "addormo": "addormire",
    "addormon": "addormire",
    "addormono": "addormire",
    "addormì": "addormire",
    "addossa": "addossare",
    "addossai": "addossare",
    "addossammo": "addossare",
    "addossan": "addossare",
    "addossando": "addossare",
    "addossano": "addossare",
    "addossante": "addossare",
    "addossanti": "addossare",
    "addossar": "addossare",
    "addossaron": "addossare",
    "addossarono": "addossare",
    "addossasse": "addossare",
    "addossasser": "addossare",
    "addossassero": "addossare",
    "addossassi": "addossare",
    "addossassimo": "addossare",
    "addossaste": "addossare",
    "addossasti": "addossare",
    "addossata": "addossato",
    "addossate": "addossato",
    "addossati": "addossato",
    "addossato": "addossare",
    "addossava": "addossare",
    "addossavamo": "addossare",
    "addossavan": "addossare",
    "addossavano": "addossare",
    "addossavate": "addossare",
    "addossavi": "addossare",
    "addossavo": "addossare",
    "addosserai": "addossare",
    "addosseran": "addossare",
    "addosseranno": "addossare",
    "addosserebbe": "addossare",
    "addosserebber": "addossare",
    "addosserebbero": "addossare",
    "addosserei": "addossare",
    "addosseremmo": "addossare",
    "addosseremo": "addossare",
    "addossereste": "addossare",
    "addosseresti": "addossare",
    "addosserete": "addossare",
    "addosserà": "addossare",
    "addosserò": "addossare",
    "addossi": "addossare",
    "addossiamo": "addossare",
    "addossiate": "addossare",
    "addossin": "addossare",
    "addossino": "addossare",
    "addosso": "addossare",
    "addossò": "addossare",
    "addotta": "addurre",
    "addotte": "addurre",
    "addotti": "addurre",
    "addotto": "addurre",
    "addottora": "addottorare",
    "addottorai": "addottorare",
    "addottorammo": "addottorare",
    "addottoran": "addottorare",
    "addottorando": "addottorare",
    "addottorano": "addottorare",
    "addottorante": "addottorare",
    "addottoranti": "addottorare",
    "addottorar": "addottorare",
    "addottoraron": "addottorare",
    "addottorarono": "addottorare",
    "addottorasse": "addottorare",
    "addottorasser": "addottorare",
    "addottorassero": "addottorare",
    "addottorassi": "addottorare",
    "addottorassimo": "addottorare",
    "addottoraste": "addottorare",
    "addottorasti": "addottorare",
    "addottorata": "addottorare",
    "addottorate": "addottorare",
    "addottorati": "addottorare",
    "addottorato": "addottorare",
    "addottorava": "addottorare",
    "addottoravamo": "addottorare",
    "addottoravan": "addottorare",
    "addottoravano": "addottorare",
    "addottoravate": "addottorare",
    "addottoravi": "addottorare",
    "addottoravo": "addottorare",
    "addottorerai": "addottorare",
    "addottoreran": "addottorare",
    "addottoreranno": "addottorare",
    "addottorerebbe": "addottorare",
    "addottorerebber": "addottorare",
    "addottorerebbero": "addottorare",
    "addottorerei": "addottorare",
    "addottoreremmo": "addottorare",
    "addottoreremo": "addottorare",
    "addottorereste": "addottorare",
    "addottoreresti": "addottorare",
    "addottorerete": "addottorare",
    "addottorerà": "addottorare",
    "addottorerò": "addottorare",
    "addottori": "addottorare",
    "addottoriamo": "addottorare",
    "addottoriate": "addottorare",
    "addottorin": "addottorare",
    "addottorino": "addottorare",
    "addottoro": "addottorare",
    "addottorò": "addottorare",
    "addottrina": "addottrinare",
    "addottrinai": "addottrinare",
    "addottrinammo": "addottrinare",
    "addottrinan": "addottrinare",
    "addottrinando": "addottrinare",
    "addottrinano": "addottrinare",
    "addottrinante": "addottrinare",
    "addottrinanti": "addottrinare",
    "addottrinar": "addottrinare",
    "addottrinaron": "addottrinare",
    "addottrinarono": "addottrinare",
    "addottrinasse": "addottrinare",
    "addottrinasser": "addottrinare",
    "addottrinassero": "addottrinare",
    "addottrinassi": "addottrinare",
    "addottrinassimo": "addottrinare",
    "addottrinaste": "addottrinare",
    "addottrinasti": "addottrinare",
    "addottrinata": "addottrinare",
    "addottrinate": "addottrinare",
    "addottrinati": "addottrinare",
    "addottrinato": "addottrinare",
    "addottrinava": "addottrinare",
    "addottrinavamo": "addottrinare",
    "addottrinavan": "addottrinare",
    "addottrinavano": "addottrinare",
    "addottrinavate": "addottrinare",
    "addottrinavi": "addottrinare",
    "addottrinavo": "addottrinare",
    "addottrinerai": "addottrinare",
    "addottrineran": "addottrinare",
    "addottrineranno": "addottrinare",
    "addottrinerebbe": "addottrinare",
    "addottrinerebber": "addottrinare",
    "addottrinerebbero": "addottrinare",
    "addottrinerei": "addottrinare",
    "addottrineremmo": "addottrinare",
    "addottrineremo": "addottrinare",
    "addottrinereste": "addottrinare",
    "addottrineresti": "addottrinare",
    "addottrinerete": "addottrinare",
    "addottrinerà": "addottrinare",
    "addottrinerò": "addottrinare",
    "addottrini": "addottrinare",
    "addottriniamo": "addottrinare",
    "addottriniate": "addottrinare",
    "addottrinin": "addottrinare",
    "addottrinino": "addottrinare",
    "addottrino": "addottrinare",
    "addottrinò": "addottrinare",
    "adduca": "addurre",
    "adducan": "addurre",
    "adducano": "addurre",
    "adduce": "addurre",
    "adducemmo": "addurre",
    "adducendo": "addurre",
    "adducente": "addurre",
    "adducenti": "addurre",
    "adducesse": "addurre",
    "adducesser": "addurre",
    "adducessero": "addurre",
    "adducessi": "addurre",
    "adducessimo": "addurre",
    "adduceste": "addurre",
    "adducesti": "addurre",
    "adducete": "addurre",
    "adduceva": "addurre",
    "adducevamo": "addurre",
    "adducevan": "addurre",
    "adducevano": "addurre",
    "adducevate": "addurre",
    "adducevi": "addurre",
    "adducevo": "addurre",
    "adduci": "addurre",
    "adduciamo": "addurre",
    "adduciate": "addurre",
    "adduco": "addurre",
    "adducon": "addurre",
    "adducono": "addurre",
    "addurr": "addurre",
    "addurrai": "addurre",
    "addurran": "addurre",
    "addurranno": "addurre",
    "addurrebbe": "addurre",
    "addurrebber": "addurre",
    "addurrebbero": "addurre",
    "addurrei": "addurre",
    "addurremmo": "addurre",
    "addurremo": "addurre",
    "addurreste": "addurre",
    "addurresti": "addurre",
    "addurrete": "addurre",
    "addurrà": "addurre",
    "addurrò": "addurre",
    "addusse": "addurre",
    "addusser": "addurre",
    "addussero": "addurre",
    "addussi": "addurre",
    "adduttori": "adduttore",
    "adegua": "adeguare",
    "adeguai": "adeguare",
    "adeguamenti": "adeguamento",
    "adeguammo": "adeguare",
    "adeguan": "adeguare",
    "adeguando": "adeguare",
    "adeguano": "adeguare",
    "adeguante": "adeguare",
    "adeguanti": "adeguare",
    "adeguar": "adeguare",
    "adeguaron": "adeguare",
    "adeguarono": "adeguare",
    "adeguasse": "adeguare",
    "adeguasser": "adeguare",
    "adeguassero": "adeguare",
    "adeguassi": "adeguare",
    "adeguassimo": "adeguare",
    "adeguaste": "adeguare",
    "adeguasti": "adeguare",
    "adeguata": "adeguato",
    "adeguate": "adeguato",
    "adeguati": "adeguato",
    "adeguato": "adeguare",
    "adeguava": "adeguare",
    "adeguavamo": "adeguare",
    "adeguavan": "adeguare",
    "adeguavano": "adeguare",
    "adeguavate": "adeguare",
    "adeguavi": "adeguare",
    "adeguavo": "adeguare",
    "adeguerai": "adeguare",
    "adegueran": "adeguare",
    "adegueranno": "adeguare",
    "adeguerebbe": "adeguare",
    "adeguerebber": "adeguare",
    "adeguerebbero": "adeguare",
    "adeguerei": "adeguare",
    "adegueremmo": "adeguare",
    "adegueremo": "adeguare",
    "adeguereste": "adeguare",
    "adegueresti": "adeguare",
    "adeguerete": "adeguare",
    "adeguerà": "adeguare",
    "adeguerò": "adeguare",
    "adegui": "adeguare",
    "adeguiamo": "adeguare",
    "adeguiate": "adeguare",
    "adeguin": "adeguare",
    "adeguino": "adeguare",
    "adeguo": "adeguare",
    "adeguò": "adeguare",
    "adempa": "adempire",
    "adempan": "adempire",
    "adempano": "adempire",
    "adempe": "adempire",
    "adempendo": "adempire",
    "adempente": "adempire",
    "adempenti": "adempire",
    "adempi": "adempire",
    "adempia": "adempiere",
    "adempiamo": "adempire",
    "adempian": "adempiere",
    "adempiano": "adempiere",
    "adempiate": "adempire",
    "adempie": "adempiere",
    "adempiei": "adempiere",
    "adempiemmo": "adempiere",
    "adempiendo": "adempiere",
    "adempiente": "adempiere",
    "adempienti": "adempiere",
    "adempier": "adempiere",
    "adempierai": "adempiere",
    "adempieran": "adempiere",
    "adempieranno": "adempiere",
    "adempierebbe": "adempiere",
    "adempierebber": "adempiere",
    "adempierebbero": "adempiere",
    "adempierei": "adempiere",
    "adempieremmo": "adempiere",
    "adempieremo": "adempiere",
    "adempiereste": "adempiere",
    "adempieresti": "adempiere",
    "adempierete": "adempiere",
    "adempieron": "adempiere",
    "adempierono": "adempiere",
    "adempierà": "adempiere",
    "adempierò": "adempiere",
    "adempiesse": "adempiere",
    "adempiesser": "adempiere",
    "adempiessero": "adempiere",
    "adempiessi": "adempiere",
    "adempiessimo": "adempiere",
    "adempieste": "adempiere",
    "adempiesti": "adempiere",
    "adempiete": "adempiere",
    "adempieva": "adempiere",
    "adempievamo": "adempiere",
    "adempievan": "adempiere",
    "adempievano": "adempiere",
    "adempievate": "adempiere",
    "adempievi": "adempiere",
    "adempievo": "adempiere",
    "adempii": "adempire",
    "adempiiamo": "adempiere",
    "adempiiate": "adempiere",
    "adempimenti": "adempimento",
    "adempimmo": "adempire",
    "adempio": "adempiere",
    "adempion": "adempiere",
    "adempiono": "adempiere",
    "adempir": "adempire",
    "adempirai": "adempire",
    "adempiran": "adempire",
    "adempiranno": "adempire",
    "adempirebbe": "adempire",
    "adempirebber": "adempire",
    "adempirebbero": "adempire",
    "adempirei": "adempire",
    "adempiremmo": "adempire",
    "adempiremo": "adempire",
    "adempireste": "adempire",
    "adempiresti": "adempire",
    "adempirete": "adempire",
    "adempiron": "adempire",
    "adempirono": "adempire",
    "adempirà": "adempire",
    "adempirò": "adempire",
    "adempisse": "adempire",
    "adempisser": "adempire",
    "adempissero": "adempire",
    "adempissi": "adempire",
    "adempissimo": "adempire",
    "adempiste": "adempire",
    "adempisti": "adempire",
    "adempita": "adempito",
    "adempite": "adempito",
    "adempiti": "adempito",
    "adempito": "adempire",
    "adempiuta": "adempiere",
    "adempiute": "adempiere",
    "adempiuti": "adempiere",
    "adempiuto": "adempiere",
    "adempiva": "adempire",
    "adempivamo": "adempire",
    "adempivan": "adempire",
    "adempivano": "adempire",
    "adempivate": "adempire",
    "adempivi": "adempire",
    "adempivo": "adempire",
    "adempiè": "adempiere",
    "adempo": "adempire",
    "adempon": "adempire",
    "adempono": "adempire",
    "adempì": "adempire",
    "adendo": "adire",
    "adente": "adire",
    "adenti": "adire",
    "adepta": "adepto",
    "adepte": "adepto",
    "adepti": "adepto",
    "aderendo": "aderire",
    "aderente": "aderire",
    "aderenti": "aderire",
    "aderenze": "aderenza",
    "aderga": "adergere",
    "adergan": "adergere",
    "adergano": "adergere",
    "aderge": "adergere",
    "adergemmo": "adergere",
    "adergendo": "adergere",
    "adergente": "adergere",
    "adergenti": "adergere",
    "aderger": "adergere",
    "adergerai": "adergere",
    "adergeran": "adergere",
    "adergeranno": "adergere",
    "adergerebbe": "adergere",
    "adergerebber": "adergere",
    "adergerebbero": "adergere",
    "adergerei": "adergere",
    "adergeremmo": "adergere",
    "adergeremo": "adergere",
    "adergereste": "adergere",
    "adergeresti": "adergere",
    "adergerete": "adergere",
    "adergerà": "adergere",
    "adergerò": "adergere",
    "adergesse": "adergere",
    "adergesser": "adergere",
    "adergessero": "adergere",
    "adergessi": "adergere",
    "adergessimo": "adergere",
    "adergeste": "adergere",
    "adergesti": "adergere",
    "adergete": "adergere",
    "adergeva": "adergere",
    "adergevamo": "adergere",
    "adergevan": "adergere",
    "adergevano": "adergere",
    "adergevate": "adergere",
    "adergevi": "adergere",
    "adergevo": "adergere",
    "adergi": "adergere",
    "adergiamo": "adergere",
    "adergiate": "adergere",
    "adergo": "adergere",
    "adergon": "adergere",
    "adergono": "adergere",
    "aderiamo": "aderire",
    "aderiate": "aderire",
    "aderii": "aderire",
    "aderimmo": "aderire",
    "aderir": "aderire",
    "aderirai": "aderire",
    "aderiran": "aderire",
    "aderiranno": "aderire",
    "aderirebbe": "aderire",
    "aderirebber": "aderire",
    "aderirebbero": "aderire",
    "aderirei": "aderire",
    "aderiremmo": "aderire",
    "aderiremo": "aderire",
    "aderireste": "aderire",
    "aderiresti": "aderire",
    "aderirete": "aderire",
    "aderiron": "aderire",
    "aderirono": "aderire",
    "aderirà": "aderire",
    "aderirò": "aderire",
    "aderisca": "aderire",
    "aderiscan": "aderire",
    "aderiscano": "aderire",
    "aderisce": "aderire",
    "aderisci": "aderire",
    "aderisco": "aderire",
    "aderiscon": "aderire",
    "aderiscono": "aderire",
    "aderisse": "aderire",
    "aderisser": "aderire",
    "aderissero": "aderire",
    "aderissi": "aderire",
    "aderissimo": "aderire",
    "aderiste": "aderire",
    "aderisti": "aderire",
    "aderita": "aderire",
    "aderite": "aderire",
    "aderiti": "aderire",
    "aderito": "aderire",
    "aderiva": "aderire",
    "aderivamo": "aderire",
    "aderivan": "aderire",
    "aderivano": "aderire",
    "aderivate": "aderire",
    "aderivi": "aderire",
    "aderivo": "aderire",
    "aderser": "adergere",
    "adersero": "adergere",
    "adersi": "adergere",
    "adersè": "adergere",
    "aderta": "adergere",
    "aderte": "adergere",
    "aderti": "adergere",
    "aderto": "adergere",
    "aderì": "aderire",
    "adesca": "adescare",
    "adescai": "adescare",
    "adescammo": "adescare",
    "adescan": "adescare",
    "adescando": "adescare",
    "adescano": "adescare",
    "adescante": "adescare",
    "adescanti": "adescare",
    "adescar": "adescare",
    "adescaron": "adescare",
    "adescarono": "adescare",
    "adescasse": "adescare",
    "adescasser": "adescare",
    "adescassero": "adescare",
    "adescassi": "adescare",
    "adescassimo": "adescare",
    "adescaste": "adescare",
    "adescasti": "adescare",
    "adescata": "adescare",
    "adescate": "adescare",
    "adescati": "adescare",
    "adescato": "adescare",
    "adescava": "adescare",
    "adescavamo": "adescare",
    "adescavan": "adescare",
    "adescavano": "adescare",
    "adescavate": "adescare",
    "adescavi": "adescare",
    "adescavo": "adescare",
    "adescherai": "adescare",
    "adescheran": "adescare",
    "adescheranno": "adescare",
    "adescherebbe": "adescare",
    "adescherebber": "adescare",
    "adescherebbero": "adescare",
    "adescherei": "adescare",
    "adescheremmo": "adescare",
    "adescheremo": "adescare",
    "adeschereste": "adescare",
    "adescheresti": "adescare",
    "adescherete": "adescare",
    "adescherà": "adescare",
    "adescherò": "adescare",
    "adeschi": "adescare",
    "adeschiamo": "adescare",
    "adeschiate": "adescare",
    "adeschin": "adescare",
    "adeschino": "adescare",
    "adesco": "adescare",
    "adescò": "adescare",
    "adesioni": "adesione",
    "adesiva": "adesivo",
    "adesive": "adesivo",
    "adesivi": "adesivo",
    "adiacenti": "adiacente",
    "adiacenze": "adiacenza",
    "adiamo": "adire",
    "adiate": "adire",
    "adibendo": "adibire",
    "adibente": "adibire",
    "adibenti": "adibire",
    "adibiamo": "adibire",
    "adibiate": "adibire",
    "adibii": "adibire",
    "adibimmo": "adibire",
    "adibir": "adibire",
    "adibirai": "adibire",
    "adibiran": "adibire",
    "adibiranno": "adibire",
    "adibirebbe": "adibire",
    "adibirebber": "adibire",
    "adibirebbero": "adibire",
    "adibirei": "adibire",
    "adibiremmo": "adibire",
    "adibiremo": "adibire",
    "adibireste": "adibire",
    "adibiresti": "adibire",
    "adibirete": "adibire",
    "adibiron": "adibire",
    "adibirono": "adibire",
    "adibirà": "adibire",
    "adibirò": "adibire",
    "adibisca": "adibire",
    "adibiscan": "adibire",
    "adibiscano": "adibire",
    "adibisce": "adibire",
    "adibisci": "adibire",
    "adibisco": "adibire",
    "adibiscon": "adibire",
    "adibiscono": "adibire",
    "adibisse": "adibire",
    "adibisser": "adibire",
    "adibissero": "adibire",
    "adibissi": "adibire",
    "adibissimo": "adibire",
    "adibiste": "adibire",
    "adibisti": "adibire",
    "adibita": "adibire",
    "adibite": "adibire",
    "adibiti": "adibito",
    "adibito": "adibire",
    "adibiva": "adibire",
    "adibivamo": "adibire",
    "adibivan": "adibire",
    "adibivano": "adibire",
    "adibivate": "adibire",
    "adibivi": "adibire",
    "adibivo": "adibire",
    "adibì": "adibire",
    "adii": "adire",
    "adimmo": "adire",
    "adiposa": "adiposo",
    "adipose": "adiposo",
    "adiposi": "adiposo",
    "adir": "adire",
    "adira": "adirare",
    "adirai": "adire",
    "adirammo": "adirare",
    "adiran": "adire",
    "adirando": "adirare",
    "adiranno": "adire",
    "adirano": "adirare",
    "adirar": "adirare",
    "adiraron": "adirare",
    "adirarono": "adirare",
    "adirasse": "adirare",
    "adirasser": "adirare",
    "adirassero": "adirare",
    "adirassi": "adirare",
    "adirassimo": "adirare",
    "adiraste": "adirare",
    "adirasti": "adirare",
    "adirata": "adirare",
    "adirate": "adirare",
    "adirati": "adirare",
    "adirato": "adirare",
    "adirava": "adirare",
    "adiravamo": "adirare",
    "adiravan": "adirare",
    "adiravano": "adirare",
    "adiravate": "adirare",
    "adiravi": "adirare",
    "adiravo": "adirare",
    "adirebbe": "adire",
    "adirebber": "adire",
    "adirebbero": "adire",
    "adirei": "adire",
    "adiremmo": "adire",
    "adiremo": "adire",
    "adirerai": "adirare",
    "adireran": "adirare",
    "adireranno": "adirare",
    "adirerebbe": "adirare",
    "adirerebber": "adirare",
    "adirerebbero": "adirare",
    "adirerei": "adirare",
    "adireremmo": "adirare",
    "adireremo": "adirare",
    "adirereste": "adirare",
    "adireresti": "adirare",
    "adirerete": "adirare",
    "adirerà": "adirare",
    "adirerò": "adirare",
    "adireste": "adire",
    "adiresti": "adire",
    "adirete": "adire",
    "adiri": "adirare",
    "adiriamo": "adirare",
    "adiriate": "adirare",
    "adirin": "adirare",
    "adirino": "adirare",
    "adiro": "adirare",
    "adiron": "adire",
    "adirono": "adire",
    "adirà": "adire",
    "adirò": "adire",
    "adisca": "adire",
    "adiscan": "adire",
    "adiscano": "adire",
    "adisce": "adire",
    "adisci": "adire",
    "adisco": "adire",
    "adiscon": "adire",
    "adiscono": "adire",
    "adisse": "adire",
    "adisser": "adire",
    "adissero": "adire",
    "adissi": "adire",
    "adissimo": "adire",
    "adiste": "adire",
    "adisti": "adire",
    "adita": "adire",
    "adite": "adire",
    "aditi": "adire",
    "adito": "adire",
    "adiva": "adire",
    "adivamo": "adire",
    "adivan": "adire",
    "adivano": "adire",
    "adivate": "adire",
    "adivi": "adire",
    "adivo": "adire",
    "adocchi": "adocchiare",
    "adocchia": "adocchiare",
    "adocchiai": "adocchiare",
    "adocchiammo": "adocchiare",
    "adocchiamo": "adocchiare",
    "adocchian": "adocchiare",
    "adocchiando": "adocchiare",
    "adocchiano": "adocchiare",
    "adocchiante": "adocchiare",
    "adocchianti": "adocchiare",
    "adocchiar": "adocchiare",
    "adocchiaron": "adocchiare",
    "adocchiarono": "adocchiare",
    "adocchiasse": "adocchiare",
    "adocchiasser": "adocchiare",
    "adocchiassero": "adocchiare",
    "adocchiassi": "adocchiare",
    "adocchiassimo": "adocchiare",
    "adocchiaste": "adocchiare",
    "adocchiasti": "adocchiare",
    "adocchiata": "adocchiare",
    "adocchiate": "adocchiare",
    "adocchiati": "adocchiare",
    "adocchiato": "adocchiare",
    "adocchiava": "adocchiare",
    "adocchiavamo": "adocchiare",
    "adocchiavan": "adocchiare",
    "adocchiavano": "adocchiare",
    "adocchiavate": "adocchiare",
    "adocchiavi": "adocchiare",
    "adocchiavo": "adocchiare",
    "adocchierai": "adocchiare",
    "adocchieran": "adocchiare",
    "adocchieranno": "adocchiare",
    "adocchierebbe": "adocchiare",
    "adocchierebber": "adocchiare",
    "adocchierebbero": "adocchiare",
    "adocchierei": "adocchiare",
    "adocchieremmo": "adocchiare",
    "adocchieremo": "adocchiare",
    "adocchiereste": "adocchiare",
    "adocchieresti": "adocchiare",
    "adocchierete": "adocchiare",
    "adocchierà": "adocchiare",
    "adocchierò": "adocchiare",
    "adocchin": "adocchiare",
    "adocchino": "adocchiare",
    "adocchio": "adocchiare",
    "adocchiò": "adocchiare",
    "adolescenti": "adolescente",
    "adolescenze": "adolescenza",
    "adombra": "adombrare",
    "adombrai": "adombrare",
    "adombrammo": "adombrare",
    "adombran": "adombrare",
    "adombrando": "adombrare",
    "adombrano": "adombrare",
    "adombrante": "adombrare",
    "adombranti": "adombrare",
    "adombrar": "adombrare",
    "adombraron": "adombrare",
    "adombrarono": "adombrare",
    "adombrasse": "adombrare",
    "adombrasser": "adombrare",
    "adombrassero": "adombrare",
    "adombrassi": "adombrare",
    "adombrassimo": "adombrare",
    "adombraste": "adombrare",
    "adombrasti": "adombrare",
    "adombrata": "adombrare",
    "adombrate": "adombrare",
    "adombrati": "adombrare",
    "adombrato": "adombrare",
    "adombrava": "adombrare",
    "adombravamo": "adombrare",
    "adombravan": "adombrare",
    "adombravano": "adombrare",
    "adombravate": "adombrare",
    "adombravi": "adombrare",
    "adombravo": "adombrare",
    "adombrerai": "adombrare",
    "adombreran": "adombrare",
    "adombreranno": "adombrare",
    "adombrerebbe": "adombrare",
    "adombrerebber": "adombrare",
    "adombrerebbero": "adombrare",
    "adombrerei": "adombrare",
    "adombreremmo": "adombrare",
    "adombreremo": "adombrare",
    "adombrereste": "adombrare",
    "adombreresti": "adombrare",
    "adombrerete": "adombrare",
    "adombrerà": "adombrare",
    "adombrerò": "adombrare",
    "adombri": "adombrare",
    "adombriamo": "adombrare",
    "adombriate": "adombrare",
    "adombrin": "adombrare",
    "adombrino": "adombrare",
    "adombro": "adombrare",
    "adombrò": "adombrare",
    "adonta": "adontare",
    "adontai": "adontare",
    "adontammo": "adontare",
    "adontan": "adontare",
    "adontando": "adontare",
    "adontano": "adontare",
    "adontar": "adontare",
    "adontaron": "adontare",
    "adontarono": "adontare",
    "adontasse": "adontare",
    "adontasser": "adontare",
    "adontassero": "adontare",
    "adontassi": "adontare",
    "adontassimo": "adontare",
    "adontaste": "adontare",
    "adontasti": "adontare",
    "adontata": "adontare",
    "adontate": "adontare",
    "adontati": "adontare",
    "adontato": "adontare",
    "adontava": "adontare",
    "adontavamo": "adontare",
    "adontavan": "adontare",
    "adontavano": "adontare",
    "adontavate": "adontare",
    "adontavi": "adontare",
    "adontavo": "adontare",
    "adonterai": "adontare",
    "adonteran": "adontare",
    "adonteranno": "adontare",
    "adonterebbe": "adontare",
    "adonterebber": "adontare",
    "adonterebbero": "adontare",
    "adonterei": "adontare",
    "adonteremmo": "adontare",
    "adonteremo": "adontare",
    "adontereste": "adontare",
    "adonteresti": "adontare",
    "adonterete": "adontare",
    "adonterà": "adontare",
    "adonterò": "adontare",
    "adonti": "adontare",
    "adontiamo": "adontare",
    "adontiate": "adontare",
    "adontin": "adontare",
    "adontino": "adontare",
    "adonto": "adontare",
    "adontò": "adontare",
    "adopera": "adoperare",
    "adoperai": "adoperare",
    "adoperammo": "adoperare",
    "adoperan": "adoperare",
    "adoperando": "adoperare",
    "adoperano": "adoperare",
    "adoperante": "adoperare",
    "adoperanti": "adoperare",
    "adoperar": "adoperare",
    "adoperaron": "adoperare",
    "adoperarono": "adoperare",
    "adoperasse": "adoperare",
    "adoperasser": "adoperare",
    "adoperassero": "adoperare",
    "adoperassi": "adoperare",
    "adoperassimo": "adoperare",
    "adoperaste": "adoperare",
    "adoperasti": "adoperare",
    "adoperata": "adoperare",
    "adoperate": "adoperare",
    "adoperati": "adoperare",
    "adoperato": "adoperare",
    "adoperava": "adoperare",
    "adoperavamo": "adoperare",
    "adoperavan": "adoperare",
    "adoperavano": "adoperare",
    "adoperavate": "adoperare",
    "adoperavi": "adoperare",
    "adoperavo": "adoperare",
    "adopererai": "adoperare",
    "adopereran": "adoperare",
    "adopereranno": "adoperare",
    "adopererebbe": "adoperare",
    "adopererebber": "adoperare",
    "adopererebbero": "adoperare",
    "adopererei": "adoperare",
    "adopereremmo": "adoperare",
    "adopereremo": "adoperare",
    "adoperereste": "adoperare",
    "adopereresti": "adoperare",
    "adopererete": "adoperare",
    "adopererà": "adoperare",
    "adopererò": "adoperare",
    "adoperi": "adoperare",
    "adoperiamo": "adoperare",
    "adoperiate": "adoperare",
    "adoperin": "adoperare",
    "adoperino": "adoperare",
    "adopero": "adoperare",
    "adoperò": "adoperare",
    "adopra": "adoprare",
    "adoprai": "adoprare",
    "adoprammo": "adoprare",
    "adopran": "adoprare",
    "adoprando": "adoprare",
    "adoprano": "adoprare",
    "adoprante": "adoprare",
    "adopranti": "adoprare",
    "adoprar": "adoprare",
    "adopraron": "adoprare",
    "adoprarono": "adoprare",
    "adoprasse": "adoprare",
    "adoprasser": "adoprare",
    "adoprassero": "adoprare",
    "adoprassi": "adoprare",
    "adoprassimo": "adoprare",
    "adopraste": "adoprare",
    "adoprasti": "adoprare",
    "adoprata": "adoprare",
    "adoprate": "adoprare",
    "adoprati": "adoprare",
    "adoprato": "adoprare",
    "adoprava": "adoprare",
    "adopravamo": "adoprare",
    "adopravan": "adoprare",
    "adopravano": "adoprare",
    "adopravate": "adoprare",
    "adopravi": "adoprare",
    "adopravo": "adoprare",
    "adoprerai": "adoprare",
    "adopreran": "adoprare",
    "adopreranno": "adoprare",
    "adoprerebbe": "adoprare",
    "adoprerebber": "adoprare",
    "adoprerebbero": "adoprare",
    "adoprerei": "adoprare",
    "adopreremmo": "adoprare",
    "adopreremo": "adoprare",
    "adoprereste": "adoprare",
    "adopreresti": "adoprare",
    "adoprerete": "adoprare",
    "adoprerà": "adoprare",
    "adoprerò": "adoprare",
    "adopri": "adoprare",
    "adopriamo": "adoprare",
    "adopriate": "adoprare",
    "adoprin": "adoprare",
    "adoprino": "adoprare",
    "adopro": "adoprare",
    "adoprò": "adoprare",
    "adora": "adorare",
    "adorabili": "adorabile",
    "adorai": "adorare",
    "adorammo": "adorare",
    "adoran": "adorare",
    "adorando": "adorare",
    "adorano": "adorare",
    "adorante": "adorare",
    "adoranti": "adorare",
    "adorar": "adorare",
    "adoraron": "adorare",
    "adorarono": "adorare",
    "adorasse": "adorare",
    "adorasser": "adorare",
    "adorassero": "adorare",
    "adorassi": "adorare",
    "adorassimo": "adorare",
    "adoraste": "adorare",
    "adorasti": "adorare",
    "adorata": "adorare",
    "adorate": "adorare",
    "adorati": "adorato",
    "adorato": "adorare",
    "adoratori": "adoratore",
    "adorava": "adorare",
    "adoravamo": "adorare",
    "adoravan": "adorare",
    "adoravano": "adorare",
    "adoravate": "adorare",
    "adoravi": "adorare",
    "adoravo": "adorare",
    "adorazioni": "adorazione",
    "adorerai": "adorare",
    "adoreran": "adorare",
    "adoreranno": "adorare",
    "adorerebbe": "adorare",
    "adorerebber": "adorare",
    "adorerebbero": "adorare",
    "adorerei": "adorare",
    "adoreremmo": "adorare",
    "adoreremo": "adorare",
    "adorereste": "adorare",
    "adoreresti": "adorare",
    "adorerete": "adorare",
    "adorerà": "adorare",
    "adorerò": "adorare",
    "adori": "adorare",
    "adoriamo": "adorare",
    "adoriate": "adorare",
    "adorin": "adorare",
    "adorino": "adorare",
    "adorna": "adorno",
    "adornai": "adornare",
    "adornammo": "adornare",
    "adornan": "adornare",
    "adornando": "adornare",
    "adornano": "adornare",
    "adornante": "adornare",
    "adornanti": "adornare",
    "adornar": "adornare",
    "adornaron": "adornare",
    "adornarono": "adornare",
    "adornasse": "adornare",
    "adornasser": "adornare",
    "adornassero": "adornare",
    "adornassi": "adornare",
    "adornassimo": "adornare",
    "adornaste": "adornare",
    "adornasti": "adornare",
    "adornata": "adornare",
    "adornate": "adornare",
    "adornati": "adornare",
    "adornato": "adornare",
    "adornava": "adornare",
    "adornavamo": "adornare",
    "adornavan": "adornare",
    "adornavano": "adornare",
    "adornavate": "adornare",
    "adornavi": "adornare",
    "adornavo": "adornare",
    "adorne": "adorno",
    "adornerai": "adornare",
    "adorneran": "adornare",
    "adorneranno": "adornare",
    "adornerebbe": "adornare",
    "adornerebber": "adornare",
    "adornerebbero": "adornare",
    "adornerei": "adornare",
    "adorneremmo": "adornare",
    "adorneremo": "adornare",
    "adornereste": "adornare",
    "adorneresti": "adornare",
    "adornerete": "adornare",
    "adornerà": "adornare",
    "adornerò": "adornare",
    "adorni": "adorno",
    "adorniamo": "adornare",
    "adorniate": "adornare",
    "adornin": "adornare",
    "adornino": "adornare",
    "adorno": "adornare",
    "adornò": "adornare",
    "adoro": "adorare",
    "adorò": "adorare",
    "adotta": "adottare",
    "adottabili": "adottabile",
    "adottai": "adottare",
    "adottammo": "adottare",
    "adottan": "adottare",
    "adottando": "adottare",
    "adottano": "adottare",
    "adottante": "adottare",
    "adottanti": "adottare",
    "adottar": "adottare",
    "adottaron": "adottare",
    "adottarono": "adottare",
    "adottasse": "adottare",
    "adottasser": "adottare",
    "adottassero": "adottare",
    "adottassi": "adottare",
    "adottassimo": "adottare",
    "adottaste": "adottare",
    "adottasti": "adottare",
    "adottata": "adottato",
    "adottate": "adottato",
    "adottati": "adottato",
    "adottato": "adottare",
    "adottava": "adottare",
    "adottavamo": "adottare",
    "adottavan": "adottare",
    "adottavano": "adottare",
    "adottavate": "adottare",
    "adottavi": "adottare",
    "adottavo": "adottare",
    "adotterai": "adottare",
    "adotteran": "adottare",
    "adotteranno": "adottare",
    "adotterebbe": "adottare",
    "adotterebber": "adottare",
    "adotterebbero": "adottare",
    "adotterei": "adottare",
    "adotteremmo": "adottare",
    "adotteremo": "adottare",
    "adottereste": "adottare",
    "adotteresti": "adottare",
    "adotterete": "adottare",
    "adotterà": "adottare",
    "adotterò": "adottare",
    "adotti": "adottare",
    "adottiamo": "adottare",
    "adottiate": "adottare",
    "adottin": "adottare",
    "adottino": "adottare",
    "adottiva": "adottivo",
    "adottive": "adottivo",
    "adottivi": "adottivo",
    "adotto": "adottare",
    "adottò": "adottare",
    "adozioni": "adozione",
    "adrianea": "adrianeo",
    "adrianee": "adrianeo",
    "adrianei": "adrianeo",
    "adriatica": "adriatico",
    "adriatiche": "adriatico",
    "adriatici": "adriatico",
    "aduggerai": "aduggiare",
    "aduggeran": "aduggiare",
    "aduggeranno": "aduggiare",
    "aduggerebbe": "aduggiare",
    "aduggerebber": "aduggiare",
    "aduggerebbero": "aduggiare",
    "aduggerei": "aduggiare",
    "aduggeremmo": "aduggiare",
    "aduggeremo": "aduggiare",
    "aduggereste": "aduggiare",
    "aduggeresti": "aduggiare",
    "aduggerete": "aduggiare",
    "aduggerà": "aduggiare",
    "aduggerò": "aduggiare",
    "aduggi": "aduggiare",
    "aduggia": "aduggiare",
    "aduggiai": "aduggiare",
    "aduggiammo": "aduggiare",
    "aduggiamo": "aduggiare",
    "aduggian": "aduggiare",
    "aduggiando": "aduggiare",
    "aduggiano": "aduggiare",
    "aduggiante": "aduggiare",
    "aduggianti": "aduggiare",
    "aduggiar": "aduggiare",
    "aduggiaron": "aduggiare",
    "aduggiarono": "aduggiare",
    "aduggiasse": "aduggiare",
    "aduggiasser": "aduggiare",
    "aduggiassero": "aduggiare",
    "aduggiassi": "aduggiare",
    "aduggiassimo": "aduggiare",
    "aduggiaste": "aduggiare",
    "aduggiasti": "aduggiare",
    "aduggiata": "aduggiare",
    "aduggiate": "aduggiare",
    "aduggiati": "aduggiare",
    "aduggiato": "aduggiare",
    "aduggiava": "aduggiare",
    "aduggiavamo": "aduggiare",
    "aduggiavan": "aduggiare",
    "aduggiavano": "aduggiare",
    "aduggiavate": "aduggiare",
    "aduggiavi": "aduggiare",
    "aduggiavo": "aduggiare",
    "aduggin": "aduggiare",
    "aduggino": "aduggiare",
    "aduggio": "aduggiare",
    "aduggiò": "aduggiare",
    "adula": "adulare",
    "adulai": "adulare",
    "adulammo": "adulare",
    "adulan": "adulare",
    "adulando": "adulare",
    "adulano": "adulare",
    "adulante": "adulare",
    "adulanti": "adulare",
    "adular": "adulare",
    "adularon": "adulare",
    "adularono": "adulare",
    "adulasse": "adulare",
    "adulasser": "adulare",
    "adulassero": "adulare",
    "adulassi": "adulare",
    "adulassimo": "adulare",
    "adulaste": "adulare",
    "adulasti": "adulare",
    "adulata": "adulare",
    "adulate": "adulare",
    "adulati": "adulare",
    "adulato": "adulare",
    "adulatori": "adulatorio",
    "adulatoria": "adulatorio",
    "adulatorie": "adulatorio",
    "adulava": "adulare",
    "adulavamo": "adulare",
    "adulavan": "adulare",
    "adulavano": "adulare",
    "adulavate": "adulare",
    "adulavi": "adulare",
    "adulavo": "adulare",
    "adulazioni": "adulazione",
    "adulerai": "adulare",
    "aduleran": "adulare",
    "aduleranno": "adulare",
    "adulerebbe": "adulare",
    "adulerebber": "adulare",
    "adulerebbero": "adulare",
    "adulerei": "adulare",
    "aduleremmo": "adulare",
    "aduleremo": "adulare",
    "adulereste": "adulare",
    "aduleresti": "adulare",
    "adulerete": "adulare",
    "adulerà": "adulare",
    "adulerò": "adulare",
    "aduli": "adulare",
    "aduliamo": "adulare",
    "aduliate": "adulare",
    "adulin": "adulare",
    "adulino": "adulare",
    "adulo": "adulare",
    "adulta": "adulto",
    "adulte": "adulto",
    "adultera": "adultero",
    "adulterai": "adulterare",
    "adulterammo": "adulterare",
    "adulteran": "adulterare",
    "adulterando": "adulterare",
    "adulterano": "adulterare",
    "adulterante": "adulterare",
    "adulteranti": "adulterare",
    "adulterar": "adulterare",
    "adulteraron": "adulterare",
    "adulterarono": "adulterare",
    "adulterasse": "adulterare",
    "adulterasser": "adulterare",
    "adulterassero": "adulterare",
    "adulterassi": "adulterare",
    "adulterassimo": "adulterare",
    "adulteraste": "adulterare",
    "adulterasti": "adulterare",
    "adulterata": "adulterare",
    "adulterate": "adulterare",
    "adulterati": "adulterare",
    "adulterato": "adulterare",
    "adulterava": "adulterare",
    "adulteravamo": "adulterare",
    "adulteravan": "adulterare",
    "adulteravano": "adulterare",
    "adulteravate": "adulterare",
    "adulteravi": "adulterare",
    "adulteravo": "adulterare",
    "adultere": "adultero",
    "adultererai": "adulterare",
    "adultereran": "adulterare",
    "adultereranno": "adulterare",
    "adultererebbe": "adulterare",
    "adultererebber": "adulterare",
    "adultererebbero": "adulterare",
    "adultererei": "adulterare",
    "adultereremmo": "adulterare",
    "adultereremo": "adulterare",
    "adulterereste": "adulterare",
    "adultereresti": "adulterare",
    "adultererete": "adulterare",
    "adultererà": "adulterare",
    "adultererò": "adulterare",
    "adulteri": "adultero",
    "adulteriamo": "adulterare",
    "adulteriate": "adulterare",
    "adulterin": "adulterare",
    "adulterina": "adulterino",
    "adulterine": "adulterino",
    "adulterini": "adulterino",
    "adulterino": "adulterare",
    "adultero": "adulterare",
    "adulterò": "adulterare",
    "adulti": "adulto",
    "adulò": "adulare",
    "aduna": "adunare",
    "adunai": "adunare",
    "adunammo": "adunare",
    "adunan": "adunare",
    "adunando": "adunare",
    "adunano": "adunare",
    "adunante": "adunare",
    "adunanti": "adunare",
    "adunanze": "adunanza",
    "adunar": "adunare",
    "adunaron": "adunare",
    "adunarono": "adunare",
    "adunasse": "adunare",
    "adunasser": "adunare",
    "adunassero": "adunare",
    "adunassi": "adunare",
    "adunassimo": "adunare",
    "adunaste": "adunare",
    "adunasti": "adunare",
    "adunata": "adunare",
    "adunate": "adunata",
    "adunati": "adunare",
    "adunato": "adunare",
    "adunava": "adunare",
    "adunavamo": "adunare",
    "adunavan": "adunare",
    "adunavano": "adunare",
    "adunavate": "adunare",
    "adunavi": "adunare",
    "adunavo": "adunare",
    "adunca": "adunco",
    "adunche": "adunco",
    "adunchi": "adunco",
    "adunerai": "adunare",
    "aduneran": "adunare",
    "aduneranno": "adunare",
    "adunerebbe": "adunare",
    "adunerebber": "adunare",
    "adunerebbero": "adunare",
    "adunerei": "adunare",
    "aduneremmo": "adunare",
    "aduneremo": "adunare",
    "adunereste": "adunare",
    "aduneresti": "adunare",
    "adunerete": "adunare",
    "adunerà": "adunare",
    "adunerò": "adunare",
    "aduni": "adunare",
    "aduniamo": "adunare",
    "aduniate": "adunare",
    "adunin": "adunare",
    "adunino": "adunare",
    "aduno": "adunare",
    "adunò": "adunare",
    "adusa": "aduso",
    "adusai": "adusare",
    "adusammo": "adusare",
    "adusan": "adusare",
    "adusando": "adusare",
    "adusano": "adusare",
    "adusante": "adusare",
    "adusanti": "adusare",
    "adusar": "adusare",
    "adusaron": "adusare",
    "adusarono": "adusare",
    "adusasse": "adusare",
    "adusasser": "adusare",
    "adusassero": "adusare",
    "adusassi": "adusare",
    "adusassimo": "adusare",
    "adusaste": "adusare",
    "adusasti": "adusare",
    "adusata": "adusare",
    "adusate": "adusare",
    "adusati": "adusare",
    "adusato": "adusare",
    "adusava": "adusare",
    "adusavamo": "adusare",
    "adusavan": "adusare",
    "adusavano": "adusare",
    "adusavate": "adusare",
    "adusavi": "adusare",
    "adusavo": "adusare",
    "aduse": "aduso",
    "aduserai": "adusare",
    "aduseran": "adusare",
    "aduseranno": "adusare",
    "aduserebbe": "adusare",
    "aduserebber": "adusare",
    "aduserebbero": "adusare",
    "aduserei": "adusare",
    "aduseremmo": "adusare",
    "aduseremo": "adusare",
    "adusereste": "adusare",
    "aduseresti": "adusare",
    "aduserete": "adusare",
    "aduserà": "adusare",
    "aduserò": "adusare",
    "adusi": "aduso",
    "adusiamo": "adusare",
    "adusiate": "adusare",
    "adusin": "adusare",
    "adusino": "adusare",
    "aduso": "adusare",
    "adusò": "adusare",
    "adì": "adire",
    "aera": "aerare",
    "aerai": "aerare",
    "aerammo": "aerare",
    "aeran": "aerare",
    "aerando": "aerare",
    "aerano": "aerare",
    "aerante": "aerare",
    "aeranti": "aerare",
    "aerar": "aerare",
    "aeraron": "aerare",
    "aerarono": "aerare",
    "aerasse": "aerare",
    "aerasser": "aerare",
    "aerassero": "aerare",
    "aerassi": "aerare",
    "aerassimo": "aerare",
    "aeraste": "aerare",
    "aerasti": "aerare",
    "aerata": "aerare",
    "aerate": "aerare",
    "aerati": "aerare",
    "aerato": "aerare",
    "aerava": "aerare",
    "aeravamo": "aerare",
    "aeravan": "aerare",
    "aeravano": "aerare",
    "aeravate": "aerare",
    "aeravi": "aerare",
    "aeravo": "aerare",
    "aerea": "aereo",
    "aeree": "aereo",
    "aerei": "aereo",
    "aereoplani": "aereoplano",
    "aereoporti": "aereoporto",
    "aererai": "aerare",
    "aereran": "aerare",
    "aereranno": "aerare",
    "aererebbe": "aerare",
    "aererebber": "aerare",
    "aererebbero": "aerare",
    "aererei": "aerare",
    "aereremmo": "aerare",
    "aereremo": "aerare",
    "aerereste": "aerare",
    "aereresti": "aerare",
    "aererete": "aerare",
    "aererà": "aerare",
    "aererò": "aerare",
    "aeri": "aerare",
    "aeriamo": "aerare",
    "aeriate": "aerare",
    "aerin": "aerare",
    "aerino": "aerare",
    "aero": "aerare",
    "aerobica": "aerobico",
    "aerobiche": "aerobico",
    "aerobici": "aerobico",
    "aerodinamica": "aerodinamico",
    "aerodinamiche": "aerodinamico",
    "aerodinamici": "aerodinamico",
    "aeromobili": "aeromobile",
    "aeronautica": "aeronautico",
    "aeronautiche": "aeronautico",
    "aeronautici": "aeronautico",
    "aeronavali": "aeronavale",
    "aeroplani": "aeroplano",
    "aeroplanini": "aeroplanino",
    "aeroporti": "aeroporto",
    "aeroportuali": "aeroportuale",
    "aeropostali": "aeropostale",
    "aerospaziali": "aerospaziale",
    "aerostatica": "aerostatico",
    "aerostatiche": "aerostatico",
    "aerostatici": "aerostatico",
    "aerostazioni": "aerostazione",
    "aerotrasporta": "aerotrasportare",
    "aerotrasportai": "aerotrasportare",
    "aerotrasportammo": "aerotrasportare",
    "aerotrasportan": "aerotrasportare",
    "aerotrasportando": "aerotrasportare",
    "aerotrasportano": "aerotrasportare",
    "aerotrasportante": "aerotrasportare",
    "aerotrasportanti": "aerotrasportare",
    "aerotrasportar": "aerotrasportare",
    "aerotrasportaron": "aerotrasportare",
    "aerotrasportarono": "aerotrasportare",
    "aerotrasportasse": "aerotrasportare",
    "aerotrasportasser": "aerotrasportare",
    "aerotrasportassero": "aerotrasportare",
    "aerotrasportassi": "aerotrasportare",
    "aerotrasportassimo": "aerotrasportare",
    "aerotrasportaste": "aerotrasportare",
    "aerotrasportasti": "aerotrasportare",
    "aerotrasportata": "aerotrasportare",
    "aerotrasportate": "aerotrasportare",
    "aerotrasportati": "aerotrasportare",
    "aerotrasportato": "aerotrasportare",
    "aerotrasportava": "aerotrasportare",
    "aerotrasportavamo": "aerotrasportare",
    "aerotrasportavan": "aerotrasportare",
    "aerotrasportavano": "aerotrasportare",
    "aerotrasportavate": "aerotrasportare",
    "aerotrasportavi": "aerotrasportare",
    "aerotrasportavo": "aerotrasportare",
    "aerotrasporterai": "aerotrasportare",
    "aerotrasporteran": "aerotrasportare",
    "aerotrasporteranno": "aerotrasportare",
    "aerotrasporterebbe": "aerotrasportare",
    "aerotrasporterebber": "aerotrasportare",
    "aerotrasporterebbero": "aerotrasportare",
    "aerotrasporterei": "aerotrasportare",
    "aerotrasporteremmo": "aerotrasportare",
    "aerotrasporteremo": "aerotrasportare",
    "aerotrasportereste": "aerotrasportare",
    "aerotrasporteresti": "aerotrasportare",
    "aerotrasporterete": "aerotrasportare",
    "aerotrasporterà": "aerotrasportare",
    "aerotrasporterò": "aerotrasportare",
    "aerotrasporti": "aerotrasportare",
    "aerotrasportiamo": "aerotrasportare",
    "aerotrasportiate": "aerotrasportare",
    "aerotrasportin": "aerotrasportare",
    "aerotrasportino": "aerotrasportare",
    "aerotrasporto": "aerotrasportare",
    "aerotrasportò": "aerotrasportare",
    "aerovie": "aerovia",
    "aerò": "aerare",
    "afasie": "afasia",
    "afe": "afa",
    "affa": "affare",
    "affabili": "affabile",
    "affabula": "affabulare",
    "affabulai": "affabulare",
    "affabulammo": "affabulare",
    "affabulan": "affabulare",
    "affabulando": "affabulare",
    "affabulano": "affabulare",
    "affabulante": "affabulare",
    "affabulanti": "affabulare",
    "affabular": "affabulare",
    "affabularon": "affabulare",
    "affabularono": "affabulare",
    "affabulasse": "affabulare",
    "affabulasser": "affabulare",
    "affabulassero": "affabulare",
    "affabulassi": "affabulare",
    "affabulassimo": "affabulare",
    "affabulaste": "affabulare",
    "affabulasti": "affabulare",
    "affabulata": "affabulato",
    "affabulate": "affabulato",
    "affabulati": "affabulato",
    "affabulato": "affabulare",
    "affabulatori": "affabulatore",
    "affabulava": "affabulare",
    "affabulavamo": "affabulare",
    "affabulavan": "affabulare",
    "affabulavano": "affabulare",
    "affabulavate": "affabulare",
    "affabulavi": "affabulare",
    "affabulavo": "affabulare",
    "affabulazioni": "affabulazione",
    "affabulerai": "affabulare",
    "affabuleran": "affabulare",
    "affabuleranno": "affabulare",
    "affabulerebbe": "affabulare",
    "affabulerebber": "affabulare",
    "affabulerebbero": "affabulare",
    "affabulerei": "affabulare",
    "affabuleremmo": "affabulare",
    "affabuleremo": "affabulare",
    "affabulereste": "affabulare",
    "affabuleresti": "affabulare",
    "affabulerete": "affabulare",
    "affabulerà": "affabulare",
    "affabulerò": "affabulare",
    "affabuli": "affabulare",
    "affabuliamo": "affabulare",
    "affabuliate": "affabulare",
    "affabulin": "affabulare",
    "affabulino": "affabulare",
    "affabulo": "affabulare",
    "affabulò": "affabulare",
    "affaccenda": "affaccendare",
    "affaccendai": "affaccendare",
    "affaccendammo": "affaccendare",
    "affaccendan": "affaccendare",
    "affaccendando": "affaccendare",
    "affaccendano": "affaccendare",
    "affaccendante": "affaccendare",
    "affaccendanti": "affaccendare",
    "affaccendar": "affaccendare",
    "affaccendaron": "affaccendare",
    "affaccendarono": "affaccendare",
    "affaccendasse": "affaccendare",
    "affaccendasser": "affaccendare",
    "affaccendassero": "affaccendare",
    "affaccendassi": "affaccendare",
    "affaccendassimo": "affaccendare",
    "affaccendaste": "affaccendare",
    "affaccendasti": "affaccendare",
    "affaccendata": "affaccendato",
    "affaccendate": "affaccendato",
    "affaccendati": "affaccendato",
    "affaccendato": "affaccendare",
    "affaccendava": "affaccendare",
    "affaccendavamo": "affaccendare",
    "affaccendavan": "affaccendare",
    "affaccendavano": "affaccendare",
    "affaccendavate": "affaccendare",
    "affaccendavi": "affaccendare",
    "affaccendavo": "affaccendare",
    "affaccenderai": "affaccendare",
    "affaccenderan": "affaccendare",
    "affaccenderanno": "affaccendare",
    "affaccenderebbe": "affaccendare",
    "affaccenderebber": "affaccendare",
    "affaccenderebbero": "affaccendare",
    "affaccenderei": "affaccendare",
    "affaccenderemmo": "affaccendare",
    "affaccenderemo": "affaccendare",
    "affaccendereste": "affaccendare",
    "affaccenderesti": "affaccendare",
    "affaccenderete": "affaccendare",
    "affaccenderà": "affaccendare",
    "affaccenderò": "affaccendare",
    "affaccendi": "affaccendare",
    "affaccendiamo": "affaccendare",
    "affaccendiate": "affaccendare",
    "affaccendin": "affaccendare",
    "affaccendino": "affaccendare",
    "affaccendo": "affaccendare",
    "affaccendò": "affaccendare",
    "affaccerai": "affacciare",
    "affacceran": "affacciare",
    "affacceranno": "affacciare",
    "affaccerebbe": "affacciare",
    "affaccerebber": "affacciare",
    "affaccerebbero": "affacciare",
    "affaccerei": "affacciare",
    "affacceremmo": "affacciare",
    "affacceremo": "affacciare",
    "affaccereste": "affacciare",
    "affacceresti": "affacciare",
    "affaccerete": "affacciare",
    "affaccerà": "affacciare",
    "affaccerò": "affacciare",
    "affacci": "affacciare",
    "affaccia": "affacciare",
    "affacciai": "affacciare",
    "affacciammo": "affacciare",
    "affacciamo": "affacciare",
    "affaccian": "affacciare",
    "affacciando": "affacciare",
    "affacciano": "affacciare",
    "affacciante": "affacciare",
    "affaccianti": "affacciare",
    "affacciar": "affacciare",
    "affacciaron": "affacciare",
    "affacciarono": "affacciare",
    "affacciasse": "affacciare",
    "affacciasser": "affacciare",
    "affacciassero": "affacciare",
    "affacciassi": "affacciare",
    "affacciassimo": "affacciare",
    "affacciaste": "affacciare",
    "affacciasti": "affacciare",
    "affacciata": "affacciato",
    "affacciate": "affacciato",
    "affacciati": "affacciato",
    "affacciato": "affacciare",
    "affacciava": "affacciare",
    "affacciavamo": "affacciare",
    "affacciavan": "affacciare",
    "affacciavano": "affacciare",
    "affacciavate": "affacciare",
    "affacciavi": "affacciare",
    "affacciavo": "affacciare",
    "affaccin": "affacciare",
    "affaccino": "affacciare",
    "affaccio": "affacciare",
    "affacciò": "affacciare",
    "affai": "affare",
    "affaires": "affaire",
    "affama": "affamare",
    "affamai": "affamare",
    "affamammo": "affamare",
    "affaman": "affamare",
    "affamando": "affamare",
    "affamano": "affamare",
    "affamante": "affamare",
    "affamanti": "affamare",
    "affamar": "affamare",
    "affamaron": "affamare",
    "affamarono": "affamare",
    "affamasse": "affamare",
    "affamasser": "affamare",
    "affamassero": "affamare",
    "affamassi": "affamare",
    "affamassimo": "affamare",
    "affamaste": "affamare",
    "affamasti": "affamare",
    "affamata": "affamato",
    "affamate": "affamato",
    "affamati": "affamato",
    "affamato": "affamare",
    "affamava": "affamare",
    "affamavamo": "affamare",
    "affamavan": "affamare",
    "affamavano": "affamare",
    "affamavate": "affamare",
    "affamavi": "affamare",
    "affamavo": "affamare",
    "affamerai": "affamare",
    "affameran": "affamare",
    "affameranno": "affamare",
    "affamerebbe": "affamare",
    "affamerebber": "affamare",
    "affamerebbero": "affamare",
    "affamerei": "affamare",
    "affameremmo": "affamare",
    "affameremo": "affamare",
    "affamereste": "affamare",
    "affameresti": "affamare",
    "affamerete": "affamare",
    "affamerà": "affamare",
    "affamerò": "affamare",
    "affami": "affamare",
    "affamiamo": "affamare",
    "affamiate": "affamare",
    "affamin": "affamare",
    "affamino": "affamare",
    "affammo": "affare",
    "affamo": "affamare",
    "affamò": "affamare",
    "affan": "affare",
    "affando": "affare",
    "affanna": "affannare",
    "affannai": "affannare",
    "affannammo": "affannare",
    "affannan": "affannare",
    "affannando": "affannare",
    "affannano": "affannare",
    "affannante": "affannare",
    "affannanti": "affannare",
    "affannar": "affannare",
    "affannaron": "affannare",
    "affannarono": "affannare",
    "affannasse": "affannare",
    "affannasser": "affannare",
    "affannassero": "affannare",
    "affannassi": "affannare",
    "affannassimo": "affannare",
    "affannaste": "affannare",
    "affannasti": "affannare",
    "affannata": "affannato",
    "affannate": "affannato",
    "affannati": "affannato",
    "affannato": "affannare",
    "affannava": "affannare",
    "affannavamo": "affannare",
    "affannavan": "affannare",
    "affannavano": "affannare",
    "affannavate": "affannare",
    "affannavi": "affannare",
    "affannavo": "affannare",
    "affannerai": "affannare",
    "affanneran": "affannare",
    "affanneranno": "affannare",
    "affannerebbe": "affannare",
    "affannerebber": "affannare",
    "affannerebbero": "affannare",
    "affannerei": "affannare",
    "affanneremmo": "affannare",
    "affanneremo": "affannare",
    "affannereste": "affannare",
    "affanneresti": "affannare",
    "affannerete": "affannare",
    "affannerà": "affannare",
    "affannerò": "affannare",
    "affanni": "affanno",
    "affanniamo": "affannare",
    "affanniate": "affannare",
    "affannin": "affannare",
    "affannino": "affannare",
    "affanno": "affannare",
    "affannosa": "affannoso",
    "affannose": "affannoso",
    "affannosi": "affannoso",
    "affannò": "affannare",
    "affano": "affare",
    "affar": "affare",
    "affardella": "affardellare",
    "affardellai": "affardellare",
    "affardellammo": "affardellare",
    "affardellan": "affardellare",
    "affardellando": "affardellare",
    "affardellano": "affardellare",
    "affardellante": "affardellare",
    "affardellanti": "affardellare",
    "affardellar": "affardellare",
    "affardellaron": "affardellare",
    "affardellarono": "affardellare",
    "affardellasse": "affardellare",
    "affardellasser": "affardellare",
    "affardellassero": "affardellare",
    "affardellassi": "affardellare",
    "affardellassimo": "affardellare",
    "affardellaste": "affardellare",
    "affardellasti": "affardellare",
    "affardellata": "affardellare",
    "affardellate": "affardellare",
    "affardellati": "affardellare",
    "affardellato": "affardellare",
    "affardellava": "affardellare",
    "affardellavamo": "affardellare",
    "affardellavan": "affardellare",
    "affardellavano": "affardellare",
    "affardellavate": "affardellare",
    "affardellavi": "affardellare",
    "affardellavo": "affardellare",
    "affardellerai": "affardellare",
    "affardelleran": "affardellare",
    "affardelleranno": "affardellare",
    "affardellerebbe": "affardellare",
    "affardellerebber": "affardellare",
    "affardellerebbero": "affardellare",
    "affardellerei": "affardellare",
    "affardelleremmo": "affardellare",
    "affardelleremo": "affardellare",
    "affardellereste": "affardellare",
    "affardelleresti": "affardellare",
    "affardellerete": "affardellare",
    "affardellerà": "affardellare",
    "affardellerò": "affardellare",
    "affardelli": "affardellare",
    "affardelliamo": "affardellare",
    "affardelliate": "affardellare",
    "affardellin": "affardellare",
    "affardellino": "affardellare",
    "affardello": "affardellare",
    "affardellò": "affardellare",
    "affari": "affare",
    "affaristi": "affarista",
    "affaristica": "affaristico",
    "affaristiche": "affaristico",
    "affaristici": "affaristico",
    "affaron": "affare",
    "affarono": "affare",
    "affarucci": "affaruccio",
    "affascina": "affascinare",
    "affascinai": "affascinare",
    "affascinammo": "affascinare",
    "affascinan": "affascinare",
    "affascinando": "affascinare",
    "affascinano": "affascinare",
    "affascinante": "affascinare",
    "affascinanti": "affascinare",
    "affascinar": "affascinare",
    "affascinaron": "affascinare",
    "affascinarono": "affascinare",
    "affascinasse": "affascinare",
    "affascinasser": "affascinare",
    "affascinassero": "affascinare",
    "affascinassi": "affascinare",
    "affascinassimo": "affascinare",
    "affascinaste": "affascinare",
    "affascinasti": "affascinare",
    "affascinata": "affascinare",
    "affascinate": "affascinare",
    "affascinati": "affascinare",
    "affascinato": "affascinare",
    "affascinava": "affascinare",
    "affascinavamo": "affascinare",
    "affascinavan": "affascinare",
    "affascinavano": "affascinare",
    "affascinavate": "affascinare",
    "affascinavi": "affascinare",
    "affascinavo": "affascinare",
    "affascinerai": "affascinare",
    "affascineran": "affascinare",
    "affascineranno": "affascinare",
    "affascinerebbe": "affascinare",
    "affascinerebber": "affascinare",
    "affascinerebbero": "affascinare",
    "affascinerei": "affascinare",
    "affascineremmo": "affascinare",
    "affascineremo": "affascinare",
    "affascinereste": "affascinare",
    "affascineresti": "affascinare",
    "affascinerete": "affascinare",
    "affascinerà": "affascinare",
    "affascinerò": "affascinare",
    "affascini": "affascinare",
    "affasciniamo": "affascinare",
    "affasciniate": "affascinare",
    "affascinin": "affascinare",
    "affascinino": "affascinare",
    "affascino": "affascinare",
    "affascinò": "affascinare",
    "affasse": "affare",
    "affasser": "affare",
    "affassero": "affare",
    "affassi": "affare",
    "affassimo": "affare",
    "affaste": "affare",
    "affastella": "affastellare",
    "affastellai": "affastellare",
    "affastellammo": "affastellare",
    "affastellan": "affastellare",
    "affastellando": "affastellare",
    "affastellano": "affastellare",
    "affastellante": "affastellare",
    "affastellanti": "affastellare",
    "affastellar": "affastellare",
    "affastellaron": "affastellare",
    "affastellarono": "affastellare",
    "affastellasse": "affastellare",
    "affastellasser": "affastellare",
    "affastellassero": "affastellare",
    "affastellassi": "affastellare",
    "affastellassimo": "affastellare",
    "affastellaste": "affastellare",
    "affastellasti": "affastellare",
    "affastellata": "affastellare",
    "affastellate": "affastellare",
    "affastellati": "affastellare",
    "affastellato": "affastellare",
    "affastellava": "affastellare",
    "affastellavamo": "affastellare",
    "affastellavan": "affastellare",
    "affastellavano": "affastellare",
    "affastellavate": "affastellare",
    "affastellavi": "affastellare",
    "affastellavo": "affastellare",
    "affastellerai": "affastellare",
    "affastelleran": "affastellare",
    "affastelleranno": "affastellare",
    "affastellerebbe": "affastellare",
    "affastellerebber": "affastellare",
    "affastellerebbero": "affastellare",
    "affastellerei": "affastellare",
    "affastelleremmo": "affastellare",
    "affastelleremo": "affastellare",
    "affastellereste": "affastellare",
    "affastelleresti": "affastellare",
    "affastellerete": "affastellare",
    "affastellerà": "affastellare",
    "affastellerò": "affastellare",
    "affastelli": "affastellare",
    "affastelliamo": "affastellare",
    "affastelliate": "affastellare",
    "affastellin": "affastellare",
    "affastellino": "affastellare",
    "affastello": "affastellare",
    "affastellò": "affastellare",
    "affasti": "affare",
    "affata": "affare",
    "affate": "affare",
    "affati": "affare",
    "affatica": "affaticare",
    "affaticai": "affaticare",
    "affaticamenti": "affaticamento",
    "affaticammo": "affaticare",
    "affatican": "affaticare",
    "affaticando": "affaticare",
    "affaticano": "affaticare",
    "affaticante": "affaticare",
    "affaticanti": "affaticare",
    "affaticar": "affaticare",
    "affaticaron": "affaticare",
    "affaticarono": "affaticare",
    "affaticasse": "affaticare",
    "affaticasser": "affaticare",
    "affaticassero": "affaticare",
    "affaticassi": "affaticare",
    "affaticassimo": "affaticare",
    "affaticaste": "affaticare",
    "affaticasti": "affaticare",
    "affaticata": "affaticato",
    "affaticate": "affaticato",
    "affaticati": "affaticato",
    "affaticato": "affaticare",
    "affaticava": "affaticare",
    "affaticavamo": "affaticare",
    "affaticavan": "affaticare",
    "affaticavano": "affaticare",
    "affaticavate": "affaticare",
    "affaticavi": "affaticare",
    "affaticavo": "affaticare",
    "affaticherai": "affaticare",
    "affaticheran": "affaticare",
    "affaticheranno": "affaticare",
    "affaticherebbe": "affaticare",
    "affaticherebber": "affaticare",
    "affaticherebbero": "affaticare",
    "affaticherei": "affaticare",
    "affaticheremmo": "affaticare",
    "affaticheremo": "affaticare",
    "affatichereste": "affaticare",
    "affaticheresti": "affaticare",
    "affaticherete": "affaticare",
    "affaticherà": "affaticare",
    "affaticherò": "affaticare",
    "affatichi": "affaticare",
    "affatichiamo": "affaticare",
    "affatichiate": "affaticare",
    "affatichin": "affaticare",
    "affatichino": "affaticare",
    "affatico": "affaticare",
    "affaticò": "affaticare",
    "affatigata": "affatigato",
    "affatigate": "affatigato",
    "affatigati": "affatigato",
    "affato": "affare",
    "affattura": "affatturare",
    "affatturai": "affatturare",
    "affatturammo": "affatturare",
    "affatturan": "affatturare",
    "affatturando": "affatturare",
    "affatturano": "affatturare",
    "affatturante": "affatturare",
    "affatturanti": "affatturare",
    "affatturar": "affatturare",
    "affatturaron": "affatturare",
    "affatturarono": "affatturare",
    "affatturasse": "affatturare",
    "affatturasser": "affatturare",
    "affatturassero": "affatturare",
    "affatturassi": "affatturare",
    "affatturassimo": "affatturare",
    "affatturaste": "affatturare",
    "affatturasti": "affatturare",
    "affatturata": "affatturare",
    "affatturate": "affatturare",
    "affatturati": "affatturare",
    "affatturato": "affatturare",
    "affatturava": "affatturare",
    "affatturavamo": "affatturare",
    "affatturavan": "affatturare",
    "affatturavano": "affatturare",
    "affatturavate": "affatturare",
    "affatturavi": "affatturare",
    "affatturavo": "affatturare",
    "affatturerai": "affatturare",
    "affattureran": "affatturare",
    "affattureranno": "affatturare",
    "affatturerebbe": "affatturare",
    "affatturerebber": "affatturare",
    "affatturerebbero": "affatturare",
    "affatturerei": "affatturare",
    "affattureremmo": "affatturare",
    "affattureremo": "affatturare",
    "affatturereste": "affatturare",
    "affattureresti": "affatturare",
    "affatturerete": "affatturare",
    "affatturerà": "affatturare",
    "affatturerò": "affatturare",
    "affatturi": "affatturare",
    "affatturiamo": "affatturare",
    "affatturiate": "affatturare",
    "affatturin": "affatturare",
    "affatturino": "affatturare",
    "affatturo": "affatturare",
    "affatturò": "affatturare",
    "affava": "affare",
    "affavamo": "affare",
    "affavan": "affare",
    "affavano": "affare",
    "affavate": "affare",
    "affavi": "affare",
    "affavo": "affare",
    "afferai": "affare",
    "afferan": "affare",
    "afferanno": "affare",
    "afferebbe": "affare",
    "afferebber": "affare",
    "afferebbero": "affare",
    "afferei": "affare",
    "afferemmo": "affare",
    "afferemo": "affare",
    "afferenti": "afferente",
    "affereste": "affare",
    "afferesti": "affare",
    "afferete": "affare",
    "afferma": "affermare",
    "affermai": "affermare",
    "affermammo": "affermare",
    "afferman": "affermare",
    "affermando": "affermare",
    "affermano": "affermare",
    "affermante": "affermare",
    "affermanti": "affermare",
    "affermar": "affermare",
    "affermaron": "affermare",
    "affermarono": "affermare",
    "affermasse": "affermare",
    "affermasser": "affermare",
    "affermassero": "affermare",
    "affermassi": "affermare",
    "affermassimo": "affermare",
    "affermaste": "affermare",
    "affermasti": "affermare",
    "affermata": "affermato",
    "affermate": "affermato",
    "affermati": "affermato",
    "affermativa": "affermativo",
    "affermative": "affermativo",
    "affermativi": "affermativo",
    "affermato": "affermare",
    "affermava": "affermare",
    "affermavamo": "affermare",
    "affermavan": "affermare",
    "affermavano": "affermare",
    "affermavate": "affermare",
    "affermavi": "affermare",
    "affermavo": "affermare",
    "affermazioni": "affermazione",
    "affermerai": "affermare",
    "affermeran": "affermare",
    "affermeranno": "affermare",
    "affermerebbe": "affermare",
    "affermerebber": "affermare",
    "affermerebbero": "affermare",
    "affermerei": "affermare",
    "affermeremmo": "affermare",
    "affermeremo": "affermare",
    "affermereste": "affermare",
    "affermeresti": "affermare",
    "affermerete": "affermare",
    "affermerà": "affermare",
    "affermerò": "affermare",
    "affermi": "affermare",
    "affermiamo": "affermare",
    "affermiate": "affermare",
    "affermin": "affermare",
    "affermino": "affermare",
    "affermo": "affermare",
    "affermò": "affermare",
    "afferra": "afferrare",
    "afferrabili": "afferrabile",
    "afferrai": "afferrare",
    "afferrammo": "afferrare",
    "afferran": "afferrare",
    "afferrando": "afferrare",
    "afferrano": "afferrare",
    "afferrante": "afferrare",
    "afferranti": "afferrare",
    "afferrar": "afferrare",
    "afferraron": "afferrare",
    "afferrarono": "afferrare",
    "afferrasse": "afferrare",
    "afferrasser": "afferrare",
    "afferrassero": "afferrare",
    "afferrassi": "afferrare",
    "afferrassimo": "afferrare",
    "afferraste": "afferrare",
    "afferrasti": "afferrare",
    "afferrata": "afferrare",
    "afferrate": "afferrare",
    "afferrati": "afferrare",
    "afferrato": "afferrare",
    "afferrava": "afferrare",
    "afferravamo": "afferrare",
    "afferravan": "afferrare",
    "afferravano": "afferrare",
    "afferravate": "afferrare",
    "afferravi": "afferrare",
    "afferravo": "afferrare",
    "afferrerai": "afferrare",
    "afferreran": "afferrare",
    "afferreranno": "afferrare",
    "afferrerebbe": "afferrare",
    "afferrerebber": "afferrare",
    "afferrerebbero": "afferrare",
    "afferrerei": "afferrare",
    "afferreremmo": "afferrare",
    "afferreremo": "afferrare",
    "afferrereste": "afferrare",
    "afferreresti": "afferrare",
    "afferrerete": "afferrare",
    "afferrerà": "afferrare",
    "afferrerò": "afferrare",
    "afferri": "afferrare",
    "afferriamo": "afferrare",
    "afferriate": "afferrare",
    "afferrin": "afferrare",
    "afferrino": "afferrare",
    "afferro": "afferrare",
    "afferrò": "afferrare",
    "afferà": "affare",
    "afferò": "affare",
    "affetta": "affetto",
    "affettai": "affettare",
    "affettammo": "affettare",
    "affettan": "affettare",
    "affettando": "affettare",
    "affettano": "affettare",
    "affettante": "affettare",
    "affettanti": "affettare",
    "affettar": "affettare",
    "affettaron": "affettare",
    "affettarono": "affettare",
    "affettasse": "affettare",
    "affettasser": "affettare",
    "affettassero": "affettare",
    "affettassi": "affettare",
    "affettassimo": "affettare",
    "affettaste": "affettare",
    "affettasti": "affettare",
    "affettata": "affettato",
    "affettate": "affettato",
    "affettati": "affettato",
    "affettato": "affettare",
    "affettava": "affettare",
    "affettavamo": "affettare",
    "affettavan": "affettare",
    "affettavano": "affettare",
    "affettavate": "affettare",
    "affettavi": "affettare",
    "affettavo": "affettare",
    "affettazioni": "affettazione",
    "affette": "affetto",
    "affetterai": "affettare",
    "affetteran": "affettare",
    "affetteranno": "affettare",
    "affetterebbe": "affettare",
    "affetterebber": "affettare",
    "affetterebbero": "affettare",
    "affetterei": "affettare",
    "affetteremmo": "affettare",
    "affetteremo": "affettare",
    "affettereste": "affettare",
    "affetteresti": "affettare",
    "affetterete": "affettare",
    "affetterà": "affettare",
    "affetterò": "affettare",
    "affetti": "affetto",
    "affettiamo": "affettare",
    "affettiate": "affettare",
    "affettin": "affettare",
    "affettino": "affettare",
    "affettiva": "affettivo",
    "affettive": "affettivo",
    "affettivi": "affettivo",
    "affetto": "affettare",
    "affettuosa": "affettuoso",
    "affettuose": "affettuoso",
    "affettuosi": "affettuoso",
    "affettò": "affettare",
    "affeziona": "affezionare",
    "affezionai": "affezionare",
    "affezionammo": "affezionare",
    "affezionan": "affezionare",
    "affezionando": "affezionare",
    "affezionano": "affezionare",
    "affezionante": "affezionare",
    "affezionanti": "affezionare",
    "affezionar": "affezionare",
    "affezionaron": "affezionare",
    "affezionarono": "affezionare",
    "affezionasse": "affezionare",
    "affezionasser": "affezionare",
    "affezionassero": "affezionare",
    "affezionassi": "affezionare",
    "affezionassimo": "affezionare",
    "affezionaste": "affezionare",
    "affezionasti": "affezionare",
    "affezionata": "affezionato",
    "affezionate": "affezionato",
    "affezionati": "affezionato",
    "affezionato": "affezionare",
    "affezionava": "affezionare",
    "affezionavamo": "affezionare",
    "affezionavan": "affezionare",
    "affezionavano": "affezionare",
    "affezionavate": "affezionare",
    "affezionavi": "affezionare",
    "affezionavo": "affezionare",
    "affezionerai": "affezionare",
    "affezioneran": "affezionare",
    "affezioneranno": "affezionare",
    "affezionerebbe": "affezionare",
    "affezionerebber": "affezionare",
    "affezionerebbero": "affezionare",
    "affezionerei": "affezionare",
    "affezioneremmo": "affezionare",
    "affezioneremo": "affezionare",
    "affezionereste": "affezionare",
    "affezioneresti": "affezionare",
    "affezionerete": "affezionare",
    "affezionerà": "affezionare",
    "affezionerò": "affezionare",
    "affezioni": "affezione",
    "affezioniamo": "affezionare",
    "affezioniate": "affezionare",
    "affezionin": "affezionare",
    "affezionino": "affezionare",
    "affeziono": "affezionare",
    "affezionò": "affezionare",
    "affi": "affare",
    "affiamo": "affare",
    "affianca": "affiancare",
    "affiancai": "affiancare",
    "affiancammo": "affiancare",
    "affiancan": "affiancare",
    "affiancando": "affiancare",
    "affiancano": "affiancare",
    "affiancante": "affiancare",
    "affiancanti": "affiancare",
    "affiancar": "affiancare",
    "affiancaron": "affiancare",
    "affiancarono": "affiancare",
    "affiancasse": "affiancare",
    "affiancasser": "affiancare",
    "affiancassero": "affiancare",
    "affiancassi": "affiancare",
    "affiancassimo": "affiancare",
    "affiancaste": "affiancare",
    "affiancasti": "affiancare",
    "affiancata": "affiancare",
    "affiancate": "affiancare",
    "affiancati": "affiancare",
    "affiancato": "affiancare",
    "affiancava": "affiancare",
    "affiancavamo": "affiancare",
    "affiancavan": "affiancare",
    "affiancavano": "affiancare",
    "affiancavate": "affiancare",
    "affiancavi": "affiancare",
    "affiancavo": "affiancare",
    "affiancherai": "affiancare",
    "affiancheran": "affiancare",
    "affiancheranno": "affiancare",
    "affiancherebbe": "affiancare",
    "affiancherebber": "affiancare",
    "affiancherebbero": "affiancare",
    "affiancherei": "affiancare",
    "affiancheremmo": "affiancare",
    "affiancheremo": "affiancare",
    "affianchereste": "affiancare",
    "affiancheresti": "affiancare",
    "affiancherete": "affiancare",
    "affiancherà": "affiancare",
    "affiancherò": "affiancare",
    "affianchi": "affiancare",
    "affianchiamo": "affiancare",
    "affianchiate": "affiancare",
    "affianchin": "affiancare",
    "affianchino": "affiancare",
    "affianco": "affiancare",
    "affiancò": "affiancare",
    "affiata": "affiatare",
    "affiatai": "affiatare",
    "affiatamenti": "affiatamento",
    "affiatammo": "affiatare",
    "affiatan": "affiatare",
    "affiatando": "affiatare",
    "affiatano": "affiatare",
    "affiatante": "affiatare",
    "affiatanti": "affiatare",
    "affiatar": "affiatare",
    "affiataron": "affiatare",
    "affiatarono": "affiatare",
    "affiatasse": "affiatare",
    "affiatasser": "affiatare",
    "affiatassero": "affiatare",
    "affiatassi": "affiatare",
    "affiatassimo": "affiatare",
    "affiataste": "affiatare",
    "affiatasti": "affiatare",
    "affiatata": "affiatare",
    "affiatate": "affiatare",
    "affiatati": "affiatare",
    "affiatato": "affiatare",
    "affiatava": "affiatare",
    "affiatavamo": "affiatare",
    "affiatavan": "affiatare",
    "affiatavano": "affiatare",
    "affiatavate": "affiatare",
    "affiatavi": "affiatare",
    "affiatavo": "affiatare",
    "affiate": "affare",
    "affiaterai": "affiatare",
    "affiateran": "affiatare",
    "affiateranno": "affiatare",
    "affiaterebbe": "affiatare",
    "affiaterebber": "affiatare",
    "affiaterebbero": "affiatare",
    "affiaterei": "affiatare",
    "affiateremmo": "affiatare",
    "affiateremo": "affiatare",
    "affiatereste": "affiatare",
    "affiateresti": "affiatare",
    "affiaterete": "affiatare",
    "affiaterà": "affiatare",
    "affiaterò": "affiatare",
    "affiati": "affiatare",
    "affiatiamo": "affiatare",
    "affiatiate": "affiatare",
    "affiatin": "affiatare",
    "affiatino": "affiatare",
    "affiato": "affiatare",
    "affiatò": "affiatare",
    "affibbi": "affibbiare",
    "affibbia": "affibbiare",
    "affibbiai": "affibbiare",
    "affibbiammo": "affibbiare",
    "affibbiamo": "affibbiare",
    "affibbian": "affibbiare",
    "affibbiando": "affibbiare",
    "affibbiano": "affibbiare",
    "affibbiante": "affibbiare",
    "affibbianti": "affibbiare",
    "affibbiar": "affibbiare",
    "affibbiaron": "affibbiare",
    "affibbiarono": "affibbiare",
    "affibbiasse": "affibbiare",
    "affibbiasser": "affibbiare",
    "affibbiassero": "affibbiare",
    "affibbiassi": "affibbiare",
    "affibbiassimo": "affibbiare",
    "affibbiaste": "affibbiare",
    "affibbiasti": "affibbiare",
    "affibbiata": "affibbiare",
    "affibbiate": "affibbiare",
    "affibbiati": "affibbiare",
    "affibbiato": "affibbiare",
    "affibbiava": "affibbiare",
    "affibbiavamo": "affibbiare",
    "affibbiavan": "affibbiare",
    "affibbiavano": "affibbiare",
    "affibbiavate": "affibbiare",
    "affibbiavi": "affibbiare",
    "affibbiavo": "affibbiare",
    "affibbierai": "affibbiare",
    "affibbieran": "affibbiare",
    "affibbieranno": "affibbiare",
    "affibbierebbe": "affibbiare",
    "affibbierebber": "affibbiare",
    "affibbierebbero": "affibbiare",
    "affibbierei": "affibbiare",
    "affibbieremmo": "affibbiare",
    "affibbieremo": "affibbiare",
    "affibbiereste": "affibbiare",
    "affibbieresti": "affibbiare",
    "affibbierete": "affibbiare",
    "affibbierà": "affibbiare",
    "affibbierò": "affibbiare",
    "affibbin": "affibbiare",
    "affibbino": "affibbiare",
    "affibbio": "affibbiare",
    "affibbiò": "affibbiare",
    "affida": "affidare",
    "affidabili": "affidabile",
    "affidai": "affidare",
    "affidamenti": "affidamento",
    "affidammo": "affidare",
    "affidan": "affidare",
    "affidando": "affidare",
    "affidano": "affidare",
    "affidante": "affidare",
    "affidanti": "affidare",
    "affidar": "affidare",
    "affidaron": "affidare",
    "affidarono": "affidare",
    "affidasse": "affidare",
    "affidasser": "affidare",
    "affidassero": "affidare",
    "affidassi": "affidare",
    "affidassimo": "affidare",
    "affidaste": "affidare",
    "affidasti": "affidare",
    "affidata": "affidare",
    "affidate": "affidare",
    "affidati": "affidare",
    "affidato": "affidare",
    "affidava": "affidare",
    "affidavamo": "affidare",
    "affidavan": "affidare",
    "affidavano": "affidare",
    "affidavate": "affidare",
    "affidavi": "affidare",
    "affidavo": "affidare",
    "affiderai": "affidare",
    "affideran": "affidare",
    "affideranno": "affidare",
    "affiderebbe": "affidare",
    "affiderebber": "affidare",
    "affiderebbero": "affidare",
    "affiderei": "affidare",
    "affideremmo": "affidare",
    "affideremo": "affidare",
    "affidereste": "affidare",
    "affideresti": "affidare",
    "affiderete": "affidare",
    "affiderà": "affidare",
    "affiderò": "affidare",
    "affidi": "affido",
    "affidiamo": "affidare",
    "affidiate": "affidare",
    "affidin": "affidare",
    "affidino": "affidare",
    "affido": "affidare",
    "affidò": "affidare",
    "affiena": "affienare",
    "affienai": "affienare",
    "affienammo": "affienare",
    "affienan": "affienare",
    "affienando": "affienare",
    "affienano": "affienare",
    "affienante": "affienare",
    "affienanti": "affienare",
    "affienar": "affienare",
    "affienaron": "affienare",
    "affienarono": "affienare",
    "affienasse": "affienare",
    "affienasser": "affienare",
    "affienassero": "affienare",
    "affienassi": "affienare",
    "affienassimo": "affienare",
    "affienaste": "affienare",
    "affienasti": "affienare",
    "affienata": "affienare",
    "affienate": "affienare",
    "affienati": "affienare",
    "affienato": "affienare",
    "affienava": "affienare",
    "affienavamo": "affienare",
    "affienavan": "affienare",
    "affienavano": "affienare",
    "affienavate": "affienare",
    "affienavi": "affienare",
    "affienavo": "affienare",
    "affienerai": "affienare",
    "affieneran": "affienare",
    "affieneranno": "affienare",
    "affienerebbe": "affienare",
    "affienerebber": "affienare",
    "affienerebbero": "affienare",
    "affienerei": "affienare",
    "affieneremmo": "affienare",
    "affieneremo": "affienare",
    "affienereste": "affienare",
    "affieneresti": "affienare",
    "affienerete": "affienare",
    "affienerà": "affienare",
    "affienerò": "affienare",
    "affieni": "affienare",
    "affieniamo": "affienare",
    "affieniate": "affienare",
    "affienin": "affienare",
    "affienino": "affienare",
    "affieno": "affienare",
    "affienò": "affienare",
    "affievolendo": "affievolire",
    "affievolente": "affievolire",
    "affievolenti": "affievolire",
    "affievoliamo": "affievolire",
    "affievoliate": "affievolire",
    "affievolii": "affievolire",
    "affievolimmo": "affievolire",
    "affievolir": "affievolire",
    "affievolirai": "affievolire",
    "affievoliran": "affievolire",
    "affievoliranno": "affievolire",
    "affievolirebbe": "affievolire",
    "affievolirebber": "affievolire",
    "affievolirebbero": "affievolire",
    "affievolirei": "affievolire",
    "affievoliremmo": "affievolire",
    "affievoliremo": "affievolire",
    "affievolireste": "affievolire",
    "affievoliresti": "affievolire",
    "affievolirete": "affievolire",
    "affievoliron": "affievolire",
    "affievolirono": "affievolire",
    "affievolirà": "affievolire",
    "affievolirò": "affievolire",
    "affievolisca": "affievolire",
    "affievoliscan": "affievolire",
    "affievoliscano": "affievolire",
    "affievolisce": "affievolire",
    "affievolisci": "affievolire",
    "affievolisco": "affievolire",
    "affievoliscon": "affievolire",
    "affievoliscono": "affievolire",
    "affievolisse": "affievolire",
    "affievolisser": "affievolire",
    "affievolissero": "affievolire",
    "affievolissi": "affievolire",
    "affievolissimo": "affievolire",
    "affievoliste": "affievolire",
    "affievolisti": "affievolire",
    "affievolita": "affievolire",
    "affievolite": "affievolire",
    "affievoliti": "affievolire",
    "affievolito": "affievolire",
    "affievoliva": "affievolire",
    "affievolivamo": "affievolire",
    "affievolivan": "affievolire",
    "affievolivano": "affievolire",
    "affievolivate": "affievolire",
    "affievolivi": "affievolire",
    "affievolivo": "affievolire",
    "affievolì": "affievolire",
    "affigga": "affiggere",
    "affiggan": "affiggere",
    "affiggano": "affiggere",
    "affigge": "affiggere",
    "affiggemmo": "affiggere",
    "affiggendo": "affiggere",
    "affiggente": "affiggere",
    "affiggenti": "affiggere",
    "affigger": "affiggere",
    "affiggerai": "affiggere",
    "affiggeran": "affiggere",
    "affiggeranno": "affiggere",
    "affiggerebbe": "affiggere",
    "affiggerebber": "affiggere",
    "affiggerebbero": "affiggere",
    "affiggerei": "affiggere",
    "affiggeremmo": "affiggere",
    "affiggeremo": "affiggere",
    "affiggereste": "affiggere",
    "affiggeresti": "affiggere",
    "affiggerete": "affiggere",
    "affiggerà": "affiggere",
    "affiggerò": "affiggere",
    "affiggesse": "affiggere",
    "affiggesser": "affiggere",
    "affiggessero": "affiggere",
    "affiggessi": "affiggere",
    "affiggessimo": "affiggere",
    "affiggeste": "affiggere",
    "affiggesti": "affiggere",
    "affiggete": "affiggere",
    "affiggeva": "affiggere",
    "affiggevamo": "affiggere",
    "affiggevan": "affiggere",
    "affiggevano": "affiggere",
    "affiggevate": "affiggere",
    "affiggevi": "affiggere",
    "affiggevo": "affiggere",
    "affiggi": "affiggere",
    "affiggiamo": "affiggere",
    "affiggiate": "affiggere",
    "affiggo": "affiggere",
    "affiggon": "affiggere",
    "affiggono": "affiggere",
    "affila": "affilare",
    "affilai": "affilare",
    "affilammo": "affilare",
    "affilan": "affilare",
    "affilando": "affilare",
    "affilano": "affilare",
    "affilante": "affilare",
    "affilanti": "affilare",
    "affilar": "affilare",
    "affilaron": "affilare",
    "affilarono": "affilare",
    "affilasse": "affilare",
    "affilasser": "affilare",
    "affilassero": "affilare",
    "affilassi": "affilare",
    "affilassimo": "affilare",
    "affilaste": "affilare",
    "affilasti": "affilare",
    "affilata": "affilato",
    "affilate": "affilato",
    "affilati": "affilato",
    "affilato": "affilare",
    "affilava": "affilare",
    "affilavamo": "affilare",
    "affilavan": "affilare",
    "affilavano": "affilare",
    "affilavate": "affilare",
    "affilavi": "affilare",
    "affilavo": "affilare",
    "affilerai": "affilare",
    "affileran": "affilare",
    "affileranno": "affilare",
    "affilerebbe": "affilare",
    "affilerebber": "affilare",
    "affilerebbero": "affilare",
    "affilerei": "affilare",
    "affileremmo": "affilare",
    "affileremo": "affilare",
    "affilereste": "affilare",
    "affileresti": "affilare",
    "affilerete": "affilare",
    "affilerà": "affilare",
    "affilerò": "affilare",
    "affili": "affiliare",
    "affilia": "affiliare",
    "affiliai": "affiliare",
    "affiliammo": "affiliare",
    "affiliamo": "affiliare",
    "affilian": "affiliare",
    "affiliando": "affiliare",
    "affiliano": "affiliare",
    "affiliante": "affiliare",
    "affilianti": "affiliare",
    "affiliar": "affiliare",
    "affiliaron": "affiliare",
    "affiliarono": "affiliare",
    "affiliasse": "affiliare",
    "affiliasser": "affiliare",
    "affiliassero": "affiliare",
    "affiliassi": "affiliare",
    "affiliassimo": "affiliare",
    "affiliaste": "affiliare",
    "affiliasti": "affiliare",
    "affiliata": "affiliato",
    "affiliate": "affiliato",
    "affiliati": "affiliato",
    "affiliato": "affiliare",
    "affiliava": "affiliare",
    "affiliavamo": "affiliare",
    "affiliavan": "affiliare",
    "affiliavano": "affiliare",
    "affiliavate": "affiliare",
    "affiliavi": "affiliare",
    "affiliavo": "affiliare",
    "affiliazioni": "affiliazione",
    "affilierai": "affiliare",
    "affilieran": "affiliare",
    "affilieranno": "affiliare",
    "affilierebbe": "affiliare",
    "affilierebber": "affiliare",
    "affilierebbero": "affiliare",
    "affilierei": "affiliare",
    "affilieremmo": "affiliare",
    "affilieremo": "affiliare",
    "affiliereste": "affiliare",
    "affilieresti": "affiliare",
    "affilierete": "affiliare",
    "affilierà": "affiliare",
    "affilierò": "affiliare",
    "affilin": "affiliare",
    "affilino": "affiliare",
    "affilio": "affiliare",
    "affiliò": "affiliare",
    "affilo": "affilare",
    "affilò": "affilare",
    "affin": "affare",
    "affina": "affinare",
    "affinai": "affinare",
    "affinamenti": "affinamento",
    "affinammo": "affinare",
    "affinan": "affinare",
    "affinando": "affinare",
    "affinano": "affinare",
    "affinante": "affinare",
    "affinanti": "affinare",
    "affinar": "affinare",
    "affinaron": "affinare",
    "affinarono": "affinare",
    "affinasse": "affinare",
    "affinasser": "affinare",
    "affinassero": "affinare",
    "affinassi": "affinare",
    "affinassimo": "affinare",
    "affinaste": "affinare",
    "affinasti": "affinare",
    "affinata": "affinare",
    "affinate": "affinare",
    "affinati": "affinare",
    "affinato": "affinare",
    "affinava": "affinare",
    "affinavamo": "affinare",
    "affinavan": "affinare",
    "affinavano": "affinare",
    "affinavate": "affinare",
    "affinavi": "affinare",
    "affinavo": "affinare",
    "affinerai": "affinare",
    "affineran": "affinare",
    "affineranno": "affinare",
    "affinerebbe": "affinare",
    "affinerebber": "affinare",
    "affinerebbero": "affinare",
    "affinerei": "affinare",
    "affineremmo": "affinare",
    "affineremo": "affinare",
    "affinereste": "affinare",
    "affineresti": "affinare",
    "affinerete": "affinare",
    "affinerà": "affinare",
    "affinerò": "affinare",
    "affini": "affine",
    "affiniamo": "affinare",
    "affiniate": "affinare",
    "affinin": "affinare",
    "affinino": "affinare",
    "affino": "affinare",
    "affinò": "affinare",
    "affiocha": "affiochire",
    "affiochan": "affiochire",
    "affiochano": "affiochire",
    "affioche": "affiochire",
    "affiochendo": "affiochire",
    "affiochente": "affiochire",
    "affiochenti": "affiochire",
    "affiochi": "affiochire",
    "affiochiamo": "affiochire",
    "affiochiate": "affiochire",
    "affiochii": "affiochire",
    "affiochimmo": "affiochire",
    "affiochir": "affiochire",
    "affiochirai": "affiochire",
    "affiochiran": "affiochire",
    "affiochiranno": "affiochire",
    "affiochirebbe": "affiochire",
    "affiochirebber": "affiochire",
    "affiochirebbero": "affiochire",
    "affiochirei": "affiochire",
    "affiochiremmo": "affiochire",
    "affiochiremo": "affiochire",
    "affiochireste": "affiochire",
    "affiochiresti": "affiochire",
    "affiochirete": "affiochire",
    "affiochiron": "affiochire",
    "affiochirono": "affiochire",
    "affiochirà": "affiochire",
    "affiochirò": "affiochire",
    "affiochisse": "affiochire",
    "affiochisser": "affiochire",
    "affiochissero": "affiochire",
    "affiochissi": "affiochire",
    "affiochissimo": "affiochire",
    "affiochiste": "affiochire",
    "affiochisti": "affiochire",
    "affiochita": "affiochire",
    "affiochite": "affiochire",
    "affiochiti": "affiochire",
    "affiochito": "affiochire",
    "affiochiva": "affiochire",
    "affiochivamo": "affiochire",
    "affiochivan": "affiochire",
    "affiochivano": "affiochire",
    "affiochivate": "affiochire",
    "affiochivi": "affiochire",
    "affiochivo": "affiochire",
    "affiocho": "affiochire",
    "affiochon": "affiochire",
    "affiochono": "affiochire",
    "affiochì": "affiochire",
    "affiora": "affiorare",
    "affiorai": "affiorare",
    "affioramenti": "affioramento",
    "affiorammo": "affiorare",
    "affioran": "affiorare",
    "affiorando": "affiorare",
    "affiorano": "affiorare",
    "affiorante": "affiorare",
    "affioranti": "affiorare",
    "affiorar": "affiorare",
    "affioraron": "affiorare",
    "affiorarono": "affiorare",
    "affiorasse": "affiorare",
    "affiorasser": "affiorare",
    "affiorassero": "affiorare",
    "affiorassi": "affiorare",
    "affiorassimo": "affiorare",
    "affioraste": "affiorare",
    "affiorasti": "affiorare",
    "affiorata": "affiorare",
    "affiorate": "affiorare",
    "affiorati": "affiorare",
    "affiorato": "affiorare",
    "affiorava": "affiorare",
    "affioravamo": "affiorare",
    "affioravan": "affiorare",
    "affioravano": "affiorare",
    "affioravate": "affiorare",
    "affioravi": "affiorare",
    "affioravo": "affiorare",
    "affiorerai": "affiorare",
    "affioreran": "affiorare",
    "affioreranno": "affiorare",
    "affiorerebbe": "affiorare",
    "affiorerebber": "affiorare",
    "affiorerebbero": "affiorare",
    "affiorerei": "affiorare",
    "affioreremmo": "affiorare",
    "affioreremo": "affiorare",
    "affiorereste": "affiorare",
    "affioreresti": "affiorare",
    "affiorerete": "affiorare",
    "affiorerà": "affiorare",
    "affiorerò": "affiorare",
    "affiori": "affiorare",
    "affioriamo": "affiorare",
    "affioriate": "affiorare",
    "affiorin": "affiorare",
    "affiorino": "affiorare",
    "affioro": "affiorare",
    "affiorò": "affiorare",
    "affissa": "affissare",
    "affissai": "affissare",
    "affissammo": "affissare",
    "affissan": "affissare",
    "affissando": "affissare",
    "affissano": "affissare",
    "affissante": "affissare",
    "affissanti": "affissare",
    "affissar": "affissare",
    "affissaron": "affissare",
    "affissarono": "affissare",
    "affissasse": "affissare",
    "affissasser": "affissare",
    "affissassero": "affissare",
    "affissassi": "affissare",
    "affissassimo": "affissare",
    "affissaste": "affissare",
    "affissasti": "affissare",
    "affissata": "affissare",
    "affissate": "affissare",
    "affissati": "affissare",
    "affissato": "affissare",
    "affissava": "affissare",
    "affissavamo": "affissare",
    "affissavan": "affissare",
    "affissavano": "affissare",
    "affissavate": "affissare",
    "affissavi": "affissare",
    "affissavo": "affissare",
    "affisser": "affiggere",
    "affisserai": "affissare",
    "affisseran": "affissare",
    "affisseranno": "affissare",
    "affisserebbe": "affissare",
    "affisserebber": "affissare",
    "affisserebbero": "affissare",
    "affisserei": "affissare",
    "affisseremmo": "affissare",
    "affisseremo": "affissare",
    "affissereste": "affissare",
    "affisseresti": "affissare",
    "affisserete": "affissare",
    "affissero": "affiggere",
    "affisserà": "affissare",
    "affisserò": "affissare",
    "affissi": "affissare",
    "affissiamo": "affissare",
    "affissiate": "affissare",
    "affissin": "affissare",
    "affissino": "affissare",
    "affissioni": "affissione",
    "affisso": "affissare",
    "affissè": "affiggere",
    "affissò": "affissare",
    "affitta": "affittire",
    "affittai": "affittare",
    "affittammo": "affittare",
    "affittan": "affittire",
    "affittando": "affittare",
    "affittano": "affittire",
    "affittante": "affittare",
    "affittanti": "affittare",
    "affittar": "affittare",
    "affittaron": "affittare",
    "affittarono": "affittare",
    "affittasse": "affittare",
    "affittasser": "affittare",
    "affittassero": "affittare",
    "affittassi": "affittare",
    "affittassimo": "affittare",
    "affittaste": "affittare",
    "affittasti": "affittare",
    "affittata": "affittare",
    "affittate": "affittare",
    "affittati": "affittare",
    "affittato": "affittare",
    "affittava": "affittare",
    "affittavamo": "affittare",
    "affittavan": "affittare",
    "affittavano": "affittare",
    "affittavate": "affittare",
    "affittavi": "affittare",
    "affittavo": "affittare",
    "affitte": "affittire",
    "affittendo": "affittire",
    "affittente": "affittire",
    "affittenti": "affittire",
    "affitterai": "affittare",
    "affitteran": "affittare",
    "affitteranno": "affittare",
    "affitterebbe": "affittare",
    "affitterebber": "affittare",
    "affitterebbero": "affittare",
    "affitterei": "affittare",
    "affitteremmo": "affittare",
    "affitteremo": "affittare",
    "affittereste": "affittare",
    "affitteresti": "affittare",
    "affitterete": "affittare",
    "affitterà": "affittare",
    "affitterò": "affittare",
    "affitti": "affitto",
    "affittiamo": "affittire",
    "affittiate": "affittire",
    "affittii": "affittire",
    "affittimmo": "affittire",
    "affittin": "affittare",
    "affittino": "affittare",
    "affittir": "affittire",
    "affittirai": "affittire",
    "affittiran": "affittire",
    "affittiranno": "affittire",
    "affittirebbe": "affittire",
    "affittirebber": "affittire",
    "affittirebbero": "affittire",
    "affittirei": "affittire",
    "affittiremmo": "affittire",
    "affittiremo": "affittire",
    "affittireste": "affittire",
    "affittiresti": "affittire",
    "affittirete": "affittire",
    "affittiron": "affittire",
    "affittirono": "affittire",
    "affittirà": "affittire",
    "affittirò": "affittire",
    "affittisse": "affittire",
    "affittisser": "affittire",
    "affittissero": "affittire",
    "affittissi": "affittire",
    "affittissimo": "affittire",
    "affittiste": "affittire",
    "affittisti": "affittire",
    "affittita": "affittire",
    "affittite": "affittire",
    "affittiti": "affittire",
    "affittito": "affittire",
    "affittiva": "affittire",
    "affittivamo": "affittire",
    "affittivan": "affittire",
    "affittivano": "affittire",
    "affittivate": "affittire",
    "affittivi": "affittire",
    "affittivo": "affittire",
    "affitto": "affittire",
    "affitton": "affittire",
    "affittono": "affittire",
    "affittuari": "affittuario",
    "affittì": "affittire",
    "affittò": "affittare",
    "afflati": "afflato",
    "affligga": "affliggere",
    "affliggan": "affliggere",
    "affliggano": "affliggere",
    "affligge": "affliggere",
    "affliggemmo": "affliggere",
    "affliggendo": "affliggere",
    "affliggente": "affliggere",
    "affliggenti": "affliggere",
    "affligger": "affliggere",
    "affliggerai": "affliggere",
    "affliggeran": "affliggere",
    "affliggeranno": "affliggere",
    "affliggerebbe": "affliggere",
    "affliggerebber": "affliggere",
    "affliggerebbero": "affliggere",
    "affliggerei": "affliggere",
    "affliggeremmo": "affliggere",
    "affliggeremo": "affliggere",
    "affliggereste": "affliggere",
    "affliggeresti": "affliggere",
    "affliggerete": "affliggere",
    "affliggerà": "affliggere",
    "affliggerò": "affliggere",
    "affliggesse": "affliggere",
    "affliggesser": "affliggere",
    "affliggessero": "affliggere",
    "affliggessi": "affliggere",
    "affliggessimo": "affliggere",
    "affliggeste": "affliggere",
    "affliggesti": "affliggere",
    "affliggete": "affliggere",
    "affliggeva": "affliggere",
    "affliggevamo": "affliggere",
    "affliggevan": "affliggere",
    "affliggevano": "affliggere",
    "affliggevate": "affliggere",
    "affliggevi": "affliggere",
    "affliggevo": "affliggere",
    "affliggi": "affliggere",
    "affliggiamo": "affliggere",
    "affliggiate": "affliggere",
    "affliggo": "affliggere",
    "affliggon": "affliggere",
    "affliggono": "affliggere",
    "afflisser": "affliggere",
    "afflissero": "affliggere",
    "afflissi": "affliggere",
    "afflissè": "affliggere",
    "afflitta": "afflitto",
    "afflitte": "afflitto",
    "afflitti": "afflitto",
    "afflitto": "affliggere",
    "afflizioni": "afflizione",
    "affloscerai": "afflosciare",
    "afflosceran": "afflosciare",
    "afflosceranno": "afflosciare",
    "affloscerebbe": "afflosciare",
    "affloscerebber": "afflosciare",
    "affloscerebbero": "afflosciare",
    "affloscerei": "afflosciare",
    "afflosceremmo": "afflosciare",
    "afflosceremo": "afflosciare",
    "affloscereste": "afflosciare",
    "afflosceresti": "afflosciare",
    "affloscerete": "afflosciare",
    "affloscerà": "afflosciare",
    "affloscerò": "afflosciare",
    "afflosci": "afflosciare",
    "affloscia": "afflosciare",
    "afflosciai": "afflosciare",
    "afflosciammo": "afflosciare",
    "afflosciamo": "afflosciare",
    "affloscian": "afflosciare",
    "afflosciando": "afflosciare",
    "afflosciano": "afflosciare",
    "afflosciar": "afflosciare",
    "afflosciaron": "afflosciare",
    "afflosciarono": "afflosciare",
    "afflosciasse": "afflosciare",
    "afflosciasser": "afflosciare",
    "afflosciassero": "afflosciare",
    "afflosciassi": "afflosciare",
    "afflosciassimo": "afflosciare",
    "afflosciaste": "afflosciare",
    "afflosciasti": "afflosciare",
    "afflosciata": "afflosciare",
    "afflosciate": "afflosciare",
    "afflosciati": "afflosciare",
    "afflosciato": "afflosciare",
    "afflosciava": "afflosciare",
    "afflosciavamo": "afflosciare",
    "afflosciavan": "afflosciare",
    "afflosciavano": "afflosciare",
    "afflosciavate": "afflosciare",
    "afflosciavi": "afflosciare",
    "afflosciavo": "afflosciare",
    "affloscin": "afflosciare",
    "affloscino": "afflosciare",
    "affloscio": "afflosciare",
    "afflosciò": "afflosciare",
    "affluendo": "affluire",
    "affluente": "affluire",
    "affluenti": "affluire",
    "affluenze": "affluenza",
    "affluiamo": "affluire",
    "affluiate": "affluire",
    "affluii": "affluire",
    "affluimmo": "affluire",
    "affluir": "affluire",
    "affluirai": "affluire",
    "affluiran": "affluire",
    "affluiranno": "affluire",
    "affluirebbe": "affluire",
    "affluirebber": "affluire",
    "affluirebbero": "affluire",
    "affluirei": "affluire",
    "affluiremmo": "affluire",
    "affluiremo": "affluire",
    "affluireste": "affluire",
    "affluiresti": "affluire",
    "affluirete": "affluire",
    "affluiron": "affluire",
    "affluirono": "affluire",
    "affluirà": "affluire",
    "affluirò": "affluire",
    "affluisca": "affluire",
    "affluiscan": "affluire",
    "affluiscano": "affluire",
    "affluisce": "affluire",
    "affluisci": "affluire",
    "affluisco": "affluire",
    "affluiscon": "affluire",
    "affluiscono": "affluire",
    "affluisse": "affluire",
    "affluisser": "affluire",
    "affluissero": "affluire",
    "affluissi": "affluire",
    "affluissimo": "affluire",
    "affluiste": "affluire",
    "affluisti": "affluire",
    "affluita": "affluire",
    "affluite": "affluire",
    "affluiti": "affluire",
    "affluito": "affluire",
    "affluiva": "affluire",
    "affluivamo": "affluire",
    "affluivan": "affluire",
    "affluivano": "affluire",
    "affluivate": "affluire",
    "affluivi": "affluire",
    "affluivo": "affluire",
    "afflussi": "afflusso",
    "affluì": "affluire",
    "affo": "affare",
    "affoca": "affocare",
    "affocai": "affocare",
    "affocammo": "affocare",
    "affocan": "affocare",
    "affocando": "affocare",
    "affocano": "affocare",
    "affocante": "affocare",
    "affocanti": "affocare",
    "affocar": "affocare",
    "affocaron": "affocare",
    "affocarono": "affocare",
    "affocasse": "affocare",
    "affocasser": "affocare",
    "affocassero": "affocare",
    "affocassi": "affocare",
    "affocassimo": "affocare",
    "affocaste": "affocare",
    "affocasti": "affocare",
    "affocata": "affocare",
    "affocate": "affocare",
    "affocati": "affocare",
    "affocato": "affocare",
    "affocava": "affocare",
    "affocavamo": "affocare",
    "affocavan": "affocare",
    "affocavano": "affocare",
    "affocavate": "affocare",
    "affocavi": "affocare",
    "affocavo": "affocare",
    "affocherai": "affocare",
    "affocheran": "affocare",
    "affocheranno": "affocare",
    "affocherebbe": "affocare",
    "affocherebber": "affocare",
    "affocherebbero": "affocare",
    "affocherei": "affocare",
    "affocheremmo": "affocare",
    "affocheremo": "affocare",
    "affochereste": "affocare",
    "affocheresti": "affocare",
    "affocherete": "affocare",
    "affocherà": "affocare",
    "affocherò": "affocare",
    "affochi": "affocare",
    "affochiamo": "affocare",
    "affochiate": "affocare",
    "affochin": "affocare",
    "affochino": "affocare",
    "affoco": "affocare",
    "affocò": "affocare",
    "affoga": "affogare",
    "affogai": "affogare",
    "affogammo": "affogare",
    "affogan": "affogare",
    "affogando": "affogare",
    "affogano": "affogare",
    "affogante": "affogare",
    "affoganti": "affogare",
    "affogar": "affogare",
    "affogaron": "affogare",
    "affogarono": "affogare",
    "affogasse": "affogare",
    "affogasser": "affogare",
    "affogassero": "affogare",
    "affogassi": "affogare",
    "affogassimo": "affogare",
    "affogaste": "affogare",
    "affogasti": "affogare",
    "affogata": "affogato",
    "affogate": "affogato",
    "affogati": "affogato",
    "affogato": "affogare",
    "affogava": "affogare",
    "affogavamo": "affogare",
    "affogavan": "affogare",
    "affogavano": "affogare",
    "affogavate": "affogare",
    "affogavi": "affogare",
    "affogavo": "affogare",
    "affogherai": "affogare",
    "affogheran": "affogare",
    "affogheranno": "affogare",
    "affogherebbe": "affogare",
    "affogherebber": "affogare",
    "affogherebbero": "affogare",
    "affogherei": "affogare",
    "affogheremmo": "affogare",
    "affogheremo": "affogare",
    "affoghereste": "affogare",
    "affogheresti": "affogare",
    "affogherete": "affogare",
    "affogherà": "affogare",
    "affogherò": "affogare",
    "affoghi": "affogare",
    "affoghiamo": "affogare",
    "affoghiate": "affogare",
    "affoghin": "affogare",
    "affoghino": "affogare",
    "affogo": "affogare",
    "affogò": "affogare",
    "affolla": "affollare",
    "affollai": "affollare",
    "affollamenti": "affollamento",
    "affollammo": "affollare",
    "affollan": "affollare",
    "affollando": "affollare",
    "affollano": "affollare",
    "affollante": "affollare",
    "affollanti": "affollare",
    "affollar": "affollare",
    "affollaron": "affollare",
    "affollarono": "affollare",
    "affollasse": "affollare",
    "affollasser": "affollare",
    "affollassero": "affollare",
    "affollassi": "affollare",
    "affollassimo": "affollare",
    "affollaste": "affollare",
    "affollasti": "affollare",
    "affollata": "affollato",
    "affollate": "affollato",
    "affollati": "affollato",
    "affollato": "affollare",
    "affollava": "affollare",
    "affollavamo": "affollare",
    "affollavan": "affollare",
    "affollavano": "affollare",
    "affollavate": "affollare",
    "affollavi": "affollare",
    "affollavo": "affollare",
    "affollerai": "affollare",
    "affolleran": "affollare",
    "affolleranno": "affollare",
    "affollerebbe": "affollare",
    "affollerebber": "affollare",
    "affollerebbero": "affollare",
    "affollerei": "affollare",
    "affolleremmo": "affollare",
    "affolleremo": "affollare",
    "affollereste": "affollare",
    "affolleresti": "affollare",
    "affollerete": "affollare",
    "affollerà": "affollare",
    "affollerò": "affollare",
    "affolli": "affollare",
    "affolliamo": "affollare",
    "affolliate": "affollare",
    "affollin": "affollare",
    "affollino": "affollare",
    "affollo": "affollare",
    "affollò": "affollare",
    "affonda": "affondare",
    "affondai": "affondare",
    "affondammo": "affondare",
    "affondan": "affondare",
    "affondando": "affondare",
    "affondano": "affondare",
    "affondante": "affondare",
    "affondanti": "affondare",
    "affondar": "affondare",
    "affondaron": "affondare",
    "affondarono": "affondare",
    "affondasse": "affondare",
    "affondasser": "affondare",
    "affondassero": "affondare",
    "affondassi": "affondare",
    "affondassimo": "affondare",
    "affondaste": "affondare",
    "affondasti": "affondare",
    "affondata": "affondare",
    "affondate": "affondare",
    "affondati": "affondare",
    "affondato": "affondare",
    "affondava": "affondare",
    "affondavamo": "affondare",
    "affondavan": "affondare",
    "affondavano": "affondare",
    "affondavate": "affondare",
    "affondavi": "affondare",
    "affondavo": "affondare",
    "affonderai": "affondare",
    "affonderan": "affondare",
    "affonderanno": "affondare",
    "affonderebbe": "affondare",
    "affonderebber": "affondare",
    "affonderebbero": "affondare",
    "affonderei": "affondare",
    "affonderemmo": "affondare",
    "affonderemo": "affondare",
    "affondereste": "affondare",
    "affonderesti": "affondare",
    "affonderete": "affondare",
    "affonderà": "affondare",
    "affonderò": "affondare",
    "affondi": "affondo",
    "affondiamo": "affondare",
    "affondiate": "affondare",
    "affondin": "affondare",
    "affondino": "affondare",
    "affondo": "affondare",
    "affondò": "affondare",
    "affossa": "affossare",
    "affossai": "affossare",
    "affossamenti": "affossamento",
    "affossammo": "affossare",
    "affossan": "affossare",
    "affossando": "affossare",
    "affossano": "affossare",
    "affossante": "affossare",
    "affossanti": "affossare",
    "affossar": "affossare",
    "affossaron": "affossare",
    "affossarono": "affossare",
    "affossasse": "affossare",
    "affossasser": "affossare",
    "affossassero": "affossare",
    "affossassi": "affossare",
    "affossassimo": "affossare",
    "affossaste": "affossare",
    "affossasti": "affossare",
    "affossata": "affossare",
    "affossate": "affossare",
    "affossati": "affossare",
    "affossato": "affossare",
    "affossatori": "affossatore",
    "affossava": "affossare",
    "affossavamo": "affossare",
    "affossavan": "affossare",
    "affossavano": "affossare",
    "affossavate": "affossare",
    "affossavi": "affossare",
    "affossavo": "affossare",
    "affosserai": "affossare",
    "affosseran": "affossare",
    "affosseranno": "affossare",
    "affosserebbe": "affossare",
    "affosserebber": "affossare",
    "affosserebbero": "affossare",
    "affosserei": "affossare",
    "affosseremmo": "affossare",
    "affosseremo": "affossare",
    "affossereste": "affossare",
    "affosseresti": "affossare",
    "affosserete": "affossare",
    "affosserà": "affossare",
    "affosserò": "affossare",
    "affossi": "affossare",
    "affossiamo": "affossare",
    "affossiate": "affossare",
    "affossin": "affossare",
    "affossino": "affossare",
    "affosso": "affossare",
    "affossò": "affossare",
    "affranca": "affrancare",
    "affrancai": "affrancare",
    "affrancammo": "affrancare",
    "affrancan": "affrancare",
    "affrancando": "affrancare",
    "affrancano": "affrancare",
    "affrancante": "affrancare",
    "affrancanti": "affrancare",
    "affrancar": "affrancare",
    "affrancaron": "affrancare",
    "affrancarono": "affrancare",
    "affrancasse": "affrancare",
    "affrancasser": "affrancare",
    "affrancassero": "affrancare",
    "affrancassi": "affrancare",
    "affrancassimo": "affrancare",
    "affrancaste": "affrancare",
    "affrancasti": "affrancare",
    "affrancata": "affrancare",
    "affrancate": "affrancare",
    "affrancati": "affrancare",
    "affrancato": "affrancare",
    "affrancava": "affrancare",
    "affrancavamo": "affrancare",
    "affrancavan": "affrancare",
    "affrancavano": "affrancare",
    "affrancavate": "affrancare",
    "affrancavi": "affrancare",
    "affrancavo": "affrancare",
    "affrancherai": "affrancare",
    "affrancheran": "affrancare",
    "affrancheranno": "affrancare",
    "affrancherebbe": "affrancare",
    "affrancherebber": "affrancare",
    "affrancherebbero": "affrancare",
    "affrancherei": "affrancare",
    "affrancheremmo": "affrancare",
    "affrancheremo": "affrancare",
    "affranchereste": "affrancare",
    "affrancheresti": "affrancare",
    "affrancherete": "affrancare",
    "affrancherà": "affrancare",
    "affrancherò": "affrancare",
    "affranchi": "affrancare",
    "affranchiamo": "affrancare",
    "affranchiate": "affrancare",
    "affranchin": "affrancare",
    "affranchino": "affrancare",
    "affranco": "affrancare",
    "affrancò": "affrancare",
    "affranta": "affranto",
    "affrante": "affranto",
    "affranti": "affranto",
    "affratella": "affratellare",
    "affratellai": "affratellare",
    "affratellammo": "affratellare",
    "affratellan": "affratellare",
    "affratellando": "affratellare",
    "affratellano": "affratellare",
    "affratellante": "affratellare",
    "affratellanti": "affratellare",
    "affratellar": "affratellare",
    "affratellaron": "affratellare",
    "affratellarono": "affratellare",
    "affratellasse": "affratellare",
    "affratellasser": "affratellare",
    "affratellassero": "affratellare",
    "affratellassi": "affratellare",
    "affratellassimo": "affratellare",
    "affratellaste": "affratellare",
    "affratellasti": "affratellare",
    "affratellata": "affratellare",
    "affratellate": "affratellare",
    "affratellati": "affratellare",
    "affratellato": "affratellare",
    "affratellava": "affratellare",
    "affratellavamo": "affratellare",
    "affratellavan": "affratellare",
    "affratellavano": "affratellare",
    "affratellavate": "affratellare",
    "affratellavi": "affratellare",
    "affratellavo": "affratellare",
    "affratellerai": "affratellare",
    "affratelleran": "affratellare",
    "affratelleranno": "affratellare",
    "affratellerebbe": "affratellare",
    "affratellerebber": "affratellare",
    "affratellerebbero": "affratellare",
    "affratellerei": "affratellare",
    "affratelleremmo": "affratellare",
    "affratelleremo": "affratellare",
    "affratellereste": "affratellare",
    "affratelleresti": "affratellare",
    "affratellerete": "affratellare",
    "affratellerà": "affratellare",
    "affratellerò": "affratellare",
    "affratelli": "affratellare",
    "affratelliamo": "affratellare",
    "affratelliate": "affratellare",
    "affratellin": "affratellare",
    "affratellino": "affratellare",
    "affratello": "affratellare",
    "affratellò": "affratellare",
    "affresca": "affrescare",
    "affrescai": "affrescare",
    "affrescammo": "affrescare",
    "affrescan": "affrescare",
    "affrescando": "affrescare",
    "affrescano": "affrescare",
    "affrescante": "affrescare",
    "affrescanti": "affrescare",
    "affrescar": "affrescare",
    "affrescaron": "affrescare",
    "affrescarono": "affrescare",
    "affrescasse": "affrescare",
    "affrescasser": "affrescare",
    "affrescassero": "affrescare",
    "affrescassi": "affrescare",
    "affrescassimo": "affrescare",
    "affrescaste": "affrescare",
    "affrescasti": "affrescare",
    "affrescata": "affrescare",
    "affrescate": "affrescare",
    "affrescati": "affrescare",
    "affrescato": "affrescare",
    "affrescava": "affrescare",
    "affrescavamo": "affrescare",
    "affrescavan": "affrescare",
    "affrescavano": "affrescare",
    "affrescavate": "affrescare",
    "affrescavi": "affrescare",
    "affrescavo": "affrescare",
    "affrescherai": "affrescare",
    "affrescheran": "affrescare",
    "affrescheranno": "affrescare",
    "affrescherebbe": "affrescare",
    "affrescherebber": "affrescare",
    "affrescherebbero": "affrescare",
    "affrescherei": "affrescare",
    "affrescheremmo": "affrescare",
    "affrescheremo": "affrescare",
    "affreschereste": "affrescare",
    "affrescheresti": "affrescare",
    "affrescherete": "affrescare",
    "affrescherà": "affrescare",
    "affrescherò": "affrescare",
    "affreschi": "affresco",
    "affreschiamo": "affrescare",
    "affreschiate": "affrescare",
    "affreschin": "affrescare",
    "affreschino": "affrescare",
    "affresco": "affrescare",
    "affrescò": "affrescare",
    "affretta": "affrettare",
    "affrettai": "affrettare",
    "affrettammo": "affrettare",
    "affrettan": "affrettare",
    "affrettando": "affrettare",
    "affrettano": "affrettare",
    "affrettante": "affrettare",
    "affrettanti": "affrettare",
    "affrettar": "affrettare",
    "affrettaron": "affrettare",
    "affrettarono": "affrettare",
    "affrettasse": "affrettare",
    "affrettasser": "affrettare",
    "affrettassero": "affrettare",
    "affrettassi": "affrettare",
    "affrettassimo": "affrettare",
    "affrettaste": "affrettare",
    "affrettasti": "affrettare",
    "affrettata": "affrettato",
    "affrettate": "affrettato",
    "affrettati": "affrettato",
    "affrettato": "affrettare",
    "affrettava": "affrettare",
    "affrettavamo": "affrettare",
    "affrettavan": "affrettare",
    "affrettavano": "affrettare",
    "affrettavate": "affrettare",
    "affrettavi": "affrettare",
    "affrettavo": "affrettare",
    "affretterai": "affrettare",
    "affretteran": "affrettare",
    "affretteranno": "affrettare",
    "affretterebbe": "affrettare",
    "affretterebber": "affrettare",
    "affretterebbero": "affrettare",
    "affretterei": "affrettare",
    "affretteremmo": "affrettare",
    "affretteremo": "affrettare",
    "affrettereste": "affrettare",
    "affretteresti": "affrettare",
    "affretterete": "affrettare",
    "affretterà": "affrettare",
    "affretterò": "affrettare",
    "affretti": "affrettare",
    "affrettiamo": "affrettare",
    "affrettiate": "affrettare",
    "affrettin": "affrettare",
    "affrettino": "affrettare",
    "affretto": "affrettare",
    "affrettò": "affrettare",
    "affronta": "affrontare",
    "affrontai": "affrontare",
    "affrontammo": "affrontare",
    "affrontan": "affrontare",
    "affrontando": "affrontare",
    "affrontano": "affrontare",
    "affrontante": "affrontare",
    "affrontanti": "affrontare",
    "affrontar": "affrontare",
    "affrontaron": "affrontare",
    "affrontarono": "affrontare",
    "affrontasse": "affrontare",
    "affrontasser": "affrontare",
    "affrontassero": "affrontare",
    "affrontassi": "affrontare",
    "affrontassimo": "affrontare",
    "affrontaste": "affrontare",
    "affrontasti": "affrontare",
    "affrontata": "affrontato",
    "affrontate": "affrontato",
    "affrontati": "affrontato",
    "affrontato": "affrontare",
    "affrontava": "affrontare",
    "affrontavamo": "affrontare",
    "affrontavan": "affrontare",
    "affrontavano": "affrontare",
    "affrontavate": "affrontare",
    "affrontavi": "affrontare",
    "affrontavo": "affrontare",
    "affronterai": "affrontare",
    "affronteran": "affrontare",
    "affronteranno": "affrontare",
    "affronterebbe": "affrontare",
    "affronterebber": "affrontare",
    "affronterebbero": "affrontare",
    "affronterei": "affrontare",
    "affronteremmo": "affrontare",
    "affronteremo": "affrontare",
    "affrontereste": "affrontare",
    "affronteresti": "affrontare",
    "affronterete": "affrontare",
    "affronterà": "affrontare",
    "affronterò": "affrontare",
    "affronti": "affronto",
    "affrontiamo": "affrontare",
    "affrontiate": "affrontare",
    "affrontin": "affrontare",
    "affrontino": "affrontare",
    "affronto": "affrontare",
    "affrontò": "affrontare",
    "affumica": "affumicare",
    "affumicai": "affumicare",
    "affumicammo": "affumicare",
    "affumican": "affumicare",
    "affumicando": "affumicare",
    "affumicano": "affumicare",
    "affumicante": "affumicare",
    "affumicanti": "affumicare",
    "affumicar": "affumicare",
    "affumicaron": "affumicare",
    "affumicarono": "affumicare",
    "affumicasse": "affumicare",
    "affumicasser": "affumicare",
    "affumicassero": "affumicare",
    "affumicassi": "affumicare",
    "affumicassimo": "affumicare",
    "affumicaste": "affumicare",
    "affumicasti": "affumicare",
    "affumicata": "affumicato",
    "affumicate": "affumicato",
    "affumicati": "affumicato",
    "affumicato": "affumicare",
    "affumicava": "affumicare",
    "affumicavamo": "affumicare",
    "affumicavan": "affumicare",
    "affumicavano": "affumicare",
    "affumicavate": "affumicare",
    "affumicavi": "affumicare",
    "affumicavo": "affumicare",
    "affumicherai": "affumicare",
    "affumicheran": "affumicare",
    "affumicheranno": "affumicare",
    "affumicherebbe": "affumicare",
    "affumicherebber": "affumicare",
    "affumicherebbero": "affumicare",
    "affumicherei": "affumicare",
    "affumicheremmo": "affumicare",
    "affumicheremo": "affumicare",
    "affumichereste": "affumicare",
    "affumicheresti": "affumicare",
    "affumicherete": "affumicare",
    "affumicherà": "affumicare",
    "affumicherò": "affumicare",
    "affumichi": "affumicare",
    "affumichiamo": "affumicare",
    "affumichiate": "affumicare",
    "affumichin": "affumicare",
    "affumichino": "affumicare",
    "affumico": "affumicare",
    "affumicò": "affumicare",
    "affusola": "affusolare",
    "affusolai": "affusolare",
    "affusolammo": "affusolare",
    "affusolan": "affusolare",
    "affusolando": "affusolare",
    "affusolano": "affusolare",
    "affusolante": "affusolare",
    "affusolanti": "affusolare",
    "affusolar": "affusolare",
    "affusolaron": "affusolare",
    "affusolarono": "affusolare",
    "affusolasse": "affusolare",
    "affusolasser": "affusolare",
    "affusolassero": "affusolare",
    "affusolassi": "affusolare",
    "affusolassimo": "affusolare",
    "affusolaste": "affusolare",
    "affusolasti": "affusolare",
    "affusolata": "affusolato",
    "affusolate": "affusolato",
    "affusolati": "affusolato",
    "affusolato": "affusolare",
    "affusolava": "affusolare",
    "affusolavamo": "affusolare",
    "affusolavan": "affusolare",
    "affusolavano": "affusolare",
    "affusolavate": "affusolare",
    "affusolavi": "affusolare",
    "affusolavo": "affusolare",
    "affusolerai": "affusolare",
    "affusoleran": "affusolare",
    "affusoleranno": "affusolare",
    "affusolerebbe": "affusolare",
    "affusolerebber": "affusolare",
    "affusolerebbero": "affusolare",
    "affusolerei": "affusolare",
    "affusoleremmo": "affusolare",
    "affusoleremo": "affusolare",
    "affusolereste": "affusolare",
    "affusoleresti": "affusolare",
    "affusolerete": "affusolare",
    "affusolerà": "affusolare",
    "affusolerò": "affusolare",
    "affusoli": "affusolare",
    "affusoliamo": "affusolare",
    "affusoliate": "affusolare",
    "affusolin": "affusolare",
    "affusolino": "affusolare",
    "affusolo": "affusolare",
    "affusolò": "affusolare",
    "affò": "affare",
    "afghana": "afghano",
    "afghane": "afghano",
    "afghani": "afghano",
    "aficionados": "aficionado",
    "afona": "afono",
    "afone": "afono",
    "afoni": "afono",
    "aforismi": "aforisma",
    "afosa": "afoso",
    "afose": "afoso",
    "afosi": "afoso",
    "afra": "afro",
    "afre": "afro",
    "afri": "afro",
    "africa": "africo",
    "africana": "africano",
    "africane": "africano",
    "africani": "africano",
    "afriche": "africo",
    "africi": "africo",
    "afro-americana": "afro-americano",
    "afro-americane": "afro-americano",
    "afro-americani": "afro-americano",
    "afro-asiatica": "afro-asiatico",
    "afro-asiatiche": "afro-asiatico",
    "afro-asiatici": "afro-asiatico",
    "afro-iberica": "afro-iberico",
    "afro-iberiche": "afro-iberico",
    "afro-iberici": "afro-iberico",
    "afro-mediterranea": "afro-mediterraneo",
    "afro-mediterranee": "afro-mediterraneo",
    "afro-mediterranei": "afro-mediterraneo",
    "afro-polacca": "afro-polacco",
    "afro-polacche": "afro-polacco",
    "afro-polacchi": "afro-polacco",
    "afro-tedesca": "afro-tedesco",
    "afro-tedesche": "afro-tedesco",
    "afro-tedeschi": "afro-tedesco",
    "afroamericana": "afroamericano",
    "afroamericane": "afroamericano",
    "afroamericani": "afroamericano",
    "afrodisiaci": "afrodisiaco",
    "afrori": "afrore",
    "agapi": "agape",
    "agende": "agenda",
    "agendine": "agendina",
    "agendo": "agire",
    "agente": "agire",
    "agenti": "agire",
    "agenzie": "agenzia",
    "agevola": "agevolare",
    "agevolai": "agevolare",
    "agevolammo": "agevolare",
    "agevolan": "agevolare",
    "agevolando": "agevolare",
    "agevolano": "agevolare",
    "agevolante": "agevolare",
    "agevolanti": "agevolare",
    "agevolar": "agevolare",
    "agevolaron": "agevolare",
    "agevolarono": "agevolare",
    "agevolasse": "agevolare",
    "agevolasser": "agevolare",
    "agevolassero": "agevolare",
    "agevolassi": "agevolare",
    "agevolassimo": "agevolare",
    "agevolaste": "agevolare",
    "agevolasti": "agevolare",
    "agevolata": "agevolare",
    "agevolate": "agevolare",
    "agevolati": "agevolare",
    "agevolativa": "agevolativo",
    "agevolative": "agevolativo",
    "agevolativi": "agevolativo",
    "agevolato": "agevolare",
    "agevolava": "agevolare",
    "agevolavamo": "agevolare",
    "agevolavan": "agevolare",
    "agevolavano": "agevolare",
    "agevolavate": "agevolare",
    "agevolavi": "agevolare",
    "agevolavo": "agevolare",
    "agevolazioni": "agevolazione",
    "agevolerai": "agevolare",
    "agevoleran": "agevolare",
    "agevoleranno": "agevolare",
    "agevolerebbe": "agevolare",
    "agevolerebber": "agevolare",
    "agevolerebbero": "agevolare",
    "agevolerei": "agevolare",
    "agevoleremmo": "agevolare",
    "agevoleremo": "agevolare",
    "agevolereste": "agevolare",
    "agevoleresti": "agevolare",
    "agevolerete": "agevolare",
    "agevolerà": "agevolare",
    "agevolerò": "agevolare",
    "agevoli": "agevole",
    "agevoliamo": "agevolare",
    "agevoliate": "agevolare",
    "agevolin": "agevolare",
    "agevolino": "agevolare",
    "agevolo": "agevolare",
    "agevolò": "agevolare",
    "aggancerai": "agganciare",
    "agganceran": "agganciare",
    "agganceranno": "agganciare",
    "aggancerebbe": "agganciare",
    "aggancerebber": "agganciare",
    "aggancerebbero": "agganciare",
    "aggancerei": "agganciare",
    "agganceremmo": "agganciare",
    "agganceremo": "agganciare",
    "aggancereste": "agganciare",
    "agganceresti": "agganciare",
    "aggancerete": "agganciare",
    "aggancerà": "agganciare",
    "aggancerò": "agganciare",
    "agganci": "aggancio",
    "aggancia": "agganciare",
    "agganciabili": "agganciabile",
    "agganciai": "agganciare",
    "agganciammo": "agganciare",
    "agganciamo": "agganciare",
    "aggancian": "agganciare",
    "agganciando": "agganciare",
    "agganciano": "agganciare",
    "agganciante": "agganciare",
    "aggancianti": "agganciare",
    "agganciar": "agganciare",
    "agganciaron": "agganciare",
    "agganciarono": "agganciare",
    "agganciasse": "agganciare",
    "agganciasser": "agganciare",
    "agganciassero": "agganciare",
    "agganciassi": "agganciare",
    "agganciassimo": "agganciare",
    "agganciaste": "agganciare",
    "agganciasti": "agganciare",
    "agganciata": "agganciare",
    "agganciate": "agganciare",
    "agganciati": "agganciare",
    "agganciato": "agganciare",
    "agganciava": "agganciare",
    "agganciavamo": "agganciare",
    "agganciavan": "agganciare",
    "agganciavano": "agganciare",
    "agganciavate": "agganciare",
    "agganciavi": "agganciare",
    "agganciavo": "agganciare",
    "aggancin": "agganciare",
    "aggancino": "agganciare",
    "aggancio": "agganciare",
    "agganciò": "agganciare",
    "aggeggi": "aggeggio",
    "aggetta": "aggettare",
    "aggettai": "aggettare",
    "aggettammo": "aggettare",
    "aggettan": "aggettare",
    "aggettando": "aggettare",
    "aggettano": "aggettare",
    "aggettante": "aggettare",
    "aggettanti": "aggettare",
    "aggettar": "aggettare",
    "aggettaron": "aggettare",
    "aggettarono": "aggettare",
    "aggettasse": "aggettare",
    "aggettasser": "aggettare",
    "aggettassero": "aggettare",
    "aggettassi": "aggettare",
    "aggettassimo": "aggettare",
    "aggettaste": "aggettare",
    "aggettasti": "aggettare",
    "aggettata": "aggettare",
    "aggettate": "aggettare",
    "aggettati": "aggettare",
    "aggettato": "aggettare",
    "aggettava": "aggettare",
    "aggettavamo": "aggettare",
    "aggettavan": "aggettare",
    "aggettavano": "aggettare",
    "aggettavate": "aggettare",
    "aggettavi": "aggettare",
    "aggettavo": "aggettare",
    "aggetterai": "aggettare",
    "aggetteran": "aggettare",
    "aggetteranno": "aggettare",
    "aggetterebbe": "aggettare",
    "aggetterebber": "aggettare",
    "aggetterebbero": "aggettare",
    "aggetterei": "aggettare",
    "aggetteremmo": "aggettare",
    "aggetteremo": "aggettare",
    "aggettereste": "aggettare",
    "aggetteresti": "aggettare",
    "aggetterete": "aggettare",
    "aggetterà": "aggettare",
    "aggetterò": "aggettare",
    "aggetti": "aggettare",
    "aggettiamo": "aggettare",
    "aggettiate": "aggettare",
    "aggettin": "aggettare",
    "aggettino": "aggettare",
    "aggettiva": "aggettivare",
    "aggettivai": "aggettivare",
    "aggettivammo": "aggettivare",
    "aggettivan": "aggettivare",
    "aggettivando": "aggettivare",
    "aggettivano": "aggettivare",
    "aggettivante": "aggettivare",
    "aggettivanti": "aggettivare",
    "aggettivar": "aggettivare",
    "aggettivaron": "aggettivare",
    "aggettivarono": "aggettivare",
    "aggettivasse": "aggettivare",
    "aggettivasser": "aggettivare",
    "aggettivassero": "aggettivare",
    "aggettivassi": "aggettivare",
    "aggettivassimo": "aggettivare",
    "aggettivaste": "aggettivare",
    "aggettivasti": "aggettivare",
    "aggettivata": "aggettivare",
    "aggettivate": "aggettivare",
    "aggettivati": "aggettivare",
    "aggettivato": "aggettivare",
    "aggettivava": "aggettivare",
    "aggettivavamo": "aggettivare",
    "aggettivavan": "aggettivare",
    "aggettivavano": "aggettivare",
    "aggettivavate": "aggettivare",
    "aggettivavi": "aggettivare",
    "aggettivavo": "aggettivare",
    "aggettivazioni": "aggettivazione",
    "aggettiverai": "aggettivare",
    "aggettiveran": "aggettivare",
    "aggettiveranno": "aggettivare",
    "aggettiverebbe": "aggettivare",
    "aggettiverebber": "aggettivare",
    "aggettiverebbero": "aggettivare",
    "aggettiverei": "aggettivare",
    "aggettiveremmo": "aggettivare",
    "aggettiveremo": "aggettivare",
    "aggettivereste": "aggettivare",
    "aggettiveresti": "aggettivare",
    "aggettiverete": "aggettivare",
    "aggettiverà": "aggettivare",
    "aggettiverò": "aggettivare",
    "aggettivi": "aggettivo",
    "aggettiviamo": "aggettivare",
    "aggettiviate": "aggettivare",
    "aggettivin": "aggettivare",
    "aggettivino": "aggettivare",
    "aggettivo": "aggettivare",
    "aggettivò": "aggettivare",
    "aggetto": "aggettare",
    "aggettò": "aggettare",
    "agghiaccerai": "agghiacciare",
    "agghiacceran": "agghiacciare",
    "agghiacceranno": "agghiacciare",
    "agghiaccerebbe": "agghiacciare",
    "agghiaccerebber": "agghiacciare",
    "agghiaccerebbero": "agghiacciare",
    "agghiaccerei": "agghiacciare",
    "agghiacceremmo": "agghiacciare",
    "agghiacceremo": "agghiacciare",
    "agghiaccereste": "agghiacciare",
    "agghiacceresti": "agghiacciare",
    "agghiaccerete": "agghiacciare",
    "agghiaccerà": "agghiacciare",
    "agghiaccerò": "agghiacciare",
    "agghiacci": "agghiacciare",
    "agghiaccia": "agghiacciare",
    "agghiacciai": "agghiacciare",
    "agghiacciammo": "agghiacciare",
    "agghiacciamo": "agghiacciare",
    "agghiaccian": "agghiacciare",
    "agghiacciando": "agghiacciare",
    "agghiacciano": "agghiacciare",
    "agghiacciante": "agghiacciare",
    "agghiaccianti": "agghiacciare",
    "agghiacciar": "agghiacciare",
    "agghiacciaron": "agghiacciare",
    "agghiacciarono": "agghiacciare",
    "agghiacciasse": "agghiacciare",
    "agghiacciasser": "agghiacciare",
    "agghiacciassero": "agghiacciare",
    "agghiacciassi": "agghiacciare",
    "agghiacciassimo": "agghiacciare",
    "agghiacciaste": "agghiacciare",
    "agghiacciasti": "agghiacciare",
    "agghiacciata": "agghiacciare",
    "agghiacciate": "agghiacciare",
    "agghiacciati": "agghiacciare",
    "agghiacciato": "agghiacciare",
    "agghiacciava": "agghiacciare",
    "agghiacciavamo": "agghiacciare",
    "agghiacciavan": "agghiacciare",
    "agghiacciavano": "agghiacciare",
    "agghiacciavate": "agghiacciare",
    "agghiacciavi": "agghiacciare",
    "agghiacciavo": "agghiacciare",
    "agghiaccin": "agghiacciare",
    "agghiaccino": "agghiacciare",
    "agghiaccio": "agghiacciare",
    "agghiacciò": "agghiacciare",
    "agghinda": "agghindare",
    "agghindai": "agghindare",
    "agghindammo": "agghindare",
    "agghindan": "agghindare",
    "agghindando": "agghindare",
    "agghindano": "agghindare",
    "agghindante": "agghindare",
    "agghindanti": "agghindare",
    "agghindar": "agghindare",
    "agghindaron": "agghindare",
    "agghindarono": "agghindare",
    "agghindasse": "agghindare",
    "agghindasser": "agghindare",
    "agghindassero": "agghindare",
    "agghindassi": "agghindare",
    "agghindassimo": "agghindare",
    "agghindaste": "agghindare",
    "agghindasti": "agghindare",
    "agghindata": "agghindare",
    "agghindate": "agghindare",
    "agghindati": "agghindare",
    "agghindato": "agghindare",
    "agghindava": "agghindare",
    "agghindavamo": "agghindare",
    "agghindavan": "agghindare",
    "agghindavano": "agghindare",
    "agghindavate": "agghindare",
    "agghindavi": "agghindare",
    "agghindavo": "agghindare",
    "agghinderai": "agghindare",
    "agghinderan": "agghindare",
    "agghinderanno": "agghindare",
    "agghinderebbe": "agghindare",
    "agghinderebber": "agghindare",
    "agghinderebbero": "agghindare",
    "agghinderei": "agghindare",
    "agghinderemmo": "agghindare",
    "agghinderemo": "agghindare",
    "agghindereste": "agghindare",
    "agghinderesti": "agghindare",
    "agghinderete": "agghindare",
    "agghinderà": "agghindare",
    "agghinderò": "agghindare",
    "agghindi": "agghindare",
    "agghindiamo": "agghindare",
    "agghindiate": "agghindare",
    "agghindin": "agghindare",
    "agghindino": "agghindare",
    "agghindo": "agghindare",
    "agghindò": "agghindare",
    "aggioga": "aggiogare",
    "aggiogai": "aggiogare",
    "aggiogammo": "aggiogare",
    "aggiogan": "aggiogare",
    "aggiogando": "aggiogare",
    "aggiogano": "aggiogare",
    "aggiogante": "aggiogare",
    "aggioganti": "aggiogare",
    "aggiogar": "aggiogare",
    "aggiogaron": "aggiogare",
    "aggiogarono": "aggiogare",
    "aggiogasse": "aggiogare",
    "aggiogasser": "aggiogare",
    "aggiogassero": "aggiogare",
    "aggiogassi": "aggiogare",
    "aggiogassimo": "aggiogare",
    "aggiogaste": "aggiogare",
    "aggiogasti": "aggiogare",
    "aggiogata": "aggiogare",
    "aggiogate": "aggiogare",
    "aggiogati": "aggiogare",
    "aggiogato": "aggiogare",
    "aggiogava": "aggiogare",
    "aggiogavamo": "aggiogare",
    "aggiogavan": "aggiogare",
    "aggiogavano": "aggiogare",
    "aggiogavate": "aggiogare",
    "aggiogavi": "aggiogare",
    "aggiogavo": "aggiogare",
    "aggiogherai": "aggiogare",
    "aggiogheran": "aggiogare",
    "aggiogheranno": "aggiogare",
    "aggiogherebbe": "aggiogare",
    "aggiogherebber": "aggiogare",
    "aggiogherebbero": "aggiogare",
    "aggiogherei": "aggiogare",
    "aggiogheremmo": "aggiogare",
    "aggiogheremo": "aggiogare",
    "aggioghereste": "aggiogare",
    "aggiogheresti": "aggiogare",
    "aggiogherete": "aggiogare",
    "aggiogherà": "aggiogare",
    "aggiogherò": "aggiogare",
    "aggioghi": "aggiogare",
    "aggioghiamo": "aggiogare",
    "aggioghiate": "aggiogare",
    "aggioghin": "aggiogare",
    "aggioghino": "aggiogare",
    "aggiogo": "aggiogare",
    "aggiogò": "aggiogare",
    "aggiorna": "aggiornare",
    "aggiornai": "aggiornare",
    "aggiornamenti": "aggiornamento",
    "aggiornammo": "aggiornare",
    "aggiornan": "aggiornare",
    "aggiornando": "aggiornare",
    "aggiornano": "aggiornare",
    "aggiornante": "aggiornare",
    "aggiornanti": "aggiornare",
    "aggiornar": "aggiornare",
    "aggiornaron": "aggiornare",
    "aggiornarono": "aggiornare",
    "aggiornasse": "aggiornare",
    "aggiornasser": "aggiornare",
    "aggiornassero": "aggiornare",
    "aggiornassi": "aggiornare",
    "aggiornassimo": "aggiornare",
    "aggiornaste": "aggiornare",
    "aggiornasti": "aggiornare",
    "aggiornata": "aggiornato",
    "aggiornate": "aggiornato",
    "aggiornati": "aggiornato",
    "aggiornato": "aggiornare",
    "aggiornava": "aggiornare",
    "aggiornavamo": "aggiornare",
    "aggiornavan": "aggiornare",
    "aggiornavano": "aggiornare",
    "aggiornavate": "aggiornare",
    "aggiornavi": "aggiornare",
    "aggiornavo": "aggiornare",
    "aggiornerai": "aggiornare",
    "aggiorneran": "aggiornare",
    "aggiorneranno": "aggiornare",
    "aggiornerebbe": "aggiornare",
    "aggiornerebber": "aggiornare",
    "aggiornerebbero": "aggiornare",
    "aggiornerei": "aggiornare",
    "aggiorneremmo": "aggiornare",
    "aggiorneremo": "aggiornare",
    "aggiornereste": "aggiornare",
    "aggiorneresti": "aggiornare",
    "aggiornerete": "aggiornare",
    "aggiornerà": "aggiornare",
    "aggiornerò": "aggiornare",
    "aggiorni": "aggiornare",
    "aggiorniamo": "aggiornare",
    "aggiorniate": "aggiornare",
    "aggiornin": "aggiornare",
    "aggiornino": "aggiornare",
    "aggiorno": "aggiornare",
    "aggiornò": "aggiornare",
    "aggira": "aggirare",
    "aggirabili": "aggirabile",
    "aggirai": "aggirare",
    "aggiramenti": "aggiramento",
    "aggirammo": "aggirare",
    "aggiran": "aggirare",
    "aggirando": "aggirare",
    "aggirano": "aggirare",
    "aggirante": "aggirare",
    "aggiranti": "aggirare",
    "aggirar": "aggirare",
    "aggiraron": "aggirare",
    "aggirarono": "aggirare",
    "aggirasse": "aggirare",
    "aggirasser": "aggirare",
    "aggirassero": "aggirare",
    "aggirassi": "aggirare",
    "aggirassimo": "aggirare",
    "aggiraste": "aggirare",
    "aggirasti": "aggirare",
    "aggirata": "aggirare",
    "aggirate": "aggirare",
    "aggirati": "aggirare",
    "aggirato": "aggirare",
    "aggirava": "aggirare",
    "aggiravamo": "aggirare",
    "aggiravan": "aggirare",
    "aggiravano": "aggirare",
    "aggiravate": "aggirare",
    "aggiravi": "aggirare",
    "aggiravo": "aggirare",
    "aggirerai": "aggirare",
    "aggireran": "aggirare",
    "aggireranno": "aggirare",
    "aggirerebbe": "aggirare",
    "aggirerebber": "aggirare",
    "aggirerebbero": "aggirare",
    "aggirerei": "aggirare",
    "aggireremmo": "aggirare",
    "aggireremo": "aggirare",
    "aggirereste": "aggirare",
    "aggireresti": "aggirare",
    "aggirerete": "aggirare",
    "aggirerà": "aggirare",
    "aggirerò": "aggirare",
    "aggiri": "aggirare",
    "aggiriamo": "aggirare",
    "aggiriate": "aggirare",
    "aggirin": "aggirare",
    "aggirino": "aggirare",
    "aggiro": "aggirare",
    "aggirò": "aggirare",
    "aggiudica": "aggiudicare",
    "aggiudicai": "aggiudicare",
    "aggiudicammo": "aggiudicare",
    "aggiudican": "aggiudicare",
    "aggiudicando": "aggiudicare",
    "aggiudicano": "aggiudicare",
    "aggiudicante": "aggiudicare",
    "aggiudicanti": "aggiudicare",
    "aggiudicar": "aggiudicare",
    "aggiudicaron": "aggiudicare",
    "aggiudicarono": "aggiudicare",
    "aggiudicasse": "aggiudicare",
    "aggiudicasser": "aggiudicare",
    "aggiudicassero": "aggiudicare",
    "aggiudicassi": "aggiudicare",
    "aggiudicassimo": "aggiudicare",
    "aggiudicaste": "aggiudicare",
    "aggiudicasti": "aggiudicare",
    "aggiudicata": "aggiudicare",
    "aggiudicate": "aggiudicare",
    "aggiudicati": "aggiudicare",
    "aggiudicato": "aggiudicare",
    "aggiudicava": "aggiudicare",
    "aggiudicavamo": "aggiudicare",
    "aggiudicavan": "aggiudicare",
    "aggiudicavano": "aggiudicare",
    "aggiudicavate": "aggiudicare",
    "aggiudicavi": "aggiudicare",
    "aggiudicavo": "aggiudicare",
    "aggiudicazioni": "aggiudicazione",
    "aggiudicherai": "aggiudicare",
    "aggiudicheran": "aggiudicare",
    "aggiudicheranno": "aggiudicare",
    "aggiudicherebbe": "aggiudicare",
    "aggiudicherebber": "aggiudicare",
    "aggiudicherebbero": "aggiudicare",
    "aggiudicherei": "aggiudicare",
    "aggiudicheremmo": "aggiudicare",
    "aggiudicheremo": "aggiudicare",
    "aggiudichereste": "aggiudicare",
    "aggiudicheresti": "aggiudicare",
    "aggiudicherete": "aggiudicare",
    "aggiudicherà": "aggiudicare",
    "aggiudicherò": "aggiudicare",
    "aggiudichi": "aggiudicare",
    "aggiudichiamo": "aggiudicare",
    "aggiudichiate": "aggiudicare",
    "aggiudichin": "aggiudicare",
    "aggiudichino": "aggiudicare",
    "aggiudico": "aggiudicare",
    "aggiudicò": "aggiudicare",
    "aggiunga": "aggiungere",
    "aggiungan": "aggiungere",
    "aggiungano": "aggiungere",
    "aggiunge": "aggiungere",
    "aggiungemmo": "aggiungere",
    "aggiungendo": "aggiungere",
    "aggiungente": "aggiungere",
    "aggiungenti": "aggiungere",
    "aggiunger": "aggiungere",
    "aggiungerai": "aggiungere",
    "aggiungeran": "aggiungere",
    "aggiungeranno": "aggiungere",
    "aggiungerebbe": "aggiungere",
    "aggiungerebber": "aggiungere",
    "aggiungerebbero": "aggiungere",
    "aggiungerei": "aggiungere",
    "aggiungeremmo": "aggiungere",
    "aggiungeremo": "aggiungere",
    "aggiungereste": "aggiungere",
    "aggiungeresti": "aggiungere",
    "aggiungerete": "aggiungere",
    "aggiungerà": "aggiungere",
    "aggiungerò": "aggiungere",
    "aggiungesse": "aggiungere",
    "aggiungesser": "aggiungere",
    "aggiungessero": "aggiungere",
    "aggiungessi": "aggiungere",
    "aggiungessimo": "aggiungere",
    "aggiungeste": "aggiungere",
    "aggiungesti": "aggiungere",
    "aggiungete": "aggiungere",
    "aggiungeva": "aggiungere",
    "aggiungevamo": "aggiungere",
    "aggiungevan": "aggiungere",
    "aggiungevano": "aggiungere",
    "aggiungevate": "aggiungere",
    "aggiungevi": "aggiungere",
    "aggiungevo": "aggiungere",
    "aggiungi": "aggiungere",
    "aggiungiamo": "aggiungere",
    "aggiungiate": "aggiungere",
    "aggiungo": "aggiungere",
    "aggiungon": "aggiungere",
    "aggiungono": "aggiungere",
    "aggiunse": "aggiungere",
    "aggiunser": "aggiungere",
    "aggiunsero": "aggiungere",
    "aggiunsi": "aggiungere",
    "aggiunta": "aggiunto",
    "aggiuntai": "aggiuntare",
    "aggiuntammo": "aggiuntare",
    "aggiuntan": "aggiuntare",
    "aggiuntando": "aggiuntare",
    "aggiuntano": "aggiuntare",
    "aggiuntante": "aggiuntare",
    "aggiuntanti": "aggiuntare",
    "aggiuntar": "aggiuntare",
    "aggiuntaron": "aggiuntare",
    "aggiuntarono": "aggiuntare",
    "aggiuntasse": "aggiuntare",
    "aggiuntasser": "aggiuntare",
    "aggiuntassero": "aggiuntare",
    "aggiuntassi": "aggiuntare",
    "aggiuntassimo": "aggiuntare",
    "aggiuntaste": "aggiuntare",
    "aggiuntasti": "aggiuntare",
    "aggiuntata": "aggiuntare",
    "aggiuntate": "aggiuntare",
    "aggiuntati": "aggiuntare",
    "aggiuntato": "aggiuntare",
    "aggiuntava": "aggiuntare",
    "aggiuntavamo": "aggiuntare",
    "aggiuntavan": "aggiuntare",
    "aggiuntavano": "aggiuntare",
    "aggiuntavate": "aggiuntare",
    "aggiuntavi": "aggiuntare",
    "aggiuntavo": "aggiuntare",
    "aggiunte": "aggiunto",
    "aggiunterai": "aggiuntare",
    "aggiunteran": "aggiuntare",
    "aggiunteranno": "aggiuntare",
    "aggiunterebbe": "aggiuntare",
    "aggiunterebber": "aggiuntare",
    "aggiunterebbero": "aggiuntare",
    "aggiunterei": "aggiuntare",
    "aggiunteremmo": "aggiuntare",
    "aggiunteremo": "aggiuntare",
    "aggiuntereste": "aggiuntare",
    "aggiunteresti": "aggiuntare",
    "aggiunterete": "aggiuntare",
    "aggiunterà": "aggiuntare",
    "aggiunterò": "aggiuntare",
    "aggiunti": "aggiunto",
    "aggiuntiamo": "aggiuntare",
    "aggiuntiate": "aggiuntare",
    "aggiuntin": "aggiuntare",
    "aggiuntino": "aggiuntare",
    "aggiuntiva": "aggiuntivo",
    "aggiuntive": "aggiuntivo",
    "aggiuntivi": "aggiuntivo",
    "aggiunto": "aggiuntare",
    "aggiuntò": "aggiuntare",
    "aggiusta": "aggiustare",
    "aggiustai": "aggiustare",
    "aggiustamenti": "aggiustamento",
    "aggiustammo": "aggiustare",
    "aggiustan": "aggiustare",
    "aggiustando": "aggiustare",
    "aggiustano": "aggiustare",
    "aggiustante": "aggiustare",
    "aggiustanti": "aggiustare",
    "aggiustar": "aggiustare",
    "aggiustaron": "aggiustare",
    "aggiustarono": "aggiustare",
    "aggiustasse": "aggiustare",
    "aggiustasser": "aggiustare",
    "aggiustassero": "aggiustare",
    "aggiustassi": "aggiustare",
    "aggiustassimo": "aggiustare",
    "aggiustaste": "aggiustare",
    "aggiustasti": "aggiustare",
    "aggiustata": "aggiustare",
    "aggiustate": "aggiustare",
    "aggiustati": "aggiustare",
    "aggiustato": "aggiustare",
    "aggiustava": "aggiustare",
    "aggiustavamo": "aggiustare",
    "aggiustavan": "aggiustare",
    "aggiustavano": "aggiustare",
    "aggiustavate": "aggiustare",
    "aggiustavi": "aggiustare",
    "aggiustavo": "aggiustare",
    "aggiusterai": "aggiustare",
    "aggiusteran": "aggiustare",
    "aggiusteranno": "aggiustare",
    "aggiusterebbe": "aggiustare",
    "aggiusterebber": "aggiustare",
    "aggiusterebbero": "aggiustare",
    "aggiusterei": "aggiustare",
    "aggiusteremmo": "aggiustare",
    "aggiusteremo": "aggiustare",
    "aggiustereste": "aggiustare",
    "aggiusteresti": "aggiustare",
    "aggiusterete": "aggiustare",
    "aggiusterà": "aggiustare",
    "aggiusterò": "aggiustare",
    "aggiusti": "aggiustare",
    "aggiustiamo": "aggiustare",
    "aggiustiate": "aggiustare",
    "aggiustin": "aggiustare",
    "aggiustino": "aggiustare",
    "aggiusto": "aggiustare",
    "aggiustò": "aggiustare",
    "agglomera": "agglomerare",
    "agglomerai": "agglomerare",
    "agglomerammo": "agglomerare",
    "agglomeran": "agglomerare",
    "agglomerando": "agglomerare",
    "agglomerano": "agglomerare",
    "agglomerante": "agglomerare",
    "agglomeranti": "agglomerare",
    "agglomerar": "agglomerare",
    "agglomeraron": "agglomerare",
    "agglomerarono": "agglomerare",
    "agglomerasse": "agglomerare",
    "agglomerasser": "agglomerare",
    "agglomerassero": "agglomerare",
    "agglomerassi": "agglomerare",
    "agglomerassimo": "agglomerare",
    "agglomeraste": "agglomerare",
    "agglomerasti": "agglomerare",
    "agglomerata": "agglomerato",
    "agglomerate": "agglomerato",
    "agglomerati": "agglomerato",
    "agglomerato": "agglomerare",
    "agglomerava": "agglomerare",
    "agglomeravamo": "agglomerare",
    "agglomeravan": "agglomerare",
    "agglomeravano": "agglomerare",
    "agglomeravate": "agglomerare",
    "agglomeravi": "agglomerare",
    "agglomeravo": "agglomerare",
    "agglomerazioni": "agglomerazione",
    "agglomererai": "agglomerare",
    "agglomereran": "agglomerare",
    "agglomereranno": "agglomerare",
    "agglomererebbe": "agglomerare",
    "agglomererebber": "agglomerare",
    "agglomererebbero": "agglomerare",
    "agglomererei": "agglomerare",
    "agglomereremmo": "agglomerare",
    "agglomereremo": "agglomerare",
    "agglomerereste": "agglomerare",
    "agglomereresti": "agglomerare",
    "agglomererete": "agglomerare",
    "agglomererà": "agglomerare",
    "agglomererò": "agglomerare",
    "agglomeri": "agglomerare",
    "agglomeriamo": "agglomerare",
    "agglomeriate": "agglomerare",
    "agglomerin": "agglomerare",
    "agglomerino": "agglomerare",
    "agglomero": "agglomerare",
    "agglomerò": "agglomerare",
    "agglutina": "agglutinare",
    "agglutinai": "agglutinare",
    "agglutinammo": "agglutinare",
    "agglutinan": "agglutinare",
    "agglutinando": "agglutinare",
    "agglutinano": "agglutinare",
    "agglutinante": "agglutinare",
    "agglutinanti": "agglutinare",
    "agglutinar": "agglutinare",
    "agglutinaron": "agglutinare",
    "agglutinarono": "agglutinare",
    "agglutinasse": "agglutinare",
    "agglutinasser": "agglutinare",
    "agglutinassero": "agglutinare",
    "agglutinassi": "agglutinare",
    "agglutinassimo": "agglutinare",
    "agglutinaste": "agglutinare",
    "agglutinasti": "agglutinare",
    "agglutinata": "agglutinare",
    "agglutinate": "agglutinare",
    "agglutinati": "agglutinare",
    "agglutinato": "agglutinare",
    "agglutinava": "agglutinare",
    "agglutinavamo": "agglutinare",
    "agglutinavan": "agglutinare",
    "agglutinavano": "agglutinare",
    "agglutinavate": "agglutinare",
    "agglutinavi": "agglutinare",
    "agglutinavo": "agglutinare",
    "agglutinerai": "agglutinare",
    "agglutineran": "agglutinare",
    "agglutineranno": "agglutinare",
    "agglutinerebbe": "agglutinare",
    "agglutinerebber": "agglutinare",
    "agglutinerebbero": "agglutinare",
    "agglutinerei": "agglutinare",
    "agglutineremmo": "agglutinare",
    "agglutineremo": "agglutinare",
    "agglutinereste": "agglutinare",
    "agglutineresti": "agglutinare",
    "agglutinerete": "agglutinare",
    "agglutinerà": "agglutinare",
    "agglutinerò": "agglutinare",
    "agglutini": "agglutinare",
    "agglutiniamo": "agglutinare",
    "agglutiniate": "agglutinare",
    "agglutinin": "agglutinare",
    "agglutinino": "agglutinare",
    "agglutino": "agglutinare",
    "agglutinò": "agglutinare",
    "aggomitola": "aggomitolare",
    "aggomitolai": "aggomitolare",
    "aggomitolammo": "aggomitolare",
    "aggomitolan": "aggomitolare",
    "aggomitolando": "aggomitolare",
    "aggomitolano": "aggomitolare",
    "aggomitolante": "aggomitolare",
    "aggomitolanti": "aggomitolare",
    "aggomitolar": "aggomitolare",
    "aggomitolaron": "aggomitolare",
    "aggomitolarono": "aggomitolare",
    "aggomitolasse": "aggomitolare",
    "aggomitolasser": "aggomitolare",
    "aggomitolassero": "aggomitolare",
    "aggomitolassi": "aggomitolare",
    "aggomitolassimo": "aggomitolare",
    "aggomitolaste": "aggomitolare",
    "aggomitolasti": "aggomitolare",
    "aggomitolata": "aggomitolare",
    "aggomitolate": "aggomitolare",
    "aggomitolati": "aggomitolare",
    "aggomitolato": "aggomitolare",
    "aggomitolava": "aggomitolare",
    "aggomitolavamo": "aggomitolare",
    "aggomitolavan": "aggomitolare",
    "aggomitolavano": "aggomitolare",
    "aggomitolavate": "aggomitolare",
    "aggomitolavi": "aggomitolare",
    "aggomitolavo": "aggomitolare",
    "aggomitolerai": "aggomitolare",
    "aggomitoleran": "aggomitolare",
    "aggomitoleranno": "aggomitolare",
    "aggomitolerebbe": "aggomitolare",
    "aggomitolerebber": "aggomitolare",
    "aggomitolerebbero": "aggomitolare",
    "aggomitolerei": "aggomitolare",
    "aggomitoleremmo": "aggomitolare",
    "aggomitoleremo": "aggomitolare",
    "aggomitolereste": "aggomitolare",
    "aggomitoleresti": "aggomitolare",
    "aggomitolerete": "aggomitolare",
    "aggomitolerà": "aggomitolare",
    "aggomitolerò": "aggomitolare",
    "aggomitoli": "aggomitolare",
    "aggomitoliamo": "aggomitolare",
    "aggomitoliate": "aggomitolare",
    "aggomitolin": "aggomitolare",
    "aggomitolino": "aggomitolare",
    "aggomitolo": "aggomitolare",
    "aggomitolò": "aggomitolare",
    "aggotta": "aggottare",
    "aggottai": "aggottare",
    "aggottammo": "aggottare",
    "aggottan": "aggottare",
    "aggottando": "aggottare",
    "aggottano": "aggottare",
    "aggottante": "aggottare",
    "aggottanti": "aggottare",
    "aggottar": "aggottare",
    "aggottaron": "aggottare",
    "aggottarono": "aggottare",
    "aggottasse": "aggottare",
    "aggottasser": "aggottare",
    "aggottassero": "aggottare",
    "aggottassi": "aggottare",
    "aggottassimo": "aggottare",
    "aggottaste": "aggottare",
    "aggottasti": "aggottare",
    "aggottata": "aggottare",
    "aggottate": "aggottare",
    "aggottati": "aggottare",
    "aggottato": "aggottare",
    "aggottava": "aggottare",
    "aggottavamo": "aggottare",
    "aggottavan": "aggottare",
    "aggottavano": "aggottare",
    "aggottavate": "aggottare",
    "aggottavi": "aggottare",
    "aggottavo": "aggottare",
    "aggotterai": "aggottare",
    "aggotteran": "aggottare",
    "aggotteranno": "aggottare",
    "aggotterebbe": "aggottare",
    "aggotterebber": "aggottare",
    "aggotterebbero": "aggottare",
    "aggotterei": "aggottare",
    "aggotteremmo": "aggottare",
    "aggotteremo": "aggottare",
    "aggottereste": "aggottare",
    "aggotteresti": "aggottare",
    "aggotterete": "aggottare",
    "aggotterà": "aggottare",
    "aggotterò": "aggottare",
    "aggotti": "aggottare",
    "aggottiamo": "aggottare",
    "aggottiate": "aggottare",
    "aggottin": "aggottare",
    "aggottino": "aggottare",
    "aggotto": "aggottare",
    "aggottò": "aggottare",
    "aggrada": "aggradare",
    "aggradai": "aggradare",
    "aggradammo": "aggradare",
    "aggradan": "aggradare",
    "aggradando": "aggradare",
    "aggradano": "aggradare",
    "aggradante": "aggradare",
    "aggradanti": "aggradare",
    "aggradar": "aggradare",
    "aggradaron": "aggradare",
    "aggradarono": "aggradare",
    "aggradasse": "aggradare",
    "aggradasser": "aggradare",
    "aggradassero": "aggradare",
    "aggradassi": "aggradare",
    "aggradassimo": "aggradare",
    "aggradaste": "aggradare",
    "aggradasti": "aggradare",
    "aggradata": "aggradare",
    "aggradate": "aggradare",
    "aggradati": "aggradare",
    "aggradato": "aggradare",
    "aggradava": "aggradare",
    "aggradavamo": "aggradare",
    "aggradavan": "aggradare",
    "aggradavano": "aggradare",
    "aggradavate": "aggradare",
    "aggradavi": "aggradare",
    "aggradavo": "aggradare",
    "aggraderai": "aggradare",
    "aggraderan": "aggradare",
    "aggraderanno": "aggradare",
    "aggraderebbe": "aggradare",
    "aggraderebber": "aggradare",
    "aggraderebbero": "aggradare",
    "aggraderei": "aggradare",
    "aggraderemmo": "aggradare",
    "aggraderemo": "aggradare",
    "aggradereste": "aggradare",
    "aggraderesti": "aggradare",
    "aggraderete": "aggradare",
    "aggraderà": "aggradare",
    "aggraderò": "aggradare",
    "aggradi": "aggradare",
    "aggradiamo": "aggradare",
    "aggradiate": "aggradare",
    "aggradin": "aggradare",
    "aggradino": "aggradare",
    "aggrado": "aggradare",
    "aggradò": "aggradare",
    "aggraffa": "aggraffare",
    "aggraffai": "aggraffare",
    "aggraffammo": "aggraffare",
    "aggraffan": "aggraffare",
    "aggraffando": "aggraffare",
    "aggraffano": "aggraffare",
    "aggraffante": "aggraffare",
    "aggraffanti": "aggraffare",
    "aggraffar": "aggraffare",
    "aggraffaron": "aggraffare",
    "aggraffarono": "aggraffare",
    "aggraffasse": "aggraffare",
    "aggraffasser": "aggraffare",
    "aggraffassero": "aggraffare",
    "aggraffassi": "aggraffare",
    "aggraffassimo": "aggraffare",
    "aggraffaste": "aggraffare",
    "aggraffasti": "aggraffare",
    "aggraffata": "aggraffare",
    "aggraffate": "aggraffare",
    "aggraffati": "aggraffare",
    "aggraffato": "aggraffare",
    "aggraffava": "aggraffare",
    "aggraffavamo": "aggraffare",
    "aggraffavan": "aggraffare",
    "aggraffavano": "aggraffare",
    "aggraffavate": "aggraffare",
    "aggraffavi": "aggraffare",
    "aggraffavo": "aggraffare",
    "aggrafferai": "aggraffare",
    "aggrafferan": "aggraffare",
    "aggrafferanno": "aggraffare",
    "aggrafferebbe": "aggraffare",
    "aggrafferebber": "aggraffare",
    "aggrafferebbero": "aggraffare",
    "aggrafferei": "aggraffare",
    "aggrafferemmo": "aggraffare",
    "aggrafferemo": "aggraffare",
    "aggraffereste": "aggraffare",
    "aggrafferesti": "aggraffare",
    "aggrafferete": "aggraffare",
    "aggrafferà": "aggraffare",
    "aggrafferò": "aggraffare",
    "aggraffi": "aggraffare",
    "aggraffiamo": "aggraffare",
    "aggraffiate": "aggraffare",
    "aggraffin": "aggraffare",
    "aggraffino": "aggraffare",
    "aggraffo": "aggraffare",
    "aggraffò": "aggraffare",
    "aggrancha": "aggranchire",
    "aggranchan": "aggranchire",
    "aggranchano": "aggranchire",
    "aggranche": "aggranchire",
    "aggranchendo": "aggranchire",
    "aggranchente": "aggranchire",
    "aggranchenti": "aggranchire",
    "aggranchi": "aggranchire",
    "aggranchiamo": "aggranchire",
    "aggranchiate": "aggranchire",
    "aggranchii": "aggranchire",
    "aggranchimmo": "aggranchire",
    "aggranchir": "aggranchire",
    "aggranchirai": "aggranchire",
    "aggranchiran": "aggranchire",
    "aggranchiranno": "aggranchire",
    "aggranchirebbe": "aggranchire",
    "aggranchirebber": "aggranchire",
    "aggranchirebbero": "aggranchire",
    "aggranchirei": "aggranchire",
    "aggranchiremmo": "aggranchire",
    "aggranchiremo": "aggranchire",
    "aggranchireste": "aggranchire",
    "aggranchiresti": "aggranchire",
    "aggranchirete": "aggranchire",
    "aggranchiron": "aggranchire",
    "aggranchirono": "aggranchire",
    "aggranchirà": "aggranchire",
    "aggranchirò": "aggranchire",
    "aggranchisse": "aggranchire",
    "aggranchisser": "aggranchire",
    "aggranchissero": "aggranchire",
    "aggranchissi": "aggranchire",
    "aggranchissimo": "aggranchire",
    "aggranchiste": "aggranchire",
    "aggranchisti": "aggranchire",
    "aggranchita": "aggranchire",
    "aggranchite": "aggranchire",
    "aggranchiti": "aggranchire",
    "aggranchito": "aggranchire",
    "aggranchiva": "aggranchire",
    "aggranchivamo": "aggranchire",
    "aggranchivan": "aggranchire",
    "aggranchivano": "aggranchire",
    "aggranchivate": "aggranchire",
    "aggranchivi": "aggranchire",
    "aggranchivo": "aggranchire",
    "aggrancho": "aggranchire",
    "aggranchon": "aggranchire",
    "aggranchono": "aggranchire",
    "aggranchì": "aggranchire",
    "aggrappa": "aggrappare",
    "aggrappai": "aggrappare",
    "aggrappammo": "aggrappare",
    "aggrappan": "aggrappare",
    "aggrappando": "aggrappare",
    "aggrappano": "aggrappare",
    "aggrappante": "aggrappare",
    "aggrappanti": "aggrappare",
    "aggrappar": "aggrappare",
    "aggrapparon": "aggrappare",
    "aggrapparono": "aggrappare",
    "aggrappasse": "aggrappare",
    "aggrappasser": "aggrappare",
    "aggrappassero": "aggrappare",
    "aggrappassi": "aggrappare",
    "aggrappassimo": "aggrappare",
    "aggrappaste": "aggrappare",
    "aggrappasti": "aggrappare",
    "aggrappata": "aggrappare",
    "aggrappate": "aggrappare",
    "aggrappati": "aggrappare",
    "aggrappato": "aggrappare",
    "aggrappava": "aggrappare",
    "aggrappavamo": "aggrappare",
    "aggrappavan": "aggrappare",
    "aggrappavano": "aggrappare",
    "aggrappavate": "aggrappare",
    "aggrappavi": "aggrappare",
    "aggrappavo": "aggrappare",
    "aggrapperai": "aggrappare",
    "aggrapperan": "aggrappare",
    "aggrapperanno": "aggrappare",
    "aggrapperebbe": "aggrappare",
    "aggrapperebber": "aggrappare",
    "aggrapperebbero": "aggrappare",
    "aggrapperei": "aggrappare",
    "aggrapperemmo": "aggrappare",
    "aggrapperemo": "aggrappare",
    "aggrappereste": "aggrappare",
    "aggrapperesti": "aggrappare",
    "aggrapperete": "aggrappare",
    "aggrapperà": "aggrappare",
    "aggrapperò": "aggrappare",
    "aggrappi": "aggrappare",
    "aggrappiamo": "aggrappare",
    "aggrappiate": "aggrappare",
    "aggrappin": "aggrappare",
    "aggrappino": "aggrappare",
    "aggrappo": "aggrappare",
    "aggrappò": "aggrappare",
    "aggrava": "aggravare",
    "aggravai": "aggravare",
    "aggravamenti": "aggravamento",
    "aggravammo": "aggravare",
    "aggravan": "aggravare",
    "aggravando": "aggravare",
    "aggravano": "aggravare",
    "aggravante": "aggravare",
    "aggravanti": "aggravare",
    "aggravar": "aggravare",
    "aggravaron": "aggravare",
    "aggravarono": "aggravare",
    "aggravasse": "aggravare",
    "aggravasser": "aggravare",
    "aggravassero": "aggravare",
    "aggravassi": "aggravare",
    "aggravassimo": "aggravare",
    "aggravaste": "aggravare",
    "aggravasti": "aggravare",
    "aggravata": "aggravato",
    "aggravate": "aggravato",
    "aggravati": "aggravato",
    "aggravato": "aggravare",
    "aggravava": "aggravare",
    "aggravavamo": "aggravare",
    "aggravavan": "aggravare",
    "aggravavano": "aggravare",
    "aggravavate": "aggravare",
    "aggravavi": "aggravare",
    "aggravavo": "aggravare",
    "aggraverai": "aggravare",
    "aggraveran": "aggravare",
    "aggraveranno": "aggravare",
    "aggraverebbe": "aggravare",
    "aggraverebber": "aggravare",
    "aggraverebbero": "aggravare",
    "aggraverei": "aggravare",
    "aggraveremmo": "aggravare",
    "aggraveremo": "aggravare",
    "aggravereste": "aggravare",
    "aggraveresti": "aggravare",
    "aggraverete": "aggravare",
    "aggraverà": "aggravare",
    "aggraverò": "aggravare",
    "aggravi": "aggravio",
    "aggraviamo": "aggravare",
    "aggraviate": "aggravare",
    "aggravin": "aggravare",
    "aggravino": "aggravare",
    "aggravo": "aggravare",
    "aggravò": "aggravare",
    "aggrazi": "aggraziare",
    "aggrazia": "aggraziare",
    "aggraziai": "aggraziare",
    "aggraziammo": "aggraziare",
    "aggraziamo": "aggraziare",
    "aggrazian": "aggraziare",
    "aggraziando": "aggraziare",
    "aggraziano": "aggraziare",
    "aggraziante": "aggraziare",
    "aggrazianti": "aggraziare",
    "aggraziar": "aggraziare",
    "aggraziaron": "aggraziare",
    "aggraziarono": "aggraziare",
    "aggraziasse": "aggraziare",
    "aggraziasser": "aggraziare",
    "aggraziassero": "aggraziare",
    "aggraziassi": "aggraziare",
    "aggraziassimo": "aggraziare",
    "aggraziaste": "aggraziare",
    "aggraziasti": "aggraziare",
    "aggraziata": "aggraziato",
    "aggraziate": "aggraziato",
    "aggraziati": "aggraziato",
    "aggraziato": "aggraziare",
    "aggraziava": "aggraziare",
    "aggraziavamo": "aggraziare",
    "aggraziavan": "aggraziare",
    "aggraziavano": "aggraziare",
    "aggraziavate": "aggraziare",
    "aggraziavi": "aggraziare",
    "aggraziavo": "aggraziare",
    "aggrazierai": "aggraziare",
    "aggrazieran": "aggraziare",
    "aggrazieranno": "aggraziare",
    "aggrazierebbe": "aggraziare",
    "aggrazierebber": "aggraziare",
    "aggrazierebbero": "aggraziare",
    "aggrazierei": "aggraziare",
    "aggrazieremmo": "aggraziare",
    "aggrazieremo": "aggraziare",
    "aggraziereste": "aggraziare",
    "aggrazieresti": "aggraziare",
    "aggrazierete": "aggraziare",
    "aggrazierà": "aggraziare",
    "aggrazierò": "aggraziare",
    "aggrazin": "aggraziare",
    "aggrazino": "aggraziare",
    "aggrazio": "aggraziare",
    "aggraziò": "aggraziare",
    "aggredendo": "aggredire",
    "aggredente": "aggredire",
    "aggredenti": "aggredire",
    "aggrediamo": "aggredire",
    "aggrediate": "aggredire",
    "aggredibili": "aggredibile",
    "aggredii": "aggredire",
    "aggredimmo": "aggredire",
    "aggredir": "aggredire",
    "aggredirai": "aggredire",
    "aggrediran": "aggredire",
    "aggrediranno": "aggredire",
    "aggredirebbe": "aggredire",
    "aggredirebber": "aggredire",
    "aggredirebbero": "aggredire",
    "aggredirei": "aggredire",
    "aggrediremmo": "aggredire",
    "aggrediremo": "aggredire",
    "aggredireste": "aggredire",
    "aggrediresti": "aggredire",
    "aggredirete": "aggredire",
    "aggrediron": "aggredire",
    "aggredirono": "aggredire",
    "aggredirà": "aggredire",
    "aggredirò": "aggredire",
    "aggredisca": "aggredire",
    "aggrediscan": "aggredire",
    "aggrediscano": "aggredire",
    "aggredisce": "aggredire",
    "aggredisci": "aggredire",
    "aggredisco": "aggredire",
    "aggrediscon": "aggredire",
    "aggrediscono": "aggredire",
    "aggredisse": "aggredire",
    "aggredisser": "aggredire",
    "aggredissero": "aggredire",
    "aggredissi": "aggredire",
    "aggredissimo": "aggredire",
    "aggrediste": "aggredire",
    "aggredisti": "aggredire",
    "aggredita": "aggredire",
    "aggredite": "aggredire",
    "aggrediti": "aggredito",
    "aggredito": "aggredire",
    "aggrediva": "aggredire",
    "aggredivamo": "aggredire",
    "aggredivan": "aggredire",
    "aggredivano": "aggredire",
    "aggredivate": "aggredire",
    "aggredivi": "aggredire",
    "aggredivo": "aggredire",
    "aggredì": "aggredire",
    "aggrega": "aggregare",
    "aggregai": "aggregare",
    "aggregammo": "aggregare",
    "aggregan": "aggregare",
    "aggregando": "aggregare",
    "aggregano": "aggregare",
    "aggregante": "aggregare",
    "aggreganti": "aggregare",
    "aggregar": "aggregare",
    "aggregaron": "aggregare",
    "aggregarono": "aggregare",
    "aggregasse": "aggregare",
    "aggregasser": "aggregare",
    "aggregassero": "aggregare",
    "aggregassi": "aggregare",
    "aggregassimo": "aggregare",
    "aggregaste": "aggregare",
    "aggregasti": "aggregare",
    "aggregata": "aggregato",
    "aggregate": "aggregato",
    "aggregati": "aggregato",
    "aggregato": "aggregare",
    "aggregava": "aggregare",
    "aggregavamo": "aggregare",
    "aggregavan": "aggregare",
    "aggregavano": "aggregare",
    "aggregavate": "aggregare",
    "aggregavi": "aggregare",
    "aggregavo": "aggregare",
    "aggregazioni": "aggregazione",
    "aggregherai": "aggregare",
    "aggregheran": "aggregare",
    "aggregheranno": "aggregare",
    "aggregherebbe": "aggregare",
    "aggregherebber": "aggregare",
    "aggregherebbero": "aggregare",
    "aggregherei": "aggregare",
    "aggregheremmo": "aggregare",
    "aggregheremo": "aggregare",
    "aggreghereste": "aggregare",
    "aggregheresti": "aggregare",
    "aggregherete": "aggregare",
    "aggregherà": "aggregare",
    "aggregherò": "aggregare",
    "aggreghi": "aggregare",
    "aggreghiamo": "aggregare",
    "aggreghiate": "aggregare",
    "aggreghin": "aggregare",
    "aggreghino": "aggregare",
    "aggrego": "aggregare",
    "aggregò": "aggregare",
    "aggressioni": "aggressione",
    "aggressiva": "aggressivo",
    "aggressive": "aggressivo",
    "aggressivi": "aggressivo",
    "aggressori": "aggressore",
    "aggriccerai": "aggricciare",
    "aggricceran": "aggricciare",
    "aggricceranno": "aggricciare",
    "aggriccerebbe": "aggricciare",
    "aggriccerebber": "aggricciare",
    "aggriccerebbero": "aggricciare",
    "aggriccerei": "aggricciare",
    "aggricceremmo": "aggricciare",
    "aggricceremo": "aggricciare",
    "aggriccereste": "aggricciare",
    "aggricceresti": "aggricciare",
    "aggriccerete": "aggricciare",
    "aggriccerà": "aggricciare",
    "aggriccerò": "aggricciare",
    "aggricci": "aggricciare",
    "aggriccia": "aggricciare",
    "aggricciai": "aggricciare",
    "aggricciammo": "aggricciare",
    "aggricciamo": "aggricciare",
    "aggriccian": "aggricciare",
    "aggricciando": "aggricciare",
    "aggricciano": "aggricciare",
    "aggricciante": "aggricciare",
    "aggriccianti": "aggricciare",
    "aggricciar": "aggricciare",
    "aggricciaron": "aggricciare",
    "aggricciarono": "aggricciare",
    "aggricciasse": "aggricciare",
    "aggricciasser": "aggricciare",
    "aggricciassero": "aggricciare",
    "aggricciassi": "aggricciare",
    "aggricciassimo": "aggricciare",
    "aggricciaste": "aggricciare",
    "aggricciasti": "aggricciare",
    "aggricciata": "aggricciare",
    "aggricciate": "aggricciare",
    "aggricciati": "aggricciare",
    "aggricciato": "aggricciare",
    "aggricciava": "aggricciare",
    "aggricciavamo": "aggricciare",
    "aggricciavan": "aggricciare",
    "aggricciavano": "aggricciare",
    "aggricciavate": "aggricciare",
    "aggricciavi": "aggricciare",
    "aggricciavo": "aggricciare",
    "aggriccin": "aggricciare",
    "aggriccino": "aggricciare",
    "aggriccio": "aggricciare",
    "aggricciò": "aggricciare",
    "aggrinza": "aggrinzire",
    "aggrinzai": "aggrinzare",
    "aggrinzammo": "aggrinzare",
    "aggrinzan": "aggrinzire",
    "aggrinzando": "aggrinzare",
    "aggrinzano": "aggrinzire",
    "aggrinzante": "aggrinzare",
    "aggrinzanti": "aggrinzare",
    "aggrinzar": "aggrinzare",
    "aggrinzaron": "aggrinzare",
    "aggrinzarono": "aggrinzare",
    "aggrinzasse": "aggrinzare",
    "aggrinzasser": "aggrinzare",
    "aggrinzassero": "aggrinzare",
    "aggrinzassi": "aggrinzare",
    "aggrinzassimo": "aggrinzare",
    "aggrinzaste": "aggrinzare",
    "aggrinzasti": "aggrinzare",
    "aggrinzata": "aggrinzare",
    "aggrinzate": "aggrinzare",
    "aggrinzati": "aggrinzare",
    "aggrinzato": "aggrinzare",
    "aggrinzava": "aggrinzare",
    "aggrinzavamo": "aggrinzare",
    "aggrinzavan": "aggrinzare",
    "aggrinzavano": "aggrinzare",
    "aggrinzavate": "aggrinzare",
    "aggrinzavi": "aggrinzare",
    "aggrinzavo": "aggrinzare",
    "aggrinze": "aggrinzire",
    "aggrinzendo": "aggrinzire",
    "aggrinzente": "aggrinzire",
    "aggrinzenti": "aggrinzire",
    "aggrinzerai": "aggrinzare",
    "aggrinzeran": "aggrinzare",
    "aggrinzeranno": "aggrinzare",
    "aggrinzerebbe": "aggrinzare",
    "aggrinzerebber": "aggrinzare",
    "aggrinzerebbero": "aggrinzare",
    "aggrinzerei": "aggrinzare",
    "aggrinzeremmo": "aggrinzare",
    "aggrinzeremo": "aggrinzare",
    "aggrinzereste": "aggrinzare",
    "aggrinzeresti": "aggrinzare",
    "aggrinzerete": "aggrinzare",
    "aggrinzerà": "aggrinzare",
    "aggrinzerò": "aggrinzare",
    "aggrinzi": "aggrinzire",
    "aggrinziamo": "aggrinzire",
    "aggrinziate": "aggrinzire",
    "aggrinzii": "aggrinzire",
    "aggrinzimmo": "aggrinzire",
    "aggrinzin": "aggrinzare",
    "aggrinzino": "aggrinzare",
    "aggrinzir": "aggrinzire",
    "aggrinzirai": "aggrinzire",
    "aggrinziran": "aggrinzire",
    "aggrinziranno": "aggrinzire",
    "aggrinzirebbe": "aggrinzire",
    "aggrinzirebber": "aggrinzire",
    "aggrinzirebbero": "aggrinzire",
    "aggrinzirei": "aggrinzire",
    "aggrinziremmo": "aggrinzire",
    "aggrinziremo": "aggrinzire",
    "aggrinzireste": "aggrinzire",
    "aggrinziresti": "aggrinzire",
    "aggrinzirete": "aggrinzire",
    "aggrinziron": "aggrinzire",
    "aggrinzirono": "aggrinzire",
    "aggrinzirà": "aggrinzire",
    "aggrinzirò": "aggrinzire",
    "aggrinzisse": "aggrinzire",
    "aggrinzisser": "aggrinzire",
    "aggrinzissero": "aggrinzire",
    "aggrinzissi": "aggrinzire",
    "aggrinzissimo": "aggrinzire",
    "aggrinziste": "aggrinzire",
    "aggrinzisti": "aggrinzire",
    "aggrinzita": "aggrinzire",
    "aggrinzite": "aggrinzire",
    "aggrinziti": "aggrinzire",
    "aggrinzito": "aggrinzire",
    "aggrinziva": "aggrinzire",
    "aggrinzivamo": "aggrinzire",
    "aggrinzivan": "aggrinzire",
    "aggrinzivano": "aggrinzire",
    "aggrinzivate": "aggrinzire",
    "aggrinzivi": "aggrinzire",
    "aggrinzivo": "aggrinzire",
    "aggrinzo": "aggrinzire",
    "aggrinzon": "aggrinzire",
    "aggrinzono": "aggrinzire",
    "aggrinzì": "aggrinzire",
    "aggrinzò": "aggrinzare",
    "aggronda": "aggrondare",
    "aggrondai": "aggrondare",
    "aggrondammo": "aggrondare",
    "aggrondan": "aggrondare",
    "aggrondando": "aggrondare",
    "aggrondano": "aggrondare",
    "aggrondante": "aggrondare",
    "aggrondanti": "aggrondare",
    "aggrondar": "aggrondare",
    "aggrondaron": "aggrondare",
    "aggrondarono": "aggrondare",
    "aggrondasse": "aggrondare",
    "aggrondasser": "aggrondare",
    "aggrondassero": "aggrondare",
    "aggrondassi": "aggrondare",
    "aggrondassimo": "aggrondare",
    "aggrondaste": "aggrondare",
    "aggrondasti": "aggrondare",
    "aggrondata": "aggrondare",
    "aggrondate": "aggrondare",
    "aggrondati": "aggrondare",
    "aggrondato": "aggrondare",
    "aggrondava": "aggrondare",
    "aggrondavamo": "aggrondare",
    "aggrondavan": "aggrondare",
    "aggrondavano": "aggrondare",
    "aggrondavate": "aggrondare",
    "aggrondavi": "aggrondare",
    "aggrondavo": "aggrondare",
    "aggronderai": "aggrondare",
    "aggronderan": "aggrondare",
    "aggronderanno": "aggrondare",
    "aggronderebbe": "aggrondare",
    "aggronderebber": "aggrondare",
    "aggronderebbero": "aggrondare",
    "aggronderei": "aggrondare",
    "aggronderemmo": "aggrondare",
    "aggronderemo": "aggrondare",
    "aggrondereste": "aggrondare",
    "aggronderesti": "aggrondare",
    "aggronderete": "aggrondare",
    "aggronderà": "aggrondare",
    "aggronderò": "aggrondare",
    "aggrondi": "aggrondare",
    "aggrondiamo": "aggrondare",
    "aggrondiate": "aggrondare",
    "aggrondin": "aggrondare",
    "aggrondino": "aggrondare",
    "aggrondo": "aggrondare",
    "aggrondò": "aggrondare",
    "aggrotta": "aggrottare",
    "aggrottai": "aggrottare",
    "aggrottammo": "aggrottare",
    "aggrottan": "aggrottare",
    "aggrottando": "aggrottare",
    "aggrottano": "aggrottare",
    "aggrottante": "aggrottare",
    "aggrottanti": "aggrottare",
    "aggrottar": "aggrottare",
    "aggrottaron": "aggrottare",
    "aggrottarono": "aggrottare",
    "aggrottasse": "aggrottare",
    "aggrottasser": "aggrottare",
    "aggrottassero": "aggrottare",
    "aggrottassi": "aggrottare",
    "aggrottassimo": "aggrottare",
    "aggrottaste": "aggrottare",
    "aggrottasti": "aggrottare",
    "aggrottata": "aggrottare",
    "aggrottate": "aggrottare",
    "aggrottati": "aggrottare",
    "aggrottato": "aggrottare",
    "aggrottava": "aggrottare",
    "aggrottavamo": "aggrottare",
    "aggrottavan": "aggrottare",
    "aggrottavano": "aggrottare",
    "aggrottavate": "aggrottare",
    "aggrottavi": "aggrottare",
    "aggrottavo": "aggrottare",
    "aggrotterai": "aggrottare",
    "aggrotteran": "aggrottare",
    "aggrotteranno": "aggrottare",
    "aggrotterebbe": "aggrottare",
    "aggrotterebber": "aggrottare",
    "aggrotterebbero": "aggrottare",
    "aggrotterei": "aggrottare",
    "aggrotteremmo": "aggrottare",
    "aggrotteremo": "aggrottare",
    "aggrottereste": "aggrottare",
    "aggrotteresti": "aggrottare",
    "aggrotterete": "aggrottare",
    "aggrotterà": "aggrottare",
    "aggrotterò": "aggrottare",
    "aggrotti": "aggrottare",
    "aggrottiamo": "aggrottare",
    "aggrottiate": "aggrottare",
    "aggrottin": "aggrottare",
    "aggrottino": "aggrottare",
    "aggrotto": "aggrottare",
    "aggrottò": "aggrottare",
    "aggrovigli": "aggrovigliare",
    "aggroviglia": "aggrovigliare",
    "aggrovigliai": "aggrovigliare",
    "aggrovigliammo": "aggrovigliare",
    "aggrovigliamo": "aggrovigliare",
    "aggroviglian": "aggrovigliare",
    "aggrovigliando": "aggrovigliare",
    "aggrovigliano": "aggrovigliare",
    "aggrovigliante": "aggrovigliare",
    "aggroviglianti": "aggrovigliare",
    "aggrovigliar": "aggrovigliare",
    "aggrovigliaron": "aggrovigliare",
    "aggrovigliarono": "aggrovigliare",
    "aggrovigliasse": "aggrovigliare",
    "aggrovigliasser": "aggrovigliare",
    "aggrovigliassero": "aggrovigliare",
    "aggrovigliassi": "aggrovigliare",
    "aggrovigliassimo": "aggrovigliare",
    "aggrovigliaste": "aggrovigliare",
    "aggrovigliasti": "aggrovigliare",
    "aggrovigliata": "aggrovigliato",
    "aggrovigliate": "aggrovigliato",
    "aggrovigliati": "aggrovigliato",
    "aggrovigliato": "aggrovigliare",
    "aggrovigliava": "aggrovigliare",
    "aggrovigliavamo": "aggrovigliare",
    "aggrovigliavan": "aggrovigliare",
    "aggrovigliavano": "aggrovigliare",
    "aggrovigliavate": "aggrovigliare",
    "aggrovigliavi": "aggrovigliare",
    "aggrovigliavo": "aggrovigliare",
    "aggroviglierai": "aggrovigliare",
    "aggroviglieran": "aggrovigliare",
    "aggroviglieranno": "aggrovigliare",
    "aggroviglierebbe": "aggrovigliare",
    "aggroviglierebber": "aggrovigliare",
    "aggroviglierebbero": "aggrovigliare",
    "aggroviglierei": "aggrovigliare",
    "aggroviglieremmo": "aggrovigliare",
    "aggroviglieremo": "aggrovigliare",
    "aggrovigliereste": "aggrovigliare",
    "aggroviglieresti": "aggrovigliare",
    "aggroviglierete": "aggrovigliare",
    "aggroviglierà": "aggrovigliare",
    "aggroviglierò": "aggrovigliare",
    "aggroviglin": "aggrovigliare",
    "aggroviglino": "aggrovigliare",
    "aggroviglio": "aggrovigliare",
    "aggrovigliò": "aggrovigliare",
    "aggruma": "aggrumare",
    "aggrumai": "aggrumare",
    "aggrumammo": "aggrumare",
    "aggruman": "aggrumare",
    "aggrumando": "aggrumare",
    "aggrumano": "aggrumare",
    "aggrumante": "aggrumare",
    "aggrumanti": "aggrumare",
    "aggrumar": "aggrumare",
    "aggrumaron": "aggrumare",
    "aggrumarono": "aggrumare",
    "aggrumasse": "aggrumare",
    "aggrumasser": "aggrumare",
    "aggrumassero": "aggrumare",
    "aggrumassi": "aggrumare",
    "aggrumassimo": "aggrumare",
    "aggrumaste": "aggrumare",
    "aggrumasti": "aggrumare",
    "aggrumata": "aggrumare",
    "aggrumate": "aggrumare",
    "aggrumati": "aggrumare",
    "aggrumato": "aggrumare",
    "aggrumava": "aggrumare",
    "aggrumavamo": "aggrumare",
    "aggrumavan": "aggrumare",
    "aggrumavano": "aggrumare",
    "aggrumavate": "aggrumare",
    "aggrumavi": "aggrumare",
    "aggrumavo": "aggrumare",
    "aggrumerai": "aggrumare",
    "aggrumeran": "aggrumare",
    "aggrumeranno": "aggrumare",
    "aggrumerebbe": "aggrumare",
    "aggrumerebber": "aggrumare",
    "aggrumerebbero": "aggrumare",
    "aggrumerei": "aggrumare",
    "aggrumeremmo": "aggrumare",
    "aggrumeremo": "aggrumare",
    "aggrumereste": "aggrumare",
    "aggrumeresti": "aggrumare",
    "aggrumerete": "aggrumare",
    "aggrumerà": "aggrumare",
    "aggrumerò": "aggrumare",
    "aggrumi": "aggrumare",
    "aggrumiamo": "aggrumare",
    "aggrumiate": "aggrumare",
    "aggrumin": "aggrumare",
    "aggrumino": "aggrumare",
    "aggrumo": "aggrumare",
    "aggrumò": "aggrumare",
    "aggruppa": "aggruppare",
    "aggruppai": "aggruppare",
    "aggruppammo": "aggruppare",
    "aggruppan": "aggruppare",
    "aggruppando": "aggruppare",
    "aggruppano": "aggruppare",
    "aggruppante": "aggruppare",
    "aggruppanti": "aggruppare",
    "aggruppar": "aggruppare",
    "aggrupparon": "aggruppare",
    "aggrupparono": "aggruppare",
    "aggruppasse": "aggruppare",
    "aggruppasser": "aggruppare",
    "aggruppassero": "aggruppare",
    "aggruppassi": "aggruppare",
    "aggruppassimo": "aggruppare",
    "aggruppaste": "aggruppare",
    "aggruppasti": "aggruppare",
    "aggruppata": "aggruppare",
    "aggruppate": "aggruppare",
    "aggruppati": "aggruppare",
    "aggruppato": "aggruppare",
    "aggruppava": "aggruppare",
    "aggruppavamo": "aggruppare",
    "aggruppavan": "aggruppare",
    "aggruppavano": "aggruppare",
    "aggruppavate": "aggruppare",
    "aggruppavi": "aggruppare",
    "aggruppavo": "aggruppare",
    "aggrupperai": "aggruppare",
    "aggrupperan": "aggruppare",
    "aggrupperanno": "aggruppare",
    "aggrupperebbe": "aggruppare",
    "aggrupperebber": "aggruppare",
    "aggrupperebbero": "aggruppare",
    "aggrupperei": "aggruppare",
    "aggrupperemmo": "aggruppare",
    "aggrupperemo": "aggruppare",
    "aggruppereste": "aggruppare",
    "aggrupperesti": "aggruppare",
    "aggrupperete": "aggruppare",
    "aggrupperà": "aggruppare",
    "aggrupperò": "aggruppare",
    "aggruppi": "aggruppare",
    "aggruppiamo": "aggruppare",
    "aggruppiate": "aggruppare",
    "aggruppin": "aggruppare",
    "aggruppino": "aggruppare",
    "aggruppo": "aggruppare",
    "aggruppò": "aggruppare",
    "agguagli": "agguagliare",
    "agguaglia": "agguagliare",
    "agguagliai": "agguagliare",
    "agguagliammo": "agguagliare",
    "agguagliamo": "agguagliare",
    "agguaglian": "agguagliare",
    "agguagliando": "agguagliare",
    "agguagliano": "agguagliare",
    "agguagliante": "agguagliare",
    "agguaglianti": "agguagliare",
    "agguagliar": "agguagliare",
    "agguagliaron": "agguagliare",
    "agguagliarono": "agguagliare",
    "agguagliasse": "agguagliare",
    "agguagliasser": "agguagliare",
    "agguagliassero": "agguagliare",
    "agguagliassi": "agguagliare",
    "agguagliassimo": "agguagliare",
    "agguagliaste": "agguagliare",
    "agguagliasti": "agguagliare",
    "agguagliata": "agguagliare",
    "agguagliate": "agguagliare",
    "agguagliati": "agguagliare",
    "agguagliato": "agguagliare",
    "agguagliava": "agguagliare",
    "agguagliavamo": "agguagliare",
    "agguagliavan": "agguagliare",
    "agguagliavano": "agguagliare",
    "agguagliavate": "agguagliare",
    "agguagliavi": "agguagliare",
    "agguagliavo": "agguagliare",
    "agguaglierai": "agguagliare",
    "agguaglieran": "agguagliare",
    "agguaglieranno": "agguagliare",
    "agguaglierebbe": "agguagliare",
    "agguaglierebber": "agguagliare",
    "agguaglierebbero": "agguagliare",
    "agguaglierei": "agguagliare",
    "agguaglieremmo": "agguagliare",
    "agguaglieremo": "agguagliare",
    "agguagliereste": "agguagliare",
    "agguaglieresti": "agguagliare",
    "agguaglierete": "agguagliare",
    "agguaglierà": "agguagliare",
    "agguaglierò": "agguagliare",
    "agguaglin": "agguagliare",
    "agguaglino": "agguagliare",
    "agguaglio": "agguagliare",
    "agguagliò": "agguagliare",
    "agguanta": "agguantare",
    "agguantai": "agguantare",
    "agguantammo": "agguantare",
    "agguantan": "agguantare",
    "agguantando": "agguantare",
    "agguantano": "agguantare",
    "agguantante": "agguantare",
    "agguantanti": "agguantare",
    "agguantar": "agguantare",
    "agguantaron": "agguantare",
    "agguantarono": "agguantare",
    "agguantasse": "agguantare",
    "agguantasser": "agguantare",
    "agguantassero": "agguantare",
    "agguantassi": "agguantare",
    "agguantassimo": "agguantare",
    "agguantaste": "agguantare",
    "agguantasti": "agguantare",
    "agguantata": "agguantare",
    "agguantate": "agguantare",
    "agguantati": "agguantare",
    "agguantato": "agguantare",
    "agguantava": "agguantare",
    "agguantavamo": "agguantare",
    "agguantavan": "agguantare",
    "agguantavano": "agguantare",
    "agguantavate": "agguantare",
    "agguantavi": "agguantare",
    "agguantavo": "agguantare",
    "agguanterai": "agguantare",
    "agguanteran": "agguantare",
    "agguanteranno": "agguantare",
    "agguanterebbe": "agguantare",
    "agguanterebber": "agguantare",
    "agguanterebbero": "agguantare",
    "agguanterei": "agguantare",
    "agguanteremmo": "agguantare",
    "agguanteremo": "agguantare",
    "agguantereste": "agguantare",
    "agguanteresti": "agguantare",
    "agguanterete": "agguantare",
    "agguanterà": "agguantare",
    "agguanterò": "agguantare",
    "agguanti": "agguantare",
    "agguantiamo": "agguantare",
    "agguantiate": "agguantare",
    "agguantin": "agguantare",
    "agguantino": "agguantare",
    "agguanto": "agguantare",
    "agguantò": "agguantare",
    "agguata": "agguatare",
    "agguatai": "agguatare",
    "agguatammo": "agguatare",
    "agguatan": "agguatare",
    "agguatando": "agguatare",
    "agguatano": "agguatare",
    "agguatante": "agguatare",
    "agguatanti": "agguatare",
    "agguatar": "agguatare",
    "agguataron": "agguatare",
    "agguatarono": "agguatare",
    "agguatasse": "agguatare",
    "agguatasser": "agguatare",
    "agguatassero": "agguatare",
    "agguatassi": "agguatare",
    "agguatassimo": "agguatare",
    "agguataste": "agguatare",
    "agguatasti": "agguatare",
    "agguatata": "agguatare",
    "agguatate": "agguatare",
    "agguatati": "agguatare",
    "agguatato": "agguatare",
    "agguatava": "agguatare",
    "agguatavamo": "agguatare",
    "agguatavan": "agguatare",
    "agguatavano": "agguatare",
    "agguatavate": "agguatare",
    "agguatavi": "agguatare",
    "agguatavo": "agguatare",
    "agguaterai": "agguatare",
    "agguateran": "agguatare",
    "agguateranno": "agguatare",
    "agguaterebbe": "agguatare",
    "agguaterebber": "agguatare",
    "agguaterebbero": "agguatare",
    "agguaterei": "agguatare",
    "agguateremmo": "agguatare",
    "agguateremo": "agguatare",
    "agguatereste": "agguatare",
    "agguateresti": "agguatare",
    "agguaterete": "agguatare",
    "agguaterà": "agguatare",
    "agguaterò": "agguatare",
    "agguati": "agguato",
    "agguatiamo": "agguatare",
    "agguatiate": "agguatare",
    "agguatin": "agguatare",
    "agguatino": "agguatare",
    "agguato": "agguatare",
    "agguatò": "agguatare",
    "agguerra": "agguerrire",
    "agguerran": "agguerrire",
    "agguerrano": "agguerrire",
    "agguerre": "agguerrire",
    "agguerrendo": "agguerrire",
    "agguerrente": "agguerrire",
    "agguerrenti": "agguerrire",
    "agguerri": "agguerrire",
    "agguerriamo": "agguerrire",
    "agguerriate": "agguerrire",
    "agguerrii": "agguerrire",
    "agguerrimmo": "agguerrire",
    "agguerrir": "agguerrire",
    "agguerrirai": "agguerrire",
    "agguerriran": "agguerrire",
    "agguerriranno": "agguerrire",
    "agguerrirebbe": "agguerrire",
    "agguerrirebber": "agguerrire",
    "agguerrirebbero": "agguerrire",
    "agguerrirei": "agguerrire",
    "agguerriremmo": "agguerrire",
    "agguerriremo": "agguerrire",
    "agguerrireste": "agguerrire",
    "agguerriresti": "agguerrire",
    "agguerrirete": "agguerrire",
    "agguerriron": "agguerrire",
    "agguerrirono": "agguerrire",
    "agguerrirà": "agguerrire",
    "agguerrirò": "agguerrire",
    "agguerrisse": "agguerrire",
    "agguerrisser": "agguerrire",
    "agguerrissero": "agguerrire",
    "agguerrissi": "agguerrire",
    "agguerrissimo": "agguerrire",
    "agguerriste": "agguerrire",
    "agguerristi": "agguerrire",
    "agguerrita": "agguerrito",
    "agguerrite": "agguerrito",
    "agguerriti": "agguerrito",
    "agguerrito": "agguerrire",
    "agguerriva": "agguerrire",
    "agguerrivamo": "agguerrire",
    "agguerrivan": "agguerrire",
    "agguerrivano": "agguerrire",
    "agguerrivate": "agguerrire",
    "agguerrivi": "agguerrire",
    "agguerrivo": "agguerrire",
    "agguerro": "agguerrire",
    "agguerron": "agguerrire",
    "agguerrono": "agguerrire",
    "agguerrì": "agguerrire",
    "aghi": "ago",
    "agi": "agio",
    "agiamo": "agire",
    "agiata": "agiato",
    "agiate": "agire",
    "agiati": "agiato",
    "agibili": "agibile",
    "agii": "agire",
    "agili": "agile",
    "agimmo": "agire",
    "agiografi": "agiografo",
    "agiografica": "agiografico",
    "agiografiche": "agiografico",
    "agiografici": "agiografico",
    "agiografie": "agiografia",
    "agir": "agire",
    "agirai": "agire",
    "agiran": "agire",
    "agiranno": "agire",
    "agirebbe": "agire",
    "agirebber": "agire",
    "agirebbero": "agire",
    "agirei": "agire",
    "agiremmo": "agire",
    "agiremo": "agire",
    "agireste": "agire",
    "agiresti": "agire",
    "agirete": "agire",
    "agiron": "agire",
    "agirono": "agire",
    "agirà": "agire",
    "agirò": "agire",
    "agisca": "agire",
    "agiscan": "agire",
    "agiscano": "agire",
    "agisce": "agire",
    "agisci": "agire",
    "agisco": "agire",
    "agiscon": "agire",
    "agiscono": "agire",
    "agisse": "agire",
    "agisser": "agire",
    "agissero": "agire",
    "agissi": "agire",
    "agissimo": "agire",
    "agiste": "agire",
    "agisti": "agire",
    "agita": "agitare",
    "agitai": "agitare",
    "agitammo": "agitare",
    "agitan": "agitare",
    "agitando": "agitare",
    "agitano": "agitare",
    "agitante": "agitare",
    "agitanti": "agitare",
    "agitar": "agitare",
    "agitaron": "agitare",
    "agitarono": "agitare",
    "agitasse": "agitare",
    "agitasser": "agitare",
    "agitassero": "agitare",
    "agitassi": "agitare",
    "agitassimo": "agitare",
    "agitaste": "agitare",
    "agitasti": "agitare",
    "agitata": "agitato",
    "agitate": "agitato",
    "agitati": "agitato",
    "agitato": "agitare",
    "agitatori": "agitatore",
    "agitava": "agitare",
    "agitavamo": "agitare",
    "agitavan": "agitare",
    "agitavano": "agitare",
    "agitavate": "agitare",
    "agitavi": "agitare",
    "agitavo": "agitare",
    "agitazioni": "agitazione",
    "agite": "agire",
    "agiterai": "agitare",
    "agiteran": "agitare",
    "agiteranno": "agitare",
    "agiterebbe": "agitare",
    "agiterebber": "agitare",
    "agiterebbero": "agitare",
    "agiterei": "agitare",
    "agiteremmo": "agitare",
    "agiteremo": "agitare",
    "agitereste": "agitare",
    "agiteresti": "agitare",
    "agiterete": "agitare",
    "agiterà": "agitare",
    "agiterò": "agitare",
    "agiti": "agitare",
    "agitiamo": "agitare",
    "agitiate": "agitare",
    "agitin": "agitare",
    "agitino": "agitare",
    "agito": "agitare",
    "agitò": "agitare",
    "agiva": "agire",
    "agivamo": "agire",
    "agivan": "agire",
    "agivano": "agire",
    "agivate": "agire",
    "agivi": "agire",
    "agivo": "agire",
    "agli": "al",
    "agnata": "agnato",
    "agnate": "agnato",
    "agnati": "agnato",
    "agnelli": "agnello",
    "agnelliana": "agnelliano",
    "agnelliane": "agnelliano",
    "agnelliani": "agnelliano",
    "agnellini": "agnellino",
    "agnizioni": "agnizione",
    "agnostica": "agnostico",
    "agnostiche": "agnostico",
    "agnostici": "agnostico",
    "agogna": "agognare",
    "agognai": "agognare",
    "agognammo": "agognare",
    "agognan": "agognare",
    "agognando": "agognare",
    "agognano": "agognare",
    "agognante": "agognare",
    "agognanti": "agognare",
    "agognar": "agognare",
    "agognaron": "agognare",
    "agognarono": "agognare",
    "agognasse": "agognare",
    "agognasser": "agognare",
    "agognassero": "agognare",
    "agognassi": "agognare",
    "agognassimo": "agognare",
    "agognaste": "agognare",
    "agognasti": "agognare",
    "agognata": "agognare",
    "agognate": "agognare",
    "agognati": "agognare",
    "agognato": "agognare",
    "agognava": "agognare",
    "agognavamo": "agognare",
    "agognavan": "agognare",
    "agognavano": "agognare",
    "agognavate": "agognare",
    "agognavi": "agognare",
    "agognavo": "agognare",
    "agognerai": "agognare",
    "agogneran": "agognare",
    "agogneranno": "agognare",
    "agognerebbe": "agognare",
    "agognerebber": "agognare",
    "agognerebbero": "agognare",
    "agognerei": "agognare",
    "agogneremmo": "agognare",
    "agogneremo": "agognare",
    "agognereste": "agognare",
    "agogneresti": "agognare",
    "agognerete": "agognare",
    "agognerà": "agognare",
    "agognerò": "agognare",
    "agogni": "agognare",
    "agogniamo": "agognare",
    "agogniate": "agognare",
    "agognin": "agognare",
    "agognino": "agognare",
    "agogno": "agognare",
    "agognò": "agognare",
    "agoni": "agone",
    "agonie": "agonia",
    "agonismi": "agonismo",
    "agonisti": "agonista",
    "agonistica": "agonistico",
    "agonistiche": "agonistico",
    "agonistici": "agonistico",
    "agonizza": "agonizzare",
    "agonizzai": "agonizzare",
    "agonizzammo": "agonizzare",
    "agonizzan": "agonizzare",
    "agonizzando": "agonizzare",
    "agonizzano": "agonizzare",
    "agonizzante": "agonizzare",
    "agonizzanti": "agonizzare",
    "agonizzar": "agonizzare",
    "agonizzaron": "agonizzare",
    "agonizzarono": "agonizzare",
    "agonizzasse": "agonizzare",
    "agonizzasser": "agonizzare",
    "agonizzassero": "agonizzare",
    "agonizzassi": "agonizzare",
    "agonizzassimo": "agonizzare",
    "agonizzaste": "agonizzare",
    "agonizzasti": "agonizzare",
    "agonizzata": "agonizzare",
    "agonizzate": "agonizzare",
    "agonizzati": "agonizzare",
    "agonizzato": "agonizzare",
    "agonizzava": "agonizzare",
    "agonizzavamo": "agonizzare",
    "agonizzavan": "agonizzare",
    "agonizzavano": "agonizzare",
    "agonizzavate": "agonizzare",
    "agonizzavi": "agonizzare",
    "agonizzavo": "agonizzare",
    "agonizzerai": "agonizzare",
    "agonizzeran": "agonizzare",
    "agonizzeranno": "agonizzare",
    "agonizzerebbe": "agonizzare",
    "agonizzerebber": "agonizzare",
    "agonizzerebbero": "agonizzare",
    "agonizzerei": "agonizzare",
    "agonizzeremmo": "agonizzare",
    "agonizzeremo": "agonizzare",
    "agonizzereste": "agonizzare",
    "agonizzeresti": "agonizzare",
    "agonizzerete": "agonizzare",
    "agonizzerà": "agonizzare",
    "agonizzerò": "agonizzare",
    "agonizzi": "agonizzare",
    "agonizziamo": "agonizzare",
    "agonizziate": "agonizzare",
    "agonizzin": "agonizzare",
    "agonizzino": "agonizzare",
    "agonizzo": "agonizzare",
    "agonizzò": "agonizzare",
    "agosti": "agosto",
    "agra": "agro",
    "agrari": "agrario",
    "agraria": "agrario",
    "agrarie": "agrario",
    "agre": "agro",
    "agresta": "agresto",
    "agreste": "agresto",
    "agresti": "agresto",
    "agri": "agro",
    "agricola": "agricolo",
    "agricole": "agricolo",
    "agricoli": "agricolo",
    "agricolo-alimentari": "agricolo-alimentare",
    "agricolo-pastorali": "agricolo-pastorale",
    "agricoltori": "agricoltore",
    "agricolture": "agricoltura",
    "agrigentini": "agrigentino",
    "agriturismi": "agriturismo",
    "agro-alimentari": "agro-alimentare",
    "agro-ambientali": "agro-ambientale",
    "agro-artigianali": "agro-artigianale",
    "agro-forestali": "agro-forestale",
    "agro-industriali": "agro-industriale",
    "agro-pastorali": "agro-pastorale",
    "agro-tecnica": "agro-tecnico",
    "agro-tecniche": "agro-tecnico",
    "agro-tecnici": "agro-tecnico",
    "agroalimentari": "agroalimentare",
    "agrobiotecnologica": "agrobiotecnologico",
    "agrobiotecnologiche": "agrobiotecnologico",
    "agrobiotecnologici": "agrobiotecnologico",
    "agrocentrica": "agrocentrico",
    "agrocentriche": "agrocentrico",
    "agrocentrici": "agrocentrico",
    "agrodolci": "agrodolce",
    "agroindustriali": "agroindustriale",
    "agronomi": "agronomo",
    "agronomica": "agronomico",
    "agronomiche": "agronomico",
    "agronomici": "agronomico",
    "agropastorali": "agropastorale",
    "agrumeti": "agrumeto",
    "agrumi": "agrume",
    "agrumicola": "agrumicolo",
    "agrumicole": "agrumicolo",
    "agrumicoli": "agrumicolo",
    "agucchi": "agucchiare",
    "agucchia": "agucchiare",
    "agucchiai": "agucchiare",
    "agucchiammo": "agucchiare",
    "agucchiamo": "agucchiare",
    "agucchian": "agucchiare",
    "agucchiando": "agucchiare",
    "agucchiano": "agucchiare",
    "agucchiante": "agucchiare",
    "agucchianti": "agucchiare",
    "agucchiar": "agucchiare",
    "agucchiaron": "agucchiare",
    "agucchiarono": "agucchiare",
    "agucchiasse": "agucchiare",
    "agucchiasser": "agucchiare",
    "agucchiassero": "agucchiare",
    "agucchiassi": "agucchiare",
    "agucchiassimo": "agucchiare",
    "agucchiaste": "agucchiare",
    "agucchiasti": "agucchiare",
    "agucchiata": "agucchiare",
    "agucchiate": "agucchiare",
    "agucchiati": "agucchiare",
    "agucchiato": "agucchiare",
    "agucchiava": "agucchiare",
    "agucchiavamo": "agucchiare",
    "agucchiavan": "agucchiare",
    "agucchiavano": "agucchiare",
    "agucchiavate": "agucchiare",
    "agucchiavi": "agucchiare",
    "agucchiavo": "agucchiare",
    "agucchierai": "agucchiare",
    "agucchieran": "agucchiare",
    "agucchieranno": "agucchiare",
    "agucchierebbe": "agucchiare",
    "agucchierebber": "agucchiare",
    "agucchierebbero": "agucchiare",
    "agucchierei": "agucchiare",
    "agucchieremmo": "agucchiare",
    "agucchieremo": "agucchiare",
    "agucchiereste": "agucchiare",
    "agucchieresti": "agucchiare",
    "agucchierete": "agucchiare",
    "agucchierà": "agucchiare",
    "agucchierò": "agucchiare",
    "agucchin": "agucchiare",
    "agucchino": "agucchiare",
    "agucchio": "agucchiare",
    "agucchiò": "agucchiare",
    "aguzza": "aguzzo",
    "aguzzai": "aguzzare",
    "aguzzammo": "aguzzare",
    "aguzzan": "aguzzare",
    "aguzzando": "aguzzare",
    "aguzzano": "aguzzare",
    "aguzzante": "aguzzare",
    "aguzzanti": "aguzzare",
    "aguzzar": "aguzzare",
    "aguzzaron": "aguzzare",
    "aguzzarono": "aguzzare",
    "aguzzasse": "aguzzare",
    "aguzzasser": "aguzzare",
    "aguzzassero": "aguzzare",
    "aguzzassi": "aguzzare",
    "aguzzassimo": "aguzzare",
    "aguzzaste": "aguzzare",
    "aguzzasti": "aguzzare",
    "aguzzata": "aguzzare",
    "aguzzate": "aguzzare",
    "aguzzati": "aguzzare",
    "aguzzato": "aguzzare",
    "aguzzava": "aguzzare",
    "aguzzavamo": "aguzzare",
    "aguzzavan": "aguzzare",
    "aguzzavano": "aguzzare",
    "aguzzavate": "aguzzare",
    "aguzzavi": "aguzzare",
    "aguzzavo": "aguzzare",
    "aguzze": "aguzzo",
    "aguzzerai": "aguzzare",
    "aguzzeran": "aguzzare",
    "aguzzeranno": "aguzzare",
    "aguzzerebbe": "aguzzare",
    "aguzzerebber": "aguzzare",
    "aguzzerebbero": "aguzzare",
    "aguzzerei": "aguzzare",
    "aguzzeremmo": "aguzzare",
    "aguzzeremo": "aguzzare",
    "aguzzereste": "aguzzare",
    "aguzzeresti": "aguzzare",
    "aguzzerete": "aguzzare",
    "aguzzerà": "aguzzare",
    "aguzzerò": "aguzzare",
    "aguzzi": "aguzzo",
    "aguzziamo": "aguzzare",
    "aguzziate": "aguzzare",
    "aguzzin": "aguzzare",
    "aguzzini": "aguzzino",
    "aguzzino": "aguzzare",
    "aguzzo": "aguzzare",
    "aguzzò": "aguzzare",
    "agì": "agire",
    "ai": "al",
    "aie": "aia",
    "aiole": "aiola",
    "aironi": "airone",
    "aitanti": "aitante",
    "aiuole": "aiuola",
    "aiuta": "aiutare",
    "aiutai": "aiutare",
    "aiutammo": "aiutare",
    "aiutan": "aiutare",
    "aiutando": "aiutare",
    "aiutano": "aiutare",
    "aiutante": "aiutare",
    "aiutanti": "aiutare",
    "aiutar": "aiutare",
    "aiutaron": "aiutare",
    "aiutarono": "aiutare",
    "aiutasse": "aiutare",
    "aiutasser": "aiutare",
    "aiutassero": "aiutare",
    "aiutassi": "aiutare",
    "aiutassimo": "aiutare",
    "aiutaste": "aiutare",
    "aiutasti": "aiutare",
    "aiutata": "aiutare",
    "aiutate": "aiutare",
    "aiutati": "aiutare",
    "aiutato": "aiutare",
    "aiutava": "aiutare",
    "aiutavamo": "aiutare",
    "aiutavan": "aiutare",
    "aiutavano": "aiutare",
    "aiutavate": "aiutare",
    "aiutavi": "aiutare",
    "aiutavo": "aiutare",
    "aiuterai": "aiutare",
    "aiuteran": "aiutare",
    "aiuteranno": "aiutare",
    "aiuterebbe": "aiutare",
    "aiuterebber": "aiutare",
    "aiuterebbero": "aiutare",
    "aiuterei": "aiutare",
    "aiuteremmo": "aiutare",
    "aiuteremo": "aiutare",
    "aiutereste": "aiutare",
    "aiuteresti": "aiutare",
    "aiuterete": "aiutare",
    "aiuterà": "aiutare",
    "aiuterò": "aiutare",
    "aiuti": "aiuto",
    "aiutiamo": "aiutare",
    "aiutiate": "aiutare",
    "aiutin": "aiutare",
    "aiutino": "aiutare",
    "aiuto": "aiutare",
    "aiutò": "aiutare",
    "aizza": "aizzare",
    "aizzai": "aizzare",
    "aizzammo": "aizzare",
    "aizzan": "aizzare",
    "aizzando": "aizzare",
    "aizzano": "aizzare",
    "aizzante": "aizzare",
    "aizzanti": "aizzare",
    "aizzar": "aizzare",
    "aizzaron": "aizzare",
    "aizzarono": "aizzare",
    "aizzasse": "aizzare",
    "aizzasser": "aizzare",
    "aizzassero": "aizzare",
    "aizzassi": "aizzare",
    "aizzassimo": "aizzare",
    "aizzaste": "aizzare",
    "aizzasti": "aizzare",
    "aizzata": "aizzare",
    "aizzate": "aizzare",
    "aizzati": "aizzare",
    "aizzato": "aizzare",
    "aizzava": "aizzare",
    "aizzavamo": "aizzare",
    "aizzavan": "aizzare",
    "aizzavano": "aizzare",
    "aizzavate": "aizzare",
    "aizzavi": "aizzare",
    "aizzavo": "aizzare",
    "aizzerai": "aizzare",
    "aizzeran": "aizzare",
    "aizzeranno": "aizzare",
    "aizzerebbe": "aizzare",
    "aizzerebber": "aizzare",
    "aizzerebbero": "aizzare",
    "aizzerei": "aizzare",
    "aizzeremmo": "aizzare",
    "aizzeremo": "aizzare",
    "aizzereste": "aizzare",
    "aizzeresti": "aizzare",
    "aizzerete": "aizzare",
    "aizzerà": "aizzare",
    "aizzerò": "aizzare",
    "aizzi": "aizzare",
    "aizziamo": "aizzare",
    "aizziate": "aizzare",
    "aizzin": "aizzare",
    "aizzino": "aizzare",
    "aizzo": "aizzare",
    "aizzò": "aizzare",
    "ala": "alare",
    "alacri": "alacre",
    "alai": "alare",
    "alambicchi": "alambicco",
    "alammo": "alare",
    "alan": "alare",
    "alando": "alare",
    "alano": "alare",
    "alante": "alare",
    "alanti": "alare",
    "alar": "alare",
    "alari": "alare",
    "alaron": "alare",
    "alarono": "alare",
    "alasse": "alare",
    "alasser": "alare",
    "alassero": "alare",
    "alassi": "alare",
    "alassimo": "alare",
    "alaste": "alare",
    "alasti": "alare",
    "alata": "alato",
    "alate": "alato",
    "alati": "alato",
    "alato": "alare",
    "alava": "alare",
    "alavamo": "alare",
    "alavan": "alare",
    "alavano": "alare",
    "alavate": "alare",
    "alavi": "alare",
    "alavo": "alare",
    "albanesi": "albanese",
    "albe": "alba",
    "albeggerai": "albeggiare",
    "albeggeran": "albeggiare",
    "albeggeranno": "albeggiare",
    "albeggerebbe": "albeggiare",
    "albeggerebber": "albeggiare",
    "albeggerebbero": "albeggiare",
    "albeggerei": "albeggiare",
    "albeggeremmo": "albeggiare",
    "albeggeremo": "albeggiare",
    "albeggereste": "albeggiare",
    "albeggeresti": "albeggiare",
    "albeggerete": "albeggiare",
    "albeggerà": "albeggiare",
    "albeggerò": "albeggiare",
    "albeggi": "albeggiare",
    "albeggia": "albeggiare",
    "albeggiai": "albeggiare",
    "albeggiammo": "albeggiare",
    "albeggiamo": "albeggiare",
    "albeggian": "albeggiare",
    "albeggiando": "albeggiare",
    "albeggiano": "albeggiare",
    "albeggiante": "albeggiare",
    "albeggianti": "albeggiare",
    "albeggiar": "albeggiare",
    "albeggiaron": "albeggiare",
    "albeggiarono": "albeggiare",
    "albeggiasse": "albeggiare",
    "albeggiasser": "albeggiare",
    "albeggiassero": "albeggiare",
    "albeggiassi": "albeggiare",
    "albeggiassimo": "albeggiare",
    "albeggiaste": "albeggiare",
    "albeggiasti": "albeggiare",
    "albeggiata": "albeggiare",
    "albeggiate": "albeggiare",
    "albeggiati": "albeggiare",
    "albeggiato": "albeggiare",
    "albeggiava": "albeggiare",
    "albeggiavamo": "albeggiare",
    "albeggiavan": "albeggiare",
    "albeggiavano": "albeggiare",
    "albeggiavate": "albeggiare",
    "albeggiavi": "albeggiare",
    "albeggiavo": "albeggiare",
    "albeggin": "albeggiare",
    "albeggino": "albeggiare",
    "albeggio": "albeggiare",
    "albeggiò": "albeggiare",
    "albera": "alberare",
    "alberai": "alberare",
    "alberammo": "alberare",
    "alberan": "alberare",
    "alberando": "alberare",
    "alberano": "alberare",
    "alberante": "alberare",
    "alberanti": "alberare",
    "alberar": "alberare",
    "alberaron": "alberare",
    "alberarono": "alberare",
    "alberasse": "alberare",
    "alberasser": "alberare",
    "alberassero": "alberare",
    "alberassi": "alberare",
    "alberassimo": "alberare",
    "alberaste": "alberare",
    "alberasti": "alberare",
    "alberata": "alberato",
    "alberate": "alberato",
    "alberati": "alberato",
    "alberato": "alberare",
    "alberava": "alberare",
    "alberavamo": "alberare",
    "alberavan": "alberare",
    "alberavano": "alberare",
    "alberavate": "alberare",
    "alberavi": "alberare",
    "alberavo": "alberare",
    "alberelli": "alberello",
    "albererai": "alberare",
    "albereran": "alberare",
    "albereranno": "alberare",
    "albererebbe": "alberare",
    "albererebber": "alberare",
    "albererebbero": "alberare",
    "albererei": "alberare",
    "albereremmo": "alberare",
    "albereremo": "alberare",
    "alberereste": "alberare",
    "albereresti": "alberare",
    "albererete": "alberare",
    "albererà": "alberare",
    "albererò": "alberare",
    "albergatori": "albergatore",
    "alberghetti": "alberghetto",
    "alberghi": "albergo",
    "alberghiera": "alberghiero",
    "alberghiere": "alberghiero",
    "alberghieri": "alberghiero",
    "albergoni": "albergone",
    "alberi": "albero",
    "alberiamo": "alberare",
    "alberiate": "alberare",
    "alberin": "alberare",
    "alberino": "alberare",
    "albero": "alberare",
    "alberò": "alberare",
    "albi": "albo",
    "albicocche": "albicocca",
    "albina": "albino",
    "albine": "albino",
    "albini": "albino",
    "albori": "albore",
    "alchemica": "alchemico",
    "alchemiche": "alchemico",
    "alchemici": "alchemico",
    "alchimie": "alchimia",
    "alchimisti": "alchimista",
    "alcolica": "alcolico",
    "alcoliche": "alcolico",
    "alcolici": "alcolico",
    "alcolisti": "alcolista",
    "alcolizza": "alcolizzare",
    "alcolizzai": "alcolizzare",
    "alcolizzammo": "alcolizzare",
    "alcolizzan": "alcolizzare",
    "alcolizzando": "alcolizzare",
    "alcolizzano": "alcolizzare",
    "alcolizzante": "alcolizzare",
    "alcolizzanti": "alcolizzare",
    "alcolizzar": "alcolizzare",
    "alcolizzaron": "alcolizzare",
    "alcolizzarono": "alcolizzare",
    "alcolizzasse": "alcolizzare",
    "alcolizzasser": "alcolizzare",
    "alcolizzassero": "alcolizzare",
    "alcolizzassi": "alcolizzare",
    "alcolizzassimo": "alcolizzare",
    "alcolizzaste": "alcolizzare",
    "alcolizzasti": "alcolizzare",
    "alcolizzata": "alcolizzato",
    "alcolizzate": "alcolizzato",
    "alcolizzati": "alcolizzato",
    "alcolizzato": "alcolizzare",
    "alcolizzava": "alcolizzare",
    "alcolizzavamo": "alcolizzare",
    "alcolizzavan": "alcolizzare",
    "alcolizzavano": "alcolizzare",
    "alcolizzavate": "alcolizzare",
    "alcolizzavi": "alcolizzare",
    "alcolizzavo": "alcolizzare",
    "alcolizzerai": "alcolizzare",
    "alcolizzeran": "alcolizzare",
    "alcolizzeranno": "alcolizzare",
    "alcolizzerebbe": "alcolizzare",
    "alcolizzerebber": "alcolizzare",
    "alcolizzerebbero": "alcolizzare",
    "alcolizzerei": "alcolizzare",
    "alcolizzeremmo": "alcolizzare",
    "alcolizzeremo": "alcolizzare",
    "alcolizzereste": "alcolizzare",
    "alcolizzeresti": "alcolizzare",
    "alcolizzerete": "alcolizzare",
    "alcolizzerà": "alcolizzare",
    "alcolizzerò": "alcolizzare",
    "alcolizzi": "alcolizzare",
    "alcolizziamo": "alcolizzare",
    "alcolizziate": "alcolizzare",
    "alcolizzin": "alcolizzare",
    "alcolizzino": "alcolizzare",
    "alcolizzo": "alcolizzare",
    "alcolizzò": "alcolizzare",
    "alcove": "alcova",
    "alcuna": "alcun",
    "alcune": "alcun",
    "alcuni": "alcun",
    "aldina": "aldino",
    "aldine": "aldino",
    "aldini": "aldino",
    "aleatori": "aleatorio",
    "aleatoria": "aleatorio",
    "aleatorie": "aleatorio",
    "aleggerai": "aleggiare",
    "aleggeran": "aleggiare",
    "aleggeranno": "aleggiare",
    "aleggerebbe": "aleggiare",
    "aleggerebber": "aleggiare",
    "aleggerebbero": "aleggiare",
    "aleggerei": "aleggiare",
    "aleggeremmo": "aleggiare",
    "aleggeremo": "aleggiare",
    "aleggereste": "aleggiare",
    "aleggeresti": "aleggiare",
    "aleggerete": "aleggiare",
    "aleggerà": "aleggiare",
    "aleggerò": "aleggiare",
    "aleggi": "aleggiare",
    "aleggia": "aleggiare",
    "aleggiai": "aleggiare",
    "aleggiammo": "aleggiare",
    "aleggiamo": "aleggiare",
    "aleggian": "aleggiare",
    "aleggiando": "aleggiare",
    "aleggiano": "aleggiare",
    "aleggiante": "aleggiare",
    "aleggianti": "aleggiare",
    "aleggiar": "aleggiare",
    "aleggiaron": "aleggiare",
    "aleggiarono": "aleggiare",
    "aleggiasse": "aleggiare",
    "aleggiasser": "aleggiare",
    "aleggiassero": "aleggiare",
    "aleggiassi": "aleggiare",
    "aleggiassimo": "aleggiare",
    "aleggiaste": "aleggiare",
    "aleggiasti": "aleggiare",
    "aleggiata": "aleggiare",
    "aleggiate": "aleggiare",
    "aleggiati": "aleggiare",
    "aleggiato": "aleggiare",
    "aleggiava": "aleggiare",
    "aleggiavamo": "aleggiare",
    "aleggiavan": "aleggiare",
    "aleggiavano": "aleggiare",
    "aleggiavate": "aleggiare",
    "aleggiavi": "aleggiare",
    "aleggiavo": "aleggiare",
    "aleggin": "aleggiare",
    "aleggino": "aleggiare",
    "aleggio": "aleggiare",
    "aleggiò": "aleggiare",
    "alemanna": "alemanno",
    "alemanne": "alemanno",
    "alemanni": "alemanno",
    "alena": "alenare",
    "alenai": "alenare",
    "alenammo": "alenare",
    "alenan": "alenare",
    "alenando": "alenare",
    "alenano": "alenare",
    "alenante": "alenare",
    "alenanti": "alenare",
    "alenar": "alenare",
    "alenaron": "alenare",
    "alenarono": "alenare",
    "alenasse": "alenare",
    "alenasser": "alenare",
    "alenassero": "alenare",
    "alenassi": "alenare",
    "alenassimo": "alenare",
    "alenaste": "alenare",
    "alenasti": "alenare",
    "alenata": "alenare",
    "alenate": "alenare",
    "alenati": "alenare",
    "alenato": "alenare",
    "alenava": "alenare",
    "alenavamo": "alenare",
    "alenavan": "alenare",
    "alenavano": "alenare",
    "alenavate": "alenare",
    "alenavi": "alenare",
    "alenavo": "alenare",
    "alenerai": "alenare",
    "aleneran": "alenare",
    "aleneranno": "alenare",
    "alenerebbe": "alenare",
    "alenerebber": "alenare",
    "alenerebbero": "alenare",
    "alenerei": "alenare",
    "aleneremmo": "alenare",
    "aleneremo": "alenare",
    "alenereste": "alenare",
    "aleneresti": "alenare",
    "alenerete": "alenare",
    "alenerà": "alenare",
    "alenerò": "alenare",
    "aleni": "alenare",
    "aleniamo": "alenare",
    "aleniate": "alenare",
    "alenin": "alenare",
    "alenino": "alenare",
    "aleno": "alenare",
    "alenò": "alenare",
    "alerai": "alare",
    "aleran": "alare",
    "aleranno": "alare",
    "alerebbe": "alare",
    "alerebber": "alare",
    "alerebbero": "alare",
    "alerei": "alare",
    "aleremmo": "alare",
    "aleremo": "alare",
    "alereste": "alare",
    "aleresti": "alare",
    "alerete": "alare",
    "alerà": "alare",
    "alerò": "alare",
    "alesa": "alesare",
    "alesai": "alesare",
    "alesammo": "alesare",
    "alesan": "alesare",
    "alesando": "alesare",
    "alesano": "alesare",
    "alesante": "alesare",
    "alesanti": "alesare",
    "alesar": "alesare",
    "alesaron": "alesare",
    "alesarono": "alesare",
    "alesasse": "alesare",
    "alesasser": "alesare",
    "alesassero": "alesare",
    "alesassi": "alesare",
    "alesassimo": "alesare",
    "alesaste": "alesare",
    "alesasti": "alesare",
    "alesata": "alesare",
    "alesate": "alesare",
    "alesati": "alesare",
    "alesato": "alesare",
    "alesava": "alesare",
    "alesavamo": "alesare",
    "alesavan": "alesare",
    "alesavano": "alesare",
    "alesavate": "alesare",
    "alesavi": "alesare",
    "alesavo": "alesare",
    "aleserai": "alesare",
    "aleseran": "alesare",
    "aleseranno": "alesare",
    "aleserebbe": "alesare",
    "aleserebber": "alesare",
    "aleserebbero": "alesare",
    "aleserei": "alesare",
    "aleseremmo": "alesare",
    "aleseremo": "alesare",
    "alesereste": "alesare",
    "aleseresti": "alesare",
    "aleserete": "alesare",
    "aleserà": "alesare",
    "aleserò": "alesare",
    "alesi": "alesare",
    "alesiamo": "alesare",
    "alesiate": "alesare",
    "alesin": "alesare",
    "alesino": "alesare",
    "aleso": "alesare",
    "alessandrina": "alessandrino",
    "alessandrine": "alessandrino",
    "alessandrini": "alessandrino",
    "alesò": "alesare",
    "aletta": "alettare",
    "alettai": "alettare",
    "alettammo": "alettare",
    "alettan": "alettare",
    "alettando": "alettare",
    "alettano": "alettare",
    "alettante": "alettare",
    "alettanti": "alettare",
    "alettar": "alettare",
    "alettaron": "alettare",
    "alettarono": "alettare",
    "alettasse": "alettare",
    "alettasser": "alettare",
    "alettassero": "alettare",
    "alettassi": "alettare",
    "alettassimo": "alettare",
    "alettaste": "alettare",
    "alettasti": "alettare",
    "alettata": "alettare",
    "alettate": "alettare",
    "alettati": "alettare",
    "alettato": "alettare",
    "alettava": "alettare",
    "alettavamo": "alettare",
    "alettavan": "alettare",
    "alettavano": "alettare",
    "alettavate": "alettare",
    "alettavi": "alettare",
    "alettavo": "alettare",
    "alette": "aletta",
    "aletterai": "alettare",
    "aletteran": "alettare",
    "aletteranno": "alettare",
    "aletterebbe": "alettare",
    "aletterebber": "alettare",
    "aletterebbero": "alettare",
    "aletterei": "alettare",
    "aletteremmo": "alettare",
    "aletteremo": "alettare",
    "alettereste": "alettare",
    "aletteresti": "alettare",
    "aletterete": "alettare",
    "aletterà": "alettare",
    "aletterò": "alettare",
    "aletti": "alettare",
    "alettiamo": "alettare",
    "alettiate": "alettare",
    "alettin": "alettare",
    "alettino": "alettare",
    "aletto": "alettare",
    "alettoni": "alettone",
    "alettò": "alettare",
    "alfabete": "alfabeta",
    "alfabeti": "alfabeto",
    "alfabetica": "alfabetico",
    "alfabetiche": "alfabetico",
    "alfabetici": "alfabetico",
    "alfabetizza": "alfabetizzare",
    "alfabetizzai": "alfabetizzare",
    "alfabetizzammo": "alfabetizzare",
    "alfabetizzan": "alfabetizzare",
    "alfabetizzando": "alfabetizzare",
    "alfabetizzano": "alfabetizzare",
    "alfabetizzante": "alfabetizzare",
    "alfabetizzanti": "alfabetizzare",
    "alfabetizzar": "alfabetizzare",
    "alfabetizzaron": "alfabetizzare",
    "alfabetizzarono": "alfabetizzare",
    "alfabetizzasse": "alfabetizzare",
    "alfabetizzasser": "alfabetizzare",
    "alfabetizzassero": "alfabetizzare",
    "alfabetizzassi": "alfabetizzare",
    "alfabetizzassimo": "alfabetizzare",
    "alfabetizzaste": "alfabetizzare",
    "alfabetizzasti": "alfabetizzare",
    "alfabetizzata": "alfabetizzare",
    "alfabetizzate": "alfabetizzare",
    "alfabetizzati": "alfabetizzare",
    "alfabetizzato": "alfabetizzare",
    "alfabetizzava": "alfabetizzare",
    "alfabetizzavamo": "alfabetizzare",
    "alfabetizzavan": "alfabetizzare",
    "alfabetizzavano": "alfabetizzare",
    "alfabetizzavate": "alfabetizzare",
    "alfabetizzavi": "alfabetizzare",
    "alfabetizzavo": "alfabetizzare",
    "alfabetizzazioni": "alfabetizzazione",
    "alfabetizzerai": "alfabetizzare",
    "alfabetizzeran": "alfabetizzare",
    "alfabetizzeranno": "alfabetizzare",
    "alfabetizzerebbe": "alfabetizzare",
    "alfabetizzerebber": "alfabetizzare",
    "alfabetizzerebbero": "alfabetizzare",
    "alfabetizzerei": "alfabetizzare",
    "alfabetizzeremmo": "alfabetizzare",
    "alfabetizzeremo": "alfabetizzare",
    "alfabetizzereste": "alfabetizzare",
    "alfabetizzeresti": "alfabetizzare",
    "alfabetizzerete": "alfabetizzare",
    "alfabetizzerà": "alfabetizzare",
    "alfabetizzerò": "alfabetizzare",
    "alfabetizzi": "alfabetizzare",
    "alfabetizziamo": "alfabetizzare",
    "alfabetizziate": "alfabetizzare",
    "alfabetizzin": "alfabetizzare",
    "alfabetizzino": "alfabetizzare",
    "alfabetizzo": "alfabetizzare",
    "alfabetizzò": "alfabetizzare",
    "alfette": "alfetta",
    "alfieri": "alfiere",
    "alfisti": "alfista",
    "algebrica": "algebrico",
    "algebriche": "algebrico",
    "algebrici": "algebrico",
    "algerina": "algerino",
    "algerine": "algerino",
    "algerini": "algerino",
    "alghe": "alga",
    "algida": "algido",
    "algide": "algido",
    "algidi": "algido",
    "algoritmi": "algoritmo",
    "ali": "alare",
    "aliamo": "alare",
    "alianti": "aliante",
    "aliate": "alare",
    "alida": "alido",
    "alide": "alido",
    "alidi": "alido",
    "aliena": "alieno",
    "alienabili": "alienabile",
    "alienai": "alienare",
    "alienammo": "alienare",
    "alienan": "alienare",
    "alienando": "alienare",
    "alienano": "alienare",
    "alienante": "alienare",
    "alienanti": "alienare",
    "alienar": "alienare",
    "alienaron": "alienare",
    "alienarono": "alienare",
    "alienasse": "alienare",
    "alienasser": "alienare",
    "alienassero": "alienare",
    "alienassi": "alienare",
    "alienassimo": "alienare",
    "alienaste": "alienare",
    "alienasti": "alienare",
    "alienata": "alienato",
    "alienate": "alienato",
    "alienati": "alienato",
    "alienato": "alienare",
    "alienava": "alienare",
    "alienavamo": "alienare",
    "alienavan": "alienare",
    "alienavano": "alienare",
    "alienavate": "alienare",
    "alienavi": "alienare",
    "alienavo": "alienare",
    "alienazioni": "alienazione",
    "aliene": "alieno",
    "alienerai": "alienare",
    "alieneran": "alienare",
    "alieneranno": "alienare",
    "alienerebbe": "alienare",
    "alienerebber": "alienare",
    "alienerebbero": "alienare",
    "alienerei": "alienare",
    "alieneremmo": "alienare",
    "alieneremo": "alienare",
    "alienereste": "alienare",
    "alieneresti": "alienare",
    "alienerete": "alienare",
    "alienerà": "alienare",
    "alienerò": "alienare",
    "alieni": "alieno",
    "alieniamo": "alienare",
    "alieniate": "alienare",
    "alienin": "alienare",
    "alienino": "alienare",
    "alieno": "alienare",
    "alienò": "alienare",
    "alimenta": "alimentare",
    "alimentai": "alimentare",
    "alimentammo": "alimentare",
    "alimentan": "alimentare",
    "alimentando": "alimentare",
    "alimentano": "alimentare",
    "alimentante": "alimentare",
    "alimentanti": "alimentare",
    "alimentar": "alimentare",
    "alimentari": "alimentario",
    "alimentaria": "alimentario",
    "alimentarie": "alimentario",
    "alimentaristi": "alimentarista",
    "alimentaron": "alimentare",
    "alimentarono": "alimentare",
    "alimentasse": "alimentare",
    "alimentasser": "alimentare",
    "alimentassero": "alimentare",
    "alimentassi": "alimentare",
    "alimentassimo": "alimentare",
    "alimentaste": "alimentare",
    "alimentasti": "alimentare",
    "alimentata": "alimentare",
    "alimentate": "alimentare",
    "alimentati": "alimentare",
    "alimentato": "alimentare",
    "alimentava": "alimentare",
    "alimentavamo": "alimentare",
    "alimentavan": "alimentare",
    "alimentavano": "alimentare",
    "alimentavate": "alimentare",
    "alimentavi": "alimentare",
    "alimentavo": "alimentare",
    "alimentazioni": "alimentazione",
    "alimenterai": "alimentare",
    "alimenteran": "alimentare",
    "alimenteranno": "alimentare",
    "alimenterebbe": "alimentare",
    "alimenterebber": "alimentare",
    "alimenterebbero": "alimentare",
    "alimenterei": "alimentare",
    "alimenteremmo": "alimentare",
    "alimenteremo": "alimentare",
    "alimentereste": "alimentare",
    "alimenteresti": "alimentare",
    "alimenterete": "alimentare",
    "alimenterà": "alimentare",
    "alimenterò": "alimentare",
    "alimenti": "alimento",
    "alimentiamo": "alimentare",
    "alimentiate": "alimentare",
    "alimentin": "alimentare",
    "alimentino": "alimentare",
    "alimento": "alimentare",
    "alimentò": "alimentare",
    "alin": "alare",
    "alino": "alare",
    "aliquote": "aliquota",
    "aliscafi": "aliscafo",
    "alita": "alitare",
    "alitai": "alitare",
    "alitammo": "alitare",
    "alitan": "alitare",
    "alitando": "alitare",
    "alitano": "alitare",
    "alitante": "alitare",
    "alitanti": "alitare",
    "alitar": "alitare",
    "alitaron": "alitare",
    "alitarono": "alitare",
    "alitasse": "alitare",
    "alitasser": "alitare",
    "alitassero": "alitare",
    "alitassi": "alitare",
    "alitassimo": "alitare",
    "alitaste": "alitare",
    "alitasti": "alitare",
    "alitata": "alitare",
    "alitate": "alitare",
    "alitati": "alitare",
    "alitato": "alitare",
    "alitava": "alitare",
    "alitavamo": "alitare",
    "alitavan": "alitare",
    "alitavano": "alitare",
    "alitavate": "alitare",
    "alitavi": "alitare",
    "alitavo": "alitare",
    "aliterai": "alitare",
    "aliteran": "alitare",
    "aliteranno": "alitare",
    "aliterebbe": "alitare",
    "aliterebber": "alitare",
    "aliterebbero": "alitare",
    "aliterei": "alitare",
    "aliteremmo": "alitare",
    "aliteremo": "alitare",
    "alitereste": "alitare",
    "aliteresti": "alitare",
    "aliterete": "alitare",
    "aliterà": "alitare",
    "aliterò": "alitare",
    "aliti": "alito",
    "alitiamo": "alitare",
    "alitiate": "alitare",
    "alitin": "alitare",
    "alitino": "alitare",
    "alito": "alitare",
    "alitò": "alitare",
    "all'": "alla",
    "allaccerai": "allacciare",
    "allacceran": "allacciare",
    "allacceranno": "allacciare",
    "allaccerebbe": "allacciare",
    "allaccerebber": "allacciare",
    "allaccerebbero": "allacciare",
    "allaccerei": "allacciare",
    "allacceremmo": "allacciare",
    "allacceremo": "allacciare",
    "allaccereste": "allacciare",
    "allacceresti": "allacciare",
    "allaccerete": "allacciare",
    "allaccerà": "allacciare",
    "allaccerò": "allacciare",
    "allacci": "allaccio",
    "allaccia": "allacciare",
    "allacciai": "allacciare",
    "allacciamenti": "allacciamento",
    "allacciammo": "allacciare",
    "allacciamo": "allacciare",
    "allaccian": "allacciare",
    "allacciando": "allacciare",
    "allacciano": "allacciare",
    "allacciante": "allacciare",
    "allaccianti": "allacciare",
    "allacciar": "allacciare",
    "allacciaron": "allacciare",
    "allacciarono": "allacciare",
    "allacciasse": "allacciare",
    "allacciasser": "allacciare",
    "allacciassero": "allacciare",
    "allacciassi": "allacciare",
    "allacciassimo": "allacciare",
    "allacciaste": "allacciare",
    "allacciasti": "allacciare",
    "allacciata": "allacciare",
    "allacciate": "allacciare",
    "allacciati": "allacciare",
    "allacciato": "allacciare",
    "allacciava": "allacciare",
    "allacciavamo": "allacciare",
    "allacciavan": "allacciare",
    "allacciavano": "allacciare",
    "allacciavate": "allacciare",
    "allacciavi": "allacciare",
    "allacciavo": "allacciare",
    "allaccin": "allacciare",
    "allaccino": "allacciare",
    "allaccio": "allacciare",
    "allacciò": "allacciare",
    "allaga": "allagare",
    "allagai": "allagare",
    "allagamenti": "allagamento",
    "allagammo": "allagare",
    "allagan": "allagare",
    "allagando": "allagare",
    "allagano": "allagare",
    "allagante": "allagare",
    "allaganti": "allagare",
    "allagar": "allagare",
    "allagaron": "allagare",
    "allagarono": "allagare",
    "allagasse": "allagare",
    "allagasser": "allagare",
    "allagassero": "allagare",
    "allagassi": "allagare",
    "allagassimo": "allagare",
    "allagaste": "allagare",
    "allagasti": "allagare",
    "allagata": "allagare",
    "allagate": "allagare",
    "allagati": "allagare",
    "allagato": "allagare",
    "allagava": "allagare",
    "allagavamo": "allagare",
    "allagavan": "allagare",
    "allagavano": "allagare",
    "allagavate": "allagare",
    "allagavi": "allagare",
    "allagavo": "allagare",
    "allagherai": "allagare",
    "allagheran": "allagare",
    "allagheranno": "allagare",
    "allagherebbe": "allagare",
    "allagherebber": "allagare",
    "allagherebbero": "allagare",
    "allagherei": "allagare",
    "allagheremmo": "allagare",
    "allagheremo": "allagare",
    "allaghereste": "allagare",
    "allagheresti": "allagare",
    "allagherete": "allagare",
    "allagherà": "allagare",
    "allagherò": "allagare",
    "allaghi": "allagare",
    "allaghiamo": "allagare",
    "allaghiate": "allagare",
    "allaghin": "allagare",
    "allaghino": "allagare",
    "allago": "allagare",
    "allagò": "allagare",
    "allampanata": "allampanato",
    "allampanate": "allampanato",
    "allampanati": "allampanato",
    "allappa": "allappare",
    "allappai": "allappare",
    "allappammo": "allappare",
    "allappan": "allappare",
    "allappando": "allappare",
    "allappano": "allappare",
    "allappante": "allappare",
    "allappanti": "allappare",
    "allappar": "allappare",
    "allapparon": "allappare",
    "allapparono": "allappare",
    "allappasse": "allappare",
    "allappasser": "allappare",
    "allappassero": "allappare",
    "allappassi": "allappare",
    "allappassimo": "allappare",
    "allappaste": "allappare",
    "allappasti": "allappare",
    "allappata": "allappare",
    "allappate": "allappare",
    "allappati": "allappare",
    "allappato": "allappare",
    "allappava": "allappare",
    "allappavamo": "allappare",
    "allappavan": "allappare",
    "allappavano": "allappare",
    "allappavate": "allappare",
    "allappavi": "allappare",
    "allappavo": "allappare",
    "allapperai": "allappare",
    "allapperan": "allappare",
    "allapperanno": "allappare",
    "allapperebbe": "allappare",
    "allapperebber": "allappare",
    "allapperebbero": "allappare",
    "allapperei": "allappare",
    "allapperemmo": "allappare",
    "allapperemo": "allappare",
    "allappereste": "allappare",
    "allapperesti": "allappare",
    "allapperete": "allappare",
    "allapperà": "allappare",
    "allapperò": "allappare",
    "allappi": "allappare",
    "allappiamo": "allappare",
    "allappiate": "allappare",
    "allappin": "allappare",
    "allappino": "allappare",
    "allappo": "allappare",
    "allappò": "allappare",
    "allarga": "allargare",
    "allargai": "allargare",
    "allargamenti": "allargamento",
    "allargammo": "allargare",
    "allargan": "allargare",
    "allargando": "allargare",
    "allargano": "allargare",
    "allargante": "allargare",
    "allarganti": "allargare",
    "allargar": "allargare",
    "allargaron": "allargare",
    "allargarono": "allargare",
    "allargasse": "allargare",
    "allargasser": "allargare",
    "allargassero": "allargare",
    "allargassi": "allargare",
    "allargassimo": "allargare",
    "allargaste": "allargare",
    "allargasti": "allargare",
    "allargata": "allargare",
    "allargate": "allargare",
    "allargati": "allargare",
    "allargato": "allargare",
    "allargava": "allargare",
    "allargavamo": "allargare",
    "allargavan": "allargare",
    "allargavano": "allargare",
    "allargavate": "allargare",
    "allargavi": "allargare",
    "allargavo": "allargare",
    "allargherai": "allargare",
    "allargheran": "allargare",
    "allargheranno": "allargare",
    "allargherebbe": "allargare",
    "allargherebber": "allargare",
    "allargherebbero": "allargare",
    "allargherei": "allargare",
    "allargheremmo": "allargare",
    "allargheremo": "allargare",
    "allarghereste": "allargare",
    "allargheresti": "allargare",
    "allargherete": "allargare",
    "allargherà": "allargare",
    "allargherò": "allargare",
    "allarghi": "allargare",
    "allarghiamo": "allargare",
    "allarghiate": "allargare",
    "allarghin": "allargare",
    "allarghino": "allargare",
    "allargo": "allargare",
    "allargò": "allargare",
    "allarma": "allarmare",
    "allarmai": "allarmare",
    "allarmammo": "allarmare",
    "allarman": "allarmare",
    "allarmando": "allarmare",
    "allarmano": "allarmare",
    "allarmante": "allarmare",
    "allarmanti": "allarmare",
    "allarmar": "allarmare",
    "allarmaron": "allarmare",
    "allarmarono": "allarmare",
    "allarmasse": "allarmare",
    "allarmasser": "allarmare",
    "allarmassero": "allarmare",
    "allarmassi": "allarmare",
    "allarmassimo": "allarmare",
    "allarmaste": "allarmare",
    "allarmasti": "allarmare",
    "allarmata": "allarmato",
    "allarmate": "allarmato",
    "allarmati": "allarmato",
    "allarmato": "allarmare",
    "allarmava": "allarmare",
    "allarmavamo": "allarmare",
    "allarmavan": "allarmare",
    "allarmavano": "allarmare",
    "allarmavate": "allarmare",
    "allarmavi": "allarmare",
    "allarmavo": "allarmare",
    "allarmerai": "allarmare",
    "allarmeran": "allarmare",
    "allarmeranno": "allarmare",
    "allarmerebbe": "allarmare",
    "allarmerebber": "allarmare",
    "allarmerebbero": "allarmare",
    "allarmerei": "allarmare",
    "allarmeremmo": "allarmare",
    "allarmeremo": "allarmare",
    "allarmereste": "allarmare",
    "allarmeresti": "allarmare",
    "allarmerete": "allarmare",
    "allarmerà": "allarmare",
    "allarmerò": "allarmare",
    "allarmi": "allarme",
    "allarmiamo": "allarmare",
    "allarmiate": "allarmare",
    "allarmin": "allarmare",
    "allarmino": "allarmare",
    "allarmismi": "allarmismo",
    "allarmistica": "allarmistico",
    "allarmistiche": "allarmistico",
    "allarmistici": "allarmistico",
    "allarmo": "allarmare",
    "allarmò": "allarmare",
    "allatta": "allattare",
    "allattai": "allattare",
    "allattammo": "allattare",
    "allattan": "allattare",
    "allattando": "allattare",
    "allattano": "allattare",
    "allattante": "allattare",
    "allattanti": "allattare",
    "allattar": "allattare",
    "allattaron": "allattare",
    "allattarono": "allattare",
    "allattasse": "allattare",
    "allattasser": "allattare",
    "allattassero": "allattare",
    "allattassi": "allattare",
    "allattassimo": "allattare",
    "allattaste": "allattare",
    "allattasti": "allattare",
    "allattata": "allattare",
    "allattate": "allattare",
    "allattati": "allattare",
    "allattato": "allattare",
    "allattava": "allattare",
    "allattavamo": "allattare",
    "allattavan": "allattare",
    "allattavano": "allattare",
    "allattavate": "allattare",
    "allattavi": "allattare",
    "allattavo": "allattare",
    "allatterai": "allattare",
    "allatteran": "allattare",
    "allatteranno": "allattare",
    "allatterebbe": "allattare",
    "allatterebber": "allattare",
    "allatterebbero": "allattare",
    "allatterei": "allattare",
    "allatteremmo": "allattare",
    "allatteremo": "allattare",
    "allattereste": "allattare",
    "allatteresti": "allattare",
    "allatterete": "allattare",
    "allatterà": "allattare",
    "allatterò": "allattare",
    "allatti": "allattare",
    "allattiamo": "allattare",
    "allattiate": "allattare",
    "allattin": "allattare",
    "allattino": "allattare",
    "allatto": "allattare",
    "allattò": "allattare",
    "alle": "alla",
    "allea": "alleare",
    "alleai": "alleare",
    "alleammo": "alleare",
    "allean": "alleare",
    "alleando": "alleare",
    "alleano": "alleare",
    "alleante": "alleare",
    "alleanti": "alleare",
    "alleanze": "alleanza",
    "allear": "alleare",
    "allearon": "alleare",
    "allearono": "alleare",
    "alleasse": "alleare",
    "alleasser": "alleare",
    "alleassero": "alleare",
    "alleassi": "alleare",
    "alleassimo": "alleare",
    "alleaste": "alleare",
    "alleasti": "alleare",
    "alleata": "alleato",
    "alleate": "alleato",
    "alleati": "alleato",
    "alleato": "alleare",
    "alleava": "alleare",
    "alleavamo": "alleare",
    "alleavan": "alleare",
    "alleavano": "alleare",
    "alleavate": "alleare",
    "alleavi": "alleare",
    "alleavo": "alleare",
    "alleerai": "alleare",
    "alleeran": "alleare",
    "alleeranno": "alleare",
    "alleerebbe": "alleare",
    "alleerebber": "alleare",
    "alleerebbero": "alleare",
    "alleerei": "alleare",
    "alleeremmo": "alleare",
    "alleeremo": "alleare",
    "alleereste": "alleare",
    "alleeresti": "alleare",
    "alleerete": "alleare",
    "alleerà": "alleare",
    "alleerò": "alleare",
    "allega": "allegare",
    "allegai": "allegare",
    "allegammo": "allegare",
    "allegan": "allegare",
    "allegando": "allegare",
    "allegano": "allegare",
    "allegante": "allegare",
    "alleganti": "allegare",
    "allegar": "allegare",
    "allegaron": "allegare",
    "allegarono": "allegare",
    "allegasse": "allegare",
    "allegasser": "allegare",
    "allegassero": "allegare",
    "allegassi": "allegare",
    "allegassimo": "allegare",
    "allegaste": "allegare",
    "allegasti": "allegare",
    "allegata": "allegato",
    "allegate": "allegato",
    "allegati": "allegato",
    "allegato": "allegare",
    "allegava": "allegare",
    "allegavamo": "allegare",
    "allegavan": "allegare",
    "allegavano": "allegare",
    "allegavate": "allegare",
    "allegavi": "allegare",
    "allegavo": "allegare",
    "alleggerendo": "alleggerire",
    "alleggerente": "alleggerire",
    "alleggerenti": "alleggerire",
    "alleggeriamo": "alleggerire",
    "alleggeriate": "alleggerire",
    "alleggerii": "alleggerire",
    "alleggerimenti": "alleggerimento",
    "alleggerimmo": "alleggerire",
    "alleggerir": "alleggerire",
    "alleggerirai": "alleggerire",
    "alleggeriran": "alleggerire",
    "alleggeriranno": "alleggerire",
    "alleggerirebbe": "alleggerire",
    "alleggerirebber": "alleggerire",
    "alleggerirebbero": "alleggerire",
    "alleggerirei": "alleggerire",
    "alleggeriremmo": "alleggerire",
    "alleggeriremo": "alleggerire",
    "alleggerireste": "alleggerire",
    "alleggeriresti": "alleggerire",
    "alleggerirete": "alleggerire",
    "alleggeriron": "alleggerire",
    "alleggerirono": "alleggerire",
    "alleggerirà": "alleggerire",
    "alleggerirò": "alleggerire",
    "alleggerisca": "alleggerire",
    "alleggeriscan": "alleggerire",
    "alleggeriscano": "alleggerire",
    "alleggerisce": "alleggerire",
    "alleggerisci": "alleggerire",
    "alleggerisco": "alleggerire",
    "alleggeriscon": "alleggerire",
    "alleggeriscono": "alleggerire",
    "alleggerisse": "alleggerire",
    "alleggerisser": "alleggerire",
    "alleggerissero": "alleggerire",
    "alleggerissi": "alleggerire",
    "alleggerissimo": "alleggerire",
    "alleggeriste": "alleggerire",
    "alleggeristi": "alleggerire",
    "alleggerita": "alleggerire",
    "alleggerite": "alleggerire",
    "alleggeriti": "alleggerire",
    "alleggerito": "alleggerire",
    "alleggeriva": "alleggerire",
    "alleggerivamo": "alleggerire",
    "alleggerivan": "alleggerire",
    "alleggerivano": "alleggerire",
    "alleggerivate": "alleggerire",
    "alleggerivi": "alleggerire",
    "alleggerivo": "alleggerire",
    "alleggerì": "alleggerire",
    "allegherai": "allegare",
    "allegheran": "allegare",
    "allegheranno": "allegare",
    "allegherebbe": "allegare",
    "allegherebber": "allegare",
    "allegherebbero": "allegare",
    "allegherei": "allegare",
    "allegheremmo": "allegare",
    "allegheremo": "allegare",
    "alleghereste": "allegare",
    "allegheresti": "allegare",
    "allegherete": "allegare",
    "allegherà": "allegare",
    "allegherò": "allegare",
    "alleghi": "allegare",
    "alleghiamo": "allegare",
    "alleghiate": "allegare",
    "alleghin": "allegare",
    "alleghino": "allegare",
    "allego": "allegare",
    "allegorica": "allegorico",
    "allegoriche": "allegorico",
    "allegorici": "allegorico",
    "allegorie": "allegoria",
    "allegra": "allegro",
    "allegre": "allegro",
    "allegri": "allegro",
    "allegrie": "allegria",
    "allegò": "allegare",
    "allei": "alleare",
    "alleiamo": "alleare",
    "alleiate": "alleare",
    "allein": "alleare",
    "alleino": "alleare",
    "allena": "allenare",
    "allenai": "allenare",
    "allenamenti": "allenamento",
    "allenammo": "allenare",
    "allenan": "allenare",
    "allenando": "allenare",
    "allenano": "allenare",
    "allenante": "allenare",
    "allenanti": "allenare",
    "allenar": "allenare",
    "allenaron": "allenare",
    "allenarono": "allenare",
    "allenasse": "allenare",
    "allenasser": "allenare",
    "allenassero": "allenare",
    "allenassi": "allenare",
    "allenassimo": "allenare",
    "allenaste": "allenare",
    "allenasti": "allenare",
    "allenata": "allenare",
    "allenate": "allenare",
    "allenati": "allenare",
    "allenato": "allenare",
    "allenatori": "allenatore",
    "allenava": "allenare",
    "allenavamo": "allenare",
    "allenavan": "allenare",
    "allenavano": "allenare",
    "allenavate": "allenare",
    "allenavi": "allenare",
    "allenavo": "allenare",
    "allenerai": "allenare",
    "alleneran": "allenare",
    "alleneranno": "allenare",
    "allenerebbe": "allenare",
    "allenerebber": "allenare",
    "allenerebbero": "allenare",
    "allenerei": "allenare",
    "alleneremmo": "allenare",
    "alleneremo": "allenare",
    "allenereste": "allenare",
    "alleneresti": "allenare",
    "allenerete": "allenare",
    "allenerà": "allenare",
    "allenerò": "allenare",
    "alleni": "allenare",
    "alleniamo": "allenare",
    "alleniate": "allenare",
    "allenin": "allenare",
    "allenino": "allenare",
    "alleno": "allenare",
    "allenta": "allentare",
    "allentai": "allentare",
    "allentamenti": "allentamento",
    "allentammo": "allentare",
    "allentan": "allentare",
    "allentando": "allentare",
    "allentano": "allentare",
    "allentante": "allentare",
    "allentanti": "allentare",
    "allentar": "allentare",
    "allentaron": "allentare",
    "allentarono": "allentare",
    "allentasse": "allentare",
    "allentasser": "allentare",
    "allentassero": "allentare",
    "allentassi": "allentare",
    "allentassimo": "allentare",
    "allentaste": "allentare",
    "allentasti": "allentare",
    "allentata": "allentare",
    "allentate": "allentare",
    "allentati": "allentare",
    "allentato": "allentare",
    "allentava": "allentare",
    "allentavamo": "allentare",
    "allentavan": "allentare",
    "allentavano": "allentare",
    "allentavate": "allentare",
    "allentavi": "allentare",
    "allentavo": "allentare",
    "allenterai": "allentare",
    "allenteran": "allentare",
    "allenteranno": "allentare",
    "allenterebbe": "allentare",
    "allenterebber": "allentare",
    "allenterebbero": "allentare",
    "allenterei": "allentare",
    "allenteremmo": "allentare",
    "allenteremo": "allentare",
    "allentereste": "allentare",
    "allenteresti": "allentare",
    "allenterete": "allentare",
    "allenterà": "allentare",
    "allenterò": "allentare",
    "allenti": "allentare",
    "allentiamo": "allentare",
    "allentiate": "allentare",
    "allentin": "allentare",
    "allentino": "allentare",
    "allento": "allentare",
    "allentò": "allentare",
    "allenze": "allenza",
    "allenò": "allenare",
    "alleo": "alleare",
    "allergeni": "allergene",
    "allergica": "allergico",
    "allergiche": "allergico",
    "allergici": "allergico",
    "allergie": "allergia",
    "allerta": "allertare",
    "allertai": "allertare",
    "allertammo": "allertare",
    "allertan": "allertare",
    "allertando": "allertare",
    "allertano": "allertare",
    "allertante": "allertare",
    "allertanti": "allertare",
    "allertar": "allertare",
    "allertaron": "allertare",
    "allertarono": "allertare",
    "allertasse": "allertare",
    "allertasser": "allertare",
    "allertassero": "allertare",
    "allertassi": "allertare",
    "allertassimo": "allertare",
    "allertaste": "allertare",
    "allertasti": "allertare",
    "allertata": "allertare",
    "allertate": "allertare",
    "allertati": "allertare",
    "allertato": "allertare",
    "allertava": "allertare",
    "allertavamo": "allertare",
    "allertavan": "allertare",
    "allertavano": "allertare",
    "allertavate": "allertare",
    "allertavi": "allertare",
    "allertavo": "allertare",
    "allerte": "allerta",
    "allerterai": "allertare",
    "allerteran": "allertare",
    "allerteranno": "allertare",
    "allerterebbe": "allertare",
    "allerterebber": "allertare",
    "allerterebbero": "allertare",
    "allerterei": "allertare",
    "allerteremmo": "allertare",
    "allerteremo": "allertare",
    "allertereste": "allertare",
    "allerteresti": "allertare",
    "allerterete": "allertare",
    "allerterà": "allertare",
    "allerterò": "allertare",
    "allerti": "allertare",
    "allertiamo": "allertare",
    "allertiate": "allertare",
    "allertin": "allertare",
    "allertino": "allertare",
    "allerto": "allertare",
    "allertò": "allertare",
    "allestendo": "allestire",
    "allestente": "allestire",
    "allestenti": "allestire",
    "allestiamo": "allestire",
    "allestiate": "allestire",
    "allestii": "allestire",
    "allestimenti": "allestimento",
    "allestimmo": "allestire",
    "allestir": "allestire",
    "allestirai": "allestire",
    "allestiran": "allestire",
    "allestiranno": "allestire",
    "allestirebbe": "allestire",
    "allestirebber": "allestire",
    "allestirebbero": "allestire",
    "allestirei": "allestire",
    "allestiremmo": "allestire",
    "allestiremo": "allestire",
    "allestireste": "allestire",
    "allestiresti": "allestire",
    "allestirete": "allestire",
    "allestiron": "allestire",
    "allestirono": "allestire",
    "allestirà": "allestire",
    "allestirò": "allestire",
    "allestisca": "allestire",
    "allestiscan": "allestire",
    "allestiscano": "allestire",
    "allestisce": "allestire",
    "allestisci": "allestire",
    "allestisco": "allestire",
    "allestiscon": "allestire",
    "allestiscono": "allestire",
    "allestisse": "allestire",
    "allestisser": "allestire",
    "allestissero": "allestire",
    "allestissi": "allestire",
    "allestissimo": "allestire",
    "allestiste": "allestire",
    "allestisti": "allestire",
    "allestita": "allestire",
    "allestite": "allestire",
    "allestiti": "allestire",
    "allestito": "allestire",
    "allestitori": "allestitore",
    "allestiva": "allestire",
    "allestivamo": "allestire",
    "allestivan": "allestire",
    "allestivano": "allestire",
    "allestivate": "allestire",
    "allestivi": "allestire",
    "allestivo": "allestire",
    "allestì": "allestire",
    "alletta": "allettare",
    "allettai": "allettare",
    "allettammo": "allettare",
    "allettan": "allettare",
    "allettando": "allettare",
    "allettano": "allettare",
    "allettante": "allettare",
    "allettanti": "allettare",
    "allettar": "allettare",
    "allettaron": "allettare",
    "allettarono": "allettare",
    "allettasse": "allettare",
    "allettasser": "allettare",
    "allettassero": "allettare",
    "allettassi": "allettare",
    "allettassimo": "allettare",
    "allettaste": "allettare",
    "allettasti": "allettare",
    "allettata": "allettare",
    "allettate": "allettare",
    "allettati": "allettare",
    "allettato": "allettare",
    "allettava": "allettare",
    "allettavamo": "allettare",
    "allettavan": "allettare",
    "allettavano": "allettare",
    "allettavate": "allettare",
    "allettavi": "allettare",
    "allettavo": "allettare",
    "alletterai": "allettare",
    "alletteran": "allettare",
    "alletteranno": "allettare",
    "alletterebbe": "allettare",
    "alletterebber": "allettare",
    "alletterebbero": "allettare",
    "alletterei": "allettare",
    "alletteremmo": "allettare",
    "alletteremo": "allettare",
    "allettereste": "allettare",
    "alletteresti": "allettare",
    "alletterete": "allettare",
    "alletterà": "allettare",
    "alletterò": "allettare",
    "alletti": "allettare",
    "allettiamo": "allettare",
    "allettiate": "allettare",
    "allettin": "allettare",
    "allettino": "allettare",
    "alletto": "allettare",
    "allettò": "allettare",
    "alleva": "allevare",
    "allevai": "allevare",
    "allevamenti": "allevamento",
    "allevammo": "allevare",
    "allevan": "allevare",
    "allevando": "allevare",
    "allevano": "allevare",
    "allevante": "allevare",
    "allevanti": "allevare",
    "allevar": "allevare",
    "allevaron": "allevare",
    "allevarono": "allevare",
    "allevasse": "allevare",
    "allevasser": "allevare",
    "allevassero": "allevare",
    "allevassi": "allevare",
    "allevassimo": "allevare",
    "allevaste": "allevare",
    "allevasti": "allevare",
    "allevata": "allevare",
    "allevate": "allevare",
    "allevati": "allevare",
    "allevato": "allevare",
    "allevatori": "allevatore",
    "allevava": "allevare",
    "allevavamo": "allevare",
    "allevavan": "allevare",
    "allevavano": "allevare",
    "allevavate": "allevare",
    "allevavi": "allevare",
    "allevavo": "allevare",
    "alleverai": "allevare",
    "alleveran": "allevare",
    "alleveranno": "allevare",
    "alleverebbe": "allevare",
    "alleverebber": "allevare",
    "alleverebbero": "allevare",
    "alleverei": "allevare",
    "alleveremmo": "allevare",
    "alleveremo": "allevare",
    "allevereste": "allevare",
    "alleveresti": "allevare",
    "alleverete": "allevare",
    "alleverà": "allevare",
    "alleverò": "allevare",
    "allevi": "alleviare",
    "allevia": "alleviare",
    "alleviai": "alleviare",
    "alleviammo": "alleviare",
    "alleviamo": "alleviare",
    "allevian": "alleviare",
    "alleviando": "alleviare",
    "alleviano": "alleviare",
    "alleviante": "alleviare",
    "allevianti": "alleviare",
    "alleviar": "alleviare",
    "alleviaron": "alleviare",
    "alleviarono": "alleviare",
    "alleviasse": "alleviare",
    "alleviasser": "alleviare",
    "alleviassero": "alleviare",
    "alleviassi": "alleviare",
    "alleviassimo": "alleviare",
    "alleviaste": "alleviare",
    "alleviasti": "alleviare",
    "alleviata": "alleviare",
    "alleviate": "alleviare",
    "alleviati": "alleviare",
    "alleviato": "alleviare",
    "alleviava": "alleviare",
    "alleviavamo": "alleviare",
    "alleviavan": "alleviare",
    "alleviavano": "alleviare",
    "alleviavate": "alleviare",
    "alleviavi": "alleviare",
    "alleviavo": "alleviare",
    "allevierai": "alleviare",
    "allevieran": "alleviare",
    "allevieranno": "alleviare",
    "allevierebbe": "alleviare",
    "allevierebber": "alleviare",
    "allevierebbero": "alleviare",
    "allevierei": "alleviare",
    "allevieremmo": "alleviare",
    "allevieremo": "alleviare",
    "alleviereste": "alleviare",
    "allevieresti": "alleviare",
    "allevierete": "alleviare",
    "allevierà": "alleviare",
    "allevierò": "alleviare",
    "allevin": "alleviare",
    "allevino": "alleviare",
    "allevio": "alleviare",
    "alleviò": "alleviare",
    "allevo": "allevare",
    "allevò": "allevare",
    "alleò": "alleare",
    "allibendo": "allibire",
    "allibente": "allibire",
    "allibenti": "allibire",
    "allibiamo": "allibire",
    "allibiate": "allibire",
    "allibii": "allibire",
    "allibimmo": "allibire",
    "allibir": "allibire",
    "allibirai": "allibire",
    "allibiran": "allibire",
    "allibiranno": "allibire",
    "allibirebbe": "allibire",
    "allibirebber": "allibire",
    "allibirebbero": "allibire",
    "allibirei": "allibire",
    "allibiremmo": "allibire",
    "allibiremo": "allibire",
    "allibireste": "allibire",
    "allibiresti": "allibire",
    "allibirete": "allibire",
    "allibiron": "allibire",
    "allibirono": "allibire",
    "allibirà": "allibire",
    "allibirò": "allibire",
    "allibisca": "allibire",
    "allibiscan": "allibire",
    "allibiscano": "allibire",
    "allibisce": "allibire",
    "allibisci": "allibire",
    "allibisco": "allibire",
    "allibiscon": "allibire",
    "allibiscono": "allibire",
    "allibisse": "allibire",
    "allibisser": "allibire",
    "allibissero": "allibire",
    "allibissi": "allibire",
    "allibissimo": "allibire",
    "allibiste": "allibire",
    "allibisti": "allibire",
    "allibita": "allibito",
    "allibite": "allibito",
    "allibiti": "allibito",
    "allibito": "allibire",
    "allibiva": "allibire",
    "allibivamo": "allibire",
    "allibivan": "allibire",
    "allibivano": "allibire",
    "allibivate": "allibire",
    "allibivi": "allibire",
    "allibivo": "allibire",
    "allibra": "allibrare",
    "allibrai": "allibrare",
    "allibrammo": "allibrare",
    "allibran": "allibrare",
    "allibrando": "allibrare",
    "allibrano": "allibrare",
    "allibrante": "allibrare",
    "allibranti": "allibrare",
    "allibrar": "allibrare",
    "allibraron": "allibrare",
    "allibrarono": "allibrare",
    "allibrasse": "allibrare",
    "allibrasser": "allibrare",
    "allibrassero": "allibrare",
    "allibrassi": "allibrare",
    "allibrassimo": "allibrare",
    "allibraste": "allibrare",
    "allibrasti": "allibrare",
    "allibrata": "allibrare",
    "allibrate": "allibrare",
    "allibrati": "allibrare",
    "allibrato": "allibrare",
    "allibratori": "allibratore",
    "allibrava": "allibrare",
    "allibravamo": "allibrare",
    "allibravan": "allibrare",
    "allibravano": "allibrare",
    "allibravate": "allibrare",
    "allibravi": "allibrare",
    "allibravo": "allibrare",
    "allibrerai": "allibrare",
    "allibreran": "allibrare",
    "allibreranno": "allibrare",
    "allibrerebbe": "allibrare",
    "allibrerebber": "allibrare",
    "allibrerebbero": "allibrare",
    "allibrerei": "allibrare",
    "allibreremmo": "allibrare",
    "allibreremo": "allibrare",
    "allibrereste": "allibrare",
    "allibreresti": "allibrare",
    "allibrerete": "allibrare",
    "allibrerà": "allibrare",
    "allibrerò": "allibrare",
    "allibri": "allibrare",
    "allibriamo": "allibrare",
    "allibriate": "allibrare",
    "allibrin": "allibrare",
    "allibrino": "allibrare",
    "allibro": "allibrare",
    "allibrò": "allibrare",
    "allibì": "allibire",
    "allieta": "allietare",
    "allietai": "allietare",
    "allietammo": "allietare",
    "allietan": "allietare",
    "allietando": "allietare",
    "allietano": "allietare",
    "allietante": "allietare",
    "allietanti": "allietare",
    "allietar": "allietare",
    "allietaron": "allietare",
    "allietarono": "allietare",
    "allietasse": "allietare",
    "allietasser": "allietare",
    "allietassero": "allietare",
    "allietassi": "allietare",
    "allietassimo": "allietare",
    "allietaste": "allietare",
    "allietasti": "allietare",
    "allietata": "allietare",
    "allietate": "allietare",
    "allietati": "allietare",
    "allietato": "allietare",
    "allietava": "allietare",
    "allietavamo": "allietare",
    "allietavan": "allietare",
    "allietavano": "allietare",
    "allietavate": "allietare",
    "allietavi": "allietare",
    "allietavo": "allietare",
    "allieterai": "allietare",
    "allieteran": "allietare",
    "allieteranno": "allietare",
    "allieterebbe": "allietare",
    "allieterebber": "allietare",
    "allieterebbero": "allietare",
    "allieterei": "allietare",
    "allieteremmo": "allietare",
    "allieteremo": "allietare",
    "allietereste": "allietare",
    "allieteresti": "allietare",
    "allieterete": "allietare",
    "allieterà": "allietare",
    "allieterò": "allietare",
    "allieti": "allietare",
    "allietiamo": "allietare",
    "allietiate": "allietare",
    "allietin": "allietare",
    "allietino": "allietare",
    "allieto": "allietare",
    "allietò": "allietare",
    "allieve": "allieva",
    "allievi": "allievo",
    "alligatori": "alligatore",
    "alligna": "allignare",
    "allignai": "allignare",
    "allignammo": "allignare",
    "allignan": "allignare",
    "allignando": "allignare",
    "allignano": "allignare",
    "allignante": "allignare",
    "allignanti": "allignare",
    "allignar": "allignare",
    "allignaron": "allignare",
    "allignarono": "allignare",
    "allignasse": "allignare",
    "allignasser": "allignare",
    "allignassero": "allignare",
    "allignassi": "allignare",
    "allignassimo": "allignare",
    "allignaste": "allignare",
    "allignasti": "allignare",
    "allignata": "allignare",
    "allignate": "allignare",
    "allignati": "allignare",
    "allignato": "allignare",
    "allignava": "allignare",
    "allignavamo": "allignare",
    "allignavan": "allignare",
    "allignavano": "allignare",
    "allignavate": "allignare",
    "allignavi": "allignare",
    "allignavo": "allignare",
    "allignerai": "allignare",
    "alligneran": "allignare",
    "alligneranno": "allignare",
    "allignerebbe": "allignare",
    "allignerebber": "allignare",
    "allignerebbero": "allignare",
    "allignerei": "allignare",
    "alligneremmo": "allignare",
    "alligneremo": "allignare",
    "allignereste": "allignare",
    "alligneresti": "allignare",
    "allignerete": "allignare",
    "allignerà": "allignare",
    "allignerò": "allignare",
    "alligni": "allignare",
    "alligniamo": "allignare",
    "alligniate": "allignare",
    "allignin": "allignare",
    "allignino": "allignare",
    "alligno": "allignare",
    "allignò": "allignare",
    "allinea": "allineare",
    "allineabili": "allineabile",
    "allineai": "allineare",
    "allineamenti": "allineamento",
    "allineammo": "allineare",
    "allinean": "allineare",
    "allineando": "allineare",
    "allineano": "allineare",
    "allineante": "allineare",
    "allineanti": "allineare",
    "allinear": "allineare",
    "allinearon": "allineare",
    "allinearono": "allineare",
    "allineasse": "allineare",
    "allineasser": "allineare",
    "allineassero": "allineare",
    "allineassi": "allineare",
    "allineassimo": "allineare",
    "allineaste": "allineare",
    "allineasti": "allineare",
    "allineata": "allineato",
    "allineate": "allineato",
    "allineati": "allineato",
    "allineato": "allineare",
    "allineava": "allineare",
    "allineavamo": "allineare",
    "allineavan": "allineare",
    "allineavano": "allineare",
    "allineavate": "allineare",
    "allineavi": "allineare",
    "allineavo": "allineare",
    "allineerai": "allineare",
    "allineeran": "allineare",
    "allineeranno": "allineare",
    "allineerebbe": "allineare",
    "allineerebber": "allineare",
    "allineerebbero": "allineare",
    "allineerei": "allineare",
    "allineeremmo": "allineare",
    "allineeremo": "allineare",
    "allineereste": "allineare",
    "allineeresti": "allineare",
    "allineerete": "allineare",
    "allineerà": "allineare",
    "allineerò": "allineare",
    "allinei": "allineare",
    "allineiamo": "allineare",
    "allineiate": "allineare",
    "allinein": "allineare",
    "allineino": "allineare",
    "allineo": "allineare",
    "allineò": "allineare",
    "allitterazioni": "allitterazione",
    "allo": "al",
    "alloca": "allocare",
    "allocai": "allocare",
    "allocammo": "allocare",
    "allocan": "allocare",
    "allocando": "allocare",
    "allocano": "allocare",
    "allocante": "allocare",
    "allocanti": "allocare",
    "allocar": "allocare",
    "allocaron": "allocare",
    "allocarono": "allocare",
    "allocasse": "allocare",
    "allocasser": "allocare",
    "allocassero": "allocare",
    "allocassi": "allocare",
    "allocassimo": "allocare",
    "allocaste": "allocare",
    "allocasti": "allocare",
    "allocata": "allocare",
    "allocate": "allocare",
    "allocati": "allocare",
    "allocato": "allocare",
    "allocava": "allocare",
    "allocavamo": "allocare",
    "allocavan": "allocare",
    "allocavano": "allocare",
    "allocavate": "allocare",
    "allocavi": "allocare",
    "allocavo": "allocare",
    "allocazioni": "allocazione",
    "allocchi": "allocco",
    "allocherai": "allocare",
    "allocheran": "allocare",
    "allocheranno": "allocare",
    "allocherebbe": "allocare",
    "allocherebber": "allocare",
    "allocherebbero": "allocare",
    "allocherei": "allocare",
    "allocheremmo": "allocare",
    "allocheremo": "allocare",
    "allochereste": "allocare",
    "allocheresti": "allocare",
    "allocherete": "allocare",
    "allocherà": "allocare",
    "allocherò": "allocare",
    "allochi": "allocare",
    "allochiamo": "allocare",
    "allochiate": "allocare",
    "allochin": "allocare",
    "allochino": "allocare",
    "alloco": "allocare",
    "allocuzioni": "allocuzione",
    "allocò": "allocare",
    "allodole": "allodola",
    "alloga": "allogare",
    "allogai": "allogare",
    "allogammo": "allogare",
    "allogan": "allogare",
    "allogando": "allogare",
    "allogano": "allogare",
    "allogante": "allogare",
    "alloganti": "allogare",
    "allogar": "allogare",
    "allogaron": "allogare",
    "allogarono": "allogare",
    "allogasse": "allogare",
    "allogasser": "allogare",
    "allogassero": "allogare",
    "allogassi": "allogare",
    "allogassimo": "allogare",
    "allogaste": "allogare",
    "allogasti": "allogare",
    "allogata": "allogare",
    "allogate": "allogare",
    "allogati": "allogare",
    "allogato": "allogare",
    "allogava": "allogare",
    "allogavamo": "allogare",
    "allogavan": "allogare",
    "allogavano": "allogare",
    "allogavate": "allogare",
    "allogavi": "allogare",
    "allogavo": "allogare",
    "alloggerai": "alloggiare",
    "alloggeran": "alloggiare",
    "alloggeranno": "alloggiare",
    "alloggerebbe": "alloggiare",
    "alloggerebber": "alloggiare",
    "alloggerebbero": "alloggiare",
    "alloggerei": "alloggiare",
    "alloggeremmo": "alloggiare",
    "alloggeremo": "alloggiare",
    "alloggereste": "alloggiare",
    "alloggeresti": "alloggiare",
    "alloggerete": "alloggiare",
    "alloggerà": "alloggiare",
    "alloggerò": "alloggiare",
    "alloggi": "alloggio",
    "alloggia": "alloggiare",
    "alloggiai": "alloggiare",
    "alloggiamenti": "alloggiamento",
    "alloggiammo": "alloggiare",
    "alloggiamo": "alloggiare",
    "alloggian": "alloggiare",
    "alloggiando": "alloggiare",
    "alloggiano": "alloggiare",
    "alloggiante": "alloggiare",
    "alloggianti": "alloggiare",
    "alloggiar": "alloggiare",
    "alloggiaron": "alloggiare",
    "alloggiarono": "alloggiare",
    "alloggiasse": "alloggiare",
    "alloggiasser": "alloggiare",
    "alloggiassero": "alloggiare",
    "alloggiassi": "alloggiare",
    "alloggiassimo": "alloggiare",
    "alloggiaste": "alloggiare",
    "alloggiasti": "alloggiare",
    "alloggiata": "alloggiare",
    "alloggiate": "alloggiare",
    "alloggiati": "alloggiare",
    "alloggiato": "alloggiare",
    "alloggiava": "alloggiare",
    "alloggiavamo": "alloggiare",
    "alloggiavan": "alloggiare",
    "alloggiavano": "alloggiare",
    "alloggiavate": "alloggiare",
    "alloggiavi": "alloggiare",
    "alloggiavo": "alloggiare",
    "alloggin": "alloggiare",
    "alloggino": "alloggiare",
    "alloggio": "alloggiare",
    "alloggiò": "alloggiare",
    "allogherai": "allogare",
    "allogheran": "allogare",
    "allogheranno": "allogare",
    "allogherebbe": "allogare",
    "allogherebber": "allogare",
    "allogherebbero": "allogare",
    "allogherei": "allogare",
    "allogheremmo": "allogare",
    "allogheremo": "allogare",
    "alloghereste": "allogare",
    "allogheresti": "allogare",
    "allogherete": "allogare",
    "allogherà": "allogare",
    "allogherò": "allogare",
    "alloghi": "allogare",
    "alloghiamo": "allogare",
    "alloghiate": "allogare",
    "alloghin": "allogare",
    "alloghino": "allogare",
    "allogo": "allogare",
    "allogò": "allogare",
    "allontana": "allontanare",
    "allontanai": "allontanare",
    "allontanamenti": "allontanamento",
    "allontanammo": "allontanare",
    "allontanan": "allontanare",
    "allontanando": "allontanare",
    "allontanano": "allontanare",
    "allontanante": "allontanare",
    "allontananti": "allontanare",
    "allontanar": "allontanare",
    "allontanaron": "allontanare",
    "allontanarono": "allontanare",
    "allontanasse": "allontanare",
    "allontanasser": "allontanare",
    "allontanassero": "allontanare",
    "allontanassi": "allontanare",
    "allontanassimo": "allontanare",
    "allontanaste": "allontanare",
    "allontanasti": "allontanare",
    "allontanata": "allontanare",
    "allontanate": "allontanare",
    "allontanati": "allontanare",
    "allontanato": "allontanare",
    "allontanava": "allontanare",
    "allontanavamo": "allontanare",
    "allontanavan": "allontanare",
    "allontanavano": "allontanare",
    "allontanavate": "allontanare",
    "allontanavi": "allontanare",
    "allontanavo": "allontanare",
    "allontanerai": "allontanare",
    "allontaneran": "allontanare",
    "allontaneranno": "allontanare",
    "allontanerebbe": "allontanare",
    "allontanerebber": "allontanare",
    "allontanerebbero": "allontanare",
    "allontanerei": "allontanare",
    "allontaneremmo": "allontanare",
    "allontaneremo": "allontanare",
    "allontanereste": "allontanare",
    "allontaneresti": "allontanare",
    "allontanerete": "allontanare",
    "allontanerà": "allontanare",
    "allontanerò": "allontanare",
    "allontani": "allontanare",
    "allontaniamo": "allontanare",
    "allontaniate": "allontanare",
    "allontanin": "allontanare",
    "allontanino": "allontanare",
    "allontano": "allontanare",
    "allontanò": "allontanare",
    "allori": "alloro",
    "alluci": "alluce",
    "allucina": "allucinare",
    "allucinai": "allucinare",
    "allucinammo": "allucinare",
    "allucinan": "allucinare",
    "allucinando": "allucinare",
    "allucinano": "allucinare",
    "allucinante": "allucinare",
    "allucinanti": "allucinare",
    "allucinar": "allucinare",
    "allucinaron": "allucinare",
    "allucinarono": "allucinare",
    "allucinasse": "allucinare",
    "allucinasser": "allucinare",
    "allucinassero": "allucinare",
    "allucinassi": "allucinare",
    "allucinassimo": "allucinare",
    "allucinaste": "allucinare",
    "allucinasti": "allucinare",
    "allucinata": "allucinato",
    "allucinate": "allucinato",
    "allucinati": "allucinato",
    "allucinato": "allucinare",
    "allucinatori": "allucinatorio",
    "allucinatoria": "allucinatorio",
    "allucinatorie": "allucinatorio",
    "allucinava": "allucinare",
    "allucinavamo": "allucinare",
    "allucinavan": "allucinare",
    "allucinavano": "allucinare",
    "allucinavate": "allucinare",
    "allucinavi": "allucinare",
    "allucinavo": "allucinare",
    "allucinazioni": "allucinazione",
    "allucinerai": "allucinare",
    "allucineran": "allucinare",
    "allucineranno": "allucinare",
    "allucinerebbe": "allucinare",
    "allucinerebber": "allucinare",
    "allucinerebbero": "allucinare",
    "allucinerei": "allucinare",
    "allucineremmo": "allucinare",
    "allucineremo": "allucinare",
    "allucinereste": "allucinare",
    "allucineresti": "allucinare",
    "allucinerete": "allucinare",
    "allucinerà": "allucinare",
    "allucinerò": "allucinare",
    "allucini": "allucinare",
    "alluciniamo": "allucinare",
    "alluciniate": "allucinare",
    "allucinin": "allucinare",
    "allucinino": "allucinare",
    "allucino": "allucinare",
    "allucinogena": "allucinogeno",
    "allucinogene": "allucinogeno",
    "allucinogeni": "allucinogeno",
    "allucinò": "allucinare",
    "alluda": "alludere",
    "alludan": "alludere",
    "alludano": "alludere",
    "allude": "alludere",
    "alludemmo": "alludere",
    "alludendo": "alludere",
    "alludente": "alludere",
    "alludenti": "alludere",
    "alluder": "alludere",
    "alluderai": "alludere",
    "alluderan": "alludere",
    "alluderanno": "alludere",
    "alluderebbe": "alludere",
    "alluderebber": "alludere",
    "alluderebbero": "alludere",
    "alluderei": "alludere",
    "alluderemmo": "alludere",
    "alluderemo": "alludere",
    "alludereste": "alludere",
    "alluderesti": "alludere",
    "alluderete": "alludere",
    "alluderà": "alludere",
    "alluderò": "alludere",
    "alludesse": "alludere",
    "alludesser": "alludere",
    "alludessero": "alludere",
    "alludessi": "alludere",
    "alludessimo": "alludere",
    "alludeste": "alludere",
    "alludesti": "alludere",
    "alludete": "alludere",
    "alludeva": "alludere",
    "alludevamo": "alludere",
    "alludevan": "alludere",
    "alludevano": "alludere",
    "alludevate": "alludere",
    "alludevi": "alludere",
    "alludevo": "alludere",
    "alludi": "alludere",
    "alludiamo": "alludere",
    "alludiate": "alludere",
    "alludo": "alludere",
    "alludon": "alludere",
    "alludono": "alludere",
    "alluma": "allumare",
    "allumai": "allumare",
    "allumammo": "allumare",
    "alluman": "allumare",
    "allumando": "allumare",
    "allumano": "allumare",
    "allumante": "allumare",
    "allumanti": "allumare",
    "allumar": "allumare",
    "allumaron": "allumare",
    "allumarono": "allumare",
    "allumasse": "allumare",
    "allumasser": "allumare",
    "allumassero": "allumare",
    "allumassi": "allumare",
    "allumassimo": "allumare",
    "allumaste": "allumare",
    "allumasti": "allumare",
    "allumata": "allumare",
    "allumate": "allumare",
    "allumati": "allumare",
    "allumato": "allumare",
    "allumava": "allumare",
    "allumavamo": "allumare",
    "allumavan": "allumare",
    "allumavano": "allumare",
    "allumavate": "allumare",
    "allumavi": "allumare",
    "allumavo": "allumare",
    "allumerai": "allumare",
    "allumeran": "allumare",
    "allumeranno": "allumare",
    "allumerebbe": "allumare",
    "allumerebber": "allumare",
    "allumerebbero": "allumare",
    "allumerei": "allumare",
    "allumeremmo": "allumare",
    "allumeremo": "allumare",
    "allumereste": "allumare",
    "allumeresti": "allumare",
    "allumerete": "allumare",
    "allumerà": "allumare",
    "allumerò": "allumare",
    "allumi": "allumare",
    "allumiamo": "allumare",
    "allumiate": "allumare",
    "allumin": "allumare",
    "allumina": "alluminare",
    "alluminai": "alluminare",
    "alluminammo": "alluminare",
    "alluminan": "alluminare",
    "alluminando": "alluminare",
    "alluminano": "alluminare",
    "alluminante": "alluminare",
    "alluminanti": "alluminare",
    "alluminar": "alluminare",
    "alluminaron": "alluminare",
    "alluminarono": "alluminare",
    "alluminasse": "alluminare",
    "alluminasser": "alluminare",
    "alluminassero": "alluminare",
    "alluminassi": "alluminare",
    "alluminassimo": "alluminare",
    "alluminaste": "alluminare",
    "alluminasti": "alluminare",
    "alluminata": "alluminare",
    "alluminate": "alluminare",
    "alluminati": "alluminare",
    "alluminato": "alluminare",
    "alluminava": "alluminare",
    "alluminavamo": "alluminare",
    "alluminavan": "alluminare",
    "alluminavano": "alluminare",
    "alluminavate": "alluminare",
    "alluminavi": "alluminare",
    "alluminavo": "alluminare",
    "alluminerai": "alluminare",
    "allumineran": "alluminare",
    "allumineranno": "alluminare",
    "alluminerebbe": "alluminare",
    "alluminerebber": "alluminare",
    "alluminerebbero": "alluminare",
    "alluminerei": "alluminare",
    "allumineremmo": "alluminare",
    "allumineremo": "alluminare",
    "alluminereste": "alluminare",
    "allumineresti": "alluminare",
    "alluminerete": "alluminare",
    "alluminerà": "alluminare",
    "alluminerò": "alluminare",
    "allumini": "alluminare",
    "alluminiamo": "alluminare",
    "alluminiate": "alluminare",
    "alluminin": "alluminare",
    "alluminino": "alluminare",
    "allumino": "alluminare",
    "alluminò": "alluminare",
    "allumo": "allumare",
    "allumò": "allumare",
    "alluna": "allunare",
    "allunai": "allunare",
    "allunammo": "allunare",
    "allunan": "allunare",
    "allunando": "allunare",
    "allunano": "allunare",
    "allunante": "allunare",
    "allunanti": "allunare",
    "allunar": "allunare",
    "allunaron": "allunare",
    "allunarono": "allunare",
    "allunasse": "allunare",
    "allunasser": "allunare",
    "allunassero": "allunare",
    "allunassi": "allunare",
    "allunassimo": "allunare",
    "allunaste": "allunare",
    "allunasti": "allunare",
    "allunata": "allunare",
    "allunate": "allunare",
    "allunati": "allunare",
    "allunato": "allunare",
    "allunava": "allunare",
    "allunavamo": "allunare",
    "allunavan": "allunare",
    "allunavano": "allunare",
    "allunavate": "allunare",
    "allunavi": "allunare",
    "allunavo": "allunare",
    "allunerai": "allunare",
    "alluneran": "allunare",
    "alluneranno": "allunare",
    "allunerebbe": "allunare",
    "allunerebber": "allunare",
    "allunerebbero": "allunare",
    "allunerei": "allunare",
    "alluneremmo": "allunare",
    "alluneremo": "allunare",
    "allunereste": "allunare",
    "alluneresti": "allunare",
    "allunerete": "allunare",
    "allunerà": "allunare",
    "allunerò": "allunare",
    "allunga": "allungare",
    "allungai": "allungare",
    "allungamenti": "allungamento",
    "allungammo": "allungare",
    "allungan": "allungare",
    "allungando": "allungare",
    "allungano": "allungare",
    "allungante": "allungare",
    "allunganti": "allungare",
    "allungar": "allungare",
    "allungaron": "allungare",
    "allungarono": "allungare",
    "allungasse": "allungare",
    "allungasser": "allungare",
    "allungassero": "allungare",
    "allungassi": "allungare",
    "allungassimo": "allungare",
    "allungaste": "allungare",
    "allungasti": "allungare",
    "allungata": "allungare",
    "allungate": "allungare",
    "allungati": "allungare",
    "allungato": "allungare",
    "allungava": "allungare",
    "allungavamo": "allungare",
    "allungavan": "allungare",
    "allungavano": "allungare",
    "allungavate": "allungare",
    "allungavi": "allungare",
    "allungavo": "allungare",
    "allungherai": "allungare",
    "allungheran": "allungare",
    "allungheranno": "allungare",
    "allungherebbe": "allungare",
    "allungherebber": "allungare",
    "allungherebbero": "allungare",
    "allungherei": "allungare",
    "allungheremmo": "allungare",
    "allungheremo": "allungare",
    "allunghereste": "allungare",
    "allungheresti": "allungare",
    "allungherete": "allungare",
    "allungherà": "allungare",
    "allungherò": "allungare",
    "allunghi": "allungo",
    "allunghiamo": "allungare",
    "allunghiate": "allungare",
    "allunghin": "allungare",
    "allunghino": "allungare",
    "allungo": "allungare",
    "allungò": "allungare",
    "alluni": "allunare",
    "alluniamo": "allunare",
    "alluniate": "allunare",
    "allunin": "allunare",
    "allunino": "allunare",
    "alluno": "allunare",
    "allunò": "allunare",
    "allusa": "alludere",
    "alluse": "alludere",
    "alluser": "alludere",
    "allusero": "alludere",
    "allusi": "alludere",
    "allusioni": "allusione",
    "allusiva": "allusivo",
    "allusive": "allusivo",
    "allusivi": "allusivo",
    "alluso": "alludere",
    "alluvionali": "alluvionale",
    "alluvionata": "alluvionato",
    "alluvionate": "alluvionato",
    "alluvionati": "alluvionato",
    "alluvioni": "alluvione",
    "alma": "almo",
    "almanacca": "almanaccare",
    "almanaccai": "almanaccare",
    "almanaccammo": "almanaccare",
    "almanaccan": "almanaccare",
    "almanaccando": "almanaccare",
    "almanaccano": "almanaccare",
    "almanaccante": "almanaccare",
    "almanaccanti": "almanaccare",
    "almanaccar": "almanaccare",
    "almanaccaron": "almanaccare",
    "almanaccarono": "almanaccare",
    "almanaccasse": "almanaccare",
    "almanaccasser": "almanaccare",
    "almanaccassero": "almanaccare",
    "almanaccassi": "almanaccare",
    "almanaccassimo": "almanaccare",
    "almanaccaste": "almanaccare",
    "almanaccasti": "almanaccare",
    "almanaccata": "almanaccare",
    "almanaccate": "almanaccare",
    "almanaccati": "almanaccare",
    "almanaccato": "almanaccare",
    "almanaccava": "almanaccare",
    "almanaccavamo": "almanaccare",
    "almanaccavan": "almanaccare",
    "almanaccavano": "almanaccare",
    "almanaccavate": "almanaccare",
    "almanaccavi": "almanaccare",
    "almanaccavo": "almanaccare",
    "almanaccherai": "almanaccare",
    "almanaccheran": "almanaccare",
    "almanaccheranno": "almanaccare",
    "almanaccherebbe": "almanaccare",
    "almanaccherebber": "almanaccare",
    "almanaccherebbero": "almanaccare",
    "almanaccherei": "almanaccare",
    "almanaccheremmo": "almanaccare",
    "almanaccheremo": "almanaccare",
    "almanacchereste": "almanaccare",
    "almanaccheresti": "almanaccare",
    "almanaccherete": "almanaccare",
    "almanaccherà": "almanaccare",
    "almanaccherò": "almanaccare",
    "almanacchi": "almanacco",
    "almanacchiamo": "almanaccare",
    "almanacchiate": "almanaccare",
    "almanacchin": "almanaccare",
    "almanacchino": "almanaccare",
    "almanacco": "almanaccare",
    "almanaccò": "almanaccare",
    "alme": "almo",
    "almi": "almo",
    "almirantiana": "almirantiano",
    "almirantiane": "almirantiano",
    "almirantiani": "almirantiano",
    "almodovariana": "almodovariano",
    "almodovariane": "almodovariano",
    "almodovariani": "almodovariano",
    "alo": "alare",
    "alogena": "alogeno",
    "alogene": "alogeno",
    "alogeni": "alogeno",
    "aloni": "alone",
    "alpeggi": "alpeggio",
    "alpestri": "alpestre",
    "alpina": "alpino",
    "alpine": "alpino",
    "alpini": "alpino",
    "alpinisti": "alpinista",
    "alta": "alto",
    "altalena": "altalenare",
    "altalenai": "altalenare",
    "altalenammo": "altalenare",
    "altalenan": "altalenare",
    "altalenando": "altalenare",
    "altalenano": "altalenare",
    "altalenante": "altalenare",
    "altalenanti": "altalenare",
    "altalenar": "altalenare",
    "altalenaron": "altalenare",
    "altalenarono": "altalenare",
    "altalenasse": "altalenare",
    "altalenasser": "altalenare",
    "altalenassero": "altalenare",
    "altalenassi": "altalenare",
    "altalenassimo": "altalenare",
    "altalenaste": "altalenare",
    "altalenasti": "altalenare",
    "altalenata": "altalenare",
    "altalenate": "altalenare",
    "altalenati": "altalenare",
    "altalenato": "altalenare",
    "altalenava": "altalenare",
    "altalenavamo": "altalenare",
    "altalenavan": "altalenare",
    "altalenavano": "altalenare",
    "altalenavate": "altalenare",
    "altalenavi": "altalenare",
    "altalenavo": "altalenare",
    "altalene": "altalena",
    "altalenerai": "altalenare",
    "altaleneran": "altalenare",
    "altaleneranno": "altalenare",
    "altalenerebbe": "altalenare",
    "altalenerebber": "altalenare",
    "altalenerebbero": "altalenare",
    "altalenerei": "altalenare",
    "altaleneremmo": "altalenare",
    "altaleneremo": "altalenare",
    "altalenereste": "altalenare",
    "altaleneresti": "altalenare",
    "altalenerete": "altalenare",
    "altalenerà": "altalenare",
    "altalenerò": "altalenare",
    "altaleni": "altalenare",
    "altaleniamo": "altalenare",
    "altaleniate": "altalenare",
    "altalenin": "altalenare",
    "altalenino": "altalenare",
    "altaleno": "altalenare",
    "altalenò": "altalenare",
    "altane": "altana",
    "altari": "altare",
    "altarini": "altarino",
    "alte": "alto",
    "altera": "alterare",
    "alterai": "alterare",
    "alterammo": "alterare",
    "alteran": "alterare",
    "alterando": "alterare",
    "alterano": "alterare",
    "alterante": "alterare",
    "alteranti": "alterare",
    "alterar": "alterare",
    "alteraron": "alterare",
    "alterarono": "alterare",
    "alterasse": "alterare",
    "alterasser": "alterare",
    "alterassero": "alterare",
    "alterassi": "alterare",
    "alterassimo": "alterare",
    "alteraste": "alterare",
    "alterasti": "alterare",
    "alterata": "alterato",
    "alterate": "alterato",
    "alterati": "alterato",
    "alterato": "alterare",
    "alterava": "alterare",
    "alteravamo": "alterare",
    "alteravan": "alterare",
    "alteravano": "alterare",
    "alteravate": "alterare",
    "alteravi": "alterare",
    "alteravo": "alterare",
    "alterazioni": "alterazione",
    "alterca": "altercare",
    "altercai": "altercare",
    "altercammo": "altercare",
    "altercan": "altercare",
    "altercando": "altercare",
    "altercano": "altercare",
    "altercante": "altercare",
    "altercanti": "altercare",
    "altercar": "altercare",
    "altercaron": "altercare",
    "altercarono": "altercare",
    "altercasse": "altercare",
    "altercasser": "altercare",
    "altercassero": "altercare",
    "altercassi": "altercare",
    "altercassimo": "altercare",
    "altercaste": "altercare",
    "altercasti": "altercare",
    "altercata": "altercare",
    "altercate": "altercare",
    "altercati": "altercare",
    "altercato": "altercare",
    "altercava": "altercare",
    "altercavamo": "altercare",
    "altercavan": "altercare",
    "altercavano": "altercare",
    "altercavate": "altercare",
    "altercavi": "altercare",
    "altercavo": "altercare",
    "altercherai": "altercare",
    "altercheran": "altercare",
    "altercheranno": "altercare",
    "altercherebbe": "altercare",
    "altercherebber": "altercare",
    "altercherebbero": "altercare",
    "altercherei": "altercare",
    "altercheremmo": "altercare",
    "altercheremo": "altercare",
    "alterchereste": "altercare",
    "altercheresti": "altercare",
    "altercherete": "altercare",
    "altercherà": "altercare",
    "altercherò": "altercare",
    "alterchi": "alterco",
    "alterchiamo": "altercare",
    "alterchiate": "altercare",
    "alterchin": "altercare",
    "alterchino": "altercare",
    "alterco": "altercare",
    "altercò": "altercare",
    "altere": "altera",
    "altererai": "alterare",
    "altereran": "alterare",
    "altereranno": "alterare",
    "altererebbe": "alterare",
    "altererebber": "alterare",
    "altererebbero": "alterare",
    "altererei": "alterare",
    "altereremmo": "alterare",
    "altereremo": "alterare",
    "alterereste": "alterare",
    "altereresti": "alterare",
    "altererete": "alterare",
    "altererà": "alterare",
    "altererò": "alterare",
    "alteri": "altero",
    "alteriamo": "alterare",
    "alteriate": "alterare",
    "alterin": "alterare",
    "alterino": "alterare",
    "alterna": "alterno",
    "alternai": "alternare",
    "alternammo": "alternare",
    "alternan": "alternare",
    "alternando": "alternare",
    "alternano": "alternare",
    "alternante": "alternare",
    "alternanti": "alternare",
    "alternanze": "alternanza",
    "alternar": "alternare",
    "alternaron": "alternare",
    "alternarono": "alternare",
    "alternasse": "alternare",
    "alternasser": "alternare",
    "alternassero": "alternare",
    "alternassi": "alternare",
    "alternassimo": "alternare",
    "alternaste": "alternare",
    "alternasti": "alternare",
    "alternata": "alternato",
    "alternate": "alternato",
    "alternati": "alternato",
    "alternativa": "alternativo",
    "alternative": "alternativo",
    "alternativi": "alternativo",
    "alternativistica": "alternativistico",
    "alternativistiche": "alternativistico",
    "alternativistici": "alternativistico",
    "alternato": "alternare",
    "alternava": "alternare",
    "alternavamo": "alternare",
    "alternavan": "alternare",
    "alternavano": "alternare",
    "alternavate": "alternare",
    "alternavi": "alternare",
    "alternavo": "alternare",
    "alterne": "alterno",
    "alternerai": "alternare",
    "alterneran": "alternare",
    "alterneranno": "alternare",
    "alternerebbe": "alternare",
    "alternerebber": "alternare",
    "alternerebbero": "alternare",
    "alternerei": "alternare",
    "alterneremmo": "alternare",
    "alterneremo": "alternare",
    "alternereste": "alternare",
    "alterneresti": "alternare",
    "alternerete": "alternare",
    "alternerà": "alternare",
    "alternerò": "alternare",
    "alterni": "alterno",
    "alterniamo": "alternare",
    "alterniate": "alternare",
    "alternin": "alternare",
    "alternino": "alternare",
    "alterno": "alternare",
    "alternò": "alternare",
    "altero": "alterare",
    "alterò": "alterare",
    "altezze": "altezza",
    "altezzosa": "altezzoso",
    "altezzose": "altezzoso",
    "altezzosi": "altezzoso",
    "alti": "alto",
    "alticce": "alticcio",
    "alticci": "alticcio",
    "alticcia": "alticcio",
    "altiforni": "altoforno",
    "altimetri": "altimetro",
    "altimetrica": "altimetrico",
    "altimetriche": "altimetrico",
    "altimetrici": "altimetrico",
    "altipiani": "altipiano",
    "altisonanti": "altisonante",
    "altitudini": "altitudine",
    "alto-borghesi": "alto-borghese",
    "altoatesina": "altoatesino",
    "altoatesine": "altoatesino",
    "altoatesini": "altoatesino",
    "altoborghesi": "altoborghese",
    "altoforni": "altoforno",
    "altolocata": "altolocato",
    "altolocate": "altolocato",
    "altolocati": "altolocato",
    "altomedievali": "altomedievale",
    "altoparlanti": "altoparlante",
    "altopiani": "altopiano",
    "altorinascimentali": "altorinascimentale",
    "altra": "altro",
    "altre": "altro",
    "altrettanta": "altrettanto",
    "altrettante": "altrettanto",
    "altrettanti": "altrettanto",
    "altri": "altro",
    "altruiste": "altruista",
    "altruisti": "altruista",
    "altruistica": "altruistico",
    "altruistiche": "altruistico",
    "altruistici": "altruistico",
    "alture": "altura",
    "alunne": "alunna",
    "alunni": "alunno",
    "alvea": "alveare",
    "alveai": "alveare",
    "alveammo": "alveare",
    "alvean": "alveare",
    "alveando": "alveare",
    "alveano": "alveare",
    "alveante": "alveare",
    "alveanti": "alveare",
    "alvear": "alveare",
    "alveari": "alveare",
    "alvearon": "alveare",
    "alvearono": "alveare",
    "alveasse": "alveare",
    "alveasser": "alveare",
    "alveassero": "alveare",
    "alveassi": "alveare",
    "alveassimo": "alveare",
    "alveaste": "alveare",
    "alveasti": "alveare",
    "alveata": "alveare",
    "alveate": "alveare",
    "alveati": "alveare",
    "alveato": "alveare",
    "alveava": "alveare",
    "alveavamo": "alveare",
    "alveavan": "alveare",
    "alveavano": "alveare",
    "alveavate": "alveare",
    "alveavi": "alveare",
    "alveavo": "alveare",
    "alveerai": "alveare",
    "alveeran": "alveare",
    "alveeranno": "alveare",
    "alveerebbe": "alveare",
    "alveerebber": "alveare",
    "alveerebbero": "alveare",
    "alveerei": "alveare",
    "alveeremmo": "alveare",
    "alveeremo": "alveare",
    "alveereste": "alveare",
    "alveeresti": "alveare",
    "alveerete": "alveare",
    "alveerà": "alveare",
    "alveerò": "alveare",
    "alvei": "alveo",
    "alveiamo": "alveare",
    "alveiate": "alveare",
    "alvein": "alveare",
    "alveino": "alveare",
    "alveo": "alveare",
    "alveò": "alveare",
    "alza": "alzare",
    "alzai": "alzare",
    "alzammo": "alzare",
    "alzan": "alzare",
    "alzando": "alzare",
    "alzano": "alzare",
    "alzante": "alzare",
    "alzanti": "alzare",
    "alzar": "alzare",
    "alzaron": "alzare",
    "alzarono": "alzare",
    "alzasse": "alzare",
    "alzasser": "alzare",
    "alzassero": "alzare",
    "alzassi": "alzare",
    "alzassimo": "alzare",
    "alzaste": "alzare",
    "alzasti": "alzare",
    "alzata": "alzato",
    "alzatacce": "alzataccia",
    "alzate": "alzato",
    "alzati": "alzato",
    "alzato": "alzare",
    "alzatori": "alzatore",
    "alzava": "alzare",
    "alzavamo": "alzare",
    "alzavan": "alzare",
    "alzavano": "alzare",
    "alzavate": "alzare",
    "alzavi": "alzare",
    "alzavo": "alzare",
    "alzerai": "alzare",
    "alzeran": "alzare",
    "alzeranno": "alzare",
    "alzerebbe": "alzare",
    "alzerebber": "alzare",
    "alzerebbero": "alzare",
    "alzerei": "alzare",
    "alzeremmo": "alzare",
    "alzeremo": "alzare",
    "alzereste": "alzare",
    "alzeresti": "alzare",
    "alzerete": "alzare",
    "alzerà": "alzare",
    "alzerò": "alzare",
    "alzi": "alzare",
    "alziamo": "alzare",
    "alziate": "alzare",
    "alzin": "alzare",
    "alzino": "alzare",
    "alzo": "alzare",
    "alzò": "alzare",
    "alò": "alare",
    "ama": "amare",
    "amabili": "amabile",
    "amache": "amaca",
    "amai": "amare",
    "amalgama": "amalgamare",
    "amalgamabili": "amalgamabile",
    "amalgamai": "amalgamare",
    "amalgamammo": "amalgamare",
    "amalgaman": "amalgamare",
    "amalgamando": "amalgamare",
    "amalgamano": "amalgamare",
    "amalgamante": "amalgamare",
    "amalgamanti": "amalgamare",
    "amalgamar": "amalgamare",
    "amalgamaron": "amalgamare",
    "amalgamarono": "amalgamare",
    "amalgamasse": "amalgamare",
    "amalgamasser": "amalgamare",
    "amalgamassero": "amalgamare",
    "amalgamassi": "amalgamare",
    "amalgamassimo": "amalgamare",
    "amalgamaste": "amalgamare",
    "amalgamasti": "amalgamare",
    "amalgamata": "amalgamare",
    "amalgamate": "amalgamare",
    "amalgamati": "amalgamare",
    "amalgamato": "amalgamare",
    "amalgamava": "amalgamare",
    "amalgamavamo": "amalgamare",
    "amalgamavan": "amalgamare",
    "amalgamavano": "amalgamare",
    "amalgamavate": "amalgamare",
    "amalgamavi": "amalgamare",
    "amalgamavo": "amalgamare",
    "amalgamerai": "amalgamare",
    "amalgameran": "amalgamare",
    "amalgameranno": "amalgamare",
    "amalgamerebbe": "amalgamare",
    "amalgamerebber": "amalgamare",
    "amalgamerebbero": "amalgamare",
    "amalgamerei": "amalgamare",
    "amalgameremmo": "amalgamare",
    "amalgameremo": "amalgamare",
    "amalgamereste": "amalgamare",
    "amalgameresti": "amalgamare",
    "amalgamerete": "amalgamare",
    "amalgamerà": "amalgamare",
    "amalgamerò": "amalgamare",
    "amalgami": "amalgamare",
    "amalgamiamo": "amalgamare",
    "amalgamiate": "amalgamare",
    "amalgamin": "amalgamare",
    "amalgamino": "amalgamare",
    "amalgamo": "amalgamare",
    "amalgamò": "amalgamare",
    "amammo": "amare",
    "aman": "amare",
    "amando": "amare",
    "amano": "amare",
    "amante": "amare",
    "amanti": "amare",
    "amanuensi": "amanuense",
    "amar": "amare",
    "amara": "amaro",
    "amarcordiana": "amarcordiano",
    "amarcordiane": "amarcordiano",
    "amarcordiani": "amarcordiano",
    "amare": "amaro",
    "amareggerai": "amareggiare",
    "amareggeran": "amareggiare",
    "amareggeranno": "amareggiare",
    "amareggerebbe": "amareggiare",
    "amareggerebber": "amareggiare",
    "amareggerebbero": "amareggiare",
    "amareggerei": "amareggiare",
    "amareggeremmo": "amareggiare",
    "amareggeremo": "amareggiare",
    "amareggereste": "amareggiare",
    "amareggeresti": "amareggiare",
    "amareggerete": "amareggiare",
    "amareggerà": "amareggiare",
    "amareggerò": "amareggiare",
    "amareggi": "amareggiare",
    "amareggia": "amareggiare",
    "amareggiai": "amareggiare",
    "amareggiammo": "amareggiare",
    "amareggiamo": "amareggiare",
    "amareggian": "amareggiare",
    "amareggiando": "amareggiare",
    "amareggiano": "amareggiare",
    "amareggiante": "amareggiare",
    "amareggianti": "amareggiare",
    "amareggiar": "amareggiare",
    "amareggiaron": "amareggiare",
    "amareggiarono": "amareggiare",
    "amareggiasse": "amareggiare",
    "amareggiasser": "amareggiare",
    "amareggiassero": "amareggiare",
    "amareggiassi": "amareggiare",
    "amareggiassimo": "amareggiare",
    "amareggiaste": "amareggiare",
    "amareggiasti": "amareggiare",
    "amareggiata": "amareggiato",
    "amareggiate": "amareggiato",
    "amareggiati": "amareggiato",
    "amareggiato": "amareggiare",
    "amareggiava": "amareggiare",
    "amareggiavamo": "amareggiare",
    "amareggiavan": "amareggiare",
    "amareggiavano": "amareggiare",
    "amareggiavate": "amareggiare",
    "amareggiavi": "amareggiare",
    "amareggiavo": "amareggiare",
    "amareggin": "amareggiare",
    "amareggino": "amareggiare",
    "amareggio": "amareggiare",
    "amareggiò": "amareggiare",
    "amarezze": "amarezza",
    "amari": "amaro",
    "amaron": "amare",
    "amarono": "amare",
    "amasse": "amare",
    "amasser": "amare",
    "amassero": "amare",
    "amassi": "amare",
    "amassimo": "amare",
    "amaste": "amare",
    "amasti": "amare",
    "amata": "amato",
    "amate": "amato",
    "amati": "amato",
    "amato": "amare",
    "amatori": "amatorio",
    "amatoria": "amatorio",
    "amatorie": "amatorio",
    "amava": "amare",
    "amavamo": "amare",
    "amavan": "amare",
    "amavano": "amare",
    "amavate": "amare",
    "amavi": "amare",
    "amavo": "amare",
    "amazzoni": "amazzone",
    "amazzonica": "amazzonico",
    "amazzoniche": "amazzonico",
    "amazzonici": "amazzonico",
    "amba": "ambo",
    "ambascerie": "ambasceria",
    "ambasciate": "ambasciata",
    "ambasciatori": "ambasciatore",
    "ambasciatrici": "ambasciatrice",
    "ambe": "ambo",
    "ambedui": "ambedue",
    "ambendo": "ambire",
    "ambente": "ambire",
    "ambenti": "ambire",
    "ambi": "ambo",
    "ambia": "ambiare",
    "ambiai": "ambiare",
    "ambiammo": "ambiare",
    "ambiamo": "ambire",
    "ambian": "ambiare",
    "ambiando": "ambiare",
    "ambiano": "ambiare",
    "ambiante": "ambiare",
    "ambianti": "ambiare",
    "ambiar": "ambiare",
    "ambiaron": "ambiare",
    "ambiarono": "ambiare",
    "ambiasse": "ambiare",
    "ambiasser": "ambiare",
    "ambiassero": "ambiare",
    "ambiassi": "ambiare",
    "ambiassimo": "ambiare",
    "ambiaste": "ambiare",
    "ambiasti": "ambiare",
    "ambiata": "ambiare",
    "ambiate": "ambire",
    "ambiati": "ambiare",
    "ambiato": "ambiare",
    "ambiava": "ambiare",
    "ambiavamo": "ambiare",
    "ambiavan": "ambiare",
    "ambiavano": "ambiare",
    "ambiavate": "ambiare",
    "ambiavi": "ambiare",
    "ambiavo": "ambiare",
    "ambienta": "ambientare",
    "ambientai": "ambientare",
    "ambientali": "ambientale",
    "ambientaliste": "ambientalista",
    "ambientalisti": "ambientalista",
    "ambientalistica": "ambientalistico",
    "ambientalistiche": "ambientalistico",
    "ambientalistici": "ambientalistico",
    "ambientammo": "ambientare",
    "ambientan": "ambientare",
    "ambientando": "ambientare",
    "ambientano": "ambientare",
    "ambientante": "ambientare",
    "ambientanti": "ambientare",
    "ambientar": "ambientare",
    "ambientaron": "ambientare",
    "ambientarono": "ambientare",
    "ambientasse": "ambientare",
    "ambientasser": "ambientare",
    "ambientassero": "ambientare",
    "ambientassi": "ambientare",
    "ambientassimo": "ambientare",
    "ambientaste": "ambientare",
    "ambientasti": "ambientare",
    "ambientata": "ambientare",
    "ambientate": "ambientare",
    "ambientati": "ambientare",
    "ambientato": "ambientare",
    "ambientava": "ambientare",
    "ambientavamo": "ambientare",
    "ambientavan": "ambientare",
    "ambientavano": "ambientare",
    "ambientavate": "ambientare",
    "ambientavi": "ambientare",
    "ambientavo": "ambientare",
    "ambientazioni": "ambientazione",
    "ambienterai": "ambientare",
    "ambienteran": "ambientare",
    "ambienteranno": "ambientare",
    "ambienterebbe": "ambientare",
    "ambienterebber": "ambientare",
    "ambienterebbero": "ambientare",
    "ambienterei": "ambientare",
    "ambienteremmo": "ambientare",
    "ambienteremo": "ambientare",
    "ambientereste": "ambientare",
    "ambienteresti": "ambientare",
    "ambienterete": "ambientare",
    "ambienterà": "ambientare",
    "ambienterò": "ambientare",
    "ambienti": "ambiente",
    "ambientiamo": "ambientare",
    "ambientiate": "ambientare",
    "ambientin": "ambientare",
    "ambientino": "ambientare",
    "ambiento": "ambientare",
    "ambientò": "ambientare",
    "ambierai": "ambiare",
    "ambieran": "ambiare",
    "ambieranno": "ambiare",
    "ambierebbe": "ambiare",
    "ambierebber": "ambiare",
    "ambierebbero": "ambiare",
    "ambierei": "ambiare",
    "ambieremmo": "ambiare",
    "ambieremo": "ambiare",
    "ambiereste": "ambiare",
    "ambieresti": "ambiare",
    "ambierete": "ambiare",
    "ambierà": "ambiare",
    "ambierò": "ambiare",
    "ambigua": "ambiguo",
    "ambigue": "ambiguo",
    "ambigui": "ambiguo",
    "ambii": "ambire",
    "ambimmo": "ambire",
    "ambin": "ambiare",
    "ambino": "ambiare",
    "ambio": "ambiare",
    "ambir": "ambire",
    "ambirai": "ambire",
    "ambiran": "ambire",
    "ambiranno": "ambire",
    "ambirebbe": "ambire",
    "ambirebber": "ambire",
    "ambirebbero": "ambire",
    "ambirei": "ambire",
    "ambiremmo": "ambire",
    "ambiremo": "ambire",
    "ambireste": "ambire",
    "ambiresti": "ambire",
    "ambirete": "ambire",
    "ambiron": "ambire",
    "ambirono": "ambire",
    "ambirà": "ambire",
    "ambirò": "ambire",
    "ambisca": "ambire",
    "ambiscan": "ambire",
    "ambiscano": "ambire",
    "ambisce": "ambire",
    "ambisci": "ambire",
    "ambisco": "ambire",
    "ambiscon": "ambire",
    "ambiscono": "ambire",
    "ambisse": "ambire",
    "ambisser": "ambire",
    "ambissero": "ambire",
    "ambissi": "ambire",
    "ambissimo": "ambire",
    "ambiste": "ambire",
    "ambisti": "ambire",
    "ambita": "ambito",
    "ambite": "ambito",
    "ambiti": "ambito",
    "ambito": "ambire",
    "ambiva": "ambire",
    "ambivalenti": "ambivalente",
    "ambivalenze": "ambivalenza",
    "ambivamo": "ambire",
    "ambivan": "ambire",
    "ambivano": "ambire",
    "ambivate": "ambire",
    "ambivi": "ambire",
    "ambivo": "ambire",
    "ambizioni": "ambizione",
    "ambiziosa": "ambizioso",
    "ambiziose": "ambizioso",
    "ambiziosi": "ambizioso",
    "ambiò": "ambiare",
    "ambrata": "ambrato",
    "ambrate": "ambrato",
    "ambrati": "ambrato",
    "ambrosiana": "ambrosiano",
    "ambrosiane": "ambrosiano",
    "ambrosiani": "ambrosiano",
    "ambulanti": "ambulante",
    "ambulanze": "ambulanza",
    "ambulatori": "ambulatorio",
    "ambulatoriali": "ambulatoriale",
    "ambì": "ambire",
    "amena": "ameno",
    "amendoliana": "amendoliano",
    "amendoliane": "amendoliano",
    "amendoliani": "amendoliano",
    "amene": "ameno",
    "ameni": "ameno",
    "amerai": "amare",
    "ameran": "amare",
    "ameranno": "amare",
    "amerebbe": "amare",
    "amerebber": "amare",
    "amerebbero": "amare",
    "amerei": "amare",
    "ameremmo": "amare",
    "ameremo": "amare",
    "amereste": "amare",
    "ameresti": "amare",
    "amerete": "amare",
    "americana": "americano",
    "americanate": "americanata",
    "americane": "americano",
    "americaneggerai": "americaneggiare",
    "americaneggeran": "americaneggiare",
    "americaneggeranno": "americaneggiare",
    "americaneggerebbe": "americaneggiare",
    "americaneggerebber": "americaneggiare",
    "americaneggerebbero": "americaneggiare",
    "americaneggerei": "americaneggiare",
    "americaneggeremmo": "americaneggiare",
    "americaneggeremo": "americaneggiare",
    "americaneggereste": "americaneggiare",
    "americaneggeresti": "americaneggiare",
    "americaneggerete": "americaneggiare",
    "americaneggerà": "americaneggiare",
    "americaneggerò": "americaneggiare",
    "americaneggi": "americaneggiare",
    "americaneggia": "americaneggiare",
    "americaneggiai": "americaneggiare",
    "americaneggiammo": "americaneggiare",
    "americaneggiamo": "americaneggiare",
    "americaneggian": "americaneggiare",
    "americaneggiando": "americaneggiare",
    "americaneggiano": "americaneggiare",
    "americaneggiante": "americaneggiare",
    "americaneggianti": "americaneggiare",
    "americaneggiar": "americaneggiare",
    "americaneggiaron": "americaneggiare",
    "americaneggiarono": "americaneggiare",
    "americaneggiasse": "americaneggiare",
    "americaneggiasser": "americaneggiare",
    "americaneggiassero": "americaneggiare",
    "americaneggiassi": "americaneggiare",
    "americaneggiassimo": "americaneggiare",
    "americaneggiaste": "americaneggiare",
    "americaneggiasti": "americaneggiare",
    "americaneggiata": "americaneggiare",
    "americaneggiate": "americaneggiare",
    "americaneggiati": "americaneggiare",
    "americaneggiato": "americaneggiare",
    "americaneggiava": "americaneggiare",
    "americaneggiavamo": "americaneggiare",
    "americaneggiavan": "americaneggiare",
    "americaneggiavano": "americaneggiare",
    "americaneggiavate": "americaneggiare",
    "americaneggiavi": "americaneggiare",
    "americaneggiavo": "americaneggiare",
    "americaneggin": "americaneggiare",
    "americaneggino": "americaneggiare",
    "americaneggio": "americaneggiare",
    "americaneggiò": "americaneggiare",
    "americani": "americano",
    "americanizza": "americanizzare",
    "americanizzai": "americanizzare",
    "americanizzammo": "americanizzare",
    "americanizzan": "americanizzare",
    "americanizzando": "americanizzare",
    "americanizzano": "americanizzare",
    "americanizzante": "americanizzare",
    "americanizzanti": "americanizzare",
    "americanizzar": "americanizzare",
    "americanizzaron": "americanizzare",
    "americanizzarono": "americanizzare",
    "americanizzasse": "americanizzare",
    "americanizzasser": "americanizzare",
    "americanizzassero": "americanizzare",
    "americanizzassi": "americanizzare",
    "americanizzassimo": "americanizzare",
    "americanizzaste": "americanizzare",
    "americanizzasti": "americanizzare",
    "americanizzata": "americanizzare",
    "americanizzate": "americanizzare",
    "americanizzati": "americanizzare",
    "americanizzato": "americanizzare",
    "americanizzava": "americanizzare",
    "americanizzavamo": "americanizzare",
    "americanizzavan": "americanizzare",
    "americanizzavano": "americanizzare",
    "americanizzavate": "americanizzare",
    "americanizzavi": "americanizzare",
    "americanizzavo": "americanizzare",
    "americanizzerai": "americanizzare",
    "americanizzeran": "americanizzare",
    "americanizzeranno": "americanizzare",
    "americanizzerebbe": "americanizzare",
    "americanizzerebber": "americanizzare",
    "americanizzerebbero": "americanizzare",
    "americanizzerei": "americanizzare",
    "americanizzeremmo": "americanizzare",
    "americanizzeremo": "americanizzare",
    "americanizzereste": "americanizzare",
    "americanizzeresti": "americanizzare",
    "americanizzerete": "americanizzare",
    "americanizzerà": "americanizzare",
    "americanizzerò": "americanizzare",
    "americanizzi": "americanizzare",
    "americanizziamo": "americanizzare",
    "americanizziate": "americanizzare",
    "americanizzin": "americanizzare",
    "americanizzino": "americanizzare",
    "americanizzo": "americanizzare",
    "americanizzò": "americanizzare",
    "americano-sioniste": "americano-sionista",
    "americano-sionisti": "americano-sionista",
    "americano-sovietica": "americano-sovietico",
    "americano-sovietiche": "americano-sovietico",
    "americano-sovietici": "americano-sovietico",
    "americanofila": "americanofilo",
    "americanofile": "americanofilo",
    "americanofili": "americanofilo",
    "americanoidi": "americanoide",
    "amerà": "amare",
    "amerò": "amare",
    "ami": "amare",
    "amiamo": "amare",
    "amiate": "amare",
    "amica": "amico",
    "amicai": "amicare",
    "amicammo": "amicare",
    "amican": "amicare",
    "amicando": "amicare",
    "amicano": "amicare",
    "amicante": "amicare",
    "amicanti": "amicare",
    "amicar": "amicare",
    "amicaron": "amicare",
    "amicarono": "amicare",
    "amicasse": "amicare",
    "amicasser": "amicare",
    "amicassero": "amicare",
    "amicassi": "amicare",
    "amicassimo": "amicare",
    "amicaste": "amicare",
    "amicasti": "amicare",
    "amicata": "amicare",
    "amicate": "amicare",
    "amicati": "amicare",
    "amicato": "amicare",
    "amicava": "amicare",
    "amicavamo": "amicare",
    "amicavan": "amicare",
    "amicavano": "amicare",
    "amicavate": "amicare",
    "amicavi": "amicare",
    "amicavo": "amicare",
    "amiche": "amico",
    "amicherai": "amicare",
    "amicheran": "amicare",
    "amicheranno": "amicare",
    "amicherebbe": "amicare",
    "amicherebber": "amicare",
    "amicherebbero": "amicare",
    "amicherei": "amicare",
    "amicheremmo": "amicare",
    "amicheremo": "amicare",
    "amichereste": "amicare",
    "amicheresti": "amicare",
    "amicherete": "amicare",
    "amicherà": "amicare",
    "amicherò": "amicare",
    "amichette": "amichetta",
    "amichetti": "amichetto",
    "amichevoli": "amichevole",
    "amichi": "amicare",
    "amichiamo": "amicare",
    "amichiate": "amicare",
    "amichin": "amicare",
    "amichino": "amicare",
    "amici": "amico",
    "amicizie": "amicizia",
    "amico": "amicare",
    "amiconi": "amicone",
    "amicò": "amicare",
    "amin": "amare",
    "amino": "amare",
    "aminoacidi": "aminoacido",
    "amletica": "amletico",
    "amletiche": "amletico",
    "amletici": "amletico",
    "ammacca": "ammaccare",
    "ammaccai": "ammaccare",
    "ammaccammo": "ammaccare",
    "ammaccan": "ammaccare",
    "ammaccando": "ammaccare",
    "ammaccano": "ammaccare",
    "ammaccante": "ammaccare",
    "ammaccanti": "ammaccare",
    "ammaccar": "ammaccare",
    "ammaccaron": "ammaccare",
    "ammaccarono": "ammaccare",
    "ammaccasse": "ammaccare",
    "ammaccasser": "ammaccare",
    "ammaccassero": "ammaccare",
    "ammaccassi": "ammaccare",
    "ammaccassimo": "ammaccare",
    "ammaccaste": "ammaccare",
    "ammaccasti": "ammaccare",
    "ammaccata": "ammaccare",
    "ammaccate": "ammaccare",
    "ammaccati": "ammaccare",
    "ammaccato": "ammaccare",
    "ammaccature": "ammaccatura",
    "ammaccava": "ammaccare",
    "ammaccavamo": "ammaccare",
    "ammaccavan": "ammaccare",
    "ammaccavano": "ammaccare",
    "ammaccavate": "ammaccare",
    "ammaccavi": "ammaccare",
    "ammaccavo": "ammaccare",
    "ammaccherai": "ammaccare",
    "ammaccheran": "ammaccare",
    "ammaccheranno": "ammaccare",
    "ammaccherebbe": "ammaccare",
    "ammaccherebber": "ammaccare",
    "ammaccherebbero": "ammaccare",
    "ammaccherei": "ammaccare",
    "ammaccheremmo": "ammaccare",
    "ammaccheremo": "ammaccare",
    "ammacchereste": "ammaccare",
    "ammaccheresti": "ammaccare",
    "ammaccherete": "ammaccare",
    "ammaccherà": "ammaccare",
    "ammaccherò": "ammaccare",
    "ammacchi": "ammaccare",
    "ammacchiamo": "ammaccare",
    "ammacchiate": "ammaccare",
    "ammacchin": "ammaccare",
    "ammacchino": "ammaccare",
    "ammacco": "ammaccare",
    "ammaccò": "ammaccare",
    "ammaestra": "ammaestrare",
    "ammaestrai": "ammaestrare",
    "ammaestramenti": "ammaestramento",
    "ammaestrammo": "ammaestrare",
    "ammaestran": "ammaestrare",
    "ammaestrando": "ammaestrare",
    "ammaestrano": "ammaestrare",
    "ammaestrante": "ammaestrare",
    "ammaestranti": "ammaestrare",
    "ammaestrar": "ammaestrare",
    "ammaestraron": "ammaestrare",
    "ammaestrarono": "ammaestrare",
    "ammaestrasse": "ammaestrare",
    "ammaestrasser": "ammaestrare",
    "ammaestrassero": "ammaestrare",
    "ammaestrassi": "ammaestrare",
    "ammaestrassimo": "ammaestrare",
    "ammaestraste": "ammaestrare",
    "ammaestrasti": "ammaestrare",
    "ammaestrata": "ammaestrare",
    "ammaestrate": "ammaestrare",
    "ammaestrati": "ammaestrare",
    "ammaestrato": "ammaestrare",
    "ammaestrava": "ammaestrare",
    "ammaestravamo": "ammaestrare",
    "ammaestravan": "ammaestrare",
    "ammaestravano": "ammaestrare",
    "ammaestravate": "ammaestrare",
    "ammaestravi": "ammaestrare",
    "ammaestravo": "ammaestrare",
    "ammaestrerai": "ammaestrare",
    "ammaestreran": "ammaestrare",
    "ammaestreranno": "ammaestrare",
    "ammaestrerebbe": "ammaestrare",
    "ammaestrerebber": "ammaestrare",
    "ammaestrerebbero": "ammaestrare",
    "ammaestrerei": "ammaestrare",
    "ammaestreremmo": "ammaestrare",
    "ammaestreremo": "ammaestrare",
    "ammaestrereste": "ammaestrare",
    "ammaestreresti": "ammaestrare",
    "ammaestrerete": "ammaestrare",
    "ammaestrerà": "ammaestrare",
    "ammaestrerò": "ammaestrare",
    "ammaestri": "ammaestrare",
    "ammaestriamo": "ammaestrare",
    "ammaestriate": "ammaestrare",
    "ammaestrin": "ammaestrare",
    "ammaestrino": "ammaestrare",
    "ammaestro": "ammaestrare",
    "ammaestrò": "ammaestrare",
    "ammagli": "ammagliare",
    "ammaglia": "ammagliare",
    "ammagliai": "ammagliare",
    "ammagliammo": "ammagliare",
    "ammagliamo": "ammagliare",
    "ammaglian": "ammagliare",
    "ammagliando": "ammagliare",
    "ammagliano": "ammagliare",
    "ammagliante": "ammagliare",
    "ammaglianti": "ammagliare",
    "ammagliar": "ammagliare",
    "ammagliaron": "ammagliare",
    "ammagliarono": "ammagliare",
    "ammagliasse": "ammagliare",
    "ammagliasser": "ammagliare",
    "ammagliassero": "ammagliare",
    "ammagliassi": "ammagliare",
    "ammagliassimo": "ammagliare",
    "ammagliaste": "ammagliare",
    "ammagliasti": "ammagliare",
    "ammagliata": "ammagliare",
    "ammagliate": "ammagliare",
    "ammagliati": "ammagliare",
    "ammagliato": "ammagliare",
    "ammagliava": "ammagliare",
    "ammagliavamo": "ammagliare",
    "ammagliavan": "ammagliare",
    "ammagliavano": "ammagliare",
    "ammagliavate": "ammagliare",
    "ammagliavi": "ammagliare",
    "ammagliavo": "ammagliare",
    "ammaglierai": "ammagliare",
    "ammaglieran": "ammagliare",
    "ammaglieranno": "ammagliare",
    "ammaglierebbe": "ammagliare",
    "ammaglierebber": "ammagliare",
    "ammaglierebbero": "ammagliare",
    "ammaglierei": "ammagliare",
    "ammaglieremmo": "ammagliare",
    "ammaglieremo": "ammagliare",
    "ammagliereste": "ammagliare",
    "ammaglieresti": "ammagliare",
    "ammaglierete": "ammagliare",
    "ammaglierà": "ammagliare",
    "ammaglierò": "ammagliare",
    "ammaglin": "ammagliare",
    "ammaglino": "ammagliare",
    "ammaglio": "ammagliare",
    "ammagliò": "ammagliare",
    "ammaina": "ammainare",
    "ammainai": "ammainare",
    "ammainammo": "ammainare",
    "ammainan": "ammainare",
    "ammainando": "ammainare",
    "ammainano": "ammainare",
    "ammainante": "ammainare",
    "ammainanti": "ammainare",
    "ammainar": "ammainare",
    "ammainaron": "ammainare",
    "ammainarono": "ammainare",
    "ammainasse": "ammainare",
    "ammainasser": "ammainare",
    "ammainassero": "ammainare",
    "ammainassi": "ammainare",
    "ammainassimo": "ammainare",
    "ammainaste": "ammainare",
    "ammainasti": "ammainare",
    "ammainata": "ammainare",
    "ammainate": "ammainare",
    "ammainati": "ammainare",
    "ammainato": "ammainare",
    "ammainava": "ammainare",
    "ammainavamo": "ammainare",
    "ammainavan": "ammainare",
    "ammainavano": "ammainare",
    "ammainavate": "ammainare",
    "ammainavi": "ammainare",
    "ammainavo": "ammainare",
    "ammainerai": "ammainare",
    "ammaineran": "ammainare",
    "ammaineranno": "ammainare",
    "ammainerebbe": "ammainare",
    "ammainerebber": "ammainare",
    "ammainerebbero": "ammainare",
    "ammainerei": "ammainare",
    "ammaineremmo": "ammainare",
    "ammaineremo": "ammainare",
    "ammainereste": "ammainare",
    "ammaineresti": "ammainare",
    "ammainerete": "ammainare",
    "ammainerà": "ammainare",
    "ammainerò": "ammainare",
    "ammaini": "ammainare",
    "ammainiamo": "ammainare",
    "ammainiate": "ammainare",
    "ammainin": "ammainare",
    "ammainino": "ammainare",
    "ammaino": "ammainare",
    "ammainò": "ammainare",
    "ammala": "ammalare",
    "ammalai": "ammalare",
    "ammalammo": "ammalare",
    "ammalan": "ammalare",
    "ammalando": "ammalare",
    "ammalano": "ammalare",
    "ammalante": "ammalare",
    "ammalanti": "ammalare",
    "ammalar": "ammalare",
    "ammalaron": "ammalare",
    "ammalarono": "ammalare",
    "ammalasse": "ammalare",
    "ammalasser": "ammalare",
    "ammalassero": "ammalare",
    "ammalassi": "ammalare",
    "ammalassimo": "ammalare",
    "ammalaste": "ammalare",
    "ammalasti": "ammalare",
    "ammalata": "ammalato",
    "ammalate": "ammalato",
    "ammalati": "ammalato",
    "ammalato": "ammalare",
    "ammalava": "ammalare",
    "ammalavamo": "ammalare",
    "ammalavan": "ammalare",
    "ammalavano": "ammalare",
    "ammalavate": "ammalare",
    "ammalavi": "ammalare",
    "ammalavo": "ammalare",
    "ammalerai": "ammalare",
    "ammaleran": "ammalare",
    "ammaleranno": "ammalare",
    "ammalerebbe": "ammalare",
    "ammalerebber": "ammalare",
    "ammalerebbero": "ammalare",
    "ammalerei": "ammalare",
    "ammaleremmo": "ammalare",
    "ammaleremo": "ammalare",
    "ammalereste": "ammalare",
    "ammaleresti": "ammalare",
    "ammalerete": "ammalare",
    "ammalerà": "ammalare",
    "ammalerò": "ammalare",
    "ammali": "ammaliare",
    "ammalia": "ammaliare",
    "ammaliai": "ammaliare",
    "ammaliammo": "ammaliare",
    "ammaliamo": "ammaliare",
    "ammalian": "ammaliare",
    "ammaliando": "ammaliare",
    "ammaliano": "ammaliare",
    "ammaliante": "ammaliare",
    "ammalianti": "ammaliare",
    "ammaliar": "ammaliare",
    "ammaliaron": "ammaliare",
    "ammaliarono": "ammaliare",
    "ammaliasse": "ammaliare",
    "ammaliasser": "ammaliare",
    "ammaliassero": "ammaliare",
    "ammaliassi": "ammaliare",
    "ammaliassimo": "ammaliare",
    "ammaliaste": "ammaliare",
    "ammaliasti": "ammaliare",
    "ammaliata": "ammaliare",
    "ammaliate": "ammaliare",
    "ammaliati": "ammaliare",
    "ammaliato": "ammaliare",
    "ammaliava": "ammaliare",
    "ammaliavamo": "ammaliare",
    "ammaliavan": "ammaliare",
    "ammaliavano": "ammaliare",
    "ammaliavate": "ammaliare",
    "ammaliavi": "ammaliare",
    "ammaliavo": "ammaliare",
    "ammalierai": "ammaliare",
    "ammalieran": "ammaliare",
    "ammalieranno": "ammaliare",
    "ammalierebbe": "ammaliare",
    "ammalierebber": "ammaliare",
    "ammalierebbero": "ammaliare",
    "ammalierei": "ammaliare",
    "ammalieremmo": "ammaliare",
    "ammalieremo": "ammaliare",
    "ammaliereste": "ammaliare",
    "ammalieresti": "ammaliare",
    "ammalierete": "ammaliare",
    "ammalierà": "ammaliare",
    "ammalierò": "ammaliare",
    "ammalin": "ammaliare",
    "ammalino": "ammaliare",
    "ammalio": "ammaliare",
    "ammaliò": "ammaliare",
    "ammalo": "ammalare",
    "ammalò": "ammalare",
    "ammanchi": "ammanco",
    "ammanetta": "ammanettare",
    "ammanettai": "ammanettare",
    "ammanettammo": "ammanettare",
    "ammanettan": "ammanettare",
    "ammanettando": "ammanettare",
    "ammanettano": "ammanettare",
    "ammanettante": "ammanettare",
    "ammanettanti": "ammanettare",
    "ammanettar": "ammanettare",
    "ammanettaron": "ammanettare",
    "ammanettarono": "ammanettare",
    "ammanettasse": "ammanettare",
    "ammanettasser": "ammanettare",
    "ammanettassero": "ammanettare",
    "ammanettassi": "ammanettare",
    "ammanettassimo": "ammanettare",
    "ammanettaste": "ammanettare",
    "ammanettasti": "ammanettare",
    "ammanettata": "ammanettare",
    "ammanettate": "ammanettare",
    "ammanettati": "ammanettare",
    "ammanettato": "ammanettare",
    "ammanettava": "ammanettare",
    "ammanettavamo": "ammanettare",
    "ammanettavan": "ammanettare",
    "ammanettavano": "ammanettare",
    "ammanettavate": "ammanettare",
    "ammanettavi": "ammanettare",
    "ammanettavo": "ammanettare",
    "ammanetterai": "ammanettare",
    "ammanetteran": "ammanettare",
    "ammanetteranno": "ammanettare",
    "ammanetterebbe": "ammanettare",
    "ammanetterebber": "ammanettare",
    "ammanetterebbero": "ammanettare",
    "ammanetterei": "ammanettare",
    "ammanetteremmo": "ammanettare",
    "ammanetteremo": "ammanettare",
    "ammanettereste": "ammanettare",
    "ammanetteresti": "ammanettare",
    "ammanetterete": "ammanettare",
    "ammanetterà": "ammanettare",
    "ammanetterò": "ammanettare",
    "ammanetti": "ammanettare",
    "ammanettiamo": "ammanettare",
    "ammanettiate": "ammanettare",
    "ammanettin": "ammanettare",
    "ammanettino": "ammanettare",
    "ammanetto": "ammanettare",
    "ammanettò": "ammanettare",
    "ammaniera": "ammanierare",
    "ammanierai": "ammanierare",
    "ammanierammo": "ammanierare",
    "ammanieran": "ammanierare",
    "ammanierando": "ammanierare",
    "ammanierano": "ammanierare",
    "ammanierante": "ammanierare",
    "ammanieranti": "ammanierare",
    "ammanierar": "ammanierare",
    "ammanieraron": "ammanierare",
    "ammanierarono": "ammanierare",
    "ammanierasse": "ammanierare",
    "ammanierasser": "ammanierare",
    "ammanierassero": "ammanierare",
    "ammanierassi": "ammanierare",
    "ammanierassimo": "ammanierare",
    "ammanieraste": "ammanierare",
    "ammanierasti": "ammanierare",
    "ammanierata": "ammanierare",
    "ammanierate": "ammanierare",
    "ammanierati": "ammanierare",
    "ammanierato": "ammanierare",
    "ammanierava": "ammanierare",
    "ammanieravamo": "ammanierare",
    "ammanieravan": "ammanierare",
    "ammanieravano": "ammanierare",
    "ammanieravate": "ammanierare",
    "ammanieravi": "ammanierare",
    "ammanieravo": "ammanierare",
    "ammaniererai": "ammanierare",
    "ammaniereran": "ammanierare",
    "ammaniereranno": "ammanierare",
    "ammaniererebbe": "ammanierare",
    "ammaniererebber": "ammanierare",
    "ammaniererebbero": "ammanierare",
    "ammaniererei": "ammanierare",
    "ammaniereremmo": "ammanierare",
    "ammaniereremo": "ammanierare",
    "ammanierereste": "ammanierare",
    "ammaniereresti": "ammanierare",
    "ammaniererete": "ammanierare",
    "ammaniererà": "ammanierare",
    "ammaniererò": "ammanierare",
    "ammanieri": "ammanierare",
    "ammanieriamo": "ammanierare",
    "ammanieriate": "ammanierare",
    "ammanierin": "ammanierare",
    "ammanierino": "ammanierare",
    "ammaniero": "ammanierare",
    "ammanierò": "ammanierare",
    "ammanigli": "ammanigliare",
    "ammaniglia": "ammanigliare",
    "ammanigliai": "ammanigliare",
    "ammanigliammo": "ammanigliare",
    "ammanigliamo": "ammanigliare",
    "ammaniglian": "ammanigliare",
    "ammanigliando": "ammanigliare",
    "ammanigliano": "ammanigliare",
    "ammanigliante": "ammanigliare",
    "ammaniglianti": "ammanigliare",
    "ammanigliar": "ammanigliare",
    "ammanigliaron": "ammanigliare",
    "ammanigliarono": "ammanigliare",
    "ammanigliasse": "ammanigliare",
    "ammanigliasser": "ammanigliare",
    "ammanigliassero": "ammanigliare",
    "ammanigliassi": "ammanigliare",
    "ammanigliassimo": "ammanigliare",
    "ammanigliaste": "ammanigliare",
    "ammanigliasti": "ammanigliare",
    "ammanigliata": "ammanigliare",
    "ammanigliate": "ammanigliare",
    "ammanigliati": "ammanigliare",
    "ammanigliato": "ammanigliare",
    "ammanigliava": "ammanigliare",
    "ammanigliavamo": "ammanigliare",
    "ammanigliavan": "ammanigliare",
    "ammanigliavano": "ammanigliare",
    "ammanigliavate": "ammanigliare",
    "ammanigliavi": "ammanigliare",
    "ammanigliavo": "ammanigliare",
    "ammaniglierai": "ammanigliare",
    "ammaniglieran": "ammanigliare",
    "ammaniglieranno": "ammanigliare",
    "ammaniglierebbe": "ammanigliare",
    "ammaniglierebber": "ammanigliare",
    "ammaniglierebbero": "ammanigliare",
    "ammaniglierei": "ammanigliare",
    "ammaniglieremmo": "ammanigliare",
    "ammaniglieremo": "ammanigliare",
    "ammanigliereste": "ammanigliare",
    "ammaniglieresti": "ammanigliare",
    "ammaniglierete": "ammanigliare",
    "ammaniglierà": "ammanigliare",
    "ammaniglierò": "ammanigliare",
    "ammaniglin": "ammanigliare",
    "ammaniglino": "ammanigliare",
    "ammaniglio": "ammanigliare",
    "ammanigliò": "ammanigliare",
    "ammannendo": "ammannire",
    "ammannente": "ammannire",
    "ammannenti": "ammannire",
    "ammanniamo": "ammannire",
    "ammanniate": "ammannire",
    "ammannii": "ammannire",
    "ammannimmo": "ammannire",
    "ammannir": "ammannire",
    "ammannirai": "ammannire",
    "ammanniran": "ammannire",
    "ammanniranno": "ammannire",
    "ammannirebbe": "ammannire",
    "ammannirebber": "ammannire",
    "ammannirebbero": "ammannire",
    "ammannirei": "ammannire",
    "ammanniremmo": "ammannire",
    "ammanniremo": "ammannire",
    "ammannireste": "ammannire",
    "ammanniresti": "ammannire",
    "ammannirete": "ammannire",
    "ammanniron": "ammannire",
    "ammannirono": "ammannire",
    "ammannirà": "ammannire",
    "ammannirò": "ammannire",
    "ammannisca": "ammannire",
    "ammanniscan": "ammannire",
    "ammanniscano": "ammannire",
    "ammannisce": "ammannire",
    "ammannisci": "ammannire",
    "ammannisco": "ammannire",
    "ammanniscon": "ammannire",
    "ammanniscono": "ammannire",
    "ammannisse": "ammannire",
    "ammannisser": "ammannire",
    "ammannissero": "ammannire",
    "ammannissi": "ammannire",
    "ammannissimo": "ammannire",
    "ammanniste": "ammannire",
    "ammannisti": "ammannire",
    "ammannita": "ammannire",
    "ammannite": "ammannire",
    "ammanniti": "ammannire",
    "ammannito": "ammannire",
    "ammanniva": "ammannire",
    "ammannivamo": "ammannire",
    "ammannivan": "ammannire",
    "ammannivano": "ammannire",
    "ammannivate": "ammannire",
    "ammannivi": "ammannire",
    "ammannivo": "ammannire",
    "ammannì": "ammannire",
    "ammansendo": "ammansire",
    "ammansente": "ammansire",
    "ammansenti": "ammansire",
    "ammansiamo": "ammansire",
    "ammansiate": "ammansire",
    "ammansii": "ammansire",
    "ammansimmo": "ammansire",
    "ammansir": "ammansire",
    "ammansirai": "ammansire",
    "ammansiran": "ammansire",
    "ammansiranno": "ammansire",
    "ammansirebbe": "ammansire",
    "ammansirebber": "ammansire",
    "ammansirebbero": "ammansire",
    "ammansirei": "ammansire",
    "ammansiremmo": "ammansire",
    "ammansiremo": "ammansire",
    "ammansireste": "ammansire",
    "ammansiresti": "ammansire",
    "ammansirete": "ammansire",
    "ammansiron": "ammansire",
    "ammansirono": "ammansire",
    "ammansirà": "ammansire",
    "ammansirò": "ammansire",
    "ammansisca": "ammansire",
    "ammansiscan": "ammansire",
    "ammansiscano": "ammansire",
    "ammansisce": "ammansire",
    "ammansisci": "ammansire",
    "ammansisco": "ammansire",
    "ammansiscon": "ammansire",
    "ammansiscono": "ammansire",
    "ammansisse": "ammansire",
    "ammansisser": "ammansire",
    "ammansissero": "ammansire",
    "ammansissi": "ammansire",
    "ammansissimo": "ammansire",
    "ammansiste": "ammansire",
    "ammansisti": "ammansire",
    "ammansita": "ammansire",
    "ammansite": "ammansire",
    "ammansiti": "ammansire",
    "ammansito": "ammansire",
    "ammansiva": "ammansire",
    "ammansivamo": "ammansire",
    "ammansivan": "ammansire",
    "ammansivano": "ammansire",
    "ammansivate": "ammansire",
    "ammansivi": "ammansire",
    "ammansivo": "ammansire",
    "ammansì": "ammansire",
    "ammanta": "ammantare",
    "ammantai": "ammantare",
    "ammantammo": "ammantare",
    "ammantan": "ammantare",
    "ammantando": "ammantare",
    "ammantano": "ammantare",
    "ammantante": "ammantare",
    "ammantanti": "ammantare",
    "ammantar": "ammantare",
    "ammantaron": "ammantare",
    "ammantarono": "ammantare",
    "ammantasse": "ammantare",
    "ammantasser": "ammantare",
    "ammantassero": "ammantare",
    "ammantassi": "ammantare",
    "ammantassimo": "ammantare",
    "ammantaste": "ammantare",
    "ammantasti": "ammantare",
    "ammantata": "ammantare",
    "ammantate": "ammantare",
    "ammantati": "ammantare",
    "ammantato": "ammantare",
    "ammantava": "ammantare",
    "ammantavamo": "ammantare",
    "ammantavan": "ammantare",
    "ammantavano": "ammantare",
    "ammantavate": "ammantare",
    "ammantavi": "ammantare",
    "ammantavo": "ammantare",
    "ammanterai": "ammantare",
    "ammanteran": "ammantare",
    "ammanteranno": "ammantare",
    "ammanterebbe": "ammantare",
    "ammanterebber": "ammantare",
    "ammanterebbero": "ammantare",
    "ammanterei": "ammantare",
    "ammanteremmo": "ammantare",
    "ammanteremo": "ammantare",
    "ammantereste": "ammantare",
    "ammanteresti": "ammantare",
    "ammanterete": "ammantare",
    "ammanterà": "ammantare",
    "ammanterò": "ammantare",
    "ammanti": "ammantare",
    "ammantiamo": "ammantare",
    "ammantiate": "ammantare",
    "ammantin": "ammantare",
    "ammantino": "ammantare",
    "ammanto": "ammantare",
    "ammantò": "ammantare",
    "ammara": "ammarare",
    "ammarai": "ammarare",
    "ammarammo": "ammarare",
    "ammaran": "ammarare",
    "ammarando": "ammarare",
    "ammarano": "ammarare",
    "ammarante": "ammarare",
    "ammaranti": "ammarare",
    "ammarar": "ammarare",
    "ammararon": "ammarare",
    "ammararono": "ammarare",
    "ammarasse": "ammarare",
    "ammarasser": "ammarare",
    "ammarassero": "ammarare",
    "ammarassi": "ammarare",
    "ammarassimo": "ammarare",
    "ammaraste": "ammarare",
    "ammarasti": "ammarare",
    "ammarata": "ammarare",
    "ammarate": "ammarare",
    "ammarati": "ammarare",
    "ammarato": "ammarare",
    "ammarava": "ammarare",
    "ammaravamo": "ammarare",
    "ammaravan": "ammarare",
    "ammaravano": "ammarare",
    "ammaravate": "ammarare",
    "ammaravi": "ammarare",
    "ammaravo": "ammarare",
    "ammarerai": "ammarare",
    "ammareran": "ammarare",
    "ammareranno": "ammarare",
    "ammarerebbe": "ammarare",
    "ammarerebber": "ammarare",
    "ammarerebbero": "ammarare",
    "ammarerei": "ammarare",
    "ammareremmo": "ammarare",
    "ammareremo": "ammarare",
    "ammarereste": "ammarare",
    "ammareresti": "ammarare",
    "ammarerete": "ammarare",
    "ammarerà": "ammarare",
    "ammarerò": "ammarare",
    "ammari": "ammarare",
    "ammariamo": "ammarare",
    "ammariate": "ammarare",
    "ammarin": "ammarare",
    "ammarino": "ammarare",
    "ammaro": "ammarare",
    "ammarò": "ammarare",
    "ammassa": "ammassare",
    "ammassai": "ammassare",
    "ammassammo": "ammassare",
    "ammassan": "ammassare",
    "ammassando": "ammassare",
    "ammassano": "ammassare",
    "ammassante": "ammassare",
    "ammassanti": "ammassare",
    "ammassar": "ammassare",
    "ammassaron": "ammassare",
    "ammassarono": "ammassare",
    "ammassasse": "ammassare",
    "ammassasser": "ammassare",
    "ammassassero": "ammassare",
    "ammassassi": "ammassare",
    "ammassassimo": "ammassare",
    "ammassaste": "ammassare",
    "ammassasti": "ammassare",
    "ammassata": "ammassare",
    "ammassate": "ammassare",
    "ammassati": "ammassare",
    "ammassato": "ammassare",
    "ammassava": "ammassare",
    "ammassavamo": "ammassare",
    "ammassavan": "ammassare",
    "ammassavano": "ammassare",
    "ammassavate": "ammassare",
    "ammassavi": "ammassare",
    "ammassavo": "ammassare",
    "ammasserai": "ammassare",
    "ammasseran": "ammassare",
    "ammasseranno": "ammassare",
    "ammasserebbe": "ammassare",
    "ammasserebber": "ammassare",
    "ammasserebbero": "ammassare",
    "ammasserei": "ammassare",
    "ammasseremmo": "ammassare",
    "ammasseremo": "ammassare",
    "ammassereste": "ammassare",
    "ammasseresti": "ammassare",
    "ammasserete": "ammassare",
    "ammasserà": "ammassare",
    "ammasserò": "ammassare",
    "ammassi": "ammasso",
    "ammassiamo": "ammassare",
    "ammassiate": "ammassare",
    "ammassin": "ammassare",
    "ammassino": "ammassare",
    "ammasso": "ammassare",
    "ammassò": "ammassare",
    "ammatta": "ammattire",
    "ammattan": "ammattire",
    "ammattano": "ammattire",
    "ammatte": "ammattire",
    "ammattendo": "ammattire",
    "ammattente": "ammattire",
    "ammattenti": "ammattire",
    "ammatti": "ammattire",
    "ammattiamo": "ammattire",
    "ammattiate": "ammattire",
    "ammattii": "ammattire",
    "ammattimmo": "ammattire",
    "ammattir": "ammattire",
    "ammattirai": "ammattire",
    "ammattiran": "ammattire",
    "ammattiranno": "ammattire",
    "ammattirebbe": "ammattire",
    "ammattirebber": "ammattire",
    "ammattirebbero": "ammattire",
    "ammattirei": "ammattire",
    "ammattiremmo": "ammattire",
    "ammattiremo": "ammattire",
    "ammattireste": "ammattire",
    "ammattiresti": "ammattire",
    "ammattirete": "ammattire",
    "ammattiron": "ammattire",
    "ammattirono": "ammattire",
    "ammattirà": "ammattire",
    "ammattirò": "ammattire",
    "ammattisse": "ammattire",
    "ammattisser": "ammattire",
    "ammattissero": "ammattire",
    "ammattissi": "ammattire",
    "ammattissimo": "ammattire",
    "ammattiste": "ammattire",
    "ammattisti": "ammattire",
    "ammattita": "ammattire",
    "ammattite": "ammattire",
    "ammattiti": "ammattire",
    "ammattito": "ammattire",
    "ammattiva": "ammattire",
    "ammattivamo": "ammattire",
    "ammattivan": "ammattire",
    "ammattivano": "ammattire",
    "ammattivate": "ammattire",
    "ammattivi": "ammattire",
    "ammattivo": "ammattire",
    "ammatto": "ammattire",
    "ammatton": "ammattire",
    "ammattona": "ammattonare",
    "ammattonai": "ammattonare",
    "ammattonammo": "ammattonare",
    "ammattonan": "ammattonare",
    "ammattonando": "ammattonare",
    "ammattonano": "ammattonare",
    "ammattonante": "ammattonare",
    "ammattonanti": "ammattonare",
    "ammattonar": "ammattonare",
    "ammattonaron": "ammattonare",
    "ammattonarono": "ammattonare",
    "ammattonasse": "ammattonare",
    "ammattonasser": "ammattonare",
    "ammattonassero": "ammattonare",
    "ammattonassi": "ammattonare",
    "ammattonassimo": "ammattonare",
    "ammattonaste": "ammattonare",
    "ammattonasti": "ammattonare",
    "ammattonata": "ammattonare",
    "ammattonate": "ammattonare",
    "ammattonati": "ammattonare",
    "ammattonato": "ammattonare",
    "ammattonava": "ammattonare",
    "ammattonavamo": "ammattonare",
    "ammattonavan": "ammattonare",
    "ammattonavano": "ammattonare",
    "ammattonavate": "ammattonare",
    "ammattonavi": "ammattonare",
    "ammattonavo": "ammattonare",
    "ammattonerai": "ammattonare",
    "ammattoneran": "ammattonare",
    "ammattoneranno": "ammattonare",
    "ammattonerebbe": "ammattonare",
    "ammattonerebber": "ammattonare",
    "ammattonerebbero": "ammattonare",
    "ammattonerei": "ammattonare",
    "ammattoneremmo": "ammattonare",
    "ammattoneremo": "ammattonare",
    "ammattonereste": "ammattonare",
    "ammattoneresti": "ammattonare",
    "ammattonerete": "ammattonare",
    "ammattonerà": "ammattonare",
    "ammattonerò": "ammattonare",
    "ammattoni": "ammattonare",
    "ammattoniamo": "ammattonare",
    "ammattoniate": "ammattonare",
    "ammattonin": "ammattonare",
    "ammattonino": "ammattonare",
    "ammattono": "ammattonare",
    "ammattonò": "ammattonare",
    "ammattì": "ammattire",
    "ammazza": "ammazzare",
    "ammazzai": "ammazzare",
    "ammazzammo": "ammazzare",
    "ammazzan": "ammazzare",
    "ammazzando": "ammazzare",
    "ammazzano": "ammazzare",
    "ammazzante": "ammazzare",
    "ammazzanti": "ammazzare",
    "ammazzar": "ammazzare",
    "ammazzaron": "ammazzare",
    "ammazzarono": "ammazzare",
    "ammazzasse": "ammazzare",
    "ammazzasser": "ammazzare",
    "ammazzassero": "ammazzare",
    "ammazzassi": "ammazzare",
    "ammazzassimo": "ammazzare",
    "ammazzaste": "ammazzare",
    "ammazzasti": "ammazzare",
    "ammazzata": "ammazzare",
    "ammazzate": "ammazzare",
    "ammazzati": "ammazzare",
    "ammazzato": "ammazzare",
    "ammazzava": "ammazzare",
    "ammazzavamo": "ammazzare",
    "ammazzavan": "ammazzare",
    "ammazzavano": "ammazzare",
    "ammazzavate": "ammazzare",
    "ammazzavi": "ammazzare",
    "ammazzavo": "ammazzare",
    "ammazzerai": "ammazzare",
    "ammazzeran": "ammazzare",
    "ammazzeranno": "ammazzare",
    "ammazzerebbe": "ammazzare",
    "ammazzerebber": "ammazzare",
    "ammazzerebbero": "ammazzare",
    "ammazzerei": "ammazzare",
    "ammazzeremmo": "ammazzare",
    "ammazzeremo": "ammazzare",
    "ammazzereste": "ammazzare",
    "ammazzeresti": "ammazzare",
    "ammazzerete": "ammazzare",
    "ammazzerà": "ammazzare",
    "ammazzerò": "ammazzare",
    "ammazzi": "ammazzare",
    "ammazziamo": "ammazzare",
    "ammazziate": "ammazzare",
    "ammazzin": "ammazzare",
    "ammazzino": "ammazzare",
    "ammazzo": "ammazzare",
    "ammazzò": "ammazzare",
    "ammende": "ammenda",
    "ammessa": "ammettere",
    "ammesse": "ammettere",
    "ammessi": "ammettere",
    "ammesso": "ammettere",
    "ammetta": "ammettere",
    "ammettan": "ammettere",
    "ammettano": "ammettere",
    "ammette": "ammettere",
    "ammettemmo": "ammettere",
    "ammettendo": "ammettere",
    "ammettente": "ammettere",
    "ammettenti": "ammettere",
    "ammetter": "ammettere",
    "ammetterai": "ammettere",
    "ammetteran": "ammettere",
    "ammetteranno": "ammettere",
    "ammetterebbe": "ammettere",
    "ammetterebber": "ammettere",
    "ammetterebbero": "ammettere",
    "ammetterei": "ammettere",
    "ammetteremmo": "ammettere",
    "ammetteremo": "ammettere",
    "ammettereste": "ammettere",
    "ammetteresti": "ammettere",
    "ammetterete": "ammettere",
    "ammetterà": "ammettere",
    "ammetterò": "ammettere",
    "ammettesse": "ammettere",
    "ammettesser": "ammettere",
    "ammettessero": "ammettere",
    "ammettessi": "ammettere",
    "ammettessimo": "ammettere",
    "ammetteste": "ammettere",
    "ammettesti": "ammettere",
    "ammettete": "ammettere",
    "ammetteva": "ammettere",
    "ammettevamo": "ammettere",
    "ammettevan": "ammettere",
    "ammettevano": "ammettere",
    "ammettevate": "ammettere",
    "ammettevi": "ammettere",
    "ammettevo": "ammettere",
    "ammetti": "ammettere",
    "ammettiamo": "ammettere",
    "ammettiate": "ammettere",
    "ammetto": "ammettere",
    "ammetton": "ammettere",
    "ammettono": "ammettere",
    "ammezza": "ammezzare",
    "ammezzai": "ammezzare",
    "ammezzammo": "ammezzare",
    "ammezzan": "ammezzare",
    "ammezzando": "ammezzare",
    "ammezzano": "ammezzare",
    "ammezzante": "ammezzare",
    "ammezzanti": "ammezzare",
    "ammezzar": "ammezzare",
    "ammezzaron": "ammezzare",
    "ammezzarono": "ammezzare",
    "ammezzasse": "ammezzare",
    "ammezzasser": "ammezzare",
    "ammezzassero": "ammezzare",
    "ammezzassi": "ammezzare",
    "ammezzassimo": "ammezzare",
    "ammezzaste": "ammezzare",
    "ammezzasti": "ammezzare",
    "ammezzata": "ammezzare",
    "ammezzate": "ammezzare",
    "ammezzati": "ammezzare",
    "ammezzato": "ammezzare",
    "ammezzava": "ammezzare",
    "ammezzavamo": "ammezzare",
    "ammezzavan": "ammezzare",
    "ammezzavano": "ammezzare",
    "ammezzavate": "ammezzare",
    "ammezzavi": "ammezzare",
    "ammezzavo": "ammezzare",
    "ammezzerai": "ammezzare",
    "ammezzeran": "ammezzare",
    "ammezzeranno": "ammezzare",
    "ammezzerebbe": "ammezzare",
    "ammezzerebber": "ammezzare",
    "ammezzerebbero": "ammezzare",
    "ammezzerei": "ammezzare",
    "ammezzeremmo": "ammezzare",
    "ammezzeremo": "ammezzare",
    "ammezzereste": "ammezzare",
    "ammezzeresti": "ammezzare",
    "ammezzerete": "ammezzare",
    "ammezzerà": "ammezzare",
    "ammezzerò": "ammezzare",
    "ammezzi": "ammezzare",
    "ammezziamo": "ammezzare",
    "ammezziate": "ammezzare",
    "ammezzin": "ammezzare",
    "ammezzino": "ammezzare",
    "ammezzo": "ammezzare",
    "ammezzò": "ammezzare",
    "ammicca": "ammiccare",
    "ammiccai": "ammiccare",
    "ammiccamenti": "ammiccamento",
    "ammiccammo": "ammiccare",
    "ammiccan": "ammiccare",
    "ammiccando": "ammiccare",
    "ammiccano": "ammiccare",
    "ammiccante": "ammiccare",
    "ammiccanti": "ammiccare",
    "ammiccar": "ammiccare",
    "ammiccaron": "ammiccare",
    "ammiccarono": "ammiccare",
    "ammiccasse": "ammiccare",
    "ammiccasser": "ammiccare",
    "ammiccassero": "ammiccare",
    "ammiccassi": "ammiccare",
    "ammiccassimo": "ammiccare",
    "ammiccaste": "ammiccare",
    "ammiccasti": "ammiccare",
    "ammiccata": "ammiccare",
    "ammiccate": "ammiccare",
    "ammiccati": "ammiccare",
    "ammiccato": "ammiccare",
    "ammiccava": "ammiccare",
    "ammiccavamo": "ammiccare",
    "ammiccavan": "ammiccare",
    "ammiccavano": "ammiccare",
    "ammiccavate": "ammiccare",
    "ammiccavi": "ammiccare",
    "ammiccavo": "ammiccare",
    "ammiccherai": "ammiccare",
    "ammiccheran": "ammiccare",
    "ammiccheranno": "ammiccare",
    "ammiccherebbe": "ammiccare",
    "ammiccherebber": "ammiccare",
    "ammiccherebbero": "ammiccare",
    "ammiccherei": "ammiccare",
    "ammiccheremmo": "ammiccare",
    "ammiccheremo": "ammiccare",
    "ammicchereste": "ammiccare",
    "ammiccheresti": "ammiccare",
    "ammiccherete": "ammiccare",
    "ammiccherà": "ammiccare",
    "ammiccherò": "ammiccare",
    "ammicchi": "ammicco",
    "ammicchiamo": "ammiccare",
    "ammicchiate": "ammiccare",
    "ammicchin": "ammiccare",
    "ammicchino": "ammiccare",
    "ammicco": "ammiccare",
    "ammiccò": "ammiccare",
    "amministra": "amministrare",
    "amministrai": "amministrare",
    "amministrammo": "amministrare",
    "amministran": "amministrare",
    "amministrando": "amministrare",
    "amministrano": "amministrare",
    "amministrante": "amministrare",
    "amministranti": "amministrare",
    "amministrar": "amministrare",
    "amministraron": "amministrare",
    "amministrarono": "amministrare",
    "amministrasse": "amministrare",
    "amministrasser": "amministrare",
    "amministrassero": "amministrare",
    "amministrassi": "amministrare",
    "amministrassimo": "amministrare",
    "amministraste": "amministrare",
    "amministrasti": "amministrare",
    "amministrata": "amministrare",
    "amministrate": "amministrare",
    "amministrati": "amministrare",
    "amministrativa": "amministrativo",
    "amministrative": "amministrativo",
    "amministrativi": "amministrativo",
    "amministrativo-conoscitiva": "amministrativo-conoscitivo",
    "amministrativo-conoscitive": "amministrativo-conoscitivo",
    "amministrativo-conoscitivi": "amministrativo-conoscitivo",
    "amministrativo-contabili": "amministrativo-contabile",
    "amministrativo-finanziari": "amministrativo-finanziario",
    "amministrativo-finanziaria": "amministrativo-finanziario",
    "amministrativo-finanziarie": "amministrativo-finanziario",
    "amministrativo-gestionali": "amministrativo-gestionale",
    "amministrato": "amministrare",
    "amministratori": "amministratore",
    "amministratrici": "amministratrice",
    "amministrava": "amministrare",
    "amministravamo": "amministrare",
    "amministravan": "amministrare",
    "amministravano": "amministrare",
    "amministravate": "amministrare",
    "amministravi": "amministrare",
    "amministravo": "amministrare",
    "amministrazioni": "amministrazione",
    "amministrerai": "amministrare",
    "amministreran": "amministrare",
    "amministreranno": "amministrare",
    "amministrerebbe": "amministrare",
    "amministrerebber": "amministrare",
    "amministrerebbero": "amministrare",
    "amministrerei": "amministrare",
    "amministreremmo": "amministrare",
    "amministreremo": "amministrare",
    "amministrereste": "amministrare",
    "amministreresti": "amministrare",
    "amministrerete": "amministrare",
    "amministrerà": "amministrare",
    "amministrerò": "amministrare",
    "amministri": "amministrare",
    "amministriamo": "amministrare",
    "amministriate": "amministrare",
    "amministrin": "amministrare",
    "amministrino": "amministrare",
    "amministro": "amministrare",
    "amministrò": "amministrare",
    "ammira": "ammirare",
    "ammiragli": "ammiraglio",
    "ammiraglie": "ammiraglia",
    "ammirai": "ammirare",
    "ammirammo": "ammirare",
    "ammiran": "ammirare",
    "ammirando": "ammirare",
    "ammirano": "ammirare",
    "ammirante": "ammirare",
    "ammiranti": "ammirare",
    "ammirar": "ammirare",
    "ammiraron": "ammirare",
    "ammirarono": "ammirare",
    "ammirasse": "ammirare",
    "ammirasser": "ammirare",
    "ammirassero": "ammirare",
    "ammirassi": "ammirare",
    "ammirassimo": "ammirare",
    "ammiraste": "ammirare",
    "ammirasti": "ammirare",
    "ammirata": "ammirato",
    "ammirate": "ammirato",
    "ammirati": "ammirato",
    "ammirato": "ammirare",
    "ammiratori": "ammiratore",
    "ammiratrici": "ammiratrice",
    "ammirava": "ammirare",
    "ammiravamo": "ammirare",
    "ammiravan": "ammirare",
    "ammiravano": "ammirare",
    "ammiravate": "ammirare",
    "ammiravi": "ammirare",
    "ammiravo": "ammirare",
    "ammirazioni": "ammirazione",
    "ammirerai": "ammirare",
    "ammireran": "ammirare",
    "ammireranno": "ammirare",
    "ammirerebbe": "ammirare",
    "ammirerebber": "ammirare",
    "ammirerebbero": "ammirare",
    "ammirerei": "ammirare",
    "ammireremmo": "ammirare",
    "ammireremo": "ammirare",
    "ammirereste": "ammirare",
    "ammireresti": "ammirare",
    "ammirerete": "ammirare",
    "ammirerà": "ammirare",
    "ammirerò": "ammirare",
    "ammirevoli": "ammirevole",
    "ammiri": "ammirare",
    "ammiriamo": "ammirare",
    "ammiriate": "ammirare",
    "ammirin": "ammirare",
    "ammirino": "ammirare",
    "ammiro": "ammirare",
    "ammirò": "ammirare",
    "ammise": "ammettere",
    "ammiser": "ammettere",
    "ammisero": "ammettere",
    "ammisi": "ammettere",
    "ammissibili": "ammissibile",
    "ammissioni": "ammissione",
    "ammobili": "ammobiliare",
    "ammobilia": "ammobiliare",
    "ammobiliai": "ammobiliare",
    "ammobiliammo": "ammobiliare",
    "ammobiliamo": "ammobiliare",
    "ammobilian": "ammobiliare",
    "ammobiliando": "ammobiliare",
    "ammobiliano": "ammobiliare",
    "ammobiliante": "ammobiliare",
    "ammobilianti": "ammobiliare",
    "ammobiliar": "ammobiliare",
    "ammobiliaron": "ammobiliare",
    "ammobiliarono": "ammobiliare",
    "ammobiliasse": "ammobiliare",
    "ammobiliasser": "ammobiliare",
    "ammobiliassero": "ammobiliare",
    "ammobiliassi": "ammobiliare",
    "ammobiliassimo": "ammobiliare",
    "ammobiliaste": "ammobiliare",
    "ammobiliasti": "ammobiliare",
    "ammobiliata": "ammobiliare",
    "ammobiliate": "ammobiliare",
    "ammobiliati": "ammobiliare",
    "ammobiliato": "ammobiliare",
    "ammobiliava": "ammobiliare",
    "ammobiliavamo": "ammobiliare",
    "ammobiliavan": "ammobiliare",
    "ammobiliavano": "ammobiliare",
    "ammobiliavate": "ammobiliare",
    "ammobiliavi": "ammobiliare",
    "ammobiliavo": "ammobiliare",
    "ammobilierai": "ammobiliare",
    "ammobilieran": "ammobiliare",
    "ammobilieranno": "ammobiliare",
    "ammobilierebbe": "ammobiliare",
    "ammobilierebber": "ammobiliare",
    "ammobilierebbero": "ammobiliare",
    "ammobilierei": "ammobiliare",
    "ammobilieremmo": "ammobiliare",
    "ammobilieremo": "ammobiliare",
    "ammobiliereste": "ammobiliare",
    "ammobilieresti": "ammobiliare",
    "ammobilierete": "ammobiliare",
    "ammobilierà": "ammobiliare",
    "ammobilierò": "ammobiliare",
    "ammobilin": "ammobiliare",
    "ammobilino": "ammobiliare",
    "ammobilio": "ammobiliare",
    "ammobiliò": "ammobiliare",
    "ammoderna": "ammodernare",
    "ammodernai": "ammodernare",
    "ammodernamenti": "ammodernamento",
    "ammodernammo": "ammodernare",
    "ammodernan": "ammodernare",
    "ammodernando": "ammodernare",
    "ammodernano": "ammodernare",
    "ammodernante": "ammodernare",
    "ammodernanti": "ammodernare",
    "ammodernar": "ammodernare",
    "ammodernaron": "ammodernare",
    "ammodernarono": "ammodernare",
    "ammodernasse": "ammodernare",
    "ammodernasser": "ammodernare",
    "ammodernassero": "ammodernare",
    "ammodernassi": "ammodernare",
    "ammodernassimo": "ammodernare",
    "ammodernaste": "ammodernare",
    "ammodernasti": "ammodernare",
    "ammodernata": "ammodernare",
    "ammodernate": "ammodernare",
    "ammodernati": "ammodernare",
    "ammodernato": "ammodernare",
    "ammodernava": "ammodernare",
    "ammodernavamo": "ammodernare",
    "ammodernavan": "ammodernare",
    "ammodernavano": "ammodernare",
    "ammodernavate": "ammodernare",
    "ammodernavi": "ammodernare",
    "ammodernavo": "ammodernare",
    "ammodernerai": "ammodernare",
    "ammoderneran": "ammodernare",
    "ammoderneranno": "ammodernare",
    "ammodernerebbe": "ammodernare",
    "ammodernerebber": "ammodernare",
    "ammodernerebbero": "ammodernare",
    "ammodernerei": "ammodernare",
    "ammoderneremmo": "ammodernare",
    "ammoderneremo": "ammodernare",
    "ammodernereste": "ammodernare",
    "ammoderneresti": "ammodernare",
    "ammodernerete": "ammodernare",
    "ammodernerà": "ammodernare",
    "ammodernerò": "ammodernare",
    "ammoderni": "ammodernare",
    "ammoderniamo": "ammodernare",
    "ammoderniate": "ammodernare",
    "ammodernin": "ammodernare",
    "ammodernino": "ammodernare",
    "ammoderno": "ammodernare",
    "ammodernò": "ammodernare",
    "ammogli": "ammogliare",
    "ammoglia": "ammogliare",
    "ammogliai": "ammogliare",
    "ammogliammo": "ammogliare",
    "ammogliamo": "ammogliare",
    "ammoglian": "ammogliare",
    "ammogliando": "ammogliare",
    "ammogliano": "ammogliare",
    "ammogliante": "ammogliare",
    "ammoglianti": "ammogliare",
    "ammogliar": "ammogliare",
    "ammogliaron": "ammogliare",
    "ammogliarono": "ammogliare",
    "ammogliasse": "ammogliare",
    "ammogliasser": "ammogliare",
    "ammogliassero": "ammogliare",
    "ammogliassi": "ammogliare",
    "ammogliassimo": "ammogliare",
    "ammogliaste": "ammogliare",
    "ammogliasti": "ammogliare",
    "ammogliata": "ammogliato",
    "ammogliate": "ammogliato",
    "ammogliati": "ammogliato",
    "ammogliato": "ammogliare",
    "ammogliava": "ammogliare",
    "ammogliavamo": "ammogliare",
    "ammogliavan": "ammogliare",
    "ammogliavano": "ammogliare",
    "ammogliavate": "ammogliare",
    "ammogliavi": "ammogliare",
    "ammogliavo": "ammogliare",
    "ammoglierai": "ammogliare",
    "ammoglieran": "ammogliare",
    "ammoglieranno": "ammogliare",
    "ammoglierebbe": "ammogliare",
    "ammoglierebber": "ammogliare",
    "ammoglierebbero": "ammogliare",
    "ammoglierei": "ammogliare",
    "ammoglieremmo": "ammogliare",
    "ammoglieremo": "ammogliare",
    "ammogliereste": "ammogliare",
    "ammoglieresti": "ammogliare",
    "ammoglierete": "ammogliare",
    "ammoglierà": "ammogliare",
    "ammoglierò": "ammogliare",
    "ammoglin": "ammogliare",
    "ammoglino": "ammogliare",
    "ammoglio": "ammogliare",
    "ammogliò": "ammogliare",
    "ammolla": "ammollire",
    "ammollai": "ammollare",
    "ammollammo": "ammollare",
    "ammollan": "ammollire",
    "ammollando": "ammollare",
    "ammollano": "ammollire",
    "ammollante": "ammollare",
    "ammollanti": "ammollare",
    "ammollar": "ammollare",
    "ammollaron": "ammollare",
    "ammollarono": "ammollare",
    "ammollasse": "ammollare",
    "ammollasser": "ammollare",
    "ammollassero": "ammollare",
    "ammollassi": "ammollare",
    "ammollassimo": "ammollare",
    "ammollaste": "ammollare",
    "ammollasti": "ammollare",
    "ammollata": "ammollare",
    "ammollate": "ammollare",
    "ammollati": "ammollare",
    "ammollato": "ammollare",
    "ammollava": "ammollare",
    "ammollavamo": "ammollare",
    "ammollavan": "ammollare",
    "ammollavano": "ammollare",
    "ammollavate": "ammollare",
    "ammollavi": "ammollare",
    "ammollavo": "ammollare",
    "ammolle": "ammollire",
    "ammollendo": "ammollire",
    "ammollente": "ammollire",
    "ammollenti": "ammollire",
    "ammollerai": "ammollare",
    "ammolleran": "ammollare",
    "ammolleranno": "ammollare",
    "ammollerebbe": "ammollare",
    "ammollerebber": "ammollare",
    "ammollerebbero": "ammollare",
    "ammollerei": "ammollare",
    "ammolleremmo": "ammollare",
    "ammolleremo": "ammollare",
    "ammollereste": "ammollare",
    "ammolleresti": "ammollare",
    "ammollerete": "ammollare",
    "ammollerà": "ammollare",
    "ammollerò": "ammollare",
    "ammolli": "ammollire",
    "ammolliamo": "ammollire",
    "ammolliate": "ammollire",
    "ammollii": "ammollire",
    "ammollimmo": "ammollire",
    "ammollin": "ammollare",
    "ammollino": "ammollare",
    "ammollir": "ammollire",
    "ammollirai": "ammollire",
    "ammolliran": "ammollire",
    "ammolliranno": "ammollire",
    "ammollirebbe": "ammollire",
    "ammollirebber": "ammollire",
    "ammollirebbero": "ammollire",
    "ammollirei": "ammollire",
    "ammolliremmo": "ammollire",
    "ammolliremo": "ammollire",
    "ammollireste": "ammollire",
    "ammolliresti": "ammollire",
    "ammollirete": "ammollire",
    "ammolliron": "ammollire",
    "ammollirono": "ammollire",
    "ammollirà": "ammollire",
    "ammollirò": "ammollire",
    "ammollisse": "ammollire",
    "ammollisser": "ammollire",
    "ammollissero": "ammollire",
    "ammollissi": "ammollire",
    "ammollissimo": "ammollire",
    "ammolliste": "ammollire",
    "ammollisti": "ammollire",
    "ammollita": "ammollire",
    "ammollite": "ammollire",
    "ammolliti": "ammollire",
    "ammollito": "ammollire",
    "ammolliva": "ammollire",
    "ammollivamo": "ammollire",
    "ammollivan": "ammollire",
    "ammollivano": "ammollire",
    "ammollivate": "ammollire",
    "ammollivi": "ammollire",
    "ammollivo": "ammollire",
    "ammollo": "ammollire",
    "ammollon": "ammollire",
    "ammollono": "ammollire",
    "ammollì": "ammollire",
    "ammollò": "ammollare",
    "ammonendo": "ammonire",
    "ammonente": "ammonire",
    "ammonenti": "ammonire",
    "ammoniacali": "ammoniacale",
    "ammoniamo": "ammonire",
    "ammoniate": "ammonire",
    "ammonii": "ammonire",
    "ammonimenti": "ammonimento",
    "ammonimmo": "ammonire",
    "ammonir": "ammonire",
    "ammonirai": "ammonire",
    "ammoniran": "ammonire",
    "ammoniranno": "ammonire",
    "ammonirebbe": "ammonire",
    "ammonirebber": "ammonire",
    "ammonirebbero": "ammonire",
    "ammonirei": "ammonire",
    "ammoniremmo": "ammonire",
    "ammoniremo": "ammonire",
    "ammonireste": "ammonire",
    "ammoniresti": "ammonire",
    "ammonirete": "ammonire",
    "ammoniron": "ammonire",
    "ammonirono": "ammonire",
    "ammonirà": "ammonire",
    "ammonirò": "ammonire",
    "ammonisca": "ammonire",
    "ammoniscan": "ammonire",
    "ammoniscano": "ammonire",
    "ammonisce": "ammonire",
    "ammonisci": "ammonire",
    "ammonisco": "ammonire",
    "ammoniscon": "ammonire",
    "ammoniscono": "ammonire",
    "ammonisse": "ammonire",
    "ammonisser": "ammonire",
    "ammonissero": "ammonire",
    "ammonissi": "ammonire",
    "ammonissimo": "ammonire",
    "ammoniste": "ammonire",
    "ammonisti": "ammonire",
    "ammonita": "ammonito",
    "ammonite": "ammonito",
    "ammoniti": "ammonito",
    "ammonito": "ammonire",
    "ammoniva": "ammonire",
    "ammonivamo": "ammonire",
    "ammonivan": "ammonire",
    "ammonivano": "ammonire",
    "ammonivate": "ammonire",
    "ammonivi": "ammonire",
    "ammonivo": "ammonire",
    "ammonizioni": "ammonizione",
    "ammonta": "ammontare",
    "ammontai": "ammontare",
    "ammontammo": "ammontare",
    "ammontan": "ammontare",
    "ammontando": "ammontare",
    "ammontano": "ammontare",
    "ammontante": "ammontare",
    "ammontanti": "ammontare",
    "ammontar": "ammontare",
    "ammontari": "ammontare",
    "ammontaron": "ammontare",
    "ammontarono": "ammontare",
    "ammontasse": "ammontare",
    "ammontasser": "ammontare",
    "ammontassero": "ammontare",
    "ammontassi": "ammontare",
    "ammontassimo": "ammontare",
    "ammontaste": "ammontare",
    "ammontasti": "ammontare",
    "ammontata": "ammontare",
    "ammontate": "ammontare",
    "ammontati": "ammontare",
    "ammontato": "ammontare",
    "ammontava": "ammontare",
    "ammontavamo": "ammontare",
    "ammontavan": "ammontare",
    "ammontavano": "ammontare",
    "ammontavate": "ammontare",
    "ammontavi": "ammontare",
    "ammontavo": "ammontare",
    "ammonterai": "ammontare",
    "ammonteran": "ammontare",
    "ammonteranno": "ammontare",
    "ammonterebbe": "ammontare",
    "ammonterebber": "ammontare",
    "ammonterebbero": "ammontare",
    "ammonterei": "ammontare",
    "ammonteremmo": "ammontare",
    "ammonteremo": "ammontare",
    "ammontereste": "ammontare",
    "ammonteresti": "ammontare",
    "ammonterete": "ammontare",
    "ammonterà": "ammontare",
    "ammonterò": "ammontare",
    "ammonti": "ammontare",
    "ammontiamo": "ammontare",
    "ammontiate": "ammontare",
    "ammonticchi": "ammonticchiare",
    "ammonticchia": "ammonticchiare",
    "ammonticchiai": "ammonticchiare",
    "ammonticchiammo": "ammonticchiare",
    "ammonticchiamo": "ammonticchiare",
    "ammonticchian": "ammonticchiare",
    "ammonticchiando": "ammonticchiare",
    "ammonticchiano": "ammonticchiare",
    "ammonticchiante": "ammonticchiare",
    "ammonticchianti": "ammonticchiare",
    "ammonticchiar": "ammonticchiare",
    "ammonticchiaron": "ammonticchiare",
    "ammonticchiarono": "ammonticchiare",
    "ammonticchiasse": "ammonticchiare",
    "ammonticchiasser": "ammonticchiare",
    "ammonticchiassero": "ammonticchiare",
    "ammonticchiassi": "ammonticchiare",
    "ammonticchiassimo": "ammonticchiare",
    "ammonticchiaste": "ammonticchiare",
    "ammonticchiasti": "ammonticchiare",
    "ammonticchiata": "ammonticchiare",
    "ammonticchiate": "ammonticchiare",
    "ammonticchiati": "ammonticchiare",
    "ammonticchiato": "ammonticchiare",
    "ammonticchiava": "ammonticchiare",
    "ammonticchiavamo": "ammonticchiare",
    "ammonticchiavan": "ammonticchiare",
    "ammonticchiavano": "ammonticchiare",
    "ammonticchiavate": "ammonticchiare",
    "ammonticchiavi": "ammonticchiare",
    "ammonticchiavo": "ammonticchiare",
    "ammonticchierai": "ammonticchiare",
    "ammonticchieran": "ammonticchiare",
    "ammonticchieranno": "ammonticchiare",
    "ammonticchierebbe": "ammonticchiare",
    "ammonticchierebber": "ammonticchiare",
    "ammonticchierebbero": "ammonticchiare",
    "ammonticchierei": "ammonticchiare",
    "ammonticchieremmo": "ammonticchiare",
    "ammonticchieremo": "ammonticchiare",
    "ammonticchiereste": "ammonticchiare",
    "ammonticchieresti": "ammonticchiare",
    "ammonticchierete": "ammonticchiare",
    "ammonticchierà": "ammonticchiare",
    "ammonticchierò": "ammonticchiare",
    "ammonticchin": "ammonticchiare",
    "ammonticchino": "ammonticchiare",
    "ammonticchio": "ammonticchiare",
    "ammonticchiò": "ammonticchiare",
    "ammontin": "ammontare",
    "ammontino": "ammontare",
    "ammonto": "ammontare",
    "ammontò": "ammontare",
    "ammonì": "ammonire",
    "ammorba": "ammorbare",
    "ammorbai": "ammorbare",
    "ammorbammo": "ammorbare",
    "ammorban": "ammorbare",
    "ammorbando": "ammorbare",
    "ammorbano": "ammorbare",
    "ammorbante": "ammorbare",
    "ammorbanti": "ammorbare",
    "ammorbar": "ammorbare",
    "ammorbaron": "ammorbare",
    "ammorbarono": "ammorbare",
    "ammorbasse": "ammorbare",
    "ammorbasser": "ammorbare",
    "ammorbassero": "ammorbare",
    "ammorbassi": "ammorbare",
    "ammorbassimo": "ammorbare",
    "ammorbaste": "ammorbare",
    "ammorbasti": "ammorbare",
    "ammorbata": "ammorbare",
    "ammorbate": "ammorbare",
    "ammorbati": "ammorbare",
    "ammorbato": "ammorbare",
    "ammorbava": "ammorbare",
    "ammorbavamo": "ammorbare",
    "ammorbavan": "ammorbare",
    "ammorbavano": "ammorbare",
    "ammorbavate": "ammorbare",
    "ammorbavi": "ammorbare",
    "ammorbavo": "ammorbare",
    "ammorberai": "ammorbare",
    "ammorberan": "ammorbare",
    "ammorberanno": "ammorbare",
    "ammorberebbe": "ammorbare",
    "ammorberebber": "ammorbare",
    "ammorberebbero": "ammorbare",
    "ammorberei": "ammorbare",
    "ammorberemmo": "ammorbare",
    "ammorberemo": "ammorbare",
    "ammorbereste": "ammorbare",
    "ammorberesti": "ammorbare",
    "ammorberete": "ammorbare",
    "ammorberà": "ammorbare",
    "ammorberò": "ammorbare",
    "ammorbi": "ammorbare",
    "ammorbiamo": "ammorbare",
    "ammorbiate": "ammorbare",
    "ammorbidendo": "ammorbidire",
    "ammorbidente": "ammorbidire",
    "ammorbidenti": "ammorbidire",
    "ammorbidiamo": "ammorbidire",
    "ammorbidiate": "ammorbidire",
    "ammorbidii": "ammorbidire",
    "ammorbidimenti": "ammorbidimento",
    "ammorbidimmo": "ammorbidire",
    "ammorbidir": "ammorbidire",
    "ammorbidirai": "ammorbidire",
    "ammorbidiran": "ammorbidire",
    "ammorbidiranno": "ammorbidire",
    "ammorbidirebbe": "ammorbidire",
    "ammorbidirebber": "ammorbidire",
    "ammorbidirebbero": "ammorbidire",
    "ammorbidirei": "ammorbidire",
    "ammorbidiremmo": "ammorbidire",
    "ammorbidiremo": "ammorbidire",
    "ammorbidireste": "ammorbidire",
    "ammorbidiresti": "ammorbidire",
    "ammorbidirete": "ammorbidire",
    "ammorbidiron": "ammorbidire",
    "ammorbidirono": "ammorbidire",
    "ammorbidirà": "ammorbidire",
    "ammorbidirò": "ammorbidire",
    "ammorbidisca": "ammorbidire",
    "ammorbidiscan": "ammorbidire",
    "ammorbidiscano": "ammorbidire",
    "ammorbidisce": "ammorbidire",
    "ammorbidisci": "ammorbidire",
    "ammorbidisco": "ammorbidire",
    "ammorbidiscon": "ammorbidire",
    "ammorbidiscono": "ammorbidire",
    "ammorbidisse": "ammorbidire",
    "ammorbidisser": "ammorbidire",
    "ammorbidissero": "ammorbidire",
    "ammorbidissi": "ammorbidire",
    "ammorbidissimo": "ammorbidire",
    "ammorbidiste": "ammorbidire",
    "ammorbidisti": "ammorbidire",
    "ammorbidita": "ammorbidire",
    "ammorbidite": "ammorbidire",
    "ammorbiditi": "ammorbidire",
    "ammorbidito": "ammorbidire",
    "ammorbidiva": "ammorbidire",
    "ammorbidivamo": "ammorbidire",
    "ammorbidivan": "ammorbidire",
    "ammorbidivano": "ammorbidire",
    "ammorbidivate": "ammorbidire",
    "ammorbidivi": "ammorbidire",
    "ammorbidivo": "ammorbidire",
    "ammorbidì": "ammorbidire",
    "ammorbin": "ammorbare",
    "ammorbino": "ammorbare",
    "ammorbo": "ammorbare",
    "ammorbò": "ammorbare",
    "ammorta": "ammortare",
    "ammortai": "ammortare",
    "ammortamenti": "ammortamento",
    "ammortammo": "ammortare",
    "ammortan": "ammortare",
    "ammortando": "ammortare",
    "ammortano": "ammortare",
    "ammortante": "ammortare",
    "ammortanti": "ammortare",
    "ammortar": "ammortare",
    "ammortaron": "ammortare",
    "ammortarono": "ammortare",
    "ammortasse": "ammortare",
    "ammortasser": "ammortare",
    "ammortassero": "ammortare",
    "ammortassi": "ammortare",
    "ammortassimo": "ammortare",
    "ammortaste": "ammortare",
    "ammortasti": "ammortare",
    "ammortata": "ammortare",
    "ammortate": "ammortare",
    "ammortati": "ammortare",
    "ammortato": "ammortare",
    "ammortava": "ammortare",
    "ammortavamo": "ammortare",
    "ammortavan": "ammortare",
    "ammortavano": "ammortare",
    "ammortavate": "ammortare",
    "ammortavi": "ammortare",
    "ammortavo": "ammortare",
    "ammorterai": "ammortare",
    "ammorteran": "ammortare",
    "ammorteranno": "ammortare",
    "ammorterebbe": "ammortare",
    "ammorterebber": "ammortare",
    "ammorterebbero": "ammortare",
    "ammorterei": "ammortare",
    "ammorteremmo": "ammortare",
    "ammorteremo": "ammortare",
    "ammortereste": "ammortare",
    "ammorteresti": "ammortare",
    "ammorterete": "ammortare",
    "ammorterà": "ammortare",
    "ammorterò": "ammortare",
    "ammorti": "ammortare",
    "ammortiamo": "ammortare",
    "ammortiate": "ammortare",
    "ammortin": "ammortare",
    "ammortino": "ammortare",
    "ammortizza": "ammortizzare",
    "ammortizzabili": "ammortizzabile",
    "ammortizzai": "ammortizzare",
    "ammortizzammo": "ammortizzare",
    "ammortizzan": "ammortizzare",
    "ammortizzando": "ammortizzare",
    "ammortizzano": "ammortizzare",
    "ammortizzante": "ammortizzare",
    "ammortizzanti": "ammortizzare",
    "ammortizzar": "ammortizzare",
    "ammortizzaron": "ammortizzare",
    "ammortizzarono": "ammortizzare",
    "ammortizzasse": "ammortizzare",
    "ammortizzasser": "ammortizzare",
    "ammortizzassero": "ammortizzare",
    "ammortizzassi": "ammortizzare",
    "ammortizzassimo": "ammortizzare",
    "ammortizzaste": "ammortizzare",
    "ammortizzasti": "ammortizzare",
    "ammortizzata": "ammortizzare",
    "ammortizzate": "ammortizzare",
    "ammortizzati": "ammortizzare",
    "ammortizzato": "ammortizzare",
    "ammortizzatori": "ammortizzatore",
    "ammortizzava": "ammortizzare",
    "ammortizzavamo": "ammortizzare",
    "ammortizzavan": "ammortizzare",
    "ammortizzavano": "ammortizzare",
    "ammortizzavate": "ammortizzare",
    "ammortizzavi": "ammortizzare",
    "ammortizzavo": "ammortizzare",
    "ammortizzerai": "ammortizzare",
    "ammortizzeran": "ammortizzare",
    "ammortizzeranno": "ammortizzare",
    "ammortizzerebbe": "ammortizzare",
    "ammortizzerebber": "ammortizzare",
    "ammortizzerebbero": "ammortizzare",
    "ammortizzerei": "ammortizzare",
    "ammortizzeremmo": "ammortizzare",
    "ammortizzeremo": "ammortizzare",
    "ammortizzereste": "ammortizzare",
    "ammortizzeresti": "ammortizzare",
    "ammortizzerete": "ammortizzare",
    "ammortizzerà": "ammortizzare",
    "ammortizzerò": "ammortizzare",
    "ammortizzi": "ammortizzare",
    "ammortizziamo": "ammortizzare",
    "ammortizziate": "ammortizzare",
    "ammortizzin": "ammortizzare",
    "ammortizzino": "ammortizzare",
    "ammortizzo": "ammortizzare",
    "ammortizzò": "ammortizzare",
    "ammorto": "ammortare",
    "ammortò": "ammortare",
    "ammoscerai": "ammosciare",
    "ammosceran": "ammosciare",
    "ammosceranno": "ammosciare",
    "ammoscerebbe": "ammosciare",
    "ammoscerebber": "ammosciare",
    "ammoscerebbero": "ammosciare",
    "ammoscerei": "ammosciare",
    "ammosceremmo": "ammosciare",
    "ammosceremo": "ammosciare",
    "ammoscereste": "ammosciare",
    "ammosceresti": "ammosciare",
    "ammoscerete": "ammosciare",
    "ammoscerà": "ammosciare",
    "ammoscerò": "ammosciare",
    "ammosci": "ammosciare",
    "ammoscia": "ammosciare",
    "ammosciai": "ammosciare",
    "ammosciammo": "ammosciare",
    "ammosciamo": "ammosciare",
    "ammoscian": "ammosciare",
    "ammosciando": "ammosciare",
    "ammosciano": "ammosciare",
    "ammosciante": "ammosciare",
    "ammoscianti": "ammosciare",
    "ammosciar": "ammosciare",
    "ammosciaron": "ammosciare",
    "ammosciarono": "ammosciare",
    "ammosciasse": "ammosciare",
    "ammosciasser": "ammosciare",
    "ammosciassero": "ammosciare",
    "ammosciassi": "ammosciare",
    "ammosciassimo": "ammosciare",
    "ammosciaste": "ammosciare",
    "ammosciasti": "ammosciare",
    "ammosciata": "ammosciare",
    "ammosciate": "ammosciare",
    "ammosciati": "ammosciare",
    "ammosciato": "ammosciare",
    "ammosciava": "ammosciare",
    "ammosciavamo": "ammosciare",
    "ammosciavan": "ammosciare",
    "ammosciavano": "ammosciare",
    "ammosciavate": "ammosciare",
    "ammosciavi": "ammosciare",
    "ammosciavo": "ammosciare",
    "ammoscin": "ammosciare",
    "ammoscino": "ammosciare",
    "ammoscio": "ammosciare",
    "ammosciò": "ammosciare",
    "ammucchi": "ammucchiare",
    "ammucchia": "ammucchiare",
    "ammucchiai": "ammucchiare",
    "ammucchiammo": "ammucchiare",
    "ammucchiamo": "ammucchiare",
    "ammucchian": "ammucchiare",
    "ammucchiando": "ammucchiare",
    "ammucchiano": "ammucchiare",
    "ammucchiante": "ammucchiare",
    "ammucchianti": "ammucchiare",
    "ammucchiar": "ammucchiare",
    "ammucchiaron": "ammucchiare",
    "ammucchiarono": "ammucchiare",
    "ammucchiasse": "ammucchiare",
    "ammucchiasser": "ammucchiare",
    "ammucchiassero": "ammucchiare",
    "ammucchiassi": "ammucchiare",
    "ammucchiassimo": "ammucchiare",
    "ammucchiaste": "ammucchiare",
    "ammucchiasti": "ammucchiare",
    "ammucchiata": "ammucchiare",
    "ammucchiate": "ammucchiata",
    "ammucchiati": "ammucchiare",
    "ammucchiato": "ammucchiare",
    "ammucchiava": "ammucchiare",
    "ammucchiavamo": "ammucchiare",
    "ammucchiavan": "ammucchiare",
    "ammucchiavano": "ammucchiare",
    "ammucchiavate": "ammucchiare",
    "ammucchiavi": "ammucchiare",
    "ammucchiavo": "ammucchiare",
    "ammucchierai": "ammucchiare",
    "ammucchieran": "ammucchiare",
    "ammucchieranno": "ammucchiare",
    "ammucchierebbe": "ammucchiare",
    "ammucchierebber": "ammucchiare",
    "ammucchierebbero": "ammucchiare",
    "ammucchierei": "ammucchiare",
    "ammucchieremmo": "ammucchiare",
    "ammucchieremo": "ammucchiare",
    "ammucchiereste": "ammucchiare",
    "ammucchieresti": "ammucchiare",
    "ammucchierete": "ammucchiare",
    "ammucchierà": "ammucchiare",
    "ammucchierò": "ammucchiare",
    "ammucchin": "ammucchiare",
    "ammucchino": "ammucchiare",
    "ammucchio": "ammucchiare",
    "ammucchiò": "ammucchiare",
    "ammuffa": "ammuffire",
    "ammuffan": "ammuffire",
    "ammuffano": "ammuffire",
    "ammuffe": "ammuffire",
    "ammuffendo": "ammuffire",
    "ammuffente": "ammuffire",
    "ammuffenti": "ammuffire",
    "ammuffi": "ammuffire",
    "ammuffiamo": "ammuffire",
    "ammuffiate": "ammuffire",
    "ammuffii": "ammuffire",
    "ammuffimmo": "ammuffire",
    "ammuffir": "ammuffire",
    "ammuffirai": "ammuffire",
    "ammuffiran": "ammuffire",
    "ammuffiranno": "ammuffire",
    "ammuffirebbe": "ammuffire",
    "ammuffirebber": "ammuffire",
    "ammuffirebbero": "ammuffire",
    "ammuffirei": "ammuffire",
    "ammuffiremmo": "ammuffire",
    "ammuffiremo": "ammuffire",
    "ammuffireste": "ammuffire",
    "ammuffiresti": "ammuffire",
    "ammuffirete": "ammuffire",
    "ammuffiron": "ammuffire",
    "ammuffirono": "ammuffire",
    "ammuffirà": "ammuffire",
    "ammuffirò": "ammuffire",
    "ammuffisse": "ammuffire",
    "ammuffisser": "ammuffire",
    "ammuffissero": "ammuffire",
    "ammuffissi": "ammuffire",
    "ammuffissimo": "ammuffire",
    "ammuffiste": "ammuffire",
    "ammuffisti": "ammuffire",
    "ammuffita": "ammuffito",
    "ammuffite": "ammuffito",
    "ammuffiti": "ammuffito",
    "ammuffito": "ammuffire",
    "ammuffiva": "ammuffire",
    "ammuffivamo": "ammuffire",
    "ammuffivan": "ammuffire",
    "ammuffivano": "ammuffire",
    "ammuffivate": "ammuffire",
    "ammuffivi": "ammuffire",
    "ammuffivo": "ammuffire",
    "ammuffo": "ammuffire",
    "ammuffon": "ammuffire",
    "ammuffono": "ammuffire",
    "ammuffì": "ammuffire",
    "ammutina": "ammutinare",
    "ammutinai": "ammutinare",
    "ammutinamenti": "ammutinamento",
    "ammutinammo": "ammutinare",
    "ammutinan": "ammutinare",
    "ammutinando": "ammutinare",
    "ammutinano": "ammutinare",
    "ammutinante": "ammutinare",
    "ammutinanti": "ammutinare",
    "ammutinar": "ammutinare",
    "ammutinaron": "ammutinare",
    "ammutinarono": "ammutinare",
    "ammutinasse": "ammutinare",
    "ammutinasser": "ammutinare",
    "ammutinassero": "ammutinare",
    "ammutinassi": "ammutinare",
    "ammutinassimo": "ammutinare",
    "ammutinaste": "ammutinare",
    "ammutinasti": "ammutinare",
    "ammutinata": "ammutinato",
    "ammutinate": "ammutinato",
    "ammutinati": "ammutinato",
    "ammutinato": "ammutinare",
    "ammutinava": "ammutinare",
    "ammutinavamo": "ammutinare",
    "ammutinavan": "ammutinare",
    "ammutinavano": "ammutinare",
    "ammutinavate": "ammutinare",
    "ammutinavi": "ammutinare",
    "ammutinavo": "ammutinare",
    "ammutinerai": "ammutinare",
    "ammutineran": "ammutinare",
    "ammutineranno": "ammutinare",
    "ammutinerebbe": "ammutinare",
    "ammutinerebber": "ammutinare",
    "ammutinerebbero": "ammutinare",
    "ammutinerei": "ammutinare",
    "ammutineremmo": "ammutinare",
    "ammutineremo": "ammutinare",
    "ammutinereste": "ammutinare",
    "ammutineresti": "ammutinare",
    "ammutinerete": "ammutinare",
    "ammutinerà": "ammutinare",
    "ammutinerò": "ammutinare",
    "ammutini": "ammutinare",
    "ammutiniamo": "ammutinare",
    "ammutiniate": "ammutinare",
    "ammutinin": "ammutinare",
    "ammutinino": "ammutinare",
    "ammutino": "ammutinare",
    "ammutinò": "ammutinare",
    "ammutolendo": "ammutolire",
    "ammutolente": "ammutolire",
    "ammutolenti": "ammutolire",
    "ammutoliamo": "ammutolire",
    "ammutoliate": "ammutolire",
    "ammutolii": "ammutolire",
    "ammutolimmo": "ammutolire",
    "ammutolir": "ammutolire",
    "ammutolirai": "ammutolire",
    "ammutoliran": "ammutolire",
    "ammutoliranno": "ammutolire",
    "ammutolirebbe": "ammutolire",
    "ammutolirebber": "ammutolire",
    "ammutolirebbero": "ammutolire",
    "ammutolirei": "ammutolire",
    "ammutoliremmo": "ammutolire",
    "ammutoliremo": "ammutolire",
    "ammutolireste": "ammutolire",
    "ammutoliresti": "ammutolire",
    "ammutolirete": "ammutolire",
    "ammutoliron": "ammutolire",
    "ammutolirono": "ammutolire",
    "ammutolirà": "ammutolire",
    "ammutolirò": "ammutolire",
    "ammutolisca": "ammutolire",
    "ammutoliscan": "ammutolire",
    "ammutoliscano": "ammutolire",
    "ammutolisce": "ammutolire",
    "ammutolisci": "ammutolire",
    "ammutolisco": "ammutolire",
    "ammutoliscon": "ammutolire",
    "ammutoliscono": "ammutolire",
    "ammutolisse": "ammutolire",
    "ammutolisser": "ammutolire",
    "ammutolissero": "ammutolire",
    "ammutolissi": "ammutolire",
    "ammutolissimo": "ammutolire",
    "ammutoliste": "ammutolire",
    "ammutolisti": "ammutolire",
    "ammutolita": "ammutolire",
    "ammutolite": "ammutolire",
    "ammutoliti": "ammutolire",
    "ammutolito": "ammutolire",
    "ammutoliva": "ammutolire",
    "ammutolivamo": "ammutolire",
    "ammutolivan": "ammutolire",
    "ammutolivano": "ammutolire",
    "ammutolivate": "ammutolire",
    "ammutolivi": "ammutolire",
    "ammutolivo": "ammutolire",
    "ammutolì": "ammutolire",
    "amnesie": "amnesia",
    "amniotica": "amniotico",
    "amniotiche": "amniotico",
    "amniotici": "amniotico",
    "amnisti": "amnistiare",
    "amnistia": "amnistiare",
    "amnistiai": "amnistiare",
    "amnistiammo": "amnistiare",
    "amnistiamo": "amnistiare",
    "amnistian": "amnistiare",
    "amnistiando": "amnistiare",
    "amnistiano": "amnistiare",
    "amnistiante": "amnistiare",
    "amnistianti": "amnistiare",
    "amnistiar": "amnistiare",
    "amnistiaron": "amnistiare",
    "amnistiarono": "amnistiare",
    "amnistiasse": "amnistiare",
    "amnistiasser": "amnistiare",
    "amnistiassero": "amnistiare",
    "amnistiassi": "amnistiare",
    "amnistiassimo": "amnistiare",
    "amnistiaste": "amnistiare",
    "amnistiasti": "amnistiare",
    "amnistiata": "amnistiato",
    "amnistiate": "amnistiato",
    "amnistiati": "amnistiato",
    "amnistiato": "amnistiare",
    "amnistiava": "amnistiare",
    "amnistiavamo": "amnistiare",
    "amnistiavan": "amnistiare",
    "amnistiavano": "amnistiare",
    "amnistiavate": "amnistiare",
    "amnistiavi": "amnistiare",
    "amnistiavo": "amnistiare",
    "amnistie": "amnistia",
    "amnistierai": "amnistiare",
    "amnistieran": "amnistiare",
    "amnistieranno": "amnistiare",
    "amnistierebbe": "amnistiare",
    "amnistierebber": "amnistiare",
    "amnistierebbero": "amnistiare",
    "amnistierei": "amnistiare",
    "amnistieremmo": "amnistiare",
    "amnistieremo": "amnistiare",
    "amnistiereste": "amnistiare",
    "amnistieresti": "amnistiare",
    "amnistierete": "amnistiare",
    "amnistierà": "amnistiare",
    "amnistierò": "amnistiare",
    "amnistin": "amnistiare",
    "amnistino": "amnistiare",
    "amnistio": "amnistiare",
    "amnistiò": "amnistiare",
    "amo": "amare",
    "amor": "amore",
    "amorali": "amorale",
    "amorazzi": "amorazzo",
    "amoreggerai": "amoreggiare",
    "amoreggeran": "amoreggiare",
    "amoreggeranno": "amoreggiare",
    "amoreggerebbe": "amoreggiare",
    "amoreggerebber": "amoreggiare",
    "amoreggerebbero": "amoreggiare",
    "amoreggerei": "amoreggiare",
    "amoreggeremmo": "amoreggiare",
    "amoreggeremo": "amoreggiare",
    "amoreggereste": "amoreggiare",
    "amoreggeresti": "amoreggiare",
    "amoreggerete": "amoreggiare",
    "amoreggerà": "amoreggiare",
    "amoreggerò": "amoreggiare",
    "amoreggi": "amoreggiare",
    "amoreggia": "amoreggiare",
    "amoreggiai": "amoreggiare",
    "amoreggiammo": "amoreggiare",
    "amoreggiamo": "amoreggiare",
    "amoreggian": "amoreggiare",
    "amoreggiando": "amoreggiare",
    "amoreggiano": "amoreggiare",
    "amoreggiante": "amoreggiare",
    "amoreggianti": "amoreggiare",
    "amoreggiar": "amoreggiare",
    "amoreggiaron": "amoreggiare",
    "amoreggiarono": "amoreggiare",
    "amoreggiasse": "amoreggiare",
    "amoreggiasser": "amoreggiare",
    "amoreggiassero": "amoreggiare",
    "amoreggiassi": "amoreggiare",
    "amoreggiassimo": "amoreggiare",
    "amoreggiaste": "amoreggiare",
    "amoreggiasti": "amoreggiare",
    "amoreggiata": "amoreggiare",
    "amoreggiate": "amoreggiare",
    "amoreggiati": "amoreggiare",
    "amoreggiato": "amoreggiare",
    "amoreggiava": "amoreggiare",
    "amoreggiavamo": "amoreggiare",
    "amoreggiavan": "amoreggiare",
    "amoreggiavano": "amoreggiare",
    "amoreggiavate": "amoreggiare",
    "amoreggiavi": "amoreggiare",
    "amoreggiavo": "amoreggiare",
    "amoreggin": "amoreggiare",
    "amoreggino": "amoreggiare",
    "amoreggio": "amoreggiare",
    "amoreggiò": "amoreggiare",
    "amoretti": "amoretto",
    "amorevoli": "amorevole",
    "amorfa": "amorfo",
    "amorfe": "amorfo",
    "amorfi": "amorfo",
    "amori": "amore",
    "amorini": "amorino",
    "amorosa": "amoroso",
    "amorose": "amoroso",
    "amorosi": "amoroso",
    "ampi": "ampio",
    "ampia": "ampio",
    "ampie": "ampio",
    "ampiezze": "ampiezza",
    "amplessi": "amplesso",
    "ampli": "ampliare",
    "amplia": "ampliare",
    "ampliai": "ampliare",
    "ampliamenti": "ampliamento",
    "ampliammo": "ampliare",
    "ampliamo": "ampliare",
    "amplian": "ampliare",
    "ampliando": "ampliare",
    "ampliano": "ampliare",
    "ampliante": "ampliare",
    "amplianti": "ampliare",
    "ampliar": "ampliare",
    "ampliaron": "ampliare",
    "ampliarono": "ampliare",
    "ampliasse": "ampliare",
    "ampliasser": "ampliare",
    "ampliassero": "ampliare",
    "ampliassi": "ampliare",
    "ampliassimo": "ampliare",
    "ampliaste": "ampliare",
    "ampliasti": "ampliare",
    "ampliata": "ampliare",
    "ampliate": "ampliare",
    "ampliati": "ampliare",
    "ampliato": "ampliare",
    "ampliava": "ampliare",
    "ampliavamo": "ampliare",
    "ampliavan": "ampliare",
    "ampliavano": "ampliare",
    "ampliavate": "ampliare",
    "ampliavi": "ampliare",
    "ampliavo": "ampliare",
    "amplierai": "ampliare",
    "amplieran": "ampliare",
    "amplieranno": "ampliare",
    "amplierebbe": "ampliare",
    "amplierebber": "ampliare",
    "amplierebbero": "ampliare",
    "amplierei": "ampliare",
    "amplieremmo": "ampliare",
    "amplieremo": "ampliare",
    "ampliereste": "ampliare",
    "amplieresti": "ampliare",
    "amplierete": "ampliare",
    "amplierà": "ampliare",
    "amplierò": "ampliare",
    "amplifica": "amplificare",
    "amplificai": "amplificare",
    "amplificammo": "amplificare",
    "amplifican": "amplificare",
    "amplificando": "amplificare",
    "amplificano": "amplificare",
    "amplificante": "amplificare",
    "amplificanti": "amplificare",
    "amplificar": "amplificare",
    "amplificaron": "amplificare",
    "amplificarono": "amplificare",
    "amplificasse": "amplificare",
    "amplificasser": "amplificare",
    "amplificassero": "amplificare",
    "amplificassi": "amplificare",
    "amplificassimo": "amplificare",
    "amplificaste": "amplificare",
    "amplificasti": "amplificare",
    "amplificata": "amplificare",
    "amplificate": "amplificare",
    "amplificati": "amplificare",
    "amplificato": "amplificare",
    "amplificatori": "amplificatore",
    "amplificatrice": "amplificatore",
    "amplificatrici": "amplificatore",
    "amplificava": "amplificare",
    "amplificavamo": "amplificare",
    "amplificavan": "amplificare",
    "amplificavano": "amplificare",
    "amplificavate": "amplificare",
    "amplificavi": "amplificare",
    "amplificavo": "amplificare",
    "amplificazioni": "amplificazione",
    "amplificherai": "amplificare",
    "amplificheran": "amplificare",
    "amplificheranno": "amplificare",
    "amplificherebbe": "amplificare",
    "amplificherebber": "amplificare",
    "amplificherebbero": "amplificare",
    "amplificherei": "amplificare",
    "amplificheremmo": "amplificare",
    "amplificheremo": "amplificare",
    "amplifichereste": "amplificare",
    "amplificheresti": "amplificare",
    "amplificherete": "amplificare",
    "amplificherà": "amplificare",
    "amplificherò": "amplificare",
    "amplifichi": "amplificare",
    "amplifichiamo": "amplificare",
    "amplifichiate": "amplificare",
    "amplifichin": "amplificare",
    "amplifichino": "amplificare",
    "amplifico": "amplificare",
    "amplificò": "amplificare",
    "amplin": "ampliare",
    "amplino": "ampliare",
    "amplio": "ampliare",
    "ampliò": "ampliare",
    "ampolle": "ampolla",
    "ampollosa": "ampolloso",
    "ampollose": "ampolloso",
    "ampollosi": "ampolloso",
    "amputa": "amputare",
    "amputabili": "amputabile",
    "amputai": "amputare",
    "amputammo": "amputare",
    "amputan": "amputare",
    "amputando": "amputare",
    "amputano": "amputare",
    "amputante": "amputare",
    "amputanti": "amputare",
    "amputar": "amputare",
    "amputaron": "amputare",
    "amputarono": "amputare",
    "amputasse": "amputare",
    "amputasser": "amputare",
    "amputassero": "amputare",
    "amputassi": "amputare",
    "amputassimo": "amputare",
    "amputaste": "amputare",
    "amputasti": "amputare",
    "amputata": "amputare",
    "amputate": "amputare",
    "amputati": "amputare",
    "amputato": "amputare",
    "amputava": "amputare",
    "amputavamo": "amputare",
    "amputavan": "amputare",
    "amputavano": "amputare",
    "amputavate": "amputare",
    "amputavi": "amputare",
    "amputavo": "amputare",
    "amputazioni": "amputazione",
    "amputerai": "amputare",
    "amputeran": "amputare",
    "amputeranno": "amputare",
    "amputerebbe": "amputare",
    "amputerebber": "amputare",
    "amputerebbero": "amputare",
    "amputerei": "amputare",
    "amputeremmo": "amputare",
    "amputeremo": "amputare",
    "amputereste": "amputare",
    "amputeresti": "amputare",
    "amputerete": "amputare",
    "amputerà": "amputare",
    "amputerò": "amputare",
    "amputi": "amputare",
    "amputiamo": "amputare",
    "amputiate": "amputare",
    "amputin": "amputare",
    "amputino": "amputare",
    "amputo": "amputare",
    "amputò": "amputare",
    "amuleti": "amuleto",
    "amò": "amare",
    "anabbaglianti": "anabbagliante",
    "anabolizzanti": "anabolizzante",
    "anacolutica": "anacolutico",
    "anacolutiche": "anacolutico",
    "anacolutici": "anacolutico",
    "anacronismi": "anacronismo",
    "anacronistica": "anacronistico",
    "anacronistiche": "anacronistico",
    "anacronistici": "anacronistico",
    "anagrafi": "anagrafe",
    "anagrafica": "anagrafico",
    "anagrafiche": "anagrafico",
    "anagrafici": "anagrafico",
    "anagramma": "anagrammare",
    "anagrammai": "anagrammare",
    "anagrammammo": "anagrammare",
    "anagramman": "anagrammare",
    "anagrammando": "anagrammare",
    "anagrammano": "anagrammare",
    "anagrammante": "anagrammare",
    "anagrammanti": "anagrammare",
    "anagrammar": "anagrammare",
    "anagrammaron": "anagrammare",
    "anagrammarono": "anagrammare",
    "anagrammasse": "anagrammare",
    "anagrammasser": "anagrammare",
    "anagrammassero": "anagrammare",
    "anagrammassi": "anagrammare",
    "anagrammassimo": "anagrammare",
    "anagrammaste": "anagrammare",
    "anagrammasti": "anagrammare",
    "anagrammata": "anagrammare",
    "anagrammate": "anagrammare",
    "anagrammati": "anagrammare",
    "anagrammato": "anagrammare",
    "anagrammava": "anagrammare",
    "anagrammavamo": "anagrammare",
    "anagrammavan": "anagrammare",
    "anagrammavano": "anagrammare",
    "anagrammavate": "anagrammare",
    "anagrammavi": "anagrammare",
    "anagrammavo": "anagrammare",
    "anagrammerai": "anagrammare",
    "anagrammeran": "anagrammare",
    "anagrammeranno": "anagrammare",
    "anagrammerebbe": "anagrammare",
    "anagrammerebber": "anagrammare",
    "anagrammerebbero": "anagrammare",
    "anagrammerei": "anagrammare",
    "anagrammeremmo": "anagrammare",
    "anagrammeremo": "anagrammare",
    "anagrammereste": "anagrammare",
    "anagrammeresti": "anagrammare",
    "anagrammerete": "anagrammare",
    "anagrammerà": "anagrammare",
    "anagrammerò": "anagrammare",
    "anagrammi": "anagrammare",
    "anagrammiamo": "anagrammare",
    "anagrammiate": "anagrammare",
    "anagrammin": "anagrammare",
    "anagrammino": "anagrammare",
    "anagrammo": "anagrammare",
    "anagrammò": "anagrammare",
    "analcolica": "analcolico",
    "analcoliche": "analcolico",
    "analcolici": "analcolico",
    "analfabete": "analfabeta",
    "analfabeti": "analfabeta",
    "analfabetismi": "analfabetismo",
    "analgesica": "analgesico",
    "analgesiche": "analgesico",
    "analgesici": "analgesico",
    "anali": "anale",
    "analiste": "analista",
    "analisti": "analista",
    "analitica": "analitico",
    "analitiche": "analitico",
    "analitici": "analitico",
    "analizza": "analizzare",
    "analizzabili": "analizzabile",
    "analizzai": "analizzare",
    "analizzammo": "analizzare",
    "analizzan": "analizzare",
    "analizzando": "analizzare",
    "analizzano": "analizzare",
    "analizzante": "analizzare",
    "analizzanti": "analizzare",
    "analizzar": "analizzare",
    "analizzaron": "analizzare",
    "analizzarono": "analizzare",
    "analizzasse": "analizzare",
    "analizzasser": "analizzare",
    "analizzassero": "analizzare",
    "analizzassi": "analizzare",
    "analizzassimo": "analizzare",
    "analizzaste": "analizzare",
    "analizzasti": "analizzare",
    "analizzata": "analizzare",
    "analizzate": "analizzare",
    "analizzati": "analizzare",
    "analizzato": "analizzare",
    "analizzava": "analizzare",
    "analizzavamo": "analizzare",
    "analizzavan": "analizzare",
    "analizzavano": "analizzare",
    "analizzavate": "analizzare",
    "analizzavi": "analizzare",
    "analizzavo": "analizzare",
    "analizzerai": "analizzare",
    "analizzeran": "analizzare",
    "analizzeranno": "analizzare",
    "analizzerebbe": "analizzare",
    "analizzerebber": "analizzare",
    "analizzerebbero": "analizzare",
    "analizzerei": "analizzare",
    "analizzeremmo": "analizzare",
    "analizzeremo": "analizzare",
    "analizzereste": "analizzare",
    "analizzeresti": "analizzare",
    "analizzerete": "analizzare",
    "analizzerà": "analizzare",
    "analizzerò": "analizzare",
    "analizzi": "analizzare",
    "analizziamo": "analizzare",
    "analizziate": "analizzare",
    "analizzin": "analizzare",
    "analizzino": "analizzare",
    "analizzo": "analizzare",
    "analizzò": "analizzare",
    "analoga": "analogo",
    "analoghe": "analogo",
    "analoghi": "analogo",
    "analogica": "analogico",
    "analogiche": "analogico",
    "analogici": "analogico",
    "analogie": "analogia",
    "anarchica": "anarchico",
    "anarchiche": "anarchico",
    "anarchicheggianti": "anarchicheggiante",
    "anarchici": "anarchico",
    "anarchie": "anarchia",
    "anarcoidi": "anarcoide",
    "anastomizza": "anastomizzare",
    "anastomizzai": "anastomizzare",
    "anastomizzammo": "anastomizzare",
    "anastomizzan": "anastomizzare",
    "anastomizzando": "anastomizzare",
    "anastomizzano": "anastomizzare",
    "anastomizzante": "anastomizzare",
    "anastomizzanti": "anastomizzare",
    "anastomizzar": "anastomizzare",
    "anastomizzaron": "anastomizzare",
    "anastomizzarono": "anastomizzare",
    "anastomizzasse": "anastomizzare",
    "anastomizzasser": "anastomizzare",
    "anastomizzassero": "anastomizzare",
    "anastomizzassi": "anastomizzare",
    "anastomizzassimo": "anastomizzare",
    "anastomizzaste": "anastomizzare",
    "anastomizzasti": "anastomizzare",
    "anastomizzata": "anastomizzare",
    "anastomizzate": "anastomizzare",
    "anastomizzati": "anastomizzare",
    "anastomizzato": "anastomizzare",
    "anastomizzava": "anastomizzare",
    "anastomizzavamo": "anastomizzare",
    "anastomizzavan": "anastomizzare",
    "anastomizzavano": "anastomizzare",
    "anastomizzavate": "anastomizzare",
    "anastomizzavi": "anastomizzare",
    "anastomizzavo": "anastomizzare",
    "anastomizzerai": "anastomizzare",
    "anastomizzeran": "anastomizzare",
    "anastomizzeranno": "anastomizzare",
    "anastomizzerebbe": "anastomizzare",
    "anastomizzerebber": "anastomizzare",
    "anastomizzerebbero": "anastomizzare",
    "anastomizzerei": "anastomizzare",
    "anastomizzeremmo": "anastomizzare",
    "anastomizzeremo": "anastomizzare",
    "anastomizzereste": "anastomizzare",
    "anastomizzeresti": "anastomizzare",
    "anastomizzerete": "anastomizzare",
    "anastomizzerà": "anastomizzare",
    "anastomizzerò": "anastomizzare",
    "anastomizzi": "anastomizzare",
    "anastomizziamo": "anastomizzare",
    "anastomizziate": "anastomizzare",
    "anastomizzin": "anastomizzare",
    "anastomizzino": "anastomizzare",
    "anastomizzo": "anastomizzare",
    "anastomizzò": "anastomizzare",
    "anatemi": "anatema",
    "anatemizza": "anatemizzare",
    "anatemizzai": "anatemizzare",
    "anatemizzammo": "anatemizzare",
    "anatemizzan": "anatemizzare",
    "anatemizzando": "anatemizzare",
    "anatemizzano": "anatemizzare",
    "anatemizzante": "anatemizzare",
    "anatemizzanti": "anatemizzare",
    "anatemizzar": "anatemizzare",
    "anatemizzaron": "anatemizzare",
    "anatemizzarono": "anatemizzare",
    "anatemizzasse": "anatemizzare",
    "anatemizzasser": "anatemizzare",
    "anatemizzassero": "anatemizzare",
    "anatemizzassi": "anatemizzare",
    "anatemizzassimo": "anatemizzare",
    "anatemizzaste": "anatemizzare",
    "anatemizzasti": "anatemizzare",
    "anatemizzata": "anatemizzare",
    "anatemizzate": "anatemizzare",
    "anatemizzati": "anatemizzare",
    "anatemizzato": "anatemizzare",
    "anatemizzava": "anatemizzare",
    "anatemizzavamo": "anatemizzare",
    "anatemizzavan": "anatemizzare",
    "anatemizzavano": "anatemizzare",
    "anatemizzavate": "anatemizzare",
    "anatemizzavi": "anatemizzare",
    "anatemizzavo": "anatemizzare",
    "anatemizzerai": "anatemizzare",
    "anatemizzeran": "anatemizzare",
    "anatemizzeranno": "anatemizzare",
    "anatemizzerebbe": "anatemizzare",
    "anatemizzerebber": "anatemizzare",
    "anatemizzerebbero": "anatemizzare",
    "anatemizzerei": "anatemizzare",
    "anatemizzeremmo": "anatemizzare",
    "anatemizzeremo": "anatemizzare",
    "anatemizzereste": "anatemizzare",
    "anatemizzeresti": "anatemizzare",
    "anatemizzerete": "anatemizzare",
    "anatemizzerà": "anatemizzare",
    "anatemizzerò": "anatemizzare",
    "anatemizzi": "anatemizzare",
    "anatemizziamo": "anatemizzare",
    "anatemizziate": "anatemizzare",
    "anatemizzin": "anatemizzare",
    "anatemizzino": "anatemizzare",
    "anatemizzo": "anatemizzare",
    "anatemizzò": "anatemizzare",
    "anatomica": "anatomico",
    "anatomiche": "anatomico",
    "anatomici": "anatomico",
    "anatomie": "anatomia",
    "anatomizza": "anatomizzare",
    "anatomizzai": "anatomizzare",
    "anatomizzammo": "anatomizzare",
    "anatomizzan": "anatomizzare",
    "anatomizzando": "anatomizzare",
    "anatomizzano": "anatomizzare",
    "anatomizzante": "anatomizzare",
    "anatomizzanti": "anatomizzare",
    "anatomizzar": "anatomizzare",
    "anatomizzaron": "anatomizzare",
    "anatomizzarono": "anatomizzare",
    "anatomizzasse": "anatomizzare",
    "anatomizzasser": "anatomizzare",
    "anatomizzassero": "anatomizzare",
    "anatomizzassi": "anatomizzare",
    "anatomizzassimo": "anatomizzare",
    "anatomizzaste": "anatomizzare",
    "anatomizzasti": "anatomizzare",
    "anatomizzata": "anatomizzare",
    "anatomizzate": "anatomizzare",
    "anatomizzati": "anatomizzare",
    "anatomizzato": "anatomizzare",
    "anatomizzava": "anatomizzare",
    "anatomizzavamo": "anatomizzare",
    "anatomizzavan": "anatomizzare",
    "anatomizzavano": "anatomizzare",
    "anatomizzavate": "anatomizzare",
    "anatomizzavi": "anatomizzare",
    "anatomizzavo": "anatomizzare",
    "anatomizzerai": "anatomizzare",
    "anatomizzeran": "anatomizzare",
    "anatomizzeranno": "anatomizzare",
    "anatomizzerebbe": "anatomizzare",
    "anatomizzerebber": "anatomizzare",
    "anatomizzerebbero": "anatomizzare",
    "anatomizzerei": "anatomizzare",
    "anatomizzeremmo": "anatomizzare",
    "anatomizzeremo": "anatomizzare",
    "anatomizzereste": "anatomizzare",
    "anatomizzeresti": "anatomizzare",
    "anatomizzerete": "anatomizzare",
    "anatomizzerà": "anatomizzare",
    "anatomizzerò": "anatomizzare",
    "anatomizzi": "anatomizzare",
    "anatomizziamo": "anatomizzare",
    "anatomizziate": "anatomizzare",
    "anatomizzin": "anatomizzare",
    "anatomizzino": "anatomizzare",
    "anatomizzo": "anatomizzare",
    "anatomizzò": "anatomizzare",
    "anatomopatologi": "anatomopatologo",
    "anatre": "anatra",
    "anatroccoli": "anatroccolo",
    "ancelle": "ancella",
    "ancestrali": "ancestrale",
    "ancheggerai": "ancheggiare",
    "ancheggeran": "ancheggiare",
    "ancheggeranno": "ancheggiare",
    "ancheggerebbe": "ancheggiare",
    "ancheggerebber": "ancheggiare",
    "ancheggerebbero": "ancheggiare",
    "ancheggerei": "ancheggiare",
    "ancheggeremmo": "ancheggiare",
    "ancheggeremo": "ancheggiare",
    "ancheggereste": "ancheggiare",
    "ancheggeresti": "ancheggiare",
    "ancheggerete": "ancheggiare",
    "ancheggerà": "ancheggiare",
    "ancheggerò": "ancheggiare",
    "ancheggi": "ancheggiare",
    "ancheggia": "ancheggiare",
    "ancheggiai": "ancheggiare",
    "ancheggiammo": "ancheggiare",
    "ancheggiamo": "ancheggiare",
    "ancheggian": "ancheggiare",
    "ancheggiando": "ancheggiare",
    "ancheggiano": "ancheggiare",
    "ancheggiante": "ancheggiare",
    "ancheggianti": "ancheggiare",
    "ancheggiar": "ancheggiare",
    "ancheggiaron": "ancheggiare",
    "ancheggiarono": "ancheggiare",
    "ancheggiasse": "ancheggiare",
    "ancheggiasser": "ancheggiare",
    "ancheggiassero": "ancheggiare",
    "ancheggiassi": "ancheggiare",
    "ancheggiassimo": "ancheggiare",
    "ancheggiaste": "ancheggiare",
    "ancheggiasti": "ancheggiare",
    "ancheggiata": "ancheggiare",
    "ancheggiate": "ancheggiare",
    "ancheggiati": "ancheggiare",
    "ancheggiato": "ancheggiare",
    "ancheggiava": "ancheggiare",
    "ancheggiavamo": "ancheggiare",
    "ancheggiavan": "ancheggiare",
    "ancheggiavano": "ancheggiare",
    "ancheggiavate": "ancheggiare",
    "ancheggiavi": "ancheggiare",
    "ancheggiavo": "ancheggiare",
    "ancheggin": "ancheggiare",
    "ancheggino": "ancheggiare",
    "ancheggio": "ancheggiare",
    "ancheggiò": "ancheggiare",
    "anchilosa": "anchilosare",
    "anchilosai": "anchilosare",
    "anchilosammo": "anchilosare",
    "anchilosan": "anchilosare",
    "anchilosando": "anchilosare",
    "anchilosano": "anchilosare",
    "anchilosante": "anchilosare",
    "anchilosanti": "anchilosare",
    "anchilosar": "anchilosare",
    "anchilosaron": "anchilosare",
    "anchilosarono": "anchilosare",
    "anchilosasse": "anchilosare",
    "anchilosasser": "anchilosare",
    "anchilosassero": "anchilosare",
    "anchilosassi": "anchilosare",
    "anchilosassimo": "anchilosare",
    "anchilosaste": "anchilosare",
    "anchilosasti": "anchilosare",
    "anchilosata": "anchilosato",
    "anchilosate": "anchilosato",
    "anchilosati": "anchilosato",
    "anchilosato": "anchilosare",
    "anchilosava": "anchilosare",
    "anchilosavamo": "anchilosare",
    "anchilosavan": "anchilosare",
    "anchilosavano": "anchilosare",
    "anchilosavate": "anchilosare",
    "anchilosavi": "anchilosare",
    "anchilosavo": "anchilosare",
    "anchiloserai": "anchilosare",
    "anchiloseran": "anchilosare",
    "anchiloseranno": "anchilosare",
    "anchiloserebbe": "anchilosare",
    "anchiloserebber": "anchilosare",
    "anchiloserebbero": "anchilosare",
    "anchiloserei": "anchilosare",
    "anchiloseremmo": "anchilosare",
    "anchiloseremo": "anchilosare",
    "anchilosereste": "anchilosare",
    "anchiloseresti": "anchilosare",
    "anchiloserete": "anchilosare",
    "anchiloserà": "anchilosare",
    "anchiloserò": "anchilosare",
    "anchilosi": "anchilosare",
    "anchilosiamo": "anchilosare",
    "anchilosiate": "anchilosare",
    "anchilosin": "anchilosare",
    "anchilosino": "anchilosare",
    "anchiloso": "anchilosare",
    "anchilosò": "anchilosare",
    "anchormen": "anchorman",
    "ancillari": "ancillare",
    "anconetana": "anconetano",
    "anconetane": "anconetano",
    "anconetani": "anconetano",
    "ancora": "ancorare",
    "ancoraggi": "ancoraggio",
    "ancorai": "ancorare",
    "ancorammo": "ancorare",
    "ancoran": "ancorare",
    "ancorando": "ancorare",
    "ancorano": "ancorare",
    "ancorante": "ancorare",
    "ancoranti": "ancorare",
    "ancorar": "ancorare",
    "ancoraron": "ancorare",
    "ancorarono": "ancorare",
    "ancorasse": "ancorare",
    "ancorasser": "ancorare",
    "ancorassero": "ancorare",
    "ancorassi": "ancorare",
    "ancorassimo": "ancorare",
    "ancoraste": "ancorare",
    "ancorasti": "ancorare",
    "ancorata": "ancorare",
    "ancorate": "ancorare",
    "ancorati": "ancorare",
    "ancorato": "ancorare",
    "ancorava": "ancorare",
    "ancoravamo": "ancorare",
    "ancoravan": "ancorare",
    "ancoravano": "ancorare",
    "ancoravate": "ancorare",
    "ancoravi": "ancorare",
    "ancoravo": "ancorare",
    "ancorerai": "ancorare",
    "ancoreran": "ancorare",
    "ancoreranno": "ancorare",
    "ancorerebbe": "ancorare",
    "ancorerebber": "ancorare",
    "ancorerebbero": "ancorare",
    "ancorerei": "ancorare",
    "ancoreremmo": "ancorare",
    "ancoreremo": "ancorare",
    "ancorereste": "ancorare",
    "ancoreresti": "ancorare",
    "ancorerete": "ancorare",
    "ancorerà": "ancorare",
    "ancorerò": "ancorare",
    "ancori": "ancorare",
    "ancoriamo": "ancorare",
    "ancoriate": "ancorare",
    "ancorin": "ancorare",
    "ancorino": "ancorare",
    "ancoro": "ancorare",
    "ancorò": "ancorare",
    "andai": "andare",
    "andalusi": "andaluso",
    "andamenti": "andamento",
    "andammo": "andare",
    "andando": "andare",
    "andante": "andare",
    "andanti": "andare",
    "andar": "andare",
    "andaron": "andare",
    "andarono": "andare",
    "andasse": "andare",
    "andasser": "andare",
    "andassero": "andare",
    "andassi": "andare",
    "andassimo": "andare",
    "andaste": "andare",
    "andasti": "andare",
    "andata": "andato",
    "andate": "andato",
    "andati": "andato",
    "andato": "andare",
    "andature": "andatura",
    "andava": "andare",
    "andavamo": "andare",
    "andavan": "andare",
    "andavano": "andare",
    "andavate": "andare",
    "andavi": "andare",
    "andavo": "andare",
    "andazzi": "andazzo",
    "andiamo": "andare",
    "andiate": "andare",
    "andina": "andino",
    "andine": "andino",
    "andini": "andino",
    "anditi": "andito",
    "andrai": "andare",
    "andran": "andare",
    "andranno": "andare",
    "andrebbe": "andare",
    "andrebber": "andare",
    "andrebbero": "andare",
    "andrei": "andare",
    "andremmo": "andare",
    "andremo": "andare",
    "andreottesca": "andreottesco",
    "andreottesche": "andreottesco",
    "andreotteschi": "andreottesco",
    "andreottian-craxiste": "andreottian-craxista",
    "andreottian-craxisti": "andreottian-craxista",
    "andreottian-repubblicana": "andreottian-repubblicano",
    "andreottian-repubblicane": "andreottian-repubblicano",
    "andreottian-repubblicani": "andreottian-repubblicano",
    "andreottiana": "andreottiano",
    "andreottiane": "andreottiano",
    "andreottiani": "andreottiano",
    "andreste": "andare",
    "andresti": "andare",
    "andrete": "andare",
    "androgina": "androgino",
    "androgine": "androgino",
    "androgini": "androgino",
    "andrologi": "andrologo",
    "androni": "androne",
    "andropoviana": "andropoviano",
    "andropoviane": "andropoviano",
    "andropoviani": "andropoviano",
    "andrà": "andare",
    "andrò": "andare",
    "andò": "andare",
    "aneddoti": "aneddoto",
    "anedottica": "anedottico",
    "anedottiche": "anedottico",
    "anedottici": "anedottico",
    "anela": "anelare",
    "anelai": "anelare",
    "anelammo": "anelare",
    "anelan": "anelare",
    "anelando": "anelare",
    "anelano": "anelare",
    "anelante": "anelare",
    "anelanti": "anelare",
    "anelar": "anelare",
    "anelaron": "anelare",
    "anelarono": "anelare",
    "anelasse": "anelare",
    "anelasser": "anelare",
    "anelassero": "anelare",
    "anelassi": "anelare",
    "anelassimo": "anelare",
    "anelaste": "anelare",
    "anelasti": "anelare",
    "anelastica": "anelastico",
    "anelastiche": "anelastico",
    "anelastici": "anelastico",
    "anelata": "anelare",
    "anelate": "anelare",
    "anelati": "anelare",
    "anelato": "anelare",
    "anelava": "anelare",
    "anelavamo": "anelare",
    "anelavan": "anelare",
    "anelavano": "anelare",
    "anelavate": "anelare",
    "anelavi": "anelare",
    "anelavo": "anelare",
    "anelerai": "anelare",
    "aneleran": "anelare",
    "aneleranno": "anelare",
    "anelerebbe": "anelare",
    "anelerebber": "anelare",
    "anelerebbero": "anelare",
    "anelerei": "anelare",
    "aneleremmo": "anelare",
    "aneleremo": "anelare",
    "anelereste": "anelare",
    "aneleresti": "anelare",
    "anelerete": "anelare",
    "anelerà": "anelare",
    "anelerò": "anelare",
    "aneli": "anelare",
    "aneliamo": "anelare",
    "aneliate": "anelare",
    "anelin": "anelare",
    "anelino": "anelare",
    "aneliti": "anelito",
    "anelli": "anello",
    "anellini": "anellino",
    "anelo": "anelare",
    "anelò": "anelare",
    "anemica": "anemico",
    "anemiche": "anemico",
    "anemici": "anemico",
    "anemie": "anemia",
    "anestesie": "anestesia",
    "anestesisti": "anestesista",
    "anestetica": "anestetico",
    "anestetiche": "anestetico",
    "anestetici": "anestetico",
    "anestetizza": "anestetizzare",
    "anestetizzai": "anestetizzare",
    "anestetizzammo": "anestetizzare",
    "anestetizzan": "anestetizzare",
    "anestetizzando": "anestetizzare",
    "anestetizzano": "anestetizzare",
    "anestetizzante": "anestetizzare",
    "anestetizzanti": "anestetizzare",
    "anestetizzar": "anestetizzare",
    "anestetizzaron": "anestetizzare",
    "anestetizzarono": "anestetizzare",
    "anestetizzasse": "anestetizzare",
    "anestetizzasser": "anestetizzare",
    "anestetizzassero": "anestetizzare",
    "anestetizzassi": "anestetizzare",
    "anestetizzassimo": "anestetizzare",
    "anestetizzaste": "anestetizzare",
    "anestetizzasti": "anestetizzare",
    "anestetizzata": "anestetizzare",
    "anestetizzate": "anestetizzare",
    "anestetizzati": "anestetizzare",
    "anestetizzato": "anestetizzare",
    "anestetizzava": "anestetizzare",
    "anestetizzavamo": "anestetizzare",
    "anestetizzavan": "anestetizzare",
    "anestetizzavano": "anestetizzare",
    "anestetizzavate": "anestetizzare",
    "anestetizzavi": "anestetizzare",
    "anestetizzavo": "anestetizzare",
    "anestetizzerai": "anestetizzare",
    "anestetizzeran": "anestetizzare",
    "anestetizzeranno": "anestetizzare",
    "anestetizzerebbe": "anestetizzare",
    "anestetizzerebber": "anestetizzare",
    "anestetizzerebbero": "anestetizzare",
    "anestetizzerei": "anestetizzare",
    "anestetizzeremmo": "anestetizzare",
    "anestetizzeremo": "anestetizzare",
    "anestetizzereste": "anestetizzare",
    "anestetizzeresti": "anestetizzare",
    "anestetizzerete": "anestetizzare",
    "anestetizzerà": "anestetizzare",
    "anestetizzerò": "anestetizzare",
    "anestetizzi": "anestetizzare",
    "anestetizziamo": "anestetizzare",
    "anestetizziate": "anestetizzare",
    "anestetizzin": "anestetizzare",
    "anestetizzino": "anestetizzare",
    "anestetizzo": "anestetizzare",
    "anestetizzò": "anestetizzare",
    "anfana": "anfanare",
    "anfanai": "anfanare",
    "anfanammo": "anfanare",
    "anfanan": "anfanare",
    "anfanando": "anfanare",
    "anfanano": "anfanare",
    "anfanante": "anfanare",
    "anfananti": "anfanare",
    "anfanar": "anfanare",
    "anfanaron": "anfanare",
    "anfanarono": "anfanare",
    "anfanasse": "anfanare",
    "anfanasser": "anfanare",
    "anfanassero": "anfanare",
    "anfanassi": "anfanare",
    "anfanassimo": "anfanare",
    "anfanaste": "anfanare",
    "anfanasti": "anfanare",
    "anfanata": "anfanare",
    "anfanate": "anfanare",
    "anfanati": "anfanare",
    "anfanato": "anfanare",
    "anfanava": "anfanare",
    "anfanavamo": "anfanare",
    "anfanavan": "anfanare",
    "anfanavano": "anfanare",
    "anfanavate": "anfanare",
    "anfanavi": "anfanare",
    "anfanavo": "anfanare",
    "anfanerai": "anfanare",
    "anfaneran": "anfanare",
    "anfaneranno": "anfanare",
    "anfanerebbe": "anfanare",
    "anfanerebber": "anfanare",
    "anfanerebbero": "anfanare",
    "anfanerei": "anfanare",
    "anfaneremmo": "anfanare",
    "anfaneremo": "anfanare",
    "anfanereste": "anfanare",
    "anfaneresti": "anfanare",
    "anfanerete": "anfanare",
    "anfanerà": "anfanare",
    "anfanerò": "anfanare",
    "anfani": "anfanare",
    "anfaniamo": "anfanare",
    "anfaniate": "anfanare",
    "anfanin": "anfanare",
    "anfanino": "anfanare",
    "anfano": "anfanare",
    "anfanò": "anfanare",
    "anfetamine": "anfetamina",
    "anfetaminizzata": "anfetaminizzato",
    "anfetaminizzate": "anfetaminizzato",
    "anfetaminizzati": "anfetaminizzato",
    "anfibi": "anfibio",
    "anfibia": "anfibio",
    "anfibie": "anfibio",
    "anfiteatri": "anfiteatro",
    "anfitrioni": "anfitrione",
    "anfore": "anfora",
    "anfratti": "anfratto",
    "angari": "angariare",
    "angaria": "angariare",
    "angariai": "angariare",
    "angariammo": "angariare",
    "angariamo": "angariare",
    "angarian": "angariare",
    "angariando": "angariare",
    "angariano": "angariare",
    "angariante": "angariare",
    "angarianti": "angariare",
    "angariar": "angariare",
    "angariaron": "angariare",
    "angariarono": "angariare",
    "angariasse": "angariare",
    "angariasser": "angariare",
    "angariassero": "angariare",
    "angariassi": "angariare",
    "angariassimo": "angariare",
    "angariaste": "angariare",
    "angariasti": "angariare",
    "angariata": "angariare",
    "angariate": "angariare",
    "angariati": "angariare",
    "angariato": "angariare",
    "angariava": "angariare",
    "angariavamo": "angariare",
    "angariavan": "angariare",
    "angariavano": "angariare",
    "angariavate": "angariare",
    "angariavi": "angariare",
    "angariavo": "angariare",
    "angarierai": "angariare",
    "angarieran": "angariare",
    "angarieranno": "angariare",
    "angarierebbe": "angariare",
    "angarierebber": "angariare",
    "angarierebbero": "angariare",
    "angarierei": "angariare",
    "angarieremmo": "angariare",
    "angarieremo": "angariare",
    "angariereste": "angariare",
    "angarieresti": "angariare",
    "angarierete": "angariare",
    "angarierà": "angariare",
    "angarierò": "angariare",
    "angarin": "angariare",
    "angarino": "angariare",
    "angario": "angariare",
    "angariò": "angariare",
    "angeli": "angelo",
    "angelica": "angelico",
    "angeliche": "angelico",
    "angelici": "angelico",
    "angherie": "angheria",
    "angioletti": "angioletto",
    "angiomi": "angioma",
    "angiporti": "angiporto",
    "anglicana": "anglicano",
    "anglicane": "anglicano",
    "anglicani": "anglicano",
    "anglicismi": "anglicismo",
    "anglicizza": "anglicizzare",
    "anglicizzai": "anglicizzare",
    "anglicizzammo": "anglicizzare",
    "anglicizzan": "anglicizzare",
    "anglicizzando": "anglicizzare",
    "anglicizzano": "anglicizzare",
    "anglicizzante": "anglicizzare",
    "anglicizzanti": "anglicizzare",
    "anglicizzar": "anglicizzare",
    "anglicizzaron": "anglicizzare",
    "anglicizzarono": "anglicizzare",
    "anglicizzasse": "anglicizzare",
    "anglicizzasser": "anglicizzare",
    "anglicizzassero": "anglicizzare",
    "anglicizzassi": "anglicizzare",
    "anglicizzassimo": "anglicizzare",
    "anglicizzaste": "anglicizzare",
    "anglicizzasti": "anglicizzare",
    "anglicizzata": "anglicizzare",
    "anglicizzate": "anglicizzare",
    "anglicizzati": "anglicizzare",
    "anglicizzato": "anglicizzare",
    "anglicizzava": "anglicizzare",
    "anglicizzavamo": "anglicizzare",
    "anglicizzavan": "anglicizzare",
    "anglicizzavano": "anglicizzare",
    "anglicizzavate": "anglicizzare",
    "anglicizzavi": "anglicizzare",
    "anglicizzavo": "anglicizzare",
    "anglicizzerai": "anglicizzare",
    "anglicizzeran": "anglicizzare",
    "anglicizzeranno": "anglicizzare",
    "anglicizzerebbe": "anglicizzare",
    "anglicizzerebber": "anglicizzare",
    "anglicizzerebbero": "anglicizzare",
    "anglicizzerei": "anglicizzare",
    "anglicizzeremmo": "anglicizzare",
    "anglicizzeremo": "anglicizzare",
    "anglicizzereste": "anglicizzare",
    "anglicizzeresti": "anglicizzare",
    "anglicizzerete": "anglicizzare",
    "anglicizzerà": "anglicizzare",
    "anglicizzerò": "anglicizzare",
    "anglicizzi": "anglicizzare",
    "anglicizziamo": "anglicizzare",
    "anglicizziate": "anglicizzare",
    "anglicizzin": "anglicizzare",
    "anglicizzino": "anglicizzare",
    "anglicizzo": "anglicizzare",
    "anglicizzò": "anglicizzare",
    "anglisti": "anglista",
    "anglo-americana": "anglo-americano",
    "anglo-americane": "anglo-americano",
    "anglo-americani": "anglo-americano",
    "anglo-australiana": "anglo-australiano",
    "anglo-australiane": "anglo-australiano",
    "anglo-australiani": "anglo-australiano",
    "anglo-caraibica": "anglo-caraibico",
    "anglo-caraibiche": "anglo-caraibico",
    "anglo-caraibici": "anglo-caraibico",
    "anglo-cinesi": "anglo-cinese",
    "anglo-egiziana": "anglo-egiziano",
    "anglo-egiziane": "anglo-egiziano",
    "anglo-egiziani": "anglo-egiziano",
    "anglo-francesi": "anglo-francese",
    "anglo-franco-americana": "anglo-franco-americano",
    "anglo-franco-americane": "anglo-franco-americano",
    "anglo-franco-americani": "anglo-franco-americano",
    "anglo-giapponesi": "anglo-giapponese",
    "anglo-indiana": "anglo-indiano",
    "anglo-indiane": "anglo-indiano",
    "anglo-indiani": "anglo-indiano",
    "anglo-iraniana": "anglo-iraniano",
    "anglo-iraniane": "anglo-iraniano",
    "anglo-iraniani": "anglo-iraniano",
    "anglo-irlandesi": "anglo-irlandese",
    "anglo-israeliana": "anglo-israeliano",
    "anglo-israeliane": "anglo-israeliano",
    "anglo-israeliani": "anglo-israeliano",
    "anglo-italiana": "anglo-italiano",
    "anglo-italiane": "anglo-italiano",
    "anglo-italiani": "anglo-italiano",
    "anglo-olandesi": "anglo-olandese",
    "anglo-pakistana": "anglo-pakistano",
    "anglo-pakistane": "anglo-pakistano",
    "anglo-pakistani": "anglo-pakistano",
    "anglo-palestinesi": "anglo-palestinese",
    "anglo-russa": "anglo-russo",
    "anglo-russe": "anglo-russo",
    "anglo-russi": "anglo-russo",
    "anglo-sassoni": "anglo-sassone",
    "anglo-sovietica": "anglo-sovietico",
    "anglo-sovietiche": "anglo-sovietico",
    "anglo-sovietici": "anglo-sovietico",
    "anglo-tedesca": "anglo-tedesco",
    "anglo-tedesche": "anglo-tedesco",
    "anglo-tedeschi": "anglo-tedesco",
    "angloamericana": "angloamericano",
    "angloamericane": "angloamericano",
    "angloamericani": "angloamericano",
    "anglofila": "anglofilo",
    "anglofile": "anglofilo",
    "anglofili": "anglofilo",
    "anglofona": "anglofono",
    "anglofone": "anglofono",
    "anglofoni": "anglofono",
    "anglogiamaicana": "anglogiamaicano",
    "anglogiamaicane": "anglogiamaicano",
    "anglogiamaicani": "anglogiamaicano",
    "anglogiapponesi": "anglogiapponese",
    "angloindiana": "angloindiano",
    "angloindiane": "angloindiano",
    "angloindiani": "angloindiano",
    "angloitaliana": "angloitaliano",
    "angloitaliane": "angloitaliano",
    "angloitaliani": "angloitaliano",
    "anglomani": "anglomane",
    "anglonorvegesi": "anglonorvegese",
    "anglosassoni": "anglosassone",
    "anglosovietica": "anglosovietico",
    "anglosovietiche": "anglosovietico",
    "anglosovietici": "anglosovietico",
    "anglossassoni": "anglossassone",
    "anglotedesca": "anglotedesco",
    "anglotedesche": "anglotedesco",
    "anglotedeschi": "anglotedesco",
    "angola": "angolare",
    "angolai": "angolare",
    "angolammo": "angolare",
    "angolan": "angolare",
    "angolana": "angolano",
    "angolando": "angolare",
    "angolane": "angolano",
    "angolani": "angolano",
    "angolano": "angolare",
    "angolante": "angolare",
    "angolanti": "angolare",
    "angolar": "angolare",
    "angolari": "angolare",
    "angolaron": "angolare",
    "angolarono": "angolare",
    "angolasse": "angolare",
    "angolasser": "angolare",
    "angolassero": "angolare",
    "angolassi": "angolare",
    "angolassimo": "angolare",
    "angolaste": "angolare",
    "angolasti": "angolare",
    "angolata": "angolare",
    "angolate": "angolare",
    "angolati": "angolare",
    "angolato": "angolare",
    "angolature": "angolatura",
    "angolava": "angolare",
    "angolavamo": "angolare",
    "angolavan": "angolare",
    "angolavano": "angolare",
    "angolavate": "angolare",
    "angolavi": "angolare",
    "angolavo": "angolare",
    "angolazioni": "angolazione",
    "angolerai": "angolare",
    "angoleran": "angolare",
    "angoleranno": "angolare",
    "angolerebbe": "angolare",
    "angolerebber": "angolare",
    "angolerebbero": "angolare",
    "angolerei": "angolare",
    "angoleremmo": "angolare",
    "angoleremo": "angolare",
    "angolereste": "angolare",
    "angoleresti": "angolare",
    "angolerete": "angolare",
    "angolerà": "angolare",
    "angolerò": "angolare",
    "angoletti": "angoletto",
    "angoli": "angolo",
    "angoliamo": "angolare",
    "angoliate": "angolare",
    "angolin": "angolare",
    "angolini": "angolino",
    "angolino": "angolare",
    "angolo": "angolare",
    "angolosa": "angoloso",
    "angolose": "angoloso",
    "angolosi": "angoloso",
    "angolò": "angolare",
    "angosce": "angoscia",
    "angoscerai": "angosciare",
    "angosceran": "angosciare",
    "angosceranno": "angosciare",
    "angoscerebbe": "angosciare",
    "angoscerebber": "angosciare",
    "angoscerebbero": "angosciare",
    "angoscerei": "angosciare",
    "angosceremmo": "angosciare",
    "angosceremo": "angosciare",
    "angoscereste": "angosciare",
    "angosceresti": "angosciare",
    "angoscerete": "angosciare",
    "angoscerà": "angosciare",
    "angoscerò": "angosciare",
    "angosci": "angosciare",
    "angoscia": "angosciare",
    "angosciai": "angosciare",
    "angosciammo": "angosciare",
    "angosciamo": "angosciare",
    "angoscian": "angosciare",
    "angosciando": "angosciare",
    "angosciano": "angosciare",
    "angosciante": "angosciare",
    "angoscianti": "angosciare",
    "angosciar": "angosciare",
    "angosciaron": "angosciare",
    "angosciarono": "angosciare",
    "angosciasse": "angosciare",
    "angosciasser": "angosciare",
    "angosciassero": "angosciare",
    "angosciassi": "angosciare",
    "angosciassimo": "angosciare",
    "angosciaste": "angosciare",
    "angosciasti": "angosciare",
    "angosciata": "angosciato",
    "angosciate": "angosciato",
    "angosciati": "angosciato",
    "angosciato": "angosciare",
    "angosciava": "angosciare",
    "angosciavamo": "angosciare",
    "angosciavan": "angosciare",
    "angosciavano": "angosciare",
    "angosciavate": "angosciare",
    "angosciavi": "angosciare",
    "angosciavo": "angosciare",
    "angoscie": "angoscia",
    "angoscin": "angosciare",
    "angoscino": "angosciare",
    "angoscio": "angosciare",
    "angosciosa": "angoscioso",
    "angosciose": "angoscioso",
    "angosciosi": "angoscioso",
    "angosciò": "angosciare",
    "anguille": "anguilla",
    "angurie": "anguria",
    "angusta": "angusto",
    "anguste": "angusto",
    "angusti": "angusto",
    "angustia": "angustiare",
    "angustiai": "angustiare",
    "angustiammo": "angustiare",
    "angustiamo": "angustiare",
    "angustian": "angustiare",
    "angustiando": "angustiare",
    "angustiano": "angustiare",
    "angustiante": "angustiare",
    "angustianti": "angustiare",
    "angustiar": "angustiare",
    "angustiaron": "angustiare",
    "angustiarono": "angustiare",
    "angustiasse": "angustiare",
    "angustiasser": "angustiare",
    "angustiassero": "angustiare",
    "angustiassi": "angustiare",
    "angustiassimo": "angustiare",
    "angustiaste": "angustiare",
    "angustiasti": "angustiare",
    "angustiata": "angustiare",
    "angustiate": "angustiare",
    "angustiati": "angustiare",
    "angustiato": "angustiare",
    "angustiava": "angustiare",
    "angustiavamo": "angustiare",
    "angustiavan": "angustiare",
    "angustiavano": "angustiare",
    "angustiavate": "angustiare",
    "angustiavi": "angustiare",
    "angustiavo": "angustiare",
    "angustie": "angustia",
    "angustierai": "angustiare",
    "angustieran": "angustiare",
    "angustieranno": "angustiare",
    "angustierebbe": "angustiare",
    "angustierebber": "angustiare",
    "angustierebbero": "angustiare",
    "angustierei": "angustiare",
    "angustieremmo": "angustiare",
    "angustieremo": "angustiare",
    "angustiereste": "angustiare",
    "angustieresti": "angustiare",
    "angustierete": "angustiare",
    "angustierà": "angustiare",
    "angustierò": "angustiare",
    "angustin": "angustiare",
    "angustino": "angustiare",
    "angustio": "angustiare",
    "angustiò": "angustiare",
    "ani": "ano",
    "anidridi": "anidride",
    "anima": "animare",
    "animai": "animare",
    "animalesca": "animalesco",
    "animalesche": "animalesco",
    "animaleschi": "animalesco",
    "animaletti": "animaletto",
    "animali": "animale",
    "animalisti": "animalista",
    "animammo": "animare",
    "animan": "animare",
    "animando": "animare",
    "animano": "animare",
    "animante": "animare",
    "animanti": "animare",
    "animar": "animare",
    "animaron": "animare",
    "animarono": "animare",
    "animasse": "animare",
    "animasser": "animare",
    "animassero": "animare",
    "animassi": "animare",
    "animassimo": "animare",
    "animaste": "animare",
    "animasti": "animare",
    "animata": "animato",
    "animate": "animato",
    "animati": "animato",
    "animato": "animare",
    "animatori": "animatore",
    "animatrici": "animatrice",
    "animatronica": "animatronico",
    "animatroniche": "animatronico",
    "animatronici": "animatronico",
    "animava": "animare",
    "animavamo": "animare",
    "animavan": "animare",
    "animavano": "animare",
    "animavate": "animare",
    "animavi": "animare",
    "animavo": "animare",
    "animazioni": "animazione",
    "anime": "anima",
    "animerai": "animare",
    "animeran": "animare",
    "animeranno": "animare",
    "animerebbe": "animare",
    "animerebber": "animare",
    "animerebbero": "animare",
    "animerei": "animare",
    "animeremmo": "animare",
    "animeremo": "animare",
    "animereste": "animare",
    "animeresti": "animare",
    "animerete": "animare",
    "animerà": "animare",
    "animerò": "animare",
    "animi": "animo",
    "animiamo": "animare",
    "animiate": "animare",
    "animin": "animare",
    "animino": "animare",
    "animistica": "animistico",
    "animistiche": "animistico",
    "animistici": "animistico",
    "animo": "animare",
    "animosa": "animoso",
    "animose": "animoso",
    "animosi": "animoso",
    "animò": "animare",
    "anitre": "anitra",
    "annacqua": "annacquare",
    "annacquai": "annacquare",
    "annacquamenti": "annacquamento",
    "annacquammo": "annacquare",
    "annacquan": "annacquare",
    "annacquando": "annacquare",
    "annacquano": "annacquare",
    "annacquante": "annacquare",
    "annacquanti": "annacquare",
    "annacquar": "annacquare",
    "annacquaron": "annacquare",
    "annacquarono": "annacquare",
    "annacquasse": "annacquare",
    "annacquasser": "annacquare",
    "annacquassero": "annacquare",
    "annacquassi": "annacquare",
    "annacquassimo": "annacquare",
    "annacquaste": "annacquare",
    "annacquasti": "annacquare",
    "annacquata": "annacquare",
    "annacquate": "annacquare",
    "annacquati": "annacquare",
    "annacquato": "annacquare",
    "annacquava": "annacquare",
    "annacquavamo": "annacquare",
    "annacquavan": "annacquare",
    "annacquavano": "annacquare",
    "annacquavate": "annacquare",
    "annacquavi": "annacquare",
    "annacquavo": "annacquare",
    "annacquerai": "annacquare",
    "annacqueran": "annacquare",
    "annacqueranno": "annacquare",
    "annacquerebbe": "annacquare",
    "annacquerebber": "annacquare",
    "annacquerebbero": "annacquare",
    "annacquerei": "annacquare",
    "annacqueremmo": "annacquare",
    "annacqueremo": "annacquare",
    "annacquereste": "annacquare",
    "annacqueresti": "annacquare",
    "annacquerete": "annacquare",
    "annacquerà": "annacquare",
    "annacquerò": "annacquare",
    "annacqui": "annacquare",
    "annacquiamo": "annacquare",
    "annacquiate": "annacquare",
    "annacquin": "annacquare",
    "annacquino": "annacquare",
    "annacquo": "annacquare",
    "annacquò": "annacquare",
    "annaffi": "annaffiare",
    "annaffia": "annaffiare",
    "annaffiai": "annaffiare",
    "annaffiammo": "annaffiare",
    "annaffiamo": "annaffiare",
    "annaffian": "annaffiare",
    "annaffiando": "annaffiare",
    "annaffiano": "annaffiare",
    "annaffiante": "annaffiare",
    "annaffianti": "annaffiare",
    "annaffiar": "annaffiare",
    "annaffiaron": "annaffiare",
    "annaffiarono": "annaffiare",
    "annaffiasse": "annaffiare",
    "annaffiasser": "annaffiare",
    "annaffiassero": "annaffiare",
    "annaffiassi": "annaffiare",
    "annaffiassimo": "annaffiare",
    "annaffiaste": "annaffiare",
    "annaffiasti": "annaffiare",
    "annaffiata": "annaffiare",
    "annaffiate": "annaffiare",
    "annaffiati": "annaffiare",
    "annaffiato": "annaffiare",
    "annaffiava": "annaffiare",
    "annaffiavamo": "annaffiare",
    "annaffiavan": "annaffiare",
    "annaffiavano": "annaffiare",
    "annaffiavate": "annaffiare",
    "annaffiavi": "annaffiare",
    "annaffiavo": "annaffiare",
    "annaffierai": "annaffiare",
    "annaffieran": "annaffiare",
    "annaffieranno": "annaffiare",
    "annaffierebbe": "annaffiare",
    "annaffierebber": "annaffiare",
    "annaffierebbero": "annaffiare",
    "annaffierei": "annaffiare",
    "annaffieremmo": "annaffiare",
    "annaffieremo": "annaffiare",
    "annaffiereste": "annaffiare",
    "annaffieresti": "annaffiare",
    "annaffierete": "annaffiare",
    "annaffierà": "annaffiare",
    "annaffierò": "annaffiare",
    "annaffin": "annaffiare",
    "annaffino": "annaffiare",
    "annaffio": "annaffiare",
    "annaffiò": "annaffiare",
    "annali": "annale",
    "annaspa": "annaspare",
    "annaspai": "annaspare",
    "annaspammo": "annaspare",
    "annaspan": "annaspare",
    "annaspando": "annaspare",
    "annaspano": "annaspare",
    "annaspante": "annaspare",
    "annaspanti": "annaspare",
    "annaspar": "annaspare",
    "annasparon": "annaspare",
    "annasparono": "annaspare",
    "annaspasse": "annaspare",
    "annaspasser": "annaspare",
    "annaspassero": "annaspare",
    "annaspassi": "annaspare",
    "annaspassimo": "annaspare",
    "annaspaste": "annaspare",
    "annaspasti": "annaspare",
    "annaspata": "annaspare",
    "annaspate": "annaspare",
    "annaspati": "annaspare",
    "annaspato": "annaspare",
    "annaspava": "annaspare",
    "annaspavamo": "annaspare",
    "annaspavan": "annaspare",
    "annaspavano": "annaspare",
    "annaspavate": "annaspare",
    "annaspavi": "annaspare",
    "annaspavo": "annaspare",
    "annasperai": "annaspare",
    "annasperan": "annaspare",
    "annasperanno": "annaspare",
    "annasperebbe": "annaspare",
    "annasperebber": "annaspare",
    "annasperebbero": "annaspare",
    "annasperei": "annaspare",
    "annasperemmo": "annaspare",
    "annasperemo": "annaspare",
    "annaspereste": "annaspare",
    "annasperesti": "annaspare",
    "annasperete": "annaspare",
    "annasperà": "annaspare",
    "annasperò": "annaspare",
    "annaspi": "annaspare",
    "annaspiamo": "annaspare",
    "annaspiate": "annaspare",
    "annaspin": "annaspare",
    "annaspino": "annaspare",
    "annaspo": "annaspare",
    "annaspò": "annaspare",
    "annate": "annata",
    "annebbi": "annebbiare",
    "annebbia": "annebbiare",
    "annebbiai": "annebbiare",
    "annebbiammo": "annebbiare",
    "annebbiamo": "annebbiare",
    "annebbian": "annebbiare",
    "annebbiando": "annebbiare",
    "annebbiano": "annebbiare",
    "annebbiante": "annebbiare",
    "annebbianti": "annebbiare",
    "annebbiar": "annebbiare",
    "annebbiaron": "annebbiare",
    "annebbiarono": "annebbiare",
    "annebbiasse": "annebbiare",
    "annebbiasser": "annebbiare",
    "annebbiassero": "annebbiare",
    "annebbiassi": "annebbiare",
    "annebbiassimo": "annebbiare",
    "annebbiaste": "annebbiare",
    "annebbiasti": "annebbiare",
    "annebbiata": "annebbiare",
    "annebbiate": "annebbiare",
    "annebbiati": "annebbiare",
    "annebbiato": "annebbiare",
    "annebbiava": "annebbiare",
    "annebbiavamo": "annebbiare",
    "annebbiavan": "annebbiare",
    "annebbiavano": "annebbiare",
    "annebbiavate": "annebbiare",
    "annebbiavi": "annebbiare",
    "annebbiavo": "annebbiare",
    "annebbierai": "annebbiare",
    "annebbieran": "annebbiare",
    "annebbieranno": "annebbiare",
    "annebbierebbe": "annebbiare",
    "annebbierebber": "annebbiare",
    "annebbierebbero": "annebbiare",
    "annebbierei": "annebbiare",
    "annebbieremmo": "annebbiare",
    "annebbieremo": "annebbiare",
    "annebbiereste": "annebbiare",
    "annebbieresti": "annebbiare",
    "annebbierete": "annebbiare",
    "annebbierà": "annebbiare",
    "annebbierò": "annebbiare",
    "annebbin": "annebbiare",
    "annebbino": "annebbiare",
    "annebbio": "annebbiare",
    "annebbiò": "annebbiare",
    "annega": "annegare",
    "annegai": "annegare",
    "annegammo": "annegare",
    "annegan": "annegare",
    "annegando": "annegare",
    "annegano": "annegare",
    "annegante": "annegare",
    "anneganti": "annegare",
    "annegar": "annegare",
    "annegaron": "annegare",
    "annegarono": "annegare",
    "annegasse": "annegare",
    "annegasser": "annegare",
    "annegassero": "annegare",
    "annegassi": "annegare",
    "annegassimo": "annegare",
    "annegaste": "annegare",
    "annegasti": "annegare",
    "annegata": "annegato",
    "annegate": "annegato",
    "annegati": "annegato",
    "annegato": "annegare",
    "annegava": "annegare",
    "annegavamo": "annegare",
    "annegavan": "annegare",
    "annegavano": "annegare",
    "annegavate": "annegare",
    "annegavi": "annegare",
    "annegavo": "annegare",
    "annegherai": "annegare",
    "annegheran": "annegare",
    "annegheranno": "annegare",
    "annegherebbe": "annegare",
    "annegherebber": "annegare",
    "annegherebbero": "annegare",
    "annegherei": "annegare",
    "annegheremmo": "annegare",
    "annegheremo": "annegare",
    "anneghereste": "annegare",
    "annegheresti": "annegare",
    "annegherete": "annegare",
    "annegherà": "annegare",
    "annegherò": "annegare",
    "anneghi": "annegare",
    "anneghiamo": "annegare",
    "anneghiate": "annegare",
    "anneghin": "annegare",
    "anneghino": "annegare",
    "annego": "annegare",
    "annegò": "annegare",
    "annera": "annerire",
    "anneran": "annerire",
    "annerano": "annerire",
    "annere": "annerire",
    "annerendo": "annerire",
    "annerente": "annerire",
    "annerenti": "annerire",
    "anneri": "annerire",
    "anneriamo": "annerire",
    "anneriate": "annerire",
    "annerii": "annerire",
    "annerimmo": "annerire",
    "annerir": "annerire",
    "annerirai": "annerire",
    "anneriran": "annerire",
    "anneriranno": "annerire",
    "annerirebbe": "annerire",
    "annerirebber": "annerire",
    "annerirebbero": "annerire",
    "annerirei": "annerire",
    "anneriremmo": "annerire",
    "anneriremo": "annerire",
    "annerireste": "annerire",
    "anneriresti": "annerire",
    "annerirete": "annerire",
    "anneriron": "annerire",
    "annerirono": "annerire",
    "annerirà": "annerire",
    "annerirò": "annerire",
    "annerisse": "annerire",
    "annerisser": "annerire",
    "annerissero": "annerire",
    "annerissi": "annerire",
    "annerissimo": "annerire",
    "anneriste": "annerire",
    "anneristi": "annerire",
    "annerita": "annerire",
    "annerite": "annerire",
    "anneriti": "annerire",
    "annerito": "annerire",
    "anneriva": "annerire",
    "annerivamo": "annerire",
    "annerivan": "annerire",
    "annerivano": "annerire",
    "annerivate": "annerire",
    "annerivi": "annerire",
    "annerivo": "annerire",
    "annero": "annerire",
    "anneron": "annerire",
    "annerono": "annerire",
    "annerì": "annerire",
    "annessa": "annesso",
    "annesse": "annesso",
    "annessi": "annesso",
    "annessioni": "annessione",
    "annetta": "annettere",
    "annettan": "annettere",
    "annettano": "annettere",
    "annette": "annettere",
    "annettei": "annettere",
    "annettemmo": "annettere",
    "annettendo": "annettere",
    "annettente": "annettere",
    "annettenti": "annettere",
    "annetter": "annettere",
    "annetterai": "annettere",
    "annetteran": "annettere",
    "annetteranno": "annettere",
    "annetterebbe": "annettere",
    "annetterebber": "annettere",
    "annetterebbero": "annettere",
    "annetterei": "annettere",
    "annetteremmo": "annettere",
    "annetteremo": "annettere",
    "annettereste": "annettere",
    "annetteresti": "annettere",
    "annetterete": "annettere",
    "annetteron": "annettere",
    "annetterono": "annettere",
    "annetterà": "annettere",
    "annetterò": "annettere",
    "annettesse": "annettere",
    "annettesser": "annettere",
    "annettessero": "annettere",
    "annettessi": "annettere",
    "annettessimo": "annettere",
    "annetteste": "annettere",
    "annettesti": "annettere",
    "annettete": "annettere",
    "annetteva": "annettere",
    "annettevamo": "annettere",
    "annettevan": "annettere",
    "annettevano": "annettere",
    "annettevate": "annettere",
    "annettevi": "annettere",
    "annettevo": "annettere",
    "annetti": "annetto",
    "annettiamo": "annettere",
    "annettiate": "annettere",
    "annetto": "annettere",
    "annetton": "annettere",
    "annettono": "annettere",
    "annettuta": "annettere",
    "annettute": "annettere",
    "annettuti": "annettere",
    "annettuto": "annettere",
    "annettè": "annettere",
    "anni": "anno",
    "annichila": "annichilire",
    "annichilai": "annichilare",
    "annichilammo": "annichilare",
    "annichilan": "annichilire",
    "annichilando": "annichilare",
    "annichilano": "annichilire",
    "annichilante": "annichilare",
    "annichilanti": "annichilare",
    "annichilar": "annichilare",
    "annichilaron": "annichilare",
    "annichilarono": "annichilare",
    "annichilasse": "annichilare",
    "annichilasser": "annichilare",
    "annichilassero": "annichilare",
    "annichilassi": "annichilare",
    "annichilassimo": "annichilare",
    "annichilaste": "annichilare",
    "annichilasti": "annichilare",
    "annichilata": "annichilare",
    "annichilate": "annichilare",
    "annichilati": "annichilare",
    "annichilato": "annichilare",
    "annichilava": "annichilare",
    "annichilavamo": "annichilare",
    "annichilavan": "annichilare",
    "annichilavano": "annichilare",
    "annichilavate": "annichilare",
    "annichilavi": "annichilare",
    "annichilavo": "annichilare",
    "annichile": "annichilire",
    "annichilendo": "annichilire",
    "annichilente": "annichilire",
    "annichilenti": "annichilire",
    "annichilerai": "annichilare",
    "annichileran": "annichilare",
    "annichileranno": "annichilare",
    "annichilerebbe": "annichilare",
    "annichilerebber": "annichilare",
    "annichilerebbero": "annichilare",
    "annichilerei": "annichilare",
    "annichileremmo": "annichilare",
    "annichileremo": "annichilare",
    "annichilereste": "annichilare",
    "annichileresti": "annichilare",
    "annichilerete": "annichilare",
    "annichilerà": "annichilare",
    "annichilerò": "annichilare",
    "annichili": "annichilire",
    "annichiliamo": "annichilire",
    "annichiliate": "annichilire",
    "annichilii": "annichilire",
    "annichilimmo": "annichilire",
    "annichilin": "annichilare",
    "annichilino": "annichilare",
    "annichilir": "annichilire",
    "annichilirai": "annichilire",
    "annichiliran": "annichilire",
    "annichiliranno": "annichilire",
    "annichilirebbe": "annichilire",
    "annichilirebber": "annichilire",
    "annichilirebbero": "annichilire",
    "annichilirei": "annichilire",
    "annichiliremmo": "annichilire",
    "annichiliremo": "annichilire",
    "annichilireste": "annichilire",
    "annichiliresti": "annichilire",
    "annichilirete": "annichilire",
    "annichiliron": "annichilire",
    "annichilirono": "annichilire",
    "annichilirà": "annichilire",
    "annichilirò": "annichilire",
    "annichilisse": "annichilire",
    "annichilisser": "annichilire",
    "annichilissero": "annichilire",
    "annichilissi": "annichilire",
    "annichilissimo": "annichilire",
    "annichiliste": "annichilire",
    "annichilisti": "annichilire",
    "annichilita": "annichilire",
    "annichilite": "annichilire",
    "annichiliti": "annichilire",
    "annichilito": "annichilire",
    "annichiliva": "annichilire",
    "annichilivamo": "annichilire",
    "annichilivan": "annichilire",
    "annichilivano": "annichilire",
    "annichilivate": "annichilire",
    "annichilivi": "annichilire",
    "annichilivo": "annichilire",
    "annichilo": "annichilire",
    "annichilon": "annichilire",
    "annichilono": "annichilire",
    "annichilì": "annichilire",
    "annichilò": "annichilare",
    "annida": "annidare",
    "annidai": "annidare",
    "annidammo": "annidare",
    "annidan": "annidare",
    "annidando": "annidare",
    "annidano": "annidare",
    "annidante": "annidare",
    "annidanti": "annidare",
    "annidar": "annidare",
    "annidaron": "annidare",
    "annidarono": "annidare",
    "annidasse": "annidare",
    "annidasser": "annidare",
    "annidassero": "annidare",
    "annidassi": "annidare",
    "annidassimo": "annidare",
    "annidaste": "annidare",
    "annidasti": "annidare",
    "annidata": "annidare",
    "annidate": "annidare",
    "annidati": "annidare",
    "annidato": "annidare",
    "annidava": "annidare",
    "annidavamo": "annidare",
    "annidavan": "annidare",
    "annidavano": "annidare",
    "annidavate": "annidare",
    "annidavi": "annidare",
    "annidavo": "annidare",
    "anniderai": "annidare",
    "annideran": "annidare",
    "annideranno": "annidare",
    "anniderebbe": "annidare",
    "anniderebber": "annidare",
    "anniderebbero": "annidare",
    "anniderei": "annidare",
    "annideremmo": "annidare",
    "annideremo": "annidare",
    "annidereste": "annidare",
    "annideresti": "annidare",
    "anniderete": "annidare",
    "anniderà": "annidare",
    "anniderò": "annidare",
    "annidi": "annidare",
    "annidiamo": "annidare",
    "annidiate": "annidare",
    "annidin": "annidare",
    "annidino": "annidare",
    "annido": "annidare",
    "annidò": "annidare",
    "annienta": "annientare",
    "annientai": "annientare",
    "annientammo": "annientare",
    "annientan": "annientare",
    "annientando": "annientare",
    "annientano": "annientare",
    "annientante": "annientare",
    "annientanti": "annientare",
    "annientar": "annientare",
    "annientaron": "annientare",
    "annientarono": "annientare",
    "annientasse": "annientare",
    "annientasser": "annientare",
    "annientassero": "annientare",
    "annientassi": "annientare",
    "annientassimo": "annientare",
    "annientaste": "annientare",
    "annientasti": "annientare",
    "annientata": "annientare",
    "annientate": "annientare",
    "annientati": "annientare",
    "annientato": "annientare",
    "annientatori": "annientatore",
    "annientatrice": "annientatore",
    "annientatrici": "annientatore",
    "annientava": "annientare",
    "annientavamo": "annientare",
    "annientavan": "annientare",
    "annientavano": "annientare",
    "annientavate": "annientare",
    "annientavi": "annientare",
    "annientavo": "annientare",
    "annienterai": "annientare",
    "annienteran": "annientare",
    "annienteranno": "annientare",
    "annienterebbe": "annientare",
    "annienterebber": "annientare",
    "annienterebbero": "annientare",
    "annienterei": "annientare",
    "annienteremmo": "annientare",
    "annienteremo": "annientare",
    "annientereste": "annientare",
    "annienteresti": "annientare",
    "annienterete": "annientare",
    "annienterà": "annientare",
    "annienterò": "annientare",
    "annienti": "annientare",
    "annientiamo": "annientare",
    "annientiate": "annientare",
    "annientin": "annientare",
    "annientino": "annientare",
    "anniento": "annientare",
    "annientò": "annientare",
    "anniversari": "anniversario",
    "annoda": "annodare",
    "annodai": "annodare",
    "annodammo": "annodare",
    "annodan": "annodare",
    "annodando": "annodare",
    "annodano": "annodare",
    "annodante": "annodare",
    "annodanti": "annodare",
    "annodar": "annodare",
    "annodaron": "annodare",
    "annodarono": "annodare",
    "annodasse": "annodare",
    "annodasser": "annodare",
    "annodassero": "annodare",
    "annodassi": "annodare",
    "annodassimo": "annodare",
    "annodaste": "annodare",
    "annodasti": "annodare",
    "annodata": "annodare",
    "annodate": "annodare",
    "annodati": "annodare",
    "annodato": "annodare",
    "annodava": "annodare",
    "annodavamo": "annodare",
    "annodavan": "annodare",
    "annodavano": "annodare",
    "annodavate": "annodare",
    "annodavi": "annodare",
    "annodavo": "annodare",
    "annoderai": "annodare",
    "annoderan": "annodare",
    "annoderanno": "annodare",
    "annoderebbe": "annodare",
    "annoderebber": "annodare",
    "annoderebbero": "annodare",
    "annoderei": "annodare",
    "annoderemmo": "annodare",
    "annoderemo": "annodare",
    "annodereste": "annodare",
    "annoderesti": "annodare",
    "annoderete": "annodare",
    "annoderà": "annodare",
    "annoderò": "annodare",
    "annodi": "annodare",
    "annodiamo": "annodare",
    "annodiate": "annodare",
    "annodin": "annodare",
    "annodino": "annodare",
    "annodo": "annodare",
    "annodò": "annodare",
    "annoi": "annoiare",
    "annoia": "annoiare",
    "annoiai": "annoiare",
    "annoiammo": "annoiare",
    "annoiamo": "annoiare",
    "annoian": "annoiare",
    "annoiando": "annoiare",
    "annoiano": "annoiare",
    "annoiante": "annoiare",
    "annoianti": "annoiare",
    "annoiar": "annoiare",
    "annoiaron": "annoiare",
    "annoiarono": "annoiare",
    "annoiasse": "annoiare",
    "annoiasser": "annoiare",
    "annoiassero": "annoiare",
    "annoiassi": "annoiare",
    "annoiassimo": "annoiare",
    "annoiaste": "annoiare",
    "annoiasti": "annoiare",
    "annoiata": "annoiato",
    "annoiate": "annoiato",
    "annoiati": "annoiato",
    "annoiato": "annoiare",
    "annoiava": "annoiare",
    "annoiavamo": "annoiare",
    "annoiavan": "annoiare",
    "annoiavano": "annoiare",
    "annoiavate": "annoiare",
    "annoiavi": "annoiare",
    "annoiavo": "annoiare",
    "annoierai": "annoiare",
    "annoieran": "annoiare",
    "annoieranno": "annoiare",
    "annoierebbe": "annoiare",
    "annoierebber": "annoiare",
    "annoierebbero": "annoiare",
    "annoierei": "annoiare",
    "annoieremmo": "annoiare",
    "annoieremo": "annoiare",
    "annoiereste": "annoiare",
    "annoieresti": "annoiare",
    "annoierete": "annoiare",
    "annoierà": "annoiare",
    "annoierò": "annoiare",
    "annoin": "annoiare",
    "annoino": "annoiare",
    "annoio": "annoiare",
    "annoiò": "annoiare",
    "annonari": "annonario",
    "annonaria": "annonario",
    "annonarie": "annonario",
    "annosa": "annoso",
    "annose": "annoso",
    "annosi": "annoso",
    "annota": "annotare",
    "annotai": "annotare",
    "annotammo": "annotare",
    "annotan": "annotare",
    "annotando": "annotare",
    "annotano": "annotare",
    "annotante": "annotare",
    "annotanti": "annotare",
    "annotar": "annotare",
    "annotaron": "annotare",
    "annotarono": "annotare",
    "annotasse": "annotare",
    "annotasser": "annotare",
    "annotassero": "annotare",
    "annotassi": "annotare",
    "annotassimo": "annotare",
    "annotaste": "annotare",
    "annotasti": "annotare",
    "annotata": "annotare",
    "annotate": "annotare",
    "annotati": "annotare",
    "annotato": "annotare",
    "annotava": "annotare",
    "annotavamo": "annotare",
    "annotavan": "annotare",
    "annotavano": "annotare",
    "annotavate": "annotare",
    "annotavi": "annotare",
    "annotavo": "annotare",
    "annotazioni": "annotazione",
    "annoterai": "annotare",
    "annoteran": "annotare",
    "annoteranno": "annotare",
    "annoterebbe": "annotare",
    "annoterebber": "annotare",
    "annoterebbero": "annotare",
    "annoterei": "annotare",
    "annoteremmo": "annotare",
    "annoteremo": "annotare",
    "annotereste": "annotare",
    "annoteresti": "annotare",
    "annoterete": "annotare",
    "annoterà": "annotare",
    "annoterò": "annotare",
    "annoti": "annotare",
    "annotiamo": "annotare",
    "annotiate": "annotare",
    "annotin": "annotare",
    "annotino": "annotare",
    "annoto": "annotare",
    "annotta": "annottare",
    "annottai": "annottare",
    "annottammo": "annottare",
    "annottan": "annottare",
    "annottando": "annottare",
    "annottano": "annottare",
    "annottante": "annottare",
    "annottanti": "annottare",
    "annottar": "annottare",
    "annottaron": "annottare",
    "annottarono": "annottare",
    "annottasse": "annottare",
    "annottasser": "annottare",
    "annottassero": "annottare",
    "annottassi": "annottare",
    "annottassimo": "annottare",
    "annottaste": "annottare",
    "annottasti": "annottare",
    "annottata": "annottare",
    "annottate": "annottare",
    "annottati": "annottare",
    "annottato": "annottare",
    "annottava": "annottare",
    "annottavamo": "annottare",
    "annottavan": "annottare",
    "annottavano": "annottare",
    "annottavate": "annottare",
    "annottavi": "annottare",
    "annottavo": "annottare",
    "annotterai": "annottare",
    "annotteran": "annottare",
    "annotteranno": "annottare",
    "annotterebbe": "annottare",
    "annotterebber": "annottare",
    "annotterebbero": "annottare",
    "annotterei": "annottare",
    "annotteremmo": "annottare",
    "annotteremo": "annottare",
    "annottereste": "annottare",
    "annotteresti": "annottare",
    "annotterete": "annottare",
    "annotterà": "annottare",
    "annotterò": "annottare",
    "annotti": "annottare",
    "annottiamo": "annottare",
    "annottiate": "annottare",
    "annottin": "annottare",
    "annottino": "annottare",
    "annotto": "annottare",
    "annottò": "annottare",
    "annotò": "annotare",
    "annovera": "annoverare",
    "annoverai": "annoverare",
    "annoverammo": "annoverare",
    "annoveran": "annoverare",
    "annoverando": "annoverare",
    "annoverano": "annoverare",
    "annoverante": "annoverare",
    "annoveranti": "annoverare",
    "annoverar": "annoverare",
    "annoveraron": "annoverare",
    "annoverarono": "annoverare",
    "annoverasse": "annoverare",
    "annoverasser": "annoverare",
    "annoverassero": "annoverare",
    "annoverassi": "annoverare",
    "annoverassimo": "annoverare",
    "annoveraste": "annoverare",
    "annoverasti": "annoverare",
    "annoverata": "annoverare",
    "annoverate": "annoverare",
    "annoverati": "annoverare",
    "annoverato": "annoverare",
    "annoverava": "annoverare",
    "annoveravamo": "annoverare",
    "annoveravan": "annoverare",
    "annoveravano": "annoverare",
    "annoveravate": "annoverare",
    "annoveravi": "annoverare",
    "annoveravo": "annoverare",
    "annovererai": "annoverare",
    "annovereran": "annoverare",
    "annovereranno": "annoverare",
    "annovererebbe": "annoverare",
    "annovererebber": "annoverare",
    "annovererebbero": "annoverare",
    "annovererei": "annoverare",
    "annovereremmo": "annoverare",
    "annovereremo": "annoverare",
    "annoverereste": "annoverare",
    "annovereresti": "annoverare",
    "annovererete": "annoverare",
    "annovererà": "annoverare",
    "annovererò": "annoverare",
    "annoveri": "annoverare",
    "annoveriamo": "annoverare",
    "annoveriate": "annoverare",
    "annoverin": "annoverare",
    "annoverino": "annoverare",
    "annovero": "annoverare",
    "annoverò": "annoverare",
    "annua": "annuo",
    "annuali": "annuale",
    "annualizza": "annualizzare",
    "annualizzai": "annualizzare",
    "annualizzammo": "annualizzare",
    "annualizzan": "annualizzare",
    "annualizzando": "annualizzare",
    "annualizzano": "annualizzare",
    "annualizzante": "annualizzare",
    "annualizzanti": "annualizzare",
    "annualizzar": "annualizzare",
    "annualizzaron": "annualizzare",
    "annualizzarono": "annualizzare",
    "annualizzasse": "annualizzare",
    "annualizzasser": "annualizzare",
    "annualizzassero": "annualizzare",
    "annualizzassi": "annualizzare",
    "annualizzassimo": "annualizzare",
    "annualizzaste": "annualizzare",
    "annualizzasti": "annualizzare",
    "annualizzata": "annualizzare",
    "annualizzate": "annualizzare",
    "annualizzati": "annualizzare",
    "annualizzato": "annualizzare",
    "annualizzava": "annualizzare",
    "annualizzavamo": "annualizzare",
    "annualizzavan": "annualizzare",
    "annualizzavano": "annualizzare",
    "annualizzavate": "annualizzare",
    "annualizzavi": "annualizzare",
    "annualizzavo": "annualizzare",
    "annualizzerai": "annualizzare",
    "annualizzeran": "annualizzare",
    "annualizzeranno": "annualizzare",
    "annualizzerebbe": "annualizzare",
    "annualizzerebber": "annualizzare",
    "annualizzerebbero": "annualizzare",
    "annualizzerei": "annualizzare",
    "annualizzeremmo": "annualizzare",
    "annualizzeremo": "annualizzare",
    "annualizzereste": "annualizzare",
    "annualizzeresti": "annualizzare",
    "annualizzerete": "annualizzare",
    "annualizzerà": "annualizzare",
    "annualizzerò": "annualizzare",
    "annualizzi": "annualizzare",
    "annualizziamo": "annualizzare",
    "annualizziate": "annualizzare",
    "annualizzin": "annualizzare",
    "annualizzino": "annualizzare",
    "annualizzo": "annualizzare",
    "annualizzò": "annualizzare",
    "annuari": "annuario",
    "annue": "annuo",
    "annuendo": "annuire",
    "annuente": "annuire",
    "annuenti": "annuire",
    "annui": "annuo",
    "annuiamo": "annuire",
    "annuiate": "annuire",
    "annuii": "annuire",
    "annuimmo": "annuire",
    "annuir": "annuire",
    "annuirai": "annuire",
    "annuiran": "annuire",
    "annuiranno": "annuire",
    "annuirebbe": "annuire",
    "annuirebber": "annuire",
    "annuirebbero": "annuire",
    "annuirei": "annuire",
    "annuiremmo": "annuire",
    "annuiremo": "annuire",
    "annuireste": "annuire",
    "annuiresti": "annuire",
    "annuirete": "annuire",
    "annuiron": "annuire",
    "annuirono": "annuire",
    "annuirà": "annuire",
    "annuirò": "annuire",
    "annuisca": "annuire",
    "annuiscan": "annuire",
    "annuiscano": "annuire",
    "annuisce": "annuire",
    "annuisci": "annuire",
    "annuisco": "annuire",
    "annuiscon": "annuire",
    "annuiscono": "annuire",
    "annuisse": "annuire",
    "annuisser": "annuire",
    "annuissero": "annuire",
    "annuissi": "annuire",
    "annuissimo": "annuire",
    "annuiste": "annuire",
    "annuisti": "annuire",
    "annuita": "annuire",
    "annuite": "annuire",
    "annuiti": "annuire",
    "annuito": "annuire",
    "annuiva": "annuire",
    "annuivamo": "annuire",
    "annuivan": "annuire",
    "annuivano": "annuire",
    "annuivate": "annuire",
    "annuivi": "annuire",
    "annuivo": "annuire",
    "annulla": "annullare",
    "annullabili": "annullabile",
    "annullai": "annullare",
    "annullamenti": "annullamento",
    "annullammo": "annullare",
    "annullan": "annullare",
    "annullando": "annullare",
    "annullano": "annullare",
    "annullante": "annullare",
    "annullanti": "annullare",
    "annullar": "annullare",
    "annullaron": "annullare",
    "annullarono": "annullare",
    "annullasse": "annullare",
    "annullasser": "annullare",
    "annullassero": "annullare",
    "annullassi": "annullare",
    "annullassimo": "annullare",
    "annullaste": "annullare",
    "annullasti": "annullare",
    "annullata": "annullare",
    "annullate": "annullare",
    "annullati": "annullare",
    "annullato": "annullare",
    "annullava": "annullare",
    "annullavamo": "annullare",
    "annullavan": "annullare",
    "annullavano": "annullare",
    "annullavate": "annullare",
    "annullavi": "annullare",
    "annullavo": "annullare",
    "annullerai": "annullare",
    "annulleran": "annullare",
    "annulleranno": "annullare",
    "annullerebbe": "annullare",
    "annullerebber": "annullare",
    "annullerebbero": "annullare",
    "annullerei": "annullare",
    "annulleremmo": "annullare",
    "annulleremo": "annullare",
    "annullereste": "annullare",
    "annulleresti": "annullare",
    "annullerete": "annullare",
    "annullerà": "annullare",
    "annullerò": "annullare",
    "annulli": "annullare",
    "annulliamo": "annullare",
    "annulliate": "annullare",
    "annullin": "annullare",
    "annullino": "annullare",
    "annullo": "annullare",
    "annullò": "annullare",
    "annuncerai": "annunciare",
    "annunceran": "annunciare",
    "annunceranno": "annunciare",
    "annuncerebbe": "annunciare",
    "annuncerebber": "annunciare",
    "annuncerebbero": "annunciare",
    "annuncerei": "annunciare",
    "annunceremmo": "annunciare",
    "annunceremo": "annunciare",
    "annuncereste": "annunciare",
    "annunceresti": "annunciare",
    "annuncerete": "annunciare",
    "annuncerà": "annunciare",
    "annuncerò": "annunciare",
    "annunci": "annuncio",
    "annuncia": "annunciare",
    "annunciai": "annunciare",
    "annunciammo": "annunciare",
    "annunciamo": "annunciare",
    "annuncian": "annunciare",
    "annunciando": "annunciare",
    "annunciano": "annunciare",
    "annunciante": "annunciare",
    "annuncianti": "annunciare",
    "annunciar": "annunciare",
    "annunciaron": "annunciare",
    "annunciarono": "annunciare",
    "annunciasse": "annunciare",
    "annunciasser": "annunciare",
    "annunciassero": "annunciare",
    "annunciassi": "annunciare",
    "annunciassimo": "annunciare",
    "annunciaste": "annunciare",
    "annunciasti": "annunciare",
    "annunciata": "annunciare",
    "annunciate": "annunciare",
    "annunciati": "annunciare",
    "annunciato": "annunciare",
    "annunciatori": "annunciatore",
    "annunciatrice": "annunciatore",
    "annunciatrici": "annunciatrice",
    "annunciava": "annunciare",
    "annunciavamo": "annunciare",
    "annunciavan": "annunciare",
    "annunciavano": "annunciare",
    "annunciavate": "annunciare",
    "annunciavi": "annunciare",
    "annunciavo": "annunciare",
    "annuncin": "annunciare",
    "annuncino": "annunciare",
    "annuncio": "annunciare",
    "annunciò": "annunciare",
    "annunzi": "annunziare",
    "annunzia": "annunziare",
    "annunziai": "annunziare",
    "annunziammo": "annunziare",
    "annunziamo": "annunziare",
    "annunzian": "annunziare",
    "annunziando": "annunziare",
    "annunziano": "annunziare",
    "annunziante": "annunziare",
    "annunzianti": "annunziare",
    "annunziar": "annunziare",
    "annunziaron": "annunziare",
    "annunziarono": "annunziare",
    "annunziasse": "annunziare",
    "annunziasser": "annunziare",
    "annunziassero": "annunziare",
    "annunziassi": "annunziare",
    "annunziassimo": "annunziare",
    "annunziaste": "annunziare",
    "annunziasti": "annunziare",
    "annunziata": "annunziare",
    "annunziate": "annunziare",
    "annunziati": "annunziare",
    "annunziato": "annunziare",
    "annunziava": "annunziare",
    "annunziavamo": "annunziare",
    "annunziavan": "annunziare",
    "annunziavano": "annunziare",
    "annunziavate": "annunziare",
    "annunziavi": "annunziare",
    "annunziavo": "annunziare",
    "annunzierai": "annunziare",
    "annunzieran": "annunziare",
    "annunzieranno": "annunziare",
    "annunzierebbe": "annunziare",
    "annunzierebber": "annunziare",
    "annunzierebbero": "annunziare",
    "annunzierei": "annunziare",
    "annunzieremmo": "annunziare",
    "annunzieremo": "annunziare",
    "annunziereste": "annunziare",
    "annunzieresti": "annunziare",
    "annunzierete": "annunziare",
    "annunzierà": "annunziare",
    "annunzierò": "annunziare",
    "annunzin": "annunziare",
    "annunzino": "annunziare",
    "annunzio": "annunziare",
    "annunziò": "annunziare",
    "annusa": "annusare",
    "annusai": "annusare",
    "annusammo": "annusare",
    "annusan": "annusare",
    "annusando": "annusare",
    "annusano": "annusare",
    "annusante": "annusare",
    "annusanti": "annusare",
    "annusar": "annusare",
    "annusaron": "annusare",
    "annusarono": "annusare",
    "annusasse": "annusare",
    "annusasser": "annusare",
    "annusassero": "annusare",
    "annusassi": "annusare",
    "annusassimo": "annusare",
    "annusaste": "annusare",
    "annusasti": "annusare",
    "annusata": "annusare",
    "annusate": "annusare",
    "annusati": "annusare",
    "annusato": "annusare",
    "annusava": "annusare",
    "annusavamo": "annusare",
    "annusavan": "annusare",
    "annusavano": "annusare",
    "annusavate": "annusare",
    "annusavi": "annusare",
    "annusavo": "annusare",
    "annuserai": "annusare",
    "annuseran": "annusare",
    "annuseranno": "annusare",
    "annuserebbe": "annusare",
    "annuserebber": "annusare",
    "annuserebbero": "annusare",
    "annuserei": "annusare",
    "annuseremmo": "annusare",
    "annuseremo": "annusare",
    "annusereste": "annusare",
    "annuseresti": "annusare",
    "annuserete": "annusare",
    "annuserà": "annusare",
    "annuserò": "annusare",
    "annusi": "annusare",
    "annusiamo": "annusare",
    "annusiate": "annusare",
    "annusin": "annusare",
    "annusino": "annusare",
    "annuso": "annusare",
    "annusò": "annusare",
    "annuvola": "annuvolare",
    "annuvolai": "annuvolare",
    "annuvolamenti": "annuvolamento",
    "annuvolammo": "annuvolare",
    "annuvolan": "annuvolare",
    "annuvolando": "annuvolare",
    "annuvolano": "annuvolare",
    "annuvolante": "annuvolare",
    "annuvolanti": "annuvolare",
    "annuvolar": "annuvolare",
    "annuvolaron": "annuvolare",
    "annuvolarono": "annuvolare",
    "annuvolasse": "annuvolare",
    "annuvolasser": "annuvolare",
    "annuvolassero": "annuvolare",
    "annuvolassi": "annuvolare",
    "annuvolassimo": "annuvolare",
    "annuvolaste": "annuvolare",
    "annuvolasti": "annuvolare",
    "annuvolata": "annuvolare",
    "annuvolate": "annuvolare",
    "annuvolati": "annuvolare",
    "annuvolato": "annuvolare",
    "annuvolava": "annuvolare",
    "annuvolavamo": "annuvolare",
    "annuvolavan": "annuvolare",
    "annuvolavano": "annuvolare",
    "annuvolavate": "annuvolare",
    "annuvolavi": "annuvolare",
    "annuvolavo": "annuvolare",
    "annuvolerai": "annuvolare",
    "annuvoleran": "annuvolare",
    "annuvoleranno": "annuvolare",
    "annuvolerebbe": "annuvolare",
    "annuvolerebber": "annuvolare",
    "annuvolerebbero": "annuvolare",
    "annuvolerei": "annuvolare",
    "annuvoleremmo": "annuvolare",
    "annuvoleremo": "annuvolare",
    "annuvolereste": "annuvolare",
    "annuvoleresti": "annuvolare",
    "annuvolerete": "annuvolare",
    "annuvolerà": "annuvolare",
    "annuvolerò": "annuvolare",
    "annuvoli": "annuvolare",
    "annuvoliamo": "annuvolare",
    "annuvoliate": "annuvolare",
    "annuvolin": "annuvolare",
    "annuvolino": "annuvolare",
    "annuvolo": "annuvolare",
    "annuvolò": "annuvolare",
    "annuì": "annuire",
    "anodina": "anodino",
    "anodine": "anodino",
    "anodini": "anodino",
    "anodizza": "anodizzare",
    "anodizzai": "anodizzare",
    "anodizzammo": "anodizzare",
    "anodizzan": "anodizzare",
    "anodizzando": "anodizzare",
    "anodizzano": "anodizzare",
    "anodizzante": "anodizzare",
    "anodizzanti": "anodizzare",
    "anodizzar": "anodizzare",
    "anodizzaron": "anodizzare",
    "anodizzarono": "anodizzare",
    "anodizzasse": "anodizzare",
    "anodizzasser": "anodizzare",
    "anodizzassero": "anodizzare",
    "anodizzassi": "anodizzare",
    "anodizzassimo": "anodizzare",
    "anodizzaste": "anodizzare",
    "anodizzasti": "anodizzare",
    "anodizzata": "anodizzare",
    "anodizzate": "anodizzare",
    "anodizzati": "anodizzare",
    "anodizzato": "anodizzare",
    "anodizzava": "anodizzare",
    "anodizzavamo": "anodizzare",
    "anodizzavan": "anodizzare",
    "anodizzavano": "anodizzare",
    "anodizzavate": "anodizzare",
    "anodizzavi": "anodizzare",
    "anodizzavo": "anodizzare",
    "anodizzerai": "anodizzare",
    "anodizzeran": "anodizzare",
    "anodizzeranno": "anodizzare",
    "anodizzerebbe": "anodizzare",
    "anodizzerebber": "anodizzare",
    "anodizzerebbero": "anodizzare",
    "anodizzerei": "anodizzare",
    "anodizzeremmo": "anodizzare",
    "anodizzeremo": "anodizzare",
    "anodizzereste": "anodizzare",
    "anodizzeresti": "anodizzare",
    "anodizzerete": "anodizzare",
    "anodizzerà": "anodizzare",
    "anodizzerò": "anodizzare",
    "anodizzi": "anodizzare",
    "anodizziamo": "anodizzare",
    "anodizziate": "anodizzare",
    "anodizzin": "anodizzare",
    "anodizzino": "anodizzare",
    "anodizzo": "anodizzare",
    "anodizzò": "anodizzare",
    "anomala": "anomalo",
    "anomale": "anomalo",
    "anomali": "anomalo",
    "anomalie": "anomalia",
    "anomalìe": "anomalìa",
    "anonima": "anonimo",
    "anonime": "anonimo",
    "anonimi": "anonimo",
    "anoressiche": "anoressica",
    "anoressici": "anoressico",
    "anoressie": "anoressia",
    "anormali": "anormale",
    "ansa": "ansare",
    "ansai": "ansare",
    "ansammo": "ansare",
    "ansan": "ansare",
    "ansando": "ansare",
    "ansano": "ansare",
    "ansante": "ansare",
    "ansanti": "ansare",
    "ansar": "ansare",
    "ansaron": "ansare",
    "ansarono": "ansare",
    "ansasse": "ansare",
    "ansasser": "ansare",
    "ansassero": "ansare",
    "ansassi": "ansare",
    "ansassimo": "ansare",
    "ansaste": "ansare",
    "ansasti": "ansare",
    "ansata": "ansare",
    "ansate": "ansare",
    "ansati": "ansare",
    "ansato": "ansare",
    "ansava": "ansare",
    "ansavamo": "ansare",
    "ansavan": "ansare",
    "ansavano": "ansare",
    "ansavate": "ansare",
    "ansavi": "ansare",
    "ansavo": "ansare",
    "anse": "ansa",
    "anserai": "ansare",
    "anseran": "ansare",
    "anseranno": "ansare",
    "anserebbe": "ansare",
    "anserebber": "ansare",
    "anserebbero": "ansare",
    "anserei": "ansare",
    "anseremmo": "ansare",
    "anseremo": "ansare",
    "ansereste": "ansare",
    "anseresti": "ansare",
    "anserete": "ansare",
    "anserà": "ansare",
    "anserò": "ansare",
    "ansi": "ansare",
    "ansiamo": "ansare",
    "ansiate": "ansare",
    "ansie": "ansia",
    "ansima": "ansimare",
    "ansimai": "ansimare",
    "ansimammo": "ansimare",
    "ansiman": "ansimare",
    "ansimando": "ansimare",
    "ansimano": "ansimare",
    "ansimante": "ansimare",
    "ansimanti": "ansimare",
    "ansimar": "ansimare",
    "ansimaron": "ansimare",
    "ansimarono": "ansimare",
    "ansimasse": "ansimare",
    "ansimasser": "ansimare",
    "ansimassero": "ansimare",
    "ansimassi": "ansimare",
    "ansimassimo": "ansimare",
    "ansimaste": "ansimare",
    "ansimasti": "ansimare",
    "ansimata": "ansimare",
    "ansimate": "ansimare",
    "ansimati": "ansimare",
    "ansimato": "ansimare",
    "ansimava": "ansimare",
    "ansimavamo": "ansimare",
    "ansimavan": "ansimare",
    "ansimavano": "ansimare",
    "ansimavate": "ansimare",
    "ansimavi": "ansimare",
    "ansimavo": "ansimare",
    "ansimerai": "ansimare",
    "ansimeran": "ansimare",
    "ansimeranno": "ansimare",
    "ansimerebbe": "ansimare",
    "ansimerebber": "ansimare",
    "ansimerebbero": "ansimare",
    "ansimerei": "ansimare",
    "ansimeremmo": "ansimare",
    "ansimeremo": "ansimare",
    "ansimereste": "ansimare",
    "ansimeresti": "ansimare",
    "ansimerete": "ansimare",
    "ansimerà": "ansimare",
    "ansimerò": "ansimare",
    "ansimi": "ansimare",
    "ansimiamo": "ansimare",
    "ansimiate": "ansimare",
    "ansimin": "ansimare",
    "ansimino": "ansimare",
    "ansimo": "ansimare",
    "ansimò": "ansimare",
    "ansin": "ansare",
    "ansino": "ansare",
    "ansiosa": "ansioso",
    "ansiose": "ansioso",
    "ansiosi": "ansioso",
    "anso": "ansare",
    "ansò": "ansare",
    "antagonismi": "antagonismo",
    "antagoniste": "antagonista",
    "antagonisti": "antagonista",
    "antagonistica": "antagonistico",
    "antagonistiche": "antagonistico",
    "antagonistici": "antagonistico",
    "antartica": "antartico",
    "antartiche": "antartico",
    "antartici": "antartico",
    "antecedenti": "antecedente",
    "antefatti": "antefatto",
    "antelucana": "antelucano",
    "antelucane": "antelucano",
    "antelucani": "antelucano",
    "antenata": "antenato",
    "antenate": "antenato",
    "antenati": "antenato",
    "antenne": "antenna",
    "antepone": "anteporre",
    "anteponemmo": "anteporre",
    "anteponendo": "anteporre",
    "anteponente": "anteporre",
    "anteponenti": "anteporre",
    "anteponesse": "anteporre",
    "anteponesser": "anteporre",
    "anteponessero": "anteporre",
    "anteponessi": "anteporre",
    "anteponessimo": "anteporre",
    "anteponeste": "anteporre",
    "anteponesti": "anteporre",
    "anteponete": "anteporre",
    "anteponeva": "anteporre",
    "anteponevamo": "anteporre",
    "anteponevan": "anteporre",
    "anteponevano": "anteporre",
    "anteponevate": "anteporre",
    "anteponevi": "anteporre",
    "anteponevo": "anteporre",
    "anteponga": "anteporre",
    "antepongan": "anteporre",
    "antepongano": "anteporre",
    "antepongo": "anteporre",
    "antepongon": "anteporre",
    "antepongono": "anteporre",
    "anteponi": "anteporre",
    "anteponiamo": "anteporre",
    "anteponiate": "anteporre",
    "anteporr": "anteporre",
    "anteporrai": "anteporre",
    "anteporran": "anteporre",
    "anteporranno": "anteporre",
    "anteporrebbe": "anteporre",
    "anteporrebber": "anteporre",
    "anteporrebbero": "anteporre",
    "anteporrei": "anteporre",
    "anteporremmo": "anteporre",
    "anteporremo": "anteporre",
    "anteporreste": "anteporre",
    "anteporresti": "anteporre",
    "anteporrete": "anteporre",
    "anteporrà": "anteporre",
    "anteporrò": "anteporre",
    "antepose": "anteporre",
    "anteposer": "anteporre",
    "anteposero": "anteporre",
    "anteposi": "anteporre",
    "anteposta": "anteporre",
    "anteposte": "anteporre",
    "anteposti": "anteporre",
    "anteposto": "anteporre",
    "anteprime": "anteprima",
    "anteriori": "anteriore",
    "antesignani": "antesignano",
    "anti-abortiste": "anti-abortista",
    "anti-abortisti": "anti-abortista",
    "anti-abrogazioniste": "anti-abrogazionista",
    "anti-abrogazionisti": "anti-abrogazionista",
    "anti-americana": "anti-americano",
    "anti-americane": "anti-americano",
    "anti-americani": "anti-americano",
    "anti-araba": "anti-arabo",
    "anti-arabe": "anti-arabo",
    "anti-arabi": "anti-arabo",
    "anti-ariostea": "anti-ariosteo",
    "anti-ariostee": "anti-ariosteo",
    "anti-ariostei": "anti-ariosteo",
    "anti-austriaca": "anti-austriaco",
    "anti-austriache": "anti-austriaco",
    "anti-austriaci": "anti-austriaco",
    "anti-balistica": "anti-balistico",
    "anti-balistiche": "anti-balistico",
    "anti-balistici": "anti-balistico",
    "anti-batterica": "anti-batterico",
    "anti-batteriche": "anti-batterico",
    "anti-batterici": "anti-batterico",
    "anti-berlusconiana": "anti-berlusconiano",
    "anti-berlusconiane": "anti-berlusconiano",
    "anti-berlusconiani": "anti-berlusconiano",
    "anti-cancerosa": "anti-canceroso",
    "anti-cancerose": "anti-canceroso",
    "anti-cancerosi": "anti-canceroso",
    "anti-castriste": "anti-castrista",
    "anti-castristi": "anti-castrista",
    "anti-cattolica": "anti-cattolico",
    "anti-cattoliche": "anti-cattolico",
    "anti-cattolici": "anti-cattolico",
    "anti-coagulanti": "anti-coagulante",
    "anti-colonialiste": "anti-colonialista",
    "anti-colonialisti": "anti-colonialista",
    "anti-colpevoliste": "anti-colpevolista",
    "anti-colpevolisti": "anti-colpevolista",
    "anti-comuniste": "anti-comunista",
    "anti-comunisti": "anti-comunista",
    "anti-conformiste": "anti-conformista",
    "anti-conformisti": "anti-conformista",
    "anti-confuciana": "anti-confuciano",
    "anti-confuciane": "anti-confuciano",
    "anti-confuciani": "anti-confuciano",
    "anti-congiunturali": "anti-congiunturale",
    "anti-convenzionali": "anti-convenzionale",
    "anti-cossighiana": "anti-cossighiano",
    "anti-cossighiane": "anti-cossighiano",
    "anti-cossighiani": "anti-cossighiano",
    "anti-demartiniana": "anti-demartiniano",
    "anti-demartiniane": "anti-demartiniano",
    "anti-demartiniani": "anti-demartiniano",
    "anti-democratica": "anti-democratico",
    "anti-democratiche": "anti-democratico",
    "anti-democratici": "anti-democratico",
    "anti-depressiva": "anti-depressivo",
    "anti-depressive": "anti-depressivo",
    "anti-depressivi": "anti-depressivo",
    "anti-ebraica": "anti-ebraico",
    "anti-ebraiche": "anti-ebraico",
    "anti-ebraici": "anti-ebraico",
    "anti-economica": "anti-economico",
    "anti-economiche": "anti-economico",
    "anti-economici": "anti-economico",
    "anti-europea": "anti-europeo",
    "anti-europee": "anti-europeo",
    "anti-europei": "anti-europeo",
    "anti-fasciste": "anti-fascista",
    "anti-fascisti": "anti-fascista",
    "anti-federaliste": "anti-federalista",
    "anti-federalisti": "anti-federalista",
    "anti-giapponesi": "anti-giapponese",
    "anti-giudici": "anti-giudice",
    "anti-governativa": "anti-governativo",
    "anti-governative": "anti-governativo",
    "anti-governativi": "anti-governativo",
    "anti-hollywoodiana": "anti-hollywoodiano",
    "anti-hollywoodiane": "anti-hollywoodiano",
    "anti-hollywoodiani": "anti-hollywoodiano",
    "anti-imperialiste": "anti-imperialista",
    "anti-imperialisti": "anti-imperialista",
    "anti-indipendentistica": "anti-indipendentistico",
    "anti-indipendentistiche": "anti-indipendentistico",
    "anti-indipendentistici": "anti-indipendentistico",
    "anti-individualiste": "anti-individualista",
    "anti-individualisti": "anti-individualista",
    "anti-indonesiana": "anti-indonesiano",
    "anti-indonesiane": "anti-indonesiano",
    "anti-indonesiani": "anti-indonesiano",
    "anti-infiammatori": "anti-infiammatorio",
    "anti-infiammatoria": "anti-infiammatorio",
    "anti-infiammatorie": "anti-infiammatorio",
    "anti-inflazionistica": "anti-inflazionistico",
    "anti-inflazionistiche": "anti-inflazionistico",
    "anti-inflazionistici": "anti-inflazionistico",
    "anti-influenzali": "anti-influenzale",
    "anti-infortunistica": "anti-infortunistico",
    "anti-infortunistiche": "anti-infortunistico",
    "anti-infortunistici": "anti-infortunistico",
    "anti-inglesi": "anti-inglese",
    "anti-integraliste": "anti-integralista",
    "anti-integralisti": "anti-integralista",
    "anti-ipertensiva": "anti-ipertensivo",
    "anti-ipertensive": "anti-ipertensivo",
    "anti-ipertensivi": "anti-ipertensivo",
    "anti-irachena": "anti-iracheno",
    "anti-irachene": "anti-iracheno",
    "anti-iracheni": "anti-iracheno",
    "anti-iraniana": "anti-iraniano",
    "anti-iraniane": "anti-iraniano",
    "anti-iraniani": "anti-iraniano",
    "anti-islamica": "anti-islamico",
    "anti-islamiche": "anti-islamico",
    "anti-islamici": "anti-islamico",
    "anti-israeliana": "anti-israeliano",
    "anti-israeliane": "anti-israeliano",
    "anti-israeliani": "anti-israeliano",
    "anti-italiana": "anti-italiano",
    "anti-italiane": "anti-italiano",
    "anti-italiani": "anti-italiano",
    "anti-juventina": "anti-juventino",
    "anti-juventine": "anti-juventino",
    "anti-juventini": "anti-juventino",
    "anti-leniniste": "anti-leninista",
    "anti-leninisti": "anti-leninista",
    "anti-libica": "anti-libico",
    "anti-libiche": "anti-libico",
    "anti-libici": "anti-libico",
    "anti-malarica": "anti-malarico",
    "anti-malariche": "anti-malarico",
    "anti-malarici": "anti-malarico",
    "anti-meridionaliste": "anti-meridionalista",
    "anti-meridionalisti": "anti-meridionalista",
    "anti-michelangiolesca": "anti-michelangiolesco",
    "anti-michelangiolesche": "anti-michelangiolesco",
    "anti-michelangioleschi": "anti-michelangiolesco",
    "anti-missilistica": "anti-missilistico",
    "anti-missilistiche": "anti-missilistico",
    "anti-missilistici": "anti-missilistico",
    "anti-monarchica": "anti-monarchico",
    "anti-monarchiche": "anti-monarchico",
    "anti-monarchici": "anti-monarchico",
    "anti-monopolistica": "anti-monopolistico",
    "anti-monopolistiche": "anti-monopolistico",
    "anti-monopolistici": "anti-monopolistico",
    "anti-naziste": "anti-nazista",
    "anti-nazisti": "anti-nazista",
    "anti-nucleari": "anti-nucleare",
    "anti-occidentali": "anti-occidentale",
    "anti-padana": "anti-padano",
    "anti-padane": "anti-padano",
    "anti-padani": "anti-padano",
    "anti-peroniste": "anti-peronista",
    "anti-peronisti": "anti-peronista",
    "anti-pinochetiste": "anti-pinochetista",
    "anti-pinochetisti": "anti-pinochetista",
    "anti-proibizioniste": "anti-proibizionista",
    "anti-proibizionisti": "anti-proibizionista",
    "anti-razziste": "anti-razzista",
    "anti-razzisti": "anti-razzista",
    "anti-realistica": "anti-realistico",
    "anti-realistiche": "anti-realistico",
    "anti-realistici": "anti-realistico",
    "anti-recessiva": "anti-recessivo",
    "anti-recessive": "anti-recessivo",
    "anti-recessivi": "anti-recessivo",
    "anti-repressiva": "anti-repressivo",
    "anti-repressive": "anti-repressivo",
    "anti-repressivi": "anti-repressivo",
    "anti-russa": "anti-russo",
    "anti-russe": "anti-russo",
    "anti-russi": "anti-russo",
    "anti-scientifica": "anti-scientifico",
    "anti-scientifiche": "anti-scientifico",
    "anti-scientifici": "anti-scientifico",
    "anti-separatiste": "anti-separatista",
    "anti-separatisti": "anti-separatista",
    "anti-serba": "anti-serbo",
    "anti-serbe": "anti-serbo",
    "anti-serbi": "anti-serbo",
    "anti-sindacali": "anti-sindacale",
    "anti-sioniste": "anti-sionista",
    "anti-sionisti": "anti-sionista",
    "anti-sovietica": "anti-sovietico",
    "anti-sovietiche": "anti-sovietico",
    "anti-sovietici": "anti-sovietico",
    "anti-spagnola": "anti-spagnolo",
    "anti-spagnole": "anti-spagnolo",
    "anti-spagnoli": "anti-spagnolo",
    "anti-spettacolari": "anti-spettacolare",
    "anti-thatcheriana": "anti-thatcheriano",
    "anti-thatcheriane": "anti-thatcheriano",
    "anti-thatcheriani": "anti-thatcheriano",
    "anti-trapiantistica": "anti-trapiantistico",
    "anti-trapiantistiche": "anti-trapiantistico",
    "anti-trapiantistici": "anti-trapiantistico",
    "anti-tumorali": "anti-tumorale",
    "anti-turca": "anti-turco",
    "anti-turche": "anti-turco",
    "anti-turchi": "anti-turco",
    "anti-unitari": "anti-unitario",
    "anti-unitaria": "anti-unitario",
    "anti-unitarie": "anti-unitario",
    "anti-zemaniana": "anti-zemaniano",
    "anti-zemaniane": "anti-zemaniano",
    "anti-zemaniani": "anti-zemaniano",
    "antiabortisti": "antiabortista",
    "antiaerea": "antiaereo",
    "antiaeree": "antiaereo",
    "antiaerei": "antiaereo",
    "antiamericana": "antiamericano",
    "antiamericane": "antiamericano",
    "antiamericani": "antiamericano",
    "antiaraba": "antiarabo",
    "antiarabe": "antiarabo",
    "antiarabi": "antiarabo",
    "antiasmatica": "antiasmatico",
    "antiasmatiche": "antiasmatico",
    "antiasmatici": "antiasmatico",
    "antiatomica": "antiatomico",
    "antiatomiche": "antiatomico",
    "antiatomici": "antiatomico",
    "antiaustriaca": "antiaustriaco",
    "antiaustriache": "antiaustriaco",
    "antiaustriaci": "antiaustriaco",
    "antiberniniana": "antiberniniano",
    "antiberniniane": "antiberniniano",
    "antiberniniani": "antiberniniano",
    "antibiotica": "antibiotico",
    "antibiotiche": "antibiotico",
    "antibiotici": "antibiotico",
    "antiburocratica": "antiburocratico",
    "antiburocratiche": "antiburocratico",
    "antiburocratici": "antiburocratico",
    "antica": "antico",
    "anticaglie": "anticaglia",
    "anticamere": "anticamera",
    "anticanonica": "anticanonico",
    "anticanoniche": "anticanonico",
    "anticanonici": "anticanonico",
    "antiche": "antico",
    "anticheggianti": "anticheggiante",
    "antichi": "antico",
    "anticicloni": "anticiclone",
    "anticinematografica": "anticinematografico",
    "anticinematografiche": "anticinematografico",
    "anticinematografici": "anticinematografico",
    "anticinesi": "anticinese",
    "anticipa": "anticipare",
    "anticipai": "anticipare",
    "anticipammo": "anticipare",
    "anticipan": "anticipare",
    "anticipando": "anticipare",
    "anticipano": "anticipare",
    "anticipante": "anticipare",
    "anticipanti": "anticipare",
    "anticipar": "anticipare",
    "anticiparon": "anticipare",
    "anticiparono": "anticipare",
    "anticipasse": "anticipare",
    "anticipasser": "anticipare",
    "anticipassero": "anticipare",
    "anticipassi": "anticipare",
    "anticipassimo": "anticipare",
    "anticipaste": "anticipare",
    "anticipasti": "anticipare",
    "anticipata": "anticipato",
    "anticipate": "anticipato",
    "anticipati": "anticipato",
    "anticipato": "anticipare",
    "anticipatori": "anticipatorio",
    "anticipatoria": "anticipatorio",
    "anticipatorie": "anticipatorio",
    "anticipava": "anticipare",
    "anticipavamo": "anticipare",
    "anticipavan": "anticipare",
    "anticipavano": "anticipare",
    "anticipavate": "anticipare",
    "anticipavi": "anticipare",
    "anticipavo": "anticipare",
    "anticipazioni": "anticipazione",
    "anticiperai": "anticipare",
    "anticiperan": "anticipare",
    "anticiperanno": "anticipare",
    "anticiperebbe": "anticipare",
    "anticiperebber": "anticipare",
    "anticiperebbero": "anticipare",
    "anticiperei": "anticipare",
    "anticiperemmo": "anticipare",
    "anticiperemo": "anticipare",
    "anticipereste": "anticipare",
    "anticiperesti": "anticipare",
    "anticiperete": "anticipare",
    "anticiperà": "anticipare",
    "anticiperò": "anticipare",
    "anticipi": "anticipo",
    "anticipiamo": "anticipare",
    "anticipiate": "anticipare",
    "anticipin": "anticipare",
    "anticipino": "anticipare",
    "anticipo": "anticipare",
    "anticipò": "anticipare",
    "anticlassica": "anticlassico",
    "anticlassiche": "anticlassico",
    "anticlassici": "anticlassico",
    "anticlericali": "anticlericale",
    "anticomunismi": "anticomunismo",
    "anticoncezionali": "anticoncezionale",
    "anticonciliari": "anticonciliare",
    "anticonfederali": "anticonfederale",
    "anticonformismi": "anticonformismo",
    "anticonformiste": "anticonformista",
    "anticonformisti": "anticonformista",
    "anticongiunturali": "anticongiunturale",
    "anticonsumistica": "anticonsumistico",
    "anticonsumistiche": "anticonsumistico",
    "anticonsumistici": "anticonsumistico",
    "anticorpi": "anticorpo",
    "anticostituzionali": "anticostituzionale",
    "anticraxiana": "anticraxiano",
    "anticraxiane": "anticraxiano",
    "anticraxiani": "anticraxiano",
    "anticrociana": "anticrociano",
    "anticrociane": "anticrociano",
    "anticrociani": "anticrociano",
    "antidannunziana": "antidannunziano",
    "antidannunziane": "antidannunziano",
    "antidannunziani": "antidannunziano",
    "antidata": "antidatare",
    "antidatai": "antidatare",
    "antidatammo": "antidatare",
    "antidatan": "antidatare",
    "antidatando": "antidatare",
    "antidatano": "antidatare",
    "antidatante": "antidatare",
    "antidatanti": "antidatare",
    "antidatar": "antidatare",
    "antidataron": "antidatare",
    "antidatarono": "antidatare",
    "antidatasse": "antidatare",
    "antidatasser": "antidatare",
    "antidatassero": "antidatare",
    "antidatassi": "antidatare",
    "antidatassimo": "antidatare",
    "antidataste": "antidatare",
    "antidatasti": "antidatare",
    "antidatata": "antidatare",
    "antidatate": "antidatare",
    "antidatati": "antidatare",
    "antidatato": "antidatare",
    "antidatava": "antidatare",
    "antidatavamo": "antidatare",
    "antidatavan": "antidatare",
    "antidatavano": "antidatare",
    "antidatavate": "antidatare",
    "antidatavi": "antidatare",
    "antidatavo": "antidatare",
    "antidaterai": "antidatare",
    "antidateran": "antidatare",
    "antidateranno": "antidatare",
    "antidaterebbe": "antidatare",
    "antidaterebber": "antidatare",
    "antidaterebbero": "antidatare",
    "antidaterei": "antidatare",
    "antidateremmo": "antidatare",
    "antidateremo": "antidatare",
    "antidatereste": "antidatare",
    "antidateresti": "antidatare",
    "antidaterete": "antidatare",
    "antidaterà": "antidatare",
    "antidaterò": "antidatare",
    "antidati": "antidatare",
    "antidatiamo": "antidatare",
    "antidatiate": "antidatare",
    "antidatin": "antidatare",
    "antidatino": "antidatare",
    "antidato": "antidatare",
    "antidatò": "antidatare",
    "antidemitiana": "antidemitiano",
    "antidemitiane": "antidemitiano",
    "antidemitiani": "antidemitiano",
    "antidemocratica": "antidemocratico",
    "antidemocratiche": "antidemocratico",
    "antidemocratici": "antidemocratico",
    "antidemocristiana": "antidemocristiano",
    "antidemocristiane": "antidemocristiano",
    "antidemocristiani": "antidemocristiano",
    "antidepressivi": "antidepressivo",
    "antidiluviana": "antidiluviano",
    "antidiluviane": "antidiluviano",
    "antidiluviani": "antidiluviano",
    "antidogmatica": "antidogmatico",
    "antidogmatiche": "antidogmatico",
    "antidogmatici": "antidogmatico",
    "antidolorifica": "antidolorifico",
    "antidolorifiche": "antidolorifico",
    "antidolorifici": "antidolorifico",
    "antidoti": "antidoto",
    "antiebraica": "antiebraico",
    "antiebraiche": "antiebraico",
    "antiebraici": "antiebraico",
    "antiecologica": "antiecologico",
    "antiecologiche": "antiecologico",
    "antiecologici": "antiecologico",
    "antieconomica": "antieconomico",
    "antieconomiche": "antieconomico",
    "antieconomici": "antieconomico",
    "antieroi": "antieroe",
    "antieroica": "antieroico",
    "antieroiche": "antieroico",
    "antieroici": "antieroico",
    "antiestetica": "antiestetico",
    "antiestetiche": "antiestetico",
    "antiestetici": "antiestetico",
    "antifascismi": "antifascismo",
    "antifasciste": "antifascista",
    "antifascisti": "antifascista",
    "antifemministe": "antifemminista",
    "antifemministi": "antifemminista",
    "antifurti": "antifurto",
    "antigeni": "antigene",
    "antigiapponesi": "antigiapponese",
    "antigienica": "antigienico",
    "antigieniche": "antigienico",
    "antigienici": "antigienico",
    "antigiudaica": "antigiudaico",
    "antigiudaiche": "antigiudaico",
    "antigiudaici": "antigiudaico",
    "antigorbacioviana": "antigorbacioviano",
    "antigorbacioviane": "antigorbacioviano",
    "antigorbacioviani": "antigorbacioviano",
    "antilibica": "antilibico",
    "antilibiche": "antilibico",
    "antilibici": "antilibico",
    "antimaoiste": "antimaoista",
    "antimaoisti": "antimaoista",
    "antimarxiste": "antimarxista",
    "antimarxisti": "antimarxista",
    "antimeridiana": "antimeridiano",
    "antimeridiane": "antimeridiano",
    "antimeridiani": "antimeridiano",
    "antimeridionali": "antimeridionale",
    "antimetafisica": "antimetafisico",
    "antimetafisiche": "antimetafisico",
    "antimetafisici": "antimetafisico",
    "antimilitariste": "antimilitarista",
    "antimilitaristi": "antimilitarista",
    "antimperialiste": "antimperialista",
    "antimperialisti": "antimperialista",
    "antinaturalistica": "antinaturalistico",
    "antinaturalistiche": "antinaturalistico",
    "antinaturalistici": "antinaturalistico",
    "antinazionali": "antinazionale",
    "antinazionaliste": "antinazionalista",
    "antinazionalisti": "antinazionalista",
    "antindustriali": "antindustriale",
    "antinfiammatori": "antinfiammatorio",
    "antinflattiva": "antinflattivo",
    "antinflattive": "antinflattivo",
    "antinflattivi": "antinflattivo",
    "antinflazionistica": "antinflazionistico",
    "antinflazionistiche": "antinflazionistico",
    "antinflazionistici": "antinflazionistico",
    "antinomie": "antinomia",
    "antiorari": "antiorario",
    "antioraria": "antiorario",
    "antiorarie": "antiorario",
    "antiossidanti": "antiossidante",
    "antiparassitari": "antiparassitario",
    "antipasti": "antipasto",
    "antipatica": "antipatico",
    "antipatiche": "antipatico",
    "antipatici": "antipatico",
    "antipatie": "antipatia",
    "antipatizzanti": "antipatizzante",
    "antipodi": "antipode",
    "antipopolari": "antipopolare",
    "antiproibizionisti": "antiproibizionista",
    "antiproibizionistica": "antiproibizionistico",
    "antiproibizionistiche": "antiproibizionistico",
    "antiproibizionistici": "antiproibizionistico",
    "antiquari": "antiquario",
    "antiquaria": "antiquario",
    "antiquarie": "antiquario",
    "antiquata": "antiquato",
    "antiquate": "antiquato",
    "antiquati": "antiquato",
    "antirazziste": "antirazzista",
    "antirazzisti": "antirazzista",
    "antirealistica": "antirealistico",
    "antirealistiche": "antirealistico",
    "antirealistici": "antirealistico",
    "antireazionari": "antireazionario",
    "antireazionaria": "antireazionario",
    "antireazionarie": "antireazionario",
    "antireligiosa": "antireligioso",
    "antireligiose": "antireligioso",
    "antireligiosi": "antireligioso",
    "antiretorica": "antiretorico",
    "antiretoriche": "antiretorico",
    "antiretorici": "antiretorico",
    "antiribassiste": "antiribassista",
    "antiribassisti": "antiribassista",
    "antirivoluzionari": "antirivoluzionario",
    "antirivoluzionaria": "antirivoluzionario",
    "antirivoluzionarie": "antirivoluzionario",
    "antiromana": "antiromano",
    "antiromane": "antiromano",
    "antiromani": "antiromano",
    "antirussa": "antirusso",
    "antirusse": "antirusso",
    "antirussi": "antirusso",
    "antisandiniste": "antisandinista",
    "antisandinisti": "antisandinista",
    "antisegregazioniste": "antisegregazionista",
    "antisegregazionisti": "antisegregazionista",
    "antisemite": "antisemita",
    "antisemiti": "antisemita",
    "antisemitismi": "antisemitismo",
    "antiserba": "antiserbo",
    "antiserbe": "antiserbo",
    "antiserbi": "antiserbo",
    "antisindacali": "antisindacale",
    "antisioniste": "antisionista",
    "antisionisti": "antisionista",
    "antisismica": "antisismico",
    "antisismiche": "antisismico",
    "antisismici": "antisismico",
    "antisociali": "antisociale",
    "antisocialiste": "antisocialista",
    "antisocialisti": "antisocialista",
    "antispagnola": "antispagnolo",
    "antispagnole": "antispagnolo",
    "antispagnoli": "antispagnolo",
    "antisportiva": "antisportivo",
    "antisportive": "antisportivo",
    "antisportivi": "antisportivo",
    "antistaliniana": "antistaliniano",
    "antistaliniane": "antistaliniano",
    "antistaliniani": "antistaliniano",
    "antistanti": "antistante",
    "antistorica": "antistorico",
    "antistoriche": "antistorico",
    "antistorici": "antistorico",
    "antitaliana": "antitaliano",
    "antitaliane": "antitaliano",
    "antitaliani": "antitaliano",
    "antitecnica": "antitecnico",
    "antitecniche": "antitecnico",
    "antitecnici": "antitecnico",
    "antitelevisiva": "antitelevisivo",
    "antitelevisive": "antitelevisivo",
    "antitelevisivi": "antitelevisivo",
    "antiterroriste": "antiterrorista",
    "antiterroristi": "antiterrorista",
    "antitetica": "antitetico",
    "antitetiche": "antitetico",
    "antitetici": "antitetico",
    "antithatcheriana": "antithatcheriano",
    "antithatcheriane": "antithatcheriano",
    "antithatcheriani": "antithatcheriano",
    "antitrionfalistica": "antitrionfalistico",
    "antitrionfalistiche": "antitrionfalistico",
    "antitrionfalistici": "antitrionfalistico",
    "antitubercola": "antitubercolare",
    "antitubercolai": "antitubercolare",
    "antitubercolammo": "antitubercolare",
    "antitubercolan": "antitubercolare",
    "antitubercolando": "antitubercolare",
    "antitubercolano": "antitubercolare",
    "antitubercolante": "antitubercolare",
    "antitubercolanti": "antitubercolare",
    "antitubercolar": "antitubercolare",
    "antitubercolaron": "antitubercolare",
    "antitubercolarono": "antitubercolare",
    "antitubercolasse": "antitubercolare",
    "antitubercolasser": "antitubercolare",
    "antitubercolassero": "antitubercolare",
    "antitubercolassi": "antitubercolare",
    "antitubercolassimo": "antitubercolare",
    "antitubercolaste": "antitubercolare",
    "antitubercolasti": "antitubercolare",
    "antitubercolata": "antitubercolare",
    "antitubercolate": "antitubercolare",
    "antitubercolati": "antitubercolare",
    "antitubercolato": "antitubercolare",
    "antitubercolava": "antitubercolare",
    "antitubercolavamo": "antitubercolare",
    "antitubercolavan": "antitubercolare",
    "antitubercolavano": "antitubercolare",
    "antitubercolavate": "antitubercolare",
    "antitubercolavi": "antitubercolare",
    "antitubercolavo": "antitubercolare",
    "antitubercolerai": "antitubercolare",
    "antitubercoleran": "antitubercolare",
    "antitubercoleranno": "antitubercolare",
    "antitubercolerebbe": "antitubercolare",
    "antitubercolerebber": "antitubercolare",
    "antitubercolerebbero": "antitubercolare",
    "antitubercolerei": "antitubercolare",
    "antitubercoleremmo": "antitubercolare",
    "antitubercoleremo": "antitubercolare",
    "antitubercolereste": "antitubercolare",
    "antitubercoleresti": "antitubercolare",
    "antitubercolerete": "antitubercolare",
    "antitubercolerà": "antitubercolare",
    "antitubercolerò": "antitubercolare",
    "antitubercoli": "antitubercolare",
    "antitubercoliamo": "antitubercolare",
    "antitubercoliate": "antitubercolare",
    "antitubercolin": "antitubercolare",
    "antitubercolino": "antitubercolare",
    "antitubercolo": "antitubercolare",
    "antitubercolò": "antitubercolare",
    "antitumorali": "antitumorale",
    "antiunitari": "antiunitario",
    "antiunitaria": "antiunitario",
    "antiunitarie": "antiunitario",
    "antivaticana": "antivaticano",
    "antivaticane": "antivaticano",
    "antivaticani": "antivaticano",
    "antivietnamite": "antivietnamita",
    "antivietnamiti": "antivietnamita",
    "antivirali": "antivirale",
    "antologica": "antologico",
    "antologiche": "antologico",
    "antologici": "antologico",
    "antologie": "antologia",
    "antri": "antro",
    "antropica": "antropico",
    "antropiche": "antropico",
    "antropici": "antropico",
    "antropofaga": "antropofago",
    "antropofaghe": "antropofago",
    "antropofaghi": "antropofago",
    "antropofagica": "antropofagico",
    "antropofagiche": "antropofagico",
    "antropofagici": "antropofagico",
    "antropogenica": "antropogenico",
    "antropogeniche": "antropogenico",
    "antropogenici": "antropogenico",
    "antropoidi": "antropoide",
    "antropologhe": "antropologa",
    "antropologi": "antropologo",
    "antropologica": "antropologico",
    "antropologiche": "antropologico",
    "antropologici": "antropologico",
    "antropologie": "antropologia",
    "antropomorfa": "antropomorfo",
    "antropomorfe": "antropomorfo",
    "antropomorfi": "antropomorfo",
    "antropomorfica": "antropomorfico",
    "antropomorfiche": "antropomorfico",
    "antropomorfici": "antropomorfico",
    "antropomorfizza": "antropomorfizzare",
    "antropomorfizzai": "antropomorfizzare",
    "antropomorfizzammo": "antropomorfizzare",
    "antropomorfizzan": "antropomorfizzare",
    "antropomorfizzando": "antropomorfizzare",
    "antropomorfizzano": "antropomorfizzare",
    "antropomorfizzante": "antropomorfizzare",
    "antropomorfizzanti": "antropomorfizzare",
    "antropomorfizzar": "antropomorfizzare",
    "antropomorfizzaron": "antropomorfizzare",
    "antropomorfizzarono": "antropomorfizzare",
    "antropomorfizzasse": "antropomorfizzare",
    "antropomorfizzasser": "antropomorfizzare",
    "antropomorfizzassero": "antropomorfizzare",
    "antropomorfizzassi": "antropomorfizzare",
    "antropomorfizzassimo": "antropomorfizzare",
    "antropomorfizzaste": "antropomorfizzare",
    "antropomorfizzasti": "antropomorfizzare",
    "antropomorfizzata": "antropomorfizzare",
    "antropomorfizzate": "antropomorfizzare",
    "antropomorfizzati": "antropomorfizzare",
    "antropomorfizzato": "antropomorfizzare",
    "antropomorfizzava": "antropomorfizzare",
    "antropomorfizzavamo": "antropomorfizzare",
    "antropomorfizzavan": "antropomorfizzare",
    "antropomorfizzavano": "antropomorfizzare",
    "antropomorfizzavate": "antropomorfizzare",
    "antropomorfizzavi": "antropomorfizzare",
    "antropomorfizzavo": "antropomorfizzare",
    "antropomorfizzerai": "antropomorfizzare",
    "antropomorfizzeran": "antropomorfizzare",
    "antropomorfizzeranno": "antropomorfizzare",
    "antropomorfizzerebbe": "antropomorfizzare",
    "antropomorfizzerebber": "antropomorfizzare",
    "antropomorfizzerebbero": "antropomorfizzare",
    "antropomorfizzerei": "antropomorfizzare",
    "antropomorfizzeremmo": "antropomorfizzare",
    "antropomorfizzeremo": "antropomorfizzare",
    "antropomorfizzereste": "antropomorfizzare",
    "antropomorfizzeresti": "antropomorfizzare",
    "antropomorfizzerete": "antropomorfizzare",
    "antropomorfizzerà": "antropomorfizzare",
    "antropomorfizzerò": "antropomorfizzare",
    "antropomorfizzi": "antropomorfizzare",
    "antropomorfizziamo": "antropomorfizzare",
    "antropomorfizziate": "antropomorfizzare",
    "antropomorfizzin": "antropomorfizzare",
    "antropomorfizzino": "antropomorfizzare",
    "antropomorfizzo": "antropomorfizzare",
    "antropomorfizzò": "antropomorfizzare",
    "anulari": "anulare",
    "anziana": "anziano",
    "anziane": "anziano",
    "anziani": "anziano",
    "apartitica": "apartitico",
    "apartitiche": "apartitico",
    "apartitici": "apartitico",
    "apatica": "apatico",
    "apatiche": "apatico",
    "apatici": "apatico",
    "apatie": "apatia",
    "aperitivi": "aperitivo",
    "aperta": "aprire",
    "aperte": "aprire",
    "aperti": "aprire",
    "aperto": "aprire",
    "aperture": "apertura",
    "api": "ape",
    "apicali": "apicale",
    "apici": "apice",
    "apicoltori": "apicoltore",
    "apocalissi": "apocalisse",
    "apocalittica": "apocalittico",
    "apocalittiche": "apocalittico",
    "apocalittici": "apocalittico",
    "apocopa": "apocopare",
    "apocopai": "apocopare",
    "apocopammo": "apocopare",
    "apocopan": "apocopare",
    "apocopando": "apocopare",
    "apocopano": "apocopare",
    "apocopante": "apocopare",
    "apocopanti": "apocopare",
    "apocopar": "apocopare",
    "apocoparon": "apocopare",
    "apocoparono": "apocopare",
    "apocopasse": "apocopare",
    "apocopasser": "apocopare",
    "apocopassero": "apocopare",
    "apocopassi": "apocopare",
    "apocopassimo": "apocopare",
    "apocopaste": "apocopare",
    "apocopasti": "apocopare",
    "apocopata": "apocopare",
    "apocopate": "apocopare",
    "apocopati": "apocopare",
    "apocopato": "apocopare",
    "apocopava": "apocopare",
    "apocopavamo": "apocopare",
    "apocopavan": "apocopare",
    "apocopavano": "apocopare",
    "apocopavate": "apocopare",
    "apocopavi": "apocopare",
    "apocopavo": "apocopare",
    "apocoperai": "apocopare",
    "apocoperan": "apocopare",
    "apocoperanno": "apocopare",
    "apocoperebbe": "apocopare",
    "apocoperebber": "apocopare",
    "apocoperebbero": "apocopare",
    "apocoperei": "apocopare",
    "apocoperemmo": "apocopare",
    "apocoperemo": "apocopare",
    "apocopereste": "apocopare",
    "apocoperesti": "apocopare",
    "apocoperete": "apocopare",
    "apocoperà": "apocopare",
    "apocoperò": "apocopare",
    "apocopi": "apocopare",
    "apocopiamo": "apocopare",
    "apocopiate": "apocopare",
    "apocopin": "apocopare",
    "apocopino": "apocopare",
    "apocopo": "apocopare",
    "apocopò": "apocopare",
    "apocrifa": "apocrifo",
    "apocrife": "apocrifo",
    "apocrifi": "apocrifo",
    "apodittica": "apodittico",
    "apodittiche": "apodittico",
    "apodittici": "apodittico",
    "apolidi": "apolide",
    "apolitica": "apolitico",
    "apolitiche": "apolitico",
    "apolitici": "apolitico",
    "apollinea": "apollineo",
    "apollinee": "apollineo",
    "apollinei": "apollineo",
    "apologeti": "apologeta",
    "apologetica": "apologetico",
    "apologetiche": "apologetico",
    "apologetici": "apologetico",
    "apologhi": "apologo",
    "apologie": "apologia",
    "apoplettica": "apoplettico",
    "apoplettiche": "apoplettico",
    "apoplettici": "apoplettico",
    "aporie": "aporia",
    "apostata": "apostatare",
    "apostatai": "apostatare",
    "apostatammo": "apostatare",
    "apostatan": "apostatare",
    "apostatando": "apostatare",
    "apostatano": "apostatare",
    "apostatante": "apostatare",
    "apostatanti": "apostatare",
    "apostatar": "apostatare",
    "apostataron": "apostatare",
    "apostatarono": "apostatare",
    "apostatasse": "apostatare",
    "apostatasser": "apostatare",
    "apostatassero": "apostatare",
    "apostatassi": "apostatare",
    "apostatassimo": "apostatare",
    "apostataste": "apostatare",
    "apostatasti": "apostatare",
    "apostatata": "apostatare",
    "apostatate": "apostatare",
    "apostatati": "apostatare",
    "apostatato": "apostatare",
    "apostatava": "apostatare",
    "apostatavamo": "apostatare",
    "apostatavan": "apostatare",
    "apostatavano": "apostatare",
    "apostatavate": "apostatare",
    "apostatavi": "apostatare",
    "apostatavo": "apostatare",
    "apostaterai": "apostatare",
    "apostateran": "apostatare",
    "apostateranno": "apostatare",
    "apostaterebbe": "apostatare",
    "apostaterebber": "apostatare",
    "apostaterebbero": "apostatare",
    "apostaterei": "apostatare",
    "apostateremmo": "apostatare",
    "apostateremo": "apostatare",
    "apostatereste": "apostatare",
    "apostateresti": "apostatare",
    "apostaterete": "apostatare",
    "apostaterà": "apostatare",
    "apostaterò": "apostatare",
    "apostati": "apostatare",
    "apostatiamo": "apostatare",
    "apostatiate": "apostatare",
    "apostatin": "apostatare",
    "apostatino": "apostatare",
    "apostato": "apostatare",
    "apostatò": "apostatare",
    "apostoli": "apostolo",
    "apostolica": "apostolico",
    "apostoliche": "apostolico",
    "apostolici": "apostolico",
    "apostrofa": "apostrofare",
    "apostrofai": "apostrofare",
    "apostrofammo": "apostrofare",
    "apostrofan": "apostrofare",
    "apostrofando": "apostrofare",
    "apostrofano": "apostrofare",
    "apostrofante": "apostrofare",
    "apostrofanti": "apostrofare",
    "apostrofar": "apostrofare",
    "apostrofaron": "apostrofare",
    "apostrofarono": "apostrofare",
    "apostrofasse": "apostrofare",
    "apostrofasser": "apostrofare",
    "apostrofassero": "apostrofare",
    "apostrofassi": "apostrofare",
    "apostrofassimo": "apostrofare",
    "apostrofaste": "apostrofare",
    "apostrofasti": "apostrofare",
    "apostrofata": "apostrofare",
    "apostrofate": "apostrofare",
    "apostrofati": "apostrofare",
    "apostrofato": "apostrofare",
    "apostrofava": "apostrofare",
    "apostrofavamo": "apostrofare",
    "apostrofavan": "apostrofare",
    "apostrofavano": "apostrofare",
    "apostrofavate": "apostrofare",
    "apostrofavi": "apostrofare",
    "apostrofavo": "apostrofare",
    "apostroferai": "apostrofare",
    "apostroferan": "apostrofare",
    "apostroferanno": "apostrofare",
    "apostroferebbe": "apostrofare",
    "apostroferebber": "apostrofare",
    "apostroferebbero": "apostrofare",
    "apostroferei": "apostrofare",
    "apostroferemmo": "apostrofare",
    "apostroferemo": "apostrofare",
    "apostrofereste": "apostrofare",
    "apostroferesti": "apostrofare",
    "apostroferete": "apostrofare",
    "apostroferà": "apostrofare",
    "apostroferò": "apostrofare",
    "apostrofi": "apostrofare",
    "apostrofiamo": "apostrofare",
    "apostrofiate": "apostrofare",
    "apostrofin": "apostrofare",
    "apostrofino": "apostrofare",
    "apostrofo": "apostrofare",
    "apostrofò": "apostrofare",
    "apotropaica": "apotropaico",
    "apotropaiche": "apotropaico",
    "apotropaici": "apotropaico",
    "appaga": "appagare",
    "appagai": "appagare",
    "appagammo": "appagare",
    "appagan": "appagare",
    "appagando": "appagare",
    "appagano": "appagare",
    "appagante": "appagare",
    "appaganti": "appagare",
    "appagar": "appagare",
    "appagaron": "appagare",
    "appagarono": "appagare",
    "appagasse": "appagare",
    "appagasser": "appagare",
    "appagassero": "appagare",
    "appagassi": "appagare",
    "appagassimo": "appagare",
    "appagaste": "appagare",
    "appagasti": "appagare",
    "appagata": "appagato",
    "appagate": "appagato",
    "appagati": "appagato",
    "appagato": "appagare",
    "appagava": "appagare",
    "appagavamo": "appagare",
    "appagavan": "appagare",
    "appagavano": "appagare",
    "appagavate": "appagare",
    "appagavi": "appagare",
    "appagavo": "appagare",
    "appagherai": "appagare",
    "appagheran": "appagare",
    "appagheranno": "appagare",
    "appagherebbe": "appagare",
    "appagherebber": "appagare",
    "appagherebbero": "appagare",
    "appagherei": "appagare",
    "appagheremmo": "appagare",
    "appagheremo": "appagare",
    "appaghereste": "appagare",
    "appagheresti": "appagare",
    "appagherete": "appagare",
    "appagherà": "appagare",
    "appagherò": "appagare",
    "appaghi": "appagare",
    "appaghiamo": "appagare",
    "appaghiate": "appagare",
    "appaghin": "appagare",
    "appaghino": "appagare",
    "appago": "appagare",
    "appagò": "appagare",
    "appai": "appaiare",
    "appaia": "apparire",
    "appaiai": "appaiare",
    "appaiammo": "appaiare",
    "appaiamo": "appaiare",
    "appaian": "apparire",
    "appaiando": "appaiare",
    "appaiano": "apparire",
    "appaiante": "appaiare",
    "appaianti": "appaiare",
    "appaiar": "appaiare",
    "appaiaron": "appaiare",
    "appaiarono": "appaiare",
    "appaiasse": "appaiare",
    "appaiasser": "appaiare",
    "appaiassero": "appaiare",
    "appaiassi": "appaiare",
    "appaiassimo": "appaiare",
    "appaiaste": "appaiare",
    "appaiasti": "appaiare",
    "appaiata": "appaiare",
    "appaiate": "appaiare",
    "appaiati": "appaiare",
    "appaiato": "appaiare",
    "appaiava": "appaiare",
    "appaiavamo": "appaiare",
    "appaiavan": "appaiare",
    "appaiavano": "appaiare",
    "appaiavate": "appaiare",
    "appaiavi": "appaiare",
    "appaiavo": "appaiare",
    "appaierai": "appaiare",
    "appaieran": "appaiare",
    "appaieranno": "appaiare",
    "appaierebbe": "appaiare",
    "appaierebber": "appaiare",
    "appaierebbero": "appaiare",
    "appaierei": "appaiare",
    "appaieremmo": "appaiare",
    "appaieremo": "appaiare",
    "appaiereste": "appaiare",
    "appaieresti": "appaiare",
    "appaierete": "appaiare",
    "appaierà": "appaiare",
    "appaierò": "appaiare",
    "appain": "appaiare",
    "appaino": "appaiare",
    "appaio": "apparire",
    "appaion": "apparire",
    "appaiono": "apparire",
    "appaiò": "appaiare",
    "appallottola": "appallottolare",
    "appallottolai": "appallottolare",
    "appallottolammo": "appallottolare",
    "appallottolan": "appallottolare",
    "appallottolando": "appallottolare",
    "appallottolano": "appallottolare",
    "appallottolante": "appallottolare",
    "appallottolanti": "appallottolare",
    "appallottolar": "appallottolare",
    "appallottolaron": "appallottolare",
    "appallottolarono": "appallottolare",
    "appallottolasse": "appallottolare",
    "appallottolasser": "appallottolare",
    "appallottolassero": "appallottolare",
    "appallottolassi": "appallottolare",
    "appallottolassimo": "appallottolare",
    "appallottolaste": "appallottolare",
    "appallottolasti": "appallottolare",
    "appallottolata": "appallottolare",
    "appallottolate": "appallottolare",
    "appallottolati": "appallottolare",
    "appallottolato": "appallottolare",
    "appallottolava": "appallottolare",
    "appallottolavamo": "appallottolare",
    "appallottolavan": "appallottolare",
    "appallottolavano": "appallottolare",
    "appallottolavate": "appallottolare",
    "appallottolavi": "appallottolare",
    "appallottolavo": "appallottolare",
    "appallottolerai": "appallottolare",
    "appallottoleran": "appallottolare",
    "appallottoleranno": "appallottolare",
    "appallottolerebbe": "appallottolare",
    "appallottolerebber": "appallottolare",
    "appallottolerebbero": "appallottolare",
    "appallottolerei": "appallottolare",
    "appallottoleremmo": "appallottolare",
    "appallottoleremo": "appallottolare",
    "appallottolereste": "appallottolare",
    "appallottoleresti": "appallottolare",
    "appallottolerete": "appallottolare",
    "appallottolerà": "appallottolare",
    "appallottolerò": "appallottolare",
    "appallottoli": "appallottolare",
    "appallottoliamo": "appallottolare",
    "appallottoliate": "appallottolare",
    "appallottolin": "appallottolare",
    "appallottolino": "appallottolare",
    "appallottolo": "appallottolare",
    "appallottolò": "appallottolare",
    "appalta": "appaltare",
    "appaltabili": "appaltabile",
    "appaltai": "appaltare",
    "appaltammo": "appaltare",
    "appaltan": "appaltare",
    "appaltando": "appaltare",
    "appaltano": "appaltare",
    "appaltante": "appaltare",
    "appaltanti": "appaltare",
    "appaltar": "appaltare",
    "appaltaron": "appaltare",
    "appaltarono": "appaltare",
    "appaltasse": "appaltare",
    "appaltasser": "appaltare",
    "appaltassero": "appaltare",
    "appaltassi": "appaltare",
    "appaltassimo": "appaltare",
    "appaltaste": "appaltare",
    "appaltasti": "appaltare",
    "appaltata": "appaltare",
    "appaltate": "appaltare",
    "appaltati": "appaltare",
    "appaltato": "appaltare",
    "appaltatori": "appaltatore",
    "appaltava": "appaltare",
    "appaltavamo": "appaltare",
    "appaltavan": "appaltare",
    "appaltavano": "appaltare",
    "appaltavate": "appaltare",
    "appaltavi": "appaltare",
    "appaltavo": "appaltare",
    "appalterai": "appaltare",
    "appalteran": "appaltare",
    "appalteranno": "appaltare",
    "appalterebbe": "appaltare",
    "appalterebber": "appaltare",
    "appalterebbero": "appaltare",
    "appalterei": "appaltare",
    "appalteremmo": "appaltare",
    "appalteremo": "appaltare",
    "appaltereste": "appaltare",
    "appalteresti": "appaltare",
    "appalterete": "appaltare",
    "appalterà": "appaltare",
    "appalterò": "appaltare",
    "appalti": "appalto",
    "appaltiamo": "appaltare",
    "appaltiate": "appaltare",
    "appaltin": "appaltare",
    "appaltino": "appaltare",
    "appalto": "appaltare",
    "appaltò": "appaltare",
    "appalusi": "appaluso",
    "appanna": "appannare",
    "appannaggi": "appannaggio",
    "appannai": "appannare",
    "appannamenti": "appannamento",
    "appannammo": "appannare",
    "appannan": "appannare",
    "appannando": "appannare",
    "appannano": "appannare",
    "appannante": "appannare",
    "appannanti": "appannare",
    "appannar": "appannare",
    "appannaron": "appannare",
    "appannarono": "appannare",
    "appannasse": "appannare",
    "appannasser": "appannare",
    "appannassero": "appannare",
    "appannassi": "appannare",
    "appannassimo": "appannare",
    "appannaste": "appannare",
    "appannasti": "appannare",
    "appannata": "appannare",
    "appannate": "appannare",
    "appannati": "appannare",
    "appannato": "appannare",
    "appannava": "appannare",
    "appannavamo": "appannare",
    "appannavan": "appannare",
    "appannavano": "appannare",
    "appannavate": "appannare",
    "appannavi": "appannare",
    "appannavo": "appannare",
    "appannerai": "appannare",
    "appanneran": "appannare",
    "appanneranno": "appannare",
    "appannerebbe": "appannare",
    "appannerebber": "appannare",
    "appannerebbero": "appannare",
    "appannerei": "appannare",
    "appanneremmo": "appannare",
    "appanneremo": "appannare",
    "appannereste": "appannare",
    "appanneresti": "appannare",
    "appannerete": "appannare",
    "appannerà": "appannare",
    "appannerò": "appannare",
    "appanni": "appannare",
    "appanniamo": "appannare",
    "appanniate": "appannare",
    "appannin": "appannare",
    "appannino": "appannare",
    "appanno": "appannare",
    "appannò": "appannare",
    "apparati": "apparato",
    "appare": "apparire",
    "apparecchi": "apparecchio",
    "apparecchia": "apparecchiare",
    "apparecchiai": "apparecchiare",
    "apparecchiammo": "apparecchiare",
    "apparecchiamo": "apparecchiare",
    "apparecchian": "apparecchiare",
    "apparecchiando": "apparecchiare",
    "apparecchiano": "apparecchiare",
    "apparecchiante": "apparecchiare",
    "apparecchianti": "apparecchiare",
    "apparecchiar": "apparecchiare",
    "apparecchiaron": "apparecchiare",
    "apparecchiarono": "apparecchiare",
    "apparecchiasse": "apparecchiare",
    "apparecchiasser": "apparecchiare",
    "apparecchiassero": "apparecchiare",
    "apparecchiassi": "apparecchiare",
    "apparecchiassimo": "apparecchiare",
    "apparecchiaste": "apparecchiare",
    "apparecchiasti": "apparecchiare",
    "apparecchiata": "apparecchiare",
    "apparecchiate": "apparecchiare",
    "apparecchiati": "apparecchiare",
    "apparecchiato": "apparecchiare",
    "apparecchiature": "apparecchiatura",
    "apparecchiava": "apparecchiare",
    "apparecchiavamo": "apparecchiare",
    "apparecchiavan": "apparecchiare",
    "apparecchiavano": "apparecchiare",
    "apparecchiavate": "apparecchiare",
    "apparecchiavi": "apparecchiare",
    "apparecchiavo": "apparecchiare",
    "apparecchierai": "apparecchiare",
    "apparecchieran": "apparecchiare",
    "apparecchieranno": "apparecchiare",
    "apparecchierebbe": "apparecchiare",
    "apparecchierebber": "apparecchiare",
    "apparecchierebbero": "apparecchiare",
    "apparecchierei": "apparecchiare",
    "apparecchieremmo": "apparecchiare",
    "apparecchieremo": "apparecchiare",
    "apparecchiereste": "apparecchiare",
    "apparecchieresti": "apparecchiare",
    "apparecchierete": "apparecchiare",
    "apparecchierà": "apparecchiare",
    "apparecchierò": "apparecchiare",
    "apparecchietti": "apparecchietto",
    "apparecchin": "apparecchiare",
    "apparecchino": "apparecchiare",
    "apparecchio": "apparecchiare",
    "apparecchiò": "apparecchiare",
    "apparendo": "apparire",
    "apparenta": "apparentare",
    "apparentai": "apparentare",
    "apparentamenti": "apparentamento",
    "apparentammo": "apparentare",
    "apparentan": "apparentare",
    "apparentando": "apparentare",
    "apparentano": "apparentare",
    "apparentante": "apparentare",
    "apparentanti": "apparentare",
    "apparentar": "apparentare",
    "apparentaron": "apparentare",
    "apparentarono": "apparentare",
    "apparentasse": "apparentare",
    "apparentasser": "apparentare",
    "apparentassero": "apparentare",
    "apparentassi": "apparentare",
    "apparentassimo": "apparentare",
    "apparentaste": "apparentare",
    "apparentasti": "apparentare",
    "apparentata": "apparentare",
    "apparentate": "apparentare",
    "apparentati": "apparentare",
    "apparentato": "apparentare",
    "apparentava": "apparentare",
    "apparentavamo": "apparentare",
    "apparentavan": "apparentare",
    "apparentavano": "apparentare",
    "apparentavate": "apparentare",
    "apparentavi": "apparentare",
    "apparentavo": "apparentare",
    "apparente": "apparire",
    "apparenterai": "apparentare",
    "apparenteran": "apparentare",
    "apparenteranno": "apparentare",
    "apparenterebbe": "apparentare",
    "apparenterebber": "apparentare",
    "apparenterebbero": "apparentare",
    "apparenterei": "apparentare",
    "apparenteremmo": "apparentare",
    "apparenteremo": "apparentare",
    "apparentereste": "apparentare",
    "apparenteresti": "apparentare",
    "apparenterete": "apparentare",
    "apparenterà": "apparentare",
    "apparenterò": "apparentare",
    "apparenti": "apparire",
    "apparentiamo": "apparentare",
    "apparentiate": "apparentare",
    "apparentin": "apparentare",
    "apparentino": "apparentare",
    "apparento": "apparentare",
    "apparentò": "apparentare",
    "apparenze": "apparenza",
    "appari": "apparire",
    "appariamo": "apparire",
    "appariate": "apparire",
    "apparimmo": "apparire",
    "apparir": "apparire",
    "apparirai": "apparire",
    "appariran": "apparire",
    "appariranno": "apparire",
    "apparirebbe": "apparire",
    "apparirebber": "apparire",
    "apparirebbero": "apparire",
    "apparirei": "apparire",
    "appariremmo": "apparire",
    "appariremo": "apparire",
    "apparireste": "apparire",
    "appariresti": "apparire",
    "apparirete": "apparire",
    "apparirà": "apparire",
    "apparirò": "apparire",
    "appariscenti": "appariscente",
    "apparisse": "apparire",
    "apparisser": "apparire",
    "apparissero": "apparire",
    "apparissi": "apparire",
    "apparissimo": "apparire",
    "appariste": "apparire",
    "apparisti": "apparire",
    "apparite": "apparire",
    "appariva": "apparire",
    "apparivamo": "apparire",
    "apparivan": "apparire",
    "apparivano": "apparire",
    "apparivate": "apparire",
    "apparivi": "apparire",
    "apparivo": "apparire",
    "apparizioni": "apparizione",
    "apparsa": "apparso",
    "apparse": "apparso",
    "apparsi": "apparso",
    "apparso": "apparire",
    "apparta": "appartare",
    "appartai": "appartare",
    "appartamenti": "appartamento",
    "appartamentini": "appartamentino",
    "appartammo": "appartare",
    "appartan": "appartare",
    "appartando": "appartare",
    "appartano": "appartare",
    "appartante": "appartare",
    "appartanti": "appartare",
    "appartar": "appartare",
    "appartaron": "appartare",
    "appartarono": "appartare",
    "appartasse": "appartare",
    "appartasser": "appartare",
    "appartassero": "appartare",
    "appartassi": "appartare",
    "appartassimo": "appartare",
    "appartaste": "appartare",
    "appartasti": "appartare",
    "appartata": "appartato",
    "appartate": "appartato",
    "appartati": "appartato",
    "appartato": "appartare",
    "appartava": "appartare",
    "appartavamo": "appartare",
    "appartavan": "appartare",
    "appartavano": "appartare",
    "appartavate": "appartare",
    "appartavi": "appartare",
    "appartavo": "appartare",
    "appartenemmo": "appartenere",
    "appartenendo": "appartenere",
    "appartenente": "appartenere",
    "appartenenti": "appartenere",
    "appartenenze": "appartenenza",
    "appartener": "appartenere",
    "appartenesse": "appartenere",
    "appartenesser": "appartenere",
    "appartenessero": "appartenere",
    "appartenessi": "appartenere",
    "appartenessimo": "appartenere",
    "apparteneste": "appartenere",
    "appartenesti": "appartenere",
    "appartenete": "appartenere",
    "apparteneva": "appartenere",
    "appartenevamo": "appartenere",
    "appartenevan": "appartenere",
    "appartenevano": "appartenere",
    "appartenevate": "appartenere",
    "appartenevi": "appartenere",
    "appartenevo": "appartenere",
    "appartenga": "appartenere",
    "appartengan": "appartenere",
    "appartengano": "appartenere",
    "appartengo": "appartenere",
    "appartengon": "appartenere",
    "appartengono": "appartenere",
    "apparteniamo": "appartenere",
    "apparteniate": "appartenere",
    "appartenne": "appartenere",
    "appartenner": "appartenere",
    "appartennero": "appartenere",
    "appartenni": "appartenere",
    "appartenuta": "appartenere",
    "appartenute": "appartenere",
    "appartenuti": "appartenere",
    "appartenuto": "appartenere",
    "apparterai": "appartare",
    "apparteran": "appartare",
    "apparteranno": "appartare",
    "apparterebbe": "appartare",
    "apparterebber": "appartare",
    "apparterebbero": "appartare",
    "apparterei": "appartare",
    "apparteremmo": "appartare",
    "apparteremo": "appartare",
    "appartereste": "appartare",
    "apparteresti": "appartare",
    "apparterete": "appartare",
    "apparterrai": "appartenere",
    "apparterran": "appartenere",
    "apparterranno": "appartenere",
    "apparterrebbe": "appartenere",
    "apparterrebber": "appartenere",
    "apparterrebbero": "appartenere",
    "apparterrei": "appartenere",
    "apparterremmo": "appartenere",
    "apparterremo": "appartenere",
    "apparterreste": "appartenere",
    "apparterresti": "appartenere",
    "apparterrete": "appartenere",
    "apparterrà": "appartenere",
    "apparterrò": "appartenere",
    "apparterà": "appartare",
    "apparterò": "appartare",
    "apparti": "appartare",
    "appartiamo": "appartare",
    "appartiate": "appartare",
    "appartiene": "appartenere",
    "appartieni": "appartenere",
    "appartin": "appartare",
    "appartino": "appartare",
    "apparto": "appartare",
    "appartò": "appartare",
    "apparve": "apparire",
    "apparver": "apparire",
    "apparvero": "apparire",
    "apparvi": "apparire",
    "appassendo": "appassire",
    "appassente": "appassire",
    "appassenti": "appassire",
    "appassiamo": "appassire",
    "appassiate": "appassire",
    "appassii": "appassire",
    "appassimmo": "appassire",
    "appassiona": "appassionare",
    "appassionai": "appassionare",
    "appassionammo": "appassionare",
    "appassionan": "appassionare",
    "appassionando": "appassionare",
    "appassionano": "appassionare",
    "appassionante": "appassionare",
    "appassionanti": "appassionare",
    "appassionar": "appassionare",
    "appassionaron": "appassionare",
    "appassionarono": "appassionare",
    "appassionasse": "appassionare",
    "appassionasser": "appassionare",
    "appassionassero": "appassionare",
    "appassionassi": "appassionare",
    "appassionassimo": "appassionare",
    "appassionaste": "appassionare",
    "appassionasti": "appassionare",
    "appassionata": "appassionato",
    "appassionate": "appassionato",
    "appassionati": "appassionato",
    "appassionato": "appassionare",
    "appassionava": "appassionare",
    "appassionavamo": "appassionare",
    "appassionavan": "appassionare",
    "appassionavano": "appassionare",
    "appassionavate": "appassionare",
    "appassionavi": "appassionare",
    "appassionavo": "appassionare",
    "appassionerai": "appassionare",
    "appassioneran": "appassionare",
    "appassioneranno": "appassionare",
    "appassionerebbe": "appassionare",
    "appassionerebber": "appassionare",
    "appassionerebbero": "appassionare",
    "appassionerei": "appassionare",
    "appassioneremmo": "appassionare",
    "appassioneremo": "appassionare",
    "appassionereste": "appassionare",
    "appassioneresti": "appassionare",
    "appassionerete": "appassionare",
    "appassionerà": "appassionare",
    "appassionerò": "appassionare",
    "appassioni": "appassionare",
    "appassioniamo": "appassionare",
    "appassioniate": "appassionare",
    "appassionin": "appassionare",
    "appassionino": "appassionare",
    "appassiono": "appassionare",
    "appassionò": "appassionare",
    "appassir": "appassire",
    "appassirai": "appassire",
    "appassiran": "appassire",
    "appassiranno": "appassire",
    "appassirebbe": "appassire",
    "appassirebber": "appassire",
    "appassirebbero": "appassire",
    "appassirei": "appassire",
    "appassiremmo": "appassire",
    "appassiremo": "appassire",
    "appassireste": "appassire",
    "appassiresti": "appassire",
    "appassirete": "appassire",
    "appassiron": "appassire",
    "appassirono": "appassire",
    "appassirà": "appassire",
    "appassirò": "appassire",
    "appassisca": "appassire",
    "appassiscan": "appassire",
    "appassiscano": "appassire",
    "appassisce": "appassire",
    "appassisci": "appassire",
    "appassisco": "appassire",
    "appassiscon": "appassire",
    "appassiscono": "appassire",
    "appassisse": "appassire",
    "appassisser": "appassire",
    "appassissero": "appassire",
    "appassissi": "appassire",
    "appassissimo": "appassire",
    "appassiste": "appassire",
    "appassisti": "appassire",
    "appassita": "appassire",
    "appassite": "appassire",
    "appassiti": "appassire",
    "appassito": "appassire",
    "appassiva": "appassire",
    "appassivamo": "appassire",
    "appassivan": "appassire",
    "appassivano": "appassire",
    "appassivate": "appassire",
    "appassivi": "appassire",
    "appassivo": "appassire",
    "appassì": "appassire",
    "appella": "appellare",
    "appellabili": "appellabile",
    "appellai": "appellare",
    "appellammo": "appellare",
    "appellan": "appellare",
    "appellando": "appellare",
    "appellano": "appellare",
    "appellante": "appellare",
    "appellanti": "appellare",
    "appellar": "appellare",
    "appellaron": "appellare",
    "appellarono": "appellare",
    "appellasse": "appellare",
    "appellasser": "appellare",
    "appellassero": "appellare",
    "appellassi": "appellare",
    "appellassimo": "appellare",
    "appellaste": "appellare",
    "appellasti": "appellare",
    "appellata": "appellare",
    "appellate": "appellare",
    "appellati": "appellare",
    "appellativi": "appellativo",
    "appellato": "appellare",
    "appellava": "appellare",
    "appellavamo": "appellare",
    "appellavan": "appellare",
    "appellavano": "appellare",
    "appellavate": "appellare",
    "appellavi": "appellare",
    "appellavo": "appellare",
    "appellerai": "appellare",
    "appelleran": "appellare",
    "appelleranno": "appellare",
    "appellerebbe": "appellare",
    "appellerebber": "appellare",
    "appellerebbero": "appellare",
    "appellerei": "appellare",
    "appelleremmo": "appellare",
    "appelleremo": "appellare",
    "appellereste": "appellare",
    "appelleresti": "appellare",
    "appellerete": "appellare",
    "appellerà": "appellare",
    "appellerò": "appellare",
    "appelli": "appello",
    "appelliamo": "appellare",
    "appelliate": "appellare",
    "appellin": "appellare",
    "appellino": "appellare",
    "appello": "appellare",
    "appellò": "appellare",
    "appenda": "appendere",
    "appendan": "appendere",
    "appendano": "appendere",
    "appende": "appendere",
    "appendemmo": "appendere",
    "appendendo": "appendere",
    "appendente": "appendere",
    "appendenti": "appendere",
    "appender": "appendere",
    "appenderai": "appendere",
    "appenderan": "appendere",
    "appenderanno": "appendere",
    "appenderebbe": "appendere",
    "appenderebber": "appendere",
    "appenderebbero": "appendere",
    "appenderei": "appendere",
    "appenderemmo": "appendere",
    "appenderemo": "appendere",
    "appendereste": "appendere",
    "appenderesti": "appendere",
    "appenderete": "appendere",
    "appenderà": "appendere",
    "appenderò": "appendere",
    "appendesse": "appendere",
    "appendesser": "appendere",
    "appendessero": "appendere",
    "appendessi": "appendere",
    "appendessimo": "appendere",
    "appendeste": "appendere",
    "appendesti": "appendere",
    "appendete": "appendere",
    "appendeva": "appendere",
    "appendevamo": "appendere",
    "appendevan": "appendere",
    "appendevano": "appendere",
    "appendevate": "appendere",
    "appendevi": "appendere",
    "appendevo": "appendere",
    "appendi": "appendere",
    "appendiamo": "appendere",
    "appendiate": "appendere",
    "appendibili": "appendibile",
    "appendici": "appendice",
    "appendiciti": "appendicite",
    "appendo": "appendere",
    "appendon": "appendere",
    "appendono": "appendere",
    "appennini": "appennino",
    "appenninica": "appenninico",
    "appenniniche": "appenninico",
    "appenninici": "appenninico",
    "appesa": "appeso",
    "appesantendo": "appesantire",
    "appesantente": "appesantire",
    "appesantenti": "appesantire",
    "appesantiamo": "appesantire",
    "appesantiate": "appesantire",
    "appesantii": "appesantire",
    "appesantimenti": "appesantimento",
    "appesantimmo": "appesantire",
    "appesantir": "appesantire",
    "appesantirai": "appesantire",
    "appesantiran": "appesantire",
    "appesantiranno": "appesantire",
    "appesantirebbe": "appesantire",
    "appesantirebber": "appesantire",
    "appesantirebbero": "appesantire",
    "appesantirei": "appesantire",
    "appesantiremmo": "appesantire",
    "appesantiremo": "appesantire",
    "appesantireste": "appesantire",
    "appesantiresti": "appesantire",
    "appesantirete": "appesantire",
    "appesantiron": "appesantire",
    "appesantirono": "appesantire",
    "appesantirà": "appesantire",
    "appesantirò": "appesantire",
    "appesantisca": "appesantire",
    "appesantiscan": "appesantire",
    "appesantiscano": "appesantire",
    "appesantisce": "appesantire",
    "appesantisci": "appesantire",
    "appesantisco": "appesantire",
    "appesantiscon": "appesantire",
    "appesantiscono": "appesantire",
    "appesantisse": "appesantire",
    "appesantisser": "appesantire",
    "appesantissero": "appesantire",
    "appesantissi": "appesantire",
    "appesantissimo": "appesantire",
    "appesantiste": "appesantire",
    "appesantisti": "appesantire",
    "appesantita": "appesantire",
    "appesantite": "appesantire",
    "appesantiti": "appesantire",
    "appesantito": "appesantire",
    "appesantiva": "appesantire",
    "appesantivamo": "appesantire",
    "appesantivan": "appesantire",
    "appesantivano": "appesantire",
    "appesantivate": "appesantire",
    "appesantivi": "appesantire",
    "appesantivo": "appesantire",
    "appesantì": "appesantire",
    "appese": "appeso",
    "appeser": "appendere",
    "appesero": "appendere",
    "appesi": "appeso",
    "appeso": "appendere",
    "appesta": "appestare",
    "appestai": "appestare",
    "appestammo": "appestare",
    "appestan": "appestare",
    "appestando": "appestare",
    "appestano": "appestare",
    "appestante": "appestare",
    "appestanti": "appestare",
    "appestar": "appestare",
    "appestaron": "appestare",
    "appestarono": "appestare",
    "appestasse": "appestare",
    "appestasser": "appestare",
    "appestassero": "appestare",
    "appestassi": "appestare",
    "appestassimo": "appestare",
    "appestaste": "appestare",
    "appestasti": "appestare",
    "appestata": "appestato",
    "appestate": "appestato",
    "appestati": "appestato",
    "appestato": "appestare",
    "appestava": "appestare",
    "appestavamo": "appestare",
    "appestavan": "appestare",
    "appestavano": "appestare",
    "appestavate": "appestare",
    "appestavi": "appestare",
    "appestavo": "appestare",
    "appesterai": "appestare",
    "appesteran": "appestare",
    "appesteranno": "appestare",
    "appesterebbe": "appestare",
    "appesterebber": "appestare",
    "appesterebbero": "appestare",
    "appesterei": "appestare",
    "appesteremmo": "appestare",
    "appesteremo": "appestare",
    "appestereste": "appestare",
    "appesteresti": "appestare",
    "appesterete": "appestare",
    "appesterà": "appestare",
    "appesterò": "appestare",
    "appesti": "appestare",
    "appestiamo": "appestare",
    "appestiate": "appestare",
    "appestin": "appestare",
    "appestino": "appestare",
    "appesto": "appestare",
    "appestò": "appestare",
    "appesè": "appendere",
    "appetendo": "appetire",
    "appetente": "appetire",
    "appetenti": "appetire",
    "appetiamo": "appetire",
    "appetiate": "appetire",
    "appetibili": "appetibile",
    "appetii": "appetire",
    "appetimmo": "appetire",
    "appetir": "appetire",
    "appetirai": "appetire",
    "appetiran": "appetire",
    "appetiranno": "appetire",
    "appetirebbe": "appetire",
    "appetirebber": "appetire",
    "appetirebbero": "appetire",
    "appetirei": "appetire",
    "appetiremmo": "appetire",
    "appetiremo": "appetire",
    "appetireste": "appetire",
    "appetiresti": "appetire",
    "appetirete": "appetire",
    "appetiron": "appetire",
    "appetirono": "appetire",
    "appetirà": "appetire",
    "appetirò": "appetire",
    "appetisca": "appetire",
    "appetiscan": "appetire",
    "appetiscano": "appetire",
    "appetisce": "appetire",
    "appetisci": "appetire",
    "appetisco": "appetire",
    "appetiscon": "appetire",
    "appetiscono": "appetire",
    "appetisse": "appetire",
    "appetisser": "appetire",
    "appetissero": "appetire",
    "appetissi": "appetire",
    "appetissimo": "appetire",
    "appetiste": "appetire",
    "appetisti": "appetire",
    "appetita": "appetire",
    "appetite": "appetire",
    "appetiti": "appetito",
    "appetito": "appetire",
    "appetitosa": "appetitoso",
    "appetitose": "appetitoso",
    "appetitosi": "appetitoso",
    "appetiva": "appetire",
    "appetivamo": "appetire",
    "appetivan": "appetire",
    "appetivano": "appetire",
    "appetivate": "appetire",
    "appetivi": "appetire",
    "appetivo": "appetire",
    "appettiti": "appettito",
    "appetì": "appetire",
    "appezza": "appezzare",
    "appezzai": "appezzare",
    "appezzamenti": "appezzamento",
    "appezzammo": "appezzare",
    "appezzan": "appezzare",
    "appezzando": "appezzare",
    "appezzano": "appezzare",
    "appezzante": "appezzare",
    "appezzanti": "appezzare",
    "appezzar": "appezzare",
    "appezzaron": "appezzare",
    "appezzarono": "appezzare",
    "appezzasse": "appezzare",
    "appezzasser": "appezzare",
    "appezzassero": "appezzare",
    "appezzassi": "appezzare",
    "appezzassimo": "appezzare",
    "appezzaste": "appezzare",
    "appezzasti": "appezzare",
    "appezzata": "appezzare",
    "appezzate": "appezzare",
    "appezzati": "appezzare",
    "appezzato": "appezzare",
    "appezzava": "appezzare",
    "appezzavamo": "appezzare",
    "appezzavan": "appezzare",
    "appezzavano": "appezzare",
    "appezzavate": "appezzare",
    "appezzavi": "appezzare",
    "appezzavo": "appezzare",
    "appezzerai": "appezzare",
    "appezzeran": "appezzare",
    "appezzeranno": "appezzare",
    "appezzerebbe": "appezzare",
    "appezzerebber": "appezzare",
    "appezzerebbero": "appezzare",
    "appezzerei": "appezzare",
    "appezzeremmo": "appezzare",
    "appezzeremo": "appezzare",
    "appezzereste": "appezzare",
    "appezzeresti": "appezzare",
    "appezzerete": "appezzare",
    "appezzerà": "appezzare",
    "appezzerò": "appezzare",
    "appezzi": "appezzare",
    "appezziamo": "appezzare",
    "appezziate": "appezzare",
    "appezzin": "appezzare",
    "appezzino": "appezzare",
    "appezzo": "appezzare",
    "appezzò": "appezzare",
    "appiana": "appianare",
    "appianabili": "appianabile",
    "appianai": "appianare",
    "appianammo": "appianare",
    "appianan": "appianare",
    "appianando": "appianare",
    "appianano": "appianare",
    "appianante": "appianare",
    "appiananti": "appianare",
    "appianar": "appianare",
    "appianaron": "appianare",
    "appianarono": "appianare",
    "appianasse": "appianare",
    "appianasser": "appianare",
    "appianassero": "appianare",
    "appianassi": "appianare",
    "appianassimo": "appianare",
    "appianaste": "appianare",
    "appianasti": "appianare",
    "appianata": "appianare",
    "appianate": "appianare",
    "appianati": "appianare",
    "appianato": "appianare",
    "appianava": "appianare",
    "appianavamo": "appianare",
    "appianavan": "appianare",
    "appianavano": "appianare",
    "appianavate": "appianare",
    "appianavi": "appianare",
    "appianavo": "appianare",
    "appianerai": "appianare",
    "appianeran": "appianare",
    "appianeranno": "appianare",
    "appianerebbe": "appianare",
    "appianerebber": "appianare",
    "appianerebbero": "appianare",
    "appianerei": "appianare",
    "appianeremmo": "appianare",
    "appianeremo": "appianare",
    "appianereste": "appianare",
    "appianeresti": "appianare",
    "appianerete": "appianare",
    "appianerà": "appianare",
    "appianerò": "appianare",
    "appiani": "appianare",
    "appianiamo": "appianare",
    "appianiate": "appianare",
    "appianin": "appianare",
    "appianino": "appianare",
    "appiano": "appianare",
    "appianò": "appianare",
    "appiatta": "appiattare",
    "appiattai": "appiattare",
    "appiattammo": "appiattare",
    "appiattan": "appiattare",
    "appiattando": "appiattare",
    "appiattano": "appiattare",
    "appiattante": "appiattare",
    "appiattanti": "appiattare",
    "appiattar": "appiattare",
    "appiattaron": "appiattare",
    "appiattarono": "appiattare",
    "appiattasse": "appiattare",
    "appiattasser": "appiattare",
    "appiattassero": "appiattare",
    "appiattassi": "appiattare",
    "appiattassimo": "appiattare",
    "appiattaste": "appiattare",
    "appiattasti": "appiattare",
    "appiattata": "appiattare",
    "appiattate": "appiattare",
    "appiattati": "appiattare",
    "appiattato": "appiattare",
    "appiattava": "appiattare",
    "appiattavamo": "appiattare",
    "appiattavan": "appiattare",
    "appiattavano": "appiattare",
    "appiattavate": "appiattare",
    "appiattavi": "appiattare",
    "appiattavo": "appiattare",
    "appiatterai": "appiattare",
    "appiatteran": "appiattare",
    "appiatteranno": "appiattare",
    "appiatterebbe": "appiattare",
    "appiatterebber": "appiattare",
    "appiatterebbero": "appiattare",
    "appiatterei": "appiattare",
    "appiatteremmo": "appiattare",
    "appiatteremo": "appiattare",
    "appiattereste": "appiattare",
    "appiatteresti": "appiattare",
    "appiatterete": "appiattare",
    "appiatterà": "appiattare",
    "appiatterò": "appiattare",
    "appiatti": "appiattare",
    "appiattiamo": "appiattare",
    "appiattiate": "appiattare",
    "appiattimenti": "appiattimento",
    "appiattin": "appiattare",
    "appiattino": "appiattare",
    "appiatto": "appiattare",
    "appiattò": "appiattare",
    "appicca": "appiccare",
    "appiccai": "appiccare",
    "appiccammo": "appiccare",
    "appiccan": "appiccare",
    "appiccando": "appiccare",
    "appiccano": "appiccare",
    "appiccante": "appiccare",
    "appiccanti": "appiccare",
    "appiccar": "appiccare",
    "appiccaron": "appiccare",
    "appiccarono": "appiccare",
    "appiccasse": "appiccare",
    "appiccasser": "appiccare",
    "appiccassero": "appiccare",
    "appiccassi": "appiccare",
    "appiccassimo": "appiccare",
    "appiccaste": "appiccare",
    "appiccasti": "appiccare",
    "appiccata": "appiccare",
    "appiccate": "appiccare",
    "appiccati": "appiccare",
    "appiccato": "appiccare",
    "appiccava": "appiccare",
    "appiccavamo": "appiccare",
    "appiccavan": "appiccare",
    "appiccavano": "appiccare",
    "appiccavate": "appiccare",
    "appiccavi": "appiccare",
    "appiccavo": "appiccare",
    "appiccherai": "appiccare",
    "appiccheran": "appiccare",
    "appiccheranno": "appiccare",
    "appiccherebbe": "appiccare",
    "appiccherebber": "appiccare",
    "appiccherebbero": "appiccare",
    "appiccherei": "appiccare",
    "appiccheremmo": "appiccare",
    "appiccheremo": "appiccare",
    "appicchereste": "appiccare",
    "appiccheresti": "appiccare",
    "appiccherete": "appiccare",
    "appiccherà": "appiccare",
    "appiccherò": "appiccare",
    "appicchi": "appiccare",
    "appicchiamo": "appiccare",
    "appicchiate": "appiccare",
    "appicchin": "appiccare",
    "appicchino": "appiccare",
    "appiccica": "appiccicare",
    "appiccicai": "appiccicare",
    "appiccicammo": "appiccicare",
    "appiccican": "appiccicare",
    "appiccicando": "appiccicare",
    "appiccicano": "appiccicare",
    "appiccicante": "appiccicare",
    "appiccicanti": "appiccicare",
    "appiccicar": "appiccicare",
    "appiccicaron": "appiccicare",
    "appiccicarono": "appiccicare",
    "appiccicasse": "appiccicare",
    "appiccicasser": "appiccicare",
    "appiccicassero": "appiccicare",
    "appiccicassi": "appiccicare",
    "appiccicassimo": "appiccicare",
    "appiccicaste": "appiccicare",
    "appiccicasti": "appiccicare",
    "appiccicata": "appiccicare",
    "appiccicate": "appiccicare",
    "appiccicati": "appiccicare",
    "appiccicato": "appiccicare",
    "appiccicava": "appiccicare",
    "appiccicavamo": "appiccicare",
    "appiccicavan": "appiccicare",
    "appiccicavano": "appiccicare",
    "appiccicavate": "appiccicare",
    "appiccicavi": "appiccicare",
    "appiccicavo": "appiccicare",
    "appiccicherai": "appiccicare",
    "appiccicheran": "appiccicare",
    "appiccicheranno": "appiccicare",
    "appiccicherebbe": "appiccicare",
    "appiccicherebber": "appiccicare",
    "appiccicherebbero": "appiccicare",
    "appiccicherei": "appiccicare",
    "appiccicheremmo": "appiccicare",
    "appiccicheremo": "appiccicare",
    "appiccichereste": "appiccicare",
    "appiccicheresti": "appiccicare",
    "appiccicherete": "appiccicare",
    "appiccicherà": "appiccicare",
    "appiccicherò": "appiccicare",
    "appiccichi": "appiccicare",
    "appiccichiamo": "appiccicare",
    "appiccichiate": "appiccicare",
    "appiccichin": "appiccicare",
    "appiccichino": "appiccicare",
    "appiccico": "appiccicare",
    "appiccicosa": "appiccicoso",
    "appiccicose": "appiccicoso",
    "appiccicosi": "appiccicoso",
    "appiccicò": "appiccicare",
    "appicco": "appiccare",
    "appiccò": "appiccare",
    "appieda": "appiedare",
    "appiedai": "appiedare",
    "appiedammo": "appiedare",
    "appiedan": "appiedare",
    "appiedando": "appiedare",
    "appiedano": "appiedare",
    "appiedante": "appiedare",
    "appiedanti": "appiedare",
    "appiedar": "appiedare",
    "appiedaron": "appiedare",
    "appiedarono": "appiedare",
    "appiedasse": "appiedare",
    "appiedasser": "appiedare",
    "appiedassero": "appiedare",
    "appiedassi": "appiedare",
    "appiedassimo": "appiedare",
    "appiedaste": "appiedare",
    "appiedasti": "appiedare",
    "appiedata": "appiedare",
    "appiedate": "appiedare",
    "appiedati": "appiedare",
    "appiedato": "appiedare",
    "appiedava": "appiedare",
    "appiedavamo": "appiedare",
    "appiedavan": "appiedare",
    "appiedavano": "appiedare",
    "appiedavate": "appiedare",
    "appiedavi": "appiedare",
    "appiedavo": "appiedare",
    "appiederai": "appiedare",
    "appiederan": "appiedare",
    "appiederanno": "appiedare",
    "appiederebbe": "appiedare",
    "appiederebber": "appiedare",
    "appiederebbero": "appiedare",
    "appiederei": "appiedare",
    "appiederemmo": "appiedare",
    "appiederemo": "appiedare",
    "appiedereste": "appiedare",
    "appiederesti": "appiedare",
    "appiederete": "appiedare",
    "appiederà": "appiedare",
    "appiederò": "appiedare",
    "appiedi": "appiedare",
    "appiediamo": "appiedare",
    "appiediate": "appiedare",
    "appiedin": "appiedare",
    "appiedino": "appiedare",
    "appiedo": "appiedare",
    "appiedò": "appiedare",
    "appigli": "appiglio",
    "appiglia": "appigliare",
    "appigliai": "appigliare",
    "appigliammo": "appigliare",
    "appigliamo": "appigliare",
    "appiglian": "appigliare",
    "appigliando": "appigliare",
    "appigliano": "appigliare",
    "appigliar": "appigliare",
    "appigliaron": "appigliare",
    "appigliarono": "appigliare",
    "appigliasse": "appigliare",
    "appigliasser": "appigliare",
    "appigliassero": "appigliare",
    "appigliassi": "appigliare",
    "appigliassimo": "appigliare",
    "appigliaste": "appigliare",
    "appigliasti": "appigliare",
    "appigliata": "appigliare",
    "appigliate": "appigliare",
    "appigliati": "appigliare",
    "appigliato": "appigliare",
    "appigliava": "appigliare",
    "appigliavamo": "appigliare",
    "appigliavan": "appigliare",
    "appigliavano": "appigliare",
    "appigliavate": "appigliare",
    "appigliavi": "appigliare",
    "appigliavo": "appigliare",
    "appiglierai": "appigliare",
    "appiglieran": "appigliare",
    "appiglieranno": "appigliare",
    "appiglierebbe": "appigliare",
    "appiglierebber": "appigliare",
    "appiglierebbero": "appigliare",
    "appiglierei": "appigliare",
    "appiglieremmo": "appigliare",
    "appiglieremo": "appigliare",
    "appigliereste": "appigliare",
    "appiglieresti": "appigliare",
    "appiglierete": "appigliare",
    "appiglierà": "appigliare",
    "appiglierò": "appigliare",
    "appiglin": "appigliare",
    "appiglino": "appigliare",
    "appiglio": "appigliare",
    "appigliò": "appigliare",
    "appioppa": "appioppare",
    "appioppai": "appioppare",
    "appioppammo": "appioppare",
    "appioppan": "appioppare",
    "appioppando": "appioppare",
    "appioppano": "appioppare",
    "appioppante": "appioppare",
    "appioppanti": "appioppare",
    "appioppar": "appioppare",
    "appiopparon": "appioppare",
    "appiopparono": "appioppare",
    "appioppasse": "appioppare",
    "appioppasser": "appioppare",
    "appioppassero": "appioppare",
    "appioppassi": "appioppare",
    "appioppassimo": "appioppare",
    "appioppaste": "appioppare",
    "appioppasti": "appioppare",
    "appioppata": "appioppare",
    "appioppate": "appioppare",
    "appioppati": "appioppare",
    "appioppato": "appioppare",
    "appioppava": "appioppare",
    "appioppavamo": "appioppare",
    "appioppavan": "appioppare",
    "appioppavano": "appioppare",
    "appioppavate": "appioppare",
    "appioppavi": "appioppare",
    "appioppavo": "appioppare",
    "appiopperai": "appioppare",
    "appiopperan": "appioppare",
    "appiopperanno": "appioppare",
    "appiopperebbe": "appioppare",
    "appiopperebber": "appioppare",
    "appiopperebbero": "appioppare",
    "appiopperei": "appioppare",
    "appiopperemmo": "appioppare",
    "appiopperemo": "appioppare",
    "appioppereste": "appioppare",
    "appiopperesti": "appioppare",
    "appiopperete": "appioppare",
    "appiopperà": "appioppare",
    "appiopperò": "appioppare",
    "appioppi": "appioppare",
    "appioppiamo": "appioppare",
    "appioppiate": "appioppare",
    "appioppin": "appioppare",
    "appioppino": "appioppare",
    "appioppo": "appioppare",
    "appioppò": "appioppare",
    "appisola": "appisolare",
    "appisolai": "appisolare",
    "appisolammo": "appisolare",
    "appisolan": "appisolare",
    "appisolando": "appisolare",
    "appisolano": "appisolare",
    "appisolar": "appisolare",
    "appisolaron": "appisolare",
    "appisolarono": "appisolare",
    "appisolasse": "appisolare",
    "appisolasser": "appisolare",
    "appisolassero": "appisolare",
    "appisolassi": "appisolare",
    "appisolassimo": "appisolare",
    "appisolaste": "appisolare",
    "appisolasti": "appisolare",
    "appisolata": "appisolare",
    "appisolate": "appisolare",
    "appisolati": "appisolare",
    "appisolato": "appisolare",
    "appisolava": "appisolare",
    "appisolavamo": "appisolare",
    "appisolavan": "appisolare",
    "appisolavano": "appisolare",
    "appisolavate": "appisolare",
    "appisolavi": "appisolare",
    "appisolavo": "appisolare",
    "appisolerai": "appisolare",
    "appisoleran": "appisolare",
    "appisoleranno": "appisolare",
    "appisolerebbe": "appisolare",
    "appisolerebber": "appisolare",
    "appisolerebbero": "appisolare",
    "appisolerei": "appisolare",
    "appisoleremmo": "appisolare",
    "appisoleremo": "appisolare",
    "appisolereste": "appisolare",
    "appisoleresti": "appisolare",
    "appisolerete": "appisolare",
    "appisolerà": "appisolare",
    "appisolerò": "appisolare",
    "appisoli": "appisolare",
    "appisoliamo": "appisolare",
    "appisoliate": "appisolare",
    "appisolin": "appisolare",
    "appisolino": "appisolare",
    "appisolo": "appisolare",
    "appisolò": "appisolare",
    "applauda": "applaudire",
    "applaudan": "applaudire",
    "applaudano": "applaudire",
    "applaude": "applaudire",
    "applaudendo": "applaudire",
    "applaudente": "applaudire",
    "applaudenti": "applaudire",
    "applaudi": "applaudire",
    "applaudiamo": "applaudire",
    "applaudiate": "applaudire",
    "applaudii": "applaudire",
    "applaudimmo": "applaudire",
    "applaudir": "applaudire",
    "applaudirai": "applaudire",
    "applaudiran": "applaudire",
    "applaudiranno": "applaudire",
    "applaudirebbe": "applaudire",
    "applaudirebber": "applaudire",
    "applaudirebbero": "applaudire",
    "applaudirei": "applaudire",
    "applaudiremmo": "applaudire",
    "applaudiremo": "applaudire",
    "applaudireste": "applaudire",
    "applaudiresti": "applaudire",
    "applaudirete": "applaudire",
    "applaudiron": "applaudire",
    "applaudirono": "applaudire",
    "applaudirà": "applaudire",
    "applaudirò": "applaudire",
    "applaudisse": "applaudire",
    "applaudisser": "applaudire",
    "applaudissero": "applaudire",
    "applaudissi": "applaudire",
    "applaudissimo": "applaudire",
    "applaudiste": "applaudire",
    "applaudisti": "applaudire",
    "applaudita": "applaudito",
    "applaudite": "applaudito",
    "applauditi": "applaudito",
    "applaudito": "applaudire",
    "applaudiva": "applaudire",
    "applaudivamo": "applaudire",
    "applaudivan": "applaudire",
    "applaudivano": "applaudire",
    "applaudivate": "applaudire",
    "applaudivi": "applaudire",
    "applaudivo": "applaudire",
    "applaudo": "applaudire",
    "applaudon": "applaudire",
    "applaudono": "applaudire",
    "applaudì": "applaudire",
    "applausi": "applauso",
    "applica": "applicare",
    "applicabili": "applicabile",
    "applicai": "applicare",
    "applicammo": "applicare",
    "applican": "applicare",
    "applicando": "applicare",
    "applicano": "applicare",
    "applicante": "applicare",
    "applicanti": "applicare",
    "applicar": "applicare",
    "applicaron": "applicare",
    "applicarono": "applicare",
    "applicasse": "applicare",
    "applicasser": "applicare",
    "applicassero": "applicare",
    "applicassi": "applicare",
    "applicassimo": "applicare",
    "applicaste": "applicare",
    "applicasti": "applicare",
    "applicata": "applicato",
    "applicate": "applicato",
    "applicati": "applicato",
    "applicativa": "applicativo",
    "applicative": "applicativo",
    "applicativi": "applicativo",
    "applicato": "applicare",
    "applicava": "applicare",
    "applicavamo": "applicare",
    "applicavan": "applicare",
    "applicavano": "applicare",
    "applicavate": "applicare",
    "applicavi": "applicare",
    "applicavo": "applicare",
    "applicazioni": "applicazione",
    "applicherai": "applicare",
    "applicheran": "applicare",
    "applicheranno": "applicare",
    "applicherebbe": "applicare",
    "applicherebber": "applicare",
    "applicherebbero": "applicare",
    "applicherei": "applicare",
    "applicheremmo": "applicare",
    "applicheremo": "applicare",
    "applichereste": "applicare",
    "applicheresti": "applicare",
    "applicherete": "applicare",
    "applicherà": "applicare",
    "applicherò": "applicare",
    "applichi": "applicare",
    "applichiamo": "applicare",
    "applichiate": "applicare",
    "applichin": "applicare",
    "applichino": "applicare",
    "applico": "applicare",
    "applicò": "applicare",
    "appoggerai": "appoggiare",
    "appoggeran": "appoggiare",
    "appoggeranno": "appoggiare",
    "appoggerebbe": "appoggiare",
    "appoggerebber": "appoggiare",
    "appoggerebbero": "appoggiare",
    "appoggerei": "appoggiare",
    "appoggeremmo": "appoggiare",
    "appoggeremo": "appoggiare",
    "appoggereste": "appoggiare",
    "appoggeresti": "appoggiare",
    "appoggerete": "appoggiare",
    "appoggerà": "appoggiare",
    "appoggerò": "appoggiare",
    "appoggi": "appoggio",
    "appoggia": "appoggiare",
    "appoggiai": "appoggiare",
    "appoggiammo": "appoggiare",
    "appoggiamo": "appoggiare",
    "appoggian": "appoggiare",
    "appoggiando": "appoggiare",
    "appoggiano": "appoggiare",
    "appoggiante": "appoggiare",
    "appoggianti": "appoggiare",
    "appoggiar": "appoggiare",
    "appoggiaron": "appoggiare",
    "appoggiarono": "appoggiare",
    "appoggiasse": "appoggiare",
    "appoggiasser": "appoggiare",
    "appoggiassero": "appoggiare",
    "appoggiassi": "appoggiare",
    "appoggiassimo": "appoggiare",
    "appoggiaste": "appoggiare",
    "appoggiasti": "appoggiare",
    "appoggiata": "appoggiare",
    "appoggiate": "appoggiare",
    "appoggiati": "appoggiare",
    "appoggiato": "appoggiare",
    "appoggiava": "appoggiare",
    "appoggiavamo": "appoggiare",
    "appoggiavan": "appoggiare",
    "appoggiavano": "appoggiare",
    "appoggiavate": "appoggiare",
    "appoggiavi": "appoggiare",
    "appoggiavo": "appoggiare",
    "appoggin": "appoggiare",
    "appoggino": "appoggiare",
    "appoggio": "appoggiare",
    "appoggiò": "appoggiare",
    "appollai": "appollaiare",
    "appollaia": "appollaiare",
    "appollaiai": "appollaiare",
    "appollaiammo": "appollaiare",
    "appollaiamo": "appollaiare",
    "appollaian": "appollaiare",
    "appollaiando": "appollaiare",
    "appollaiano": "appollaiare",
    "appollaiar": "appollaiare",
    "appollaiaron": "appollaiare",
    "appollaiarono": "appollaiare",
    "appollaiasse": "appollaiare",
    "appollaiasser": "appollaiare",
    "appollaiassero": "appollaiare",
    "appollaiassi": "appollaiare",
    "appollaiassimo": "appollaiare",
    "appollaiaste": "appollaiare",
    "appollaiasti": "appollaiare",
    "appollaiata": "appollaiare",
    "appollaiate": "appollaiare",
    "appollaiati": "appollaiare",
    "appollaiato": "appollaiare",
    "appollaiava": "appollaiare",
    "appollaiavamo": "appollaiare",
    "appollaiavan": "appollaiare",
    "appollaiavano": "appollaiare",
    "appollaiavate": "appollaiare",
    "appollaiavi": "appollaiare",
    "appollaiavo": "appollaiare",
    "appollaierai": "appollaiare",
    "appollaieran": "appollaiare",
    "appollaieranno": "appollaiare",
    "appollaierebbe": "appollaiare",
    "appollaierebber": "appollaiare",
    "appollaierebbero": "appollaiare",
    "appollaierei": "appollaiare",
    "appollaieremmo": "appollaiare",
    "appollaieremo": "appollaiare",
    "appollaiereste": "appollaiare",
    "appollaieresti": "appollaiare",
    "appollaierete": "appollaiare",
    "appollaierà": "appollaiare",
    "appollaierò": "appollaiare",
    "appollain": "appollaiare",
    "appollaino": "appollaiare",
    "appollaio": "appollaiare",
    "appollaiò": "appollaiare",
    "appone": "apporre",
    "apponemmo": "apporre",
    "apponendo": "apporre",
    "apponente": "apporre",
    "apponenti": "apporre",
    "apponesse": "apporre",
    "apponesser": "apporre",
    "apponessero": "apporre",
    "apponessi": "apporre",
    "apponessimo": "apporre",
    "apponeste": "apporre",
    "apponesti": "apporre",
    "apponete": "apporre",
    "apponeva": "apporre",
    "apponevamo": "apporre",
    "apponevan": "apporre",
    "apponevano": "apporre",
    "apponevate": "apporre",
    "apponevi": "apporre",
    "apponevo": "apporre",
    "apponga": "apporre",
    "appongan": "apporre",
    "appongano": "apporre",
    "appongo": "apporre",
    "appongon": "apporre",
    "appongono": "apporre",
    "apponi": "apporre",
    "apponiamo": "apporre",
    "apponiate": "apporre",
    "apponta": "appontare",
    "appontai": "appontare",
    "appontammo": "appontare",
    "appontan": "appontare",
    "appontando": "appontare",
    "appontano": "appontare",
    "appontante": "appontare",
    "appontanti": "appontare",
    "appontar": "appontare",
    "appontaron": "appontare",
    "appontarono": "appontare",
    "appontasse": "appontare",
    "appontasser": "appontare",
    "appontassero": "appontare",
    "appontassi": "appontare",
    "appontassimo": "appontare",
    "appontaste": "appontare",
    "appontasti": "appontare",
    "appontata": "appontare",
    "appontate": "appontare",
    "appontati": "appontare",
    "appontato": "appontare",
    "appontava": "appontare",
    "appontavamo": "appontare",
    "appontavan": "appontare",
    "appontavano": "appontare",
    "appontavate": "appontare",
    "appontavi": "appontare",
    "appontavo": "appontare",
    "apponterai": "appontare",
    "apponteran": "appontare",
    "apponteranno": "appontare",
    "apponterebbe": "appontare",
    "apponterebber": "appontare",
    "apponterebbero": "appontare",
    "apponterei": "appontare",
    "apponteremmo": "appontare",
    "apponteremo": "appontare",
    "appontereste": "appontare",
    "apponteresti": "appontare",
    "apponterete": "appontare",
    "apponterà": "appontare",
    "apponterò": "appontare",
    "apponti": "appontare",
    "appontiamo": "appontare",
    "appontiate": "appontare",
    "appontin": "appontare",
    "appontino": "appontare",
    "apponto": "appontare",
    "appontò": "appontare",
    "apporr": "apporre",
    "apporrai": "apporre",
    "apporran": "apporre",
    "apporranno": "apporre",
    "apporrebbe": "apporre",
    "apporrebber": "apporre",
    "apporrebbero": "apporre",
    "apporrei": "apporre",
    "apporremmo": "apporre",
    "apporremo": "apporre",
    "apporreste": "apporre",
    "apporresti": "apporre",
    "apporrete": "apporre",
    "apporrà": "apporre",
    "apporrò": "apporre",
    "apporta": "apportare",
    "apportai": "apportare",
    "apportammo": "apportare",
    "apportan": "apportare",
    "apportando": "apportare",
    "apportano": "apportare",
    "apportante": "apportare",
    "apportanti": "apportare",
    "apportar": "apportare",
    "apportaron": "apportare",
    "apportarono": "apportare",
    "apportasse": "apportare",
    "apportasser": "apportare",
    "apportassero": "apportare",
    "apportassi": "apportare",
    "apportassimo": "apportare",
    "apportaste": "apportare",
    "apportasti": "apportare",
    "apportata": "apportare",
    "apportate": "apportare",
    "apportati": "apportare",
    "apportato": "apportare",
    "apportava": "apportare",
    "apportavamo": "apportare",
    "apportavan": "apportare",
    "apportavano": "apportare",
    "apportavate": "apportare",
    "apportavi": "apportare",
    "apportavo": "apportare",
    "apporterai": "apportare",
    "apporteran": "apportare",
    "apporteranno": "apportare",
    "apporterebbe": "apportare",
    "apporterebber": "apportare",
    "apporterebbero": "apportare",
    "apporterei": "apportare",
    "apporteremmo": "apportare",
    "apporteremo": "apportare",
    "apportereste": "apportare",
    "apporteresti": "apportare",
    "apporterete": "apportare",
    "apporterà": "apportare",
    "apporterò": "apportare",
    "apporti": "apporto",
    "apportiamo": "apportare",
    "apportiate": "apportare",
    "apportin": "apportare",
    "apportino": "apportare",
    "apporto": "apportare",
    "apportò": "apportare",
    "appose": "apporre",
    "apposer": "apporre",
    "apposero": "apporre",
    "apposi": "apporre",
    "apposita": "apposito",
    "apposite": "apposito",
    "appositi": "apposito",
    "apposta": "appostare",
    "appostai": "appostare",
    "appostamenti": "appostamento",
    "appostammo": "appostare",
    "appostan": "appostare",
    "appostando": "appostare",
    "appostano": "appostare",
    "appostante": "appostare",
    "appostanti": "appostare",
    "appostar": "appostare",
    "appostaron": "appostare",
    "appostarono": "appostare",
    "appostasse": "appostare",
    "appostasser": "appostare",
    "appostassero": "appostare",
    "appostassi": "appostare",
    "appostassimo": "appostare",
    "appostaste": "appostare",
    "appostasti": "appostare",
    "appostata": "appostare",
    "appostate": "appostare",
    "appostati": "appostare",
    "appostato": "appostare",
    "appostava": "appostare",
    "appostavamo": "appostare",
    "appostavan": "appostare",
    "appostavano": "appostare",
    "appostavate": "appostare",
    "appostavi": "appostare",
    "appostavo": "appostare",
    "apposte": "apporre",
    "apposterai": "appostare",
    "apposteran": "appostare",
    "apposteranno": "appostare",
    "apposterebbe": "appostare",
    "apposterebber": "appostare",
    "apposterebbero": "appostare",
    "apposterei": "appostare",
    "apposteremmo": "appostare",
    "apposteremo": "appostare",
    "appostereste": "appostare",
    "apposteresti": "appostare",
    "apposterete": "appostare",
    "apposterà": "appostare",
    "apposterò": "appostare",
    "apposti": "appostare",
    "appostiamo": "appostare",
    "appostiate": "appostare",
    "appostin": "appostare",
    "appostino": "appostare",
    "apposto": "appostare",
    "appostò": "appostare",
    "apprenda": "apprendere",
    "apprendan": "apprendere",
    "apprendano": "apprendere",
    "apprende": "apprendere",
    "apprendemmo": "apprendere",
    "apprendendo": "apprendere",
    "apprendente": "apprendere",
    "apprendenti": "apprendere",
    "apprender": "apprendere",
    "apprenderai": "apprendere",
    "apprenderan": "apprendere",
    "apprenderanno": "apprendere",
    "apprenderebbe": "apprendere",
    "apprenderebber": "apprendere",
    "apprenderebbero": "apprendere",
    "apprenderei": "apprendere",
    "apprenderemmo": "apprendere",
    "apprenderemo": "apprendere",
    "apprendereste": "apprendere",
    "apprenderesti": "apprendere",
    "apprenderete": "apprendere",
    "apprenderà": "apprendere",
    "apprenderò": "apprendere",
    "apprendesse": "apprendere",
    "apprendesser": "apprendere",
    "apprendessero": "apprendere",
    "apprendessi": "apprendere",
    "apprendessimo": "apprendere",
    "apprendeste": "apprendere",
    "apprendesti": "apprendere",
    "apprendete": "apprendere",
    "apprendeva": "apprendere",
    "apprendevamo": "apprendere",
    "apprendevan": "apprendere",
    "apprendevano": "apprendere",
    "apprendevate": "apprendere",
    "apprendevi": "apprendere",
    "apprendevo": "apprendere",
    "apprendi": "apprendere",
    "apprendiamo": "apprendere",
    "apprendiate": "apprendere",
    "apprendimenti": "apprendimento",
    "apprendistati": "apprendistato",
    "apprendisti": "apprendista",
    "apprendo": "apprendere",
    "apprendon": "apprendere",
    "apprendono": "apprendere",
    "apprensioni": "apprensione",
    "apprensiva": "apprensivo",
    "apprensive": "apprensivo",
    "apprensivi": "apprensivo",
    "appresa": "apprendere",
    "apprese": "apprendere",
    "appreser": "apprendere",
    "appresero": "apprendere",
    "appresi": "apprendere",
    "appreso": "apprendere",
    "appressa": "appresso",
    "appressai": "appressare",
    "appressammo": "appressare",
    "appressan": "appressare",
    "appressando": "appressare",
    "appressano": "appressare",
    "appressante": "appressare",
    "appressanti": "appressare",
    "appressar": "appressare",
    "appressaron": "appressare",
    "appressarono": "appressare",
    "appressasse": "appressare",
    "appressasser": "appressare",
    "appressassero": "appressare",
    "appressassi": "appressare",
    "appressassimo": "appressare",
    "appressaste": "appressare",
    "appressasti": "appressare",
    "appressata": "appressare",
    "appressate": "appressare",
    "appressati": "appressare",
    "appressato": "appressare",
    "appressava": "appressare",
    "appressavamo": "appressare",
    "appressavan": "appressare",
    "appressavano": "appressare",
    "appressavate": "appressare",
    "appressavi": "appressare",
    "appressavo": "appressare",
    "appresse": "appresso",
    "appresserai": "appressare",
    "appresseran": "appressare",
    "appresseranno": "appressare",
    "appresserebbe": "appressare",
    "appresserebber": "appressare",
    "appresserebbero": "appressare",
    "appresserei": "appressare",
    "appresseremmo": "appressare",
    "appresseremo": "appressare",
    "appressereste": "appressare",
    "appresseresti": "appressare",
    "appresserete": "appressare",
    "appresserà": "appressare",
    "appresserò": "appressare",
    "appressi": "appresso",
    "appressiamo": "appressare",
    "appressiate": "appressare",
    "appressin": "appressare",
    "appressino": "appressare",
    "appresso": "appressare",
    "appressò": "appressare",
    "appresta": "apprestare",
    "apprestai": "apprestare",
    "apprestammo": "apprestare",
    "apprestan": "apprestare",
    "apprestando": "apprestare",
    "apprestano": "apprestare",
    "apprestante": "apprestare",
    "apprestanti": "apprestare",
    "apprestar": "apprestare",
    "apprestaron": "apprestare",
    "apprestarono": "apprestare",
    "apprestasse": "apprestare",
    "apprestasser": "apprestare",
    "apprestassero": "apprestare",
    "apprestassi": "apprestare",
    "apprestassimo": "apprestare",
    "apprestaste": "apprestare",
    "apprestasti": "apprestare",
    "apprestata": "apprestare",
    "apprestate": "apprestare",
    "apprestati": "apprestare",
    "apprestato": "apprestare",
    "apprestava": "apprestare",
    "apprestavamo": "apprestare",
    "apprestavan": "apprestare",
    "apprestavano": "apprestare",
    "apprestavate": "apprestare",
    "apprestavi": "apprestare",
    "apprestavo": "apprestare",
    "appresterai": "apprestare",
    "appresteran": "apprestare",
    "appresteranno": "apprestare",
    "appresterebbe": "apprestare",
    "appresterebber": "apprestare",
    "appresterebbero": "apprestare",
    "appresterei": "apprestare",
    "appresteremmo": "apprestare",
    "appresteremo": "apprestare",
    "apprestereste": "apprestare",
    "appresteresti": "apprestare",
    "appresterete": "apprestare",
    "appresterà": "apprestare",
    "appresterò": "apprestare",
    "appresti": "apprestare",
    "apprestiamo": "apprestare",
    "apprestiate": "apprestare",
    "apprestin": "apprestare",
    "apprestino": "apprestare",
    "appresto": "apprestare",
    "apprestò": "apprestare",
    "appresè": "apprendere",
    "appretta": "apprettare",
    "apprettai": "apprettare",
    "apprettammo": "apprettare",
    "apprettan": "apprettare",
    "apprettando": "apprettare",
    "apprettano": "apprettare",
    "apprettante": "apprettare",
    "apprettanti": "apprettare",
    "apprettar": "apprettare",
    "apprettaron": "apprettare",
    "apprettarono": "apprettare",
    "apprettasse": "apprettare",
    "apprettasser": "apprettare",
    "apprettassero": "apprettare",
    "apprettassi": "apprettare",
    "apprettassimo": "apprettare",
    "apprettaste": "apprettare",
    "apprettasti": "apprettare",
    "apprettata": "apprettare",
    "apprettate": "apprettare",
    "apprettati": "apprettare",
    "apprettato": "apprettare",
    "apprettava": "apprettare",
    "apprettavamo": "apprettare",
    "apprettavan": "apprettare",
    "apprettavano": "apprettare",
    "apprettavate": "apprettare",
    "apprettavi": "apprettare",
    "apprettavo": "apprettare",
    "appretterai": "apprettare",
    "appretteran": "apprettare",
    "appretteranno": "apprettare",
    "appretterebbe": "apprettare",
    "appretterebber": "apprettare",
    "appretterebbero": "apprettare",
    "appretterei": "apprettare",
    "appretteremmo": "apprettare",
    "appretteremo": "apprettare",
    "apprettereste": "apprettare",
    "appretteresti": "apprettare",
    "appretterete": "apprettare",
    "appretterà": "apprettare",
    "appretterò": "apprettare",
    "appretti": "apprettare",
    "apprettiamo": "apprettare",
    "apprettiate": "apprettare",
    "apprettin": "apprettare",
    "apprettino": "apprettare",
    "appretto": "apprettare",
    "apprettò": "apprettare",
    "apprezza": "apprezzare",
    "apprezzabili": "apprezzabile",
    "apprezzai": "apprezzare",
    "apprezzamenti": "apprezzamento",
    "apprezzammo": "apprezzare",
    "apprezzan": "apprezzare",
    "apprezzando": "apprezzare",
    "apprezzano": "apprezzare",
    "apprezzante": "apprezzare",
    "apprezzanti": "apprezzare",
    "apprezzar": "apprezzare",
    "apprezzaron": "apprezzare",
    "apprezzarono": "apprezzare",
    "apprezzasse": "apprezzare",
    "apprezzasser": "apprezzare",
    "apprezzassero": "apprezzare",
    "apprezzassi": "apprezzare",
    "apprezzassimo": "apprezzare",
    "apprezzaste": "apprezzare",
    "apprezzasti": "apprezzare",
    "apprezzata": "apprezzato",
    "apprezzate": "apprezzato",
    "apprezzati": "apprezzato",
    "apprezzato": "apprezzare",
    "apprezzava": "apprezzare",
    "apprezzavamo": "apprezzare",
    "apprezzavan": "apprezzare",
    "apprezzavano": "apprezzare",
    "apprezzavate": "apprezzare",
    "apprezzavi": "apprezzare",
    "apprezzavo": "apprezzare",
    "apprezzerai": "apprezzare",
    "apprezzeran": "apprezzare",
    "apprezzeranno": "apprezzare",
    "apprezzerebbe": "apprezzare",
    "apprezzerebber": "apprezzare",
    "apprezzerebbero": "apprezzare",
    "apprezzerei": "apprezzare",
    "apprezzeremmo": "apprezzare",
    "apprezzeremo": "apprezzare",
    "apprezzereste": "apprezzare",
    "apprezzeresti": "apprezzare",
    "apprezzerete": "apprezzare",
    "apprezzerà": "apprezzare",
    "apprezzerò": "apprezzare",
    "apprezzi": "apprezzare",
    "apprezziamo": "apprezzare",
    "apprezziate": "apprezzare",
    "apprezzin": "apprezzare",
    "apprezzino": "apprezzare",
    "apprezzo": "apprezzare",
    "apprezzò": "apprezzare",
    "approcci": "approccio",
    "approda": "approdare",
    "approdai": "approdare",
    "approdammo": "approdare",
    "approdan": "approdare",
    "approdando": "approdare",
    "approdano": "approdare",
    "approdante": "approdare",
    "approdanti": "approdare",
    "approdar": "approdare",
    "approdaron": "approdare",
    "approdarono": "approdare",
    "approdasse": "approdare",
    "approdasser": "approdare",
    "approdassero": "approdare",
    "approdassi": "approdare",
    "approdassimo": "approdare",
    "approdaste": "approdare",
    "approdasti": "approdare",
    "approdata": "approdare",
    "approdate": "approdare",
    "approdati": "approdare",
    "approdato": "approdare",
    "approdava": "approdare",
    "approdavamo": "approdare",
    "approdavan": "approdare",
    "approdavano": "approdare",
    "approdavate": "approdare",
    "approdavi": "approdare",
    "approdavo": "approdare",
    "approderai": "approdare",
    "approderan": "approdare",
    "approderanno": "approdare",
    "approderebbe": "approdare",
    "approderebber": "approdare",
    "approderebbero": "approdare",
    "approderei": "approdare",
    "approderemmo": "approdare",
    "approderemo": "approdare",
    "approdereste": "approdare",
    "approderesti": "approdare",
    "approderete": "approdare",
    "approderà": "approdare",
    "approderò": "approdare",
    "approdi": "approdo",
    "approdiamo": "approdare",
    "approdiate": "approdare",
    "approdin": "approdare",
    "approdino": "approdare",
    "approdo": "approdare",
    "approdò": "approdare",
    "approfitta": "approfittare",
    "approfittai": "approfittare",
    "approfittammo": "approfittare",
    "approfittan": "approfittare",
    "approfittando": "approfittare",
    "approfittano": "approfittare",
    "approfittante": "approfittare",
    "approfittanti": "approfittare",
    "approfittar": "approfittare",
    "approfittaron": "approfittare",
    "approfittarono": "approfittare",
    "approfittasse": "approfittare",
    "approfittasser": "approfittare",
    "approfittassero": "approfittare",
    "approfittassi": "approfittare",
    "approfittassimo": "approfittare",
    "approfittaste": "approfittare",
    "approfittasti": "approfittare",
    "approfittata": "approfittare",
    "approfittate": "approfittare",
    "approfittati": "approfittare",
    "approfittato": "approfittare",
    "approfittava": "approfittare",
    "approfittavamo": "approfittare",
    "approfittavan": "approfittare",
    "approfittavano": "approfittare",
    "approfittavate": "approfittare",
    "approfittavi": "approfittare",
    "approfittavo": "approfittare",
    "approfitterai": "approfittare",
    "approfitteran": "approfittare",
    "approfitteranno": "approfittare",
    "approfitterebbe": "approfittare",
    "approfitterebber": "approfittare",
    "approfitterebbero": "approfittare",
    "approfitterei": "approfittare",
    "approfitteremmo": "approfittare",
    "approfitteremo": "approfittare",
    "approfittereste": "approfittare",
    "approfitteresti": "approfittare",
    "approfitterete": "approfittare",
    "approfitterà": "approfittare",
    "approfitterò": "approfittare",
    "approfitti": "approfittare",
    "approfittiamo": "approfittare",
    "approfittiate": "approfittare",
    "approfittin": "approfittare",
    "approfittino": "approfittare",
    "approfitto": "approfittare",
    "approfittò": "approfittare",
    "approfondendo": "approfondire",
    "approfondente": "approfondire",
    "approfondenti": "approfondire",
    "approfondiamo": "approfondire",
    "approfondiate": "approfondire",
    "approfondii": "approfondire",
    "approfondimenti": "approfondimento",
    "approfondimmo": "approfondire",
    "approfondir": "approfondire",
    "approfondirai": "approfondire",
    "approfondiran": "approfondire",
    "approfondiranno": "approfondire",
    "approfondirebbe": "approfondire",
    "approfondirebber": "approfondire",
    "approfondirebbero": "approfondire",
    "approfondirei": "approfondire",
    "approfondiremmo": "approfondire",
    "approfondiremo": "approfondire",
    "approfondireste": "approfondire",
    "approfondiresti": "approfondire",
    "approfondirete": "approfondire",
    "approfondiron": "approfondire",
    "approfondirono": "approfondire",
    "approfondirà": "approfondire",
    "approfondirò": "approfondire",
    "approfondisca": "approfondire",
    "approfondiscan": "approfondire",
    "approfondiscano": "approfondire",
    "approfondisce": "approfondire",
    "approfondisci": "approfondire",
    "approfondisco": "approfondire",
    "approfondiscon": "approfondire",
    "approfondiscono": "approfondire",
    "approfondisse": "approfondire",
    "approfondisser": "approfondire",
    "approfondissero": "approfondire",
    "approfondissi": "approfondire",
    "approfondissimo": "approfondire",
    "approfondiste": "approfondire",
    "approfondisti": "approfondire",
    "approfondita": "approfondito",
    "approfondite": "approfondito",
    "approfonditi": "approfondito",
    "approfondito": "approfondire",
    "approfondiva": "approfondire",
    "approfondivamo": "approfondire",
    "approfondivan": "approfondire",
    "approfondivano": "approfondire",
    "approfondivate": "approfondire",
    "approfondivi": "approfondire",
    "approfondivo": "approfondire",
    "approfondì": "approfondire",
    "appronta": "approntare",
    "approntai": "approntare",
    "approntammo": "approntare",
    "approntan": "approntare",
    "approntando": "approntare",
    "approntano": "approntare",
    "approntante": "approntare",
    "approntanti": "approntare",
    "approntar": "approntare",
    "approntaron": "approntare",
    "approntarono": "approntare",
    "approntasse": "approntare",
    "approntasser": "approntare",
    "approntassero": "approntare",
    "approntassi": "approntare",
    "approntassimo": "approntare",
    "approntaste": "approntare",
    "approntasti": "approntare",
    "approntata": "approntare",
    "approntate": "approntare",
    "approntati": "approntare",
    "approntato": "approntare",
    "approntava": "approntare",
    "approntavamo": "approntare",
    "approntavan": "approntare",
    "approntavano": "approntare",
    "approntavate": "approntare",
    "approntavi": "approntare",
    "approntavo": "approntare",
    "appronterai": "approntare",
    "appronteran": "approntare",
    "appronteranno": "approntare",
    "appronterebbe": "approntare",
    "appronterebber": "approntare",
    "appronterebbero": "approntare",
    "appronterei": "approntare",
    "appronteremmo": "approntare",
    "appronteremo": "approntare",
    "approntereste": "approntare",
    "appronteresti": "approntare",
    "appronterete": "approntare",
    "appronterà": "approntare",
    "appronterò": "approntare",
    "appronti": "approntare",
    "approntiamo": "approntare",
    "approntiate": "approntare",
    "approntin": "approntare",
    "approntino": "approntare",
    "appronto": "approntare",
    "approntò": "approntare",
    "appropinqua": "appropinquare",
    "appropinquai": "appropinquare",
    "appropinquammo": "appropinquare",
    "appropinquan": "appropinquare",
    "appropinquando": "appropinquare",
    "appropinquano": "appropinquare",
    "appropinquante": "appropinquare",
    "appropinquanti": "appropinquare",
    "appropinquar": "appropinquare",
    "appropinquaron": "appropinquare",
    "appropinquarono": "appropinquare",
    "appropinquasse": "appropinquare",
    "appropinquasser": "appropinquare",
    "appropinquassero": "appropinquare",
    "appropinquassi": "appropinquare",
    "appropinquassimo": "appropinquare",
    "appropinquaste": "appropinquare",
    "appropinquasti": "appropinquare",
    "appropinquata": "appropinquare",
    "appropinquate": "appropinquare",
    "appropinquati": "appropinquare",
    "appropinquato": "appropinquare",
    "appropinquava": "appropinquare",
    "appropinquavamo": "appropinquare",
    "appropinquavan": "appropinquare",
    "appropinquavano": "appropinquare",
    "appropinquavate": "appropinquare",
    "appropinquavi": "appropinquare",
    "appropinquavo": "appropinquare",
    "appropinquerai": "appropinquare",
    "appropinqueran": "appropinquare",
    "appropinqueranno": "appropinquare",
    "appropinquerebbe": "appropinquare",
    "appropinquerebber": "appropinquare",
    "appropinquerebbero": "appropinquare",
    "appropinquerei": "appropinquare",
    "appropinqueremmo": "appropinquare",
    "appropinqueremo": "appropinquare",
    "appropinquereste": "appropinquare",
    "appropinqueresti": "appropinquare",
    "appropinquerete": "appropinquare",
    "appropinquerà": "appropinquare",
    "appropinquerò": "appropinquare",
    "appropinqui": "appropinquare",
    "appropinquiamo": "appropinquare",
    "appropinquiate": "appropinquare",
    "appropinquin": "appropinquare",
    "appropinquino": "appropinquare",
    "appropinquo": "appropinquare",
    "appropinquò": "appropinquare",
    "appropri": "appropriare",
    "appropria": "appropriare",
    "appropriai": "appropriare",
    "appropriammo": "appropriare",
    "appropriamo": "appropriare",
    "approprian": "appropriare",
    "appropriando": "appropriare",
    "appropriano": "appropriare",
    "appropriante": "appropriare",
    "approprianti": "appropriare",
    "appropriar": "appropriare",
    "appropriaron": "appropriare",
    "appropriarono": "appropriare",
    "appropriasse": "appropriare",
    "appropriasser": "appropriare",
    "appropriassero": "appropriare",
    "appropriassi": "appropriare",
    "appropriassimo": "appropriare",
    "appropriaste": "appropriare",
    "appropriasti": "appropriare",
    "appropriata": "appropriato",
    "appropriate": "appropriato",
    "appropriati": "appropriato",
    "appropriato": "appropriare",
    "appropriava": "appropriare",
    "appropriavamo": "appropriare",
    "appropriavan": "appropriare",
    "appropriavano": "appropriare",
    "appropriavate": "appropriare",
    "appropriavi": "appropriare",
    "appropriavo": "appropriare",
    "appropriazioni": "appropriazione",
    "approprierai": "appropriare",
    "approprieran": "appropriare",
    "approprieranno": "appropriare",
    "approprierebbe": "appropriare",
    "approprierebber": "appropriare",
    "approprierebbero": "appropriare",
    "approprierei": "appropriare",
    "approprieremmo": "appropriare",
    "approprieremo": "appropriare",
    "appropriereste": "appropriare",
    "approprieresti": "appropriare",
    "approprierete": "appropriare",
    "approprierà": "appropriare",
    "approprierò": "appropriare",
    "approprin": "appropriare",
    "approprino": "appropriare",
    "approprio": "appropriare",
    "appropriò": "appropriare",
    "approssima": "approssimare",
    "approssimai": "approssimare",
    "approssimammo": "approssimare",
    "approssiman": "approssimare",
    "approssimando": "approssimare",
    "approssimano": "approssimare",
    "approssimante": "approssimare",
    "approssimanti": "approssimare",
    "approssimar": "approssimare",
    "approssimaron": "approssimare",
    "approssimarono": "approssimare",
    "approssimasse": "approssimare",
    "approssimasser": "approssimare",
    "approssimassero": "approssimare",
    "approssimassi": "approssimare",
    "approssimassimo": "approssimare",
    "approssimaste": "approssimare",
    "approssimasti": "approssimare",
    "approssimata": "approssimare",
    "approssimate": "approssimare",
    "approssimati": "approssimare",
    "approssimativa": "approssimativo",
    "approssimative": "approssimativo",
    "approssimativi": "approssimativo",
    "approssimato": "approssimare",
    "approssimava": "approssimare",
    "approssimavamo": "approssimare",
    "approssimavan": "approssimare",
    "approssimavano": "approssimare",
    "approssimavate": "approssimare",
    "approssimavi": "approssimare",
    "approssimavo": "approssimare",
    "approssimazioni": "approssimazione",
    "approssimerai": "approssimare",
    "approssimeran": "approssimare",
    "approssimeranno": "approssimare",
    "approssimerebbe": "approssimare",
    "approssimerebber": "approssimare",
    "approssimerebbero": "approssimare",
    "approssimerei": "approssimare",
    "approssimeremmo": "approssimare",
    "approssimeremo": "approssimare",
    "approssimereste": "approssimare",
    "approssimeresti": "approssimare",
    "approssimerete": "approssimare",
    "approssimerà": "approssimare",
    "approssimerò": "approssimare",
    "approssimi": "approssimare",
    "approssimiamo": "approssimare",
    "approssimiate": "approssimare",
    "approssimin": "approssimare",
    "approssimino": "approssimare",
    "approssimo": "approssimare",
    "approssimò": "approssimare",
    "approva": "approvare",
    "approvai": "approvare",
    "approvammo": "approvare",
    "approvan": "approvare",
    "approvando": "approvare",
    "approvano": "approvare",
    "approvante": "approvare",
    "approvanti": "approvare",
    "approvar": "approvare",
    "approvaron": "approvare",
    "approvarono": "approvare",
    "approvasse": "approvare",
    "approvasser": "approvare",
    "approvassero": "approvare",
    "approvassi": "approvare",
    "approvassimo": "approvare",
    "approvaste": "approvare",
    "approvasti": "approvare",
    "approvata": "approvare",
    "approvate": "approvare",
    "approvati": "approvare",
    "approvato": "approvare",
    "approvava": "approvare",
    "approvavamo": "approvare",
    "approvavan": "approvare",
    "approvavano": "approvare",
    "approvavate": "approvare",
    "approvavi": "approvare",
    "approvavo": "approvare",
    "approvazioni": "approvazione",
    "approverai": "approvare",
    "approveran": "approvare",
    "approveranno": "approvare",
    "approverebbe": "approvare",
    "approverebber": "approvare",
    "approverebbero": "approvare",
    "approverei": "approvare",
    "approveremmo": "approvare",
    "approveremo": "approvare",
    "approvereste": "approvare",
    "approveresti": "approvare",
    "approverete": "approvare",
    "approverà": "approvare",
    "approverò": "approvare",
    "approvi": "approvare",
    "approviamo": "approvare",
    "approviate": "approvare",
    "approvigionamenti": "approvigionamento",
    "approvin": "approvare",
    "approvino": "approvare",
    "approvo": "approvare",
    "approvvigiona": "approvvigionare",
    "approvvigionai": "approvvigionare",
    "approvvigionamenti": "approvvigionamento",
    "approvvigionammo": "approvvigionare",
    "approvvigionan": "approvvigionare",
    "approvvigionando": "approvvigionare",
    "approvvigionano": "approvvigionare",
    "approvvigionante": "approvvigionare",
    "approvvigionanti": "approvvigionare",
    "approvvigionar": "approvvigionare",
    "approvvigionaron": "approvvigionare",
    "approvvigionarono": "approvvigionare",
    "approvvigionasse": "approvvigionare",
    "approvvigionasser": "approvvigionare",
    "approvvigionassero": "approvvigionare",
    "approvvigionassi": "approvvigionare",
    "approvvigionassimo": "approvvigionare",
    "approvvigionaste": "approvvigionare",
    "approvvigionasti": "approvvigionare",
    "approvvigionata": "approvvigionare",
    "approvvigionate": "approvvigionare",
    "approvvigionati": "approvvigionare",
    "approvvigionato": "approvvigionare",
    "approvvigionava": "approvvigionare",
    "approvvigionavamo": "approvvigionare",
    "approvvigionavan": "approvvigionare",
    "approvvigionavano": "approvvigionare",
    "approvvigionavate": "approvvigionare",
    "approvvigionavi": "approvvigionare",
    "approvvigionavo": "approvvigionare",
    "approvvigionerai": "approvvigionare",
    "approvvigioneran": "approvvigionare",
    "approvvigioneranno": "approvvigionare",
    "approvvigionerebbe": "approvvigionare",
    "approvvigionerebber": "approvvigionare",
    "approvvigionerebbero": "approvvigionare",
    "approvvigionerei": "approvvigionare",
    "approvvigioneremmo": "approvvigionare",
    "approvvigioneremo": "approvvigionare",
    "approvvigionereste": "approvvigionare",
    "approvvigioneresti": "approvvigionare",
    "approvvigionerete": "approvvigionare",
    "approvvigionerà": "approvvigionare",
    "approvvigionerò": "approvvigionare",
    "approvvigioni": "approvvigionare",
    "approvvigioniamo": "approvvigionare",
    "approvvigioniate": "approvvigionare",
    "approvvigionin": "approvvigionare",
    "approvvigionino": "approvvigionare",
    "approvvigiono": "approvvigionare",
    "approvvigionò": "approvvigionare",
    "approvò": "approvare",
    "apprua": "appruare",
    "appruai": "appruare",
    "appruammo": "appruare",
    "appruan": "appruare",
    "appruando": "appruare",
    "appruano": "appruare",
    "appruante": "appruare",
    "appruanti": "appruare",
    "appruar": "appruare",
    "appruaron": "appruare",
    "appruarono": "appruare",
    "appruasse": "appruare",
    "appruasser": "appruare",
    "appruassero": "appruare",
    "appruassi": "appruare",
    "appruassimo": "appruare",
    "appruaste": "appruare",
    "appruasti": "appruare",
    "appruata": "appruare",
    "appruate": "appruare",
    "appruati": "appruare",
    "appruato": "appruare",
    "appruava": "appruare",
    "appruavamo": "appruare",
    "appruavan": "appruare",
    "appruavano": "appruare",
    "appruavate": "appruare",
    "appruavi": "appruare",
    "appruavo": "appruare",
    "appruerai": "appruare",
    "apprueran": "appruare",
    "apprueranno": "appruare",
    "appruerebbe": "appruare",
    "appruerebber": "appruare",
    "appruerebbero": "appruare",
    "appruerei": "appruare",
    "apprueremmo": "appruare",
    "apprueremo": "appruare",
    "appruereste": "appruare",
    "apprueresti": "appruare",
    "appruerete": "appruare",
    "appruerà": "appruare",
    "appruerò": "appruare",
    "apprui": "appruare",
    "appruiamo": "appruare",
    "appruiate": "appruare",
    "appruin": "appruare",
    "appruino": "appruare",
    "appruo": "appruare",
    "appruò": "appruare",
    "appunta": "appuntire",
    "appuntai": "appuntare",
    "appuntamenti": "appuntamento",
    "appuntammo": "appuntare",
    "appuntan": "appuntire",
    "appuntando": "appuntare",
    "appuntano": "appuntire",
    "appuntante": "appuntare",
    "appuntanti": "appuntare",
    "appuntar": "appuntare",
    "appuntaron": "appuntare",
    "appuntarono": "appuntare",
    "appuntasse": "appuntare",
    "appuntasser": "appuntare",
    "appuntassero": "appuntare",
    "appuntassi": "appuntare",
    "appuntassimo": "appuntare",
    "appuntaste": "appuntare",
    "appuntasti": "appuntare",
    "appuntata": "appuntare",
    "appuntate": "appuntare",
    "appuntati": "appuntare",
    "appuntato": "appuntare",
    "appuntava": "appuntare",
    "appuntavamo": "appuntare",
    "appuntavan": "appuntare",
    "appuntavano": "appuntare",
    "appuntavate": "appuntare",
    "appuntavi": "appuntare",
    "appuntavo": "appuntare",
    "appunte": "appuntire",
    "appuntendo": "appuntire",
    "appuntente": "appuntire",
    "appuntenti": "appuntire",
    "appunterai": "appuntare",
    "appunteran": "appuntare",
    "appunteranno": "appuntare",
    "appunterebbe": "appuntare",
    "appunterebber": "appuntare",
    "appunterebbero": "appuntare",
    "appunterei": "appuntare",
    "appunteremmo": "appuntare",
    "appunteremo": "appuntare",
    "appuntereste": "appuntare",
    "appunteresti": "appuntare",
    "appunterete": "appuntare",
    "appunterà": "appuntare",
    "appunterò": "appuntare",
    "appunti": "appunto",
    "appuntiamo": "appuntire",
    "appuntiate": "appuntire",
    "appuntii": "appuntire",
    "appuntimmo": "appuntire",
    "appuntin": "appuntare",
    "appuntino": "appuntare",
    "appuntir": "appuntire",
    "appuntirai": "appuntire",
    "appuntiran": "appuntire",
    "appuntiranno": "appuntire",
    "appuntirebbe": "appuntire",
    "appuntirebber": "appuntire",
    "appuntirebbero": "appuntire",
    "appuntirei": "appuntire",
    "appuntiremmo": "appuntire",
    "appuntiremo": "appuntire",
    "appuntireste": "appuntire",
    "appuntiresti": "appuntire",
    "appuntirete": "appuntire",
    "appuntiron": "appuntire",
    "appuntirono": "appuntire",
    "appuntirà": "appuntire",
    "appuntirò": "appuntire",
    "appuntisse": "appuntire",
    "appuntisser": "appuntire",
    "appuntissero": "appuntire",
    "appuntissi": "appuntire",
    "appuntissimo": "appuntire",
    "appuntiste": "appuntire",
    "appuntisti": "appuntire",
    "appuntita": "appuntire",
    "appuntite": "appuntire",
    "appuntiti": "appuntire",
    "appuntito": "appuntire",
    "appuntiva": "appuntire",
    "appuntivamo": "appuntire",
    "appuntivan": "appuntire",
    "appuntivano": "appuntire",
    "appuntivate": "appuntire",
    "appuntivi": "appuntire",
    "appuntivo": "appuntire",
    "appunto": "appuntire",
    "appunton": "appuntire",
    "appuntono": "appuntire",
    "appuntì": "appuntire",
    "appuntò": "appuntare",
    "appura": "appurare",
    "appurai": "appurare",
    "appurammo": "appurare",
    "appuran": "appurare",
    "appurando": "appurare",
    "appurano": "appurare",
    "appurante": "appurare",
    "appuranti": "appurare",
    "appurar": "appurare",
    "appuraron": "appurare",
    "appurarono": "appurare",
    "appurasse": "appurare",
    "appurasser": "appurare",
    "appurassero": "appurare",
    "appurassi": "appurare",
    "appurassimo": "appurare",
    "appuraste": "appurare",
    "appurasti": "appurare",
    "appurata": "appurare",
    "appurate": "appurare",
    "appurati": "appurare",
    "appurato": "appurare",
    "appurava": "appurare",
    "appuravamo": "appurare",
    "appuravan": "appurare",
    "appuravano": "appurare",
    "appuravate": "appurare",
    "appuravi": "appurare",
    "appuravo": "appurare",
    "appurerai": "appurare",
    "appureran": "appurare",
    "appureranno": "appurare",
    "appurerebbe": "appurare",
    "appurerebber": "appurare",
    "appurerebbero": "appurare",
    "appurerei": "appurare",
    "appureremmo": "appurare",
    "appureremo": "appurare",
    "appurereste": "appurare",
    "appureresti": "appurare",
    "appurerete": "appurare",
    "appurerà": "appurare",
    "appurerò": "appurare",
    "appuri": "appurare",
    "appuriamo": "appurare",
    "appuriate": "appurare",
    "appurin": "appurare",
    "appurino": "appurare",
    "appuro": "appurare",
    "appurò": "appurare",
    "apra": "aprire",
    "apran": "aprire",
    "aprano": "aprire",
    "apre": "aprire",
    "aprendo": "aprire",
    "aprente": "aprire",
    "aprenti": "aprire",
    "apri": "aprire",
    "apriamo": "aprire",
    "apriate": "aprire",
    "apribili": "apribile",
    "aprica": "aprico",
    "apriche": "aprico",
    "aprici": "aprico",
    "aprii": "aprire",
    "aprili": "aprile",
    "aprimmo": "aprire",
    "aprioristica": "aprioristico",
    "aprioristiche": "aprioristico",
    "aprioristici": "aprioristico",
    "aprir": "aprire",
    "aprirai": "aprire",
    "apriran": "aprire",
    "apriranno": "aprire",
    "aprirebbe": "aprire",
    "aprirebber": "aprire",
    "aprirebbero": "aprire",
    "aprirei": "aprire",
    "apriremmo": "aprire",
    "apriremo": "aprire",
    "aprireste": "aprire",
    "apriresti": "aprire",
    "aprirete": "aprire",
    "apriron": "aprire",
    "aprirono": "aprire",
    "aprirà": "aprire",
    "aprirò": "aprire",
    "aprisse": "aprire",
    "aprisser": "aprire",
    "aprissero": "aprire",
    "aprissi": "aprire",
    "aprissimo": "aprire",
    "apriste": "aprire",
    "apristi": "aprire",
    "aprite": "aprire",
    "apriva": "aprire",
    "aprivamo": "aprire",
    "aprivan": "aprire",
    "aprivano": "aprire",
    "aprivate": "aprire",
    "aprivi": "aprire",
    "aprivo": "aprire",
    "apro": "aprire",
    "apron": "aprire",
    "aprono": "aprire",
    "aprì": "aprire",
    "aquilana": "aquilano",
    "aquilane": "aquilano",
    "aquilani": "aquilano",
    "aquile": "aquila",
    "aquilina": "aquilino",
    "aquiline": "aquilino",
    "aquilini": "aquilino",
    "aquiloni": "aquilone",
    "ara": "arare",
    "araba": "arabo",
    "arabe": "arabo",
    "arabesca": "arabesco",
    "arabescai": "arabescare",
    "arabescammo": "arabescare",
    "arabescan": "arabescare",
    "arabescando": "arabescare",
    "arabescano": "arabescare",
    "arabescante": "arabescare",
    "arabescanti": "arabescare",
    "arabescar": "arabescare",
    "arabescaron": "arabescare",
    "arabescarono": "arabescare",
    "arabescasse": "arabescare",
    "arabescasser": "arabescare",
    "arabescassero": "arabescare",
    "arabescassi": "arabescare",
    "arabescassimo": "arabescare",
    "arabescaste": "arabescare",
    "arabescasti": "arabescare",
    "arabescata": "arabescare",
    "arabescate": "arabescare",
    "arabescati": "arabescare",
    "arabescato": "arabescare",
    "arabescava": "arabescare",
    "arabescavamo": "arabescare",
    "arabescavan": "arabescare",
    "arabescavano": "arabescare",
    "arabescavate": "arabescare",
    "arabescavi": "arabescare",
    "arabescavo": "arabescare",
    "arabesche": "arabesco",
    "arabescherai": "arabescare",
    "arabescheran": "arabescare",
    "arabescheranno": "arabescare",
    "arabescherebbe": "arabescare",
    "arabescherebber": "arabescare",
    "arabescherebbero": "arabescare",
    "arabescherei": "arabescare",
    "arabescheremmo": "arabescare",
    "arabescheremo": "arabescare",
    "arabeschereste": "arabescare",
    "arabescheresti": "arabescare",
    "arabescherete": "arabescare",
    "arabescherà": "arabescare",
    "arabescherò": "arabescare",
    "arabeschi": "arabesco",
    "arabeschiamo": "arabescare",
    "arabeschiate": "arabescare",
    "arabeschin": "arabescare",
    "arabeschino": "arabescare",
    "arabesco": "arabescare",
    "arabescò": "arabescare",
    "arabi": "arabo",
    "arabica": "arabico",
    "arabiche": "arabico",
    "arabici": "arabico",
    "arabili": "arabile",
    "arabisti": "arabista",
    "arabo-africana": "arabo-africano",
    "arabo-africane": "arabo-africano",
    "arabo-africani": "arabo-africano",
    "arabo-americana": "arabo-americano",
    "arabo-americane": "arabo-americano",
    "arabo-americani": "arabo-americano",
    "arabo-israeliana": "arabo-israeliano",
    "arabo-israeliane": "arabo-israeliano",
    "arabo-israeliani": "arabo-israeliano",
    "arabo-palestinesi": "arabo-palestinese",
    "arafattiana": "arafattiano",
    "arafattiane": "arafattiano",
    "arafattiani": "arafattiano",
    "aragoste": "aragosta",
    "arai": "arare",
    "araldica": "araldico",
    "araldiche": "araldico",
    "araldici": "araldico",
    "arammo": "arare",
    "aran": "arare",
    "arance": "arancia",
    "aranci": "arancio",
    "aranciata": "aranciato",
    "aranciate": "aranciato",
    "aranciati": "aranciato",
    "arancioni": "arancione",
    "arando": "arare",
    "arano": "arare",
    "arante": "arare",
    "aranti": "arare",
    "arar": "arare",
    "araron": "arare",
    "ararono": "arare",
    "arasse": "arare",
    "arasser": "arare",
    "arassero": "arare",
    "arassi": "arare",
    "arassimo": "arare",
    "araste": "arare",
    "arasti": "arare",
    "arata": "arare",
    "arate": "arare",
    "arati": "arare",
    "arato": "arare",
    "aratri": "aratro",
    "arava": "arare",
    "aravamo": "arare",
    "aravan": "arare",
    "aravano": "arare",
    "aravate": "arare",
    "aravi": "arare",
    "aravo": "arare",
    "arazzi": "arazzo",
    "arbitraggi": "arbitraggio",
    "arbitrali": "arbitrale",
    "arbitrari": "arbitrario",
    "arbitraria": "arbitrario",
    "arbitrarie": "arbitrario",
    "arbitrata": "arbitrato",
    "arbitrate": "arbitrato",
    "arbitrati": "arbitrato",
    "arbitri": "arbitro",
    "arbitrii": "arbitrio",
    "arborea": "arboreo",
    "arboree": "arboreo",
    "arborei": "arboreo",
    "arboriana": "arboriano",
    "arboriane": "arboriano",
    "arboriani": "arboriano",
    "arboricola": "arboricolo",
    "arboricole": "arboricolo",
    "arboricoli": "arboricolo",
    "arbusti": "arbusto",
    "arbustiva": "arbustivo",
    "arbustive": "arbustivo",
    "arbustivi": "arbustivo",
    "arcadi": "arcade",
    "arcadica": "arcadico",
    "arcadiche": "arcadico",
    "arcadici": "arcadico",
    "arcaica": "arcaico",
    "arcaiche": "arcaico",
    "arcaici": "arcaico",
    "arcaicizza": "arcaicizzare",
    "arcaicizzai": "arcaicizzare",
    "arcaicizzammo": "arcaicizzare",
    "arcaicizzan": "arcaicizzare",
    "arcaicizzando": "arcaicizzare",
    "arcaicizzano": "arcaicizzare",
    "arcaicizzante": "arcaicizzare",
    "arcaicizzanti": "arcaicizzare",
    "arcaicizzar": "arcaicizzare",
    "arcaicizzaron": "arcaicizzare",
    "arcaicizzarono": "arcaicizzare",
    "arcaicizzasse": "arcaicizzare",
    "arcaicizzasser": "arcaicizzare",
    "arcaicizzassero": "arcaicizzare",
    "arcaicizzassi": "arcaicizzare",
    "arcaicizzassimo": "arcaicizzare",
    "arcaicizzaste": "arcaicizzare",
    "arcaicizzasti": "arcaicizzare",
    "arcaicizzata": "arcaicizzare",
    "arcaicizzate": "arcaicizzare",
    "arcaicizzati": "arcaicizzare",
    "arcaicizzato": "arcaicizzare",
    "arcaicizzava": "arcaicizzare",
    "arcaicizzavamo": "arcaicizzare",
    "arcaicizzavan": "arcaicizzare",
    "arcaicizzavano": "arcaicizzare",
    "arcaicizzavate": "arcaicizzare",
    "arcaicizzavi": "arcaicizzare",
    "arcaicizzavo": "arcaicizzare",
    "arcaicizzerai": "arcaicizzare",
    "arcaicizzeran": "arcaicizzare",
    "arcaicizzeranno": "arcaicizzare",
    "arcaicizzerebbe": "arcaicizzare",
    "arcaicizzerebber": "arcaicizzare",
    "arcaicizzerebbero": "arcaicizzare",
    "arcaicizzerei": "arcaicizzare",
    "arcaicizzeremmo": "arcaicizzare",
    "arcaicizzeremo": "arcaicizzare",
    "arcaicizzereste": "arcaicizzare",
    "arcaicizzeresti": "arcaicizzare",
    "arcaicizzerete": "arcaicizzare",
    "arcaicizzerà": "arcaicizzare",
    "arcaicizzerò": "arcaicizzare",
    "arcaicizzi": "arcaicizzare",
    "arcaicizziamo": "arcaicizzare",
    "arcaicizziate": "arcaicizzare",
    "arcaicizzin": "arcaicizzare",
    "arcaicizzino": "arcaicizzare",
    "arcaicizzo": "arcaicizzare",
    "arcaicizzò": "arcaicizzare",
    "arcaismi": "arcaismo",
    "arcaizza": "arcaizzare",
    "arcaizzai": "arcaizzare",
    "arcaizzammo": "arcaizzare",
    "arcaizzan": "arcaizzare",
    "arcaizzando": "arcaizzare",
    "arcaizzano": "arcaizzare",
    "arcaizzante": "arcaizzare",
    "arcaizzanti": "arcaizzare",
    "arcaizzar": "arcaizzare",
    "arcaizzaron": "arcaizzare",
    "arcaizzarono": "arcaizzare",
    "arcaizzasse": "arcaizzare",
    "arcaizzasser": "arcaizzare",
    "arcaizzassero": "arcaizzare",
    "arcaizzassi": "arcaizzare",
    "arcaizzassimo": "arcaizzare",
    "arcaizzaste": "arcaizzare",
    "arcaizzasti": "arcaizzare",
    "arcaizzata": "arcaizzare",
    "arcaizzate": "arcaizzare",
    "arcaizzati": "arcaizzare",
    "arcaizzato": "arcaizzare",
    "arcaizzava": "arcaizzare",
    "arcaizzavamo": "arcaizzare",
    "arcaizzavan": "arcaizzare",
    "arcaizzavano": "arcaizzare",
    "arcaizzavate": "arcaizzare",
    "arcaizzavi": "arcaizzare",
    "arcaizzavo": "arcaizzare",
    "arcaizzerai": "arcaizzare",
    "arcaizzeran": "arcaizzare",
    "arcaizzeranno": "arcaizzare",
    "arcaizzerebbe": "arcaizzare",
    "arcaizzerebber": "arcaizzare",
    "arcaizzerebbero": "arcaizzare",
    "arcaizzerei": "arcaizzare",
    "arcaizzeremmo": "arcaizzare",
    "arcaizzeremo": "arcaizzare",
    "arcaizzereste": "arcaizzare",
    "arcaizzeresti": "arcaizzare",
    "arcaizzerete": "arcaizzare",
    "arcaizzerà": "arcaizzare",
    "arcaizzerò": "arcaizzare",
    "arcaizzi": "arcaizzare",
    "arcaizziamo": "arcaizzare",
    "arcaizziate": "arcaizzare",
    "arcaizzin": "arcaizzare",
    "arcaizzino": "arcaizzare",
    "arcaizzo": "arcaizzare",
    "arcaizzò": "arcaizzare",
    "arcana": "arcano",
    "arcane": "arcano",
    "arcangeli": "arcangelo",
    "arcani": "arcano",
    "arcate": "arcata",
    "archeologi": "archeologo",
    "archeologica": "archeologico",
    "archeologiche": "archeologico",
    "archeologici": "archeologico",
    "archeologie": "archeologia",
    "archetipi": "archetipo",
    "archetti": "archetto",
    "archi": "arco",
    "architetta": "architettare",
    "architettai": "architettare",
    "architettammo": "architettare",
    "architettan": "architettare",
    "architettando": "architettare",
    "architettano": "architettare",
    "architettante": "architettare",
    "architettanti": "architettare",
    "architettar": "architettare",
    "architettaron": "architettare",
    "architettarono": "architettare",
    "architettasse": "architettare",
    "architettasser": "architettare",
    "architettassero": "architettare",
    "architettassi": "architettare",
    "architettassimo": "architettare",
    "architettaste": "architettare",
    "architettasti": "architettare",
    "architettata": "architettare",
    "architettate": "architettare",
    "architettati": "architettare",
    "architettato": "architettare",
    "architettava": "architettare",
    "architettavamo": "architettare",
    "architettavan": "architettare",
    "architettavano": "architettare",
    "architettavate": "architettare",
    "architettavi": "architettare",
    "architettavo": "architettare",
    "architetterai": "architettare",
    "architetteran": "architettare",
    "architetteranno": "architettare",
    "architetterebbe": "architettare",
    "architetterebber": "architettare",
    "architetterebbero": "architettare",
    "architetterei": "architettare",
    "architetteremmo": "architettare",
    "architetteremo": "architettare",
    "architettereste": "architettare",
    "architetteresti": "architettare",
    "architetterete": "architettare",
    "architetterà": "architettare",
    "architetterò": "architettare",
    "architetti": "architetto",
    "architettiamo": "architettare",
    "architettiate": "architettare",
    "architettin": "architettare",
    "architettino": "architettare",
    "architetto": "architettare",
    "architettonica": "architettonico",
    "architettoniche": "architettonico",
    "architettonici": "architettonico",
    "architetture": "architettura",
    "architettò": "architettare",
    "architravi": "architrave",
    "archivi": "archivio",
    "archivia": "archiviare",
    "archiviai": "archiviare",
    "archiviammo": "archiviare",
    "archiviamo": "archiviare",
    "archivian": "archiviare",
    "archiviando": "archiviare",
    "archiviano": "archiviare",
    "archiviante": "archiviare",
    "archivianti": "archiviare",
    "archiviar": "archiviare",
    "archiviaron": "archiviare",
    "archiviarono": "archiviare",
    "archiviasse": "archiviare",
    "archiviasser": "archiviare",
    "archiviassero": "archiviare",
    "archiviassi": "archiviare",
    "archiviassimo": "archiviare",
    "archiviaste": "archiviare",
    "archiviasti": "archiviare",
    "archiviata": "archiviare",
    "archiviate": "archiviare",
    "archiviati": "archiviare",
    "archiviato": "archiviare",
    "archiviava": "archiviare",
    "archiviavamo": "archiviare",
    "archiviavan": "archiviare",
    "archiviavano": "archiviare",
    "archiviavate": "archiviare",
    "archiviavi": "archiviare",
    "archiviavo": "archiviare",
    "archiviazioni": "archiviazione",
    "archivierai": "archiviare",
    "archivieran": "archiviare",
    "archivieranno": "archiviare",
    "archivierebbe": "archiviare",
    "archivierebber": "archiviare",
    "archivierebbero": "archiviare",
    "archivierei": "archiviare",
    "archivieremmo": "archiviare",
    "archivieremo": "archiviare",
    "archiviereste": "archiviare",
    "archivieresti": "archiviare",
    "archivierete": "archiviare",
    "archivierà": "archiviare",
    "archivierò": "archiviare",
    "archivin": "archiviare",
    "archivino": "archiviare",
    "archivio": "archiviare",
    "archivisti": "archivista",
    "archivistica": "archivistico",
    "archivistiche": "archivistico",
    "archivistici": "archivistico",
    "archiviò": "archiviare",
    "arcieri": "arciere",
    "arcigna": "arcigno",
    "arcigne": "arcigno",
    "arcigni": "arcigno",
    "arcinemici": "arcinemico",
    "arcipelaghi": "arcipelago",
    "arcivescovi": "arcivescovo",
    "arcivescovili": "arcivescovile",
    "arcobaleni": "arcobaleno",
    "arcua": "arcuare",
    "arcuai": "arcuare",
    "arcuammo": "arcuare",
    "arcuan": "arcuare",
    "arcuando": "arcuare",
    "arcuano": "arcuare",
    "arcuante": "arcuare",
    "arcuanti": "arcuare",
    "arcuar": "arcuare",
    "arcuaron": "arcuare",
    "arcuarono": "arcuare",
    "arcuasse": "arcuare",
    "arcuasser": "arcuare",
    "arcuassero": "arcuare",
    "arcuassi": "arcuare",
    "arcuassimo": "arcuare",
    "arcuaste": "arcuare",
    "arcuasti": "arcuare",
    "arcuata": "arcuato",
    "arcuate": "arcuato",
    "arcuati": "arcuato",
    "arcuato": "arcuare",
    "arcuava": "arcuare",
    "arcuavamo": "arcuare",
    "arcuavan": "arcuare",
    "arcuavano": "arcuare",
    "arcuavate": "arcuare",
    "arcuavi": "arcuare",
    "arcuavo": "arcuare",
    "arcuerai": "arcuare",
    "arcueran": "arcuare",
    "arcueranno": "arcuare",
    "arcuerebbe": "arcuare",
    "arcuerebber": "arcuare",
    "arcuerebbero": "arcuare",
    "arcuerei": "arcuare",
    "arcueremmo": "arcuare",
    "arcueremo": "arcuare",
    "arcuereste": "arcuare",
    "arcueresti": "arcuare",
    "arcuerete": "arcuare",
    "arcuerà": "arcuare",
    "arcuerò": "arcuare",
    "arcui": "arcuare",
    "arcuiamo": "arcuare",
    "arcuiate": "arcuare",
    "arcuin": "arcuare",
    "arcuino": "arcuare",
    "arcuo": "arcuare",
    "arcuò": "arcuare",
    "arda": "ardere",
    "ardan": "ardere",
    "ardano": "ardere",
    "arde": "ardere",
    "ardemmo": "ardere",
    "ardendo": "ardire",
    "ardente": "ardire",
    "ardenti": "ardire",
    "arder": "ardere",
    "arderai": "ardere",
    "arderan": "ardere",
    "arderanno": "ardere",
    "arderebbe": "ardere",
    "arderebber": "ardere",
    "arderebbero": "ardere",
    "arderei": "ardere",
    "arderemmo": "ardere",
    "arderemo": "ardere",
    "ardereste": "ardere",
    "arderesti": "ardere",
    "arderete": "ardere",
    "arderà": "ardere",
    "arderò": "ardere",
    "ardesse": "ardere",
    "ardesser": "ardere",
    "ardessero": "ardere",
    "ardessi": "ardere",
    "ardessimo": "ardere",
    "ardeste": "ardere",
    "ardesti": "ardere",
    "ardete": "ardere",
    "ardeva": "ardere",
    "ardevamo": "ardere",
    "ardevan": "ardere",
    "ardevano": "ardere",
    "ardevate": "ardere",
    "ardevi": "ardere",
    "ardevo": "ardere",
    "ardi": "ardere",
    "ardiamo": "ardire",
    "ardiate": "ardire",
    "ardii": "ardire",
    "ardimenti": "ardimento",
    "ardimentosa": "ardimentoso",
    "ardimentose": "ardimentoso",
    "ardimentosi": "ardimentoso",
    "ardimmo": "ardire",
    "ardir": "ardire",
    "ardirai": "ardire",
    "ardiran": "ardire",
    "ardiranno": "ardire",
    "ardirebbe": "ardire",
    "ardirebber": "ardire",
    "ardirebbero": "ardire",
    "ardirei": "ardire",
    "ardiremmo": "ardire",
    "ardiremo": "ardire",
    "ardireste": "ardire",
    "ardiresti": "ardire",
    "ardirete": "ardire",
    "ardiron": "ardire",
    "ardirono": "ardire",
    "ardirà": "ardire",
    "ardirò": "ardire",
    "ardisca": "ardire",
    "ardiscan": "ardire",
    "ardiscano": "ardire",
    "ardisce": "ardire",
    "ardisci": "ardire",
    "ardisco": "ardire",
    "ardiscon": "ardire",
    "ardiscono": "ardire",
    "ardisse": "ardire",
    "ardisser": "ardire",
    "ardissero": "ardire",
    "ardissi": "ardire",
    "ardissimo": "ardire",
    "ardiste": "ardire",
    "ardisti": "ardire",
    "ardita": "ardito",
    "ardite": "ardito",
    "arditezze": "arditezza",
    "arditi": "ardito",
    "ardito": "ardire",
    "ardiva": "ardire",
    "ardivamo": "ardire",
    "ardivan": "ardire",
    "ardivano": "ardire",
    "ardivate": "ardire",
    "ardivi": "ardire",
    "ardivo": "ardire",
    "ardo": "ardere",
    "ardon": "ardere",
    "ardono": "ardere",
    "ardori": "ardore",
    "ardua": "arduo",
    "ardue": "arduo",
    "ardui": "arduo",
    "ardì": "ardire",
    "aree": "area",
    "arena": "arenare",
    "arenai": "arenare",
    "arenammo": "arenare",
    "arenan": "arenare",
    "arenando": "arenare",
    "arenano": "arenare",
    "arenante": "arenare",
    "arenanti": "arenare",
    "arenar": "arenare",
    "arenaron": "arenare",
    "arenarono": "arenare",
    "arenasse": "arenare",
    "arenasser": "arenare",
    "arenassero": "arenare",
    "arenassi": "arenare",
    "arenassimo": "arenare",
    "arenaste": "arenare",
    "arenasti": "arenare",
    "arenata": "arenare",
    "arenate": "arenare",
    "arenati": "arenare",
    "arenato": "arenare",
    "arenava": "arenare",
    "arenavamo": "arenare",
    "arenavan": "arenare",
    "arenavano": "arenare",
    "arenavate": "arenare",
    "arenavi": "arenare",
    "arenavo": "arenare",
    "arene": "arena",
    "arenerai": "arenare",
    "areneran": "arenare",
    "areneranno": "arenare",
    "arenerebbe": "arenare",
    "arenerebber": "arenare",
    "arenerebbero": "arenare",
    "arenerei": "arenare",
    "areneremmo": "arenare",
    "areneremo": "arenare",
    "arenereste": "arenare",
    "areneresti": "arenare",
    "arenerete": "arenare",
    "arenerà": "arenare",
    "arenerò": "arenare",
    "areni": "arenare",
    "areniamo": "arenare",
    "areniana": "areniano",
    "areniane": "areniano",
    "areniani": "areniano",
    "areniate": "arenare",
    "arenin": "arenare",
    "arenino": "arenare",
    "areno": "arenare",
    "arenò": "arenare",
    "arerai": "arare",
    "areran": "arare",
    "areranno": "arare",
    "arerebbe": "arare",
    "arerebber": "arare",
    "arerebbero": "arare",
    "arerei": "arare",
    "areremmo": "arare",
    "areremo": "arare",
    "arereste": "arare",
    "areresti": "arare",
    "arerete": "arare",
    "arerà": "arare",
    "arerò": "arare",
    "argani": "argano",
    "argenta": "argentare",
    "argentai": "argentare",
    "argentammo": "argentare",
    "argentan": "argentare",
    "argentando": "argentare",
    "argentano": "argentare",
    "argentante": "argentare",
    "argentanti": "argentare",
    "argentar": "argentare",
    "argentari": "argentario",
    "argentaria": "argentario",
    "argentarie": "argentario",
    "argentaron": "argentare",
    "argentarono": "argentare",
    "argentasse": "argentare",
    "argentasser": "argentare",
    "argentassero": "argentare",
    "argentassi": "argentare",
    "argentassimo": "argentare",
    "argentaste": "argentare",
    "argentasti": "argentare",
    "argentata": "argentare",
    "argentate": "argentare",
    "argentati": "argentare",
    "argentato": "argentare",
    "argentava": "argentare",
    "argentavamo": "argentare",
    "argentavan": "argentare",
    "argentavano": "argentare",
    "argentavate": "argentare",
    "argentavi": "argentare",
    "argentavo": "argentare",
    "argentea": "argenteo",
    "argentee": "argenteo",
    "argentei": "argenteo",
    "argenterai": "argentare",
    "argenteran": "argentare",
    "argenteranno": "argentare",
    "argenterebbe": "argentare",
    "argenterebber": "argentare",
    "argenterebbero": "argentare",
    "argenterei": "argentare",
    "argenteremmo": "argentare",
    "argenteremo": "argentare",
    "argentereste": "argentare",
    "argenteresti": "argentare",
    "argenterete": "argentare",
    "argenterie": "argenteria",
    "argenterà": "argentare",
    "argenterò": "argentare",
    "argenti": "argento",
    "argentiamo": "argentare",
    "argentiate": "argentare",
    "argentin": "argentare",
    "argentina": "argentino",
    "argentine": "argentino",
    "argentini": "argentino",
    "argentino": "argentare",
    "argento": "argentare",
    "argentò": "argentare",
    "argille": "argilla",
    "argillosa": "argilloso",
    "argillose": "argilloso",
    "argillosi": "argilloso",
    "argina": "arginare",
    "arginai": "arginare",
    "arginammo": "arginare",
    "arginan": "arginare",
    "arginando": "arginare",
    "arginano": "arginare",
    "arginante": "arginare",
    "arginanti": "arginare",
    "arginar": "arginare",
    "arginaron": "arginare",
    "arginarono": "arginare",
    "arginasse": "arginare",
    "arginasser": "arginare",
    "arginassero": "arginare",
    "arginassi": "arginare",
    "arginassimo": "arginare",
    "arginaste": "arginare",
    "arginasti": "arginare",
    "arginata": "arginare",
    "arginate": "arginare",
    "arginati": "arginare",
    "arginato": "arginare",
    "arginava": "arginare",
    "arginavamo": "arginare",
    "arginavan": "arginare",
    "arginavano": "arginare",
    "arginavate": "arginare",
    "arginavi": "arginare",
    "arginavo": "arginare",
    "arginerai": "arginare",
    "argineran": "arginare",
    "argineranno": "arginare",
    "arginerebbe": "arginare",
    "arginerebber": "arginare",
    "arginerebbero": "arginare",
    "arginerei": "arginare",
    "argineremmo": "arginare",
    "argineremo": "arginare",
    "arginereste": "arginare",
    "argineresti": "arginare",
    "arginerete": "arginare",
    "arginerà": "arginare",
    "arginerò": "arginare",
    "argini": "argine",
    "arginiamo": "arginare",
    "arginiate": "arginare",
    "arginin": "arginare",
    "arginino": "arginare",
    "argino": "arginare",
    "arginò": "arginare",
    "argomenta": "argomentare",
    "argomentai": "argomentare",
    "argomentammo": "argomentare",
    "argomentan": "argomentare",
    "argomentando": "argomentare",
    "argomentano": "argomentare",
    "argomentante": "argomentare",
    "argomentanti": "argomentare",
    "argomentar": "argomentare",
    "argomentaron": "argomentare",
    "argomentarono": "argomentare",
    "argomentasse": "argomentare",
    "argomentasser": "argomentare",
    "argomentassero": "argomentare",
    "argomentassi": "argomentare",
    "argomentassimo": "argomentare",
    "argomentaste": "argomentare",
    "argomentasti": "argomentare",
    "argomentata": "argomentato",
    "argomentate": "argomentato",
    "argomentati": "argomentato",
    "argomentativa": "argomentativo",
    "argomentative": "argomentativo",
    "argomentativi": "argomentativo",
    "argomentato": "argomentare",
    "argomentava": "argomentare",
    "argomentavamo": "argomentare",
    "argomentavan": "argomentare",
    "argomentavano": "argomentare",
    "argomentavate": "argomentare",
    "argomentavi": "argomentare",
    "argomentavo": "argomentare",
    "argomentazioni": "argomentazione",
    "argomenterai": "argomentare",
    "argomenteran": "argomentare",
    "argomenteranno": "argomentare",
    "argomenterebbe": "argomentare",
    "argomenterebber": "argomentare",
    "argomenterebbero": "argomentare",
    "argomenterei": "argomentare",
    "argomenteremmo": "argomentare",
    "argomenteremo": "argomentare",
    "argomentereste": "argomentare",
    "argomenteresti": "argomentare",
    "argomenterete": "argomentare",
    "argomenterà": "argomentare",
    "argomenterò": "argomentare",
    "argomenti": "argomento",
    "argomentiamo": "argomentare",
    "argomentiate": "argomentare",
    "argomentin": "argomentare",
    "argomentino": "argomentare",
    "argomento": "argomentare",
    "argomentò": "argomentare",
    "arguendo": "arguire",
    "arguente": "arguire",
    "arguenti": "arguire",
    "arguiamo": "arguire",
    "arguiate": "arguire",
    "arguii": "arguire",
    "arguimmo": "arguire",
    "arguir": "arguire",
    "arguirai": "arguire",
    "arguiran": "arguire",
    "arguiranno": "arguire",
    "arguirebbe": "arguire",
    "arguirebber": "arguire",
    "arguirebbero": "arguire",
    "arguirei": "arguire",
    "arguiremmo": "arguire",
    "arguiremo": "arguire",
    "arguireste": "arguire",
    "arguiresti": "arguire",
    "arguirete": "arguire",
    "arguiron": "arguire",
    "arguirono": "arguire",
    "arguirà": "arguire",
    "arguirò": "arguire",
    "arguisca": "arguire",
    "arguiscan": "arguire",
    "arguiscano": "arguire",
    "arguisce": "arguire",
    "arguisci": "arguire",
    "arguisco": "arguire",
    "arguiscon": "arguire",
    "arguiscono": "arguire",
    "arguisse": "arguire",
    "arguisser": "arguire",
    "arguissero": "arguire",
    "arguissi": "arguire",
    "arguissimo": "arguire",
    "arguiste": "arguire",
    "arguisti": "arguire",
    "arguita": "arguire",
    "arguite": "arguire",
    "arguiti": "arguire",
    "arguito": "arguire",
    "arguiva": "arguire",
    "arguivamo": "arguire",
    "arguivan": "arguire",
    "arguivano": "arguire",
    "arguivate": "arguire",
    "arguivi": "arguire",
    "arguivo": "arguire",
    "arguta": "arguto",
    "argute": "arguto",
    "arguti": "arguto",
    "arguzie": "arguzia",
    "arguì": "arguire",
    "ari": "arare",
    "ariamo": "arare",
    "ariana": "ariano",
    "ariane": "ariano",
    "ariani": "ariano",
    "ariate": "arare",
    "arida": "arido",
    "aride": "arido",
    "aridi": "arido",
    "arie": "aria",
    "arieggerai": "arieggiare",
    "arieggeran": "arieggiare",
    "arieggeranno": "arieggiare",
    "arieggerebbe": "arieggiare",
    "arieggerebber": "arieggiare",
    "arieggerebbero": "arieggiare",
    "arieggerei": "arieggiare",
    "arieggeremmo": "arieggiare",
    "arieggeremo": "arieggiare",
    "arieggereste": "arieggiare",
    "arieggeresti": "arieggiare",
    "arieggerete": "arieggiare",
    "arieggerà": "arieggiare",
    "arieggerò": "arieggiare",
    "arieggi": "arieggiare",
    "arieggia": "arieggiare",
    "arieggiai": "arieggiare",
    "arieggiammo": "arieggiare",
    "arieggiamo": "arieggiare",
    "arieggian": "arieggiare",
    "arieggiando": "arieggiare",
    "arieggiano": "arieggiare",
    "arieggiante": "arieggiare",
    "arieggianti": "arieggiare",
    "arieggiar": "arieggiare",
    "arieggiaron": "arieggiare",
    "arieggiarono": "arieggiare",
    "arieggiasse": "arieggiare",
    "arieggiasser": "arieggiare",
    "arieggiassero": "arieggiare",
    "arieggiassi": "arieggiare",
    "arieggiassimo": "arieggiare",
    "arieggiaste": "arieggiare",
    "arieggiasti": "arieggiare",
    "arieggiata": "arieggiare",
    "arieggiate": "arieggiare",
    "arieggiati": "arieggiare",
    "arieggiato": "arieggiare",
    "arieggiava": "arieggiare",
    "arieggiavamo": "arieggiare",
    "arieggiavan": "arieggiare",
    "arieggiavano": "arieggiare",
    "arieggiavate": "arieggiare",
    "arieggiavi": "arieggiare",
    "arieggiavo": "arieggiare",
    "arieggin": "arieggiare",
    "arieggino": "arieggiare",
    "arieggio": "arieggiare",
    "arieggiò": "arieggiare",
    "ariette": "arietta",
    "arin": "arare",
    "arino": "arare",
    "ariosa": "arioso",
    "ariose": "arioso",
    "ariosi": "arioso",
    "aristocratica": "aristocratico",
    "aristocratiche": "aristocratico",
    "aristocratici": "aristocratico",
    "aristocrazie": "aristocrazia",
    "aristotelica": "aristotelico",
    "aristoteliche": "aristotelico",
    "aristotelici": "aristotelico",
    "aritmetica": "aritmetico",
    "aritmetiche": "aritmetico",
    "aritmetici": "aritmetico",
    "aritmica": "aritmico",
    "aritmiche": "aritmico",
    "aritmici": "aritmico",
    "aritmie": "aritmia",
    "arlecchina": "arlecchino",
    "arlecchine": "arlecchino",
    "arlecchinesca": "arlecchinesco",
    "arlecchinesche": "arlecchinesco",
    "arlecchineschi": "arlecchinesco",
    "arlecchini": "arlecchino",
    "arma": "armare",
    "armadi": "armadio",
    "armadietti": "armadietto",
    "armadioni": "armadione",
    "armai": "armare",
    "armaioli": "armaiolo",
    "armamenta": "armamentare",
    "armamentai": "armamentare",
    "armamentammo": "armamentare",
    "armamentan": "armamentare",
    "armamentando": "armamentare",
    "armamentano": "armamentare",
    "armamentante": "armamentare",
    "armamentanti": "armamentare",
    "armamentar": "armamentare",
    "armamentari": "armamentario",
    "armamentaron": "armamentare",
    "armamentarono": "armamentare",
    "armamentasse": "armamentare",
    "armamentasser": "armamentare",
    "armamentassero": "armamentare",
    "armamentassi": "armamentare",
    "armamentassimo": "armamentare",
    "armamentaste": "armamentare",
    "armamentasti": "armamentare",
    "armamentata": "armamentare",
    "armamentate": "armamentare",
    "armamentati": "armamentare",
    "armamentato": "armamentare",
    "armamentava": "armamentare",
    "armamentavamo": "armamentare",
    "armamentavan": "armamentare",
    "armamentavano": "armamentare",
    "armamentavate": "armamentare",
    "armamentavi": "armamentare",
    "armamentavo": "armamentare",
    "armamenterai": "armamentare",
    "armamenteran": "armamentare",
    "armamenteranno": "armamentare",
    "armamenterebbe": "armamentare",
    "armamenterebber": "armamentare",
    "armamenterebbero": "armamentare",
    "armamenterei": "armamentare",
    "armamenteremmo": "armamentare",
    "armamenteremo": "armamentare",
    "armamentereste": "armamentare",
    "armamenteresti": "armamentare",
    "armamenterete": "armamentare",
    "armamenterà": "armamentare",
    "armamenterò": "armamentare",
    "armamenti": "armamento",
    "armamentiamo": "armamentare",
    "armamentiate": "armamentare",
    "armamentin": "armamentare",
    "armamentino": "armamentare",
    "armamento": "armamentare",
    "armamentò": "armamentare",
    "armammo": "armare",
    "arman": "armare",
    "armando": "armare",
    "armano": "armare",
    "armante": "armare",
    "armanti": "armare",
    "armar": "armare",
    "armaron": "armare",
    "armarono": "armare",
    "armasse": "armare",
    "armasser": "armare",
    "armassero": "armare",
    "armassi": "armare",
    "armassimo": "armare",
    "armaste": "armare",
    "armasti": "armare",
    "armata": "armato",
    "armate": "armato",
    "armati": "armato",
    "armato": "armare",
    "armatori": "armatore",
    "armatoriali": "armatoriale",
    "armatrice": "armatore",
    "armatrici": "armatore",
    "armature": "armatura",
    "armava": "armare",
    "armavamo": "armare",
    "armavan": "armare",
    "armavano": "armare",
    "armavate": "armare",
    "armavi": "armare",
    "armavo": "armare",
    "armeggerai": "armeggiare",
    "armeggeran": "armeggiare",
    "armeggeranno": "armeggiare",
    "armeggerebbe": "armeggiare",
    "armeggerebber": "armeggiare",
    "armeggerebbero": "armeggiare",
    "armeggerei": "armeggiare",
    "armeggeremmo": "armeggiare",
    "armeggeremo": "armeggiare",
    "armeggereste": "armeggiare",
    "armeggeresti": "armeggiare",
    "armeggerete": "armeggiare",
    "armeggerà": "armeggiare",
    "armeggerò": "armeggiare",
    "armeggi": "armeggiare",
    "armeggia": "armeggiare",
    "armeggiai": "armeggiare",
    "armeggiammo": "armeggiare",
    "armeggiamo": "armeggiare",
    "armeggian": "armeggiare",
    "armeggiando": "armeggiare",
    "armeggiano": "armeggiare",
    "armeggiante": "armeggiare",
    "armeggianti": "armeggiare",
    "armeggiar": "armeggiare",
    "armeggiaron": "armeggiare",
    "armeggiarono": "armeggiare",
    "armeggiasse": "armeggiare",
    "armeggiasser": "armeggiare",
    "armeggiassero": "armeggiare",
    "armeggiassi": "armeggiare",
    "armeggiassimo": "armeggiare",
    "armeggiaste": "armeggiare",
    "armeggiasti": "armeggiare",
    "armeggiata": "armeggiare",
    "armeggiate": "armeggiare",
    "armeggiati": "armeggiare",
    "armeggiato": "armeggiare",
    "armeggiava": "armeggiare",
    "armeggiavamo": "armeggiare",
    "armeggiavan": "armeggiare",
    "armeggiavano": "armeggiare",
    "armeggiavate": "armeggiare",
    "armeggiavi": "armeggiare",
    "armeggiavo": "armeggiare",
    "armeggin": "armeggiare",
    "armeggino": "armeggiare",
    "armeggio": "armeggiare",
    "armeggiò": "armeggiare",
    "armena": "armeno",
    "armene": "armeno",
    "armeni": "armeno",
    "armerai": "armare",
    "armeran": "armare",
    "armeranno": "armare",
    "armerebbe": "armare",
    "armerebber": "armare",
    "armerebbero": "armare",
    "armerei": "armare",
    "armeremmo": "armare",
    "armeremo": "armare",
    "armereste": "armare",
    "armeresti": "armare",
    "armerete": "armare",
    "armerie": "armeria",
    "armerà": "armare",
    "armerò": "armare",
    "armi": "armare",
    "armiamo": "armare",
    "armiate": "armare",
    "armieri": "armiere",
    "armin": "armare",
    "armino": "armare",
    "armistizi": "armistizio",
    "armo": "armare",
    "armonica": "armonico",
    "armoniche": "armonico",
    "armonici": "armonico",
    "armonie": "armonia",
    "armoniosa": "armonioso",
    "armoniose": "armonioso",
    "armoniosi": "armonioso",
    "armonizza": "armonizzare",
    "armonizzai": "armonizzare",
    "armonizzammo": "armonizzare",
    "armonizzan": "armonizzare",
    "armonizzando": "armonizzare",
    "armonizzano": "armonizzare",
    "armonizzante": "armonizzare",
    "armonizzanti": "armonizzare",
    "armonizzar": "armonizzare",
    "armonizzaron": "armonizzare",
    "armonizzarono": "armonizzare",
    "armonizzasse": "armonizzare",
    "armonizzasser": "armonizzare",
    "armonizzassero": "armonizzare",
    "armonizzassi": "armonizzare",
    "armonizzassimo": "armonizzare",
    "armonizzaste": "armonizzare",
    "armonizzasti": "armonizzare",
    "armonizzata": "armonizzare",
    "armonizzate": "armonizzare",
    "armonizzati": "armonizzare",
    "armonizzato": "armonizzare",
    "armonizzava": "armonizzare",
    "armonizzavamo": "armonizzare",
    "armonizzavan": "armonizzare",
    "armonizzavano": "armonizzare",
    "armonizzavate": "armonizzare",
    "armonizzavi": "armonizzare",
    "armonizzavo": "armonizzare",
    "armonizzazioni": "armonizzazione",
    "armonizzerai": "armonizzare",
    "armonizzeran": "armonizzare",
    "armonizzeranno": "armonizzare",
    "armonizzerebbe": "armonizzare",
    "armonizzerebber": "armonizzare",
    "armonizzerebbero": "armonizzare",
    "armonizzerei": "armonizzare",
    "armonizzeremmo": "armonizzare",
    "armonizzeremo": "armonizzare",
    "armonizzereste": "armonizzare",
    "armonizzeresti": "armonizzare",
    "armonizzerete": "armonizzare",
    "armonizzerà": "armonizzare",
    "armonizzerò": "armonizzare",
    "armonizzi": "armonizzare",
    "armonizziamo": "armonizzare",
    "armonizziate": "armonizzare",
    "armonizzin": "armonizzare",
    "armonizzino": "armonizzare",
    "armonizzo": "armonizzare",
    "armonizzò": "armonizzare",
    "armò": "armare",
    "arnesi": "arnese",
    "arnie": "arnia",
    "aro": "arare",
    "aromatica": "aromatico",
    "aromatiche": "aromatico",
    "aromatici": "aromatico",
    "aromatizza": "aromatizzare",
    "aromatizzai": "aromatizzare",
    "aromatizzammo": "aromatizzare",
    "aromatizzan": "aromatizzare",
    "aromatizzando": "aromatizzare",
    "aromatizzano": "aromatizzare",
    "aromatizzante": "aromatizzare",
    "aromatizzanti": "aromatizzare",
    "aromatizzar": "aromatizzare",
    "aromatizzaron": "aromatizzare",
    "aromatizzarono": "aromatizzare",
    "aromatizzasse": "aromatizzare",
    "aromatizzasser": "aromatizzare",
    "aromatizzassero": "aromatizzare",
    "aromatizzassi": "aromatizzare",
    "aromatizzassimo": "aromatizzare",
    "aromatizzaste": "aromatizzare",
    "aromatizzasti": "aromatizzare",
    "aromatizzata": "aromatizzare",
    "aromatizzate": "aromatizzare",
    "aromatizzati": "aromatizzare",
    "aromatizzato": "aromatizzare",
    "aromatizzava": "aromatizzare",
    "aromatizzavamo": "aromatizzare",
    "aromatizzavan": "aromatizzare",
    "aromatizzavano": "aromatizzare",
    "aromatizzavate": "aromatizzare",
    "aromatizzavi": "aromatizzare",
    "aromatizzavo": "aromatizzare",
    "aromatizzerai": "aromatizzare",
    "aromatizzeran": "aromatizzare",
    "aromatizzeranno": "aromatizzare",
    "aromatizzerebbe": "aromatizzare",
    "aromatizzerebber": "aromatizzare",
    "aromatizzerebbero": "aromatizzare",
    "aromatizzerei": "aromatizzare",
    "aromatizzeremmo": "aromatizzare",
    "aromatizzeremo": "aromatizzare",
    "aromatizzereste": "aromatizzare",
    "aromatizzeresti": "aromatizzare",
    "aromatizzerete": "aromatizzare",
    "aromatizzerà": "aromatizzare",
    "aromatizzerò": "aromatizzare",
    "aromatizzi": "aromatizzare",
    "aromatizziamo": "aromatizzare",
    "aromatizziate": "aromatizzare",
    "aromatizzin": "aromatizzare",
    "aromatizzino": "aromatizzare",
    "aromatizzo": "aromatizzare",
    "aromatizzò": "aromatizzare",
    "aromi": "aroma",
    "arpe": "arpa",
    "arpeggerai": "arpeggiare",
    "arpeggeran": "arpeggiare",
    "arpeggeranno": "arpeggiare",
    "arpeggerebbe": "arpeggiare",
    "arpeggerebber": "arpeggiare",
    "arpeggerebbero": "arpeggiare",
    "arpeggerei": "arpeggiare",
    "arpeggeremmo": "arpeggiare",
    "arpeggeremo": "arpeggiare",
    "arpeggereste": "arpeggiare",
    "arpeggeresti": "arpeggiare",
    "arpeggerete": "arpeggiare",
    "arpeggerà": "arpeggiare",
    "arpeggerò": "arpeggiare",
    "arpeggi": "arpeggio",
    "arpeggia": "arpeggiare",
    "arpeggiai": "arpeggiare",
    "arpeggiammo": "arpeggiare",
    "arpeggiamo": "arpeggiare",
    "arpeggian": "arpeggiare",
    "arpeggiando": "arpeggiare",
    "arpeggiano": "arpeggiare",
    "arpeggiante": "arpeggiare",
    "arpeggianti": "arpeggiare",
    "arpeggiar": "arpeggiare",
    "arpeggiaron": "arpeggiare",
    "arpeggiarono": "arpeggiare",
    "arpeggiasse": "arpeggiare",
    "arpeggiasser": "arpeggiare",
    "arpeggiassero": "arpeggiare",
    "arpeggiassi": "arpeggiare",
    "arpeggiassimo": "arpeggiare",
    "arpeggiaste": "arpeggiare",
    "arpeggiasti": "arpeggiare",
    "arpeggiata": "arpeggiare",
    "arpeggiate": "arpeggiare",
    "arpeggiati": "arpeggiare",
    "arpeggiato": "arpeggiare",
    "arpeggiava": "arpeggiare",
    "arpeggiavamo": "arpeggiare",
    "arpeggiavan": "arpeggiare",
    "arpeggiavano": "arpeggiare",
    "arpeggiavate": "arpeggiare",
    "arpeggiavi": "arpeggiare",
    "arpeggiavo": "arpeggiare",
    "arpeggin": "arpeggiare",
    "arpeggino": "arpeggiare",
    "arpeggio": "arpeggiare",
    "arpeggiò": "arpeggiare",
    "arpie": "arpia",
    "arpiona": "arpionare",
    "arpionai": "arpionare",
    "arpionammo": "arpionare",
    "arpionan": "arpionare",
    "arpionando": "arpionare",
    "arpionano": "arpionare",
    "arpionante": "arpionare",
    "arpionanti": "arpionare",
    "arpionar": "arpionare",
    "arpionaron": "arpionare",
    "arpionarono": "arpionare",
    "arpionasse": "arpionare",
    "arpionasser": "arpionare",
    "arpionassero": "arpionare",
    "arpionassi": "arpionare",
    "arpionassimo": "arpionare",
    "arpionaste": "arpionare",
    "arpionasti": "arpionare",
    "arpionata": "arpionare",
    "arpionate": "arpionare",
    "arpionati": "arpionare",
    "arpionato": "arpionare",
    "arpionava": "arpionare",
    "arpionavamo": "arpionare",
    "arpionavan": "arpionare",
    "arpionavano": "arpionare",
    "arpionavate": "arpionare",
    "arpionavi": "arpionare",
    "arpionavo": "arpionare",
    "arpionerai": "arpionare",
    "arpioneran": "arpionare",
    "arpioneranno": "arpionare",
    "arpionerebbe": "arpionare",
    "arpionerebber": "arpionare",
    "arpionerebbero": "arpionare",
    "arpionerei": "arpionare",
    "arpioneremmo": "arpionare",
    "arpioneremo": "arpionare",
    "arpionereste": "arpionare",
    "arpioneresti": "arpionare",
    "arpionerete": "arpionare",
    "arpionerà": "arpionare",
    "arpionerò": "arpionare",
    "arpioni": "arpione",
    "arpioniamo": "arpionare",
    "arpioniate": "arpionare",
    "arpionin": "arpionare",
    "arpionino": "arpionare",
    "arpiono": "arpionare",
    "arpionò": "arpionare",
    "arrabatta": "arrabattare",
    "arrabattai": "arrabattare",
    "arrabattammo": "arrabattare",
    "arrabattan": "arrabattare",
    "arrabattando": "arrabattare",
    "arrabattano": "arrabattare",
    "arrabattar": "arrabattare",
    "arrabattaron": "arrabattare",
    "arrabattarono": "arrabattare",
    "arrabattasse": "arrabattare",
    "arrabattasser": "arrabattare",
    "arrabattassero": "arrabattare",
    "arrabattassi": "arrabattare",
    "arrabattassimo": "arrabattare",
    "arrabattaste": "arrabattare",
    "arrabattasti": "arrabattare",
    "arrabattata": "arrabattare",
    "arrabattate": "arrabattare",
    "arrabattati": "arrabattare",
    "arrabattato": "arrabattare",
    "arrabattava": "arrabattare",
    "arrabattavamo": "arrabattare",
    "arrabattavan": "arrabattare",
    "arrabattavano": "arrabattare",
    "arrabattavate": "arrabattare",
    "arrabattavi": "arrabattare",
    "arrabattavo": "arrabattare",
    "arrabatterai": "arrabattare",
    "arrabatteran": "arrabattare",
    "arrabatteranno": "arrabattare",
    "arrabatterebbe": "arrabattare",
    "arrabatterebber": "arrabattare",
    "arrabatterebbero": "arrabattare",
    "arrabatterei": "arrabattare",
    "arrabatteremmo": "arrabattare",
    "arrabatteremo": "arrabattare",
    "arrabattereste": "arrabattare",
    "arrabatteresti": "arrabattare",
    "arrabatterete": "arrabattare",
    "arrabatterà": "arrabattare",
    "arrabatterò": "arrabattare",
    "arrabatti": "arrabattare",
    "arrabattiamo": "arrabattare",
    "arrabattiate": "arrabattare",
    "arrabattin": "arrabattare",
    "arrabattino": "arrabattare",
    "arrabatto": "arrabattare",
    "arrabattò": "arrabattare",
    "arrabbi": "arrabbiare",
    "arrabbia": "arrabbiare",
    "arrabbiai": "arrabbiare",
    "arrabbiammo": "arrabbiare",
    "arrabbiamo": "arrabbiare",
    "arrabbian": "arrabbiare",
    "arrabbiando": "arrabbiare",
    "arrabbiano": "arrabbiare",
    "arrabbiante": "arrabbiare",
    "arrabbianti": "arrabbiare",
    "arrabbiar": "arrabbiare",
    "arrabbiaron": "arrabbiare",
    "arrabbiarono": "arrabbiare",
    "arrabbiasse": "arrabbiare",
    "arrabbiasser": "arrabbiare",
    "arrabbiassero": "arrabbiare",
    "arrabbiassi": "arrabbiare",
    "arrabbiassimo": "arrabbiare",
    "arrabbiaste": "arrabbiare",
    "arrabbiasti": "arrabbiare",
    "arrabbiata": "arrabbiato",
    "arrabbiate": "arrabbiato",
    "arrabbiati": "arrabbiato",
    "arrabbiato": "arrabbiare",
    "arrabbiature": "arrabbiatura",
    "arrabbiava": "arrabbiare",
    "arrabbiavamo": "arrabbiare",
    "arrabbiavan": "arrabbiare",
    "arrabbiavano": "arrabbiare",
    "arrabbiavate": "arrabbiare",
    "arrabbiavi": "arrabbiare",
    "arrabbiavo": "arrabbiare",
    "arrabbierai": "arrabbiare",
    "arrabbieran": "arrabbiare",
    "arrabbieranno": "arrabbiare",
    "arrabbierebbe": "arrabbiare",
    "arrabbierebber": "arrabbiare",
    "arrabbierebbero": "arrabbiare",
    "arrabbierei": "arrabbiare",
    "arrabbieremmo": "arrabbiare",
    "arrabbieremo": "arrabbiare",
    "arrabbiereste": "arrabbiare",
    "arrabbieresti": "arrabbiare",
    "arrabbierete": "arrabbiare",
    "arrabbierà": "arrabbiare",
    "arrabbierò": "arrabbiare",
    "arrabbin": "arrabbiare",
    "arrabbino": "arrabbiare",
    "arrabbio": "arrabbiare",
    "arrabbiò": "arrabbiare",
    "arraffa": "arraffare",
    "arraffai": "arraffare",
    "arraffammo": "arraffare",
    "arraffan": "arraffare",
    "arraffando": "arraffare",
    "arraffano": "arraffare",
    "arraffante": "arraffare",
    "arraffanti": "arraffare",
    "arraffar": "arraffare",
    "arraffaron": "arraffare",
    "arraffarono": "arraffare",
    "arraffasse": "arraffare",
    "arraffasser": "arraffare",
    "arraffassero": "arraffare",
    "arraffassi": "arraffare",
    "arraffassimo": "arraffare",
    "arraffaste": "arraffare",
    "arraffasti": "arraffare",
    "arraffata": "arraffare",
    "arraffate": "arraffare",
    "arraffati": "arraffare",
    "arraffato": "arraffare",
    "arraffava": "arraffare",
    "arraffavamo": "arraffare",
    "arraffavan": "arraffare",
    "arraffavano": "arraffare",
    "arraffavate": "arraffare",
    "arraffavi": "arraffare",
    "arraffavo": "arraffare",
    "arrafferai": "arraffare",
    "arrafferan": "arraffare",
    "arrafferanno": "arraffare",
    "arrafferebbe": "arraffare",
    "arrafferebber": "arraffare",
    "arrafferebbero": "arraffare",
    "arrafferei": "arraffare",
    "arrafferemmo": "arraffare",
    "arrafferemo": "arraffare",
    "arraffereste": "arraffare",
    "arrafferesti": "arraffare",
    "arrafferete": "arraffare",
    "arrafferà": "arraffare",
    "arrafferò": "arraffare",
    "arraffi": "arraffare",
    "arraffiamo": "arraffare",
    "arraffiate": "arraffare",
    "arraffin": "arraffare",
    "arraffino": "arraffare",
    "arraffo": "arraffare",
    "arraffò": "arraffare",
    "arrampica": "arrampicare",
    "arrampicai": "arrampicare",
    "arrampicammo": "arrampicare",
    "arrampican": "arrampicare",
    "arrampicando": "arrampicare",
    "arrampicano": "arrampicare",
    "arrampicante": "arrampicare",
    "arrampicanti": "arrampicare",
    "arrampicar": "arrampicare",
    "arrampicaron": "arrampicare",
    "arrampicarono": "arrampicare",
    "arrampicasse": "arrampicare",
    "arrampicasser": "arrampicare",
    "arrampicassero": "arrampicare",
    "arrampicassi": "arrampicare",
    "arrampicassimo": "arrampicare",
    "arrampicaste": "arrampicare",
    "arrampicasti": "arrampicare",
    "arrampicata": "arrampicare",
    "arrampicate": "arrampicata",
    "arrampicati": "arrampicare",
    "arrampicato": "arrampicare",
    "arrampicatori": "arrampicatore",
    "arrampicava": "arrampicare",
    "arrampicavamo": "arrampicare",
    "arrampicavan": "arrampicare",
    "arrampicavano": "arrampicare",
    "arrampicavate": "arrampicare",
    "arrampicavi": "arrampicare",
    "arrampicavo": "arrampicare",
    "arrampicherai": "arrampicare",
    "arrampicheran": "arrampicare",
    "arrampicheranno": "arrampicare",
    "arrampicherebbe": "arrampicare",
    "arrampicherebber": "arrampicare",
    "arrampicherebbero": "arrampicare",
    "arrampicherei": "arrampicare",
    "arrampicheremmo": "arrampicare",
    "arrampicheremo": "arrampicare",
    "arrampichereste": "arrampicare",
    "arrampicheresti": "arrampicare",
    "arrampicherete": "arrampicare",
    "arrampicherà": "arrampicare",
    "arrampicherò": "arrampicare",
    "arrampichi": "arrampicare",
    "arrampichiamo": "arrampicare",
    "arrampichiate": "arrampicare",
    "arrampichin": "arrampicare",
    "arrampichino": "arrampicare",
    "arrampico": "arrampicare",
    "arrampicò": "arrampicare",
    "arranca": "arrancare",
    "arrancai": "arrancare",
    "arrancammo": "arrancare",
    "arrancan": "arrancare",
    "arrancando": "arrancare",
    "arrancano": "arrancare",
    "arrancante": "arrancare",
    "arrancanti": "arrancare",
    "arrancar": "arrancare",
    "arrancaron": "arrancare",
    "arrancarono": "arrancare",
    "arrancasse": "arrancare",
    "arrancasser": "arrancare",
    "arrancassero": "arrancare",
    "arrancassi": "arrancare",
    "arrancassimo": "arrancare",
    "arrancaste": "arrancare",
    "arrancasti": "arrancare",
    "arrancata": "arrancare",
    "arrancate": "arrancare",
    "arrancati": "arrancare",
    "arrancato": "arrancare",
    "arrancava": "arrancare",
    "arrancavamo": "arrancare",
    "arrancavan": "arrancare",
    "arrancavano": "arrancare",
    "arrancavate": "arrancare",
    "arrancavi": "arrancare",
    "arrancavo": "arrancare",
    "arrancherai": "arrancare",
    "arrancheran": "arrancare",
    "arrancheranno": "arrancare",
    "arrancherebbe": "arrancare",
    "arrancherebber": "arrancare",
    "arrancherebbero": "arrancare",
    "arrancherei": "arrancare",
    "arrancheremmo": "arrancare",
    "arrancheremo": "arrancare",
    "arranchereste": "arrancare",
    "arrancheresti": "arrancare",
    "arrancherete": "arrancare",
    "arrancherà": "arrancare",
    "arrancherò": "arrancare",
    "arranchi": "arrancare",
    "arranchiamo": "arrancare",
    "arranchiate": "arrancare",
    "arranchin": "arrancare",
    "arranchino": "arrancare",
    "arranco": "arrancare",
    "arrancò": "arrancare",
    "arrangerai": "arrangiare",
    "arrangeran": "arrangiare",
    "arrangeranno": "arrangiare",
    "arrangerebbe": "arrangiare",
    "arrangerebber": "arrangiare",
    "arrangerebbero": "arrangiare",
    "arrangerei": "arrangiare",
    "arrangeremmo": "arrangiare",
    "arrangeremo": "arrangiare",
    "arrangereste": "arrangiare",
    "arrangeresti": "arrangiare",
    "arrangerete": "arrangiare",
    "arrangerà": "arrangiare",
    "arrangerò": "arrangiare",
    "arrangi": "arrangiare",
    "arrangia": "arrangiare",
    "arrangiai": "arrangiare",
    "arrangiamenti": "arrangiamento",
    "arrangiammo": "arrangiare",
    "arrangiamo": "arrangiare",
    "arrangian": "arrangiare",
    "arrangiando": "arrangiare",
    "arrangiano": "arrangiare",
    "arrangiante": "arrangiare",
    "arrangianti": "arrangiare",
    "arrangiar": "arrangiare",
    "arrangiaron": "arrangiare",
    "arrangiarono": "arrangiare",
    "arrangiasse": "arrangiare",
    "arrangiasser": "arrangiare",
    "arrangiassero": "arrangiare",
    "arrangiassi": "arrangiare",
    "arrangiassimo": "arrangiare",
    "arrangiaste": "arrangiare",
    "arrangiasti": "arrangiare",
    "arrangiata": "arrangiare",
    "arrangiate": "arrangiare",
    "arrangiati": "arrangiare",
    "arrangiato": "arrangiare",
    "arrangiatori": "arrangiatore",
    "arrangiava": "arrangiare",
    "arrangiavamo": "arrangiare",
    "arrangiavan": "arrangiare",
    "arrangiavano": "arrangiare",
    "arrangiavate": "arrangiare",
    "arrangiavi": "arrangiare",
    "arrangiavo": "arrangiare",
    "arrangin": "arrangiare",
    "arrangino": "arrangiare",
    "arrangio": "arrangiare",
    "arrangiò": "arrangiare",
    "arreca": "arrecare",
    "arrecai": "arrecare",
    "arrecammo": "arrecare",
    "arrecan": "arrecare",
    "arrecando": "arrecare",
    "arrecano": "arrecare",
    "arrecante": "arrecare",
    "arrecanti": "arrecare",
    "arrecar": "arrecare",
    "arrecaron": "arrecare",
    "arrecarono": "arrecare",
    "arrecasse": "arrecare",
    "arrecasser": "arrecare",
    "arrecassero": "arrecare",
    "arrecassi": "arrecare",
    "arrecassimo": "arrecare",
    "arrecaste": "arrecare",
    "arrecasti": "arrecare",
    "arrecata": "arrecare",
    "arrecate": "arrecare",
    "arrecati": "arrecare",
    "arrecato": "arrecare",
    "arrecava": "arrecare",
    "arrecavamo": "arrecare",
    "arrecavan": "arrecare",
    "arrecavano": "arrecare",
    "arrecavate": "arrecare",
    "arrecavi": "arrecare",
    "arrecavo": "arrecare",
    "arrecherai": "arrecare",
    "arrecheran": "arrecare",
    "arrecheranno": "arrecare",
    "arrecherebbe": "arrecare",
    "arrecherebber": "arrecare",
    "arrecherebbero": "arrecare",
    "arrecherei": "arrecare",
    "arrecheremmo": "arrecare",
    "arrecheremo": "arrecare",
    "arrechereste": "arrecare",
    "arrecheresti": "arrecare",
    "arrecherete": "arrecare",
    "arrecherà": "arrecare",
    "arrecherò": "arrecare",
    "arrechi": "arrecare",
    "arrechiamo": "arrecare",
    "arrechiate": "arrecare",
    "arrechin": "arrecare",
    "arrechino": "arrecare",
    "arreco": "arrecare",
    "arrecò": "arrecare",
    "arreda": "arredare",
    "arredai": "arredare",
    "arredamenti": "arredamento",
    "arredammo": "arredare",
    "arredan": "arredare",
    "arredando": "arredare",
    "arredano": "arredare",
    "arredante": "arredare",
    "arredanti": "arredare",
    "arredar": "arredare",
    "arredaron": "arredare",
    "arredarono": "arredare",
    "arredasse": "arredare",
    "arredasser": "arredare",
    "arredassero": "arredare",
    "arredassi": "arredare",
    "arredassimo": "arredare",
    "arredaste": "arredare",
    "arredasti": "arredare",
    "arredata": "arredare",
    "arredate": "arredare",
    "arredati": "arredare",
    "arredato": "arredare",
    "arredatori": "arredatore",
    "arredava": "arredare",
    "arredavamo": "arredare",
    "arredavan": "arredare",
    "arredavano": "arredare",
    "arredavate": "arredare",
    "arredavi": "arredare",
    "arredavo": "arredare",
    "arrederai": "arredare",
    "arrederan": "arredare",
    "arrederanno": "arredare",
    "arrederebbe": "arredare",
    "arrederebber": "arredare",
    "arrederebbero": "arredare",
    "arrederei": "arredare",
    "arrederemmo": "arredare",
    "arrederemo": "arredare",
    "arredereste": "arredare",
    "arrederesti": "arredare",
    "arrederete": "arredare",
    "arrederà": "arredare",
    "arrederò": "arredare",
    "arredi": "arredo",
    "arrediamo": "arredare",
    "arrediate": "arredare",
    "arredin": "arredare",
    "arredino": "arredare",
    "arredo": "arredare",
    "arredò": "arredare",
    "arremba": "arrembare",
    "arrembaggi": "arrembaggio",
    "arrembai": "arrembare",
    "arrembammo": "arrembare",
    "arremban": "arrembare",
    "arrembando": "arrembare",
    "arrembano": "arrembare",
    "arrembante": "arrembare",
    "arrembanti": "arrembare",
    "arrembar": "arrembare",
    "arrembaron": "arrembare",
    "arrembarono": "arrembare",
    "arrembasse": "arrembare",
    "arrembasser": "arrembare",
    "arrembassero": "arrembare",
    "arrembassi": "arrembare",
    "arrembassimo": "arrembare",
    "arrembaste": "arrembare",
    "arrembasti": "arrembare",
    "arrembata": "arrembare",
    "arrembate": "arrembare",
    "arrembati": "arrembare",
    "arrembato": "arrembare",
    "arrembava": "arrembare",
    "arrembavamo": "arrembare",
    "arrembavan": "arrembare",
    "arrembavano": "arrembare",
    "arrembavate": "arrembare",
    "arrembavi": "arrembare",
    "arrembavo": "arrembare",
    "arremberai": "arrembare",
    "arremberan": "arrembare",
    "arremberanno": "arrembare",
    "arremberebbe": "arrembare",
    "arremberebber": "arrembare",
    "arremberebbero": "arrembare",
    "arremberei": "arrembare",
    "arremberemmo": "arrembare",
    "arremberemo": "arrembare",
    "arrembereste": "arrembare",
    "arremberesti": "arrembare",
    "arremberete": "arrembare",
    "arremberà": "arrembare",
    "arremberò": "arrembare",
    "arrembi": "arrembare",
    "arrembiamo": "arrembare",
    "arrembiate": "arrembare",
    "arrembin": "arrembare",
    "arrembino": "arrembare",
    "arrembo": "arrembare",
    "arrembò": "arrembare",
    "arrenda": "arrendere",
    "arrendan": "arrendere",
    "arrendano": "arrendere",
    "arrende": "arrendere",
    "arrendemmo": "arrendere",
    "arrendendo": "arrendere",
    "arrendente": "arrendere",
    "arrendenti": "arrendere",
    "arrender": "arrendere",
    "arrenderai": "arrendere",
    "arrenderan": "arrendere",
    "arrenderanno": "arrendere",
    "arrenderebbe": "arrendere",
    "arrenderebber": "arrendere",
    "arrenderebbero": "arrendere",
    "arrenderei": "arrendere",
    "arrenderemmo": "arrendere",
    "arrenderemo": "arrendere",
    "arrendereste": "arrendere",
    "arrenderesti": "arrendere",
    "arrenderete": "arrendere",
    "arrenderà": "arrendere",
    "arrenderò": "arrendere",
    "arrendesse": "arrendere",
    "arrendesser": "arrendere",
    "arrendessero": "arrendere",
    "arrendessi": "arrendere",
    "arrendessimo": "arrendere",
    "arrendeste": "arrendere",
    "arrendesti": "arrendere",
    "arrendete": "arrendere",
    "arrendeva": "arrendere",
    "arrendevamo": "arrendere",
    "arrendevan": "arrendere",
    "arrendevano": "arrendere",
    "arrendevate": "arrendere",
    "arrendevi": "arrendere",
    "arrendevo": "arrendere",
    "arrendevolezze": "arrendevolezza",
    "arrendevoli": "arrendevole",
    "arrendi": "arrendere",
    "arrendiamo": "arrendere",
    "arrendiate": "arrendere",
    "arrendo": "arrendere",
    "arrendon": "arrendere",
    "arrendono": "arrendere",
    "arresa": "arrendere",
    "arrese": "arrendere",
    "arreser": "arrendere",
    "arresero": "arrendere",
    "arresi": "arrendere",
    "arreso": "arrendere",
    "arresta": "arrestare",
    "arrestai": "arrestare",
    "arrestammo": "arrestare",
    "arrestan": "arrestare",
    "arrestando": "arrestare",
    "arrestano": "arrestare",
    "arrestante": "arrestare",
    "arrestanti": "arrestare",
    "arrestar": "arrestare",
    "arrestaron": "arrestare",
    "arrestarono": "arrestare",
    "arrestasse": "arrestare",
    "arrestasser": "arrestare",
    "arrestassero": "arrestare",
    "arrestassi": "arrestare",
    "arrestassimo": "arrestare",
    "arrestaste": "arrestare",
    "arrestasti": "arrestare",
    "arrestata": "arrestato",
    "arrestate": "arrestato",
    "arrestati": "arrestato",
    "arrestato": "arrestare",
    "arrestava": "arrestare",
    "arrestavamo": "arrestare",
    "arrestavan": "arrestare",
    "arrestavano": "arrestare",
    "arrestavate": "arrestare",
    "arrestavi": "arrestare",
    "arrestavo": "arrestare",
    "arresterai": "arrestare",
    "arresteran": "arrestare",
    "arresteranno": "arrestare",
    "arresterebbe": "arrestare",
    "arresterebber": "arrestare",
    "arresterebbero": "arrestare",
    "arresterei": "arrestare",
    "arresteremmo": "arrestare",
    "arresteremo": "arrestare",
    "arrestereste": "arrestare",
    "arresteresti": "arrestare",
    "arresterete": "arrestare",
    "arresterà": "arrestare",
    "arresterò": "arrestare",
    "arresti": "arresto",
    "arrestiamo": "arrestare",
    "arrestiate": "arrestare",
    "arrestin": "arrestare",
    "arrestino": "arrestare",
    "arresto": "arrestare",
    "arrestò": "arrestare",
    "arresè": "arrendere",
    "arretra": "arretrare",
    "arretrai": "arretrare",
    "arretramenti": "arretramento",
    "arretrammo": "arretrare",
    "arretran": "arretrare",
    "arretrando": "arretrare",
    "arretrano": "arretrare",
    "arretrante": "arretrare",
    "arretranti": "arretrare",
    "arretrar": "arretrare",
    "arretraron": "arretrare",
    "arretrarono": "arretrare",
    "arretrasse": "arretrare",
    "arretrasser": "arretrare",
    "arretrassero": "arretrare",
    "arretrassi": "arretrare",
    "arretrassimo": "arretrare",
    "arretraste": "arretrare",
    "arretrasti": "arretrare",
    "arretrata": "arretrato",
    "arretrate": "arretrato",
    "arretratezze": "arretratezza",
    "arretrati": "arretrato",
    "arretrato": "arretrare",
    "arretrava": "arretrare",
    "arretravamo": "arretrare",
    "arretravan": "arretrare",
    "arretravano": "arretrare",
    "arretravate": "arretrare",
    "arretravi": "arretrare",
    "arretravo": "arretrare",
    "arretrerai": "arretrare",
    "arretreran": "arretrare",
    "arretreranno": "arretrare",
    "arretrerebbe": "arretrare",
    "arretrerebber": "arretrare",
    "arretrerebbero": "arretrare",
    "arretrerei": "arretrare",
    "arretreremmo": "arretrare",
    "arretreremo": "arretrare",
    "arretrereste": "arretrare",
    "arretreresti": "arretrare",
    "arretrerete": "arretrare",
    "arretrerà": "arretrare",
    "arretrerò": "arretrare",
    "arretri": "arretrare",
    "arretriamo": "arretrare",
    "arretriate": "arretrare",
    "arretrin": "arretrare",
    "arretrino": "arretrare",
    "arretro": "arretrare",
    "arretrò": "arretrare",
    "arriccerai": "arricciare",
    "arricceran": "arricciare",
    "arricceranno": "arricciare",
    "arriccerebbe": "arricciare",
    "arriccerebber": "arricciare",
    "arriccerebbero": "arricciare",
    "arriccerei": "arricciare",
    "arricceremmo": "arricciare",
    "arricceremo": "arricciare",
    "arriccereste": "arricciare",
    "arricceresti": "arricciare",
    "arriccerete": "arricciare",
    "arriccerà": "arricciare",
    "arriccerò": "arricciare",
    "arricchendo": "arricchire",
    "arricchente": "arricchire",
    "arricchenti": "arricchire",
    "arricchiamo": "arricchire",
    "arricchiate": "arricchire",
    "arricchii": "arricchire",
    "arricchimenti": "arricchimento",
    "arricchimmo": "arricchire",
    "arricchir": "arricchire",
    "arricchirai": "arricchire",
    "arricchiran": "arricchire",
    "arricchiranno": "arricchire",
    "arricchirebbe": "arricchire",
    "arricchirebber": "arricchire",
    "arricchirebbero": "arricchire",
    "arricchirei": "arricchire",
    "arricchiremmo": "arricchire",
    "arricchiremo": "arricchire",
    "arricchireste": "arricchire",
    "arricchiresti": "arricchire",
    "arricchirete": "arricchire",
    "arricchiron": "arricchire",
    "arricchirono": "arricchire",
    "arricchirà": "arricchire",
    "arricchirò": "arricchire",
    "arricchisca": "arricchire",
    "arricchiscan": "arricchire",
    "arricchiscano": "arricchire",
    "arricchisce": "arricchire",
    "arricchisci": "arricchire",
    "arricchisco": "arricchire",
    "arricchiscon": "arricchire",
    "arricchiscono": "arricchire",
    "arricchisse": "arricchire",
    "arricchisser": "arricchire",
    "arricchissero": "arricchire",
    "arricchissi": "arricchire",
    "arricchissimo": "arricchire",
    "arricchiste": "arricchire",
    "arricchisti": "arricchire",
    "arricchita": "arricchito",
    "arricchite": "arricchito",
    "arricchiti": "arricchito",
    "arricchito": "arricchire",
    "arricchiva": "arricchire",
    "arricchivamo": "arricchire",
    "arricchivan": "arricchire",
    "arricchivano": "arricchire",
    "arricchivate": "arricchire",
    "arricchivi": "arricchire",
    "arricchivo": "arricchire",
    "arricchì": "arricchire",
    "arricci": "arricciare",
    "arriccia": "arricciare",
    "arricciai": "arricciare",
    "arricciammo": "arricciare",
    "arricciamo": "arricciare",
    "arriccian": "arricciare",
    "arricciando": "arricciare",
    "arricciano": "arricciare",
    "arricciante": "arricciare",
    "arriccianti": "arricciare",
    "arricciar": "arricciare",
    "arricciaron": "arricciare",
    "arricciarono": "arricciare",
    "arricciasse": "arricciare",
    "arricciasser": "arricciare",
    "arricciassero": "arricciare",
    "arricciassi": "arricciare",
    "arricciassimo": "arricciare",
    "arricciaste": "arricciare",
    "arricciasti": "arricciare",
    "arricciata": "arricciare",
    "arricciate": "arricciare",
    "arricciati": "arricciare",
    "arricciato": "arricciare",
    "arricciava": "arricciare",
    "arricciavamo": "arricciare",
    "arricciavan": "arricciare",
    "arricciavano": "arricciare",
    "arricciavate": "arricciare",
    "arricciavi": "arricciare",
    "arricciavo": "arricciare",
    "arriccin": "arricciare",
    "arriccino": "arricciare",
    "arriccio": "arricciare",
    "arricciola": "arricciolare",
    "arricciolai": "arricciolare",
    "arricciolammo": "arricciolare",
    "arricciolan": "arricciolare",
    "arricciolando": "arricciolare",
    "arricciolano": "arricciolare",
    "arricciolante": "arricciolare",
    "arricciolanti": "arricciolare",
    "arricciolar": "arricciolare",
    "arricciolaron": "arricciolare",
    "arricciolarono": "arricciolare",
    "arricciolasse": "arricciolare",
    "arricciolasser": "arricciolare",
    "arricciolassero": "arricciolare",
    "arricciolassi": "arricciolare",
    "arricciolassimo": "arricciolare",
    "arricciolaste": "arricciolare",
    "arricciolasti": "arricciolare",
    "arricciolata": "arricciolare",
    "arricciolate": "arricciolare",
    "arricciolati": "arricciolare",
    "arricciolato": "arricciolare",
    "arricciolava": "arricciolare",
    "arricciolavamo": "arricciolare",
    "arricciolavan": "arricciolare",
    "arricciolavano": "arricciolare",
    "arricciolavate": "arricciolare",
    "arricciolavi": "arricciolare",
    "arricciolavo": "arricciolare",
    "arricciolerai": "arricciolare",
    "arriccioleran": "arricciolare",
    "arriccioleranno": "arricciolare",
    "arricciolerebbe": "arricciolare",
    "arricciolerebber": "arricciolare",
    "arricciolerebbero": "arricciolare",
    "arricciolerei": "arricciolare",
    "arriccioleremmo": "arricciolare",
    "arriccioleremo": "arricciolare",
    "arricciolereste": "arricciolare",
    "arriccioleresti": "arricciolare",
    "arricciolerete": "arricciolare",
    "arricciolerà": "arricciolare",
    "arricciolerò": "arricciolare",
    "arriccioli": "arricciolare",
    "arriccioliamo": "arricciolare",
    "arriccioliate": "arricciolare",
    "arricciolin": "arricciolare",
    "arricciolino": "arricciolare",
    "arricciolo": "arricciolare",
    "arricciolò": "arricciolare",
    "arricciò": "arricciare",
    "arrida": "arridere",
    "arridan": "arridere",
    "arridano": "arridere",
    "arride": "arridere",
    "arridei": "arridere",
    "arridemmo": "arridere",
    "arridendo": "arridere",
    "arridente": "arridere",
    "arridenti": "arridere",
    "arrider": "arridere",
    "arriderai": "arridere",
    "arrideran": "arridere",
    "arrideranno": "arridere",
    "arriderebbe": "arridere",
    "arriderebber": "arridere",
    "arriderebbero": "arridere",
    "arriderei": "arridere",
    "arrideremmo": "arridere",
    "arrideremo": "arridere",
    "arridereste": "arridere",
    "arrideresti": "arridere",
    "arriderete": "arridere",
    "arrideron": "arridere",
    "arriderono": "arridere",
    "arriderà": "arridere",
    "arriderò": "arridere",
    "arridesse": "arridere",
    "arridesser": "arridere",
    "arridessero": "arridere",
    "arridessi": "arridere",
    "arridessimo": "arridere",
    "arrideste": "arridere",
    "arridesti": "arridere",
    "arridete": "arridere",
    "arrideva": "arridere",
    "arridevamo": "arridere",
    "arridevan": "arridere",
    "arridevano": "arridere",
    "arridevate": "arridere",
    "arridevi": "arridere",
    "arridevo": "arridere",
    "arridi": "arridere",
    "arridiamo": "arridere",
    "arridiate": "arridere",
    "arrido": "arridere",
    "arridon": "arridere",
    "arridono": "arridere",
    "arriduta": "arridere",
    "arridute": "arridere",
    "arriduti": "arridere",
    "arriduto": "arridere",
    "arridè": "arridere",
    "arringa": "arringare",
    "arringai": "arringare",
    "arringammo": "arringare",
    "arringan": "arringare",
    "arringando": "arringare",
    "arringano": "arringare",
    "arringante": "arringare",
    "arringanti": "arringare",
    "arringar": "arringare",
    "arringaron": "arringare",
    "arringarono": "arringare",
    "arringasse": "arringare",
    "arringasser": "arringare",
    "arringassero": "arringare",
    "arringassi": "arringare",
    "arringassimo": "arringare",
    "arringaste": "arringare",
    "arringasti": "arringare",
    "arringata": "arringare",
    "arringate": "arringare",
    "arringati": "arringare",
    "arringato": "arringare",
    "arringava": "arringare",
    "arringavamo": "arringare",
    "arringavan": "arringare",
    "arringavano": "arringare",
    "arringavate": "arringare",
    "arringavi": "arringare",
    "arringavo": "arringare",
    "arringhe": "arringa",
    "arringherai": "arringare",
    "arringheran": "arringare",
    "arringheranno": "arringare",
    "arringherebbe": "arringare",
    "arringherebber": "arringare",
    "arringherebbero": "arringare",
    "arringherei": "arringare",
    "arringheremmo": "arringare",
    "arringheremo": "arringare",
    "arringhereste": "arringare",
    "arringheresti": "arringare",
    "arringherete": "arringare",
    "arringherà": "arringare",
    "arringherò": "arringare",
    "arringhi": "arringare",
    "arringhiamo": "arringare",
    "arringhiate": "arringare",
    "arringhin": "arringare",
    "arringhino": "arringare",
    "arringo": "arringare",
    "arringò": "arringare",
    "arrischi": "arrischiare",
    "arrischia": "arrischiare",
    "arrischiai": "arrischiare",
    "arrischiammo": "arrischiare",
    "arrischiamo": "arrischiare",
    "arrischian": "arrischiare",
    "arrischiando": "arrischiare",
    "arrischiano": "arrischiare",
    "arrischiante": "arrischiare",
    "arrischianti": "arrischiare",
    "arrischiar": "arrischiare",
    "arrischiaron": "arrischiare",
    "arrischiarono": "arrischiare",
    "arrischiasse": "arrischiare",
    "arrischiasser": "arrischiare",
    "arrischiassero": "arrischiare",
    "arrischiassi": "arrischiare",
    "arrischiassimo": "arrischiare",
    "arrischiaste": "arrischiare",
    "arrischiasti": "arrischiare",
    "arrischiata": "arrischiato",
    "arrischiate": "arrischiato",
    "arrischiati": "arrischiato",
    "arrischiato": "arrischiare",
    "arrischiava": "arrischiare",
    "arrischiavamo": "arrischiare",
    "arrischiavan": "arrischiare",
    "arrischiavano": "arrischiare",
    "arrischiavate": "arrischiare",
    "arrischiavi": "arrischiare",
    "arrischiavo": "arrischiare",
    "arrischierai": "arrischiare",
    "arrischieran": "arrischiare",
    "arrischieranno": "arrischiare",
    "arrischierebbe": "arrischiare",
    "arrischierebber": "arrischiare",
    "arrischierebbero": "arrischiare",
    "arrischierei": "arrischiare",
    "arrischieremmo": "arrischiare",
    "arrischieremo": "arrischiare",
    "arrischiereste": "arrischiare",
    "arrischieresti": "arrischiare",
    "arrischierete": "arrischiare",
    "arrischierà": "arrischiare",
    "arrischierò": "arrischiare",
    "arrischin": "arrischiare",
    "arrischino": "arrischiare",
    "arrischio": "arrischiare",
    "arrischiò": "arrischiare",
    "arriva": "arrivare",
    "arrivai": "arrivare",
    "arrivammo": "arrivare",
    "arrivan": "arrivare",
    "arrivando": "arrivare",
    "arrivano": "arrivare",
    "arrivante": "arrivare",
    "arrivanti": "arrivare",
    "arrivar": "arrivare",
    "arrivaron": "arrivare",
    "arrivarono": "arrivare",
    "arrivasse": "arrivare",
    "arrivasser": "arrivare",
    "arrivassero": "arrivare",
    "arrivassi": "arrivare",
    "arrivassimo": "arrivare",
    "arrivaste": "arrivare",
    "arrivasti": "arrivare",
    "arrivata": "arrivato",
    "arrivate": "arrivato",
    "arrivati": "arrivato",
    "arrivato": "arrivare",
    "arrivava": "arrivare",
    "arrivavamo": "arrivare",
    "arrivavan": "arrivare",
    "arrivavano": "arrivare",
    "arrivavate": "arrivare",
    "arrivavi": "arrivare",
    "arrivavo": "arrivare",
    "arriverai": "arrivare",
    "arriveran": "arrivare",
    "arriveranno": "arrivare",
    "arriverebbe": "arrivare",
    "arriverebber": "arrivare",
    "arriverebbero": "arrivare",
    "arriverei": "arrivare",
    "arriveremmo": "arrivare",
    "arriveremo": "arrivare",
    "arrivereste": "arrivare",
    "arriveresti": "arrivare",
    "arriverete": "arrivare",
    "arriverà": "arrivare",
    "arriverò": "arrivare",
    "arrivi": "arrivo",
    "arriviamo": "arrivare",
    "arriviate": "arrivare",
    "arrivin": "arrivare",
    "arrivino": "arrivare",
    "arrivisti": "arrivista",
    "arrivo": "arrivare",
    "arrivò": "arrivare",
    "arrocca": "arroccare",
    "arroccai": "arroccare",
    "arroccamenti": "arroccamento",
    "arroccammo": "arroccare",
    "arroccan": "arroccare",
    "arroccando": "arroccare",
    "arroccano": "arroccare",
    "arroccante": "arroccare",
    "arroccanti": "arroccare",
    "arroccar": "arroccare",
    "arroccaron": "arroccare",
    "arroccarono": "arroccare",
    "arroccasse": "arroccare",
    "arroccasser": "arroccare",
    "arroccassero": "arroccare",
    "arroccassi": "arroccare",
    "arroccassimo": "arroccare",
    "arroccaste": "arroccare",
    "arroccasti": "arroccare",
    "arroccata": "arroccare",
    "arroccate": "arroccare",
    "arroccati": "arroccare",
    "arroccato": "arroccare",
    "arroccava": "arroccare",
    "arroccavamo": "arroccare",
    "arroccavan": "arroccare",
    "arroccavano": "arroccare",
    "arroccavate": "arroccare",
    "arroccavi": "arroccare",
    "arroccavo": "arroccare",
    "arroccherai": "arroccare",
    "arroccheran": "arroccare",
    "arroccheranno": "arroccare",
    "arroccherebbe": "arroccare",
    "arroccherebber": "arroccare",
    "arroccherebbero": "arroccare",
    "arroccherei": "arroccare",
    "arroccheremmo": "arroccare",
    "arroccheremo": "arroccare",
    "arrocchereste": "arroccare",
    "arroccheresti": "arroccare",
    "arroccherete": "arroccare",
    "arroccherà": "arroccare",
    "arroccherò": "arroccare",
    "arrocchi": "arroccare",
    "arrocchiamo": "arroccare",
    "arrocchiate": "arroccare",
    "arrocchin": "arroccare",
    "arrocchino": "arroccare",
    "arrocco": "arroccare",
    "arroccò": "arroccare",
    "arrocha": "arrochire",
    "arrochan": "arrochire",
    "arrochano": "arrochire",
    "arroche": "arrochire",
    "arrochendo": "arrochire",
    "arrochente": "arrochire",
    "arrochenti": "arrochire",
    "arrochi": "arrochire",
    "arrochiamo": "arrochire",
    "arrochiate": "arrochire",
    "arrochii": "arrochire",
    "arrochimmo": "arrochire",
    "arrochir": "arrochire",
    "arrochirai": "arrochire",
    "arrochiran": "arrochire",
    "arrochiranno": "arrochire",
    "arrochirebbe": "arrochire",
    "arrochirebber": "arrochire",
    "arrochirebbero": "arrochire",
    "arrochirei": "arrochire",
    "arrochiremmo": "arrochire",
    "arrochiremo": "arrochire",
    "arrochireste": "arrochire",
    "arrochiresti": "arrochire",
    "arrochirete": "arrochire",
    "arrochiron": "arrochire",
    "arrochirono": "arrochire",
    "arrochirà": "arrochire",
    "arrochirò": "arrochire",
    "arrochisse": "arrochire",
    "arrochisser": "arrochire",
    "arrochissero": "arrochire",
    "arrochissi": "arrochire",
    "arrochissimo": "arrochire",
    "arrochiste": "arrochire",
    "arrochisti": "arrochire",
    "arrochita": "arrochire",
    "arrochite": "arrochire",
    "arrochiti": "arrochire",
    "arrochito": "arrochire",
    "arrochiva": "arrochire",
    "arrochivamo": "arrochire",
    "arrochivan": "arrochire",
    "arrochivano": "arrochire",
    "arrochivate": "arrochire",
    "arrochivi": "arrochire",
    "arrochivo": "arrochire",
    "arrocho": "arrochire",
    "arrochon": "arrochire",
    "arrochono": "arrochire",
    "arrochì": "arrochire",
    "arroga": "arrogare",
    "arrogai": "arrogare",
    "arrogammo": "arrogare",
    "arrogan": "arrogare",
    "arrogando": "arrogare",
    "arrogano": "arrogare",
    "arrogante": "arrogare",
    "arroganti": "arrogare",
    "arroganze": "arroganza",
    "arrogar": "arrogare",
    "arrogaron": "arrogare",
    "arrogarono": "arrogare",
    "arrogasse": "arrogare",
    "arrogasser": "arrogare",
    "arrogassero": "arrogare",
    "arrogassi": "arrogare",
    "arrogassimo": "arrogare",
    "arrogaste": "arrogare",
    "arrogasti": "arrogare",
    "arrogata": "arrogare",
    "arrogate": "arrogare",
    "arrogati": "arrogare",
    "arrogato": "arrogare",
    "arrogava": "arrogare",
    "arrogavamo": "arrogare",
    "arrogavan": "arrogare",
    "arrogavano": "arrogare",
    "arrogavate": "arrogare",
    "arrogavi": "arrogare",
    "arrogavo": "arrogare",
    "arrogherai": "arrogare",
    "arrogheran": "arrogare",
    "arrogheranno": "arrogare",
    "arrogherebbe": "arrogare",
    "arrogherebber": "arrogare",
    "arrogherebbero": "arrogare",
    "arrogherei": "arrogare",
    "arrogheremmo": "arrogare",
    "arrogheremo": "arrogare",
    "arroghereste": "arrogare",
    "arrogheresti": "arrogare",
    "arrogherete": "arrogare",
    "arrogherà": "arrogare",
    "arrogherò": "arrogare",
    "arroghi": "arrogare",
    "arroghiamo": "arrogare",
    "arroghiate": "arrogare",
    "arroghin": "arrogare",
    "arroghino": "arrogare",
    "arrogo": "arrogare",
    "arrogò": "arrogare",
    "arrossa": "arrossare",
    "arrossai": "arrossare",
    "arrossamenti": "arrossamento",
    "arrossammo": "arrossare",
    "arrossan": "arrossare",
    "arrossando": "arrossare",
    "arrossano": "arrossare",
    "arrossante": "arrossare",
    "arrossanti": "arrossare",
    "arrossar": "arrossare",
    "arrossaron": "arrossare",
    "arrossarono": "arrossare",
    "arrossasse": "arrossare",
    "arrossasser": "arrossare",
    "arrossassero": "arrossare",
    "arrossassi": "arrossare",
    "arrossassimo": "arrossare",
    "arrossaste": "arrossare",
    "arrossasti": "arrossare",
    "arrossata": "arrossare",
    "arrossate": "arrossare",
    "arrossati": "arrossare",
    "arrossato": "arrossare",
    "arrossava": "arrossare",
    "arrossavamo": "arrossare",
    "arrossavan": "arrossare",
    "arrossavano": "arrossare",
    "arrossavate": "arrossare",
    "arrossavi": "arrossare",
    "arrossavo": "arrossare",
    "arrossendo": "arrossire",
    "arrossente": "arrossire",
    "arrossenti": "arrossire",
    "arrosserai": "arrossare",
    "arrosseran": "arrossare",
    "arrosseranno": "arrossare",
    "arrosserebbe": "arrossare",
    "arrosserebber": "arrossare",
    "arrosserebbero": "arrossare",
    "arrosserei": "arrossare",
    "arrosseremmo": "arrossare",
    "arrosseremo": "arrossare",
    "arrossereste": "arrossare",
    "arrosseresti": "arrossare",
    "arrosserete": "arrossare",
    "arrosserà": "arrossare",
    "arrosserò": "arrossare",
    "arrossi": "arrossare",
    "arrossiamo": "arrossire",
    "arrossiate": "arrossire",
    "arrossii": "arrossire",
    "arrossimmo": "arrossire",
    "arrossin": "arrossare",
    "arrossino": "arrossare",
    "arrossir": "arrossire",
    "arrossirai": "arrossire",
    "arrossiran": "arrossire",
    "arrossiranno": "arrossire",
    "arrossirebbe": "arrossire",
    "arrossirebber": "arrossire",
    "arrossirebbero": "arrossire",
    "arrossirei": "arrossire",
    "arrossiremmo": "arrossire",
    "arrossiremo": "arrossire",
    "arrossireste": "arrossire",
    "arrossiresti": "arrossire",
    "arrossirete": "arrossire",
    "arrossiron": "arrossire",
    "arrossirono": "arrossire",
    "arrossirà": "arrossire",
    "arrossirò": "arrossire",
    "arrossisca": "arrossire",
    "arrossiscan": "arrossire",
    "arrossiscano": "arrossire",
    "arrossisce": "arrossire",
    "arrossisci": "arrossire",
    "arrossisco": "arrossire",
    "arrossiscon": "arrossire",
    "arrossiscono": "arrossire",
    "arrossisse": "arrossire",
    "arrossisser": "arrossire",
    "arrossissero": "arrossire",
    "arrossissi": "arrossire",
    "arrossissimo": "arrossire",
    "arrossiste": "arrossire",
    "arrossisti": "arrossire",
    "arrossita": "arrossire",
    "arrossite": "arrossire",
    "arrossiti": "arrossire",
    "arrossito": "arrossire",
    "arrossiva": "arrossire",
    "arrossivamo": "arrossire",
    "arrossivan": "arrossire",
    "arrossivano": "arrossire",
    "arrossivate": "arrossire",
    "arrossivi": "arrossire",
    "arrossivo": "arrossire",
    "arrosso": "arrossare",
    "arrossì": "arrossire",
    "arrossò": "arrossare",
    "arrosta": "arrosto",
    "arroste": "arrosto",
    "arrostendo": "arrostire",
    "arrostente": "arrostire",
    "arrostenti": "arrostire",
    "arrosti": "arrosto",
    "arrostiamo": "arrostire",
    "arrostiate": "arrostire",
    "arrostii": "arrostire",
    "arrostimmo": "arrostire",
    "arrostir": "arrostire",
    "arrostirai": "arrostire",
    "arrostiran": "arrostire",
    "arrostiranno": "arrostire",
    "arrostirebbe": "arrostire",
    "arrostirebber": "arrostire",
    "arrostirebbero": "arrostire",
    "arrostirei": "arrostire",
    "arrostiremmo": "arrostire",
    "arrostiremo": "arrostire",
    "arrostireste": "arrostire",
    "arrostiresti": "arrostire",
    "arrostirete": "arrostire",
    "arrostiron": "arrostire",
    "arrostirono": "arrostire",
    "arrostirà": "arrostire",
    "arrostirò": "arrostire",
    "arrostisca": "arrostire",
    "arrostiscan": "arrostire",
    "arrostiscano": "arrostire",
    "arrostisce": "arrostire",
    "arrostisci": "arrostire",
    "arrostisco": "arrostire",
    "arrostiscon": "arrostire",
    "arrostiscono": "arrostire",
    "arrostisse": "arrostire",
    "arrostisser": "arrostire",
    "arrostissero": "arrostire",
    "arrostissi": "arrostire",
    "arrostissimo": "arrostire",
    "arrostiste": "arrostire",
    "arrostisti": "arrostire",
    "arrostita": "arrostire",
    "arrostite": "arrostire",
    "arrostiti": "arrostire",
    "arrostito": "arrostire",
    "arrostiva": "arrostire",
    "arrostivamo": "arrostire",
    "arrostivan": "arrostire",
    "arrostivano": "arrostire",
    "arrostivate": "arrostire",
    "arrostivi": "arrostire",
    "arrostivo": "arrostire",
    "arrostì": "arrostire",
    "arrota": "arrotare",
    "arrotai": "arrotare",
    "arrotammo": "arrotare",
    "arrotan": "arrotare",
    "arrotando": "arrotare",
    "arrotano": "arrotare",
    "arrotante": "arrotare",
    "arrotanti": "arrotare",
    "arrotar": "arrotare",
    "arrotaron": "arrotare",
    "arrotarono": "arrotare",
    "arrotasse": "arrotare",
    "arrotasser": "arrotare",
    "arrotassero": "arrotare",
    "arrotassi": "arrotare",
    "arrotassimo": "arrotare",
    "arrotaste": "arrotare",
    "arrotasti": "arrotare",
    "arrotata": "arrotare",
    "arrotate": "arrotare",
    "arrotati": "arrotare",
    "arrotato": "arrotare",
    "arrotava": "arrotare",
    "arrotavamo": "arrotare",
    "arrotavan": "arrotare",
    "arrotavano": "arrotare",
    "arrotavate": "arrotare",
    "arrotavi": "arrotare",
    "arrotavo": "arrotare",
    "arroterai": "arrotare",
    "arroteran": "arrotare",
    "arroteranno": "arrotare",
    "arroterebbe": "arrotare",
    "arroterebber": "arrotare",
    "arroterebbero": "arrotare",
    "arroterei": "arrotare",
    "arroteremmo": "arrotare",
    "arroteremo": "arrotare",
    "arrotereste": "arrotare",
    "arroteresti": "arrotare",
    "arroterete": "arrotare",
    "arroterà": "arrotare",
    "arroterò": "arrotare",
    "arroti": "arrotare",
    "arrotiamo": "arrotare",
    "arrotiate": "arrotare",
    "arrotin": "arrotare",
    "arrotini": "arrotino",
    "arrotino": "arrotare",
    "arroto": "arrotare",
    "arrotola": "arrotolare",
    "arrotolai": "arrotolare",
    "arrotolammo": "arrotolare",
    "arrotolan": "arrotolare",
    "arrotolando": "arrotolare",
    "arrotolano": "arrotolare",
    "arrotolante": "arrotolare",
    "arrotolanti": "arrotolare",
    "arrotolar": "arrotolare",
    "arrotolaron": "arrotolare",
    "arrotolarono": "arrotolare",
    "arrotolasse": "arrotolare",
    "arrotolasser": "arrotolare",
    "arrotolassero": "arrotolare",
    "arrotolassi": "arrotolare",
    "arrotolassimo": "arrotolare",
    "arrotolaste": "arrotolare",
    "arrotolasti": "arrotolare",
    "arrotolata": "arrotolare",
    "arrotolate": "arrotolare",
    "arrotolati": "arrotolare",
    "arrotolato": "arrotolare",
    "arrotolava": "arrotolare",
    "arrotolavamo": "arrotolare",
    "arrotolavan": "arrotolare",
    "arrotolavano": "arrotolare",
    "arrotolavate": "arrotolare",
    "arrotolavi": "arrotolare",
    "arrotolavo": "arrotolare",
    "arrotolerai": "arrotolare",
    "arrotoleran": "arrotolare",
    "arrotoleranno": "arrotolare",
    "arrotolerebbe": "arrotolare",
    "arrotolerebber": "arrotolare",
    "arrotolerebbero": "arrotolare",
    "arrotolerei": "arrotolare",
    "arrotoleremmo": "arrotolare",
    "arrotoleremo": "arrotolare",
    "arrotolereste": "arrotolare",
    "arrotoleresti": "arrotolare",
    "arrotolerete": "arrotolare",
    "arrotolerà": "arrotolare",
    "arrotolerò": "arrotolare",
    "arrotoli": "arrotolare",
    "arrotoliamo": "arrotolare",
    "arrotoliate": "arrotolare",
    "arrotolin": "arrotolare",
    "arrotolino": "arrotolare",
    "arrotolo": "arrotolare",
    "arrotolò": "arrotolare",
    "arrotonda": "arrotondare",
    "arrotondabili": "arrotondabile",
    "arrotondai": "arrotondare",
    "arrotondamenti": "arrotondamento",
    "arrotondammo": "arrotondare",
    "arrotondan": "arrotondare",
    "arrotondando": "arrotondare",
    "arrotondano": "arrotondare",
    "arrotondante": "arrotondare",
    "arrotondanti": "arrotondare",
    "arrotondar": "arrotondare",
    "arrotondaron": "arrotondare",
    "arrotondarono": "arrotondare",
    "arrotondasse": "arrotondare",
    "arrotondasser": "arrotondare",
    "arrotondassero": "arrotondare",
    "arrotondassi": "arrotondare",
    "arrotondassimo": "arrotondare",
    "arrotondaste": "arrotondare",
    "arrotondasti": "arrotondare",
    "arrotondata": "arrotondare",
    "arrotondate": "arrotondare",
    "arrotondati": "arrotondare",
    "arrotondato": "arrotondare",
    "arrotondava": "arrotondare",
    "arrotondavamo": "arrotondare",
    "arrotondavan": "arrotondare",
    "arrotondavano": "arrotondare",
    "arrotondavate": "arrotondare",
    "arrotondavi": "arrotondare",
    "arrotondavo": "arrotondare",
    "arrotonderai": "arrotondare",
    "arrotonderan": "arrotondare",
    "arrotonderanno": "arrotondare",
    "arrotonderebbe": "arrotondare",
    "arrotonderebber": "arrotondare",
    "arrotonderebbero": "arrotondare",
    "arrotonderei": "arrotondare",
    "arrotonderemmo": "arrotondare",
    "arrotonderemo": "arrotondare",
    "arrotondereste": "arrotondare",
    "arrotonderesti": "arrotondare",
    "arrotonderete": "arrotondare",
    "arrotonderà": "arrotondare",
    "arrotonderò": "arrotondare",
    "arrotondi": "arrotondare",
    "arrotondiamo": "arrotondare",
    "arrotondiate": "arrotondare",
    "arrotondin": "arrotondare",
    "arrotondino": "arrotondare",
    "arrotondo": "arrotondare",
    "arrotondò": "arrotondare",
    "arrotò": "arrotare",
    "arrovella": "arrovellare",
    "arrovellai": "arrovellare",
    "arrovellammo": "arrovellare",
    "arrovellan": "arrovellare",
    "arrovellando": "arrovellare",
    "arrovellano": "arrovellare",
    "arrovellante": "arrovellare",
    "arrovellanti": "arrovellare",
    "arrovellar": "arrovellare",
    "arrovellaron": "arrovellare",
    "arrovellarono": "arrovellare",
    "arrovellasse": "arrovellare",
    "arrovellasser": "arrovellare",
    "arrovellassero": "arrovellare",
    "arrovellassi": "arrovellare",
    "arrovellassimo": "arrovellare",
    "arrovellaste": "arrovellare",
    "arrovellasti": "arrovellare",
    "arrovellata": "arrovellare",
    "arrovellate": "arrovellare",
    "arrovellati": "arrovellare",
    "arrovellato": "arrovellare",
    "arrovellava": "arrovellare",
    "arrovellavamo": "arrovellare",
    "arrovellavan": "arrovellare",
    "arrovellavano": "arrovellare",
    "arrovellavate": "arrovellare",
    "arrovellavi": "arrovellare",
    "arrovellavo": "arrovellare",
    "arrovellerai": "arrovellare",
    "arrovelleran": "arrovellare",
    "arrovelleranno": "arrovellare",
    "arrovellerebbe": "arrovellare",
    "arrovellerebber": "arrovellare",
    "arrovellerebbero": "arrovellare",
    "arrovellerei": "arrovellare",
    "arrovelleremmo": "arrovellare",
    "arrovelleremo": "arrovellare",
    "arrovellereste": "arrovellare",
    "arrovelleresti": "arrovellare",
    "arrovellerete": "arrovellare",
    "arrovellerà": "arrovellare",
    "arrovellerò": "arrovellare",
    "arrovelli": "arrovellare",
    "arrovelliamo": "arrovellare",
    "arrovelliate": "arrovellare",
    "arrovellin": "arrovellare",
    "arrovellino": "arrovellare",
    "arrovello": "arrovellare",
    "arrovellò": "arrovellare",
    "arroventa": "arroventare",
    "arroventai": "arroventare",
    "arroventammo": "arroventare",
    "arroventan": "arroventare",
    "arroventando": "arroventare",
    "arroventano": "arroventare",
    "arroventante": "arroventare",
    "arroventanti": "arroventare",
    "arroventar": "arroventare",
    "arroventaron": "arroventare",
    "arroventarono": "arroventare",
    "arroventasse": "arroventare",
    "arroventasser": "arroventare",
    "arroventassero": "arroventare",
    "arroventassi": "arroventare",
    "arroventassimo": "arroventare",
    "arroventaste": "arroventare",
    "arroventasti": "arroventare",
    "arroventata": "arroventato",
    "arroventate": "arroventato",
    "arroventati": "arroventato",
    "arroventato": "arroventare",
    "arroventava": "arroventare",
    "arroventavamo": "arroventare",
    "arroventavan": "arroventare",
    "arroventavano": "arroventare",
    "arroventavate": "arroventare",
    "arroventavi": "arroventare",
    "arroventavo": "arroventare",
    "arroventerai": "arroventare",
    "arroventeran": "arroventare",
    "arroventeranno": "arroventare",
    "arroventerebbe": "arroventare",
    "arroventerebber": "arroventare",
    "arroventerebbero": "arroventare",
    "arroventerei": "arroventare",
    "arroventeremmo": "arroventare",
    "arroventeremo": "arroventare",
    "arroventereste": "arroventare",
    "arroventeresti": "arroventare",
    "arroventerete": "arroventare",
    "arroventerà": "arroventare",
    "arroventerò": "arroventare",
    "arroventi": "arroventare",
    "arroventiamo": "arroventare",
    "arroventiate": "arroventare",
    "arroventin": "arroventare",
    "arroventino": "arroventare",
    "arrovento": "arroventare",
    "arroventò": "arroventare",
    "arrovescerai": "arrovesciare",
    "arrovesceran": "arrovesciare",
    "arrovesceranno": "arrovesciare",
    "arrovescerebbe": "arrovesciare",
    "arrovescerebber": "arrovesciare",
    "arrovescerebbero": "arrovesciare",
    "arrovescerei": "arrovesciare",
    "arrovesceremmo": "arrovesciare",
    "arrovesceremo": "arrovesciare",
    "arrovescereste": "arrovesciare",
    "arrovesceresti": "arrovesciare",
    "arrovescerete": "arrovesciare",
    "arrovescerà": "arrovesciare",
    "arrovescerò": "arrovesciare",
    "arrovesci": "arrovesciare",
    "arrovescia": "arrovesciare",
    "arrovesciai": "arrovesciare",
    "arrovesciammo": "arrovesciare",
    "arrovesciamo": "arrovesciare",
    "arrovescian": "arrovesciare",
    "arrovesciando": "arrovesciare",
    "arrovesciano": "arrovesciare",
    "arrovesciante": "arrovesciare",
    "arrovescianti": "arrovesciare",
    "arrovesciar": "arrovesciare",
    "arrovesciaron": "arrovesciare",
    "arrovesciarono": "arrovesciare",
    "arrovesciasse": "arrovesciare",
    "arrovesciasser": "arrovesciare",
    "arrovesciassero": "arrovesciare",
    "arrovesciassi": "arrovesciare",
    "arrovesciassimo": "arrovesciare",
    "arrovesciaste": "arrovesciare",
    "arrovesciasti": "arrovesciare",
    "arrovesciata": "arrovesciare",
    "arrovesciate": "arrovesciare",
    "arrovesciati": "arrovesciare",
    "arrovesciato": "arrovesciare",
    "arrovesciava": "arrovesciare",
    "arrovesciavamo": "arrovesciare",
    "arrovesciavan": "arrovesciare",
    "arrovesciavano": "arrovesciare",
    "arrovesciavate": "arrovesciare",
    "arrovesciavi": "arrovesciare",
    "arrovesciavo": "arrovesciare",
    "arrovescin": "arrovesciare",
    "arrovescino": "arrovesciare",
    "arrovescio": "arrovesciare",
    "arrovesciò": "arrovesciare",
    "arruffa": "arruffare",
    "arruffai": "arruffare",
    "arruffammo": "arruffare",
    "arruffan": "arruffare",
    "arruffando": "arruffare",
    "arruffano": "arruffare",
    "arruffante": "arruffare",
    "arruffanti": "arruffare",
    "arruffar": "arruffare",
    "arruffaron": "arruffare",
    "arruffarono": "arruffare",
    "arruffasse": "arruffare",
    "arruffasser": "arruffare",
    "arruffassero": "arruffare",
    "arruffassi": "arruffare",
    "arruffassimo": "arruffare",
    "arruffaste": "arruffare",
    "arruffasti": "arruffare",
    "arruffata": "arruffato",
    "arruffate": "arruffato",
    "arruffati": "arruffato",
    "arruffato": "arruffare",
    "arruffava": "arruffare",
    "arruffavamo": "arruffare",
    "arruffavan": "arruffare",
    "arruffavano": "arruffare",
    "arruffavate": "arruffare",
    "arruffavi": "arruffare",
    "arruffavo": "arruffare",
    "arrufferai": "arruffare",
    "arrufferan": "arruffare",
    "arrufferanno": "arruffare",
    "arrufferebbe": "arruffare",
    "arrufferebber": "arruffare",
    "arrufferebbero": "arruffare",
    "arrufferei": "arruffare",
    "arrufferemmo": "arruffare",
    "arrufferemo": "arruffare",
    "arruffereste": "arruffare",
    "arrufferesti": "arruffare",
    "arrufferete": "arruffare",
    "arrufferà": "arruffare",
    "arrufferò": "arruffare",
    "arruffi": "arruffare",
    "arruffiamo": "arruffare",
    "arruffiate": "arruffare",
    "arruffin": "arruffare",
    "arruffino": "arruffare",
    "arruffo": "arruffare",
    "arruffò": "arruffare",
    "arrugginendo": "arrugginire",
    "arrugginente": "arrugginire",
    "arrugginenti": "arrugginire",
    "arrugginiamo": "arrugginire",
    "arrugginiate": "arrugginire",
    "arrugginii": "arrugginire",
    "arrugginimmo": "arrugginire",
    "arrugginir": "arrugginire",
    "arrugginirai": "arrugginire",
    "arrugginiran": "arrugginire",
    "arrugginiranno": "arrugginire",
    "arrugginirebbe": "arrugginire",
    "arrugginirebber": "arrugginire",
    "arrugginirebbero": "arrugginire",
    "arrugginirei": "arrugginire",
    "arrugginiremmo": "arrugginire",
    "arrugginiremo": "arrugginire",
    "arrugginireste": "arrugginire",
    "arrugginiresti": "arrugginire",
    "arrugginirete": "arrugginire",
    "arrugginiron": "arrugginire",
    "arrugginirono": "arrugginire",
    "arrugginirà": "arrugginire",
    "arrugginirò": "arrugginire",
    "arrugginisca": "arrugginire",
    "arrugginiscan": "arrugginire",
    "arrugginiscano": "arrugginire",
    "arrugginisce": "arrugginire",
    "arrugginisci": "arrugginire",
    "arrugginisco": "arrugginire",
    "arrugginiscon": "arrugginire",
    "arrugginiscono": "arrugginire",
    "arrugginisse": "arrugginire",
    "arrugginisser": "arrugginire",
    "arrugginissero": "arrugginire",
    "arrugginissi": "arrugginire",
    "arrugginissimo": "arrugginire",
    "arrugginiste": "arrugginire",
    "arrugginisti": "arrugginire",
    "arrugginita": "arrugginire",
    "arrugginite": "arrugginire",
    "arrugginiti": "arrugginire",
    "arrugginito": "arrugginire",
    "arrugginiva": "arrugginire",
    "arrugginivamo": "arrugginire",
    "arrugginivan": "arrugginire",
    "arrugginivano": "arrugginire",
    "arrugginivate": "arrugginire",
    "arrugginivi": "arrugginire",
    "arrugginivo": "arrugginire",
    "arrugginì": "arrugginire",
    "arruola": "arruolare",
    "arruolai": "arruolare",
    "arruolamenti": "arruolamento",
    "arruolammo": "arruolare",
    "arruolan": "arruolare",
    "arruolando": "arruolare",
    "arruolano": "arruolare",
    "arruolante": "arruolare",
    "arruolanti": "arruolare",
    "arruolar": "arruolare",
    "arruolaron": "arruolare",
    "arruolarono": "arruolare",
    "arruolasse": "arruolare",
    "arruolasser": "arruolare",
    "arruolassero": "arruolare",
    "arruolassi": "arruolare",
    "arruolassimo": "arruolare",
    "arruolaste": "arruolare",
    "arruolasti": "arruolare",
    "arruolata": "arruolare",
    "arruolate": "arruolare",
    "arruolati": "arruolare",
    "arruolato": "arruolare",
    "arruolava": "arruolare",
    "arruolavamo": "arruolare",
    "arruolavan": "arruolare",
    "arruolavano": "arruolare",
    "arruolavate": "arruolare",
    "arruolavi": "arruolare",
    "arruolavo": "arruolare",
    "arruolerai": "arruolare",
    "arruoleran": "arruolare",
    "arruoleranno": "arruolare",
    "arruolerebbe": "arruolare",
    "arruolerebber": "arruolare",
    "arruolerebbero": "arruolare",
    "arruolerei": "arruolare",
    "arruoleremmo": "arruolare",
    "arruoleremo": "arruolare",
    "arruolereste": "arruolare",
    "arruoleresti": "arruolare",
    "arruolerete": "arruolare",
    "arruolerà": "arruolare",
    "arruolerò": "arruolare",
    "arruoli": "arruolare",
    "arruoliamo": "arruolare",
    "arruoliate": "arruolare",
    "arruolin": "arruolare",
    "arruolino": "arruolare",
    "arruolo": "arruolare",
    "arruolò": "arruolare",
    "arsa": "arso",
    "arse": "arso",
    "arsenali": "arsenale",
    "arser": "ardere",
    "arsero": "ardere",
    "arsi": "arso",
    "arso": "ardere",
    "arsè": "ardere",
    "artefatta": "artefatto",
    "artefatte": "artefatto",
    "artefatti": "artefatto",
    "artefici": "artefice",
    "arterie": "arteria",
    "arteriosa": "arterioso",
    "arteriosclerotica": "arteriosclerotico",
    "arteriosclerotiche": "arteriosclerotico",
    "arteriosclerotici": "arteriosclerotico",
    "arteriose": "arterioso",
    "arteriosi": "arterioso",
    "arti": "arto",
    "artica": "artico",
    "artiche": "artico",
    "artici": "artico",
    "articola": "articolare",
    "articolai": "articolare",
    "articolammo": "articolare",
    "articolan": "articolare",
    "articolando": "articolare",
    "articolano": "articolare",
    "articolante": "articolare",
    "articolanti": "articolare",
    "articolar": "articolare",
    "articolaron": "articolare",
    "articolarono": "articolare",
    "articolasse": "articolare",
    "articolasser": "articolare",
    "articolassero": "articolare",
    "articolassi": "articolare",
    "articolassimo": "articolare",
    "articolaste": "articolare",
    "articolasti": "articolare",
    "articolata": "articolato",
    "articolate": "articolato",
    "articolati": "articolato",
    "articolato": "articolare",
    "articolava": "articolare",
    "articolavamo": "articolare",
    "articolavan": "articolare",
    "articolavano": "articolare",
    "articolavate": "articolare",
    "articolavi": "articolare",
    "articolavo": "articolare",
    "articolazioni": "articolazione",
    "articolerai": "articolare",
    "articoleran": "articolare",
    "articoleranno": "articolare",
    "articolerebbe": "articolare",
    "articolerebber": "articolare",
    "articolerebbero": "articolare",
    "articolerei": "articolare",
    "articoleremmo": "articolare",
    "articoleremo": "articolare",
    "articolereste": "articolare",
    "articoleresti": "articolare",
    "articolerete": "articolare",
    "articolerà": "articolare",
    "articolerò": "articolare",
    "articoletti": "articoletto",
    "articoli": "articolo",
    "articoliamo": "articolare",
    "articoliate": "articolare",
    "articolin": "articolare",
    "articolino": "articolare",
    "articolisti": "articolista",
    "articolo": "articolare",
    "articolò": "articolare",
    "artieri": "artiere",
    "artifici": "artificio",
    "artificiali": "artificiale",
    "artificieri": "artificiere",
    "artificiosa": "artificioso",
    "artificiose": "artificioso",
    "artificiosi": "artificioso",
    "artifizi": "artifizio",
    "artigiana": "artigiano",
    "artigianali": "artigianale",
    "artigianati": "artigianato",
    "artigiane": "artigiano",
    "artigiani": "artigiano",
    "artigli": "artiglio",
    "artiglia": "artigliare",
    "artigliai": "artigliare",
    "artigliammo": "artigliare",
    "artigliamo": "artigliare",
    "artiglian": "artigliare",
    "artigliando": "artigliare",
    "artigliano": "artigliare",
    "artigliante": "artigliare",
    "artiglianti": "artigliare",
    "artigliar": "artigliare",
    "artigliaron": "artigliare",
    "artigliarono": "artigliare",
    "artigliasse": "artigliare",
    "artigliasser": "artigliare",
    "artigliassero": "artigliare",
    "artigliassi": "artigliare",
    "artigliassimo": "artigliare",
    "artigliaste": "artigliare",
    "artigliasti": "artigliare",
    "artigliata": "artigliare",
    "artigliate": "artigliare",
    "artigliati": "artigliare",
    "artigliato": "artigliare",
    "artigliava": "artigliare",
    "artigliavamo": "artigliare",
    "artigliavan": "artigliare",
    "artigliavano": "artigliare",
    "artigliavate": "artigliare",
    "artigliavi": "artigliare",
    "artigliavo": "artigliare",
    "artiglierai": "artigliare",
    "artiglieran": "artigliare",
    "artiglieranno": "artigliare",
    "artiglierebbe": "artigliare",
    "artiglierebber": "artigliare",
    "artiglierebbero": "artigliare",
    "artiglierei": "artigliare",
    "artiglieremmo": "artigliare",
    "artiglieremo": "artigliare",
    "artigliereste": "artigliare",
    "artiglieresti": "artigliare",
    "artiglierete": "artigliare",
    "artiglieri": "artigliere",
    "artiglierie": "artiglieria",
    "artiglierà": "artigliare",
    "artiglierò": "artigliare",
    "artiglin": "artigliare",
    "artiglino": "artigliare",
    "artiglio": "artigliare",
    "artigliò": "artigliare",
    "artiste": "artista",
    "artisti": "artista",
    "artistica": "artistico",
    "artistiche": "artistico",
    "artistici": "artistico",
    "artriti": "artrite",
    "aruspici": "aruspice",
    "arzigogola": "arzigogolare",
    "arzigogolai": "arzigogolare",
    "arzigogolammo": "arzigogolare",
    "arzigogolan": "arzigogolare",
    "arzigogolando": "arzigogolare",
    "arzigogolano": "arzigogolare",
    "arzigogolante": "arzigogolare",
    "arzigogolanti": "arzigogolare",
    "arzigogolar": "arzigogolare",
    "arzigogolaron": "arzigogolare",
    "arzigogolarono": "arzigogolare",
    "arzigogolasse": "arzigogolare",
    "arzigogolasser": "arzigogolare",
    "arzigogolassero": "arzigogolare",
    "arzigogolassi": "arzigogolare",
    "arzigogolassimo": "arzigogolare",
    "arzigogolaste": "arzigogolare",
    "arzigogolasti": "arzigogolare",
    "arzigogolata": "arzigogolato",
    "arzigogolate": "arzigogolato",
    "arzigogolati": "arzigogolato",
    "arzigogolato": "arzigogolare",
    "arzigogolava": "arzigogolare",
    "arzigogolavamo": "arzigogolare",
    "arzigogolavan": "arzigogolare",
    "arzigogolavano": "arzigogolare",
    "arzigogolavate": "arzigogolare",
    "arzigogolavi": "arzigogolare",
    "arzigogolavo": "arzigogolare",
    "arzigogolerai": "arzigogolare",
    "arzigogoleran": "arzigogolare",
    "arzigogoleranno": "arzigogolare",
    "arzigogolerebbe": "arzigogolare",
    "arzigogolerebber": "arzigogolare",
    "arzigogolerebbero": "arzigogolare",
    "arzigogolerei": "arzigogolare",
    "arzigogoleremmo": "arzigogolare",
    "arzigogoleremo": "arzigogolare",
    "arzigogolereste": "arzigogolare",
    "arzigogoleresti": "arzigogolare",
    "arzigogolerete": "arzigogolare",
    "arzigogolerà": "arzigogolare",
    "arzigogolerò": "arzigogolare",
    "arzigogoli": "arzigogolo",
    "arzigogoliamo": "arzigogolare",
    "arzigogoliate": "arzigogolare",
    "arzigogolin": "arzigogolare",
    "arzigogolino": "arzigogolare",
    "arzigogolo": "arzigogolare",
    "arzigogolò": "arzigogolare",
    "arzilla": "arzillo",
    "arzille": "arzillo",
    "arzilli": "arzillo",
    "arò": "arare",
    "asburgica": "asburgico",
    "asburgiche": "asburgico",
    "asburgici": "asburgico",
    "ascari": "ascaro",
    "asce": "ascia",
    "ascelle": "ascella",
    "ascenda": "ascendere",
    "ascendan": "ascendere",
    "ascendano": "ascendere",
    "ascende": "ascendere",
    "ascendemmo": "ascendere",
    "ascendendo": "ascendere",
    "ascendente": "ascendere",
    "ascendenti": "ascendere",
    "ascendenze": "ascendenza",
    "ascender": "ascendere",
    "ascenderai": "ascendere",
    "ascenderan": "ascendere",
    "ascenderanno": "ascendere",
    "ascenderebbe": "ascendere",
    "ascenderebber": "ascendere",
    "ascenderebbero": "ascendere",
    "ascenderei": "ascendere",
    "ascenderemmo": "ascendere",
    "ascenderemo": "ascendere",
    "ascendereste": "ascendere",
    "ascenderesti": "ascendere",
    "ascenderete": "ascendere",
    "ascenderà": "ascendere",
    "ascenderò": "ascendere",
    "ascendesse": "ascendere",
    "ascendesser": "ascendere",
    "ascendessero": "ascendere",
    "ascendessi": "ascendere",
    "ascendessimo": "ascendere",
    "ascendeste": "ascendere",
    "ascendesti": "ascendere",
    "ascendete": "ascendere",
    "ascendeva": "ascendere",
    "ascendevamo": "ascendere",
    "ascendevan": "ascendere",
    "ascendevano": "ascendere",
    "ascendevate": "ascendere",
    "ascendevi": "ascendere",
    "ascendevo": "ascendere",
    "ascendi": "ascendere",
    "ascendiamo": "ascendere",
    "ascendiate": "ascendere",
    "ascendo": "ascendere",
    "ascendon": "ascendere",
    "ascendono": "ascendere",
    "ascensionali": "ascensionale",
    "ascensioni": "ascensione",
    "ascensori": "ascensore",
    "ascesa": "ascendere",
    "ascese": "ascesa",
    "asceser": "ascendere",
    "ascesero": "ascendere",
    "ascesi": "ascendere",
    "asceso": "ascendere",
    "ascessi": "ascesso",
    "ascesè": "ascendere",
    "asceti": "asceta",
    "ascetica": "ascetico",
    "ascetiche": "ascetico",
    "ascetici": "ascetico",
    "asciuga": "asciugare",
    "asciugai": "asciugare",
    "asciugamani": "asciugamano",
    "asciugammo": "asciugare",
    "asciugan": "asciugare",
    "asciugando": "asciugare",
    "asciugano": "asciugare",
    "asciugante": "asciugare",
    "asciuganti": "asciugare",
    "asciugar": "asciugare",
    "asciugaron": "asciugare",
    "asciugarono": "asciugare",
    "asciugasse": "asciugare",
    "asciugasser": "asciugare",
    "asciugassero": "asciugare",
    "asciugassi": "asciugare",
    "asciugassimo": "asciugare",
    "asciugaste": "asciugare",
    "asciugasti": "asciugare",
    "asciugata": "asciugare",
    "asciugate": "asciugare",
    "asciugati": "asciugare",
    "asciugato": "asciugare",
    "asciugava": "asciugare",
    "asciugavamo": "asciugare",
    "asciugavan": "asciugare",
    "asciugavano": "asciugare",
    "asciugavate": "asciugare",
    "asciugavi": "asciugare",
    "asciugavo": "asciugare",
    "asciugherai": "asciugare",
    "asciugheran": "asciugare",
    "asciugheranno": "asciugare",
    "asciugherebbe": "asciugare",
    "asciugherebber": "asciugare",
    "asciugherebbero": "asciugare",
    "asciugherei": "asciugare",
    "asciugheremmo": "asciugare",
    "asciugheremo": "asciugare",
    "asciughereste": "asciugare",
    "asciugheresti": "asciugare",
    "asciugherete": "asciugare",
    "asciugherà": "asciugare",
    "asciugherò": "asciugare",
    "asciughi": "asciugare",
    "asciughiamo": "asciugare",
    "asciughiate": "asciugare",
    "asciughin": "asciugare",
    "asciughino": "asciugare",
    "asciugo": "asciugare",
    "asciugò": "asciugare",
    "asciutta": "asciutto",
    "asciutte": "asciutto",
    "asciuttezze": "asciuttezza",
    "asciutti": "asciutto",
    "ascolta": "ascoltare",
    "ascoltai": "ascoltare",
    "ascoltammo": "ascoltare",
    "ascoltan": "ascoltare",
    "ascoltando": "ascoltare",
    "ascoltano": "ascoltare",
    "ascoltante": "ascoltare",
    "ascoltanti": "ascoltare",
    "ascoltar": "ascoltare",
    "ascoltaron": "ascoltare",
    "ascoltarono": "ascoltare",
    "ascoltasse": "ascoltare",
    "ascoltasser": "ascoltare",
    "ascoltassero": "ascoltare",
    "ascoltassi": "ascoltare",
    "ascoltassimo": "ascoltare",
    "ascoltaste": "ascoltare",
    "ascoltasti": "ascoltare",
    "ascoltata": "ascoltare",
    "ascoltate": "ascoltare",
    "ascoltati": "ascoltare",
    "ascoltato": "ascoltare",
    "ascoltatori": "ascoltatore",
    "ascoltava": "ascoltare",
    "ascoltavamo": "ascoltare",
    "ascoltavan": "ascoltare",
    "ascoltavano": "ascoltare",
    "ascoltavate": "ascoltare",
    "ascoltavi": "ascoltare",
    "ascoltavo": "ascoltare",
    "ascolterai": "ascoltare",
    "ascolteran": "ascoltare",
    "ascolteranno": "ascoltare",
    "ascolterebbe": "ascoltare",
    "ascolterebber": "ascoltare",
    "ascolterebbero": "ascoltare",
    "ascolterei": "ascoltare",
    "ascolteremmo": "ascoltare",
    "ascolteremo": "ascoltare",
    "ascoltereste": "ascoltare",
    "ascolteresti": "ascoltare",
    "ascolterete": "ascoltare",
    "ascolterà": "ascoltare",
    "ascolterò": "ascoltare",
    "ascolti": "ascolto",
    "ascoltiamo": "ascoltare",
    "ascoltiate": "ascoltare",
    "ascoltin": "ascoltare",
    "ascoltino": "ascoltare",
    "ascolto": "ascoltare",
    "ascoltò": "ascoltare",
    "asconda": "ascondere",
    "ascondan": "ascondere",
    "ascondano": "ascondere",
    "asconde": "ascondere",
    "ascondemmo": "ascondere",
    "ascondendo": "ascondere",
    "ascondente": "ascondere",
    "ascondenti": "ascondere",
    "asconder": "ascondere",
    "asconderai": "ascondere",
    "asconderan": "ascondere",
    "asconderanno": "ascondere",
    "asconderebbe": "ascondere",
    "asconderebber": "ascondere",
    "asconderebbero": "ascondere",
    "asconderei": "ascondere",
    "asconderemmo": "ascondere",
    "asconderemo": "ascondere",
    "ascondereste": "ascondere",
    "asconderesti": "ascondere",
    "asconderete": "ascondere",
    "asconderà": "ascondere",
    "asconderò": "ascondere",
    "ascondesse": "ascondere",
    "ascondesser": "ascondere",
    "ascondessero": "ascondere",
    "ascondessi": "ascondere",
    "ascondessimo": "ascondere",
    "ascondeste": "ascondere",
    "ascondesti": "ascondere",
    "ascondete": "ascondere",
    "ascondeva": "ascondere",
    "ascondevamo": "ascondere",
    "ascondevan": "ascondere",
    "ascondevano": "ascondere",
    "ascondevate": "ascondere",
    "ascondevi": "ascondere",
    "ascondevo": "ascondere",
    "ascondi": "ascondere",
    "ascondiamo": "ascondere",
    "ascondiate": "ascondere",
    "ascondo": "ascondere",
    "ascondon": "ascondere",
    "ascondono": "ascondere",
    "ascoser": "ascondere",
    "ascosero": "ascondere",
    "ascosi": "ascondere",
    "ascosta": "ascondere",
    "ascoste": "ascondere",
    "ascosti": "ascondere",
    "ascosto": "ascondere",
    "ascosè": "ascondere",
    "ascrisse": "ascrivere",
    "ascrisser": "ascrivere",
    "ascrissero": "ascrivere",
    "ascrissi": "ascrivere",
    "ascritta": "ascrivere",
    "ascritte": "ascrivere",
    "ascritti": "ascrivere",
    "ascritto": "ascrivere",
    "ascriva": "ascrivere",
    "ascrivan": "ascrivere",
    "ascrivano": "ascrivere",
    "ascrive": "ascrivere",
    "ascrivemmo": "ascrivere",
    "ascrivendo": "ascrivere",
    "ascrivente": "ascrivere",
    "ascriventi": "ascrivere",
    "ascriver": "ascrivere",
    "ascriverai": "ascrivere",
    "ascriveran": "ascrivere",
    "ascriveranno": "ascrivere",
    "ascriverebbe": "ascrivere",
    "ascriverebber": "ascrivere",
    "ascriverebbero": "ascrivere",
    "ascriverei": "ascrivere",
    "ascriveremmo": "ascrivere",
    "ascriveremo": "ascrivere",
    "ascrivereste": "ascrivere",
    "ascriveresti": "ascrivere",
    "ascriverete": "ascrivere",
    "ascriverà": "ascrivere",
    "ascriverò": "ascrivere",
    "ascrivesse": "ascrivere",
    "ascrivesser": "ascrivere",
    "ascrivessero": "ascrivere",
    "ascrivessi": "ascrivere",
    "ascrivessimo": "ascrivere",
    "ascriveste": "ascrivere",
    "ascrivesti": "ascrivere",
    "ascrivete": "ascrivere",
    "ascriveva": "ascrivere",
    "ascrivevamo": "ascrivere",
    "ascrivevan": "ascrivere",
    "ascrivevano": "ascrivere",
    "ascrivevate": "ascrivere",
    "ascrivevi": "ascrivere",
    "ascrivevo": "ascrivere",
    "ascrivi": "ascrivere",
    "ascriviamo": "ascrivere",
    "ascriviate": "ascrivere",
    "ascrivo": "ascrivere",
    "ascrivon": "ascrivere",
    "ascrivono": "ascrivere",
    "asessuata": "asessuato",
    "asessuate": "asessuato",
    "asessuati": "asessuato",
    "asettica": "asettico",
    "asettiche": "asettico",
    "asettici": "asettico",
    "asfalta": "asfaltare",
    "asfaltai": "asfaltare",
    "asfaltammo": "asfaltare",
    "asfaltan": "asfaltare",
    "asfaltando": "asfaltare",
    "asfaltano": "asfaltare",
    "asfaltante": "asfaltare",
    "asfaltanti": "asfaltare",
    "asfaltar": "asfaltare",
    "asfaltaron": "asfaltare",
    "asfaltarono": "asfaltare",
    "asfaltasse": "asfaltare",
    "asfaltasser": "asfaltare",
    "asfaltassero": "asfaltare",
    "asfaltassi": "asfaltare",
    "asfaltassimo": "asfaltare",
    "asfaltaste": "asfaltare",
    "asfaltasti": "asfaltare",
    "asfaltata": "asfaltare",
    "asfaltate": "asfaltare",
    "asfaltati": "asfaltare",
    "asfaltato": "asfaltare",
    "asfaltava": "asfaltare",
    "asfaltavamo": "asfaltare",
    "asfaltavan": "asfaltare",
    "asfaltavano": "asfaltare",
    "asfaltavate": "asfaltare",
    "asfaltavi": "asfaltare",
    "asfaltavo": "asfaltare",
    "asfalterai": "asfaltare",
    "asfalteran": "asfaltare",
    "asfalteranno": "asfaltare",
    "asfalterebbe": "asfaltare",
    "asfalterebber": "asfaltare",
    "asfalterebbero": "asfaltare",
    "asfalterei": "asfaltare",
    "asfalteremmo": "asfaltare",
    "asfalteremo": "asfaltare",
    "asfaltereste": "asfaltare",
    "asfalteresti": "asfaltare",
    "asfalterete": "asfaltare",
    "asfalterà": "asfaltare",
    "asfalterò": "asfaltare",
    "asfalti": "asfalto",
    "asfaltiamo": "asfaltare",
    "asfaltiate": "asfaltare",
    "asfaltin": "asfaltare",
    "asfaltino": "asfaltare",
    "asfalto": "asfaltare",
    "asfaltò": "asfaltare",
    "asfissi": "asfissiare",
    "asfissia": "asfissiare",
    "asfissiai": "asfissiare",
    "asfissiammo": "asfissiare",
    "asfissiamo": "asfissiare",
    "asfissian": "asfissiare",
    "asfissiando": "asfissiare",
    "asfissiano": "asfissiare",
    "asfissiante": "asfissiare",
    "asfissianti": "asfissiare",
    "asfissiar": "asfissiare",
    "asfissiaron": "asfissiare",
    "asfissiarono": "asfissiare",
    "asfissiasse": "asfissiare",
    "asfissiasser": "asfissiare",
    "asfissiassero": "asfissiare",
    "asfissiassi": "asfissiare",
    "asfissiassimo": "asfissiare",
    "asfissiaste": "asfissiare",
    "asfissiasti": "asfissiare",
    "asfissiata": "asfissiare",
    "asfissiate": "asfissiare",
    "asfissiati": "asfissiare",
    "asfissiato": "asfissiare",
    "asfissiava": "asfissiare",
    "asfissiavamo": "asfissiare",
    "asfissiavan": "asfissiare",
    "asfissiavano": "asfissiare",
    "asfissiavate": "asfissiare",
    "asfissiavi": "asfissiare",
    "asfissiavo": "asfissiare",
    "asfissie": "asfissia",
    "asfissierai": "asfissiare",
    "asfissieran": "asfissiare",
    "asfissieranno": "asfissiare",
    "asfissierebbe": "asfissiare",
    "asfissierebber": "asfissiare",
    "asfissierebbero": "asfissiare",
    "asfissierei": "asfissiare",
    "asfissieremmo": "asfissiare",
    "asfissieremo": "asfissiare",
    "asfissiereste": "asfissiare",
    "asfissieresti": "asfissiare",
    "asfissierete": "asfissiare",
    "asfissierà": "asfissiare",
    "asfissierò": "asfissiare",
    "asfissin": "asfissiare",
    "asfissino": "asfissiare",
    "asfissio": "asfissiare",
    "asfissiò": "asfissiare",
    "asfittica": "asfittico",
    "asfittiche": "asfittico",
    "asfittici": "asfittico",
    "asiatica": "asiatico",
    "asiatiche": "asiatico",
    "asiatici": "asiatico",
    "asili": "asilo",
    "asimmetrica": "asimmetrico",
    "asimmetriche": "asimmetrico",
    "asimmetrici": "asimmetrico",
    "asimmetrie": "asimmetria",
    "asinelli": "asinello",
    "asini": "asino",
    "asinina": "asinino",
    "asinine": "asinino",
    "asinini": "asinino",
    "asmatica": "asmatico",
    "asmatiche": "asmatico",
    "asmatici": "asmatico",
    "asociali": "asociale",
    "asole": "asola",
    "asparagi": "asparago",
    "asperga": "aspergere",
    "aspergan": "aspergere",
    "aspergano": "aspergere",
    "asperge": "aspergere",
    "aspergemmo": "aspergere",
    "aspergendo": "aspergere",
    "aspergente": "aspergere",
    "aspergenti": "aspergere",
    "asperger": "aspergere",
    "aspergerai": "aspergere",
    "aspergeran": "aspergere",
    "aspergeranno": "aspergere",
    "aspergerebbe": "aspergere",
    "aspergerebber": "aspergere",
    "aspergerebbero": "aspergere",
    "aspergerei": "aspergere",
    "aspergeremmo": "aspergere",
    "aspergeremo": "aspergere",
    "aspergereste": "aspergere",
    "aspergeresti": "aspergere",
    "aspergerete": "aspergere",
    "aspergerà": "aspergere",
    "aspergerò": "aspergere",
    "aspergesse": "aspergere",
    "aspergesser": "aspergere",
    "aspergessero": "aspergere",
    "aspergessi": "aspergere",
    "aspergessimo": "aspergere",
    "aspergeste": "aspergere",
    "aspergesti": "aspergere",
    "aspergete": "aspergere",
    "aspergeva": "aspergere",
    "aspergevamo": "aspergere",
    "aspergevan": "aspergere",
    "aspergevano": "aspergere",
    "aspergevate": "aspergere",
    "aspergevi": "aspergere",
    "aspergevo": "aspergere",
    "aspergi": "aspergere",
    "aspergiamo": "aspergere",
    "aspergiate": "aspergere",
    "aspergo": "aspergere",
    "aspergon": "aspergere",
    "aspergono": "aspergere",
    "asperrima": "asperrimo",
    "asperrime": "asperrimo",
    "asperrimi": "asperrimo",
    "asperser": "aspergere",
    "aspersero": "aspergere",
    "aspersi": "aspergere",
    "aspersè": "aspergere",
    "asperta": "aspergere",
    "asperte": "aspergere",
    "asperti": "aspergere",
    "asperto": "aspergere",
    "aspetta": "aspettare",
    "aspettai": "aspettare",
    "aspettammo": "aspettare",
    "aspettan": "aspettare",
    "aspettando": "aspettare",
    "aspettano": "aspettare",
    "aspettante": "aspettare",
    "aspettanti": "aspettare",
    "aspettar": "aspettare",
    "aspettaron": "aspettare",
    "aspettarono": "aspettare",
    "aspettasse": "aspettare",
    "aspettasser": "aspettare",
    "aspettassero": "aspettare",
    "aspettassi": "aspettare",
    "aspettassimo": "aspettare",
    "aspettaste": "aspettare",
    "aspettasti": "aspettare",
    "aspettata": "aspettare",
    "aspettate": "aspettare",
    "aspettati": "aspettare",
    "aspettative": "aspettativa",
    "aspettato": "aspettare",
    "aspettava": "aspettare",
    "aspettavamo": "aspettare",
    "aspettavan": "aspettare",
    "aspettavano": "aspettare",
    "aspettavate": "aspettare",
    "aspettavi": "aspettare",
    "aspettavo": "aspettare",
    "aspetterai": "aspettare",
    "aspetteran": "aspettare",
    "aspetteranno": "aspettare",
    "aspetterebbe": "aspettare",
    "aspetterebber": "aspettare",
    "aspetterebbero": "aspettare",
    "aspetterei": "aspettare",
    "aspetteremmo": "aspettare",
    "aspetteremo": "aspettare",
    "aspettereste": "aspettare",
    "aspetteresti": "aspettare",
    "aspetterete": "aspettare",
    "aspetterà": "aspettare",
    "aspetterò": "aspettare",
    "aspetti": "aspetto",
    "aspettiamo": "aspettare",
    "aspettiate": "aspettare",
    "aspettin": "aspettare",
    "aspettino": "aspettare",
    "aspetto": "aspettare",
    "aspettò": "aspettare",
    "aspira": "aspirare",
    "aspirai": "aspirare",
    "aspirammo": "aspirare",
    "aspiran": "aspirare",
    "aspirando": "aspirare",
    "aspirano": "aspirare",
    "aspirante": "aspirare",
    "aspiranti": "aspirare",
    "aspirar": "aspirare",
    "aspiraron": "aspirare",
    "aspirarono": "aspirare",
    "aspirasse": "aspirare",
    "aspirasser": "aspirare",
    "aspirassero": "aspirare",
    "aspirassi": "aspirare",
    "aspirassimo": "aspirare",
    "aspiraste": "aspirare",
    "aspirasti": "aspirare",
    "aspirata": "aspirare",
    "aspirate": "aspirare",
    "aspirati": "aspirare",
    "aspirato": "aspirare",
    "aspirava": "aspirare",
    "aspiravamo": "aspirare",
    "aspiravan": "aspirare",
    "aspiravano": "aspirare",
    "aspiravate": "aspirare",
    "aspiravi": "aspirare",
    "aspiravo": "aspirare",
    "aspirazioni": "aspirazione",
    "aspirerai": "aspirare",
    "aspireran": "aspirare",
    "aspireranno": "aspirare",
    "aspirerebbe": "aspirare",
    "aspirerebber": "aspirare",
    "aspirerebbero": "aspirare",
    "aspirerei": "aspirare",
    "aspireremmo": "aspirare",
    "aspireremo": "aspirare",
    "aspirereste": "aspirare",
    "aspireresti": "aspirare",
    "aspirerete": "aspirare",
    "aspirerà": "aspirare",
    "aspirerò": "aspirare",
    "aspiri": "aspirare",
    "aspiriamo": "aspirare",
    "aspiriate": "aspirare",
    "aspirin": "aspirare",
    "aspirine": "aspirina",
    "aspirino": "aspirare",
    "aspiro": "aspirare",
    "aspirò": "aspirare",
    "asporta": "asportare",
    "asportai": "asportare",
    "asportammo": "asportare",
    "asportan": "asportare",
    "asportando": "asportare",
    "asportano": "asportare",
    "asportante": "asportare",
    "asportanti": "asportare",
    "asportar": "asportare",
    "asportaron": "asportare",
    "asportarono": "asportare",
    "asportasse": "asportare",
    "asportasser": "asportare",
    "asportassero": "asportare",
    "asportassi": "asportare",
    "asportassimo": "asportare",
    "asportaste": "asportare",
    "asportasti": "asportare",
    "asportata": "asportare",
    "asportate": "asportare",
    "asportati": "asportare",
    "asportato": "asportare",
    "asportava": "asportare",
    "asportavamo": "asportare",
    "asportavan": "asportare",
    "asportavano": "asportare",
    "asportavate": "asportare",
    "asportavi": "asportare",
    "asportavo": "asportare",
    "asportazioni": "asportazione",
    "asporterai": "asportare",
    "asporteran": "asportare",
    "asporteranno": "asportare",
    "asporterebbe": "asportare",
    "asporterebber": "asportare",
    "asporterebbero": "asportare",
    "asporterei": "asportare",
    "asporteremmo": "asportare",
    "asporteremo": "asportare",
    "asportereste": "asportare",
    "asporteresti": "asportare",
    "asporterete": "asportare",
    "asporterà": "asportare",
    "asporterò": "asportare",
    "asporti": "asportare",
    "asportiamo": "asportare",
    "asportiate": "asportare",
    "asportin": "asportare",
    "asportino": "asportare",
    "asporto": "asportare",
    "asportò": "asportare",
    "aspra": "aspro",
    "aspre": "aspro",
    "asprezze": "asprezza",
    "aspri": "aspro",
    "asprigna": "asprigno",
    "asprigne": "asprigno",
    "asprigni": "asprigno",
    "assaggerai": "assaggiare",
    "assaggeran": "assaggiare",
    "assaggeranno": "assaggiare",
    "assaggerebbe": "assaggiare",
    "assaggerebber": "assaggiare",
    "assaggerebbero": "assaggiare",
    "assaggerei": "assaggiare",
    "assaggeremmo": "assaggiare",
    "assaggeremo": "assaggiare",
    "assaggereste": "assaggiare",
    "assaggeresti": "assaggiare",
    "assaggerete": "assaggiare",
    "assaggerà": "assaggiare",
    "assaggerò": "assaggiare",
    "assaggi": "assaggio",
    "assaggia": "assaggiare",
    "assaggiai": "assaggiare",
    "assaggiammo": "assaggiare",
    "assaggiamo": "assaggiare",
    "assaggian": "assaggiare",
    "assaggiando": "assaggiare",
    "assaggiano": "assaggiare",
    "assaggiante": "assaggiare",
    "assaggianti": "assaggiare",
    "assaggiar": "assaggiare",
    "assaggiaron": "assaggiare",
    "assaggiarono": "assaggiare",
    "assaggiasse": "assaggiare",
    "assaggiasser": "assaggiare",
    "assaggiassero": "assaggiare",
    "assaggiassi": "assaggiare",
    "assaggiassimo": "assaggiare",
    "assaggiaste": "assaggiare",
    "assaggiasti": "assaggiare",
    "assaggiata": "assaggiare",
    "assaggiate": "assaggiare",
    "assaggiati": "assaggiare",
    "assaggiato": "assaggiare",
    "assaggiava": "assaggiare",
    "assaggiavamo": "assaggiare",
    "assaggiavan": "assaggiare",
    "assaggiavano": "assaggiare",
    "assaggiavate": "assaggiare",
    "assaggiavi": "assaggiare",
    "assaggiavo": "assaggiare",
    "assaggin": "assaggiare",
    "assaggino": "assaggiare",
    "assaggio": "assaggiare",
    "assaggiò": "assaggiare",
    "assala": "assalire",
    "assalan": "assalire",
    "assalano": "assalire",
    "assale": "assalire",
    "assalendo": "assalire",
    "assalente": "assalire",
    "assalenti": "assalire",
    "assali": "assalire",
    "assaliamo": "assalire",
    "assaliate": "assalire",
    "assalii": "assalire",
    "assalimmo": "assalire",
    "assalir": "assalire",
    "assalirai": "assalire",
    "assaliran": "assalire",
    "assaliranno": "assalire",
    "assalirebbe": "assalire",
    "assalirebber": "assalire",
    "assalirebbero": "assalire",
    "assalirei": "assalire",
    "assaliremmo": "assalire",
    "assaliremo": "assalire",
    "assalireste": "assalire",
    "assaliresti": "assalire",
    "assalirete": "assalire",
    "assaliron": "assalire",
    "assalirono": "assalire",
    "assalirà": "assalire",
    "assalirò": "assalire",
    "assalisse": "assalire",
    "assalisser": "assalire",
    "assalissero": "assalire",
    "assalissi": "assalire",
    "assalissimo": "assalire",
    "assaliste": "assalire",
    "assalisti": "assalire",
    "assalita": "assalire",
    "assalite": "assalire",
    "assaliti": "assalire",
    "assalito": "assalire",
    "assalitori": "assalitore",
    "assaliva": "assalire",
    "assalivamo": "assalire",
    "assalivan": "assalire",
    "assalivano": "assalire",
    "assalivate": "assalire",
    "assalivi": "assalire",
    "assalivo": "assalire",
    "assalo": "assalire",
    "assalon": "assalire",
    "assalono": "assalire",
    "assalta": "assaltare",
    "assaltai": "assaltare",
    "assaltammo": "assaltare",
    "assaltan": "assaltare",
    "assaltando": "assaltare",
    "assaltano": "assaltare",
    "assaltante": "assaltare",
    "assaltanti": "assaltare",
    "assaltar": "assaltare",
    "assaltaron": "assaltare",
    "assaltarono": "assaltare",
    "assaltasse": "assaltare",
    "assaltasser": "assaltare",
    "assaltassero": "assaltare",
    "assaltassi": "assaltare",
    "assaltassimo": "assaltare",
    "assaltaste": "assaltare",
    "assaltasti": "assaltare",
    "assaltata": "assaltare",
    "assaltate": "assaltare",
    "assaltati": "assaltare",
    "assaltato": "assaltare",
    "assaltatori": "assaltatore",
    "assaltava": "assaltare",
    "assaltavamo": "assaltare",
    "assaltavan": "assaltare",
    "assaltavano": "assaltare",
    "assaltavate": "assaltare",
    "assaltavi": "assaltare",
    "assaltavo": "assaltare",
    "assalterai": "assaltare",
    "assalteran": "assaltare",
    "assalteranno": "assaltare",
    "assalterebbe": "assaltare",
    "assalterebber": "assaltare",
    "assalterebbero": "assaltare",
    "assalterei": "assaltare",
    "assalteremmo": "assaltare",
    "assalteremo": "assaltare",
    "assaltereste": "assaltare",
    "assalteresti": "assaltare",
    "assalterete": "assaltare",
    "assalterà": "assaltare",
    "assalterò": "assaltare",
    "assalti": "assalto",
    "assaltiamo": "assaltare",
    "assaltiate": "assaltare",
    "assaltin": "assaltare",
    "assaltino": "assaltare",
    "assalto": "assaltare",
    "assaltò": "assaltare",
    "assalì": "assalire",
    "assapora": "assaporare",
    "assaporai": "assaporare",
    "assaporammo": "assaporare",
    "assaporan": "assaporare",
    "assaporando": "assaporare",
    "assaporano": "assaporare",
    "assaporante": "assaporare",
    "assaporanti": "assaporare",
    "assaporar": "assaporare",
    "assaporaron": "assaporare",
    "assaporarono": "assaporare",
    "assaporasse": "assaporare",
    "assaporasser": "assaporare",
    "assaporassero": "assaporare",
    "assaporassi": "assaporare",
    "assaporassimo": "assaporare",
    "assaporaste": "assaporare",
    "assaporasti": "assaporare",
    "assaporata": "assaporare",
    "assaporate": "assaporare",
    "assaporati": "assaporare",
    "assaporato": "assaporare",
    "assaporava": "assaporare",
    "assaporavamo": "assaporare",
    "assaporavan": "assaporare",
    "assaporavano": "assaporare",
    "assaporavate": "assaporare",
    "assaporavi": "assaporare",
    "assaporavo": "assaporare",
    "assaporerai": "assaporare",
    "assaporeran": "assaporare",
    "assaporeranno": "assaporare",
    "assaporerebbe": "assaporare",
    "assaporerebber": "assaporare",
    "assaporerebbero": "assaporare",
    "assaporerei": "assaporare",
    "assaporeremmo": "assaporare",
    "assaporeremo": "assaporare",
    "assaporereste": "assaporare",
    "assaporeresti": "assaporare",
    "assaporerete": "assaporare",
    "assaporerà": "assaporare",
    "assaporerò": "assaporare",
    "assapori": "assaporare",
    "assaporiamo": "assaporare",
    "assaporiate": "assaporare",
    "assaporin": "assaporare",
    "assaporino": "assaporare",
    "assaporo": "assaporare",
    "assaporò": "assaporare",
    "assassina": "assassino",
    "assassinai": "assassinare",
    "assassinammo": "assassinare",
    "assassinan": "assassinare",
    "assassinando": "assassinare",
    "assassinano": "assassinare",
    "assassinante": "assassinare",
    "assassinanti": "assassinare",
    "assassinar": "assassinare",
    "assassinaron": "assassinare",
    "assassinarono": "assassinare",
    "assassinasse": "assassinare",
    "assassinasser": "assassinare",
    "assassinassero": "assassinare",
    "assassinassi": "assassinare",
    "assassinassimo": "assassinare",
    "assassinaste": "assassinare",
    "assassinasti": "assassinare",
    "assassinata": "assassinare",
    "assassinate": "assassinare",
    "assassinati": "assassinare",
    "assassinato": "assassinare",
    "assassinava": "assassinare",
    "assassinavamo": "assassinare",
    "assassinavan": "assassinare",
    "assassinavano": "assassinare",
    "assassinavate": "assassinare",
    "assassinavi": "assassinare",
    "assassinavo": "assassinare",
    "assassine": "assassino",
    "assassinerai": "assassinare",
    "assassineran": "assassinare",
    "assassineranno": "assassinare",
    "assassinerebbe": "assassinare",
    "assassinerebber": "assassinare",
    "assassinerebbero": "assassinare",
    "assassinerei": "assassinare",
    "assassineremmo": "assassinare",
    "assassineremo": "assassinare",
    "assassinereste": "assassinare",
    "assassineresti": "assassinare",
    "assassinerete": "assassinare",
    "assassinerà": "assassinare",
    "assassinerò": "assassinare",
    "assassini": "assassino",
    "assassiniamo": "assassinare",
    "assassiniate": "assassinare",
    "assassinii": "assassinio",
    "assassinin": "assassinare",
    "assassinino": "assassinare",
    "assassino": "assassinare",
    "assassinò": "assassinare",
    "assatanati": "assatanato",
    "asseconda": "assecondare",
    "assecondai": "assecondare",
    "assecondammo": "assecondare",
    "assecondan": "assecondare",
    "assecondando": "assecondare",
    "assecondano": "assecondare",
    "assecondante": "assecondare",
    "assecondanti": "assecondare",
    "assecondar": "assecondare",
    "assecondaron": "assecondare",
    "assecondarono": "assecondare",
    "assecondasse": "assecondare",
    "assecondasser": "assecondare",
    "assecondassero": "assecondare",
    "assecondassi": "assecondare",
    "assecondassimo": "assecondare",
    "assecondaste": "assecondare",
    "assecondasti": "assecondare",
    "assecondata": "assecondare",
    "assecondate": "assecondare",
    "assecondati": "assecondare",
    "assecondato": "assecondare",
    "assecondava": "assecondare",
    "assecondavamo": "assecondare",
    "assecondavan": "assecondare",
    "assecondavano": "assecondare",
    "assecondavate": "assecondare",
    "assecondavi": "assecondare",
    "assecondavo": "assecondare",
    "asseconderai": "assecondare",
    "asseconderan": "assecondare",
    "asseconderanno": "assecondare",
    "asseconderebbe": "assecondare",
    "asseconderebber": "assecondare",
    "asseconderebbero": "assecondare",
    "asseconderei": "assecondare",
    "asseconderemmo": "assecondare",
    "asseconderemo": "assecondare",
    "assecondereste": "assecondare",
    "asseconderesti": "assecondare",
    "asseconderete": "assecondare",
    "asseconderà": "assecondare",
    "asseconderò": "assecondare",
    "assecondi": "assecondare",
    "assecondiamo": "assecondare",
    "assecondiate": "assecondare",
    "assecondin": "assecondare",
    "assecondino": "assecondare",
    "assecondo": "assecondare",
    "assecondò": "assecondare",
    "assedi": "assedio",
    "assedia": "assediare",
    "assediai": "assediare",
    "assediammo": "assediare",
    "assediamo": "assediare",
    "assedian": "assediare",
    "assediando": "assediare",
    "assediano": "assediare",
    "assediante": "assediare",
    "assedianti": "assediare",
    "assediar": "assediare",
    "assediaron": "assediare",
    "assediarono": "assediare",
    "assediasse": "assediare",
    "assediasser": "assediare",
    "assediassero": "assediare",
    "assediassi": "assediare",
    "assediassimo": "assediare",
    "assediaste": "assediare",
    "assediasti": "assediare",
    "assediata": "assediato",
    "assediate": "assediato",
    "assediati": "assediato",
    "assediato": "assediare",
    "assediava": "assediare",
    "assediavamo": "assediare",
    "assediavan": "assediare",
    "assediavano": "assediare",
    "assediavate": "assediare",
    "assediavi": "assediare",
    "assediavo": "assediare",
    "assedierai": "assediare",
    "assedieran": "assediare",
    "assedieranno": "assediare",
    "assedierebbe": "assediare",
    "assedierebber": "assediare",
    "assedierebbero": "assediare",
    "assedierei": "assediare",
    "assedieremmo": "assediare",
    "assedieremo": "assediare",
    "assediereste": "assediare",
    "assedieresti": "assediare",
    "assedierete": "assediare",
    "assedierà": "assediare",
    "assedierò": "assediare",
    "assedin": "assediare",
    "assedino": "assediare",
    "assedio": "assediare",
    "assediò": "assediare",
    "assegna": "assegnare",
    "assegnai": "assegnare",
    "assegnammo": "assegnare",
    "assegnan": "assegnare",
    "assegnando": "assegnare",
    "assegnano": "assegnare",
    "assegnante": "assegnare",
    "assegnanti": "assegnare",
    "assegnar": "assegnare",
    "assegnaron": "assegnare",
    "assegnarono": "assegnare",
    "assegnasse": "assegnare",
    "assegnasser": "assegnare",
    "assegnassero": "assegnare",
    "assegnassi": "assegnare",
    "assegnassimo": "assegnare",
    "assegnaste": "assegnare",
    "assegnasti": "assegnare",
    "assegnata": "assegnato",
    "assegnatari": "assegnatario",
    "assegnate": "assegnato",
    "assegnati": "assegnato",
    "assegnato": "assegnare",
    "assegnava": "assegnare",
    "assegnavamo": "assegnare",
    "assegnavan": "assegnare",
    "assegnavano": "assegnare",
    "assegnavate": "assegnare",
    "assegnavi": "assegnare",
    "assegnavo": "assegnare",
    "assegnazioni": "assegnazione",
    "assegnerai": "assegnare",
    "assegneran": "assegnare",
    "assegneranno": "assegnare",
    "assegnerebbe": "assegnare",
    "assegnerebber": "assegnare",
    "assegnerebbero": "assegnare",
    "assegnerei": "assegnare",
    "assegneremmo": "assegnare",
    "assegneremo": "assegnare",
    "assegnereste": "assegnare",
    "assegneresti": "assegnare",
    "assegnerete": "assegnare",
    "assegnerà": "assegnare",
    "assegnerò": "assegnare",
    "assegni": "assegno",
    "assegniamo": "assegnare",
    "assegniate": "assegnare",
    "assegnin": "assegnare",
    "assegnino": "assegnare",
    "assegno": "assegnare",
    "assegnò": "assegnare",
    "assembla": "assemblare",
    "assemblabili": "assemblabile",
    "assemblaggi": "assemblaggio",
    "assemblai": "assemblare",
    "assemblammo": "assemblare",
    "assemblan": "assemblare",
    "assemblando": "assemblare",
    "assemblano": "assemblare",
    "assemblante": "assemblare",
    "assemblanti": "assemblare",
    "assemblar": "assemblare",
    "assemblaron": "assemblare",
    "assemblarono": "assemblare",
    "assemblasse": "assemblare",
    "assemblasser": "assemblare",
    "assemblassero": "assemblare",
    "assemblassi": "assemblare",
    "assemblassimo": "assemblare",
    "assemblaste": "assemblare",
    "assemblasti": "assemblare",
    "assemblata": "assemblare",
    "assemblate": "assemblare",
    "assemblati": "assemblare",
    "assemblato": "assemblare",
    "assemblava": "assemblare",
    "assemblavamo": "assemblare",
    "assemblavan": "assemblare",
    "assemblavano": "assemblare",
    "assemblavate": "assemblare",
    "assemblavi": "assemblare",
    "assemblavo": "assemblare",
    "assemblee": "assemblea",
    "assemblerai": "assemblare",
    "assembleran": "assemblare",
    "assembleranno": "assemblare",
    "assemblerebbe": "assemblare",
    "assemblerebber": "assemblare",
    "assemblerebbero": "assemblare",
    "assemblerei": "assemblare",
    "assembleremmo": "assemblare",
    "assembleremo": "assemblare",
    "assemblereste": "assemblare",
    "assembleresti": "assemblare",
    "assemblerete": "assemblare",
    "assemblerà": "assemblare",
    "assemblerò": "assemblare",
    "assembli": "assemblare",
    "assembliamo": "assemblare",
    "assembliate": "assemblare",
    "assemblin": "assemblare",
    "assemblino": "assemblare",
    "assemblo": "assemblare",
    "assemblò": "assemblare",
    "assembra": "assembrare",
    "assembrai": "assembrare",
    "assembramenti": "assembramento",
    "assembrammo": "assembrare",
    "assembran": "assembrare",
    "assembrando": "assembrare",
    "assembrano": "assembrare",
    "assembrante": "assembrare",
    "assembranti": "assembrare",
    "assembrar": "assembrare",
    "assembraron": "assembrare",
    "assembrarono": "assembrare",
    "assembrasse": "assembrare",
    "assembrasser": "assembrare",
    "assembrassero": "assembrare",
    "assembrassi": "assembrare",
    "assembrassimo": "assembrare",
    "assembraste": "assembrare",
    "assembrasti": "assembrare",
    "assembrata": "assembrare",
    "assembrate": "assembrare",
    "assembrati": "assembrare",
    "assembrato": "assembrare",
    "assembrava": "assembrare",
    "assembravamo": "assembrare",
    "assembravan": "assembrare",
    "assembravano": "assembrare",
    "assembravate": "assembrare",
    "assembravi": "assembrare",
    "assembravo": "assembrare",
    "assembrerai": "assembrare",
    "assembreran": "assembrare",
    "assembreranno": "assembrare",
    "assembrerebbe": "assembrare",
    "assembrerebber": "assembrare",
    "assembrerebbero": "assembrare",
    "assembrerei": "assembrare",
    "assembreremmo": "assembrare",
    "assembreremo": "assembrare",
    "assembrereste": "assembrare",
    "assembreresti": "assembrare",
    "assembrerete": "assembrare",
    "assembrerà": "assembrare",
    "assembrerò": "assembrare",
    "assembri": "assembrare",
    "assembriamo": "assembrare",
    "assembriate": "assembrare",
    "assembrin": "assembrare",
    "assembrino": "assembrare",
    "assembro": "assembrare",
    "assembrò": "assembrare",
    "assennata": "assennato",
    "assennate": "assennato",
    "assennati": "assennato",
    "assensi": "assenso",
    "assenta": "assentire",
    "assentai": "assentare",
    "assentammo": "assentare",
    "assentan": "assentire",
    "assentando": "assentare",
    "assentano": "assentire",
    "assentar": "assentare",
    "assentaron": "assentare",
    "assentarono": "assentare",
    "assentasse": "assentare",
    "assentasser": "assentare",
    "assentassero": "assentare",
    "assentassi": "assentare",
    "assentassimo": "assentare",
    "assentaste": "assentare",
    "assentasti": "assentare",
    "assentata": "assentare",
    "assentate": "assentare",
    "assentati": "assentare",
    "assentato": "assentare",
    "assentava": "assentare",
    "assentavamo": "assentare",
    "assentavan": "assentare",
    "assentavano": "assentare",
    "assentavate": "assentare",
    "assentavi": "assentare",
    "assentavo": "assentare",
    "assente": "assentire",
    "assenteismi": "assenteismo",
    "assenteiste": "assenteista",
    "assenteisti": "assenteista",
    "assentendo": "assentire",
    "assentente": "assentire",
    "assententi": "assentire",
    "assenterai": "assentare",
    "assenteran": "assentare",
    "assenteranno": "assentare",
    "assenterebbe": "assentare",
    "assenterebber": "assentare",
    "assenterebbero": "assentare",
    "assenterei": "assentare",
    "assenteremmo": "assentare",
    "assenteremo": "assentare",
    "assentereste": "assentare",
    "assenteresti": "assentare",
    "assenterete": "assentare",
    "assenterà": "assentare",
    "assenterò": "assentare",
    "assenti": "assentire",
    "assentiamo": "assentire",
    "assentiate": "assentire",
    "assentii": "assentire",
    "assentimmo": "assentire",
    "assentin": "assentare",
    "assentino": "assentare",
    "assentir": "assentire",
    "assentirai": "assentire",
    "assentiran": "assentire",
    "assentiranno": "assentire",
    "assentirebbe": "assentire",
    "assentirebber": "assentire",
    "assentirebbero": "assentire",
    "assentirei": "assentire",
    "assentiremmo": "assentire",
    "assentiremo": "assentire",
    "assentireste": "assentire",
    "assentiresti": "assentire",
    "assentirete": "assentire",
    "assentiron": "assentire",
    "assentirono": "assentire",
    "assentirà": "assentire",
    "assentirò": "assentire",
    "assentisse": "assentire",
    "assentisser": "assentire",
    "assentissero": "assentire",
    "assentissi": "assentire",
    "assentissimo": "assentire",
    "assentiste": "assentire",
    "assentisti": "assentire",
    "assentita": "assentire",
    "assentite": "assentire",
    "assentiti": "assentire",
    "assentito": "assentire",
    "assentiva": "assentire",
    "assentivamo": "assentire",
    "assentivan": "assentire",
    "assentivano": "assentire",
    "assentivate": "assentire",
    "assentivi": "assentire",
    "assentivo": "assentire",
    "assento": "assentire",
    "assenton": "assentire",
    "assentono": "assentire",
    "assentì": "assentire",
    "assentò": "assentare",
    "assenze": "assenza",
    "asserendo": "asserire",
    "asserente": "asserire",
    "asserenti": "asserire",
    "asseriamo": "asserire",
    "asseriate": "asserire",
    "asserii": "asserire",
    "asserimmo": "asserire",
    "asserir": "asserire",
    "asserirai": "asserire",
    "asseriran": "asserire",
    "asseriranno": "asserire",
    "asserirebbe": "asserire",
    "asserirebber": "asserire",
    "asserirebbero": "asserire",
    "asserirei": "asserire",
    "asseriremmo": "asserire",
    "asseriremo": "asserire",
    "asserireste": "asserire",
    "asseriresti": "asserire",
    "asserirete": "asserire",
    "asseriron": "asserire",
    "asserirono": "asserire",
    "asserirà": "asserire",
    "asserirò": "asserire",
    "asserisca": "asserire",
    "asseriscan": "asserire",
    "asseriscano": "asserire",
    "asserisce": "asserire",
    "asserisci": "asserire",
    "asserisco": "asserire",
    "asseriscon": "asserire",
    "asseriscono": "asserire",
    "asserisse": "asserire",
    "asserisser": "asserire",
    "asserissero": "asserire",
    "asserissi": "asserire",
    "asserissimo": "asserire",
    "asseriste": "asserire",
    "asseristi": "asserire",
    "asserita": "asserire",
    "asserite": "asserire",
    "asseriti": "asserire",
    "asserito": "asserire",
    "asseriva": "asserire",
    "asserivamo": "asserire",
    "asserivan": "asserire",
    "asserivano": "asserire",
    "asserivate": "asserire",
    "asserivi": "asserire",
    "asserivo": "asserire",
    "asserragli": "asserragliare",
    "asserraglia": "asserragliare",
    "asserragliai": "asserragliare",
    "asserragliammo": "asserragliare",
    "asserragliamo": "asserragliare",
    "asserraglian": "asserragliare",
    "asserragliando": "asserragliare",
    "asserragliano": "asserragliare",
    "asserragliante": "asserragliare",
    "asserraglianti": "asserragliare",
    "asserragliar": "asserragliare",
    "asserragliaron": "asserragliare",
    "asserragliarono": "asserragliare",
    "asserragliasse": "asserragliare",
    "asserragliasser": "asserragliare",
    "asserragliassero": "asserragliare",
    "asserragliassi": "asserragliare",
    "asserragliassimo": "asserragliare",
    "asserragliaste": "asserragliare",
    "asserragliasti": "asserragliare",
    "asserragliata": "asserragliare",
    "asserragliate": "asserragliare",
    "asserragliati": "asserragliare",
    "asserragliato": "asserragliare",
    "asserragliava": "asserragliare",
    "asserragliavamo": "asserragliare",
    "asserragliavan": "asserragliare",
    "asserragliavano": "asserragliare",
    "asserragliavate": "asserragliare",
    "asserragliavi": "asserragliare",
    "asserragliavo": "asserragliare",
    "asserraglierai": "asserragliare",
    "asserraglieran": "asserragliare",
    "asserraglieranno": "asserragliare",
    "asserraglierebbe": "asserragliare",
    "asserraglierebber": "asserragliare",
    "asserraglierebbero": "asserragliare",
    "asserraglierei": "asserragliare",
    "asserraglieremmo": "asserragliare",
    "asserraglieremo": "asserragliare",
    "asserragliereste": "asserragliare",
    "asserraglieresti": "asserragliare",
    "asserraglierete": "asserragliare",
    "asserraglierà": "asserragliare",
    "asserraglierò": "asserragliare",
    "asserraglin": "asserragliare",
    "asserraglino": "asserragliare",
    "asserraglio": "asserragliare",
    "asserragliò": "asserragliare",
    "asserti": "asserto",
    "assertiva": "assertivo",
    "assertive": "assertivo",
    "assertivi": "assertivo",
    "assertori": "assertore",
    "asserva": "asservire",
    "asservan": "asservire",
    "asservano": "asservire",
    "asserve": "asservire",
    "asservendo": "asservire",
    "asservente": "asservire",
    "asserventi": "asservire",
    "asservi": "asservire",
    "asserviamo": "asservire",
    "asserviate": "asservire",
    "asservii": "asservire",
    "asservimmo": "asservire",
    "asservir": "asservire",
    "asservirai": "asservire",
    "asserviran": "asservire",
    "asserviranno": "asservire",
    "asservirebbe": "asservire",
    "asservirebber": "asservire",
    "asservirebbero": "asservire",
    "asservirei": "asservire",
    "asserviremmo": "asservire",
    "asserviremo": "asservire",
    "asservireste": "asservire",
    "asserviresti": "asservire",
    "asservirete": "asservire",
    "asserviron": "asservire",
    "asservirono": "asservire",
    "asservirà": "asservire",
    "asservirò": "asservire",
    "asservisse": "asservire",
    "asservisser": "asservire",
    "asservissero": "asservire",
    "asservissi": "asservire",
    "asservissimo": "asservire",
    "asserviste": "asservire",
    "asservisti": "asservire",
    "asservita": "asservire",
    "asservite": "asservire",
    "asserviti": "asservire",
    "asservito": "asservire",
    "asserviva": "asservire",
    "asservivamo": "asservire",
    "asservivan": "asservire",
    "asservivano": "asservire",
    "asservivate": "asservire",
    "asservivi": "asservire",
    "asservivo": "asservire",
    "asservo": "asservire",
    "asservon": "asservire",
    "asservono": "asservire",
    "asservì": "asservire",
    "asserzioni": "asserzione",
    "asserì": "asserire",
    "assessorati": "assessorato",
    "assessori": "assessore",
    "assesta": "assestare",
    "assestai": "assestare",
    "assestamenti": "assestamento",
    "assestammo": "assestare",
    "assestan": "assestare",
    "assestando": "assestare",
    "assestano": "assestare",
    "assestante": "assestare",
    "assestanti": "assestare",
    "assestar": "assestare",
    "assestaron": "assestare",
    "assestarono": "assestare",
    "assestasse": "assestare",
    "assestasser": "assestare",
    "assestassero": "assestare",
    "assestassi": "assestare",
    "assestassimo": "assestare",
    "assestaste": "assestare",
    "assestasti": "assestare",
    "assestata": "assestato",
    "assestate": "assestato",
    "assestati": "assestato",
    "assestato": "assestare",
    "assestava": "assestare",
    "assestavamo": "assestare",
    "assestavan": "assestare",
    "assestavano": "assestare",
    "assestavate": "assestare",
    "assestavi": "assestare",
    "assestavo": "assestare",
    "assesterai": "assestare",
    "assesteran": "assestare",
    "assesteranno": "assestare",
    "assesterebbe": "assestare",
    "assesterebber": "assestare",
    "assesterebbero": "assestare",
    "assesterei": "assestare",
    "assesteremmo": "assestare",
    "assesteremo": "assestare",
    "assestereste": "assestare",
    "assesteresti": "assestare",
    "assesterete": "assestare",
    "assesterà": "assestare",
    "assesterò": "assestare",
    "assesti": "assestare",
    "assestiamo": "assestare",
    "assestiate": "assestare",
    "assestin": "assestare",
    "assestino": "assestare",
    "assesto": "assestare",
    "assestò": "assestare",
    "asseta": "assetare",
    "assetai": "assetare",
    "assetammo": "assetare",
    "assetan": "assetare",
    "assetando": "assetare",
    "assetano": "assetare",
    "assetante": "assetare",
    "assetanti": "assetare",
    "assetar": "assetare",
    "assetaron": "assetare",
    "assetarono": "assetare",
    "assetasse": "assetare",
    "assetasser": "assetare",
    "assetassero": "assetare",
    "assetassi": "assetare",
    "assetassimo": "assetare",
    "assetaste": "assetare",
    "assetasti": "assetare",
    "assetata": "assetato",
    "assetate": "assetato",
    "assetati": "assetato",
    "assetato": "assetare",
    "assetava": "assetare",
    "assetavamo": "assetare",
    "assetavan": "assetare",
    "assetavano": "assetare",
    "assetavate": "assetare",
    "assetavi": "assetare",
    "assetavo": "assetare",
    "asseterai": "assetare",
    "asseteran": "assetare",
    "asseteranno": "assetare",
    "asseterebbe": "assetare",
    "asseterebber": "assetare",
    "asseterebbero": "assetare",
    "asseterei": "assetare",
    "asseteremmo": "assetare",
    "asseteremo": "assetare",
    "assetereste": "assetare",
    "asseteresti": "assetare",
    "asseterete": "assetare",
    "asseterà": "assetare",
    "asseterò": "assetare",
    "asseti": "assetare",
    "assetiamo": "assetare",
    "assetiate": "assetare",
    "assetin": "assetare",
    "assetino": "assetare",
    "asseto": "assetare",
    "assets": "asset",
    "assetta": "assettare",
    "assettai": "assettare",
    "assettammo": "assettare",
    "assettan": "assettare",
    "assettando": "assettare",
    "assettano": "assettare",
    "assettante": "assettare",
    "assettanti": "assettare",
    "assettar": "assettare",
    "assettaron": "assettare",
    "assettarono": "assettare",
    "assettasse": "assettare",
    "assettasser": "assettare",
    "assettassero": "assettare",
    "assettassi": "assettare",
    "assettassimo": "assettare",
    "assettaste": "assettare",
    "assettasti": "assettare",
    "assettata": "assettare",
    "assettate": "assettare",
    "assettati": "assettare",
    "assettato": "assettare",
    "assettava": "assettare",
    "assettavamo": "assettare",
    "assettavan": "assettare",
    "assettavano": "assettare",
    "assettavate": "assettare",
    "assettavi": "assettare",
    "assettavo": "assettare",
    "assetterai": "assettare",
    "assetteran": "assettare",
    "assetteranno": "assettare",
    "assetterebbe": "assettare",
    "assetterebber": "assettare",
    "assetterebbero": "assettare",
    "assetterei": "assettare",
    "assetteremmo": "assettare",
    "assetteremo": "assettare",
    "assettereste": "assettare",
    "assetteresti": "assettare",
    "assetterete": "assettare",
    "assetterà": "assettare",
    "assetterò": "assettare",
    "assetti": "assetto",
    "assettiamo": "assettare",
    "assettiate": "assettare",
    "assettin": "assettare",
    "assettino": "assettare",
    "assetto": "assettare",
    "assettò": "assettare",
    "assetò": "assetare",
    "assevera": "asseverare",
    "asseverai": "asseverare",
    "asseverammo": "asseverare",
    "asseveran": "asseverare",
    "asseverando": "asseverare",
    "asseverano": "asseverare",
    "asseverante": "asseverare",
    "asseveranti": "asseverare",
    "asseverar": "asseverare",
    "asseveraron": "asseverare",
    "asseverarono": "asseverare",
    "asseverasse": "asseverare",
    "asseverasser": "asseverare",
    "asseverassero": "asseverare",
    "asseverassi": "asseverare",
    "asseverassimo": "asseverare",
    "asseveraste": "asseverare",
    "asseverasti": "asseverare",
    "asseverata": "asseverare",
    "asseverate": "asseverare",
    "asseverati": "asseverare",
    "asseverato": "asseverare",
    "asseverava": "asseverare",
    "asseveravamo": "asseverare",
    "asseveravan": "asseverare",
    "asseveravano": "asseverare",
    "asseveravate": "asseverare",
    "asseveravi": "asseverare",
    "asseveravo": "asseverare",
    "assevererai": "asseverare",
    "assevereran": "asseverare",
    "assevereranno": "asseverare",
    "assevererebbe": "asseverare",
    "assevererebber": "asseverare",
    "assevererebbero": "asseverare",
    "assevererei": "asseverare",
    "assevereremmo": "asseverare",
    "assevereremo": "asseverare",
    "asseverereste": "asseverare",
    "assevereresti": "asseverare",
    "assevererete": "asseverare",
    "assevererà": "asseverare",
    "assevererò": "asseverare",
    "asseveri": "asseverare",
    "asseveriamo": "asseverare",
    "asseveriate": "asseverare",
    "asseverin": "asseverare",
    "asseverino": "asseverare",
    "assevero": "asseverare",
    "asseverò": "asseverare",
    "assi": "asso",
    "assiali": "assiale",
    "assicura": "assicurare",
    "assicurabili": "assicurabile",
    "assicurai": "assicurare",
    "assicurammo": "assicurare",
    "assicuran": "assicurare",
    "assicurando": "assicurare",
    "assicurano": "assicurare",
    "assicurante": "assicurare",
    "assicuranti": "assicurare",
    "assicurar": "assicurare",
    "assicuraron": "assicurare",
    "assicurarono": "assicurare",
    "assicurasse": "assicurare",
    "assicurasser": "assicurare",
    "assicurassero": "assicurare",
    "assicurassi": "assicurare",
    "assicurassimo": "assicurare",
    "assicuraste": "assicurare",
    "assicurasti": "assicurare",
    "assicurata": "assicurato",
    "assicurate": "assicurato",
    "assicurati": "assicurato",
    "assicurativa": "assicurativo",
    "assicurative": "assicurativo",
    "assicurativi": "assicurativo",
    "assicurato": "assicurare",
    "assicuratori": "assicuratore",
    "assicuratrice": "assicuratore",
    "assicuratrici": "assicuratore",
    "assicurava": "assicurare",
    "assicuravamo": "assicurare",
    "assicuravan": "assicurare",
    "assicuravano": "assicurare",
    "assicuravate": "assicurare",
    "assicuravi": "assicurare",
    "assicuravo": "assicurare",
    "assicurazioni": "assicurazione",
    "assicurerai": "assicurare",
    "assicureran": "assicurare",
    "assicureranno": "assicurare",
    "assicurerebbe": "assicurare",
    "assicurerebber": "assicurare",
    "assicurerebbero": "assicurare",
    "assicurerei": "assicurare",
    "assicureremmo": "assicurare",
    "assicureremo": "assicurare",
    "assicurereste": "assicurare",
    "assicureresti": "assicurare",
    "assicurerete": "assicurare",
    "assicurerà": "assicurare",
    "assicurerò": "assicurare",
    "assicuri": "assicurare",
    "assicuriamo": "assicurare",
    "assicuriate": "assicurare",
    "assicurin": "assicurare",
    "assicurino": "assicurare",
    "assicuro": "assicurare",
    "assicurò": "assicurare",
    "assida": "assidere",
    "assidan": "assidere",
    "assidano": "assidere",
    "asside": "assidere",
    "assidei": "assidere",
    "assidemmo": "assidere",
    "assidendo": "assidere",
    "assidente": "assidere",
    "assidenti": "assidere",
    "assider": "assidere",
    "assidera": "assiderare",
    "assiderai": "assidere",
    "assiderammo": "assiderare",
    "assideran": "assidere",
    "assiderando": "assiderare",
    "assideranno": "assidere",
    "assiderano": "assiderare",
    "assiderante": "assiderare",
    "assideranti": "assiderare",
    "assiderar": "assiderare",
    "assideraron": "assiderare",
    "assiderarono": "assiderare",
    "assiderasse": "assiderare",
    "assiderasser": "assiderare",
    "assiderassero": "assiderare",
    "assiderassi": "assiderare",
    "assiderassimo": "assiderare",
    "assideraste": "assiderare",
    "assiderasti": "assiderare",
    "assiderata": "assiderare",
    "assiderate": "assiderare",
    "assiderati": "assiderare",
    "assiderato": "assiderare",
    "assiderava": "assiderare",
    "assideravamo": "assiderare",
    "assideravan": "assiderare",
    "assideravano": "assiderare",
    "assideravate": "assiderare",
    "assideravi": "assiderare",
    "assideravo": "assiderare",
    "assiderebbe": "assidere",
    "assiderebber": "assidere",
    "assiderebbero": "assidere",
    "assiderei": "assidere",
    "assideremmo": "assidere",
    "assideremo": "assidere",
    "assidererai": "assiderare",
    "assidereran": "assiderare",
    "assidereranno": "assiderare",
    "assidererebbe": "assiderare",
    "assidererebber": "assiderare",
    "assidererebbero": "assiderare",
    "assidererei": "assiderare",
    "assidereremmo": "assiderare",
    "assidereremo": "assiderare",
    "assiderereste": "assiderare",
    "assidereresti": "assiderare",
    "assidererete": "assiderare",
    "assidererà": "assiderare",
    "assidererò": "assiderare",
    "assidereste": "assidere",
    "assideresti": "assidere",
    "assiderete": "assidere",
    "assideri": "assiderare",
    "assideriamo": "assiderare",
    "assideriate": "assiderare",
    "assiderin": "assiderare",
    "assiderino": "assiderare",
    "assidero": "assiderare",
    "assideron": "assidere",
    "assiderono": "assidere",
    "assiderà": "assidere",
    "assiderò": "assidere",
    "assidesse": "assidere",
    "assidesser": "assidere",
    "assidessero": "assidere",
    "assidessi": "assidere",
    "assidessimo": "assidere",
    "assideste": "assidere",
    "assidesti": "assidere",
    "assidete": "assidere",
    "assideva": "assidere",
    "assidevamo": "assidere",
    "assidevan": "assidere",
    "assidevano": "assidere",
    "assidevate": "assidere",
    "assidevi": "assidere",
    "assidevo": "assidere",
    "assidi": "assidere",
    "assidiamo": "assidere",
    "assidiate": "assidere",
    "assido": "assidere",
    "assidon": "assidere",
    "assidono": "assidere",
    "assidua": "assiduo",
    "assidue": "assiduo",
    "assidui": "assiduo",
    "assiduta": "assidere",
    "assidute": "assidere",
    "assiduti": "assidere",
    "assiduto": "assidere",
    "assidè": "assidere",
    "assiepa": "assiepare",
    "assiepai": "assiepare",
    "assiepammo": "assiepare",
    "assiepan": "assiepare",
    "assiepando": "assiepare",
    "assiepano": "assiepare",
    "assiepante": "assiepare",
    "assiepanti": "assiepare",
    "assiepar": "assiepare",
    "assieparon": "assiepare",
    "assieparono": "assiepare",
    "assiepasse": "assiepare",
    "assiepasser": "assiepare",
    "assiepassero": "assiepare",
    "assiepassi": "assiepare",
    "assiepassimo": "assiepare",
    "assiepaste": "assiepare",
    "assiepasti": "assiepare",
    "assiepata": "assiepare",
    "assiepate": "assiepare",
    "assiepati": "assiepare",
    "assiepato": "assiepare",
    "assiepava": "assiepare",
    "assiepavamo": "assiepare",
    "assiepavan": "assiepare",
    "assiepavano": "assiepare",
    "assiepavate": "assiepare",
    "assiepavi": "assiepare",
    "assiepavo": "assiepare",
    "assieperai": "assiepare",
    "assieperan": "assiepare",
    "assieperanno": "assiepare",
    "assieperebbe": "assiepare",
    "assieperebber": "assiepare",
    "assieperebbero": "assiepare",
    "assieperei": "assiepare",
    "assieperemmo": "assiepare",
    "assieperemo": "assiepare",
    "assiepereste": "assiepare",
    "assieperesti": "assiepare",
    "assieperete": "assiepare",
    "assieperà": "assiepare",
    "assieperò": "assiepare",
    "assiepi": "assiepare",
    "assiepiamo": "assiepare",
    "assiepiate": "assiepare",
    "assiepin": "assiepare",
    "assiepino": "assiepare",
    "assiepo": "assiepare",
    "assiepò": "assiepare",
    "assilla": "assillare",
    "assillai": "assillare",
    "assillammo": "assillare",
    "assillan": "assillare",
    "assillando": "assillare",
    "assillano": "assillare",
    "assillante": "assillare",
    "assillanti": "assillare",
    "assillar": "assillare",
    "assillaron": "assillare",
    "assillarono": "assillare",
    "assillasse": "assillare",
    "assillasser": "assillare",
    "assillassero": "assillare",
    "assillassi": "assillare",
    "assillassimo": "assillare",
    "assillaste": "assillare",
    "assillasti": "assillare",
    "assillata": "assillare",
    "assillate": "assillare",
    "assillati": "assillare",
    "assillato": "assillare",
    "assillava": "assillare",
    "assillavamo": "assillare",
    "assillavan": "assillare",
    "assillavano": "assillare",
    "assillavate": "assillare",
    "assillavi": "assillare",
    "assillavo": "assillare",
    "assillerai": "assillare",
    "assilleran": "assillare",
    "assilleranno": "assillare",
    "assillerebbe": "assillare",
    "assillerebber": "assillare",
    "assillerebbero": "assillare",
    "assillerei": "assillare",
    "assilleremmo": "assillare",
    "assilleremo": "assillare",
    "assillereste": "assillare",
    "assilleresti": "assillare",
    "assillerete": "assillare",
    "assillerà": "assillare",
    "assillerò": "assillare",
    "assilli": "assillo",
    "assilliamo": "assillare",
    "assilliate": "assillare",
    "assillin": "assillare",
    "assillino": "assillare",
    "assillo": "assillare",
    "assillò": "assillare",
    "assimila": "assimilare",
    "assimilabili": "assimilabile",
    "assimilai": "assimilare",
    "assimilammo": "assimilare",
    "assimilan": "assimilare",
    "assimilando": "assimilare",
    "assimilano": "assimilare",
    "assimilante": "assimilare",
    "assimilanti": "assimilare",
    "assimilar": "assimilare",
    "assimilaron": "assimilare",
    "assimilarono": "assimilare",
    "assimilasse": "assimilare",
    "assimilasser": "assimilare",
    "assimilassero": "assimilare",
    "assimilassi": "assimilare",
    "assimilassimo": "assimilare",
    "assimilaste": "assimilare",
    "assimilasti": "assimilare",
    "assimilata": "assimilare",
    "assimilate": "assimilare",
    "assimilati": "assimilare",
    "assimilato": "assimilare",
    "assimilava": "assimilare",
    "assimilavamo": "assimilare",
    "assimilavan": "assimilare",
    "assimilavano": "assimilare",
    "assimilavate": "assimilare",
    "assimilavi": "assimilare",
    "assimilavo": "assimilare",
    "assimilazioni": "assimilazione",
    "assimilerai": "assimilare",
    "assimileran": "assimilare",
    "assimileranno": "assimilare",
    "assimilerebbe": "assimilare",
    "assimilerebber": "assimilare",
    "assimilerebbero": "assimilare",
    "assimilerei": "assimilare",
    "assimileremmo": "assimilare",
    "assimileremo": "assimilare",
    "assimilereste": "assimilare",
    "assimileresti": "assimilare",
    "assimilerete": "assimilare",
    "assimilerà": "assimilare",
    "assimilerò": "assimilare",
    "assimili": "assimilare",
    "assimiliamo": "assimilare",
    "assimiliate": "assimilare",
    "assimilin": "assimilare",
    "assimilino": "assimilare",
    "assimilo": "assimilare",
    "assimilò": "assimilare",
    "assiomatica": "assiomatico",
    "assiomatiche": "assiomatico",
    "assiomatici": "assiomatico",
    "assiomi": "assioma",
    "assisa": "assiso",
    "assise": "assiso",
    "assisi": "assiso",
    "assista": "assistere",
    "assistan": "assistere",
    "assistano": "assistere",
    "assiste": "assistere",
    "assistei": "assistere",
    "assistemmo": "assistere",
    "assistendo": "assistere",
    "assistente": "assistere",
    "assistenti": "assistere",
    "assistenze": "assistenza",
    "assistenziali": "assistenziale",
    "assistenzialismi": "assistenzialismo",
    "assister": "assistere",
    "assisterai": "assistere",
    "assisteran": "assistere",
    "assisteranno": "assistere",
    "assisterebbe": "assistere",
    "assisterebber": "assistere",
    "assisterebbero": "assistere",
    "assisterei": "assistere",
    "assisteremmo": "assistere",
    "assisteremo": "assistere",
    "assistereste": "assistere",
    "assisteresti": "assistere",
    "assisterete": "assistere",
    "assisterono": "assistere",
    "assisterà": "assistere",
    "assisterò": "assistere",
    "assistesse": "assistere",
    "assistesser": "assistere",
    "assistessero": "assistere",
    "assistessi": "assistere",
    "assistessimo": "assistere",
    "assisteste": "assistere",
    "assistesti": "assistere",
    "assistete": "assistere",
    "assisteva": "assistere",
    "assistevamo": "assistere",
    "assistevan": "assistere",
    "assistevano": "assistere",
    "assistevate": "assistere",
    "assistevi": "assistere",
    "assistevo": "assistere",
    "assisti": "assistere",
    "assistiamo": "assistere",
    "assistiate": "assistere",
    "assistita": "assistere",
    "assistite": "assistita",
    "assistiti": "assistito",
    "assistito": "assistere",
    "assisto": "assistere",
    "assiston": "assistere",
    "assistono": "assistere",
    "assistè": "assistere",
    "assocerai": "associare",
    "assoceran": "associare",
    "assoceranno": "associare",
    "assocerebbe": "associare",
    "assocerebber": "associare",
    "assocerebbero": "associare",
    "assocerei": "associare",
    "assoceremmo": "associare",
    "assoceremo": "associare",
    "assocereste": "associare",
    "assoceresti": "associare",
    "assocerete": "associare",
    "assocerà": "associare",
    "assocerò": "associare",
    "associ": "associare",
    "associa": "associare",
    "associabili": "associabile",
    "associai": "associare",
    "associammo": "associare",
    "associamo": "associare",
    "associan": "associare",
    "associando": "associare",
    "associano": "associare",
    "associante": "associare",
    "associanti": "associare",
    "associar": "associare",
    "associaron": "associare",
    "associarono": "associare",
    "associasse": "associare",
    "associasser": "associare",
    "associassero": "associare",
    "associassi": "associare",
    "associassimo": "associare",
    "associaste": "associare",
    "associasti": "associare",
    "associata": "associare",
    "associate": "associata",
    "associati": "associato",
    "associativa": "associativo",
    "associative": "associativo",
    "associativi": "associativo",
    "associato": "associare",
    "associava": "associare",
    "associavamo": "associare",
    "associavan": "associare",
    "associavano": "associare",
    "associavate": "associare",
    "associavi": "associare",
    "associavo": "associare",
    "associazioni": "associazione",
    "associazionismi": "associazionismo",
    "associn": "associare",
    "associno": "associare",
    "associo": "associare",
    "associò": "associare",
    "assoda": "assodare",
    "assodai": "assodare",
    "assodammo": "assodare",
    "assodan": "assodare",
    "assodando": "assodare",
    "assodano": "assodare",
    "assodante": "assodare",
    "assodanti": "assodare",
    "assodar": "assodare",
    "assodaron": "assodare",
    "assodarono": "assodare",
    "assodasse": "assodare",
    "assodasser": "assodare",
    "assodassero": "assodare",
    "assodassi": "assodare",
    "assodassimo": "assodare",
    "assodaste": "assodare",
    "assodasti": "assodare",
    "assodata": "assodare",
    "assodate": "assodare",
    "assodati": "assodare",
    "assodato": "assodare",
    "assodava": "assodare",
    "assodavamo": "assodare",
    "assodavan": "assodare",
    "assodavano": "assodare",
    "assodavate": "assodare",
    "assodavi": "assodare",
    "assodavo": "assodare",
    "assoderai": "assodare",
    "assoderan": "assodare",
    "assoderanno": "assodare",
    "assoderebbe": "assodare",
    "assoderebber": "assodare",
    "assoderebbero": "assodare",
    "assoderei": "assodare",
    "assoderemmo": "assodare",
    "assoderemo": "assodare",
    "assodereste": "assodare",
    "assoderesti": "assodare",
    "assoderete": "assodare",
    "assoderà": "assodare",
    "assoderò": "assodare",
    "assodi": "assodare",
    "assodiamo": "assodare",
    "assodiate": "assodare",
    "assodin": "assodare",
    "assodino": "assodare",
    "assodo": "assodare",
    "assodò": "assodare",
    "assoggetta": "assoggettare",
    "assoggettai": "assoggettare",
    "assoggettammo": "assoggettare",
    "assoggettan": "assoggettare",
    "assoggettando": "assoggettare",
    "assoggettano": "assoggettare",
    "assoggettante": "assoggettare",
    "assoggettanti": "assoggettare",
    "assoggettar": "assoggettare",
    "assoggettaron": "assoggettare",
    "assoggettarono": "assoggettare",
    "assoggettasse": "assoggettare",
    "assoggettasser": "assoggettare",
    "assoggettassero": "assoggettare",
    "assoggettassi": "assoggettare",
    "assoggettassimo": "assoggettare",
    "assoggettaste": "assoggettare",
    "assoggettasti": "assoggettare",
    "assoggettata": "assoggettare",
    "assoggettate": "assoggettare",
    "assoggettati": "assoggettare",
    "assoggettato": "assoggettare",
    "assoggettava": "assoggettare",
    "assoggettavamo": "assoggettare",
    "assoggettavan": "assoggettare",
    "assoggettavano": "assoggettare",
    "assoggettavate": "assoggettare",
    "assoggettavi": "assoggettare",
    "assoggettavo": "assoggettare",
    "assoggetterai": "assoggettare",
    "assoggetteran": "assoggettare",
    "assoggetteranno": "assoggettare",
    "assoggetterebbe": "assoggettare",
    "assoggetterebber": "assoggettare",
    "assoggetterebbero": "assoggettare",
    "assoggetterei": "assoggettare",
    "assoggetteremmo": "assoggettare",
    "assoggetteremo": "assoggettare",
    "assoggettereste": "assoggettare",
    "assoggetteresti": "assoggettare",
    "assoggetterete": "assoggettare",
    "assoggetterà": "assoggettare",
    "assoggetterò": "assoggettare",
    "assoggetti": "assoggettare",
    "assoggettiamo": "assoggettare",
    "assoggettiate": "assoggettare",
    "assoggettin": "assoggettare",
    "assoggettino": "assoggettare",
    "assoggetto": "assoggettare",
    "assoggettò": "assoggettare",
    "assolata": "assolato",
    "assolate": "assolato",
    "assolati": "assolato",
    "assolda": "assoldare",
    "assoldai": "assoldare",
    "assoldammo": "assoldare",
    "assoldan": "assoldare",
    "assoldando": "assoldare",
    "assoldano": "assoldare",
    "assoldante": "assoldare",
    "assoldanti": "assoldare",
    "assoldar": "assoldare",
    "assoldaron": "assoldare",
    "assoldarono": "assoldare",
    "assoldasse": "assoldare",
    "assoldasser": "assoldare",
    "assoldassero": "assoldare",
    "assoldassi": "assoldare",
    "assoldassimo": "assoldare",
    "assoldaste": "assoldare",
    "assoldasti": "assoldare",
    "assoldata": "assoldare",
    "assoldate": "assoldare",
    "assoldati": "assoldare",
    "assoldato": "assoldare",
    "assoldava": "assoldare",
    "assoldavamo": "assoldare",
    "assoldavan": "assoldare",
    "assoldavano": "assoldare",
    "assoldavate": "assoldare",
    "assoldavi": "assoldare",
    "assoldavo": "assoldare",
    "assolderai": "assoldare",
    "assolderan": "assoldare",
    "assolderanno": "assoldare",
    "assolderebbe": "assoldare",
    "assolderebber": "assoldare",
    "assolderebbero": "assoldare",
    "assolderei": "assoldare",
    "assolderemmo": "assoldare",
    "assolderemo": "assoldare",
    "assoldereste": "assoldare",
    "assolderesti": "assoldare",
    "assolderete": "assoldare",
    "assolderà": "assoldare",
    "assolderò": "assoldare",
    "assoldi": "assoldare",
    "assoldiamo": "assoldare",
    "assoldiate": "assoldare",
    "assoldin": "assoldare",
    "assoldino": "assoldare",
    "assoldo": "assoldare",
    "assoldò": "assoldare",
    "assoli": "assolo",
    "assolse": "assolvere",
    "assolser": "assolvere",
    "assolsero": "assolvere",
    "assolsi": "assolvere",
    "assolta": "assolvere",
    "assolte": "assolvere",
    "assolti": "assolvere",
    "assolto": "assolvere",
    "assoluta": "assoluto",
    "assolute": "assoluto",
    "assoluti": "assoluto",
    "assolutismi": "assolutismo",
    "assolutori": "assolutorio",
    "assolutoria": "assolutorio",
    "assolutorie": "assolutorio",
    "assoluzioni": "assoluzione",
    "assolva": "assolvere",
    "assolvan": "assolvere",
    "assolvano": "assolvere",
    "assolve": "assolvere",
    "assolvemmo": "assolvere",
    "assolvendo": "assolvere",
    "assolvente": "assolvere",
    "assolventi": "assolvere",
    "assolver": "assolvere",
    "assolverai": "assolvere",
    "assolveran": "assolvere",
    "assolveranno": "assolvere",
    "assolverebbe": "assolvere",
    "assolverebber": "assolvere",
    "assolverebbero": "assolvere",
    "assolverei": "assolvere",
    "assolveremmo": "assolvere",
    "assolveremo": "assolvere",
    "assolvereste": "assolvere",
    "assolveresti": "assolvere",
    "assolverete": "assolvere",
    "assolverà": "assolvere",
    "assolverò": "assolvere",
    "assolvesse": "assolvere",
    "assolvesser": "assolvere",
    "assolvessero": "assolvere",
    "assolvessi": "assolvere",
    "assolvessimo": "assolvere",
    "assolveste": "assolvere",
    "assolvesti": "assolvere",
    "assolvete": "assolvere",
    "assolveva": "assolvere",
    "assolvevamo": "assolvere",
    "assolvevan": "assolvere",
    "assolvevano": "assolvere",
    "assolvevate": "assolvere",
    "assolvevi": "assolvere",
    "assolvevo": "assolvere",
    "assolvi": "assolvere",
    "assolviamo": "assolvere",
    "assolviate": "assolvere",
    "assolvo": "assolvere",
    "assolvon": "assolvere",
    "assolvono": "assolvere",
    "assomigli": "assomigliare",
    "assomiglia": "assomigliare",
    "assomigliai": "assomigliare",
    "assomigliammo": "assomigliare",
    "assomigliamo": "assomigliare",
    "assomiglian": "assomigliare",
    "assomigliando": "assomigliare",
    "assomigliano": "assomigliare",
    "assomigliante": "assomigliare",
    "assomiglianti": "assomigliare",
    "assomigliar": "assomigliare",
    "assomigliaron": "assomigliare",
    "assomigliarono": "assomigliare",
    "assomigliasse": "assomigliare",
    "assomigliasser": "assomigliare",
    "assomigliassero": "assomigliare",
    "assomigliassi": "assomigliare",
    "assomigliassimo": "assomigliare",
    "assomigliaste": "assomigliare",
    "assomigliasti": "assomigliare",
    "assomigliata": "assomigliare",
    "assomigliate": "assomigliare",
    "assomigliati": "assomigliare",
    "assomigliato": "assomigliare",
    "assomigliava": "assomigliare",
    "assomigliavamo": "assomigliare",
    "assomigliavan": "assomigliare",
    "assomigliavano": "assomigliare",
    "assomigliavate": "assomigliare",
    "assomigliavi": "assomigliare",
    "assomigliavo": "assomigliare",
    "assomiglierai": "assomigliare",
    "assomiglieran": "assomigliare",
    "assomiglieranno": "assomigliare",
    "assomiglierebbe": "assomigliare",
    "assomiglierebber": "assomigliare",
    "assomiglierebbero": "assomigliare",
    "assomiglierei": "assomigliare",
    "assomiglieremmo": "assomigliare",
    "assomiglieremo": "assomigliare",
    "assomigliereste": "assomigliare",
    "assomiglieresti": "assomigliare",
    "assomiglierete": "assomigliare",
    "assomiglierà": "assomigliare",
    "assomiglierò": "assomigliare",
    "assomiglin": "assomigliare",
    "assomiglino": "assomigliare",
    "assomiglio": "assomigliare",
    "assomigliò": "assomigliare",
    "assomma": "assommare",
    "assommai": "assommare",
    "assommammo": "assommare",
    "assomman": "assommare",
    "assommando": "assommare",
    "assommano": "assommare",
    "assommante": "assommare",
    "assommanti": "assommare",
    "assommar": "assommare",
    "assommaron": "assommare",
    "assommarono": "assommare",
    "assommasse": "assommare",
    "assommasser": "assommare",
    "assommassero": "assommare",
    "assommassi": "assommare",
    "assommassimo": "assommare",
    "assommaste": "assommare",
    "assommasti": "assommare",
    "assommata": "assommare",
    "assommate": "assommare",
    "assommati": "assommare",
    "assommato": "assommare",
    "assommava": "assommare",
    "assommavamo": "assommare",
    "assommavan": "assommare",
    "assommavano": "assommare",
    "assommavate": "assommare",
    "assommavi": "assommare",
    "assommavo": "assommare",
    "assommerai": "assommare",
    "assommeran": "assommare",
    "assommeranno": "assommare",
    "assommerebbe": "assommare",
    "assommerebber": "assommare",
    "assommerebbero": "assommare",
    "assommerei": "assommare",
    "assommeremmo": "assommare",
    "assommeremo": "assommare",
    "assommereste": "assommare",
    "assommeresti": "assommare",
    "assommerete": "assommare",
    "assommerà": "assommare",
    "assommerò": "assommare",
    "assommi": "assommare",
    "assommiamo": "assommare",
    "assommiate": "assommare",
    "assommin": "assommare",
    "assommino": "assommare",
    "assommo": "assommare",
    "assommò": "assommare",
    "assonanze": "assonanza",
    "assonna": "assonnare",
    "assonnai": "assonnare",
    "assonnammo": "assonnare",
    "assonnan": "assonnare",
    "assonnando": "assonnare",
    "assonnano": "assonnare",
    "assonnante": "assonnare",
    "assonnanti": "assonnare",
    "assonnar": "assonnare",
    "assonnaron": "assonnare",
    "assonnarono": "assonnare",
    "assonnasse": "assonnare",
    "assonnasser": "assonnare",
    "assonnassero": "assonnare",
    "assonnassi": "assonnare",
    "assonnassimo": "assonnare",
    "assonnaste": "assonnare",
    "assonnasti": "assonnare",
    "assonnata": "assonnato",
    "assonnate": "assonnato",
    "assonnati": "assonnato",
    "assonnato": "assonnare",
    "assonnava": "assonnare",
    "assonnavamo": "assonnare",
    "assonnavan": "assonnare",
    "assonnavano": "assonnare",
    "assonnavate": "assonnare",
    "assonnavi": "assonnare",
    "assonnavo": "assonnare",
    "assonnerai": "assonnare",
    "assonneran": "assonnare",
    "assonneranno": "assonnare",
    "assonnerebbe": "assonnare",
    "assonnerebber": "assonnare",
    "assonnerebbero": "assonnare",
    "assonnerei": "assonnare",
    "assonneremmo": "assonnare",
    "assonneremo": "assonnare",
    "assonnereste": "assonnare",
    "assonneresti": "assonnare",
    "assonnerete": "assonnare",
    "assonnerà": "assonnare",
    "assonnerò": "assonnare",
    "assonni": "assonnare",
    "assonniamo": "assonnare",
    "assonniate": "assonnare",
    "assonnin": "assonnare",
    "assonnino": "assonnare",
    "assonno": "assonnare",
    "assonnò": "assonnare",
    "assopendo": "assopire",
    "assopente": "assopire",
    "assopenti": "assopire",
    "assopiamo": "assopire",
    "assopiate": "assopire",
    "assopii": "assopire",
    "assopimmo": "assopire",
    "assopir": "assopire",
    "assopirai": "assopire",
    "assopiran": "assopire",
    "assopiranno": "assopire",
    "assopirebbe": "assopire",
    "assopirebber": "assopire",
    "assopirebbero": "assopire",
    "assopirei": "assopire",
    "assopiremmo": "assopire",
    "assopiremo": "assopire",
    "assopireste": "assopire",
    "assopiresti": "assopire",
    "assopirete": "assopire",
    "assopiron": "assopire",
    "assopirono": "assopire",
    "assopirà": "assopire",
    "assopirò": "assopire",
    "assopisca": "assopire",
    "assopiscan": "assopire",
    "assopiscano": "assopire",
    "assopisce": "assopire",
    "assopisci": "assopire",
    "assopisco": "assopire",
    "assopiscon": "assopire",
    "assopiscono": "assopire",
    "assopisse": "assopire",
    "assopisser": "assopire",
    "assopissero": "assopire",
    "assopissi": "assopire",
    "assopissimo": "assopire",
    "assopiste": "assopire",
    "assopisti": "assopire",
    "assopita": "assopire",
    "assopite": "assopire",
    "assopiti": "assopire",
    "assopito": "assopire",
    "assopiva": "assopire",
    "assopivamo": "assopire",
    "assopivan": "assopire",
    "assopivano": "assopire",
    "assopivate": "assopire",
    "assopivi": "assopire",
    "assopivo": "assopire",
    "assopì": "assopire",
    "assorba": "assorbire",
    "assorban": "assorbire",
    "assorbano": "assorbire",
    "assorbe": "assorbire",
    "assorbendo": "assorbire",
    "assorbente": "assorbire",
    "assorbenti": "assorbire",
    "assorbi": "assorbire",
    "assorbiamo": "assorbire",
    "assorbiate": "assorbire",
    "assorbii": "assorbire",
    "assorbimenti": "assorbimento",
    "assorbimmo": "assorbire",
    "assorbir": "assorbire",
    "assorbirai": "assorbire",
    "assorbiran": "assorbire",
    "assorbiranno": "assorbire",
    "assorbirebbe": "assorbire",
    "assorbirebber": "assorbire",
    "assorbirebbero": "assorbire",
    "assorbirei": "assorbire",
    "assorbiremmo": "assorbire",
    "assorbiremo": "assorbire",
    "assorbireste": "assorbire",
    "assorbiresti": "assorbire",
    "assorbirete": "assorbire",
    "assorbiron": "assorbire",
    "assorbirono": "assorbire",
    "assorbirà": "assorbire",
    "assorbirò": "assorbire",
    "assorbisse": "assorbire",
    "assorbisser": "assorbire",
    "assorbissero": "assorbire",
    "assorbissi": "assorbire",
    "assorbissimo": "assorbire",
    "assorbiste": "assorbire",
    "assorbisti": "assorbire",
    "assorbita": "assorbire",
    "assorbite": "assorbire",
    "assorbiti": "assorbire",
    "assorbito": "assorbire",
    "assorbiva": "assorbire",
    "assorbivamo": "assorbire",
    "assorbivan": "assorbire",
    "assorbivano": "assorbire",
    "assorbivate": "assorbire",
    "assorbivi": "assorbire",
    "assorbivo": "assorbire",
    "assorbo": "assorbire",
    "assorbon": "assorbire",
    "assorbono": "assorbire",
    "assorbì": "assorbire",
    "assorda": "assordire",
    "assordai": "assordare",
    "assordammo": "assordare",
    "assordan": "assordire",
    "assordando": "assordare",
    "assordano": "assordire",
    "assordante": "assordare",
    "assordanti": "assordare",
    "assordar": "assordare",
    "assordaron": "assordare",
    "assordarono": "assordare",
    "assordasse": "assordare",
    "assordasser": "assordare",
    "assordassero": "assordare",
    "assordassi": "assordare",
    "assordassimo": "assordare",
    "assordaste": "assordare",
    "assordasti": "assordare",
    "assordata": "assordare",
    "assordate": "assordare",
    "assordati": "assordare",
    "assordato": "assordare",
    "assordava": "assordare",
    "assordavamo": "assordare",
    "assordavan": "assordare",
    "assordavano": "assordare",
    "assordavate": "assordare",
    "assordavi": "assordare",
    "assordavo": "assordare",
    "assorde": "assordire",
    "assordendo": "assordire",
    "assordente": "assordire",
    "assordenti": "assordire",
    "assorderai": "assordare",
    "assorderan": "assordare",
    "assorderanno": "assordare",
    "assorderebbe": "assordare",
    "assorderebber": "assordare",
    "assorderebbero": "assordare",
    "assorderei": "assordare",
    "assorderemmo": "assordare",
    "assorderemo": "assordare",
    "assordereste": "assordare",
    "assorderesti": "assordare",
    "assorderete": "assordare",
    "assorderà": "assordare",
    "assorderò": "assordare",
    "assordi": "assordire",
    "assordiamo": "assordire",
    "assordiate": "assordire",
    "assordii": "assordire",
    "assordimmo": "assordire",
    "assordin": "assordare",
    "assordino": "assordare",
    "assordir": "assordire",
    "assordirai": "assordire",
    "assordiran": "assordire",
    "assordiranno": "assordire",
    "assordirebbe": "assordire",
    "assordirebber": "assordire",
    "assordirebbero": "assordire",
    "assordirei": "assordire",
    "assordiremmo": "assordire",
    "assordiremo": "assordire",
    "assordireste": "assordire",
    "assordiresti": "assordire",
    "assordirete": "assordire",
    "assordiron": "assordire",
    "assordirono": "assordire",
    "assordirà": "assordire",
    "assordirò": "assordire",
    "assordisse": "assordire",
    "assordisser": "assordire",
    "assordissero": "assordire",
    "assordissi": "assordire",
    "assordissimo": "assordire",
    "assordiste": "assordire",
    "assordisti": "assordire",
    "assordita": "assordire",
    "assordite": "assordire",
    "assorditi": "assordire",
    "assordito": "assordire",
    "assordiva": "assordire",
    "assordivamo": "assordire",
    "assordivan": "assordire",
    "assordivano": "assordire",
    "assordivate": "assordire",
    "assordivi": "assordire",
    "assordivo": "assordire",
    "assordo": "assordire",
    "assordon": "assordire",
    "assordono": "assordire",
    "assordì": "assordire",
    "assordò": "assordare",
    "assorta": "assorto",
    "assorte": "assorto",
    "assortendo": "assortire",
    "assortente": "assortire",
    "assortenti": "assortire",
    "assorti": "assorto",
    "assortiamo": "assortire",
    "assortiate": "assortire",
    "assortii": "assortire",
    "assortimenti": "assortimento",
    "assortimmo": "assortire",
    "assortir": "assortire",
    "assortirai": "assortire",
    "assortiran": "assortire",
    "assortiranno": "assortire",
    "assortirebbe": "assortire",
    "assortirebber": "assortire",
    "assortirebbero": "assortire",
    "assortirei": "assortire",
    "assortiremmo": "assortire",
    "assortiremo": "assortire",
    "assortireste": "assortire",
    "assortiresti": "assortire",
    "assortirete": "assortire",
    "assortiron": "assortire",
    "assortirono": "assortire",
    "assortirà": "assortire",
    "assortirò": "assortire",
    "assortisca": "assortire",
    "assortiscan": "assortire",
    "assortiscano": "assortire",
    "assortisce": "assortire",
    "assortisci": "assortire",
    "assortisco": "assortire",
    "assortiscon": "assortire",
    "assortiscono": "assortire",
    "assortisse": "assortire",
    "assortisser": "assortire",
    "assortissero": "assortire",
    "assortissi": "assortire",
    "assortissimo": "assortire",
    "assortiste": "assortire",
    "assortisti": "assortire",
    "assortita": "assortito",
    "assortite": "assortito",
    "assortiti": "assortito",
    "assortito": "assortire",
    "assortiva": "assortire",
    "assortivamo": "assortire",
    "assortivan": "assortire",
    "assortivano": "assortire",
    "assortivate": "assortire",
    "assortivi": "assortire",
    "assortivo": "assortire",
    "assortì": "assortire",
    "assottigli": "assottigliare",
    "assottiglia": "assottigliare",
    "assottigliai": "assottigliare",
    "assottigliammo": "assottigliare",
    "assottigliamo": "assottigliare",
    "assottiglian": "assottigliare",
    "assottigliando": "assottigliare",
    "assottigliano": "assottigliare",
    "assottigliante": "assottigliare",
    "assottiglianti": "assottigliare",
    "assottigliar": "assottigliare",
    "assottigliaron": "assottigliare",
    "assottigliarono": "assottigliare",
    "assottigliasse": "assottigliare",
    "assottigliasser": "assottigliare",
    "assottigliassero": "assottigliare",
    "assottigliassi": "assottigliare",
    "assottigliassimo": "assottigliare",
    "assottigliaste": "assottigliare",
    "assottigliasti": "assottigliare",
    "assottigliata": "assottigliare",
    "assottigliate": "assottigliare",
    "assottigliati": "assottigliare",
    "assottigliato": "assottigliare",
    "assottigliava": "assottigliare",
    "assottigliavamo": "assottigliare",
    "assottigliavan": "assottigliare",
    "assottigliavano": "assottigliare",
    "assottigliavate": "assottigliare",
    "assottigliavi": "assottigliare",
    "assottigliavo": "assottigliare",
    "assottiglierai": "assottigliare",
    "assottiglieran": "assottigliare",
    "assottiglieranno": "assottigliare",
    "assottiglierebbe": "assottigliare",
    "assottiglierebber": "assottigliare",
    "assottiglierebbero": "assottigliare",
    "assottiglierei": "assottigliare",
    "assottiglieremmo": "assottigliare",
    "assottiglieremo": "assottigliare",
    "assottigliereste": "assottigliare",
    "assottiglieresti": "assottigliare",
    "assottiglierete": "assottigliare",
    "assottiglierà": "assottigliare",
    "assottiglierò": "assottigliare",
    "assottiglin": "assottigliare",
    "assottiglino": "assottigliare",
    "assottiglio": "assottigliare",
    "assottigliò": "assottigliare",
    "assuefa": "assuefare",
    "assuefa'": "assuefare",
    "assuefaccia": "assuefare",
    "assuefacciamo": "assuefare",
    "assuefaccian": "assuefare",
    "assuefacciano": "assuefare",
    "assuefacciate": "assuefare",
    "assuefaccio": "assuefare",
    "assuefacemmo": "assuefare",
    "assuefacendo": "assuefare",
    "assuefacente": "assuefare",
    "assuefacenti": "assuefare",
    "assuefacesse": "assuefare",
    "assuefacesser": "assuefare",
    "assuefacessero": "assuefare",
    "assuefacessi": "assuefare",
    "assuefacessimo": "assuefare",
    "assuefaceste": "assuefare",
    "assuefacesti": "assuefare",
    "assuefaceva": "assuefare",
    "assuefacevamo": "assuefare",
    "assuefacevan": "assuefare",
    "assuefacevano": "assuefare",
    "assuefacevate": "assuefare",
    "assuefacevi": "assuefare",
    "assuefacevo": "assuefare",
    "assuefai": "assuefare",
    "assuefan": "assuefare",
    "assuefanno": "assuefare",
    "assuefar": "assuefare",
    "assuefarai": "assuefare",
    "assuefaran": "assuefare",
    "assuefaranno": "assuefare",
    "assuefarebbe": "assuefare",
    "assuefarebber": "assuefare",
    "assuefarebbero": "assuefare",
    "assuefarei": "assuefare",
    "assuefaremmo": "assuefare",
    "assuefaremo": "assuefare",
    "assuefareste": "assuefare",
    "assuefaresti": "assuefare",
    "assuefarete": "assuefare",
    "assuefarà": "assuefare",
    "assuefarò": "assuefare",
    "assuefate": "assuefare",
    "assuefatta": "assuefare",
    "assuefatte": "assuefare",
    "assuefatti": "assuefare",
    "assuefatto": "assuefare",
    "assuefazioni": "assuefazione",
    "assuefece": "assuefare",
    "assuefecer": "assuefare",
    "assuefecero": "assuefare",
    "assuefeci": "assuefare",
    "assuma": "assumere",
    "assuman": "assumere",
    "assumano": "assumere",
    "assume": "assumere",
    "assumemmo": "assumere",
    "assumendo": "assumere",
    "assumente": "assumere",
    "assumenti": "assumere",
    "assumer": "assumere",
    "assumerai": "assumere",
    "assumeran": "assumere",
    "assumeranno": "assumere",
    "assumerebbe": "assumere",
    "assumerebber": "assumere",
    "assumerebbero": "assumere",
    "assumerei": "assumere",
    "assumeremmo": "assumere",
    "assumeremo": "assumere",
    "assumereste": "assumere",
    "assumeresti": "assumere",
    "assumerete": "assumere",
    "assumerà": "assumere",
    "assumerò": "assumere",
    "assumesse": "assumere",
    "assumesser": "assumere",
    "assumessero": "assumere",
    "assumessi": "assumere",
    "assumessimo": "assumere",
    "assumeste": "assumere",
    "assumesti": "assumere",
    "assumete": "assumere",
    "assumeva": "assumere",
    "assumevamo": "assumere",
    "assumevan": "assumere",
    "assumevano": "assumere",
    "assumevate": "assumere",
    "assumevi": "assumere",
    "assumevo": "assumere",
    "assumi": "assumere",
    "assumiamo": "assumere",
    "assumiate": "assumere",
    "assumo": "assumere",
    "assumon": "assumere",
    "assumono": "assumere",
    "assunse": "assumere",
    "assunser": "assumere",
    "assunsero": "assumere",
    "assunsi": "assumere",
    "assunta": "assumere",
    "assunte": "assumere",
    "assunti": "assunto",
    "assunto": "assumere",
    "assunzioni": "assunzione",
    "assurda": "assurdo",
    "assurde": "assurdo",
    "assurdi": "assurdo",
    "assurga": "assurgere",
    "assurgan": "assurgere",
    "assurgano": "assurgere",
    "assurge": "assurgere",
    "assurgemmo": "assurgere",
    "assurgendo": "assurgere",
    "assurgente": "assurgere",
    "assurgenti": "assurgere",
    "assurger": "assurgere",
    "assurgerai": "assurgere",
    "assurgeran": "assurgere",
    "assurgeranno": "assurgere",
    "assurgerebbe": "assurgere",
    "assurgerebber": "assurgere",
    "assurgerebbero": "assurgere",
    "assurgerei": "assurgere",
    "assurgeremmo": "assurgere",
    "assurgeremo": "assurgere",
    "assurgereste": "assurgere",
    "assurgeresti": "assurgere",
    "assurgerete": "assurgere",
    "assurgerà": "assurgere",
    "assurgerò": "assurgere",
    "assurgesse": "assurgere",
    "assurgesser": "assurgere",
    "assurgessero": "assurgere",
    "assurgessi": "assurgere",
    "assurgessimo": "assurgere",
    "assurgeste": "assurgere",
    "assurgesti": "assurgere",
    "assurgete": "assurgere",
    "assurgeva": "assurgere",
    "assurgevamo": "assurgere",
    "assurgevan": "assurgere",
    "assurgevano": "assurgere",
    "assurgevate": "assurgere",
    "assurgevi": "assurgere",
    "assurgevo": "assurgere",
    "assurgi": "assurgere",
    "assurgiamo": "assurgere",
    "assurgiate": "assurgere",
    "assurgo": "assurgere",
    "assurgon": "assurgere",
    "assurgono": "assurgere",
    "assurse": "assurgere",
    "assurser": "assurgere",
    "assursero": "assurgere",
    "assursi": "assurgere",
    "assurta": "assurgere",
    "assurte": "assurgere",
    "assurti": "assurgere",
    "assurto": "assurgere",
    "astanti": "astante",
    "aste": "asta",
    "astemi": "astemio",
    "astemia": "astemio",
    "astemie": "astemio",
    "astenemmo": "astenere",
    "astenendo": "astenere",
    "astenente": "astenere",
    "astenenti": "astenere",
    "astener": "astenere",
    "astenesse": "astenere",
    "astenesser": "astenere",
    "astenessero": "astenere",
    "astenessi": "astenere",
    "astenessimo": "astenere",
    "asteneste": "astenere",
    "astenesti": "astenere",
    "astenete": "astenere",
    "asteneva": "astenere",
    "astenevamo": "astenere",
    "astenevan": "astenere",
    "astenevano": "astenere",
    "astenevate": "astenere",
    "astenevi": "astenere",
    "astenevo": "astenere",
    "astenga": "astenere",
    "astengan": "astenere",
    "astengano": "astenere",
    "astengo": "astenere",
    "astengon": "astenere",
    "astengono": "astenere",
    "asteniamo": "astenere",
    "asteniate": "astenere",
    "astenne": "astenere",
    "astenner": "astenere",
    "astennero": "astenere",
    "astenni": "astenere",
    "astensioni": "astensione",
    "astensionismi": "astensionismo",
    "astensioniste": "astensionista",
    "astensionisti": "astensionista",
    "astenuta": "astenuto",
    "astenute": "astenuto",
    "astenuti": "astenuto",
    "astenuto": "astenere",
    "asterischi": "asterisco",
    "asteroidi": "asteroide",
    "asterrai": "astenere",
    "asterran": "astenere",
    "asterranno": "astenere",
    "asterrebbe": "astenere",
    "asterrebber": "astenere",
    "asterrebbero": "astenere",
    "asterrei": "astenere",
    "asterremmo": "astenere",
    "asterremo": "astenere",
    "asterreste": "astenere",
    "asterresti": "astenere",
    "asterrete": "astenere",
    "asterrà": "astenere",
    "asterrò": "astenere",
    "asti": "astio",
    "astiene": "astenere",
    "astieni": "astenere",
    "astinenze": "astinenza",
    "astiosa": "astioso",
    "astiose": "astioso",
    "astiosi": "astioso",
    "astrae": "astrarre",
    "astraemmo": "astrarre",
    "astraendo": "astrarre",
    "astraente": "astrarre",
    "astraenti": "astrarre",
    "astraesse": "astrarre",
    "astraesser": "astrarre",
    "astraessero": "astrarre",
    "astraessi": "astrarre",
    "astraessimo": "astrarre",
    "astraeste": "astrarre",
    "astraesti": "astrarre",
    "astraete": "astrarre",
    "astraeva": "astrarre",
    "astraevamo": "astrarre",
    "astraevan": "astrarre",
    "astraevano": "astrarre",
    "astraevate": "astrarre",
    "astraevi": "astrarre",
    "astraevo": "astrarre",
    "astragga": "astrarre",
    "astraggan": "astrarre",
    "astraggano": "astrarre",
    "astraggo": "astrarre",
    "astraggon": "astrarre",
    "astraggono": "astrarre",
    "astrai": "astrarre",
    "astraiamo": "astrarre",
    "astraiate": "astrarre",
    "astrali": "astrale",
    "astrarr": "astrarre",
    "astrarrai": "astrarre",
    "astrarran": "astrarre",
    "astrarranno": "astrarre",
    "astrarrebbe": "astrarre",
    "astrarrebber": "astrarre",
    "astrarrebbero": "astrarre",
    "astrarrei": "astrarre",
    "astrarremmo": "astrarre",
    "astrarremo": "astrarre",
    "astrarreste": "astrarre",
    "astrarresti": "astrarre",
    "astrarrete": "astrarre",
    "astrarrà": "astrarre",
    "astrarrò": "astrarre",
    "astrasse": "astrarre",
    "astrasser": "astrarre",
    "astrassero": "astrarre",
    "astrassi": "astrarre",
    "astratta": "astratto",
    "astratte": "astratto",
    "astrattezze": "astrattezza",
    "astratti": "astratto",
    "astrattisti": "astrattista",
    "astratto": "astrarre",
    "astrazioni": "astrazione",
    "astri": "astro",
    "astringa": "astringere",
    "astringan": "astringere",
    "astringano": "astringere",
    "astringe": "astringere",
    "astringemmo": "astringere",
    "astringendo": "astringere",
    "astringente": "astringere",
    "astringenti": "astringere",
    "astringer": "astringere",
    "astringerai": "astringere",
    "astringeran": "astringere",
    "astringeranno": "astringere",
    "astringerebbe": "astringere",
    "astringerebber": "astringere",
    "astringerebbero": "astringere",
    "astringerei": "astringere",
    "astringeremmo": "astringere",
    "astringeremo": "astringere",
    "astringereste": "astringere",
    "astringeresti": "astringere",
    "astringerete": "astringere",
    "astringerà": "astringere",
    "astringerò": "astringere",
    "astringesse": "astringere",
    "astringesser": "astringere",
    "astringessero": "astringere",
    "astringessi": "astringere",
    "astringessimo": "astringere",
    "astringeste": "astringere",
    "astringesti": "astringere",
    "astringete": "astringere",
    "astringeva": "astringere",
    "astringevamo": "astringere",
    "astringevan": "astringere",
    "astringevano": "astringere",
    "astringevate": "astringere",
    "astringevi": "astringere",
    "astringevo": "astringere",
    "astringi": "astringere",
    "astringiamo": "astringere",
    "astringiate": "astringere",
    "astringo": "astringere",
    "astringon": "astringere",
    "astringono": "astringere",
    "astrinser": "astringere",
    "astrinsero": "astringere",
    "astrinsi": "astringere",
    "astrinsè": "astringere",
    "astrinta": "astringere",
    "astrinte": "astringere",
    "astrinti": "astringere",
    "astrinto": "astringere",
    "astrofisica": "astrofisico",
    "astrofisiche": "astrofisico",
    "astrofisici": "astrofisico",
    "astrologa": "astrologare",
    "astrologai": "astrologare",
    "astrologammo": "astrologare",
    "astrologan": "astrologare",
    "astrologando": "astrologare",
    "astrologano": "astrologare",
    "astrologante": "astrologare",
    "astrologanti": "astrologare",
    "astrologar": "astrologare",
    "astrologaron": "astrologare",
    "astrologarono": "astrologare",
    "astrologasse": "astrologare",
    "astrologasser": "astrologare",
    "astrologassero": "astrologare",
    "astrologassi": "astrologare",
    "astrologassimo": "astrologare",
    "astrologaste": "astrologare",
    "astrologasti": "astrologare",
    "astrologata": "astrologare",
    "astrologate": "astrologare",
    "astrologati": "astrologare",
    "astrologato": "astrologare",
    "astrologava": "astrologare",
    "astrologavamo": "astrologare",
    "astrologavan": "astrologare",
    "astrologavano": "astrologare",
    "astrologavate": "astrologare",
    "astrologavi": "astrologare",
    "astrologavo": "astrologare",
    "astrologhe": "astrologa",
    "astrologherai": "astrologare",
    "astrologheran": "astrologare",
    "astrologheranno": "astrologare",
    "astrologherebbe": "astrologare",
    "astrologherebber": "astrologare",
    "astrologherebbero": "astrologare",
    "astrologherei": "astrologare",
    "astrologheremmo": "astrologare",
    "astrologheremo": "astrologare",
    "astrologhereste": "astrologare",
    "astrologheresti": "astrologare",
    "astrologherete": "astrologare",
    "astrologherà": "astrologare",
    "astrologherò": "astrologare",
    "astrologhi": "astrologare",
    "astrologhiamo": "astrologare",
    "astrologhiate": "astrologare",
    "astrologhin": "astrologare",
    "astrologhino": "astrologare",
    "astrologi": "astrologo",
    "astrologica": "astrologico",
    "astrologiche": "astrologico",
    "astrologici": "astrologico",
    "astrologo": "astrologare",
    "astrologò": "astrologare",
    "astronauti": "astronauta",
    "astronautica": "astronautico",
    "astronautiche": "astronautico",
    "astronautici": "astronautico",
    "astronavi": "astronave",
    "astronomi": "astronomo",
    "astronomica": "astronomico",
    "astronomiche": "astronomico",
    "astronomici": "astronomico",
    "astrusa": "astruso",
    "astruse": "astruso",
    "astruserie": "astruseria",
    "astrusi": "astruso",
    "astucci": "astuccio",
    "astuta": "astuto",
    "astute": "astuto",
    "astuti": "astuto",
    "astuzie": "astuzia",
    "atalantini": "atalantino",
    "atavica": "atavico",
    "ataviche": "atavico",
    "atavici": "atavico",
    "atea": "ateo",
    "atee": "ateo",
    "atei": "ateo",
    "ateismi": "ateismo",
    "atenei": "ateneo",
    "ateniesi": "ateniese",
    "atesina": "atesino",
    "atesine": "atesino",
    "atesini": "atesino",
    "atipica": "atipico",
    "atipiche": "atipico",
    "atipici": "atipico",
    "atlanti": "atlante",
    "atlantica": "atlantico",
    "atlantiche": "atlantico",
    "atlantici": "atlantico",
    "atlete": "atleta",
    "atleti": "atleta",
    "atletica": "atletico",
    "atletiche": "atletico",
    "atletici": "atletico",
    "atmosfere": "atmosfera",
    "atmosferica": "atmosferico",
    "atmosferiche": "atmosferico",
    "atmosferici": "atmosferico",
    "atolli": "atollo",
    "atomi": "atomo",
    "atomica": "atomico",
    "atomiche": "atomico",
    "atomici": "atomico",
    "atomizza": "atomizzare",
    "atomizzai": "atomizzare",
    "atomizzammo": "atomizzare",
    "atomizzan": "atomizzare",
    "atomizzando": "atomizzare",
    "atomizzano": "atomizzare",
    "atomizzante": "atomizzare",
    "atomizzanti": "atomizzare",
    "atomizzar": "atomizzare",
    "atomizzaron": "atomizzare",
    "atomizzarono": "atomizzare",
    "atomizzasse": "atomizzare",
    "atomizzasser": "atomizzare",
    "atomizzassero": "atomizzare",
    "atomizzassi": "atomizzare",
    "atomizzassimo": "atomizzare",
    "atomizzaste": "atomizzare",
    "atomizzasti": "atomizzare",
    "atomizzata": "atomizzare",
    "atomizzate": "atomizzare",
    "atomizzati": "atomizzare",
    "atomizzato": "atomizzare",
    "atomizzava": "atomizzare",
    "atomizzavamo": "atomizzare",
    "atomizzavan": "atomizzare",
    "atomizzavano": "atomizzare",
    "atomizzavate": "atomizzare",
    "atomizzavi": "atomizzare",
    "atomizzavo": "atomizzare",
    "atomizzerai": "atomizzare",
    "atomizzeran": "atomizzare",
    "atomizzeranno": "atomizzare",
    "atomizzerebbe": "atomizzare",
    "atomizzerebber": "atomizzare",
    "atomizzerebbero": "atomizzare",
    "atomizzerei": "atomizzare",
    "atomizzeremmo": "atomizzare",
    "atomizzeremo": "atomizzare",
    "atomizzereste": "atomizzare",
    "atomizzeresti": "atomizzare",
    "atomizzerete": "atomizzare",
    "atomizzerà": "atomizzare",
    "atomizzerò": "atomizzare",
    "atomizzi": "atomizzare",
    "atomizziamo": "atomizzare",
    "atomizziate": "atomizzare",
    "atomizzin": "atomizzare",
    "atomizzino": "atomizzare",
    "atomizzo": "atomizzare",
    "atomizzò": "atomizzare",
    "atona": "atono",
    "atonali": "atonale",
    "atone": "atono",
    "atoni": "atono",
    "atri": "atrio",
    "atroci": "atroce",
    "atrofica": "atrofico",
    "atrofiche": "atrofico",
    "atrofici": "atrofico",
    "atrofizza": "atrofizzare",
    "atrofizzai": "atrofizzare",
    "atrofizzammo": "atrofizzare",
    "atrofizzan": "atrofizzare",
    "atrofizzando": "atrofizzare",
    "atrofizzano": "atrofizzare",
    "atrofizzante": "atrofizzare",
    "atrofizzanti": "atrofizzare",
    "atrofizzar": "atrofizzare",
    "atrofizzaron": "atrofizzare",
    "atrofizzarono": "atrofizzare",
    "atrofizzasse": "atrofizzare",
    "atrofizzasser": "atrofizzare",
    "atrofizzassero": "atrofizzare",
    "atrofizzassi": "atrofizzare",
    "atrofizzassimo": "atrofizzare",
    "atrofizzaste": "atrofizzare",
    "atrofizzasti": "atrofizzare",
    "atrofizzata": "atrofizzare",
    "atrofizzate": "atrofizzare",
    "atrofizzati": "atrofizzare",
    "atrofizzato": "atrofizzare",
    "atrofizzava": "atrofizzare",
    "atrofizzavamo": "atrofizzare",
    "atrofizzavan": "atrofizzare",
    "atrofizzavano": "atrofizzare",
    "atrofizzavate": "atrofizzare",
    "atrofizzavi": "atrofizzare",
    "atrofizzavo": "atrofizzare",
    "atrofizzerai": "atrofizzare",
    "atrofizzeran": "atrofizzare",
    "atrofizzeranno": "atrofizzare",
    "atrofizzerebbe": "atrofizzare",
    "atrofizzerebber": "atrofizzare",
    "atrofizzerebbero": "atrofizzare",
    "atrofizzerei": "atrofizzare",
    "atrofizzeremmo": "atrofizzare",
    "atrofizzeremo": "atrofizzare",
    "atrofizzereste": "atrofizzare",
    "atrofizzeresti": "atrofizzare",
    "atrofizzerete": "atrofizzare",
    "atrofizzerà": "atrofizzare",
    "atrofizzerò": "atrofizzare",
    "atrofizzi": "atrofizzare",
    "atrofizziamo": "atrofizzare",
    "atrofizziate": "atrofizzare",
    "atrofizzin": "atrofizzare",
    "atrofizzino": "atrofizzare",
    "atrofizzo": "atrofizzare",
    "atrofizzò": "atrofizzare",
    "atta": "atto",
    "attacca": "attaccare",
    "attaccai": "attaccare",
    "attaccamenti": "attaccamento",
    "attaccammo": "attaccare",
    "attaccan": "attaccare",
    "attaccando": "attaccare",
    "attaccano": "attaccare",
    "attaccante": "attaccare",
    "attaccanti": "attaccare",
    "attaccar": "attaccare",
    "attaccaron": "attaccare",
    "attaccarono": "attaccare",
    "attaccasse": "attaccare",
    "attaccasser": "attaccare",
    "attaccassero": "attaccare",
    "attaccassi": "attaccare",
    "attaccassimo": "attaccare",
    "attaccaste": "attaccare",
    "attaccasti": "attaccare",
    "attaccata": "attaccato",
    "attaccate": "attaccato",
    "attaccati": "attaccato",
    "attaccato": "attaccare",
    "attaccava": "attaccare",
    "attaccavamo": "attaccare",
    "attaccavan": "attaccare",
    "attaccavano": "attaccare",
    "attaccavate": "attaccare",
    "attaccavi": "attaccare",
    "attaccavo": "attaccare",
    "attaccherai": "attaccare",
    "attaccheran": "attaccare",
    "attaccheranno": "attaccare",
    "attaccherebbe": "attaccare",
    "attaccherebber": "attaccare",
    "attaccherebbero": "attaccare",
    "attaccherei": "attaccare",
    "attaccheremmo": "attaccare",
    "attaccheremo": "attaccare",
    "attacchereste": "attaccare",
    "attaccheresti": "attaccare",
    "attaccherete": "attaccare",
    "attaccherà": "attaccare",
    "attaccherò": "attaccare",
    "attacchi": "attacco",
    "attacchiamo": "attaccare",
    "attacchiate": "attaccare",
    "attacchin": "attaccare",
    "attacchino": "attaccare",
    "attacco": "attaccare",
    "attaccò": "attaccare",
    "attagli": "attagliare",
    "attaglia": "attagliare",
    "attagliai": "attagliare",
    "attagliammo": "attagliare",
    "attagliamo": "attagliare",
    "attaglian": "attagliare",
    "attagliando": "attagliare",
    "attagliano": "attagliare",
    "attagliar": "attagliare",
    "attagliaron": "attagliare",
    "attagliarono": "attagliare",
    "attagliasse": "attagliare",
    "attagliasser": "attagliare",
    "attagliassero": "attagliare",
    "attagliassi": "attagliare",
    "attagliassimo": "attagliare",
    "attagliaste": "attagliare",
    "attagliasti": "attagliare",
    "attagliata": "attagliare",
    "attagliate": "attagliare",
    "attagliati": "attagliare",
    "attagliato": "attagliare",
    "attagliava": "attagliare",
    "attagliavamo": "attagliare",
    "attagliavan": "attagliare",
    "attagliavano": "attagliare",
    "attagliavate": "attagliare",
    "attagliavi": "attagliare",
    "attagliavo": "attagliare",
    "attaglierai": "attagliare",
    "attaglieran": "attagliare",
    "attaglieranno": "attagliare",
    "attaglierebbe": "attagliare",
    "attaglierebber": "attagliare",
    "attaglierebbero": "attagliare",
    "attaglierei": "attagliare",
    "attaglieremmo": "attagliare",
    "attaglieremo": "attagliare",
    "attagliereste": "attagliare",
    "attaglieresti": "attagliare",
    "attaglierete": "attagliare",
    "attaglierà": "attagliare",
    "attaglierò": "attagliare",
    "attaglin": "attagliare",
    "attaglino": "attagliare",
    "attaglio": "attagliare",
    "attagliò": "attagliare",
    "attanagli": "attanagliare",
    "attanaglia": "attanagliare",
    "attanagliai": "attanagliare",
    "attanagliammo": "attanagliare",
    "attanagliamo": "attanagliare",
    "attanaglian": "attanagliare",
    "attanagliando": "attanagliare",
    "attanagliano": "attanagliare",
    "attanagliante": "attanagliare",
    "attanaglianti": "attanagliare",
    "attanagliar": "attanagliare",
    "attanagliaron": "attanagliare",
    "attanagliarono": "attanagliare",
    "attanagliasse": "attanagliare",
    "attanagliasser": "attanagliare",
    "attanagliassero": "attanagliare",
    "attanagliassi": "attanagliare",
    "attanagliassimo": "attanagliare",
    "attanagliaste": "attanagliare",
    "attanagliasti": "attanagliare",
    "attanagliata": "attanagliare",
    "attanagliate": "attanagliare",
    "attanagliati": "attanagliare",
    "attanagliato": "attanagliare",
    "attanagliava": "attanagliare",
    "attanagliavamo": "attanagliare",
    "attanagliavan": "attanagliare",
    "attanagliavano": "attanagliare",
    "attanagliavate": "attanagliare",
    "attanagliavi": "attanagliare",
    "attanagliavo": "attanagliare",
    "attanaglierai": "attanagliare",
    "attanaglieran": "attanagliare",
    "attanaglieranno": "attanagliare",
    "attanaglierebbe": "attanagliare",
    "attanaglierebber": "attanagliare",
    "attanaglierebbero": "attanagliare",
    "attanaglierei": "attanagliare",
    "attanaglieremmo": "attanagliare",
    "attanaglieremo": "attanagliare",
    "attanagliereste": "attanagliare",
    "attanaglieresti": "attanagliare",
    "attanaglierete": "attanagliare",
    "attanaglierà": "attanagliare",
    "attanaglierò": "attanagliare",
    "attanaglin": "attanagliare",
    "attanaglino": "attanagliare",
    "attanaglio": "attanagliare",
    "attanagliò": "attanagliare",
    "attarda": "attardare",
    "attardai": "attardare",
    "attardammo": "attardare",
    "attardan": "attardare",
    "attardando": "attardare",
    "attardano": "attardare",
    "attardante": "attardare",
    "attardanti": "attardare",
    "attardar": "attardare",
    "attardaron": "attardare",
    "attardarono": "attardare",
    "attardasse": "attardare",
    "attardasser": "attardare",
    "attardassero": "attardare",
    "attardassi": "attardare",
    "attardassimo": "attardare",
    "attardaste": "attardare",
    "attardasti": "attardare",
    "attardata": "attardare",
    "attardate": "attardare",
    "attardati": "attardare",
    "attardato": "attardare",
    "attardava": "attardare",
    "attardavamo": "attardare",
    "attardavan": "attardare",
    "attardavano": "attardare",
    "attardavate": "attardare",
    "attardavi": "attardare",
    "attardavo": "attardare",
    "attarderai": "attardare",
    "attarderan": "attardare",
    "attarderanno": "attardare",
    "attarderebbe": "attardare",
    "attarderebber": "attardare",
    "attarderebbero": "attardare",
    "attarderei": "attardare",
    "attarderemmo": "attardare",
    "attarderemo": "attardare",
    "attardereste": "attardare",
    "attarderesti": "attardare",
    "attarderete": "attardare",
    "attarderà": "attardare",
    "attarderò": "attardare",
    "attardi": "attardare",
    "attardiamo": "attardare",
    "attardiate": "attardare",
    "attardin": "attardare",
    "attardino": "attardare",
    "attardo": "attardare",
    "attardò": "attardare",
    "atte": "atto",
    "attecchendo": "attecchire",
    "attecchente": "attecchire",
    "attecchenti": "attecchire",
    "attecchiamo": "attecchire",
    "attecchiate": "attecchire",
    "attecchii": "attecchire",
    "attecchimmo": "attecchire",
    "attecchir": "attecchire",
    "attecchirai": "attecchire",
    "attecchiran": "attecchire",
    "attecchiranno": "attecchire",
    "attecchirebbe": "attecchire",
    "attecchirebber": "attecchire",
    "attecchirebbero": "attecchire",
    "attecchirei": "attecchire",
    "attecchiremmo": "attecchire",
    "attecchiremo": "attecchire",
    "attecchireste": "attecchire",
    "attecchiresti": "attecchire",
    "attecchirete": "attecchire",
    "attecchiron": "attecchire",
    "attecchirono": "attecchire",
    "attecchirà": "attecchire",
    "attecchirò": "attecchire",
    "attecchisca": "attecchire",
    "attecchiscan": "attecchire",
    "attecchiscano": "attecchire",
    "attecchisce": "attecchire",
    "attecchisci": "attecchire",
    "attecchisco": "attecchire",
    "attecchiscon": "attecchire",
    "attecchiscono": "attecchire",
    "attecchisse": "attecchire",
    "attecchisser": "attecchire",
    "attecchissero": "attecchire",
    "attecchissi": "attecchire",
    "attecchissimo": "attecchire",
    "attecchiste": "attecchire",
    "attecchisti": "attecchire",
    "attecchita": "attecchire",
    "attecchite": "attecchire",
    "attecchiti": "attecchire",
    "attecchito": "attecchire",
    "attecchiva": "attecchire",
    "attecchivamo": "attecchire",
    "attecchivan": "attecchire",
    "attecchivano": "attecchire",
    "attecchivate": "attecchire",
    "attecchivi": "attecchire",
    "attecchivo": "attecchire",
    "attecchì": "attecchire",
    "atteggerai": "atteggiare",
    "atteggeran": "atteggiare",
    "atteggeranno": "atteggiare",
    "atteggerebbe": "atteggiare",
    "atteggerebber": "atteggiare",
    "atteggerebbero": "atteggiare",
    "atteggerei": "atteggiare",
    "atteggeremmo": "atteggiare",
    "atteggeremo": "atteggiare",
    "atteggereste": "atteggiare",
    "atteggeresti": "atteggiare",
    "atteggerete": "atteggiare",
    "atteggerà": "atteggiare",
    "atteggerò": "atteggiare",
    "atteggi": "atteggiare",
    "atteggia": "atteggiare",
    "atteggiai": "atteggiare",
    "atteggiamenti": "atteggiamento",
    "atteggiammo": "atteggiare",
    "atteggiamo": "atteggiare",
    "atteggian": "atteggiare",
    "atteggiando": "atteggiare",
    "atteggiano": "atteggiare",
    "atteggiante": "atteggiare",
    "atteggianti": "atteggiare",
    "atteggiar": "atteggiare",
    "atteggiaron": "atteggiare",
    "atteggiarono": "atteggiare",
    "atteggiasse": "atteggiare",
    "atteggiasser": "atteggiare",
    "atteggiassero": "atteggiare",
    "atteggiassi": "atteggiare",
    "atteggiassimo": "atteggiare",
    "atteggiaste": "atteggiare",
    "atteggiasti": "atteggiare",
    "atteggiata": "atteggiare",
    "atteggiate": "atteggiare",
    "atteggiati": "atteggiare",
    "atteggiato": "atteggiare",
    "atteggiava": "atteggiare",
    "atteggiavamo": "atteggiare",
    "atteggiavan": "atteggiare",
    "atteggiavano": "atteggiare",
    "atteggiavate": "atteggiare",
    "atteggiavi": "atteggiare",
    "atteggiavo": "atteggiare",
    "atteggin": "atteggiare",
    "atteggino": "atteggiare",
    "atteggio": "atteggiare",
    "atteggiò": "atteggiare",
    "attempata": "attempato",
    "attempate": "attempato",
    "attempati": "attempato",
    "attenda": "attendere",
    "attendai": "attendare",
    "attendammo": "attendare",
    "attendan": "attendere",
    "attendando": "attendare",
    "attendano": "attendere",
    "attendar": "attendare",
    "attendaron": "attendare",
    "attendarono": "attendare",
    "attendasse": "attendare",
    "attendasser": "attendare",
    "attendassero": "attendare",
    "attendassi": "attendare",
    "attendassimo": "attendare",
    "attendaste": "attendare",
    "attendasti": "attendare",
    "attendata": "attendare",
    "attendate": "attendare",
    "attendati": "attendare",
    "attendato": "attendare",
    "attendava": "attendare",
    "attendavamo": "attendare",
    "attendavan": "attendare",
    "attendavano": "attendare",
    "attendavate": "attendare",
    "attendavi": "attendare",
    "attendavo": "attendare",
    "attende": "attendere",
    "attendemmo": "attendere",
    "attendendo": "attendere",
    "attendente": "attendere",
    "attendenti": "attendere",
    "attender": "attendere",
    "attenderai": "attendere",
    "attenderan": "attendere",
    "attenderanno": "attendere",
    "attenderebbe": "attendere",
    "attenderebber": "attendere",
    "attenderebbero": "attendere",
    "attenderei": "attendere",
    "attenderemmo": "attendere",
    "attenderemo": "attendere",
    "attendereste": "attendere",
    "attenderesti": "attendere",
    "attenderete": "attendere",
    "attenderà": "attendere",
    "attenderò": "attendere",
    "attendesse": "attendere",
    "attendesser": "attendere",
    "attendessero": "attendere",
    "attendessi": "attendere",
    "attendessimo": "attendere",
    "attendeste": "attendere",
    "attendesti": "attendere",
    "attendete": "attendere",
    "attendeva": "attendere",
    "attendevamo": "attendere",
    "attendevan": "attendere",
    "attendevano": "attendere",
    "attendevate": "attendere",
    "attendevi": "attendere",
    "attendevo": "attendere",
    "attendi": "attendere",
    "attendiamo": "attendere",
    "attendiate": "attendere",
    "attendibili": "attendibile",
    "attendin": "attendare",
    "attendino": "attendare",
    "attendo": "attendere",
    "attendon": "attendere",
    "attendono": "attendere",
    "attendò": "attendare",
    "attenemmo": "attenere",
    "attenendo": "attenere",
    "attenente": "attenere",
    "attenenti": "attenere",
    "attener": "attenere",
    "attenesse": "attenere",
    "attenesser": "attenere",
    "attenessero": "attenere",
    "attenessi": "attenere",
    "attenessimo": "attenere",
    "atteneste": "attenere",
    "attenesti": "attenere",
    "attenete": "attenere",
    "atteneva": "attenere",
    "attenevamo": "attenere",
    "attenevan": "attenere",
    "attenevano": "attenere",
    "attenevate": "attenere",
    "attenevi": "attenere",
    "attenevo": "attenere",
    "attenga": "attenere",
    "attengan": "attenere",
    "attengano": "attenere",
    "attengo": "attenere",
    "attengon": "attenere",
    "attengono": "attenere",
    "atteniamo": "attenere",
    "atteniate": "attenere",
    "attenne": "attenere",
    "attenner": "attenere",
    "attennero": "attenere",
    "attenni": "attenere",
    "attenta": "attento",
    "attentai": "attentare",
    "attentammo": "attentare",
    "attentan": "attentare",
    "attentando": "attentare",
    "attentano": "attentare",
    "attentante": "attentare",
    "attentanti": "attentare",
    "attentar": "attentare",
    "attentaron": "attentare",
    "attentarono": "attentare",
    "attentasse": "attentare",
    "attentasser": "attentare",
    "attentassero": "attentare",
    "attentassi": "attentare",
    "attentassimo": "attentare",
    "attentaste": "attentare",
    "attentasti": "attentare",
    "attentata": "attentare",
    "attentate": "attentare",
    "attentati": "attentato",
    "attentato": "attentare",
    "attentatori": "attentatore",
    "attentava": "attentare",
    "attentavamo": "attentare",
    "attentavan": "attentare",
    "attentavano": "attentare",
    "attentavate": "attentare",
    "attentavi": "attentare",
    "attentavo": "attentare",
    "attente": "attento",
    "attenterai": "attentare",
    "attenteran": "attentare",
    "attenteranno": "attentare",
    "attenterebbe": "attentare",
    "attenterebber": "attentare",
    "attenterebbero": "attentare",
    "attenterei": "attentare",
    "attenteremmo": "attentare",
    "attenteremo": "attentare",
    "attentereste": "attentare",
    "attenteresti": "attentare",
    "attenterete": "attentare",
    "attenterà": "attentare",
    "attenterò": "attentare",
    "attenti": "attento",
    "attentiamo": "attentare",
    "attentiate": "attentare",
    "attentin": "attentare",
    "attentino": "attentare",
    "attento": "attentare",
    "attentò": "attentare",
    "attenua": "attenuare",
    "attenuai": "attenuare",
    "attenuammo": "attenuare",
    "attenuan": "attenuare",
    "attenuando": "attenuare",
    "attenuano": "attenuare",
    "attenuante": "attenuare",
    "attenuanti": "attenuare",
    "attenuar": "attenuare",
    "attenuaron": "attenuare",
    "attenuarono": "attenuare",
    "attenuasse": "attenuare",
    "attenuasser": "attenuare",
    "attenuassero": "attenuare",
    "attenuassi": "attenuare",
    "attenuassimo": "attenuare",
    "attenuaste": "attenuare",
    "attenuasti": "attenuare",
    "attenuata": "attenuare",
    "attenuate": "attenuare",
    "attenuati": "attenuare",
    "attenuato": "attenuare",
    "attenuava": "attenuare",
    "attenuavamo": "attenuare",
    "attenuavan": "attenuare",
    "attenuavano": "attenuare",
    "attenuavate": "attenuare",
    "attenuavi": "attenuare",
    "attenuavo": "attenuare",
    "attenuazioni": "attenuazione",
    "attenuerai": "attenuare",
    "attenueran": "attenuare",
    "attenueranno": "attenuare",
    "attenuerebbe": "attenuare",
    "attenuerebber": "attenuare",
    "attenuerebbero": "attenuare",
    "attenuerei": "attenuare",
    "attenueremmo": "attenuare",
    "attenueremo": "attenuare",
    "attenuereste": "attenuare",
    "attenueresti": "attenuare",
    "attenuerete": "attenuare",
    "attenuerà": "attenuare",
    "attenuerò": "attenuare",
    "attenui": "attenuare",
    "attenuiamo": "attenuare",
    "attenuiate": "attenuare",
    "attenuin": "attenuare",
    "attenuino": "attenuare",
    "attenuo": "attenuare",
    "attenuta": "attenere",
    "attenute": "attenere",
    "attenuti": "attenere",
    "attenuto": "attenere",
    "attenuò": "attenuare",
    "attenzioni": "attenzione",
    "atterra": "atterrare",
    "atterraggi": "atterraggio",
    "atterrai": "atterrare",
    "atterramenti": "atterramento",
    "atterrammo": "atterrare",
    "atterran": "atterrare",
    "atterrando": "atterrare",
    "atterranno": "attenere",
    "atterrano": "atterrare",
    "atterrante": "atterrare",
    "atterranti": "atterrare",
    "atterrar": "atterrare",
    "atterraron": "atterrare",
    "atterrarono": "atterrare",
    "atterrasse": "atterrare",
    "atterrasser": "atterrare",
    "atterrassero": "atterrare",
    "atterrassi": "atterrare",
    "atterrassimo": "atterrare",
    "atterraste": "atterrare",
    "atterrasti": "atterrare",
    "atterrata": "atterrare",
    "atterrate": "atterrare",
    "atterrati": "atterrare",
    "atterrato": "atterrare",
    "atterrava": "atterrare",
    "atterravamo": "atterrare",
    "atterravan": "atterrare",
    "atterravano": "atterrare",
    "atterravate": "atterrare",
    "atterravi": "atterrare",
    "atterravo": "atterrare",
    "atterrebbe": "attenere",
    "atterrebber": "attenere",
    "atterrebbero": "attenere",
    "atterrei": "attenere",
    "atterremmo": "attenere",
    "atterremo": "attenere",
    "atterrendo": "atterrire",
    "atterrente": "atterrire",
    "atterrenti": "atterrire",
    "atterrerai": "atterrare",
    "atterreran": "atterrare",
    "atterreranno": "atterrare",
    "atterrerebbe": "atterrare",
    "atterrerebber": "atterrare",
    "atterrerebbero": "atterrare",
    "atterrerei": "atterrare",
    "atterreremmo": "atterrare",
    "atterreremo": "atterrare",
    "atterrereste": "atterrare",
    "atterreresti": "atterrare",
    "atterrerete": "atterrare",
    "atterrerà": "atterrare",
    "atterrerò": "atterrare",
    "atterreste": "attenere",
    "atterresti": "attenere",
    "atterrete": "attenere",
    "atterri": "atterrare",
    "atterriamo": "atterrire",
    "atterriate": "atterrire",
    "atterrii": "atterrire",
    "atterrimmo": "atterrire",
    "atterrin": "atterrare",
    "atterrino": "atterrare",
    "atterrir": "atterrire",
    "atterrirai": "atterrire",
    "atterriran": "atterrire",
    "atterriranno": "atterrire",
    "atterrirebbe": "atterrire",
    "atterrirebber": "atterrire",
    "atterrirebbero": "atterrire",
    "atterrirei": "atterrire",
    "atterriremmo": "atterrire",
    "atterriremo": "atterrire",
    "atterrireste": "atterrire",
    "atterriresti": "atterrire",
    "atterrirete": "atterrire",
    "atterriron": "atterrire",
    "atterrirono": "atterrire",
    "atterrirà": "atterrire",
    "atterrirò": "atterrire",
    "atterrisca": "atterrire",
    "atterriscan": "atterrire",
    "atterriscano": "atterrire",
    "atterrisce": "atterrire",
    "atterrisci": "atterrire",
    "atterrisco": "atterrire",
    "atterriscon": "atterrire",
    "atterriscono": "atterrire",
    "atterrisse": "atterrire",
    "atterrisser": "atterrire",
    "atterrissero": "atterrire",
    "atterrissi": "atterrire",
    "atterrissimo": "atterrire",
    "atterriste": "atterrire",
    "atterristi": "atterrire",
    "atterrita": "atterrire",
    "atterrite": "atterrire",
    "atterriti": "atterrire",
    "atterrito": "atterrire",
    "atterriva": "atterrire",
    "atterrivamo": "atterrire",
    "atterrivan": "atterrire",
    "atterrivano": "atterrire",
    "atterrivate": "atterrire",
    "atterrivi": "atterrire",
    "atterrivo": "atterrire",
    "atterro": "atterrare",
    "atterrà": "attenere",
    "atterrì": "atterrire",
    "atterrò": "atterrare",
    "attesa": "atteso",
    "attese": "atteso",
    "atteser": "attendere",
    "attesero": "attendere",
    "attesi": "atteso",
    "atteso": "attendere",
    "attesta": "attestare",
    "attestai": "attestare",
    "attestammo": "attestare",
    "attestan": "attestare",
    "attestando": "attestare",
    "attestano": "attestare",
    "attestante": "attestare",
    "attestanti": "attestare",
    "attestar": "attestare",
    "attestaron": "attestare",
    "attestarono": "attestare",
    "attestasse": "attestare",
    "attestasser": "attestare",
    "attestassero": "attestare",
    "attestassi": "attestare",
    "attestassimo": "attestare",
    "attestaste": "attestare",
    "attestasti": "attestare",
    "attestata": "attestare",
    "attestate": "attestare",
    "attestati": "attestato",
    "attestato": "attestare",
    "attestava": "attestare",
    "attestavamo": "attestare",
    "attestavan": "attestare",
    "attestavano": "attestare",
    "attestavate": "attestare",
    "attestavi": "attestare",
    "attestavo": "attestare",
    "attestazioni": "attestazione",
    "attesterai": "attestare",
    "attesteran": "attestare",
    "attesteranno": "attestare",
    "attesterebbe": "attestare",
    "attesterebber": "attestare",
    "attesterebbero": "attestare",
    "attesterei": "attestare",
    "attesteremmo": "attestare",
    "attesteremo": "attestare",
    "attestereste": "attestare",
    "attesteresti": "attestare",
    "attesterete": "attestare",
    "attesterà": "attestare",
    "attesterò": "attestare",
    "attesti": "attestare",
    "attestiamo": "attestare",
    "attestiate": "attestare",
    "attestin": "attestare",
    "attestino": "attestare",
    "attesto": "attestare",
    "attestò": "attestare",
    "attesè": "attendere",
    "atti": "atto",
    "atticciata": "atticciato",
    "atticciate": "atticciato",
    "atticciati": "atticciato",
    "attiene": "attenere",
    "attieni": "attenere",
    "attigua": "attiguo",
    "attigue": "attiguo",
    "attigui": "attiguo",
    "attilla": "attillare",
    "attillai": "attillare",
    "attillammo": "attillare",
    "attillan": "attillare",
    "attillando": "attillare",
    "attillano": "attillare",
    "attillante": "attillare",
    "attillanti": "attillare",
    "attillar": "attillare",
    "attillaron": "attillare",
    "attillarono": "attillare",
    "attillasse": "attillare",
    "attillasser": "attillare",
    "attillassero": "attillare",
    "attillassi": "attillare",
    "attillassimo": "attillare",
    "attillaste": "attillare",
    "attillasti": "attillare",
    "attillata": "attillato",
    "attillate": "attillato",
    "attillati": "attillato",
    "attillato": "attillare",
    "attillava": "attillare",
    "attillavamo": "attillare",
    "attillavan": "attillare",
    "attillavano": "attillare",
    "attillavate": "attillare",
    "attillavi": "attillare",
    "attillavo": "attillare",
    "attillerai": "attillare",
    "attilleran": "attillare",
    "attilleranno": "attillare",
    "attillerebbe": "attillare",
    "attillerebber": "attillare",
    "attillerebbero": "attillare",
    "attillerei": "attillare",
    "attilleremmo": "attillare",
    "attilleremo": "attillare",
    "attillereste": "attillare",
    "attilleresti": "attillare",
    "attillerete": "attillare",
    "attillerà": "attillare",
    "attillerò": "attillare",
    "attilli": "attillare",
    "attilliamo": "attillare",
    "attilliate": "attillare",
    "attillin": "attillare",
    "attillino": "attillare",
    "attillo": "attillare",
    "attillò": "attillare",
    "attimi": "attimo",
    "attinenti": "attinente",
    "attinenze": "attinenza",
    "attinga": "attingere",
    "attingan": "attingere",
    "attingano": "attingere",
    "attinge": "attingere",
    "attingemmo": "attingere",
    "attingendo": "attingere",
    "attingente": "attingere",
    "attingenti": "attingere",
    "attinger": "attingere",
    "attingerai": "attingere",
    "attingeran": "attingere",
    "attingeranno": "attingere",
    "attingerebbe": "attingere",
    "attingerebber": "attingere",
    "attingerebbero": "attingere",
    "attingerei": "attingere",
    "attingeremmo": "attingere",
    "attingeremo": "attingere",
    "attingereste": "attingere",
    "attingeresti": "attingere",
    "attingerete": "attingere",
    "attingerà": "attingere",
    "attingerò": "attingere",
    "attingesse": "attingere",
    "attingesser": "attingere",
    "attingessero": "attingere",
    "attingessi": "attingere",
    "attingessimo": "attingere",
    "attingeste": "attingere",
    "attingesti": "attingere",
    "attingete": "attingere",
    "attingeva": "attingere",
    "attingevamo": "attingere",
    "attingevan": "attingere",
    "attingevano": "attingere",
    "attingevate": "attingere",
    "attingevi": "attingere",
    "attingevo": "attingere",
    "attingi": "attingere",
    "attingiamo": "attingere",
    "attingiate": "attingere",
    "attingo": "attingere",
    "attingon": "attingere",
    "attingono": "attingere",
    "attinser": "attingere",
    "attinsero": "attingere",
    "attinsi": "attingere",
    "attinsè": "attingere",
    "attinta": "attingere",
    "attinte": "attingere",
    "attinti": "attingere",
    "attinto": "attingere",
    "attira": "attirare",
    "attirai": "attirare",
    "attirammo": "attirare",
    "attiran": "attirare",
    "attirando": "attirare",
    "attirano": "attirare",
    "attirante": "attirare",
    "attiranti": "attirare",
    "attirar": "attirare",
    "attiraron": "attirare",
    "attirarono": "attirare",
    "attirasse": "attirare",
    "attirasser": "attirare",
    "attirassero": "attirare",
    "attirassi": "attirare",
    "attirassimo": "attirare",
    "attiraste": "attirare",
    "attirasti": "attirare",
    "attirata": "attirare",
    "attirate": "attirare",
    "attirati": "attirare",
    "attirato": "attirare",
    "attirava": "attirare",
    "attiravamo": "attirare",
    "attiravan": "attirare",
    "attiravano": "attirare",
    "attiravate": "attirare",
    "attiravi": "attirare",
    "attiravo": "attirare",
    "attirerai": "attirare",
    "attireran": "attirare",
    "attireranno": "attirare",
    "attirerebbe": "attirare",
    "attirerebber": "attirare",
    "attirerebbero": "attirare",
    "attirerei": "attirare",
    "attireremmo": "attirare",
    "attireremo": "attirare",
    "attirereste": "attirare",
    "attireresti": "attirare",
    "attirerete": "attirare",
    "attirerà": "attirare",
    "attirerò": "attirare",
    "attiri": "attirare",
    "attiriamo": "attirare",
    "attiriate": "attirare",
    "attirin": "attirare",
    "attirino": "attirare",
    "attiro": "attirare",
    "attirò": "attirare",
    "attitudinali": "attitudinale",
    "attitudini": "attitudine",
    "attiva": "attivo",
    "attivai": "attivare",
    "attivammo": "attivare",
    "attivan": "attivare",
    "attivando": "attivare",
    "attivano": "attivare",
    "attivante": "attivare",
    "attivanti": "attivare",
    "attivar": "attivare",
    "attivaron": "attivare",
    "attivarono": "attivare",
    "attivasse": "attivare",
    "attivasser": "attivare",
    "attivassero": "attivare",
    "attivassi": "attivare",
    "attivassimo": "attivare",
    "attivaste": "attivare",
    "attivasti": "attivare",
    "attivata": "attivare",
    "attivate": "attivare",
    "attivati": "attivare",
    "attivato": "attivare",
    "attivatori": "attivatore",
    "attivava": "attivare",
    "attivavamo": "attivare",
    "attivavan": "attivare",
    "attivavano": "attivare",
    "attivavate": "attivare",
    "attivavi": "attivare",
    "attivavo": "attivare",
    "attivazioni": "attivazione",
    "attive": "attivo",
    "attiverai": "attivare",
    "attiveran": "attivare",
    "attiveranno": "attivare",
    "attiverebbe": "attivare",
    "attiverebber": "attivare",
    "attiverebbero": "attivare",
    "attiverei": "attivare",
    "attiveremmo": "attivare",
    "attiveremo": "attivare",
    "attivereste": "attivare",
    "attiveresti": "attivare",
    "attiverete": "attivare",
    "attiverà": "attivare",
    "attiverò": "attivare",
    "attivi": "attivo",
    "attiviamo": "attivare",
    "attiviate": "attivare",
    "attivin": "attivare",
    "attivino": "attivare",
    "attivismi": "attivismo",
    "attiviste": "attivista",
    "attivisti": "attivista",
    "attivistica": "attivistico",
    "attivistiche": "attivistico",
    "attivistici": "attivistico",
    "attivizza": "attivizzare",
    "attivizzai": "attivizzare",
    "attivizzammo": "attivizzare",
    "attivizzan": "attivizzare",
    "attivizzando": "attivizzare",
    "attivizzano": "attivizzare",
    "attivizzante": "attivizzare",
    "attivizzanti": "attivizzare",
    "attivizzar": "attivizzare",
    "attivizzaron": "attivizzare",
    "attivizzarono": "attivizzare",
    "attivizzasse": "attivizzare",
    "attivizzasser": "attivizzare",
    "attivizzassero": "attivizzare",
    "attivizzassi": "attivizzare",
    "attivizzassimo": "attivizzare",
    "attivizzaste": "attivizzare",
    "attivizzasti": "attivizzare",
    "attivizzata": "attivizzare",
    "attivizzate": "attivizzare",
    "attivizzati": "attivizzare",
    "attivizzato": "attivizzare",
    "attivizzava": "attivizzare",
    "attivizzavamo": "attivizzare",
    "attivizzavan": "attivizzare",
    "attivizzavano": "attivizzare",
    "attivizzavate": "attivizzare",
    "attivizzavi": "attivizzare",
    "attivizzavo": "attivizzare",
    "attivizzerai": "attivizzare",
    "attivizzeran": "attivizzare",
    "attivizzeranno": "attivizzare",
    "attivizzerebbe": "attivizzare",
    "attivizzerebber": "attivizzare",
    "attivizzerebbero": "attivizzare",
    "attivizzerei": "attivizzare",
    "attivizzeremmo": "attivizzare",
    "attivizzeremo": "attivizzare",
    "attivizzereste": "attivizzare",
    "attivizzeresti": "attivizzare",
    "attivizzerete": "attivizzare",
    "attivizzerà": "attivizzare",
    "attivizzerò": "attivizzare",
    "attivizzi": "attivizzare",
    "attivizziamo": "attivizzare",
    "attivizziate": "attivizzare",
    "attivizzin": "attivizzare",
    "attivizzino": "attivizzare",
    "attivizzo": "attivizzare",
    "attivizzò": "attivizzare",
    "attivo": "attivare",
    "attivò": "attivare",
    "attizza": "attizzare",
    "attizzai": "attizzare",
    "attizzammo": "attizzare",
    "attizzan": "attizzare",
    "attizzando": "attizzare",
    "attizzano": "attizzare",
    "attizzante": "attizzare",
    "attizzanti": "attizzare",
    "attizzar": "attizzare",
    "attizzaron": "attizzare",
    "attizzarono": "attizzare",
    "attizzasse": "attizzare",
    "attizzasser": "attizzare",
    "attizzassero": "attizzare",
    "attizzassi": "attizzare",
    "attizzassimo": "attizzare",
    "attizzaste": "attizzare",
    "attizzasti": "attizzare",
    "attizzata": "attizzare",
    "attizzate": "attizzare",
    "attizzati": "attizzare",
    "attizzato": "attizzare",
    "attizzava": "attizzare",
    "attizzavamo": "attizzare",
    "attizzavan": "attizzare",
    "attizzavano": "attizzare",
    "attizzavate": "attizzare",
    "attizzavi": "attizzare",
    "attizzavo": "attizzare",
    "attizzerai": "attizzare",
    "attizzeran": "attizzare",
    "attizzeranno": "attizzare",
    "attizzerebbe": "attizzare",
    "attizzerebber": "attizzare",
    "attizzerebbero": "attizzare",
    "attizzerei": "attizzare",
    "attizzeremmo": "attizzare",
    "attizzeremo": "attizzare",
    "attizzereste": "attizzare",
    "attizzeresti": "attizzare",
    "attizzerete": "attizzare",
    "attizzerà": "attizzare",
    "attizzerò": "attizzare",
    "attizzi": "attizzare",
    "attizziamo": "attizzare",
    "attizziate": "attizzare",
    "attizzin": "attizzare",
    "attizzino": "attizzare",
    "attizzo": "attizzare",
    "attizzò": "attizzare",
    "attonita": "attonito",
    "attonite": "attonito",
    "attoniti": "attonito",
    "attorca": "attorcere",
    "attorcan": "attorcere",
    "attorcano": "attorcere",
    "attorce": "attorcere",
    "attorcei": "attorcere",
    "attorcemmo": "attorcere",
    "attorcendo": "attorcere",
    "attorcente": "attorcere",
    "attorcenti": "attorcere",
    "attorcer": "attorcere",
    "attorcerai": "attorcere",
    "attorceran": "attorcere",
    "attorceranno": "attorcere",
    "attorcerebbe": "attorcere",
    "attorcerebber": "attorcere",
    "attorcerebbero": "attorcere",
    "attorcerei": "attorcere",
    "attorceremmo": "attorcere",
    "attorceremo": "attorcere",
    "attorcereste": "attorcere",
    "attorceresti": "attorcere",
    "attorcerete": "attorcere",
    "attorceron": "attorcere",
    "attorcerono": "attorcere",
    "attorcerà": "attorcere",
    "attorcerò": "attorcere",
    "attorcesse": "attorcere",
    "attorcesser": "attorcere",
    "attorcessero": "attorcere",
    "attorcessi": "attorcere",
    "attorcessimo": "attorcere",
    "attorceste": "attorcere",
    "attorcesti": "attorcere",
    "attorcete": "attorcere",
    "attorceva": "attorcere",
    "attorcevamo": "attorcere",
    "attorcevan": "attorcere",
    "attorcevano": "attorcere",
    "attorcevate": "attorcere",
    "attorcevi": "attorcere",
    "attorcevo": "attorcere",
    "attorci": "attorcere",
    "attorciamo": "attorcere",
    "attorciate": "attorcere",
    "attorcigli": "attorcigliare",
    "attorciglia": "attorcigliare",
    "attorcigliai": "attorcigliare",
    "attorcigliammo": "attorcigliare",
    "attorcigliamo": "attorcigliare",
    "attorciglian": "attorcigliare",
    "attorcigliando": "attorcigliare",
    "attorcigliano": "attorcigliare",
    "attorcigliante": "attorcigliare",
    "attorciglianti": "attorcigliare",
    "attorcigliar": "attorcigliare",
    "attorcigliaron": "attorcigliare",
    "attorcigliarono": "attorcigliare",
    "attorcigliasse": "attorcigliare",
    "attorcigliasser": "attorcigliare",
    "attorcigliassero": "attorcigliare",
    "attorcigliassi": "attorcigliare",
    "attorcigliassimo": "attorcigliare",
    "attorcigliaste": "attorcigliare",
    "attorcigliasti": "attorcigliare",
    "attorcigliata": "attorcigliare",
    "attorcigliate": "attorcigliare",
    "attorcigliati": "attorcigliare",
    "attorcigliato": "attorcigliare",
    "attorcigliava": "attorcigliare",
    "attorcigliavamo": "attorcigliare",
    "attorcigliavan": "attorcigliare",
    "attorcigliavano": "attorcigliare",
    "attorcigliavate": "attorcigliare",
    "attorcigliavi": "attorcigliare",
    "attorcigliavo": "attorcigliare",
    "attorciglierai": "attorcigliare",
    "attorciglieran": "attorcigliare",
    "attorciglieranno": "attorcigliare",
    "attorciglierebbe": "attorcigliare",
    "attorciglierebber": "attorcigliare",
    "attorciglierebbero": "attorcigliare",
    "attorciglierei": "attorcigliare",
    "attorciglieremmo": "attorcigliare",
    "attorciglieremo": "attorcigliare",
    "attorcigliereste": "attorcigliare",
    "attorciglieresti": "attorcigliare",
    "attorciglierete": "attorcigliare",
    "attorciglierà": "attorcigliare",
    "attorciglierò": "attorcigliare",
    "attorciglin": "attorcigliare",
    "attorciglino": "attorcigliare",
    "attorciglio": "attorcigliare",
    "attorcigliò": "attorcigliare",
    "attorco": "attorcere",
    "attorcon": "attorcere",
    "attorcono": "attorcere",
    "attorcuta": "attorcere",
    "attorcute": "attorcere",
    "attorcuti": "attorcere",
    "attorcuto": "attorcere",
    "attorcè": "attorcere",
    "attori": "attore",
    "attorni": "attorniare",
    "attornia": "attorniare",
    "attorniai": "attorniare",
    "attorniammo": "attorniare",
    "attorniamo": "attorniare",
    "attornian": "attorniare",
    "attorniando": "attorniare",
    "attorniano": "attorniare",
    "attorniante": "attorniare",
    "attornianti": "attorniare",
    "attorniar": "attorniare",
    "attorniaron": "attorniare",
    "attorniarono": "attorniare",
    "attorniasse": "attorniare",
    "attorniasser": "attorniare",
    "attorniassero": "attorniare",
    "attorniassi": "attorniare",
    "attorniassimo": "attorniare",
    "attorniaste": "attorniare",
    "attorniasti": "attorniare",
    "attorniata": "attorniare",
    "attorniate": "attorniare",
    "attorniati": "attorniare",
    "attorniato": "attorniare",
    "attorniava": "attorniare",
    "attorniavamo": "attorniare",
    "attorniavan": "attorniare",
    "attorniavano": "attorniare",
    "attorniavate": "attorniare",
    "attorniavi": "attorniare",
    "attorniavo": "attorniare",
    "attornierai": "attorniare",
    "attornieran": "attorniare",
    "attornieranno": "attorniare",
    "attornierebbe": "attorniare",
    "attornierebber": "attorniare",
    "attornierebbero": "attorniare",
    "attornierei": "attorniare",
    "attornieremmo": "attorniare",
    "attornieremo": "attorniare",
    "attorniereste": "attorniare",
    "attornieresti": "attorniare",
    "attornierete": "attorniare",
    "attornierà": "attorniare",
    "attornierò": "attorniare",
    "attornin": "attorniare",
    "attornino": "attorniare",
    "attornio": "attorniare",
    "attorniò": "attorniare",
    "attossica": "attossicare",
    "attossicai": "attossicare",
    "attossicammo": "attossicare",
    "attossican": "attossicare",
    "attossicando": "attossicare",
    "attossicano": "attossicare",
    "attossicante": "attossicare",
    "attossicanti": "attossicare",
    "attossicar": "attossicare",
    "attossicaron": "attossicare",
    "attossicarono": "attossicare",
    "attossicasse": "attossicare",
    "attossicasser": "attossicare",
    "attossicassero": "attossicare",
    "attossicassi": "attossicare",
    "attossicassimo": "attossicare",
    "attossicaste": "attossicare",
    "attossicasti": "attossicare",
    "attossicata": "attossicare",
    "attossicate": "attossicare",
    "attossicati": "attossicare",
    "attossicato": "attossicare",
    "attossicava": "attossicare",
    "attossicavamo": "attossicare",
    "attossicavan": "attossicare",
    "attossicavano": "attossicare",
    "attossicavate": "attossicare",
    "attossicavi": "attossicare",
    "attossicavo": "attossicare",
    "attossicherai": "attossicare",
    "attossicheran": "attossicare",
    "attossicheranno": "attossicare",
    "attossicherebbe": "attossicare",
    "attossicherebber": "attossicare",
    "attossicherebbero": "attossicare",
    "attossicherei": "attossicare",
    "attossicheremmo": "attossicare",
    "attossicheremo": "attossicare",
    "attossichereste": "attossicare",
    "attossicheresti": "attossicare",
    "attossicherete": "attossicare",
    "attossicherà": "attossicare",
    "attossicherò": "attossicare",
    "attossichi": "attossicare",
    "attossichiamo": "attossicare",
    "attossichiate": "attossicare",
    "attossichin": "attossicare",
    "attossichino": "attossicare",
    "attossico": "attossicare",
    "attossicò": "attossicare",
    "attracca": "attraccare",
    "attraccai": "attraccare",
    "attraccammo": "attraccare",
    "attraccan": "attraccare",
    "attraccando": "attraccare",
    "attraccano": "attraccare",
    "attraccante": "attraccare",
    "attraccanti": "attraccare",
    "attraccar": "attraccare",
    "attraccaron": "attraccare",
    "attraccarono": "attraccare",
    "attraccasse": "attraccare",
    "attraccasser": "attraccare",
    "attraccassero": "attraccare",
    "attraccassi": "attraccare",
    "attraccassimo": "attraccare",
    "attraccaste": "attraccare",
    "attraccasti": "attraccare",
    "attraccata": "attraccare",
    "attraccate": "attraccare",
    "attraccati": "attraccare",
    "attraccato": "attraccare",
    "attraccava": "attraccare",
    "attraccavamo": "attraccare",
    "attraccavan": "attraccare",
    "attraccavano": "attraccare",
    "attraccavate": "attraccare",
    "attraccavi": "attraccare",
    "attraccavo": "attraccare",
    "attraccherai": "attraccare",
    "attraccheran": "attraccare",
    "attraccheranno": "attraccare",
    "attraccherebbe": "attraccare",
    "attraccherebber": "attraccare",
    "attraccherebbero": "attraccare",
    "attraccherei": "attraccare",
    "attraccheremmo": "attraccare",
    "attraccheremo": "attraccare",
    "attracchereste": "attraccare",
    "attraccheresti": "attraccare",
    "attraccherete": "attraccare",
    "attraccherà": "attraccare",
    "attraccherò": "attraccare",
    "attracchi": "attracco",
    "attracchiamo": "attraccare",
    "attracchiate": "attraccare",
    "attracchin": "attraccare",
    "attracchino": "attraccare",
    "attracco": "attraccare",
    "attraccò": "attraccare",
    "attrae": "attrarre",
    "attraemmo": "attrarre",
    "attraendo": "attrarre",
    "attraente": "attrarre",
    "attraenti": "attrarre",
    "attraesse": "attrarre",
    "attraesser": "attrarre",
    "attraessero": "attrarre",
    "attraessi": "attrarre",
    "attraessimo": "attrarre",
    "attraeste": "attrarre",
    "attraesti": "attrarre",
    "attraete": "attrarre",
    "attraeva": "attrarre",
    "attraevamo": "attrarre",
    "attraevan": "attrarre",
    "attraevano": "attrarre",
    "attraevate": "attrarre",
    "attraevi": "attrarre",
    "attraevo": "attrarre",
    "attragga": "attrarre",
    "attraggan": "attrarre",
    "attraggano": "attrarre",
    "attraggo": "attrarre",
    "attraggon": "attrarre",
    "attraggono": "attrarre",
    "attrai": "attrarre",
    "attraiamo": "attrarre",
    "attraiate": "attrarre",
    "attrarr": "attrarre",
    "attrarrai": "attrarre",
    "attrarran": "attrarre",
    "attrarranno": "attrarre",
    "attrarrebbe": "attrarre",
    "attrarrebber": "attrarre",
    "attrarrebbero": "attrarre",
    "attrarrei": "attrarre",
    "attrarremmo": "attrarre",
    "attrarremo": "attrarre",
    "attrarreste": "attrarre",
    "attrarresti": "attrarre",
    "attrarrete": "attrarre",
    "attrarrà": "attrarre",
    "attrarrò": "attrarre",
    "attrasse": "attrarre",
    "attrasser": "attrarre",
    "attrassero": "attrarre",
    "attrassi": "attrarre",
    "attratta": "attrarre",
    "attratte": "attrarre",
    "attratti": "attrarre",
    "attrattiva": "attrattivo",
    "attrattive": "attrattivo",
    "attrattivi": "attrattivo",
    "attratto": "attrarre",
    "attraversa": "attraversare",
    "attraversai": "attraversare",
    "attraversamenti": "attraversamento",
    "attraversammo": "attraversare",
    "attraversan": "attraversare",
    "attraversando": "attraversare",
    "attraversano": "attraversare",
    "attraversante": "attraversare",
    "attraversanti": "attraversare",
    "attraversar": "attraversare",
    "attraversaron": "attraversare",
    "attraversarono": "attraversare",
    "attraversasse": "attraversare",
    "attraversasser": "attraversare",
    "attraversassero": "attraversare",
    "attraversassi": "attraversare",
    "attraversassimo": "attraversare",
    "attraversaste": "attraversare",
    "attraversasti": "attraversare",
    "attraversata": "attraversare",
    "attraversate": "attraversare",
    "attraversati": "attraversare",
    "attraversato": "attraversare",
    "attraversava": "attraversare",
    "attraversavamo": "attraversare",
    "attraversavan": "attraversare",
    "attraversavano": "attraversare",
    "attraversavate": "attraversare",
    "attraversavi": "attraversare",
    "attraversavo": "attraversare",
    "attraverserai": "attraversare",
    "attraverseran": "attraversare",
    "attraverseranno": "attraversare",
    "attraverserebbe": "attraversare",
    "attraverserebber": "attraversare",
    "attraverserebbero": "attraversare",
    "attraverserei": "attraversare",
    "attraverseremmo": "attraversare",
    "attraverseremo": "attraversare",
    "attraversereste": "attraversare",
    "attraverseresti": "attraversare",
    "attraverserete": "attraversare",
    "attraverserà": "attraversare",
    "attraverserò": "attraversare",
    "attraversi": "attraversare",
    "attraversiamo": "attraversare",
    "attraversiate": "attraversare",
    "attraversin": "attraversare",
    "attraversino": "attraversare",
    "attraverso": "attraversare",
    "attraversò": "attraversare",
    "attrazioni": "attrazione",
    "attrezza": "attrezzare",
    "attrezzai": "attrezzare",
    "attrezzammo": "attrezzare",
    "attrezzan": "attrezzare",
    "attrezzando": "attrezzare",
    "attrezzano": "attrezzare",
    "attrezzante": "attrezzare",
    "attrezzanti": "attrezzare",
    "attrezzar": "attrezzare",
    "attrezzaron": "attrezzare",
    "attrezzarono": "attrezzare",
    "attrezzasse": "attrezzare",
    "attrezzasser": "attrezzare",
    "attrezzassero": "attrezzare",
    "attrezzassi": "attrezzare",
    "attrezzassimo": "attrezzare",
    "attrezzaste": "attrezzare",
    "attrezzasti": "attrezzare",
    "attrezzata": "attrezzato",
    "attrezzate": "attrezzato",
    "attrezzati": "attrezzato",
    "attrezzato": "attrezzare",
    "attrezzature": "attrezzatura",
    "attrezzava": "attrezzare",
    "attrezzavamo": "attrezzare",
    "attrezzavan": "attrezzare",
    "attrezzavano": "attrezzare",
    "attrezzavate": "attrezzare",
    "attrezzavi": "attrezzare",
    "attrezzavo": "attrezzare",
    "attrezzerai": "attrezzare",
    "attrezzeran": "attrezzare",
    "attrezzeranno": "attrezzare",
    "attrezzerebbe": "attrezzare",
    "attrezzerebber": "attrezzare",
    "attrezzerebbero": "attrezzare",
    "attrezzerei": "attrezzare",
    "attrezzeremmo": "attrezzare",
    "attrezzeremo": "attrezzare",
    "attrezzereste": "attrezzare",
    "attrezzeresti": "attrezzare",
    "attrezzerete": "attrezzare",
    "attrezzerà": "attrezzare",
    "attrezzerò": "attrezzare",
    "attrezzi": "attrezzo",
    "attrezziamo": "attrezzare",
    "attrezziate": "attrezzare",
    "attrezzin": "attrezzare",
    "attrezzino": "attrezzare",
    "attrezzo": "attrezzare",
    "attrezzò": "attrezzare",
    "attribuendo": "attribuire",
    "attribuente": "attribuire",
    "attribuenti": "attribuire",
    "attribuiamo": "attribuire",
    "attribuiate": "attribuire",
    "attribuibili": "attribuibile",
    "attribuii": "attribuire",
    "attribuimmo": "attribuire",
    "attribuir": "attribuire",
    "attribuirai": "attribuire",
    "attribuiran": "attribuire",
    "attribuiranno": "attribuire",
    "attribuirebbe": "attribuire",
    "attribuirebber": "attribuire",
    "attribuirebbero": "attribuire",
    "attribuirei": "attribuire",
    "attribuiremmo": "attribuire",
    "attribuiremo": "attribuire",
    "attribuireste": "attribuire",
    "attribuiresti": "attribuire",
    "attribuirete": "attribuire",
    "attribuiron": "attribuire",
    "attribuirono": "attribuire",
    "attribuirà": "attribuire",
    "attribuirò": "attribuire",
    "attribuisca": "attribuire",
    "attribuiscan": "attribuire",
    "attribuiscano": "attribuire",
    "attribuisce": "attribuire",
    "attribuisci": "attribuire",
    "attribuisco": "attribuire",
    "attribuiscon": "attribuire",
    "attribuiscono": "attribuire",
    "attribuisse": "attribuire",
    "attribuisser": "attribuire",
    "attribuissero": "attribuire",
    "attribuissi": "attribuire",
    "attribuissimo": "attribuire",
    "attribuiste": "attribuire",
    "attribuisti": "attribuire",
    "attribuita": "attribuire",
    "attribuite": "attribuire",
    "attribuiti": "attribuire",
    "attribuito": "attribuire",
    "attribuiva": "attribuire",
    "attribuivamo": "attribuire",
    "attribuivan": "attribuire",
    "attribuivano": "attribuire",
    "attribuivate": "attribuire",
    "attribuivi": "attribuire",
    "attribuivo": "attribuire",
    "attributi": "attributo",
    "attribuzioni": "attribuzione",
    "attribuì": "attribuire",
    "attricette": "attricetta",
    "attrici": "attrice",
    "attrista": "attristare",
    "attristai": "attristare",
    "attristammo": "attristare",
    "attristan": "attristare",
    "attristando": "attristare",
    "attristano": "attristare",
    "attristante": "attristare",
    "attristanti": "attristare",
    "attristar": "attristare",
    "attristaron": "attristare",
    "attristarono": "attristare",
    "attristasse": "attristare",
    "attristasser": "attristare",
    "attristassero": "attristare",
    "attristassi": "attristare",
    "attristassimo": "attristare",
    "attristaste": "attristare",
    "attristasti": "attristare",
    "attristata": "attristare",
    "attristate": "attristare",
    "attristati": "attristare",
    "attristato": "attristare",
    "attristava": "attristare",
    "attristavamo": "attristare",
    "attristavan": "attristare",
    "attristavano": "attristare",
    "attristavate": "attristare",
    "attristavi": "attristare",
    "attristavo": "attristare",
    "attristerai": "attristare",
    "attristeran": "attristare",
    "attristeranno": "attristare",
    "attristerebbe": "attristare",
    "attristerebber": "attristare",
    "attristerebbero": "attristare",
    "attristerei": "attristare",
    "attristeremmo": "attristare",
    "attristeremo": "attristare",
    "attristereste": "attristare",
    "attristeresti": "attristare",
    "attristerete": "attristare",
    "attristerà": "attristare",
    "attristerò": "attristare",
    "attristi": "attristare",
    "attristiamo": "attristare",
    "attristiate": "attristare",
    "attristin": "attristare",
    "attristino": "attristare",
    "attristo": "attristare",
    "attristò": "attristare",
    "attriti": "attrito",
    "attruppa": "attruppare",
    "attruppai": "attruppare",
    "attruppammo": "attruppare",
    "attruppan": "attruppare",
    "attruppando": "attruppare",
    "attruppano": "attruppare",
    "attruppante": "attruppare",
    "attruppanti": "attruppare",
    "attruppar": "attruppare",
    "attrupparon": "attruppare",
    "attrupparono": "attruppare",
    "attruppasse": "attruppare",
    "attruppasser": "attruppare",
    "attruppassero": "attruppare",
    "attruppassi": "attruppare",
    "attruppassimo": "attruppare",
    "attruppaste": "attruppare",
    "attruppasti": "attruppare",
    "attruppata": "attruppare",
    "attruppate": "attruppare",
    "attruppati": "attruppare",
    "attruppato": "attruppare",
    "attruppava": "attruppare",
    "attruppavamo": "attruppare",
    "attruppavan": "attruppare",
    "attruppavano": "attruppare",
    "attruppavate": "attruppare",
    "attruppavi": "attruppare",
    "attruppavo": "attruppare",
    "attrupperai": "attruppare",
    "attrupperan": "attruppare",
    "attrupperanno": "attruppare",
    "attrupperebbe": "attruppare",
    "attrupperebber": "attruppare",
    "attrupperebbero": "attruppare",
    "attrupperei": "attruppare",
    "attrupperemmo": "attruppare",
    "attrupperemo": "attruppare",
    "attruppereste": "attruppare",
    "attrupperesti": "attruppare",
    "attrupperete": "attruppare",
    "attrupperà": "attruppare",
    "attrupperò": "attruppare",
    "attruppi": "attruppare",
    "attruppiamo": "attruppare",
    "attruppiate": "attruppare",
    "attruppin": "attruppare",
    "attruppino": "attruppare",
    "attruppo": "attruppare",
    "attruppò": "attruppare",
    "attua": "attuare",
    "attuabili": "attuabile",
    "attuai": "attuare",
    "attuali": "attuale",
    "attualizza": "attualizzare",
    "attualizzai": "attualizzare",
    "attualizzammo": "attualizzare",
    "attualizzan": "attualizzare",
    "attualizzando": "attualizzare",
    "attualizzano": "attualizzare",
    "attualizzante": "attualizzare",
    "attualizzanti": "attualizzare",
    "attualizzar": "attualizzare",
    "attualizzaron": "attualizzare",
    "attualizzarono": "attualizzare",
    "attualizzasse": "attualizzare",
    "attualizzasser": "attualizzare",
    "attualizzassero": "attualizzare",
    "attualizzassi": "attualizzare",
    "attualizzassimo": "attualizzare",
    "attualizzaste": "attualizzare",
    "attualizzasti": "attualizzare",
    "attualizzata": "attualizzare",
    "attualizzate": "attualizzare",
    "attualizzati": "attualizzare",
    "attualizzato": "attualizzare",
    "attualizzava": "attualizzare",
    "attualizzavamo": "attualizzare",
    "attualizzavan": "attualizzare",
    "attualizzavano": "attualizzare",
    "attualizzavate": "attualizzare",
    "attualizzavi": "attualizzare",
    "attualizzavo": "attualizzare",
    "attualizzazioni": "attualizzazione",
    "attualizzerai": "attualizzare",
    "attualizzeran": "attualizzare",
    "attualizzeranno": "attualizzare",
    "attualizzerebbe": "attualizzare",
    "attualizzerebber": "attualizzare",
    "attualizzerebbero": "attualizzare",
    "attualizzerei": "attualizzare",
    "attualizzeremmo": "attualizzare",
    "attualizzeremo": "attualizzare",
    "attualizzereste": "attualizzare",
    "attualizzeresti": "attualizzare",
    "attualizzerete": "attualizzare",
    "attualizzerà": "attualizzare",
    "attualizzerò": "attualizzare",
    "attualizzi": "attualizzare",
    "attualizziamo": "attualizzare",
    "attualizziate": "attualizzare",
    "attualizzin": "attualizzare",
    "attualizzino": "attualizzare",
    "attualizzo": "attualizzare",
    "attualizzò": "attualizzare",
    "attuammo": "attuare",
    "attuan": "attuare",
    "attuando": "attuare",
    "attuano": "attuare",
    "attuante": "attuare",
    "attuanti": "attuare",
    "attuar": "attuare",
    "attuariali": "attuariale",
    "attuaron": "attuare",
    "attuarono": "attuare",
    "attuasse": "attuare",
    "attuasser": "attuare",
    "attuassero": "attuare",
    "attuassi": "attuare",
    "attuassimo": "attuare",
    "attuaste": "attuare",
    "attuasti": "attuare",
    "attuata": "attuare",
    "attuate": "attuare",
    "attuati": "attuare",
    "attuato": "attuare",
    "attuava": "attuare",
    "attuavamo": "attuare",
    "attuavan": "attuare",
    "attuavano": "attuare",
    "attuavate": "attuare",
    "attuavi": "attuare",
    "attuavo": "attuare",
    "attuazioni": "attuazione",
    "attuerai": "attuare",
    "attueran": "attuare",
    "attueranno": "attuare",
    "attuerebbe": "attuare",
    "attuerebber": "attuare",
    "attuerebbero": "attuare",
    "attuerei": "attuare",
    "attueremmo": "attuare",
    "attueremo": "attuare",
    "attuereste": "attuare",
    "attueresti": "attuare",
    "attuerete": "attuare",
    "attuerà": "attuare",
    "attuerò": "attuare",
    "attui": "attuare",
    "attuiamo": "attuare",
    "attuiate": "attuare",
    "attuin": "attuare",
    "attuino": "attuare",
    "attuo": "attuare",
    "attutendo": "attutire",
    "attutente": "attutire",
    "attutenti": "attutire",
    "attutiamo": "attutire",
    "attutiate": "attutire",
    "attutii": "attutire",
    "attutimmo": "attutire",
    "attutir": "attutire",
    "attutirai": "attutire",
    "attutiran": "attutire",
    "attutiranno": "attutire",
    "attutirebbe": "attutire",
    "attutirebber": "attutire",
    "attutirebbero": "attutire",
    "attutirei": "attutire",
    "attutiremmo": "attutire",
    "attutiremo": "attutire",
    "attutireste": "attutire",
    "attutiresti": "attutire",
    "attutirete": "attutire",
    "attutiron": "attutire",
    "attutirono": "attutire",
    "attutirà": "attutire",
    "attutirò": "attutire",
    "attutisca": "attutire",
    "attutiscan": "attutire",
    "attutiscano": "attutire",
    "attutisce": "attutire",
    "attutisci": "attutire",
    "attutisco": "attutire",
    "attutiscon": "attutire",
    "attutiscono": "attutire",
    "attutisse": "attutire",
    "attutisser": "attutire",
    "attutissero": "attutire",
    "attutissi": "attutire",
    "attutissimo": "attutire",
    "attutiste": "attutire",
    "attutisti": "attutire",
    "attutita": "attutire",
    "attutite": "attutire",
    "attutiti": "attutire",
    "attutito": "attutire",
    "attutiva": "attutire",
    "attutivamo": "attutire",
    "attutivan": "attutire",
    "attutivano": "attutire",
    "attutivate": "attutire",
    "attutivi": "attutire",
    "attutivo": "attutire",
    "attutì": "attutire",
    "attuò": "attuare",
    "audaci": "audace",
    "audacie": "audacia",
    "audiocassette": "audiocassetta",
    "audiovisiva": "audiovisivo",
    "audiovisive": "audiovisivo",
    "audiovisivi": "audiovisivo",
    "auditori": "auditorio",
    "audizioni": "audizione",
    "augura": "augurare",
    "augurai": "augurare",
    "augurali": "augurale",
    "augurammo": "augurare",
    "auguran": "augurare",
    "augurando": "augurare",
    "augurano": "augurare",
    "augurante": "augurare",
    "auguranti": "augurare",
    "augurar": "augurare",
    "auguraron": "augurare",
    "augurarono": "augurare",
    "augurasse": "augurare",
    "augurasser": "augurare",
    "augurassero": "augurare",
    "augurassi": "augurare",
    "augurassimo": "augurare",
    "auguraste": "augurare",
    "augurasti": "augurare",
    "augurata": "augurare",
    "augurate": "augurare",
    "augurati": "augurare",
    "augurato": "augurare",
    "augurava": "augurare",
    "auguravamo": "augurare",
    "auguravan": "augurare",
    "auguravano": "augurare",
    "auguravate": "augurare",
    "auguravi": "augurare",
    "auguravo": "augurare",
    "augurerai": "augurare",
    "augureran": "augurare",
    "augureranno": "augurare",
    "augurerebbe": "augurare",
    "augurerebber": "augurare",
    "augurerebbero": "augurare",
    "augurerei": "augurare",
    "augureremmo": "augurare",
    "augureremo": "augurare",
    "augurereste": "augurare",
    "augureresti": "augurare",
    "augurerete": "augurare",
    "augurerà": "augurare",
    "augurerò": "augurare",
    "auguri": "augurio",
    "auguriamo": "augurare",
    "auguriate": "augurare",
    "augurin": "augurare",
    "augurino": "augurare",
    "auguro": "augurare",
    "augurò": "augurare",
    "augusta": "augusto",
    "auguste": "augusto",
    "augusti": "augusto",
    "aula": "aulire",
    "aulan": "aulire",
    "aulano": "aulire",
    "aule": "aulire",
    "aulendo": "aulire",
    "aulente": "aulire",
    "aulenti": "aulire",
    "auli": "aulire",
    "auliamo": "aulire",
    "auliate": "aulire",
    "aulica": "aulico",
    "auliche": "aulico",
    "aulici": "aulico",
    "aulii": "aulire",
    "aulimmo": "aulire",
    "aulir": "aulire",
    "aulirai": "aulire",
    "auliran": "aulire",
    "auliranno": "aulire",
    "aulirebbe": "aulire",
    "aulirebber": "aulire",
    "aulirebbero": "aulire",
    "aulirei": "aulire",
    "auliremmo": "aulire",
    "auliremo": "aulire",
    "aulireste": "aulire",
    "auliresti": "aulire",
    "aulirete": "aulire",
    "auliron": "aulire",
    "aulirono": "aulire",
    "aulirà": "aulire",
    "aulirò": "aulire",
    "aulisse": "aulire",
    "aulisser": "aulire",
    "aulissero": "aulire",
    "aulissi": "aulire",
    "aulissimo": "aulire",
    "auliste": "aulire",
    "aulisti": "aulire",
    "aulita": "aulire",
    "aulite": "aulire",
    "auliti": "aulire",
    "aulito": "aulire",
    "auliva": "aulire",
    "aulivamo": "aulire",
    "aulivan": "aulire",
    "aulivano": "aulire",
    "aulivate": "aulire",
    "aulivi": "aulire",
    "aulivo": "aulire",
    "aulo": "aulire",
    "aulon": "aulire",
    "aulono": "aulire",
    "aulì": "aulire",
    "aumenta": "aumentare",
    "aumentabili": "aumentabile",
    "aumentai": "aumentare",
    "aumentammo": "aumentare",
    "aumentan": "aumentare",
    "aumentando": "aumentare",
    "aumentano": "aumentare",
    "aumentante": "aumentare",
    "aumentanti": "aumentare",
    "aumentar": "aumentare",
    "aumentaron": "aumentare",
    "aumentarono": "aumentare",
    "aumentasse": "aumentare",
    "aumentasser": "aumentare",
    "aumentassero": "aumentare",
    "aumentassi": "aumentare",
    "aumentassimo": "aumentare",
    "aumentaste": "aumentare",
    "aumentasti": "aumentare",
    "aumentata": "aumentare",
    "aumentate": "aumentare",
    "aumentati": "aumentare",
    "aumentato": "aumentare",
    "aumentava": "aumentare",
    "aumentavamo": "aumentare",
    "aumentavan": "aumentare",
    "aumentavano": "aumentare",
    "aumentavate": "aumentare",
    "aumentavi": "aumentare",
    "aumentavo": "aumentare",
    "aumenterai": "aumentare",
    "aumenteran": "aumentare",
    "aumenteranno": "aumentare",
    "aumenterebbe": "aumentare",
    "aumenterebber": "aumentare",
    "aumenterebbero": "aumentare",
    "aumenterei": "aumentare",
    "aumenteremmo": "aumentare",
    "aumenteremo": "aumentare",
    "aumentereste": "aumentare",
    "aumenteresti": "aumentare",
    "aumenterete": "aumentare",
    "aumenterà": "aumentare",
    "aumenterò": "aumentare",
    "aumenti": "aumento",
    "aumentiamo": "aumentare",
    "aumentiate": "aumentare",
    "aumentin": "aumentare",
    "aumentino": "aumentare",
    "aumento": "aumentare",
    "aumentò": "aumentare",
    "aure": "aura",
    "aurea": "aureo",
    "auree": "aureo",
    "aurei": "aureo",
    "aureola": "aureolare",
    "aureolai": "aureolare",
    "aureolammo": "aureolare",
    "aureolan": "aureolare",
    "aureolando": "aureolare",
    "aureolano": "aureolare",
    "aureolante": "aureolare",
    "aureolanti": "aureolare",
    "aureolar": "aureolare",
    "aureolaron": "aureolare",
    "aureolarono": "aureolare",
    "aureolasse": "aureolare",
    "aureolasser": "aureolare",
    "aureolassero": "aureolare",
    "aureolassi": "aureolare",
    "aureolassimo": "aureolare",
    "aureolaste": "aureolare",
    "aureolasti": "aureolare",
    "aureolata": "aureolare",
    "aureolate": "aureolare",
    "aureolati": "aureolare",
    "aureolato": "aureolare",
    "aureolava": "aureolare",
    "aureolavamo": "aureolare",
    "aureolavan": "aureolare",
    "aureolavano": "aureolare",
    "aureolavate": "aureolare",
    "aureolavi": "aureolare",
    "aureolavo": "aureolare",
    "aureole": "aureola",
    "aureolerai": "aureolare",
    "aureoleran": "aureolare",
    "aureoleranno": "aureolare",
    "aureolerebbe": "aureolare",
    "aureolerebber": "aureolare",
    "aureolerebbero": "aureolare",
    "aureolerei": "aureolare",
    "aureoleremmo": "aureolare",
    "aureoleremo": "aureolare",
    "aureolereste": "aureolare",
    "aureoleresti": "aureolare",
    "aureolerete": "aureolare",
    "aureolerà": "aureolare",
    "aureolerò": "aureolare",
    "aureoli": "aureolare",
    "aureoliamo": "aureolare",
    "aureoliate": "aureolare",
    "aureolin": "aureolare",
    "aureolino": "aureolare",
    "aureolo": "aureolare",
    "aureolò": "aureolare",
    "auricolari": "auricolare",
    "aurifera": "aurifero",
    "aurifere": "aurifero",
    "auriferi": "aurifero",
    "aurorali": "aurorale",
    "aurore": "aurora",
    "ausculta": "auscultare",
    "auscultai": "auscultare",
    "auscultammo": "auscultare",
    "auscultan": "auscultare",
    "auscultando": "auscultare",
    "auscultano": "auscultare",
    "auscultante": "auscultare",
    "auscultanti": "auscultare",
    "auscultar": "auscultare",
    "auscultaron": "auscultare",
    "auscultarono": "auscultare",
    "auscultasse": "auscultare",
    "auscultasser": "auscultare",
    "auscultassero": "auscultare",
    "auscultassi": "auscultare",
    "auscultassimo": "auscultare",
    "auscultaste": "auscultare",
    "auscultasti": "auscultare",
    "auscultata": "auscultare",
    "auscultate": "auscultare",
    "auscultati": "auscultare",
    "auscultato": "auscultare",
    "auscultava": "auscultare",
    "auscultavamo": "auscultare",
    "auscultavan": "auscultare",
    "auscultavano": "auscultare",
    "auscultavate": "auscultare",
    "auscultavi": "auscultare",
    "auscultavo": "auscultare",
    "ausculterai": "auscultare",
    "ausculteran": "auscultare",
    "ausculteranno": "auscultare",
    "ausculterebbe": "auscultare",
    "ausculterebber": "auscultare",
    "ausculterebbero": "auscultare",
    "ausculterei": "auscultare",
    "ausculteremmo": "auscultare",
    "ausculteremo": "auscultare",
    "auscultereste": "auscultare",
    "ausculteresti": "auscultare",
    "ausculterete": "auscultare",
    "ausculterà": "auscultare",
    "ausculterò": "auscultare",
    "ausculti": "auscultare",
    "auscultiamo": "auscultare",
    "auscultiate": "auscultare",
    "auscultin": "auscultare",
    "auscultino": "auscultare",
    "ausculto": "auscultare",
    "auscultò": "auscultare",
    "ausili": "ausilio",
    "ausiliari": "ausiliario",
    "ausiliaria": "ausiliario",
    "ausiliarie": "ausiliario",
    "ausiliatori": "ausiliatore",
    "ausiliatrice": "ausiliatore",
    "ausiliatrici": "ausiliatore",
    "auspica": "auspicare",
    "auspicabili": "auspicabile",
    "auspicai": "auspicare",
    "auspicammo": "auspicare",
    "auspican": "auspicare",
    "auspicando": "auspicare",
    "auspicano": "auspicare",
    "auspicante": "auspicare",
    "auspicanti": "auspicare",
    "auspicar": "auspicare",
    "auspicaron": "auspicare",
    "auspicarono": "auspicare",
    "auspicasse": "auspicare",
    "auspicasser": "auspicare",
    "auspicassero": "auspicare",
    "auspicassi": "auspicare",
    "auspicassimo": "auspicare",
    "auspicaste": "auspicare",
    "auspicasti": "auspicare",
    "auspicata": "auspicare",
    "auspicate": "auspicare",
    "auspicati": "auspicare",
    "auspicato": "auspicare",
    "auspicava": "auspicare",
    "auspicavamo": "auspicare",
    "auspicavan": "auspicare",
    "auspicavano": "auspicare",
    "auspicavate": "auspicare",
    "auspicavi": "auspicare",
    "auspicavo": "auspicare",
    "auspicherai": "auspicare",
    "auspicheran": "auspicare",
    "auspicheranno": "auspicare",
    "auspicherebbe": "auspicare",
    "auspicherebber": "auspicare",
    "auspicherebbero": "auspicare",
    "auspicherei": "auspicare",
    "auspicheremmo": "auspicare",
    "auspicheremo": "auspicare",
    "auspichereste": "auspicare",
    "auspicheresti": "auspicare",
    "auspicherete": "auspicare",
    "auspicherà": "auspicare",
    "auspicherò": "auspicare",
    "auspichi": "auspicare",
    "auspichiamo": "auspicare",
    "auspichiate": "auspicare",
    "auspichin": "auspicare",
    "auspichino": "auspicare",
    "auspici": "auspicio",
    "auspico": "auspicare",
    "auspicò": "auspicare",
    "austera": "austero",
    "austere": "austero",
    "austeri": "austero",
    "australi": "australe",
    "australiana": "australiano",
    "australiane": "australiano",
    "australiani": "australiano",
    "austriaca": "austriaco",
    "austriache": "austriaco",
    "austriaci": "austriaco",
    "austro-bavaresi": "austro-bavarese",
    "austro-germanica": "austro-germanico",
    "austro-germaniche": "austro-germanico",
    "austro-germanici": "austro-germanico",
    "austro-lussemburghesi": "austro-lussemburghese",
    "austro-tedesca": "austro-tedesco",
    "austro-tedesche": "austro-tedesco",
    "austro-tedeschi": "austro-tedesco",
    "austro-ungarica": "austro-ungarico",
    "austro-ungariche": "austro-ungarico",
    "austro-ungarici": "austro-ungarico",
    "austro-ungheresi": "austro-ungherese",
    "austrolussemburghesi": "austrolussemburghese",
    "austrotedesca": "austrotedesco",
    "austrotedesche": "austrotedesco",
    "austrotedeschi": "austrotedesco",
    "austroungheresi": "austroungherese",
    "autarchica": "autarchico",
    "autarchiche": "autarchico",
    "autarchici": "autarchico",
    "autarchie": "autarchia",
    "autentica": "autentico",
    "autenticai": "autenticare",
    "autenticammo": "autenticare",
    "autentican": "autenticare",
    "autenticando": "autenticare",
    "autenticano": "autenticare",
    "autenticante": "autenticare",
    "autenticanti": "autenticare",
    "autenticar": "autenticare",
    "autenticaron": "autenticare",
    "autenticarono": "autenticare",
    "autenticasse": "autenticare",
    "autenticasser": "autenticare",
    "autenticassero": "autenticare",
    "autenticassi": "autenticare",
    "autenticassimo": "autenticare",
    "autenticaste": "autenticare",
    "autenticasti": "autenticare",
    "autenticata": "autenticare",
    "autenticate": "autenticare",
    "autenticati": "autenticare",
    "autenticato": "autenticare",
    "autenticava": "autenticare",
    "autenticavamo": "autenticare",
    "autenticavan": "autenticare",
    "autenticavano": "autenticare",
    "autenticavate": "autenticare",
    "autenticavi": "autenticare",
    "autenticavo": "autenticare",
    "autentiche": "autentico",
    "autenticherai": "autenticare",
    "autenticheran": "autenticare",
    "autenticheranno": "autenticare",
    "autenticherebbe": "autenticare",
    "autenticherebber": "autenticare",
    "autenticherebbero": "autenticare",
    "autenticherei": "autenticare",
    "autenticheremmo": "autenticare",
    "autenticheremo": "autenticare",
    "autentichereste": "autenticare",
    "autenticheresti": "autenticare",
    "autenticherete": "autenticare",
    "autenticherà": "autenticare",
    "autenticherò": "autenticare",
    "autentichi": "autenticare",
    "autentichiamo": "autenticare",
    "autentichiate": "autenticare",
    "autentichin": "autenticare",
    "autentichino": "autenticare",
    "autentici": "autentico",
    "autentico": "autenticare",
    "autenticò": "autenticare",
    "autentifica": "autentificare",
    "autentificai": "autentificare",
    "autentificammo": "autentificare",
    "autentifican": "autentificare",
    "autentificando": "autentificare",
    "autentificano": "autentificare",
    "autentificante": "autentificare",
    "autentificanti": "autentificare",
    "autentificar": "autentificare",
    "autentificaron": "autentificare",
    "autentificarono": "autentificare",
    "autentificasse": "autentificare",
    "autentificasser": "autentificare",
    "autentificassero": "autentificare",
    "autentificassi": "autentificare",
    "autentificassimo": "autentificare",
    "autentificaste": "autentificare",
    "autentificasti": "autentificare",
    "autentificata": "autentificare",
    "autentificate": "autentificare",
    "autentificati": "autentificare",
    "autentificato": "autentificare",
    "autentificava": "autentificare",
    "autentificavamo": "autentificare",
    "autentificavan": "autentificare",
    "autentificavano": "autentificare",
    "autentificavate": "autentificare",
    "autentificavi": "autentificare",
    "autentificavo": "autentificare",
    "autentificherai": "autentificare",
    "autentificheran": "autentificare",
    "autentificheranno": "autentificare",
    "autentificherebbe": "autentificare",
    "autentificherebber": "autentificare",
    "autentificherebbero": "autentificare",
    "autentificherei": "autentificare",
    "autentificheremmo": "autentificare",
    "autentificheremo": "autentificare",
    "autentifichereste": "autentificare",
    "autentificheresti": "autentificare",
    "autentificherete": "autentificare",
    "autentificherà": "autentificare",
    "autentificherò": "autentificare",
    "autentifichi": "autentificare",
    "autentifichiamo": "autentificare",
    "autentifichiate": "autentificare",
    "autentifichin": "autentificare",
    "autentifichino": "autentificare",
    "autentifico": "autentificare",
    "autentificò": "autentificare",
    "autisti": "autista",
    "auto-accusatori": "auto-accusatorio",
    "auto-accusatoria": "auto-accusatorio",
    "auto-accusatorie": "auto-accusatorio",
    "auto-assegna": "auto-assegnare",
    "auto-assegnai": "auto-assegnare",
    "auto-assegnammo": "auto-assegnare",
    "auto-assegnan": "auto-assegnare",
    "auto-assegnando": "auto-assegnare",
    "auto-assegnano": "auto-assegnare",
    "auto-assegnante": "auto-assegnare",
    "auto-assegnanti": "auto-assegnare",
    "auto-assegnar": "auto-assegnare",
    "auto-assegnaron": "auto-assegnare",
    "auto-assegnarono": "auto-assegnare",
    "auto-assegnasse": "auto-assegnare",
    "auto-assegnasser": "auto-assegnare",
    "auto-assegnassero": "auto-assegnare",
    "auto-assegnassi": "auto-assegnare",
    "auto-assegnassimo": "auto-assegnare",
    "auto-assegnaste": "auto-assegnare",
    "auto-assegnasti": "auto-assegnare",
    "auto-assegnata": "auto-assegnare",
    "auto-assegnate": "auto-assegnare",
    "auto-assegnati": "auto-assegnare",
    "auto-assegnato": "auto-assegnare",
    "auto-assegnava": "auto-assegnare",
    "auto-assegnavamo": "auto-assegnare",
    "auto-assegnavan": "auto-assegnare",
    "auto-assegnavano": "auto-assegnare",
    "auto-assegnavate": "auto-assegnare",
    "auto-assegnavi": "auto-assegnare",
    "auto-assegnavo": "auto-assegnare",
    "auto-assegnerai": "auto-assegnare",
    "auto-assegneran": "auto-assegnare",
    "auto-assegneranno": "auto-assegnare",
    "auto-assegnerebbe": "auto-assegnare",
    "auto-assegnerebber": "auto-assegnare",
    "auto-assegnerebbero": "auto-assegnare",
    "auto-assegnerei": "auto-assegnare",
    "auto-assegneremmo": "auto-assegnare",
    "auto-assegneremo": "auto-assegnare",
    "auto-assegnereste": "auto-assegnare",
    "auto-assegneresti": "auto-assegnare",
    "auto-assegnerete": "auto-assegnare",
    "auto-assegnerà": "auto-assegnare",
    "auto-assegnerò": "auto-assegnare",
    "auto-assegni": "auto-assegnare",
    "auto-assegniamo": "auto-assegnare",
    "auto-assegniate": "auto-assegnare",
    "auto-assegnin": "auto-assegnare",
    "auto-assegnino": "auto-assegnare",
    "auto-assegno": "auto-assegnare",
    "auto-assegnò": "auto-assegnare",
    "auto-assolutori": "auto-assolutorio",
    "auto-assolutoria": "auto-assolutorio",
    "auto-assolutorie": "auto-assolutorio",
    "auto-cura": "auto-curare",
    "auto-curai": "auto-curare",
    "auto-curammo": "auto-curare",
    "auto-curan": "auto-curare",
    "auto-curando": "auto-curare",
    "auto-curano": "auto-curare",
    "auto-curante": "auto-curare",
    "auto-curanti": "auto-curare",
    "auto-curar": "auto-curare",
    "auto-curaron": "auto-curare",
    "auto-curarono": "auto-curare",
    "auto-curasse": "auto-curare",
    "auto-curasser": "auto-curare",
    "auto-curassero": "auto-curare",
    "auto-curassi": "auto-curare",
    "auto-curassimo": "auto-curare",
    "auto-curaste": "auto-curare",
    "auto-curasti": "auto-curare",
    "auto-curata": "auto-curare",
    "auto-curate": "auto-curare",
    "auto-curati": "auto-curare",
    "auto-curato": "auto-curare",
    "auto-curava": "auto-curare",
    "auto-curavamo": "auto-curare",
    "auto-curavan": "auto-curare",
    "auto-curavano": "auto-curare",
    "auto-curavate": "auto-curare",
    "auto-curavi": "auto-curare",
    "auto-curavo": "auto-curare",
    "auto-curerai": "auto-curare",
    "auto-cureran": "auto-curare",
    "auto-cureranno": "auto-curare",
    "auto-curerebbe": "auto-curare",
    "auto-curerebber": "auto-curare",
    "auto-curerebbero": "auto-curare",
    "auto-curerei": "auto-curare",
    "auto-cureremmo": "auto-curare",
    "auto-cureremo": "auto-curare",
    "auto-curereste": "auto-curare",
    "auto-cureresti": "auto-curare",
    "auto-curerete": "auto-curare",
    "auto-curerà": "auto-curare",
    "auto-curerò": "auto-curare",
    "auto-curi": "auto-curare",
    "auto-curiamo": "auto-curare",
    "auto-curiate": "auto-curare",
    "auto-curin": "auto-curare",
    "auto-curino": "auto-curare",
    "auto-curo": "auto-curare",
    "auto-curò": "auto-curare",
    "auto-defina": "auto-definire",
    "auto-definan": "auto-definire",
    "auto-definano": "auto-definire",
    "auto-define": "auto-definire",
    "auto-definendo": "auto-definire",
    "auto-definente": "auto-definire",
    "auto-definenti": "auto-definire",
    "auto-defini": "auto-definire",
    "auto-definiamo": "auto-definire",
    "auto-definiate": "auto-definire",
    "auto-definii": "auto-definire",
    "auto-definimmo": "auto-definire",
    "auto-definir": "auto-definire",
    "auto-definirai": "auto-definire",
    "auto-definiran": "auto-definire",
    "auto-definiranno": "auto-definire",
    "auto-definirebbe": "auto-definire",
    "auto-definirebber": "auto-definire",
    "auto-definirebbero": "auto-definire",
    "auto-definirei": "auto-definire",
    "auto-definiremmo": "auto-definire",
    "auto-definiremo": "auto-definire",
    "auto-definireste": "auto-definire",
    "auto-definiresti": "auto-definire",
    "auto-definirete": "auto-definire",
    "auto-definiron": "auto-definire",
    "auto-definirono": "auto-definire",
    "auto-definirà": "auto-definire",
    "auto-definirò": "auto-definire",
    "auto-definisse": "auto-definire",
    "auto-definisser": "auto-definire",
    "auto-definissero": "auto-definire",
    "auto-definissi": "auto-definire",
    "auto-definissimo": "auto-definire",
    "auto-definiste": "auto-definire",
    "auto-definisti": "auto-definire",
    "auto-definita": "auto-definire",
    "auto-definite": "auto-definire",
    "auto-definiti": "auto-definire",
    "auto-definito": "auto-definire",
    "auto-definiva": "auto-definire",
    "auto-definivamo": "auto-definire",
    "auto-definivan": "auto-definire",
    "auto-definivano": "auto-definire",
    "auto-definivate": "auto-definire",
    "auto-definivi": "auto-definire",
    "auto-definivo": "auto-definire",
    "auto-defino": "auto-definire",
    "auto-definon": "auto-definire",
    "auto-definono": "auto-definire",
    "auto-definì": "auto-definire",
    "auto-finanziata": "auto-finanziato",
    "auto-finanziate": "auto-finanziato",
    "auto-finanziati": "auto-finanziato",
    "auto-gestita": "auto-gestito",
    "auto-gestite": "auto-gestito",
    "auto-gestiti": "auto-gestito",
    "auto-immunizza": "auto-immunizzare",
    "auto-immunizzai": "auto-immunizzare",
    "auto-immunizzammo": "auto-immunizzare",
    "auto-immunizzan": "auto-immunizzare",
    "auto-immunizzando": "auto-immunizzare",
    "auto-immunizzano": "auto-immunizzare",
    "auto-immunizzante": "auto-immunizzare",
    "auto-immunizzanti": "auto-immunizzare",
    "auto-immunizzar": "auto-immunizzare",
    "auto-immunizzaron": "auto-immunizzare",
    "auto-immunizzarono": "auto-immunizzare",
    "auto-immunizzasse": "auto-immunizzare",
    "auto-immunizzasser": "auto-immunizzare",
    "auto-immunizzassero": "auto-immunizzare",
    "auto-immunizzassi": "auto-immunizzare",
    "auto-immunizzassimo": "auto-immunizzare",
    "auto-immunizzaste": "auto-immunizzare",
    "auto-immunizzasti": "auto-immunizzare",
    "auto-immunizzata": "auto-immunizzare",
    "auto-immunizzate": "auto-immunizzare",
    "auto-immunizzati": "auto-immunizzare",
    "auto-immunizzato": "auto-immunizzare",
    "auto-immunizzava": "auto-immunizzare",
    "auto-immunizzavamo": "auto-immunizzare",
    "auto-immunizzavan": "auto-immunizzare",
    "auto-immunizzavano": "auto-immunizzare",
    "auto-immunizzavate": "auto-immunizzare",
    "auto-immunizzavi": "auto-immunizzare",
    "auto-immunizzavo": "auto-immunizzare",
    "auto-immunizzerai": "auto-immunizzare",
    "auto-immunizzeran": "auto-immunizzare",
    "auto-immunizzeranno": "auto-immunizzare",
    "auto-immunizzerebbe": "auto-immunizzare",
    "auto-immunizzerebber": "auto-immunizzare",
    "auto-immunizzerebbero": "auto-immunizzare",
    "auto-immunizzerei": "auto-immunizzare",
    "auto-immunizzeremmo": "auto-immunizzare",
    "auto-immunizzeremo": "auto-immunizzare",
    "auto-immunizzereste": "auto-immunizzare",
    "auto-immunizzeresti": "auto-immunizzare",
    "auto-immunizzerete": "auto-immunizzare",
    "auto-immunizzerà": "auto-immunizzare",
    "auto-immunizzerò": "auto-immunizzare",
    "auto-immunizzi": "auto-immunizzare",
    "auto-immunizziamo": "auto-immunizzare",
    "auto-immunizziate": "auto-immunizzare",
    "auto-immunizzin": "auto-immunizzare",
    "auto-immunizzino": "auto-immunizzare",
    "auto-immunizzo": "auto-immunizzare",
    "auto-immunizzò": "auto-immunizzare",
    "auto-parodistica": "auto-parodistico",
    "auto-parodistiche": "auto-parodistico",
    "auto-parodistici": "auto-parodistico",
    "auto-persecutori": "auto-persecutorio",
    "auto-persecutoria": "auto-persecutorio",
    "auto-persecutorie": "auto-persecutorio",
    "auto-protettiva": "auto-protettivo",
    "auto-protettive": "auto-protettivo",
    "auto-protettivi": "auto-protettivo",
    "auto-punitiva": "auto-punitivo",
    "auto-punitive": "auto-punitivo",
    "auto-punitivi": "auto-punitivo",
    "auto-referenziali": "auto-referenziale",
    "auto-segregata": "auto-segregato",
    "auto-segregate": "auto-segregato",
    "auto-segregati": "auto-segregato",
    "auto-termoregolanti": "auto-termoregolante",
    "autoaccusa": "autoaccusare",
    "autoaccusai": "autoaccusare",
    "autoaccusammo": "autoaccusare",
    "autoaccusan": "autoaccusare",
    "autoaccusando": "autoaccusare",
    "autoaccusano": "autoaccusare",
    "autoaccusante": "autoaccusare",
    "autoaccusanti": "autoaccusare",
    "autoaccusar": "autoaccusare",
    "autoaccusaron": "autoaccusare",
    "autoaccusarono": "autoaccusare",
    "autoaccusasse": "autoaccusare",
    "autoaccusasser": "autoaccusare",
    "autoaccusassero": "autoaccusare",
    "autoaccusassi": "autoaccusare",
    "autoaccusassimo": "autoaccusare",
    "autoaccusaste": "autoaccusare",
    "autoaccusasti": "autoaccusare",
    "autoaccusata": "autoaccusare",
    "autoaccusate": "autoaccusare",
    "autoaccusati": "autoaccusare",
    "autoaccusato": "autoaccusare",
    "autoaccusava": "autoaccusare",
    "autoaccusavamo": "autoaccusare",
    "autoaccusavan": "autoaccusare",
    "autoaccusavano": "autoaccusare",
    "autoaccusavate": "autoaccusare",
    "autoaccusavi": "autoaccusare",
    "autoaccusavo": "autoaccusare",
    "autoaccuse": "autoaccusa",
    "autoaccuserai": "autoaccusare",
    "autoaccuseran": "autoaccusare",
    "autoaccuseranno": "autoaccusare",
    "autoaccuserebbe": "autoaccusare",
    "autoaccuserebber": "autoaccusare",
    "autoaccuserebbero": "autoaccusare",
    "autoaccuserei": "autoaccusare",
    "autoaccuseremmo": "autoaccusare",
    "autoaccuseremo": "autoaccusare",
    "autoaccusereste": "autoaccusare",
    "autoaccuseresti": "autoaccusare",
    "autoaccuserete": "autoaccusare",
    "autoaccuserà": "autoaccusare",
    "autoaccuserò": "autoaccusare",
    "autoaccusi": "autoaccusare",
    "autoaccusiamo": "autoaccusare",
    "autoaccusiate": "autoaccusare",
    "autoaccusin": "autoaccusare",
    "autoaccusino": "autoaccusare",
    "autoaccuso": "autoaccusare",
    "autoaccusò": "autoaccusare",
    "autoadesiva": "autoadesivo",
    "autoadesive": "autoadesivo",
    "autoadesivi": "autoadesivo",
    "autoaggrega": "autoaggregare",
    "autoaggregai": "autoaggregare",
    "autoaggregammo": "autoaggregare",
    "autoaggregan": "autoaggregare",
    "autoaggregando": "autoaggregare",
    "autoaggregano": "autoaggregare",
    "autoaggregante": "autoaggregare",
    "autoaggreganti": "autoaggregare",
    "autoaggregar": "autoaggregare",
    "autoaggregaron": "autoaggregare",
    "autoaggregarono": "autoaggregare",
    "autoaggregasse": "autoaggregare",
    "autoaggregasser": "autoaggregare",
    "autoaggregassero": "autoaggregare",
    "autoaggregassi": "autoaggregare",
    "autoaggregassimo": "autoaggregare",
    "autoaggregaste": "autoaggregare",
    "autoaggregasti": "autoaggregare",
    "autoaggregata": "autoaggregare",
    "autoaggregate": "autoaggregare",
    "autoaggregati": "autoaggregare",
    "autoaggregato": "autoaggregare",
    "autoaggregava": "autoaggregare",
    "autoaggregavamo": "autoaggregare",
    "autoaggregavan": "autoaggregare",
    "autoaggregavano": "autoaggregare",
    "autoaggregavate": "autoaggregare",
    "autoaggregavi": "autoaggregare",
    "autoaggregavo": "autoaggregare",
    "autoaggregherai": "autoaggregare",
    "autoaggregheran": "autoaggregare",
    "autoaggregheranno": "autoaggregare",
    "autoaggregherebbe": "autoaggregare",
    "autoaggregherebber": "autoaggregare",
    "autoaggregherebbero": "autoaggregare",
    "autoaggregherei": "autoaggregare",
    "autoaggregheremmo": "autoaggregare",
    "autoaggregheremo": "autoaggregare",
    "autoaggreghereste": "autoaggregare",
    "autoaggregheresti": "autoaggregare",
    "autoaggregherete": "autoaggregare",
    "autoaggregherà": "autoaggregare",
    "autoaggregherò": "autoaggregare",
    "autoaggreghi": "autoaggregare",
    "autoaggreghiamo": "autoaggregare",
    "autoaggreghiate": "autoaggregare",
    "autoaggreghin": "autoaggregare",
    "autoaggreghino": "autoaggregare",
    "autoaggrego": "autoaggregare",
    "autoaggregò": "autoaggregare",
    "autoalimenta": "autoalimentare",
    "autoalimentai": "autoalimentare",
    "autoalimentammo": "autoalimentare",
    "autoalimentan": "autoalimentare",
    "autoalimentando": "autoalimentare",
    "autoalimentano": "autoalimentare",
    "autoalimentante": "autoalimentare",
    "autoalimentanti": "autoalimentare",
    "autoalimentar": "autoalimentare",
    "autoalimentaron": "autoalimentare",
    "autoalimentarono": "autoalimentare",
    "autoalimentasse": "autoalimentare",
    "autoalimentasser": "autoalimentare",
    "autoalimentassero": "autoalimentare",
    "autoalimentassi": "autoalimentare",
    "autoalimentassimo": "autoalimentare",
    "autoalimentaste": "autoalimentare",
    "autoalimentasti": "autoalimentare",
    "autoalimentata": "autoalimentare",
    "autoalimentate": "autoalimentare",
    "autoalimentati": "autoalimentare",
    "autoalimentato": "autoalimentare",
    "autoalimentava": "autoalimentare",
    "autoalimentavamo": "autoalimentare",
    "autoalimentavan": "autoalimentare",
    "autoalimentavano": "autoalimentare",
    "autoalimentavate": "autoalimentare",
    "autoalimentavi": "autoalimentare",
    "autoalimentavo": "autoalimentare",
    "autoalimenterai": "autoalimentare",
    "autoalimenteran": "autoalimentare",
    "autoalimenteranno": "autoalimentare",
    "autoalimenterebbe": "autoalimentare",
    "autoalimenterebber": "autoalimentare",
    "autoalimenterebbero": "autoalimentare",
    "autoalimenterei": "autoalimentare",
    "autoalimenteremmo": "autoalimentare",
    "autoalimenteremo": "autoalimentare",
    "autoalimentereste": "autoalimentare",
    "autoalimenteresti": "autoalimentare",
    "autoalimenterete": "autoalimentare",
    "autoalimenterà": "autoalimentare",
    "autoalimenterò": "autoalimentare",
    "autoalimenti": "autoalimentare",
    "autoalimentiamo": "autoalimentare",
    "autoalimentiate": "autoalimentare",
    "autoalimentin": "autoalimentare",
    "autoalimentino": "autoalimentare",
    "autoalimento": "autoalimentare",
    "autoalimentò": "autoalimentare",
    "autoambulanze": "autoambulanza",
    "autoanalizza": "autoanalizzare",
    "autoanalizzai": "autoanalizzare",
    "autoanalizzammo": "autoanalizzare",
    "autoanalizzan": "autoanalizzare",
    "autoanalizzando": "autoanalizzare",
    "autoanalizzano": "autoanalizzare",
    "autoanalizzante": "autoanalizzare",
    "autoanalizzanti": "autoanalizzare",
    "autoanalizzar": "autoanalizzare",
    "autoanalizzaron": "autoanalizzare",
    "autoanalizzarono": "autoanalizzare",
    "autoanalizzasse": "autoanalizzare",
    "autoanalizzasser": "autoanalizzare",
    "autoanalizzassero": "autoanalizzare",
    "autoanalizzassi": "autoanalizzare",
    "autoanalizzassimo": "autoanalizzare",
    "autoanalizzaste": "autoanalizzare",
    "autoanalizzasti": "autoanalizzare",
    "autoanalizzata": "autoanalizzare",
    "autoanalizzate": "autoanalizzare",
    "autoanalizzati": "autoanalizzare",
    "autoanalizzato": "autoanalizzare",
    "autoanalizzava": "autoanalizzare",
    "autoanalizzavamo": "autoanalizzare",
    "autoanalizzavan": "autoanalizzare",
    "autoanalizzavano": "autoanalizzare",
    "autoanalizzavate": "autoanalizzare",
    "autoanalizzavi": "autoanalizzare",
    "autoanalizzavo": "autoanalizzare",
    "autoanalizzerai": "autoanalizzare",
    "autoanalizzeran": "autoanalizzare",
    "autoanalizzeranno": "autoanalizzare",
    "autoanalizzerebbe": "autoanalizzare",
    "autoanalizzerebber": "autoanalizzare",
    "autoanalizzerebbero": "autoanalizzare",
    "autoanalizzerei": "autoanalizzare",
    "autoanalizzeremmo": "autoanalizzare",
    "autoanalizzeremo": "autoanalizzare",
    "autoanalizzereste": "autoanalizzare",
    "autoanalizzeresti": "autoanalizzare",
    "autoanalizzerete": "autoanalizzare",
    "autoanalizzerà": "autoanalizzare",
    "autoanalizzerò": "autoanalizzare",
    "autoanalizzi": "autoanalizzare",
    "autoanalizziamo": "autoanalizzare",
    "autoanalizziate": "autoanalizzare",
    "autoanalizzin": "autoanalizzare",
    "autoanalizzino": "autoanalizzare",
    "autoanalizzo": "autoanalizzare",
    "autoanalizzò": "autoanalizzare",
    "autoannuncerai": "autoannunciare",
    "autoannunceran": "autoannunciare",
    "autoannunceranno": "autoannunciare",
    "autoannuncerebbe": "autoannunciare",
    "autoannuncerebber": "autoannunciare",
    "autoannuncerebbero": "autoannunciare",
    "autoannuncerei": "autoannunciare",
    "autoannunceremmo": "autoannunciare",
    "autoannunceremo": "autoannunciare",
    "autoannuncereste": "autoannunciare",
    "autoannunceresti": "autoannunciare",
    "autoannuncerete": "autoannunciare",
    "autoannuncerà": "autoannunciare",
    "autoannuncerò": "autoannunciare",
    "autoannunci": "autoannunciare",
    "autoannuncia": "autoannunciare",
    "autoannunciai": "autoannunciare",
    "autoannunciammo": "autoannunciare",
    "autoannunciamo": "autoannunciare",
    "autoannuncian": "autoannunciare",
    "autoannunciando": "autoannunciare",
    "autoannunciano": "autoannunciare",
    "autoannunciante": "autoannunciare",
    "autoannuncianti": "autoannunciare",
    "autoannunciar": "autoannunciare",
    "autoannunciaron": "autoannunciare",
    "autoannunciarono": "autoannunciare",
    "autoannunciasse": "autoannunciare",
    "autoannunciasser": "autoannunciare",
    "autoannunciassero": "autoannunciare",
    "autoannunciassi": "autoannunciare",
    "autoannunciassimo": "autoannunciare",
    "autoannunciaste": "autoannunciare",
    "autoannunciasti": "autoannunciare",
    "autoannunciata": "autoannunciare",
    "autoannunciate": "autoannunciare",
    "autoannunciati": "autoannunciare",
    "autoannunciato": "autoannunciare",
    "autoannunciava": "autoannunciare",
    "autoannunciavamo": "autoannunciare",
    "autoannunciavan": "autoannunciare",
    "autoannunciavano": "autoannunciare",
    "autoannunciavate": "autoannunciare",
    "autoannunciavi": "autoannunciare",
    "autoannunciavo": "autoannunciare",
    "autoannuncin": "autoannunciare",
    "autoannuncino": "autoannunciare",
    "autoannuncio": "autoannunciare",
    "autoannunciò": "autoannunciare",
    "autoarticolati": "autoarticolato",
    "autoassegna": "autoassegnare",
    "autoassegnai": "autoassegnare",
    "autoassegnammo": "autoassegnare",
    "autoassegnan": "autoassegnare",
    "autoassegnando": "autoassegnare",
    "autoassegnano": "autoassegnare",
    "autoassegnante": "autoassegnare",
    "autoassegnanti": "autoassegnare",
    "autoassegnar": "autoassegnare",
    "autoassegnaron": "autoassegnare",
    "autoassegnarono": "autoassegnare",
    "autoassegnasse": "autoassegnare",
    "autoassegnasser": "autoassegnare",
    "autoassegnassero": "autoassegnare",
    "autoassegnassi": "autoassegnare",
    "autoassegnassimo": "autoassegnare",
    "autoassegnaste": "autoassegnare",
    "autoassegnasti": "autoassegnare",
    "autoassegnata": "autoassegnare",
    "autoassegnate": "autoassegnare",
    "autoassegnati": "autoassegnare",
    "autoassegnato": "autoassegnare",
    "autoassegnava": "autoassegnare",
    "autoassegnavamo": "autoassegnare",
    "autoassegnavan": "autoassegnare",
    "autoassegnavano": "autoassegnare",
    "autoassegnavate": "autoassegnare",
    "autoassegnavi": "autoassegnare",
    "autoassegnavo": "autoassegnare",
    "autoassegnerai": "autoassegnare",
    "autoassegneran": "autoassegnare",
    "autoassegneranno": "autoassegnare",
    "autoassegnerebbe": "autoassegnare",
    "autoassegnerebber": "autoassegnare",
    "autoassegnerebbero": "autoassegnare",
    "autoassegnerei": "autoassegnare",
    "autoassegneremmo": "autoassegnare",
    "autoassegneremo": "autoassegnare",
    "autoassegnereste": "autoassegnare",
    "autoassegneresti": "autoassegnare",
    "autoassegnerete": "autoassegnare",
    "autoassegnerà": "autoassegnare",
    "autoassegnerò": "autoassegnare",
    "autoassegni": "autoassegnare",
    "autoassegniamo": "autoassegnare",
    "autoassegniate": "autoassegnare",
    "autoassegnin": "autoassegnare",
    "autoassegnino": "autoassegnare",
    "autoassegno": "autoassegnare",
    "autoassegnò": "autoassegnare",
    "autoassolva": "autoassolvere",
    "autoassolvan": "autoassolvere",
    "autoassolvano": "autoassolvere",
    "autoassolve": "autoassolvere",
    "autoassolvei": "autoassolvere",
    "autoassolvemmo": "autoassolvere",
    "autoassolvendo": "autoassolvere",
    "autoassolvente": "autoassolvere",
    "autoassolventi": "autoassolvere",
    "autoassolver": "autoassolvere",
    "autoassolverai": "autoassolvere",
    "autoassolveran": "autoassolvere",
    "autoassolveranno": "autoassolvere",
    "autoassolverebbe": "autoassolvere",
    "autoassolverebber": "autoassolvere",
    "autoassolverebbero": "autoassolvere",
    "autoassolverei": "autoassolvere",
    "autoassolveremmo": "autoassolvere",
    "autoassolveremo": "autoassolvere",
    "autoassolvereste": "autoassolvere",
    "autoassolveresti": "autoassolvere",
    "autoassolverete": "autoassolvere",
    "autoassolveron": "autoassolvere",
    "autoassolverono": "autoassolvere",
    "autoassolverà": "autoassolvere",
    "autoassolverò": "autoassolvere",
    "autoassolvesse": "autoassolvere",
    "autoassolvesser": "autoassolvere",
    "autoassolvessero": "autoassolvere",
    "autoassolvessi": "autoassolvere",
    "autoassolvessimo": "autoassolvere",
    "autoassolveste": "autoassolvere",
    "autoassolvesti": "autoassolvere",
    "autoassolvete": "autoassolvere",
    "autoassolveva": "autoassolvere",
    "autoassolvevamo": "autoassolvere",
    "autoassolvevan": "autoassolvere",
    "autoassolvevano": "autoassolvere",
    "autoassolvevate": "autoassolvere",
    "autoassolvevi": "autoassolvere",
    "autoassolvevo": "autoassolvere",
    "autoassolvi": "autoassolvere",
    "autoassolviamo": "autoassolvere",
    "autoassolviate": "autoassolvere",
    "autoassolvo": "autoassolvere",
    "autoassolvon": "autoassolvere",
    "autoassolvono": "autoassolvere",
    "autoassolvuta": "autoassolvere",
    "autoassolvute": "autoassolvere",
    "autoassolvuti": "autoassolvere",
    "autoassolvuto": "autoassolvere",
    "autoassolvè": "autoassolvere",
    "autoattribuita": "autoattribuito",
    "autoattribuite": "autoattribuito",
    "autoattribuiti": "autoattribuito",
    "autobiografica": "autobiografico",
    "autobiografiche": "autobiografico",
    "autobiografici": "autobiografico",
    "autobiografie": "autobiografia",
    "autoblinde": "autoblinda",
    "autoblocca": "autobloccare",
    "autobloccai": "autobloccare",
    "autobloccammo": "autobloccare",
    "autobloccan": "autobloccare",
    "autobloccando": "autobloccare",
    "autobloccano": "autobloccare",
    "autobloccante": "autobloccare",
    "autobloccanti": "autobloccare",
    "autobloccar": "autobloccare",
    "autobloccaron": "autobloccare",
    "autobloccarono": "autobloccare",
    "autobloccasse": "autobloccare",
    "autobloccasser": "autobloccare",
    "autobloccassero": "autobloccare",
    "autobloccassi": "autobloccare",
    "autobloccassimo": "autobloccare",
    "autobloccaste": "autobloccare",
    "autobloccasti": "autobloccare",
    "autobloccata": "autobloccare",
    "autobloccate": "autobloccare",
    "autobloccati": "autobloccare",
    "autobloccato": "autobloccare",
    "autobloccava": "autobloccare",
    "autobloccavamo": "autobloccare",
    "autobloccavan": "autobloccare",
    "autobloccavano": "autobloccare",
    "autobloccavate": "autobloccare",
    "autobloccavi": "autobloccare",
    "autobloccavo": "autobloccare",
    "autobloccherai": "autobloccare",
    "autobloccheran": "autobloccare",
    "autobloccheranno": "autobloccare",
    "autobloccherebbe": "autobloccare",
    "autobloccherebber": "autobloccare",
    "autobloccherebbero": "autobloccare",
    "autobloccherei": "autobloccare",
    "autobloccheremmo": "autobloccare",
    "autobloccheremo": "autobloccare",
    "autoblocchereste": "autobloccare",
    "autobloccheresti": "autobloccare",
    "autobloccherete": "autobloccare",
    "autobloccherà": "autobloccare",
    "autobloccherò": "autobloccare",
    "autoblocchi": "autobloccare",
    "autoblocchiamo": "autobloccare",
    "autoblocchiate": "autobloccare",
    "autoblocchin": "autobloccare",
    "autoblocchino": "autobloccare",
    "autoblocco": "autobloccare",
    "autobloccò": "autobloccare",
    "autobombe": "autobomba",
    "autobotti": "autobotte",
    "autocancella": "autocancellare",
    "autocancellai": "autocancellare",
    "autocancellammo": "autocancellare",
    "autocancellan": "autocancellare",
    "autocancellando": "autocancellare",
    "autocancellano": "autocancellare",
    "autocancellante": "autocancellare",
    "autocancellanti": "autocancellare",
    "autocancellar": "autocancellare",
    "autocancellaron": "autocancellare",
    "autocancellarono": "autocancellare",
    "autocancellasse": "autocancellare",
    "autocancellasser": "autocancellare",
    "autocancellassero": "autocancellare",
    "autocancellassi": "autocancellare",
    "autocancellassimo": "autocancellare",
    "autocancellaste": "autocancellare",
    "autocancellasti": "autocancellare",
    "autocancellata": "autocancellare",
    "autocancellate": "autocancellare",
    "autocancellati": "autocancellare",
    "autocancellato": "autocancellare",
    "autocancellava": "autocancellare",
    "autocancellavamo": "autocancellare",
    "autocancellavan": "autocancellare",
    "autocancellavano": "autocancellare",
    "autocancellavate": "autocancellare",
    "autocancellavi": "autocancellare",
    "autocancellavo": "autocancellare",
    "autocancellerai": "autocancellare",
    "autocancelleran": "autocancellare",
    "autocancelleranno": "autocancellare",
    "autocancellerebbe": "autocancellare",
    "autocancellerebber": "autocancellare",
    "autocancellerebbero": "autocancellare",
    "autocancellerei": "autocancellare",
    "autocancelleremmo": "autocancellare",
    "autocancelleremo": "autocancellare",
    "autocancellereste": "autocancellare",
    "autocancelleresti": "autocancellare",
    "autocancellerete": "autocancellare",
    "autocancellerà": "autocancellare",
    "autocancellerò": "autocancellare",
    "autocancelli": "autocancellare",
    "autocancelliamo": "autocancellare",
    "autocancelliate": "autocancellare",
    "autocancellin": "autocancellare",
    "autocancellino": "autocancellare",
    "autocancello": "autocancellare",
    "autocancellò": "autocancellare",
    "autocandida": "autocandidare",
    "autocandidai": "autocandidare",
    "autocandidammo": "autocandidare",
    "autocandidan": "autocandidare",
    "autocandidando": "autocandidare",
    "autocandidano": "autocandidare",
    "autocandidar": "autocandidare",
    "autocandidaron": "autocandidare",
    "autocandidarono": "autocandidare",
    "autocandidasse": "autocandidare",
    "autocandidasser": "autocandidare",
    "autocandidassero": "autocandidare",
    "autocandidassi": "autocandidare",
    "autocandidassimo": "autocandidare",
    "autocandidaste": "autocandidare",
    "autocandidasti": "autocandidare",
    "autocandidata": "autocandidare",
    "autocandidate": "autocandidare",
    "autocandidati": "autocandidare",
    "autocandidato": "autocandidare",
    "autocandidature": "autocandidatura",
    "autocandidava": "autocandidare",
    "autocandidavamo": "autocandidare",
    "autocandidavan": "autocandidare",
    "autocandidavano": "autocandidare",
    "autocandidavate": "autocandidare",
    "autocandidavi": "autocandidare",
    "autocandidavo": "autocandidare",
    "autocandiderai": "autocandidare",
    "autocandideran": "autocandidare",
    "autocandideranno": "autocandidare",
    "autocandiderebbe": "autocandidare",
    "autocandiderebber": "autocandidare",
    "autocandiderebbero": "autocandidare",
    "autocandiderei": "autocandidare",
    "autocandideremmo": "autocandidare",
    "autocandideremo": "autocandidare",
    "autocandidereste": "autocandidare",
    "autocandideresti": "autocandidare",
    "autocandiderete": "autocandidare",
    "autocandiderà": "autocandidare",
    "autocandiderò": "autocandidare",
    "autocandidi": "autocandidare",
    "autocandidiamo": "autocandidare",
    "autocandidiate": "autocandidare",
    "autocandidin": "autocandidare",
    "autocandidino": "autocandidare",
    "autocandido": "autocandidare",
    "autocandidò": "autocandidare",
    "autocarri": "autocarro",
    "autocelebra": "autocelebrare",
    "autocelebrai": "autocelebrare",
    "autocelebrammo": "autocelebrare",
    "autocelebran": "autocelebrare",
    "autocelebrando": "autocelebrare",
    "autocelebrano": "autocelebrare",
    "autocelebrante": "autocelebrare",
    "autocelebranti": "autocelebrare",
    "autocelebrar": "autocelebrare",
    "autocelebraron": "autocelebrare",
    "autocelebrarono": "autocelebrare",
    "autocelebrasse": "autocelebrare",
    "autocelebrasser": "autocelebrare",
    "autocelebrassero": "autocelebrare",
    "autocelebrassi": "autocelebrare",
    "autocelebrassimo": "autocelebrare",
    "autocelebraste": "autocelebrare",
    "autocelebrasti": "autocelebrare",
    "autocelebrata": "autocelebrato",
    "autocelebrate": "autocelebrato",
    "autocelebrati": "autocelebrato",
    "autocelebrativa": "autocelebrativo",
    "autocelebrative": "autocelebrativo",
    "autocelebrativi": "autocelebrativo",
    "autocelebrato": "autocelebrare",
    "autocelebrava": "autocelebrare",
    "autocelebravamo": "autocelebrare",
    "autocelebravan": "autocelebrare",
    "autocelebravano": "autocelebrare",
    "autocelebravate": "autocelebrare",
    "autocelebravi": "autocelebrare",
    "autocelebravo": "autocelebrare",
    "autocelebrazioni": "autocelebrazione",
    "autocelebrerai": "autocelebrare",
    "autocelebreran": "autocelebrare",
    "autocelebreranno": "autocelebrare",
    "autocelebrerebbe": "autocelebrare",
    "autocelebrerebber": "autocelebrare",
    "autocelebrerebbero": "autocelebrare",
    "autocelebrerei": "autocelebrare",
    "autocelebreremmo": "autocelebrare",
    "autocelebreremo": "autocelebrare",
    "autocelebrereste": "autocelebrare",
    "autocelebreresti": "autocelebrare",
    "autocelebrerete": "autocelebrare",
    "autocelebrerà": "autocelebrare",
    "autocelebrerò": "autocelebrare",
    "autocelebri": "autocelebrare",
    "autocelebriamo": "autocelebrare",
    "autocelebriate": "autocelebrare",
    "autocelebrin": "autocelebrare",
    "autocelebrino": "autocelebrare",
    "autocelebro": "autocelebrare",
    "autocelebrò": "autocelebrare",
    "autocensura": "autocensurare",
    "autocensurai": "autocensurare",
    "autocensurammo": "autocensurare",
    "autocensuran": "autocensurare",
    "autocensurando": "autocensurare",
    "autocensurano": "autocensurare",
    "autocensurante": "autocensurare",
    "autocensuranti": "autocensurare",
    "autocensurar": "autocensurare",
    "autocensuraron": "autocensurare",
    "autocensurarono": "autocensurare",
    "autocensurasse": "autocensurare",
    "autocensurasser": "autocensurare",
    "autocensurassero": "autocensurare",
    "autocensurassi": "autocensurare",
    "autocensurassimo": "autocensurare",
    "autocensuraste": "autocensurare",
    "autocensurasti": "autocensurare",
    "autocensurata": "autocensurare",
    "autocensurate": "autocensurare",
    "autocensurati": "autocensurare",
    "autocensurato": "autocensurare",
    "autocensurava": "autocensurare",
    "autocensuravamo": "autocensurare",
    "autocensuravan": "autocensurare",
    "autocensuravano": "autocensurare",
    "autocensuravate": "autocensurare",
    "autocensuravi": "autocensurare",
    "autocensuravo": "autocensurare",
    "autocensure": "autocensura",
    "autocensurerai": "autocensurare",
    "autocensureran": "autocensurare",
    "autocensureranno": "autocensurare",
    "autocensurerebbe": "autocensurare",
    "autocensurerebber": "autocensurare",
    "autocensurerebbero": "autocensurare",
    "autocensurerei": "autocensurare",
    "autocensureremmo": "autocensurare",
    "autocensureremo": "autocensurare",
    "autocensurereste": "autocensurare",
    "autocensureresti": "autocensurare",
    "autocensurerete": "autocensurare",
    "autocensurerà": "autocensurare",
    "autocensurerò": "autocensurare",
    "autocensuri": "autocensurare",
    "autocensuriamo": "autocensurare",
    "autocensuriate": "autocensurare",
    "autocensurin": "autocensurare",
    "autocensurino": "autocensurare",
    "autocensuro": "autocensurare",
    "autocensurò": "autocensurare",
    "autocentranti": "autocentrante",
    "autocentrica": "autocentrico",
    "autocentriche": "autocentrico",
    "autocentrici": "autocentrico",
    "autocertifica": "autocertificare",
    "autocertificai": "autocertificare",
    "autocertificammo": "autocertificare",
    "autocertifican": "autocertificare",
    "autocertificando": "autocertificare",
    "autocertificano": "autocertificare",
    "autocertificante": "autocertificare",
    "autocertificanti": "autocertificare",
    "autocertificar": "autocertificare",
    "autocertificaron": "autocertificare",
    "autocertificarono": "autocertificare",
    "autocertificasse": "autocertificare",
    "autocertificasser": "autocertificare",
    "autocertificassero": "autocertificare",
    "autocertificassi": "autocertificare",
    "autocertificassimo": "autocertificare",
    "autocertificaste": "autocertificare",
    "autocertificasti": "autocertificare",
    "autocertificata": "autocertificare",
    "autocertificate": "autocertificare",
    "autocertificati": "autocertificare",
    "autocertificato": "autocertificare",
    "autocertificava": "autocertificare",
    "autocertificavamo": "autocertificare",
    "autocertificavan": "autocertificare",
    "autocertificavano": "autocertificare",
    "autocertificavate": "autocertificare",
    "autocertificavi": "autocertificare",
    "autocertificavo": "autocertificare",
    "autocertificazioni": "autocertificazione",
    "autocertificherai": "autocertificare",
    "autocertificheran": "autocertificare",
    "autocertificheranno": "autocertificare",
    "autocertificherebbe": "autocertificare",
    "autocertificherebber": "autocertificare",
    "autocertificherebbero": "autocertificare",
    "autocertificherei": "autocertificare",
    "autocertificheremmo": "autocertificare",
    "autocertificheremo": "autocertificare",
    "autocertifichereste": "autocertificare",
    "autocertificheresti": "autocertificare",
    "autocertificherete": "autocertificare",
    "autocertificherà": "autocertificare",
    "autocertificherò": "autocertificare",
    "autocertifichi": "autocertificare",
    "autocertifichiamo": "autocertificare",
    "autocertifichiate": "autocertificare",
    "autocertifichin": "autocertificare",
    "autocertifichino": "autocertificare",
    "autocertifico": "autocertificare",
    "autocertificò": "autocertificare",
    "autocita": "autocitare",
    "autocitai": "autocitare",
    "autocitammo": "autocitare",
    "autocitan": "autocitare",
    "autocitando": "autocitare",
    "autocitano": "autocitare",
    "autocitante": "autocitare",
    "autocitanti": "autocitare",
    "autocitar": "autocitare",
    "autocitaron": "autocitare",
    "autocitarono": "autocitare",
    "autocitasse": "autocitare",
    "autocitasser": "autocitare",
    "autocitassero": "autocitare",
    "autocitassi": "autocitare",
    "autocitassimo": "autocitare",
    "autocitaste": "autocitare",
    "autocitasti": "autocitare",
    "autocitata": "autocitare",
    "autocitate": "autocitare",
    "autocitati": "autocitare",
    "autocitato": "autocitare",
    "autocitava": "autocitare",
    "autocitavamo": "autocitare",
    "autocitavan": "autocitare",
    "autocitavano": "autocitare",
    "autocitavate": "autocitare",
    "autocitavi": "autocitare",
    "autocitavo": "autocitare",
    "autocitazioni": "autocitazione",
    "autociterai": "autocitare",
    "autociteran": "autocitare",
    "autociteranno": "autocitare",
    "autociterebbe": "autocitare",
    "autociterebber": "autocitare",
    "autociterebbero": "autocitare",
    "autociterei": "autocitare",
    "autociteremmo": "autocitare",
    "autociteremo": "autocitare",
    "autocitereste": "autocitare",
    "autociteresti": "autocitare",
    "autociterete": "autocitare",
    "autociterà": "autocitare",
    "autociterò": "autocitare",
    "autociti": "autocitare",
    "autocitiamo": "autocitare",
    "autocitiate": "autocitare",
    "autocitin": "autocitare",
    "autocitino": "autocitare",
    "autocito": "autocitare",
    "autocitò": "autocitare",
    "autoclavi": "autoclave",
    "autocolonizza": "autocolonizzare",
    "autocolonizzai": "autocolonizzare",
    "autocolonizzammo": "autocolonizzare",
    "autocolonizzan": "autocolonizzare",
    "autocolonizzando": "autocolonizzare",
    "autocolonizzano": "autocolonizzare",
    "autocolonizzante": "autocolonizzare",
    "autocolonizzanti": "autocolonizzare",
    "autocolonizzar": "autocolonizzare",
    "autocolonizzaron": "autocolonizzare",
    "autocolonizzarono": "autocolonizzare",
    "autocolonizzasse": "autocolonizzare",
    "autocolonizzasser": "autocolonizzare",
    "autocolonizzassero": "autocolonizzare",
    "autocolonizzassi": "autocolonizzare",
    "autocolonizzassimo": "autocolonizzare",
    "autocolonizzaste": "autocolonizzare",
    "autocolonizzasti": "autocolonizzare",
    "autocolonizzata": "autocolonizzare",
    "autocolonizzate": "autocolonizzare",
    "autocolonizzati": "autocolonizzare",
    "autocolonizzato": "autocolonizzare",
    "autocolonizzava": "autocolonizzare",
    "autocolonizzavamo": "autocolonizzare",
    "autocolonizzavan": "autocolonizzare",
    "autocolonizzavano": "autocolonizzare",
    "autocolonizzavate": "autocolonizzare",
    "autocolonizzavi": "autocolonizzare",
    "autocolonizzavo": "autocolonizzare",
    "autocolonizzerai": "autocolonizzare",
    "autocolonizzeran": "autocolonizzare",
    "autocolonizzeranno": "autocolonizzare",
    "autocolonizzerebbe": "autocolonizzare",
    "autocolonizzerebber": "autocolonizzare",
    "autocolonizzerebbero": "autocolonizzare",
    "autocolonizzerei": "autocolonizzare",
    "autocolonizzeremmo": "autocolonizzare",
    "autocolonizzeremo": "autocolonizzare",
    "autocolonizzereste": "autocolonizzare",
    "autocolonizzeresti": "autocolonizzare",
    "autocolonizzerete": "autocolonizzare",
    "autocolonizzerà": "autocolonizzare",
    "autocolonizzerò": "autocolonizzare",
    "autocolonizzi": "autocolonizzare",
    "autocolonizziamo": "autocolonizzare",
    "autocolonizziate": "autocolonizzare",
    "autocolonizzin": "autocolonizzare",
    "autocolonizzino": "autocolonizzare",
    "autocolonizzo": "autocolonizzare",
    "autocolonizzò": "autocolonizzare",
    "autocoltivata": "autocoltivato",
    "autocoltivate": "autocoltivato",
    "autocoltivati": "autocoltivato",
    "autocommemorativa": "autocommemorativo",
    "autocommemorative": "autocommemorativo",
    "autocommemorativi": "autocommemorativo",
    "autocommisera": "autocommiserare",
    "autocommiserai": "autocommiserare",
    "autocommiserammo": "autocommiserare",
    "autocommiseran": "autocommiserare",
    "autocommiserando": "autocommiserare",
    "autocommiserano": "autocommiserare",
    "autocommiserante": "autocommiserare",
    "autocommiseranti": "autocommiserare",
    "autocommiserar": "autocommiserare",
    "autocommiseraron": "autocommiserare",
    "autocommiserarono": "autocommiserare",
    "autocommiserasse": "autocommiserare",
    "autocommiserasser": "autocommiserare",
    "autocommiserassero": "autocommiserare",
    "autocommiserassi": "autocommiserare",
    "autocommiserassimo": "autocommiserare",
    "autocommiseraste": "autocommiserare",
    "autocommiserasti": "autocommiserare",
    "autocommiserata": "autocommiserare",
    "autocommiserate": "autocommiserare",
    "autocommiserati": "autocommiserare",
    "autocommiserato": "autocommiserare",
    "autocommiserava": "autocommiserare",
    "autocommiseravamo": "autocommiserare",
    "autocommiseravan": "autocommiserare",
    "autocommiseravano": "autocommiserare",
    "autocommiseravate": "autocommiserare",
    "autocommiseravi": "autocommiserare",
    "autocommiseravo": "autocommiserare",
    "autocommisererai": "autocommiserare",
    "autocommisereran": "autocommiserare",
    "autocommisereranno": "autocommiserare",
    "autocommisererebbe": "autocommiserare",
    "autocommisererebber": "autocommiserare",
    "autocommisererebbero": "autocommiserare",
    "autocommisererei": "autocommiserare",
    "autocommisereremmo": "autocommiserare",
    "autocommisereremo": "autocommiserare",
    "autocommiserereste": "autocommiserare",
    "autocommisereresti": "autocommiserare",
    "autocommisererete": "autocommiserare",
    "autocommisererà": "autocommiserare",
    "autocommisererò": "autocommiserare",
    "autocommiseri": "autocommiserare",
    "autocommiseriamo": "autocommiserare",
    "autocommiseriate": "autocommiserare",
    "autocommiserin": "autocommiserare",
    "autocommiserino": "autocommiserare",
    "autocommisero": "autocommiserare",
    "autocommiserò": "autocommiserare",
    "autocompata": "autocompatire",
    "autocompatan": "autocompatire",
    "autocompatano": "autocompatire",
    "autocompate": "autocompatire",
    "autocompatendo": "autocompatire",
    "autocompatente": "autocompatire",
    "autocompatenti": "autocompatire",
    "autocompati": "autocompatire",
    "autocompatiamo": "autocompatire",
    "autocompatiate": "autocompatire",
    "autocompatii": "autocompatire",
    "autocompatimmo": "autocompatire",
    "autocompatir": "autocompatire",
    "autocompatirai": "autocompatire",
    "autocompatiran": "autocompatire",
    "autocompatiranno": "autocompatire",
    "autocompatirebbe": "autocompatire",
    "autocompatirebber": "autocompatire",
    "autocompatirebbero": "autocompatire",
    "autocompatirei": "autocompatire",
    "autocompatiremmo": "autocompatire",
    "autocompatiremo": "autocompatire",
    "autocompatireste": "autocompatire",
    "autocompatiresti": "autocompatire",
    "autocompatirete": "autocompatire",
    "autocompatiron": "autocompatire",
    "autocompatirono": "autocompatire",
    "autocompatirà": "autocompatire",
    "autocompatirò": "autocompatire",
    "autocompatisse": "autocompatire",
    "autocompatisser": "autocompatire",
    "autocompatissero": "autocompatire",
    "autocompatissi": "autocompatire",
    "autocompatissimo": "autocompatire",
    "autocompatiste": "autocompatire",
    "autocompatisti": "autocompatire",
    "autocompatita": "autocompatire",
    "autocompatite": "autocompatire",
    "autocompatiti": "autocompatire",
    "autocompatito": "autocompatire",
    "autocompativa": "autocompatire",
    "autocompativamo": "autocompatire",
    "autocompativan": "autocompatire",
    "autocompativano": "autocompatire",
    "autocompativate": "autocompatire",
    "autocompativi": "autocompatire",
    "autocompativo": "autocompatire",
    "autocompato": "autocompatire",
    "autocompaton": "autocompatire",
    "autocompatono": "autocompatire",
    "autocompatì": "autocompatire",
    "autocompiaca": "autocompiacere",
    "autocompiacan": "autocompiacere",
    "autocompiacano": "autocompiacere",
    "autocompiace": "autocompiacere",
    "autocompiacei": "autocompiacere",
    "autocompiacemmo": "autocompiacere",
    "autocompiacendo": "autocompiacere",
    "autocompiacente": "autocompiacere",
    "autocompiacenti": "autocompiacere",
    "autocompiacer": "autocompiacere",
    "autocompiacerai": "autocompiacere",
    "autocompiaceran": "autocompiacere",
    "autocompiaceranno": "autocompiacere",
    "autocompiacerebbe": "autocompiacere",
    "autocompiacerebber": "autocompiacere",
    "autocompiacerebbero": "autocompiacere",
    "autocompiacerei": "autocompiacere",
    "autocompiaceremmo": "autocompiacere",
    "autocompiaceremo": "autocompiacere",
    "autocompiacereste": "autocompiacere",
    "autocompiaceresti": "autocompiacere",
    "autocompiacerete": "autocompiacere",
    "autocompiaceron": "autocompiacere",
    "autocompiacerono": "autocompiacere",
    "autocompiacerà": "autocompiacere",
    "autocompiacerò": "autocompiacere",
    "autocompiacesse": "autocompiacere",
    "autocompiacesser": "autocompiacere",
    "autocompiacessero": "autocompiacere",
    "autocompiacessi": "autocompiacere",
    "autocompiacessimo": "autocompiacere",
    "autocompiaceste": "autocompiacere",
    "autocompiacesti": "autocompiacere",
    "autocompiacete": "autocompiacere",
    "autocompiaceva": "autocompiacere",
    "autocompiacevamo": "autocompiacere",
    "autocompiacevan": "autocompiacere",
    "autocompiacevano": "autocompiacere",
    "autocompiacevate": "autocompiacere",
    "autocompiacevi": "autocompiacere",
    "autocompiacevo": "autocompiacere",
    "autocompiaci": "autocompiacere",
    "autocompiaciamo": "autocompiacere",
    "autocompiaciate": "autocompiacere",
    "autocompiacimenti": "autocompiacimento",
    "autocompiaciuta": "autocompiacere",
    "autocompiaciute": "autocompiacere",
    "autocompiaciuti": "autocompiacere",
    "autocompiaciuto": "autocompiacere",
    "autocompiaco": "autocompiacere",
    "autocompiacon": "autocompiacere",
    "autocompiacono": "autocompiacere",
    "autocompiacè": "autocompiacere",
    "autoconclusa": "autoconcluso",
    "autoconcluse": "autoconcluso",
    "autoconclusi": "autoconcluso",
    "autocondannari": "autocondannare",
    "autoconferiri": "autoconferire",
    "autoconfinari": "autoconfinare",
    "autocongratulatori": "autocongratulatorio",
    "autocongratulatoria": "autocongratulatorio",
    "autocongratulatorie": "autocongratulatorio",
    "autoconsegna": "autoconsegnare",
    "autoconsegnai": "autoconsegnare",
    "autoconsegnammo": "autoconsegnare",
    "autoconsegnan": "autoconsegnare",
    "autoconsegnando": "autoconsegnare",
    "autoconsegnano": "autoconsegnare",
    "autoconsegnante": "autoconsegnare",
    "autoconsegnanti": "autoconsegnare",
    "autoconsegnar": "autoconsegnare",
    "autoconsegnaron": "autoconsegnare",
    "autoconsegnarono": "autoconsegnare",
    "autoconsegnasse": "autoconsegnare",
    "autoconsegnasser": "autoconsegnare",
    "autoconsegnassero": "autoconsegnare",
    "autoconsegnassi": "autoconsegnare",
    "autoconsegnassimo": "autoconsegnare",
    "autoconsegnaste": "autoconsegnare",
    "autoconsegnasti": "autoconsegnare",
    "autoconsegnata": "autoconsegnare",
    "autoconsegnate": "autoconsegnare",
    "autoconsegnati": "autoconsegnare",
    "autoconsegnato": "autoconsegnare",
    "autoconsegnava": "autoconsegnare",
    "autoconsegnavamo": "autoconsegnare",
    "autoconsegnavan": "autoconsegnare",
    "autoconsegnavano": "autoconsegnare",
    "autoconsegnavate": "autoconsegnare",
    "autoconsegnavi": "autoconsegnare",
    "autoconsegnavo": "autoconsegnare",
    "autoconsegnerai": "autoconsegnare",
    "autoconsegneran": "autoconsegnare",
    "autoconsegneranno": "autoconsegnare",
    "autoconsegnerebbe": "autoconsegnare",
    "autoconsegnerebber": "autoconsegnare",
    "autoconsegnerebbero": "autoconsegnare",
    "autoconsegnerei": "autoconsegnare",
    "autoconsegneremmo": "autoconsegnare",
    "autoconsegneremo": "autoconsegnare",
    "autoconsegnereste": "autoconsegnare",
    "autoconsegneresti": "autoconsegnare",
    "autoconsegnerete": "autoconsegnare",
    "autoconsegnerà": "autoconsegnare",
    "autoconsegnerò": "autoconsegnare",
    "autoconsegni": "autoconsegnare",
    "autoconsegniamo": "autoconsegnare",
    "autoconsegniate": "autoconsegnare",
    "autoconsegnin": "autoconsegnare",
    "autoconsegnino": "autoconsegnare",
    "autoconsegno": "autoconsegnare",
    "autoconsegnò": "autoconsegnare",
    "autocontrolla": "autocontrollare",
    "autocontrollai": "autocontrollare",
    "autocontrollammo": "autocontrollare",
    "autocontrollan": "autocontrollare",
    "autocontrollando": "autocontrollare",
    "autocontrollano": "autocontrollare",
    "autocontrollante": "autocontrollare",
    "autocontrollanti": "autocontrollare",
    "autocontrollar": "autocontrollare",
    "autocontrollaron": "autocontrollare",
    "autocontrollarono": "autocontrollare",
    "autocontrollasse": "autocontrollare",
    "autocontrollasser": "autocontrollare",
    "autocontrollassero": "autocontrollare",
    "autocontrollassi": "autocontrollare",
    "autocontrollassimo": "autocontrollare",
    "autocontrollaste": "autocontrollare",
    "autocontrollasti": "autocontrollare",
    "autocontrollata": "autocontrollare",
    "autocontrollate": "autocontrollare",
    "autocontrollati": "autocontrollare",
    "autocontrollato": "autocontrollare",
    "autocontrollava": "autocontrollare",
    "autocontrollavamo": "autocontrollare",
    "autocontrollavan": "autocontrollare",
    "autocontrollavano": "autocontrollare",
    "autocontrollavate": "autocontrollare",
    "autocontrollavi": "autocontrollare",
    "autocontrollavo": "autocontrollare",
    "autocontrollerai": "autocontrollare",
    "autocontrolleran": "autocontrollare",
    "autocontrolleranno": "autocontrollare",
    "autocontrollerebbe": "autocontrollare",
    "autocontrollerebber": "autocontrollare",
    "autocontrollerebbero": "autocontrollare",
    "autocontrollerei": "autocontrollare",
    "autocontrolleremmo": "autocontrollare",
    "autocontrolleremo": "autocontrollare",
    "autocontrollereste": "autocontrollare",
    "autocontrolleresti": "autocontrollare",
    "autocontrollerete": "autocontrollare",
    "autocontrollerà": "autocontrollare",
    "autocontrollerò": "autocontrollare",
    "autocontrolli": "autocontrollo",
    "autocontrolliamo": "autocontrollare",
    "autocontrolliate": "autocontrollare",
    "autocontrollin": "autocontrollare",
    "autocontrollino": "autocontrollare",
    "autocontrollo": "autocontrollare",
    "autocontrollò": "autocontrollare",
    "autoconvinca": "autoconvincere",
    "autoconvincan": "autoconvincere",
    "autoconvincano": "autoconvincere",
    "autoconvince": "autoconvincere",
    "autoconvincei": "autoconvincere",
    "autoconvincemmo": "autoconvincere",
    "autoconvincendo": "autoconvincere",
    "autoconvincente": "autoconvincere",
    "autoconvincenti": "autoconvincere",
    "autoconvincer": "autoconvincere",
    "autoconvincerai": "autoconvincere",
    "autoconvinceran": "autoconvincere",
    "autoconvinceranno": "autoconvincere",
    "autoconvincerebbe": "autoconvincere",
    "autoconvincerebber": "autoconvincere",
    "autoconvincerebbero": "autoconvincere",
    "autoconvincerei": "autoconvincere",
    "autoconvinceremmo": "autoconvincere",
    "autoconvinceremo": "autoconvincere",
    "autoconvincereste": "autoconvincere",
    "autoconvinceresti": "autoconvincere",
    "autoconvincerete": "autoconvincere",
    "autoconvinceron": "autoconvincere",
    "autoconvincerono": "autoconvincere",
    "autoconvincerà": "autoconvincere",
    "autoconvincerò": "autoconvincere",
    "autoconvincesse": "autoconvincere",
    "autoconvincesser": "autoconvincere",
    "autoconvincessero": "autoconvincere",
    "autoconvincessi": "autoconvincere",
    "autoconvincessimo": "autoconvincere",
    "autoconvinceste": "autoconvincere",
    "autoconvincesti": "autoconvincere",
    "autoconvincete": "autoconvincere",
    "autoconvinceva": "autoconvincere",
    "autoconvincevamo": "autoconvincere",
    "autoconvincevan": "autoconvincere",
    "autoconvincevano": "autoconvincere",
    "autoconvincevate": "autoconvincere",
    "autoconvincevi": "autoconvincere",
    "autoconvincevo": "autoconvincere",
    "autoconvinci": "autoconvincere",
    "autoconvinciamo": "autoconvincere",
    "autoconvinciate": "autoconvincere",
    "autoconvinco": "autoconvincere",
    "autoconvincon": "autoconvincere",
    "autoconvincono": "autoconvincere",
    "autoconvincuta": "autoconvincere",
    "autoconvincute": "autoconvincere",
    "autoconvincuti": "autoconvincere",
    "autoconvincuto": "autoconvincere",
    "autoconvincè": "autoconvincere",
    "autoconvinta": "autoconvinto",
    "autoconvinte": "autoconvinto",
    "autoconvinti": "autoconvinto",
    "autoconvocati": "autoconvocato",
    "autocorregga": "autocorreggere",
    "autocorreggan": "autocorreggere",
    "autocorreggano": "autocorreggere",
    "autocorregge": "autocorreggere",
    "autocorreggemmo": "autocorreggere",
    "autocorreggendo": "autocorreggere",
    "autocorreggente": "autocorreggere",
    "autocorreggenti": "autocorreggere",
    "autocorregger": "autocorreggere",
    "autocorreggerai": "autocorreggere",
    "autocorreggeran": "autocorreggere",
    "autocorreggeranno": "autocorreggere",
    "autocorreggerebbe": "autocorreggere",
    "autocorreggerebber": "autocorreggere",
    "autocorreggerebbero": "autocorreggere",
    "autocorreggerei": "autocorreggere",
    "autocorreggeremmo": "autocorreggere",
    "autocorreggeremo": "autocorreggere",
    "autocorreggereste": "autocorreggere",
    "autocorreggeresti": "autocorreggere",
    "autocorreggerete": "autocorreggere",
    "autocorreggerà": "autocorreggere",
    "autocorreggerò": "autocorreggere",
    "autocorreggesse": "autocorreggere",
    "autocorreggesser": "autocorreggere",
    "autocorreggessero": "autocorreggere",
    "autocorreggessi": "autocorreggere",
    "autocorreggessimo": "autocorreggere",
    "autocorreggeste": "autocorreggere",
    "autocorreggesti": "autocorreggere",
    "autocorreggete": "autocorreggere",
    "autocorreggeva": "autocorreggere",
    "autocorreggevamo": "autocorreggere",
    "autocorreggevan": "autocorreggere",
    "autocorreggevano": "autocorreggere",
    "autocorreggevate": "autocorreggere",
    "autocorreggevi": "autocorreggere",
    "autocorreggevo": "autocorreggere",
    "autocorreggi": "autocorreggere",
    "autocorreggiamo": "autocorreggere",
    "autocorreggiate": "autocorreggere",
    "autocorreggo": "autocorreggere",
    "autocorreggon": "autocorreggere",
    "autocorreggono": "autocorreggere",
    "autocorresser": "autocorreggere",
    "autocorressero": "autocorreggere",
    "autocorressi": "autocorreggere",
    "autocorressè": "autocorreggere",
    "autocorretta": "autocorreggere",
    "autocorrette": "autocorreggere",
    "autocorretti": "autocorreggere",
    "autocorretto": "autocorreggere",
    "autocoscienze": "autocoscienza",
    "autocostitua": "autocostituire",
    "autocostituan": "autocostituire",
    "autocostituano": "autocostituire",
    "autocostitue": "autocostituire",
    "autocostituendo": "autocostituire",
    "autocostituente": "autocostituire",
    "autocostituenti": "autocostituire",
    "autocostitui": "autocostituire",
    "autocostituiamo": "autocostituire",
    "autocostituiate": "autocostituire",
    "autocostituii": "autocostituire",
    "autocostituimmo": "autocostituire",
    "autocostituir": "autocostituire",
    "autocostituirai": "autocostituire",
    "autocostituiran": "autocostituire",
    "autocostituiranno": "autocostituire",
    "autocostituirebbe": "autocostituire",
    "autocostituirebber": "autocostituire",
    "autocostituirebbero": "autocostituire",
    "autocostituirei": "autocostituire",
    "autocostituiremmo": "autocostituire",
    "autocostituiremo": "autocostituire",
    "autocostituireste": "autocostituire",
    "autocostituiresti": "autocostituire",
    "autocostituirete": "autocostituire",
    "autocostituiron": "autocostituire",
    "autocostituirono": "autocostituire",
    "autocostituirà": "autocostituire",
    "autocostituirò": "autocostituire",
    "autocostituisse": "autocostituire",
    "autocostituisser": "autocostituire",
    "autocostituissero": "autocostituire",
    "autocostituissi": "autocostituire",
    "autocostituissimo": "autocostituire",
    "autocostituiste": "autocostituire",
    "autocostituisti": "autocostituire",
    "autocostituita": "autocostituire",
    "autocostituite": "autocostituire",
    "autocostituiti": "autocostituire",
    "autocostituito": "autocostituire",
    "autocostituiva": "autocostituire",
    "autocostituivamo": "autocostituire",
    "autocostituivan": "autocostituire",
    "autocostituivano": "autocostituire",
    "autocostituivate": "autocostituire",
    "autocostituivi": "autocostituire",
    "autocostituivo": "autocostituire",
    "autocostituo": "autocostituire",
    "autocostituon": "autocostituire",
    "autocostituono": "autocostituire",
    "autocostituì": "autocostituire",
    "autocostrua": "autocostruire",
    "autocostruan": "autocostruire",
    "autocostruano": "autocostruire",
    "autocostrue": "autocostruire",
    "autocostruendo": "autocostruire",
    "autocostruente": "autocostruire",
    "autocostruenti": "autocostruire",
    "autocostrui": "autocostruire",
    "autocostruiamo": "autocostruire",
    "autocostruiate": "autocostruire",
    "autocostruii": "autocostruire",
    "autocostruimmo": "autocostruire",
    "autocostruir": "autocostruire",
    "autocostruirai": "autocostruire",
    "autocostruiran": "autocostruire",
    "autocostruiranno": "autocostruire",
    "autocostruirebbe": "autocostruire",
    "autocostruirebber": "autocostruire",
    "autocostruirebbero": "autocostruire",
    "autocostruirei": "autocostruire",
    "autocostruiremmo": "autocostruire",
    "autocostruiremo": "autocostruire",
    "autocostruireste": "autocostruire",
    "autocostruiresti": "autocostruire",
    "autocostruirete": "autocostruire",
    "autocostruiron": "autocostruire",
    "autocostruirono": "autocostruire",
    "autocostruirà": "autocostruire",
    "autocostruirò": "autocostruire",
    "autocostruisse": "autocostruire",
    "autocostruisser": "autocostruire",
    "autocostruissero": "autocostruire",
    "autocostruissi": "autocostruire",
    "autocostruissimo": "autocostruire",
    "autocostruiste": "autocostruire",
    "autocostruisti": "autocostruire",
    "autocostruita": "autocostruire",
    "autocostruite": "autocostruire",
    "autocostruiti": "autocostruire",
    "autocostruito": "autocostruire",
    "autocostruiva": "autocostruire",
    "autocostruivamo": "autocostruire",
    "autocostruivan": "autocostruire",
    "autocostruivano": "autocostruire",
    "autocostruivate": "autocostruire",
    "autocostruivi": "autocostruire",
    "autocostruivo": "autocostruire",
    "autocostruo": "autocostruire",
    "autocostruon": "autocostruire",
    "autocostruono": "autocostruire",
    "autocostruì": "autocostruire",
    "autocrati": "autocrate",
    "autocratica": "autocratico",
    "autocratiche": "autocratico",
    "autocratici": "autocratico",
    "autocrazie": "autocrazia",
    "autocritica": "autocritico",
    "autocriticai": "autocriticare",
    "autocriticammo": "autocriticare",
    "autocritican": "autocriticare",
    "autocriticando": "autocriticare",
    "autocriticano": "autocriticare",
    "autocriticante": "autocriticare",
    "autocriticanti": "autocriticare",
    "autocriticar": "autocriticare",
    "autocriticaron": "autocriticare",
    "autocriticarono": "autocriticare",
    "autocriticasse": "autocriticare",
    "autocriticasser": "autocriticare",
    "autocriticassero": "autocriticare",
    "autocriticassi": "autocriticare",
    "autocriticassimo": "autocriticare",
    "autocriticaste": "autocriticare",
    "autocriticasti": "autocriticare",
    "autocriticata": "autocriticare",
    "autocriticate": "autocriticare",
    "autocriticati": "autocriticare",
    "autocriticato": "autocriticare",
    "autocriticava": "autocriticare",
    "autocriticavamo": "autocriticare",
    "autocriticavan": "autocriticare",
    "autocriticavano": "autocriticare",
    "autocriticavate": "autocriticare",
    "autocriticavi": "autocriticare",
    "autocriticavo": "autocriticare",
    "autocritiche": "autocritico",
    "autocriticherai": "autocriticare",
    "autocriticheran": "autocriticare",
    "autocriticheranno": "autocriticare",
    "autocriticherebbe": "autocriticare",
    "autocriticherebber": "autocriticare",
    "autocriticherebbero": "autocriticare",
    "autocriticherei": "autocriticare",
    "autocriticheremmo": "autocriticare",
    "autocriticheremo": "autocriticare",
    "autocritichereste": "autocriticare",
    "autocriticheresti": "autocriticare",
    "autocriticherete": "autocriticare",
    "autocriticherà": "autocriticare",
    "autocriticherò": "autocriticare",
    "autocritichi": "autocriticare",
    "autocritichiamo": "autocriticare",
    "autocritichiate": "autocriticare",
    "autocritichin": "autocriticare",
    "autocritichino": "autocriticare",
    "autocritici": "autocritico",
    "autocritico": "autocriticare",
    "autocriticò": "autocriticare",
    "autoctona": "autoctono",
    "autoctone": "autoctono",
    "autoctoni": "autoctono",
    "autodefina": "autodefinire",
    "autodefinan": "autodefinire",
    "autodefinano": "autodefinire",
    "autodefine": "autodefinire",
    "autodefinendo": "autodefinire",
    "autodefinente": "autodefinire",
    "autodefinenti": "autodefinire",
    "autodefini": "autodefinire",
    "autodefiniamo": "autodefinire",
    "autodefiniate": "autodefinire",
    "autodefinii": "autodefinire",
    "autodefinimmo": "autodefinire",
    "autodefinir": "autodefinire",
    "autodefinirai": "autodefinire",
    "autodefiniran": "autodefinire",
    "autodefiniranno": "autodefinire",
    "autodefinirebbe": "autodefinire",
    "autodefinirebber": "autodefinire",
    "autodefinirebbero": "autodefinire",
    "autodefinirei": "autodefinire",
    "autodefiniremmo": "autodefinire",
    "autodefiniremo": "autodefinire",
    "autodefinireste": "autodefinire",
    "autodefiniresti": "autodefinire",
    "autodefinirete": "autodefinire",
    "autodefiniron": "autodefinire",
    "autodefinirono": "autodefinire",
    "autodefinirà": "autodefinire",
    "autodefinirò": "autodefinire",
    "autodefinisse": "autodefinire",
    "autodefinisser": "autodefinire",
    "autodefinissero": "autodefinire",
    "autodefinissi": "autodefinire",
    "autodefinissimo": "autodefinire",
    "autodefiniste": "autodefinire",
    "autodefinisti": "autodefinire",
    "autodefinita": "autodefinire",
    "autodefinite": "autodefinire",
    "autodefiniti": "autodefinire",
    "autodefinito": "autodefinire",
    "autodefiniva": "autodefinire",
    "autodefinivamo": "autodefinire",
    "autodefinivan": "autodefinire",
    "autodefinivano": "autodefinire",
    "autodefinivate": "autodefinire",
    "autodefinivi": "autodefinire",
    "autodefinivo": "autodefinire",
    "autodefino": "autodefinire",
    "autodefinon": "autodefinire",
    "autodefinono": "autodefinire",
    "autodefinì": "autodefinire",
    "autodenomina": "autodenominare",
    "autodenominai": "autodenominare",
    "autodenominammo": "autodenominare",
    "autodenominan": "autodenominare",
    "autodenominando": "autodenominare",
    "autodenominano": "autodenominare",
    "autodenominante": "autodenominare",
    "autodenominanti": "autodenominare",
    "autodenominar": "autodenominare",
    "autodenominaron": "autodenominare",
    "autodenominarono": "autodenominare",
    "autodenominasse": "autodenominare",
    "autodenominasser": "autodenominare",
    "autodenominassero": "autodenominare",
    "autodenominassi": "autodenominare",
    "autodenominassimo": "autodenominare",
    "autodenominaste": "autodenominare",
    "autodenominasti": "autodenominare",
    "autodenominata": "autodenominare",
    "autodenominate": "autodenominare",
    "autodenominati": "autodenominare",
    "autodenominato": "autodenominare",
    "autodenominava": "autodenominare",
    "autodenominavamo": "autodenominare",
    "autodenominavan": "autodenominare",
    "autodenominavano": "autodenominare",
    "autodenominavate": "autodenominare",
    "autodenominavi": "autodenominare",
    "autodenominavo": "autodenominare",
    "autodenominerai": "autodenominare",
    "autodenomineran": "autodenominare",
    "autodenomineranno": "autodenominare",
    "autodenominerebbe": "autodenominare",
    "autodenominerebber": "autodenominare",
    "autodenominerebbero": "autodenominare",
    "autodenominerei": "autodenominare",
    "autodenomineremmo": "autodenominare",
    "autodenomineremo": "autodenominare",
    "autodenominereste": "autodenominare",
    "autodenomineresti": "autodenominare",
    "autodenominerete": "autodenominare",
    "autodenominerà": "autodenominare",
    "autodenominerò": "autodenominare",
    "autodenomini": "autodenominare",
    "autodenominiamo": "autodenominare",
    "autodenominiate": "autodenominare",
    "autodenominin": "autodenominare",
    "autodenominino": "autodenominare",
    "autodenomino": "autodenominare",
    "autodenominò": "autodenominare",
    "autodenunce": "autodenuncia",
    "autodenuncerai": "autodenunciare",
    "autodenunceran": "autodenunciare",
    "autodenunceranno": "autodenunciare",
    "autodenuncerebbe": "autodenunciare",
    "autodenuncerebber": "autodenunciare",
    "autodenuncerebbero": "autodenunciare",
    "autodenuncerei": "autodenunciare",
    "autodenunceremmo": "autodenunciare",
    "autodenunceremo": "autodenunciare",
    "autodenuncereste": "autodenunciare",
    "autodenunceresti": "autodenunciare",
    "autodenuncerete": "autodenunciare",
    "autodenuncerà": "autodenunciare",
    "autodenuncerò": "autodenunciare",
    "autodenunci": "autodenunciare",
    "autodenuncia": "autodenunciare",
    "autodenunciai": "autodenunciare",
    "autodenunciammo": "autodenunciare",
    "autodenunciamo": "autodenunciare",
    "autodenuncian": "autodenunciare",
    "autodenunciando": "autodenunciare",
    "autodenunciano": "autodenunciare",
    "autodenunciante": "autodenunciare",
    "autodenuncianti": "autodenunciare",
    "autodenunciar": "autodenunciare",
    "autodenunciaron": "autodenunciare",
    "autodenunciarono": "autodenunciare",
    "autodenunciasse": "autodenunciare",
    "autodenunciasser": "autodenunciare",
    "autodenunciassero": "autodenunciare",
    "autodenunciassi": "autodenunciare",
    "autodenunciassimo": "autodenunciare",
    "autodenunciaste": "autodenunciare",
    "autodenunciasti": "autodenunciare",
    "autodenunciata": "autodenunciare",
    "autodenunciate": "autodenunciare",
    "autodenunciati": "autodenunciare",
    "autodenunciato": "autodenunciare",
    "autodenunciava": "autodenunciare",
    "autodenunciavamo": "autodenunciare",
    "autodenunciavan": "autodenunciare",
    "autodenunciavano": "autodenunciare",
    "autodenunciavate": "autodenunciare",
    "autodenunciavi": "autodenunciare",
    "autodenunciavo": "autodenunciare",
    "autodenuncin": "autodenunciare",
    "autodenuncino": "autodenunciare",
    "autodenuncio": "autodenunciare",
    "autodenunciò": "autodenunciare",
    "autodestitua": "autodestituire",
    "autodestituan": "autodestituire",
    "autodestituano": "autodestituire",
    "autodestitue": "autodestituire",
    "autodestituendo": "autodestituire",
    "autodestituente": "autodestituire",
    "autodestituenti": "autodestituire",
    "autodestitui": "autodestituire",
    "autodestituiamo": "autodestituire",
    "autodestituiate": "autodestituire",
    "autodestituii": "autodestituire",
    "autodestituimmo": "autodestituire",
    "autodestituir": "autodestituire",
    "autodestituirai": "autodestituire",
    "autodestituiran": "autodestituire",
    "autodestituiranno": "autodestituire",
    "autodestituirebbe": "autodestituire",
    "autodestituirebber": "autodestituire",
    "autodestituirebbero": "autodestituire",
    "autodestituirei": "autodestituire",
    "autodestituiremmo": "autodestituire",
    "autodestituiremo": "autodestituire",
    "autodestituireste": "autodestituire",
    "autodestituiresti": "autodestituire",
    "autodestituirete": "autodestituire",
    "autodestituiron": "autodestituire",
    "autodestituirono": "autodestituire",
    "autodestituirà": "autodestituire",
    "autodestituirò": "autodestituire",
    "autodestituisse": "autodestituire",
    "autodestituisser": "autodestituire",
    "autodestituissero": "autodestituire",
    "autodestituissi": "autodestituire",
    "autodestituissimo": "autodestituire",
    "autodestituiste": "autodestituire",
    "autodestituisti": "autodestituire",
    "autodestituita": "autodestituire",
    "autodestituite": "autodestituire",
    "autodestituiti": "autodestituire",
    "autodestituito": "autodestituire",
    "autodestituiva": "autodestituire",
    "autodestituivamo": "autodestituire",
    "autodestituivan": "autodestituire",
    "autodestituivano": "autodestituire",
    "autodestituivate": "autodestituire",
    "autodestituivi": "autodestituire",
    "autodestituivo": "autodestituire",
    "autodestituo": "autodestituire",
    "autodestituon": "autodestituire",
    "autodestituono": "autodestituire",
    "autodestituì": "autodestituire",
    "autodetermina": "autodeterminare",
    "autodeterminai": "autodeterminare",
    "autodeterminammo": "autodeterminare",
    "autodeterminan": "autodeterminare",
    "autodeterminando": "autodeterminare",
    "autodeterminano": "autodeterminare",
    "autodeterminante": "autodeterminare",
    "autodeterminanti": "autodeterminare",
    "autodeterminar": "autodeterminare",
    "autodeterminaron": "autodeterminare",
    "autodeterminarono": "autodeterminare",
    "autodeterminasse": "autodeterminare",
    "autodeterminasser": "autodeterminare",
    "autodeterminassero": "autodeterminare",
    "autodeterminassi": "autodeterminare",
    "autodeterminassimo": "autodeterminare",
    "autodeterminaste": "autodeterminare",
    "autodeterminasti": "autodeterminare",
    "autodeterminata": "autodeterminare",
    "autodeterminate": "autodeterminare",
    "autodeterminati": "autodeterminare",
    "autodeterminato": "autodeterminare",
    "autodeterminava": "autodeterminare",
    "autodeterminavamo": "autodeterminare",
    "autodeterminavan": "autodeterminare",
    "autodeterminavano": "autodeterminare",
    "autodeterminavate": "autodeterminare",
    "autodeterminavi": "autodeterminare",
    "autodeterminavo": "autodeterminare",
    "autodeterminazioni": "autodeterminazione",
    "autodeterminerai": "autodeterminare",
    "autodetermineran": "autodeterminare",
    "autodetermineranno": "autodeterminare",
    "autodeterminerebbe": "autodeterminare",
    "autodeterminerebber": "autodeterminare",
    "autodeterminerebbero": "autodeterminare",
    "autodeterminerei": "autodeterminare",
    "autodetermineremmo": "autodeterminare",
    "autodetermineremo": "autodeterminare",
    "autodeterminereste": "autodeterminare",
    "autodetermineresti": "autodeterminare",
    "autodeterminerete": "autodeterminare",
    "autodeterminerà": "autodeterminare",
    "autodeterminerò": "autodeterminare",
    "autodetermini": "autodeterminare",
    "autodeterminiamo": "autodeterminare",
    "autodeterminiate": "autodeterminare",
    "autodeterminin": "autodeterminare",
    "autodeterminino": "autodeterminare",
    "autodetermino": "autodeterminare",
    "autodeterminò": "autodeterminare",
    "autodiagnostica": "autodiagnosticare",
    "autodiagnosticai": "autodiagnosticare",
    "autodiagnosticammo": "autodiagnosticare",
    "autodiagnostican": "autodiagnosticare",
    "autodiagnosticando": "autodiagnosticare",
    "autodiagnosticano": "autodiagnosticare",
    "autodiagnosticante": "autodiagnosticare",
    "autodiagnosticanti": "autodiagnosticare",
    "autodiagnosticar": "autodiagnosticare",
    "autodiagnosticaron": "autodiagnosticare",
    "autodiagnosticarono": "autodiagnosticare",
    "autodiagnosticasse": "autodiagnosticare",
    "autodiagnosticasser": "autodiagnosticare",
    "autodiagnosticassero": "autodiagnosticare",
    "autodiagnosticassi": "autodiagnosticare",
    "autodiagnosticassimo": "autodiagnosticare",
    "autodiagnosticaste": "autodiagnosticare",
    "autodiagnosticasti": "autodiagnosticare",
    "autodiagnosticata": "autodiagnosticare",
    "autodiagnosticate": "autodiagnosticare",
    "autodiagnosticati": "autodiagnosticare",
    "autodiagnosticato": "autodiagnosticare",
    "autodiagnosticava": "autodiagnosticare",
    "autodiagnosticavamo": "autodiagnosticare",
    "autodiagnosticavan": "autodiagnosticare",
    "autodiagnosticavano": "autodiagnosticare",
    "autodiagnosticavate": "autodiagnosticare",
    "autodiagnosticavi": "autodiagnosticare",
    "autodiagnosticavo": "autodiagnosticare",
    "autodiagnosticherai": "autodiagnosticare",
    "autodiagnosticheran": "autodiagnosticare",
    "autodiagnosticheranno": "autodiagnosticare",
    "autodiagnosticherebbe": "autodiagnosticare",
    "autodiagnosticherebber": "autodiagnosticare",
    "autodiagnosticherebbero": "autodiagnosticare",
    "autodiagnosticherei": "autodiagnosticare",
    "autodiagnosticheremmo": "autodiagnosticare",
    "autodiagnosticheremo": "autodiagnosticare",
    "autodiagnostichereste": "autodiagnosticare",
    "autodiagnosticheresti": "autodiagnosticare",
    "autodiagnosticherete": "autodiagnosticare",
    "autodiagnosticherà": "autodiagnosticare",
    "autodiagnosticherò": "autodiagnosticare",
    "autodiagnostichi": "autodiagnosticare",
    "autodiagnostichiamo": "autodiagnosticare",
    "autodiagnostichiate": "autodiagnosticare",
    "autodiagnostichin": "autodiagnosticare",
    "autodiagnostichino": "autodiagnosticare",
    "autodiagnostico": "autodiagnosticare",
    "autodiagnosticò": "autodiagnosticare",
    "autodichiara": "autodichiarare",
    "autodichiarai": "autodichiarare",
    "autodichiarammo": "autodichiarare",
    "autodichiaran": "autodichiarare",
    "autodichiarando": "autodichiarare",
    "autodichiarano": "autodichiarare",
    "autodichiarante": "autodichiarare",
    "autodichiaranti": "autodichiarare",
    "autodichiarar": "autodichiarare",
    "autodichiararon": "autodichiarare",
    "autodichiararono": "autodichiarare",
    "autodichiarasse": "autodichiarare",
    "autodichiarasser": "autodichiarare",
    "autodichiarassero": "autodichiarare",
    "autodichiarassi": "autodichiarare",
    "autodichiarassimo": "autodichiarare",
    "autodichiaraste": "autodichiarare",
    "autodichiarasti": "autodichiarare",
    "autodichiarata": "autodichiarare",
    "autodichiarate": "autodichiarare",
    "autodichiarati": "autodichiarare",
    "autodichiarato": "autodichiarare",
    "autodichiarava": "autodichiarare",
    "autodichiaravamo": "autodichiarare",
    "autodichiaravan": "autodichiarare",
    "autodichiaravano": "autodichiarare",
    "autodichiaravate": "autodichiarare",
    "autodichiaravi": "autodichiarare",
    "autodichiaravo": "autodichiarare",
    "autodichiarerai": "autodichiarare",
    "autodichiareran": "autodichiarare",
    "autodichiareranno": "autodichiarare",
    "autodichiarerebbe": "autodichiarare",
    "autodichiarerebber": "autodichiarare",
    "autodichiarerebbero": "autodichiarare",
    "autodichiarerei": "autodichiarare",
    "autodichiareremmo": "autodichiarare",
    "autodichiareremo": "autodichiarare",
    "autodichiarereste": "autodichiarare",
    "autodichiareresti": "autodichiarare",
    "autodichiarerete": "autodichiarare",
    "autodichiarerà": "autodichiarare",
    "autodichiarerò": "autodichiarare",
    "autodichiari": "autodichiarare",
    "autodichiariamo": "autodichiarare",
    "autodichiariate": "autodichiarare",
    "autodichiarin": "autodichiarare",
    "autodichiarino": "autodichiarare",
    "autodichiaro": "autodichiarare",
    "autodichiarò": "autodichiarare",
    "autodidatte": "autodidatta",
    "autodidatti": "autodidatta",
    "autodifenda": "autodifendere",
    "autodifendan": "autodifendere",
    "autodifendano": "autodifendere",
    "autodifende": "autodifendere",
    "autodifendemmo": "autodifendere",
    "autodifendendo": "autodifendere",
    "autodifendente": "autodifendere",
    "autodifendenti": "autodifendere",
    "autodifender": "autodifendere",
    "autodifenderai": "autodifendere",
    "autodifenderan": "autodifendere",
    "autodifenderanno": "autodifendere",
    "autodifenderebbe": "autodifendere",
    "autodifenderebber": "autodifendere",
    "autodifenderebbero": "autodifendere",
    "autodifenderei": "autodifendere",
    "autodifenderemmo": "autodifendere",
    "autodifenderemo": "autodifendere",
    "autodifendereste": "autodifendere",
    "autodifenderesti": "autodifendere",
    "autodifenderete": "autodifendere",
    "autodifenderà": "autodifendere",
    "autodifenderò": "autodifendere",
    "autodifendesse": "autodifendere",
    "autodifendesser": "autodifendere",
    "autodifendessero": "autodifendere",
    "autodifendessi": "autodifendere",
    "autodifendessimo": "autodifendere",
    "autodifendeste": "autodifendere",
    "autodifendesti": "autodifendere",
    "autodifendete": "autodifendere",
    "autodifendeva": "autodifendere",
    "autodifendevamo": "autodifendere",
    "autodifendevan": "autodifendere",
    "autodifendevano": "autodifendere",
    "autodifendevate": "autodifendere",
    "autodifendevi": "autodifendere",
    "autodifendevo": "autodifendere",
    "autodifendi": "autodifendere",
    "autodifendiamo": "autodifendere",
    "autodifendiate": "autodifendere",
    "autodifendo": "autodifendere",
    "autodifendon": "autodifendere",
    "autodifendono": "autodifendere",
    "autodifesa": "autodifendere",
    "autodifese": "autodifesa",
    "autodifeser": "autodifendere",
    "autodifesero": "autodifendere",
    "autodifesi": "autodifendere",
    "autodifeso": "autodifendere",
    "autodifesè": "autodifendere",
    "autodiriga": "autodirigere",
    "autodirigan": "autodirigere",
    "autodirigano": "autodirigere",
    "autodirige": "autodirigere",
    "autodirigei": "autodirigere",
    "autodirigemmo": "autodirigere",
    "autodirigendo": "autodirigere",
    "autodirigente": "autodirigere",
    "autodirigenti": "autodirigere",
    "autodiriger": "autodirigere",
    "autodirigerai": "autodirigere",
    "autodirigeran": "autodirigere",
    "autodirigeranno": "autodirigere",
    "autodirigerebbe": "autodirigere",
    "autodirigerebber": "autodirigere",
    "autodirigerebbero": "autodirigere",
    "autodirigerei": "autodirigere",
    "autodirigeremmo": "autodirigere",
    "autodirigeremo": "autodirigere",
    "autodirigereste": "autodirigere",
    "autodirigeresti": "autodirigere",
    "autodirigerete": "autodirigere",
    "autodirigeron": "autodirigere",
    "autodirigerono": "autodirigere",
    "autodirigerà": "autodirigere",
    "autodirigerò": "autodirigere",
    "autodirigesse": "autodirigere",
    "autodirigesser": "autodirigere",
    "autodirigessero": "autodirigere",
    "autodirigessi": "autodirigere",
    "autodirigessimo": "autodirigere",
    "autodirigeste": "autodirigere",
    "autodirigesti": "autodirigere",
    "autodirigete": "autodirigere",
    "autodirigeva": "autodirigere",
    "autodirigevamo": "autodirigere",
    "autodirigevan": "autodirigere",
    "autodirigevano": "autodirigere",
    "autodirigevate": "autodirigere",
    "autodirigevi": "autodirigere",
    "autodirigevo": "autodirigere",
    "autodirigi": "autodirigere",
    "autodirigiamo": "autodirigere",
    "autodirigiate": "autodirigere",
    "autodirigiuta": "autodirigere",
    "autodirigiute": "autodirigere",
    "autodirigiuti": "autodirigere",
    "autodirigiuto": "autodirigere",
    "autodirigo": "autodirigere",
    "autodirigon": "autodirigere",
    "autodirigono": "autodirigere",
    "autodirigè": "autodirigere",
    "autodistrugga": "autodistruggere",
    "autodistruggan": "autodistruggere",
    "autodistruggano": "autodistruggere",
    "autodistrugge": "autodistruggere",
    "autodistruggemmo": "autodistruggere",
    "autodistruggendo": "autodistruggere",
    "autodistruggente": "autodistruggere",
    "autodistruggenti": "autodistruggere",
    "autodistrugger": "autodistruggere",
    "autodistruggerai": "autodistruggere",
    "autodistruggeran": "autodistruggere",
    "autodistruggeranno": "autodistruggere",
    "autodistruggerebbe": "autodistruggere",
    "autodistruggerebber": "autodistruggere",
    "autodistruggerebbero": "autodistruggere",
    "autodistruggerei": "autodistruggere",
    "autodistruggeremmo": "autodistruggere",
    "autodistruggeremo": "autodistruggere",
    "autodistruggereste": "autodistruggere",
    "autodistruggeresti": "autodistruggere",
    "autodistruggerete": "autodistruggere",
    "autodistruggerà": "autodistruggere",
    "autodistruggerò": "autodistruggere",
    "autodistruggesse": "autodistruggere",
    "autodistruggesser": "autodistruggere",
    "autodistruggessero": "autodistruggere",
    "autodistruggessi": "autodistruggere",
    "autodistruggessimo": "autodistruggere",
    "autodistruggeste": "autodistruggere",
    "autodistruggesti": "autodistruggere",
    "autodistruggete": "autodistruggere",
    "autodistruggeva": "autodistruggere",
    "autodistruggevamo": "autodistruggere",
    "autodistruggevan": "autodistruggere",
    "autodistruggevano": "autodistruggere",
    "autodistruggevate": "autodistruggere",
    "autodistruggevi": "autodistruggere",
    "autodistruggevo": "autodistruggere",
    "autodistruggi": "autodistruggere",
    "autodistruggiamo": "autodistruggere",
    "autodistruggiate": "autodistruggere",
    "autodistruggo": "autodistruggere",
    "autodistruggon": "autodistruggere",
    "autodistruggono": "autodistruggere",
    "autodistrusser": "autodistruggere",
    "autodistrussero": "autodistruggere",
    "autodistrussi": "autodistruggere",
    "autodistrussè": "autodistruggere",
    "autodistrutta": "autodistruggere",
    "autodistrutte": "autodistruggere",
    "autodistrutti": "autodistruggere",
    "autodistruttiva": "autodistruttivo",
    "autodistruttive": "autodistruttivo",
    "autodistruttivi": "autodistruttivo",
    "autodistrutto": "autodistruggere",
    "autodistruzioni": "autodistruzione",
    "autodromi": "autodromo",
    "autoelimina": "autoeliminare",
    "autoeliminai": "autoeliminare",
    "autoeliminammo": "autoeliminare",
    "autoeliminan": "autoeliminare",
    "autoeliminando": "autoeliminare",
    "autoeliminano": "autoeliminare",
    "autoeliminante": "autoeliminare",
    "autoeliminanti": "autoeliminare",
    "autoeliminar": "autoeliminare",
    "autoeliminaron": "autoeliminare",
    "autoeliminarono": "autoeliminare",
    "autoeliminasse": "autoeliminare",
    "autoeliminasser": "autoeliminare",
    "autoeliminassero": "autoeliminare",
    "autoeliminassi": "autoeliminare",
    "autoeliminassimo": "autoeliminare",
    "autoeliminaste": "autoeliminare",
    "autoeliminasti": "autoeliminare",
    "autoeliminata": "autoeliminare",
    "autoeliminate": "autoeliminare",
    "autoeliminati": "autoeliminare",
    "autoeliminato": "autoeliminare",
    "autoeliminava": "autoeliminare",
    "autoeliminavamo": "autoeliminare",
    "autoeliminavan": "autoeliminare",
    "autoeliminavano": "autoeliminare",
    "autoeliminavate": "autoeliminare",
    "autoeliminavi": "autoeliminare",
    "autoeliminavo": "autoeliminare",
    "autoeliminerai": "autoeliminare",
    "autoelimineran": "autoeliminare",
    "autoelimineranno": "autoeliminare",
    "autoeliminerebbe": "autoeliminare",
    "autoeliminerebber": "autoeliminare",
    "autoeliminerebbero": "autoeliminare",
    "autoeliminerei": "autoeliminare",
    "autoelimineremmo": "autoeliminare",
    "autoelimineremo": "autoeliminare",
    "autoeliminereste": "autoeliminare",
    "autoelimineresti": "autoeliminare",
    "autoeliminerete": "autoeliminare",
    "autoeliminerà": "autoeliminare",
    "autoeliminerò": "autoeliminare",
    "autoelimini": "autoeliminare",
    "autoeliminiamo": "autoeliminare",
    "autoeliminiate": "autoeliminare",
    "autoeliminin": "autoeliminare",
    "autoeliminino": "autoeliminare",
    "autoelimino": "autoeliminare",
    "autoeliminò": "autoeliminare",
    "autoelogiativa": "autoelogiativo",
    "autoelogiative": "autoelogiativo",
    "autoelogiativi": "autoelogiativo",
    "autoemargina": "autoemarginare",
    "autoemarginai": "autoemarginare",
    "autoemarginammo": "autoemarginare",
    "autoemarginan": "autoemarginare",
    "autoemarginando": "autoemarginare",
    "autoemarginano": "autoemarginare",
    "autoemarginante": "autoemarginare",
    "autoemarginanti": "autoemarginare",
    "autoemarginar": "autoemarginare",
    "autoemarginaron": "autoemarginare",
    "autoemarginarono": "autoemarginare",
    "autoemarginasse": "autoemarginare",
    "autoemarginasser": "autoemarginare",
    "autoemarginassero": "autoemarginare",
    "autoemarginassi": "autoemarginare",
    "autoemarginassimo": "autoemarginare",
    "autoemarginaste": "autoemarginare",
    "autoemarginasti": "autoemarginare",
    "autoemarginata": "autoemarginare",
    "autoemarginate": "autoemarginare",
    "autoemarginati": "autoemarginare",
    "autoemarginato": "autoemarginare",
    "autoemarginava": "autoemarginare",
    "autoemarginavamo": "autoemarginare",
    "autoemarginavan": "autoemarginare",
    "autoemarginavano": "autoemarginare",
    "autoemarginavate": "autoemarginare",
    "autoemarginavi": "autoemarginare",
    "autoemarginavo": "autoemarginare",
    "autoemarginerai": "autoemarginare",
    "autoemargineran": "autoemarginare",
    "autoemargineranno": "autoemarginare",
    "autoemarginerebbe": "autoemarginare",
    "autoemarginerebber": "autoemarginare",
    "autoemarginerebbero": "autoemarginare",
    "autoemarginerei": "autoemarginare",
    "autoemargineremmo": "autoemarginare",
    "autoemargineremo": "autoemarginare",
    "autoemarginereste": "autoemarginare",
    "autoemargineresti": "autoemarginare",
    "autoemarginerete": "autoemarginare",
    "autoemarginerà": "autoemarginare",
    "autoemarginerò": "autoemarginare",
    "autoemargini": "autoemarginare",
    "autoemarginiamo": "autoemarginare",
    "autoemarginiate": "autoemarginare",
    "autoemarginin": "autoemarginare",
    "autoemarginino": "autoemarginare",
    "autoemargino": "autoemarginare",
    "autoemarginò": "autoemarginare",
    "autoemenda": "autoemendare",
    "autoemendai": "autoemendare",
    "autoemendammo": "autoemendare",
    "autoemendan": "autoemendare",
    "autoemendando": "autoemendare",
    "autoemendano": "autoemendare",
    "autoemendante": "autoemendare",
    "autoemendanti": "autoemendare",
    "autoemendar": "autoemendare",
    "autoemendaron": "autoemendare",
    "autoemendarono": "autoemendare",
    "autoemendasse": "autoemendare",
    "autoemendasser": "autoemendare",
    "autoemendassero": "autoemendare",
    "autoemendassi": "autoemendare",
    "autoemendassimo": "autoemendare",
    "autoemendaste": "autoemendare",
    "autoemendasti": "autoemendare",
    "autoemendata": "autoemendare",
    "autoemendate": "autoemendare",
    "autoemendati": "autoemendare",
    "autoemendato": "autoemendare",
    "autoemendava": "autoemendare",
    "autoemendavamo": "autoemendare",
    "autoemendavan": "autoemendare",
    "autoemendavano": "autoemendare",
    "autoemendavate": "autoemendare",
    "autoemendavi": "autoemendare",
    "autoemendavo": "autoemendare",
    "autoemenderai": "autoemendare",
    "autoemenderan": "autoemendare",
    "autoemenderanno": "autoemendare",
    "autoemenderebbe": "autoemendare",
    "autoemenderebber": "autoemendare",
    "autoemenderebbero": "autoemendare",
    "autoemenderei": "autoemendare",
    "autoemenderemmo": "autoemendare",
    "autoemenderemo": "autoemendare",
    "autoemendereste": "autoemendare",
    "autoemenderesti": "autoemendare",
    "autoemenderete": "autoemendare",
    "autoemenderà": "autoemendare",
    "autoemenderò": "autoemendare",
    "autoemendi": "autoemendare",
    "autoemendiamo": "autoemendare",
    "autoemendiate": "autoemendare",
    "autoemendin": "autoemendare",
    "autoemendino": "autoemendare",
    "autoemendo": "autoemendare",
    "autoemendò": "autoemendare",
    "autoentusiasma": "autoentusiasmare",
    "autoentusiasmai": "autoentusiasmare",
    "autoentusiasmammo": "autoentusiasmare",
    "autoentusiasman": "autoentusiasmare",
    "autoentusiasmando": "autoentusiasmare",
    "autoentusiasmano": "autoentusiasmare",
    "autoentusiasmante": "autoentusiasmare",
    "autoentusiasmanti": "autoentusiasmare",
    "autoentusiasmar": "autoentusiasmare",
    "autoentusiasmaron": "autoentusiasmare",
    "autoentusiasmarono": "autoentusiasmare",
    "autoentusiasmasse": "autoentusiasmare",
    "autoentusiasmasser": "autoentusiasmare",
    "autoentusiasmassero": "autoentusiasmare",
    "autoentusiasmassi": "autoentusiasmare",
    "autoentusiasmassimo": "autoentusiasmare",
    "autoentusiasmaste": "autoentusiasmare",
    "autoentusiasmasti": "autoentusiasmare",
    "autoentusiasmata": "autoentusiasmare",
    "autoentusiasmate": "autoentusiasmare",
    "autoentusiasmati": "autoentusiasmare",
    "autoentusiasmato": "autoentusiasmare",
    "autoentusiasmava": "autoentusiasmare",
    "autoentusiasmavamo": "autoentusiasmare",
    "autoentusiasmavan": "autoentusiasmare",
    "autoentusiasmavano": "autoentusiasmare",
    "autoentusiasmavate": "autoentusiasmare",
    "autoentusiasmavi": "autoentusiasmare",
    "autoentusiasmavo": "autoentusiasmare",
    "autoentusiasmerai": "autoentusiasmare",
    "autoentusiasmeran": "autoentusiasmare",
    "autoentusiasmeranno": "autoentusiasmare",
    "autoentusiasmerebbe": "autoentusiasmare",
    "autoentusiasmerebber": "autoentusiasmare",
    "autoentusiasmerebbero": "autoentusiasmare",
    "autoentusiasmerei": "autoentusiasmare",
    "autoentusiasmeremmo": "autoentusiasmare",
    "autoentusiasmeremo": "autoentusiasmare",
    "autoentusiasmereste": "autoentusiasmare",
    "autoentusiasmeresti": "autoentusiasmare",
    "autoentusiasmerete": "autoentusiasmare",
    "autoentusiasmerà": "autoentusiasmare",
    "autoentusiasmerò": "autoentusiasmare",
    "autoentusiasmi": "autoentusiasmare",
    "autoentusiasmiamo": "autoentusiasmare",
    "autoentusiasmiate": "autoentusiasmare",
    "autoentusiasmin": "autoentusiasmare",
    "autoentusiasmino": "autoentusiasmare",
    "autoentusiasmo": "autoentusiasmare",
    "autoentusiasmò": "autoentusiasmare",
    "autoeriga": "autoerigere",
    "autoerigan": "autoerigere",
    "autoerigano": "autoerigere",
    "autoerige": "autoerigere",
    "autoerigei": "autoerigere",
    "autoerigemmo": "autoerigere",
    "autoerigendo": "autoerigere",
    "autoerigente": "autoerigere",
    "autoerigenti": "autoerigere",
    "autoeriger": "autoerigere",
    "autoerigerai": "autoerigere",
    "autoerigeran": "autoerigere",
    "autoerigeranno": "autoerigere",
    "autoerigerebbe": "autoerigere",
    "autoerigerebber": "autoerigere",
    "autoerigerebbero": "autoerigere",
    "autoerigerei": "autoerigere",
    "autoerigeremmo": "autoerigere",
    "autoerigeremo": "autoerigere",
    "autoerigereste": "autoerigere",
    "autoerigeresti": "autoerigere",
    "autoerigerete": "autoerigere",
    "autoerigeron": "autoerigere",
    "autoerigerono": "autoerigere",
    "autoerigerà": "autoerigere",
    "autoerigerò": "autoerigere",
    "autoerigesse": "autoerigere",
    "autoerigesser": "autoerigere",
    "autoerigessero": "autoerigere",
    "autoerigessi": "autoerigere",
    "autoerigessimo": "autoerigere",
    "autoerigeste": "autoerigere",
    "autoerigesti": "autoerigere",
    "autoerigete": "autoerigere",
    "autoerigeva": "autoerigere",
    "autoerigevamo": "autoerigere",
    "autoerigevan": "autoerigere",
    "autoerigevano": "autoerigere",
    "autoerigevate": "autoerigere",
    "autoerigevi": "autoerigere",
    "autoerigevo": "autoerigere",
    "autoerigi": "autoerigere",
    "autoerigiamo": "autoerigere",
    "autoerigiate": "autoerigere",
    "autoerigiuta": "autoerigere",
    "autoerigiute": "autoerigere",
    "autoerigiuti": "autoerigere",
    "autoerigiuto": "autoerigere",
    "autoerigo": "autoerigere",
    "autoerigon": "autoerigere",
    "autoerigono": "autoerigere",
    "autoerigè": "autoerigere",
    "autoerotica": "autoerotico",
    "autoerotiche": "autoerotico",
    "autoerotici": "autoerotico",
    "autoesaltatori": "autoesaltatorio",
    "autoesaltatoria": "autoesaltatorio",
    "autoesaltatorie": "autoesaltatorio",
    "autoescluda": "autoescludere",
    "autoescludan": "autoescludere",
    "autoescludano": "autoescludere",
    "autoesclude": "autoescludere",
    "autoescludei": "autoescludere",
    "autoescludemmo": "autoescludere",
    "autoescludendo": "autoescludere",
    "autoescludente": "autoescludere",
    "autoescludenti": "autoescludere",
    "autoescluder": "autoescludere",
    "autoescluderai": "autoescludere",
    "autoescluderan": "autoescludere",
    "autoescluderanno": "autoescludere",
    "autoescluderebbe": "autoescludere",
    "autoescluderebber": "autoescludere",
    "autoescluderebbero": "autoescludere",
    "autoescluderei": "autoescludere",
    "autoescluderemmo": "autoescludere",
    "autoescluderemo": "autoescludere",
    "autoescludereste": "autoescludere",
    "autoescluderesti": "autoescludere",
    "autoescluderete": "autoescludere",
    "autoescluderon": "autoescludere",
    "autoescluderono": "autoescludere",
    "autoescluderà": "autoescludere",
    "autoescluderò": "autoescludere",
    "autoescludesse": "autoescludere",
    "autoescludesser": "autoescludere",
    "autoescludessero": "autoescludere",
    "autoescludessi": "autoescludere",
    "autoescludessimo": "autoescludere",
    "autoescludeste": "autoescludere",
    "autoescludesti": "autoescludere",
    "autoescludete": "autoescludere",
    "autoescludeva": "autoescludere",
    "autoescludevamo": "autoescludere",
    "autoescludevan": "autoescludere",
    "autoescludevano": "autoescludere",
    "autoescludevate": "autoescludere",
    "autoescludevi": "autoescludere",
    "autoescludevo": "autoescludere",
    "autoescludi": "autoescludere",
    "autoescludiamo": "autoescludere",
    "autoescludiate": "autoescludere",
    "autoescludo": "autoescludere",
    "autoescludon": "autoescludere",
    "autoescludono": "autoescludere",
    "autoescluduta": "autoescludere",
    "autoescludute": "autoescludere",
    "autoescluduti": "autoescludere",
    "autoescluduto": "autoescludere",
    "autoescludè": "autoescludere",
    "autoesili": "autoesiliare",
    "autoesilia": "autoesiliare",
    "autoesiliai": "autoesiliare",
    "autoesiliammo": "autoesiliare",
    "autoesiliamo": "autoesiliare",
    "autoesilian": "autoesiliare",
    "autoesiliando": "autoesiliare",
    "autoesiliano": "autoesiliare",
    "autoesiliante": "autoesiliare",
    "autoesilianti": "autoesiliare",
    "autoesiliar": "autoesiliare",
    "autoesiliaron": "autoesiliare",
    "autoesiliarono": "autoesiliare",
    "autoesiliasse": "autoesiliare",
    "autoesiliasser": "autoesiliare",
    "autoesiliassero": "autoesiliare",
    "autoesiliassi": "autoesiliare",
    "autoesiliassimo": "autoesiliare",
    "autoesiliaste": "autoesiliare",
    "autoesiliasti": "autoesiliare",
    "autoesiliata": "autoesiliare",
    "autoesiliate": "autoesiliare",
    "autoesiliati": "autoesiliare",
    "autoesiliato": "autoesiliare",
    "autoesiliava": "autoesiliare",
    "autoesiliavamo": "autoesiliare",
    "autoesiliavan": "autoesiliare",
    "autoesiliavano": "autoesiliare",
    "autoesiliavate": "autoesiliare",
    "autoesiliavi": "autoesiliare",
    "autoesiliavo": "autoesiliare",
    "autoesilierai": "autoesiliare",
    "autoesilieran": "autoesiliare",
    "autoesilieranno": "autoesiliare",
    "autoesilierebbe": "autoesiliare",
    "autoesilierebber": "autoesiliare",
    "autoesilierebbero": "autoesiliare",
    "autoesilierei": "autoesiliare",
    "autoesilieremmo": "autoesiliare",
    "autoesilieremo": "autoesiliare",
    "autoesiliereste": "autoesiliare",
    "autoesilieresti": "autoesiliare",
    "autoesilierete": "autoesiliare",
    "autoesilierà": "autoesiliare",
    "autoesilierò": "autoesiliare",
    "autoesilin": "autoesiliare",
    "autoesilino": "autoesiliare",
    "autoesilio": "autoesiliare",
    "autoesiliò": "autoesiliare",
    "autoferrotranviari": "autoferrotranviario",
    "autoferrotranviaria": "autoferrotranviario",
    "autoferrotranviarie": "autoferrotranviario",
    "autoferrotranvieri": "autoferrotranviere",
    "autofinanzi": "autofinanziare",
    "autofinanzia": "autofinanziare",
    "autofinanziai": "autofinanziare",
    "autofinanziamenti": "autofinanziamento",
    "autofinanziammo": "autofinanziare",
    "autofinanziamo": "autofinanziare",
    "autofinanzian": "autofinanziare",
    "autofinanziando": "autofinanziare",
    "autofinanziano": "autofinanziare",
    "autofinanziante": "autofinanziare",
    "autofinanzianti": "autofinanziare",
    "autofinanziar": "autofinanziare",
    "autofinanziaron": "autofinanziare",
    "autofinanziarono": "autofinanziare",
    "autofinanziasse": "autofinanziare",
    "autofinanziasser": "autofinanziare",
    "autofinanziassero": "autofinanziare",
    "autofinanziassi": "autofinanziare",
    "autofinanziassimo": "autofinanziare",
    "autofinanziaste": "autofinanziare",
    "autofinanziasti": "autofinanziare",
    "autofinanziata": "autofinanziare",
    "autofinanziate": "autofinanziare",
    "autofinanziati": "autofinanziare",
    "autofinanziato": "autofinanziare",
    "autofinanziava": "autofinanziare",
    "autofinanziavamo": "autofinanziare",
    "autofinanziavan": "autofinanziare",
    "autofinanziavano": "autofinanziare",
    "autofinanziavate": "autofinanziare",
    "autofinanziavi": "autofinanziare",
    "autofinanziavo": "autofinanziare",
    "autofinanzierai": "autofinanziare",
    "autofinanzieran": "autofinanziare",
    "autofinanzieranno": "autofinanziare",
    "autofinanzierebbe": "autofinanziare",
    "autofinanzierebber": "autofinanziare",
    "autofinanzierebbero": "autofinanziare",
    "autofinanzierei": "autofinanziare",
    "autofinanzieremmo": "autofinanziare",
    "autofinanzieremo": "autofinanziare",
    "autofinanziereste": "autofinanziare",
    "autofinanzieresti": "autofinanziare",
    "autofinanzierete": "autofinanziare",
    "autofinanzierà": "autofinanziare",
    "autofinanzierò": "autofinanziare",
    "autofinanzin": "autofinanziare",
    "autofinanzino": "autofinanziare",
    "autofinanzio": "autofinanziare",
    "autofinanziò": "autofinanziare",
    "autoflagella": "autoflagellare",
    "autoflagellai": "autoflagellare",
    "autoflagellammo": "autoflagellare",
    "autoflagellan": "autoflagellare",
    "autoflagellando": "autoflagellare",
    "autoflagellano": "autoflagellare",
    "autoflagellante": "autoflagellare",
    "autoflagellanti": "autoflagellare",
    "autoflagellar": "autoflagellare",
    "autoflagellaron": "autoflagellare",
    "autoflagellarono": "autoflagellare",
    "autoflagellasse": "autoflagellare",
    "autoflagellasser": "autoflagellare",
    "autoflagellassero": "autoflagellare",
    "autoflagellassi": "autoflagellare",
    "autoflagellassimo": "autoflagellare",
    "autoflagellaste": "autoflagellare",
    "autoflagellasti": "autoflagellare",
    "autoflagellata": "autoflagellato",
    "autoflagellate": "autoflagellato",
    "autoflagellati": "autoflagellato",
    "autoflagellato": "autoflagellare",
    "autoflagellava": "autoflagellare",
    "autoflagellavamo": "autoflagellare",
    "autoflagellavan": "autoflagellare",
    "autoflagellavano": "autoflagellare",
    "autoflagellavate": "autoflagellare",
    "autoflagellavi": "autoflagellare",
    "autoflagellavo": "autoflagellare",
    "autoflagellerai": "autoflagellare",
    "autoflagelleran": "autoflagellare",
    "autoflagelleranno": "autoflagellare",
    "autoflagellerebbe": "autoflagellare",
    "autoflagellerebber": "autoflagellare",
    "autoflagellerebbero": "autoflagellare",
    "autoflagellerei": "autoflagellare",
    "autoflagelleremmo": "autoflagellare",
    "autoflagelleremo": "autoflagellare",
    "autoflagellereste": "autoflagellare",
    "autoflagelleresti": "autoflagellare",
    "autoflagellerete": "autoflagellare",
    "autoflagellerà": "autoflagellare",
    "autoflagellerò": "autoflagellare",
    "autoflagelli": "autoflagellare",
    "autoflagelliamo": "autoflagellare",
    "autoflagelliate": "autoflagellare",
    "autoflagellin": "autoflagellare",
    "autoflagellino": "autoflagellare",
    "autoflagello": "autoflagellare",
    "autoflagellò": "autoflagellare",
    "autogena": "autogeno",
    "autogene": "autogeno",
    "autogenera": "autogenerare",
    "autogenerai": "autogenerare",
    "autogenerammo": "autogenerare",
    "autogeneran": "autogenerare",
    "autogenerando": "autogenerare",
    "autogenerano": "autogenerare",
    "autogenerante": "autogenerare",
    "autogeneranti": "autogenerare",
    "autogenerar": "autogenerare",
    "autogeneraron": "autogenerare",
    "autogenerarono": "autogenerare",
    "autogenerasse": "autogenerare",
    "autogenerasser": "autogenerare",
    "autogenerassero": "autogenerare",
    "autogenerassi": "autogenerare",
    "autogenerassimo": "autogenerare",
    "autogeneraste": "autogenerare",
    "autogenerasti": "autogenerare",
    "autogenerata": "autogenerare",
    "autogenerate": "autogenerare",
    "autogenerati": "autogenerare",
    "autogenerato": "autogenerare",
    "autogenerava": "autogenerare",
    "autogeneravamo": "autogenerare",
    "autogeneravan": "autogenerare",
    "autogeneravano": "autogenerare",
    "autogeneravate": "autogenerare",
    "autogeneravi": "autogenerare",
    "autogeneravo": "autogenerare",
    "autogenererai": "autogenerare",
    "autogenereran": "autogenerare",
    "autogenereranno": "autogenerare",
    "autogenererebbe": "autogenerare",
    "autogenererebber": "autogenerare",
    "autogenererebbero": "autogenerare",
    "autogenererei": "autogenerare",
    "autogenereremmo": "autogenerare",
    "autogenereremo": "autogenerare",
    "autogenerereste": "autogenerare",
    "autogenereresti": "autogenerare",
    "autogenererete": "autogenerare",
    "autogenererà": "autogenerare",
    "autogenererò": "autogenerare",
    "autogeneri": "autogenerare",
    "autogeneriamo": "autogenerare",
    "autogeneriate": "autogenerare",
    "autogenerin": "autogenerare",
    "autogenerino": "autogenerare",
    "autogenero": "autogenerare",
    "autogenerò": "autogenerare",
    "autogeni": "autogeno",
    "autogesta": "autogestire",
    "autogestan": "autogestire",
    "autogestano": "autogestire",
    "autogeste": "autogestire",
    "autogestendo": "autogestire",
    "autogestente": "autogestire",
    "autogestenti": "autogestire",
    "autogesti": "autogestire",
    "autogestiamo": "autogestire",
    "autogestiate": "autogestire",
    "autogestii": "autogestire",
    "autogestimmo": "autogestire",
    "autogestioni": "autogestione",
    "autogestir": "autogestire",
    "autogestirai": "autogestire",
    "autogestiran": "autogestire",
    "autogestiranno": "autogestire",
    "autogestirebbe": "autogestire",
    "autogestirebber": "autogestire",
    "autogestirebbero": "autogestire",
    "autogestirei": "autogestire",
    "autogestiremmo": "autogestire",
    "autogestiremo": "autogestire",
    "autogestireste": "autogestire",
    "autogestiresti": "autogestire",
    "autogestirete": "autogestire",
    "autogestiron": "autogestire",
    "autogestirono": "autogestire",
    "autogestirà": "autogestire",
    "autogestirò": "autogestire",
    "autogestisse": "autogestire",
    "autogestisser": "autogestire",
    "autogestissero": "autogestire",
    "autogestissi": "autogestire",
    "autogestissimo": "autogestire",
    "autogestiste": "autogestire",
    "autogestisti": "autogestire",
    "autogestita": "autogestire",
    "autogestite": "autogestire",
    "autogestiti": "autogestire",
    "autogestito": "autogestire",
    "autogestiva": "autogestire",
    "autogestivamo": "autogestire",
    "autogestivan": "autogestire",
    "autogestivano": "autogestire",
    "autogestivate": "autogestire",
    "autogestivi": "autogestire",
    "autogestivo": "autogestire",
    "autogesto": "autogestire",
    "autogeston": "autogestire",
    "autogestono": "autogestire",
    "autogestì": "autogestire",
    "autogiudica": "autogiudicare",
    "autogiudicai": "autogiudicare",
    "autogiudicammo": "autogiudicare",
    "autogiudican": "autogiudicare",
    "autogiudicando": "autogiudicare",
    "autogiudicano": "autogiudicare",
    "autogiudicante": "autogiudicare",
    "autogiudicanti": "autogiudicare",
    "autogiudicar": "autogiudicare",
    "autogiudicaron": "autogiudicare",
    "autogiudicarono": "autogiudicare",
    "autogiudicasse": "autogiudicare",
    "autogiudicasser": "autogiudicare",
    "autogiudicassero": "autogiudicare",
    "autogiudicassi": "autogiudicare",
    "autogiudicassimo": "autogiudicare",
    "autogiudicaste": "autogiudicare",
    "autogiudicasti": "autogiudicare",
    "autogiudicata": "autogiudicare",
    "autogiudicate": "autogiudicare",
    "autogiudicati": "autogiudicare",
    "autogiudicato": "autogiudicare",
    "autogiudicava": "autogiudicare",
    "autogiudicavamo": "autogiudicare",
    "autogiudicavan": "autogiudicare",
    "autogiudicavano": "autogiudicare",
    "autogiudicavate": "autogiudicare",
    "autogiudicavi": "autogiudicare",
    "autogiudicavo": "autogiudicare",
    "autogiudicherai": "autogiudicare",
    "autogiudicheran": "autogiudicare",
    "autogiudicheranno": "autogiudicare",
    "autogiudicherebbe": "autogiudicare",
    "autogiudicherebber": "autogiudicare",
    "autogiudicherebbero": "autogiudicare",
    "autogiudicherei": "autogiudicare",
    "autogiudicheremmo": "autogiudicare",
    "autogiudicheremo": "autogiudicare",
    "autogiudichereste": "autogiudicare",
    "autogiudicheresti": "autogiudicare",
    "autogiudicherete": "autogiudicare",
    "autogiudicherà": "autogiudicare",
    "autogiudicherò": "autogiudicare",
    "autogiudichi": "autogiudicare",
    "autogiudichiamo": "autogiudicare",
    "autogiudichiate": "autogiudicare",
    "autogiudichin": "autogiudicare",
    "autogiudichino": "autogiudicare",
    "autogiudico": "autogiudicare",
    "autogiudicò": "autogiudicare",
    "autogoverni": "autogoverno",
    "autografa": "autografo",
    "autografe": "autografo",
    "autografi": "autografo",
    "autogratificanti": "autogratificante",
    "autogratificatori": "autogratificatorio",
    "autogratificatoria": "autogratificatorio",
    "autogratificatorie": "autogratificatorio",
    "autoidentificatori": "autoidentificatorio",
    "autoidentificatoria": "autoidentificatorio",
    "autoidentificatorie": "autoidentificatorio",
    "autoimmatricola": "autoimmatricolare",
    "autoimmatricolai": "autoimmatricolare",
    "autoimmatricolammo": "autoimmatricolare",
    "autoimmatricolan": "autoimmatricolare",
    "autoimmatricolando": "autoimmatricolare",
    "autoimmatricolano": "autoimmatricolare",
    "autoimmatricolante": "autoimmatricolare",
    "autoimmatricolanti": "autoimmatricolare",
    "autoimmatricolar": "autoimmatricolare",
    "autoimmatricolaron": "autoimmatricolare",
    "autoimmatricolarono": "autoimmatricolare",
    "autoimmatricolasse": "autoimmatricolare",
    "autoimmatricolasser": "autoimmatricolare",
    "autoimmatricolassero": "autoimmatricolare",
    "autoimmatricolassi": "autoimmatricolare",
    "autoimmatricolassimo": "autoimmatricolare",
    "autoimmatricolaste": "autoimmatricolare",
    "autoimmatricolasti": "autoimmatricolare",
    "autoimmatricolata": "autoimmatricolare",
    "autoimmatricolate": "autoimmatricolare",
    "autoimmatricolati": "autoimmatricolare",
    "autoimmatricolato": "autoimmatricolare",
    "autoimmatricolava": "autoimmatricolare",
    "autoimmatricolavamo": "autoimmatricolare",
    "autoimmatricolavan": "autoimmatricolare",
    "autoimmatricolavano": "autoimmatricolare",
    "autoimmatricolavate": "autoimmatricolare",
    "autoimmatricolavi": "autoimmatricolare",
    "autoimmatricolavo": "autoimmatricolare",
    "autoimmatricolerai": "autoimmatricolare",
    "autoimmatricoleran": "autoimmatricolare",
    "autoimmatricoleranno": "autoimmatricolare",
    "autoimmatricolerebbe": "autoimmatricolare",
    "autoimmatricolerebber": "autoimmatricolare",
    "autoimmatricolerebbero": "autoimmatricolare",
    "autoimmatricolerei": "autoimmatricolare",
    "autoimmatricoleremmo": "autoimmatricolare",
    "autoimmatricoleremo": "autoimmatricolare",
    "autoimmatricolereste": "autoimmatricolare",
    "autoimmatricoleresti": "autoimmatricolare",
    "autoimmatricolerete": "autoimmatricolare",
    "autoimmatricolerà": "autoimmatricolare",
    "autoimmatricolerò": "autoimmatricolare",
    "autoimmatricoli": "autoimmatricolare",
    "autoimmatricoliamo": "autoimmatricolare",
    "autoimmatricoliate": "autoimmatricolare",
    "autoimmatricolin": "autoimmatricolare",
    "autoimmatricolino": "autoimmatricolare",
    "autoimmatricolo": "autoimmatricolare",
    "autoimmatricolò": "autoimmatricolare",
    "autoimposta": "autoimpostare",
    "autoimpostai": "autoimpostare",
    "autoimpostammo": "autoimpostare",
    "autoimpostan": "autoimpostare",
    "autoimpostando": "autoimpostare",
    "autoimpostano": "autoimpostare",
    "autoimpostante": "autoimpostare",
    "autoimpostanti": "autoimpostare",
    "autoimpostar": "autoimpostare",
    "autoimpostaron": "autoimpostare",
    "autoimpostarono": "autoimpostare",
    "autoimpostasse": "autoimpostare",
    "autoimpostasser": "autoimpostare",
    "autoimpostassero": "autoimpostare",
    "autoimpostassi": "autoimpostare",
    "autoimpostassimo": "autoimpostare",
    "autoimpostaste": "autoimpostare",
    "autoimpostasti": "autoimpostare",
    "autoimpostata": "autoimpostare",
    "autoimpostate": "autoimpostare",
    "autoimpostati": "autoimpostare",
    "autoimpostato": "autoimpostare",
    "autoimpostava": "autoimpostare",
    "autoimpostavamo": "autoimpostare",
    "autoimpostavan": "autoimpostare",
    "autoimpostavano": "autoimpostare",
    "autoimpostavate": "autoimpostare",
    "autoimpostavi": "autoimpostare",
    "autoimpostavo": "autoimpostare",
    "autoimposterai": "autoimpostare",
    "autoimposteran": "autoimpostare",
    "autoimposteranno": "autoimpostare",
    "autoimposterebbe": "autoimpostare",
    "autoimposterebber": "autoimpostare",
    "autoimposterebbero": "autoimpostare",
    "autoimposterei": "autoimpostare",
    "autoimposteremmo": "autoimpostare",
    "autoimposteremo": "autoimpostare",
    "autoimpostereste": "autoimpostare",
    "autoimposteresti": "autoimpostare",
    "autoimposterete": "autoimpostare",
    "autoimposterà": "autoimpostare",
    "autoimposterò": "autoimpostare",
    "autoimposti": "autoimpostare",
    "autoimpostiamo": "autoimpostare",
    "autoimpostiate": "autoimpostare",
    "autoimpostin": "autoimpostare",
    "autoimpostino": "autoimpostare",
    "autoimposto": "autoimpostare",
    "autoimpostò": "autoimpostare",
    "autoimprigiona": "autoimprigionare",
    "autoimprigionai": "autoimprigionare",
    "autoimprigionammo": "autoimprigionare",
    "autoimprigionan": "autoimprigionare",
    "autoimprigionando": "autoimprigionare",
    "autoimprigionano": "autoimprigionare",
    "autoimprigionante": "autoimprigionare",
    "autoimprigionanti": "autoimprigionare",
    "autoimprigionar": "autoimprigionare",
    "autoimprigionaron": "autoimprigionare",
    "autoimprigionarono": "autoimprigionare",
    "autoimprigionasse": "autoimprigionare",
    "autoimprigionasser": "autoimprigionare",
    "autoimprigionassero": "autoimprigionare",
    "autoimprigionassi": "autoimprigionare",
    "autoimprigionassimo": "autoimprigionare",
    "autoimprigionaste": "autoimprigionare",
    "autoimprigionasti": "autoimprigionare",
    "autoimprigionata": "autoimprigionare",
    "autoimprigionate": "autoimprigionare",
    "autoimprigionati": "autoimprigionare",
    "autoimprigionato": "autoimprigionare",
    "autoimprigionava": "autoimprigionare",
    "autoimprigionavamo": "autoimprigionare",
    "autoimprigionavan": "autoimprigionare",
    "autoimprigionavano": "autoimprigionare",
    "autoimprigionavate": "autoimprigionare",
    "autoimprigionavi": "autoimprigionare",
    "autoimprigionavo": "autoimprigionare",
    "autoimprigionerai": "autoimprigionare",
    "autoimprigioneran": "autoimprigionare",
    "autoimprigioneranno": "autoimprigionare",
    "autoimprigionerebbe": "autoimprigionare",
    "autoimprigionerebber": "autoimprigionare",
    "autoimprigionerebbero": "autoimprigionare",
    "autoimprigionerei": "autoimprigionare",
    "autoimprigioneremmo": "autoimprigionare",
    "autoimprigioneremo": "autoimprigionare",
    "autoimprigionereste": "autoimprigionare",
    "autoimprigioneresti": "autoimprigionare",
    "autoimprigionerete": "autoimprigionare",
    "autoimprigionerà": "autoimprigionare",
    "autoimprigionerò": "autoimprigionare",
    "autoimprigioni": "autoimprigionare",
    "autoimprigioniamo": "autoimprigionare",
    "autoimprigioniate": "autoimprigionare",
    "autoimprigionin": "autoimprigionare",
    "autoimprigionino": "autoimprigionare",
    "autoimprigiono": "autoimprigionare",
    "autoimprigionò": "autoimprigionare",
    "autoincendi": "autoincendiare",
    "autoincendia": "autoincendiare",
    "autoincendiai": "autoincendiare",
    "autoincendiammo": "autoincendiare",
    "autoincendiamo": "autoincendiare",
    "autoincendian": "autoincendiare",
    "autoincendiando": "autoincendiare",
    "autoincendiano": "autoincendiare",
    "autoincendiante": "autoincendiare",
    "autoincendianti": "autoincendiare",
    "autoincendiar": "autoincendiare",
    "autoincendiaron": "autoincendiare",
    "autoincendiarono": "autoincendiare",
    "autoincendiasse": "autoincendiare",
    "autoincendiasser": "autoincendiare",
    "autoincendiassero": "autoincendiare",
    "autoincendiassi": "autoincendiare",
    "autoincendiassimo": "autoincendiare",
    "autoincendiaste": "autoincendiare",
    "autoincendiasti": "autoincendiare",
    "autoincendiata": "autoincendiare",
    "autoincendiate": "autoincendiare",
    "autoincendiati": "autoincendiare",
    "autoincendiato": "autoincendiare",
    "autoincendiava": "autoincendiare",
    "autoincendiavamo": "autoincendiare",
    "autoincendiavan": "autoincendiare",
    "autoincendiavano": "autoincendiare",
    "autoincendiavate": "autoincendiare",
    "autoincendiavi": "autoincendiare",
    "autoincendiavo": "autoincendiare",
    "autoincendierai": "autoincendiare",
    "autoincendieran": "autoincendiare",
    "autoincendieranno": "autoincendiare",
    "autoincendierebbe": "autoincendiare",
    "autoincendierebber": "autoincendiare",
    "autoincendierebbero": "autoincendiare",
    "autoincendierei": "autoincendiare",
    "autoincendieremmo": "autoincendiare",
    "autoincendieremo": "autoincendiare",
    "autoincendiereste": "autoincendiare",
    "autoincendieresti": "autoincendiare",
    "autoincendierete": "autoincendiare",
    "autoincendierà": "autoincendiare",
    "autoincendierò": "autoincendiare",
    "autoincendin": "autoincendiare",
    "autoincendino": "autoincendiare",
    "autoincendio": "autoincendiare",
    "autoincendiò": "autoincendiare",
    "autoincolpa": "autoincolpare",
    "autoincolpai": "autoincolpare",
    "autoincolpammo": "autoincolpare",
    "autoincolpan": "autoincolpare",
    "autoincolpando": "autoincolpare",
    "autoincolpano": "autoincolpare",
    "autoincolpante": "autoincolpare",
    "autoincolpanti": "autoincolpare",
    "autoincolpar": "autoincolpare",
    "autoincolparon": "autoincolpare",
    "autoincolparono": "autoincolpare",
    "autoincolpasse": "autoincolpare",
    "autoincolpasser": "autoincolpare",
    "autoincolpassero": "autoincolpare",
    "autoincolpassi": "autoincolpare",
    "autoincolpassimo": "autoincolpare",
    "autoincolpaste": "autoincolpare",
    "autoincolpasti": "autoincolpare",
    "autoincolpata": "autoincolpare",
    "autoincolpate": "autoincolpare",
    "autoincolpati": "autoincolpare",
    "autoincolpato": "autoincolpare",
    "autoincolpava": "autoincolpare",
    "autoincolpavamo": "autoincolpare",
    "autoincolpavan": "autoincolpare",
    "autoincolpavano": "autoincolpare",
    "autoincolpavate": "autoincolpare",
    "autoincolpavi": "autoincolpare",
    "autoincolpavo": "autoincolpare",
    "autoincolperai": "autoincolpare",
    "autoincolperan": "autoincolpare",
    "autoincolperanno": "autoincolpare",
    "autoincolperebbe": "autoincolpare",
    "autoincolperebber": "autoincolpare",
    "autoincolperebbero": "autoincolpare",
    "autoincolperei": "autoincolpare",
    "autoincolperemmo": "autoincolpare",
    "autoincolperemo": "autoincolpare",
    "autoincolpereste": "autoincolpare",
    "autoincolperesti": "autoincolpare",
    "autoincolperete": "autoincolpare",
    "autoincolperà": "autoincolpare",
    "autoincolperò": "autoincolpare",
    "autoincolpi": "autoincolpare",
    "autoincolpiamo": "autoincolpare",
    "autoincolpiate": "autoincolpare",
    "autoincolpin": "autoincolpare",
    "autoincolpino": "autoincolpare",
    "autoincolpo": "autoincolpare",
    "autoincolpò": "autoincolpare",
    "autoincorona": "autoincoronare",
    "autoincoronai": "autoincoronare",
    "autoincoronammo": "autoincoronare",
    "autoincoronan": "autoincoronare",
    "autoincoronando": "autoincoronare",
    "autoincoronano": "autoincoronare",
    "autoincoronante": "autoincoronare",
    "autoincoronanti": "autoincoronare",
    "autoincoronar": "autoincoronare",
    "autoincoronaron": "autoincoronare",
    "autoincoronarono": "autoincoronare",
    "autoincoronasse": "autoincoronare",
    "autoincoronasser": "autoincoronare",
    "autoincoronassero": "autoincoronare",
    "autoincoronassi": "autoincoronare",
    "autoincoronassimo": "autoincoronare",
    "autoincoronaste": "autoincoronare",
    "autoincoronasti": "autoincoronare",
    "autoincoronata": "autoincoronare",
    "autoincoronate": "autoincoronare",
    "autoincoronati": "autoincoronare",
    "autoincoronato": "autoincoronare",
    "autoincoronava": "autoincoronare",
    "autoincoronavamo": "autoincoronare",
    "autoincoronavan": "autoincoronare",
    "autoincoronavano": "autoincoronare",
    "autoincoronavate": "autoincoronare",
    "autoincoronavi": "autoincoronare",
    "autoincoronavo": "autoincoronare",
    "autoincoronerai": "autoincoronare",
    "autoincoroneran": "autoincoronare",
    "autoincoroneranno": "autoincoronare",
    "autoincoronerebbe": "autoincoronare",
    "autoincoronerebber": "autoincoronare",
    "autoincoronerebbero": "autoincoronare",
    "autoincoronerei": "autoincoronare",
    "autoincoroneremmo": "autoincoronare",
    "autoincoroneremo": "autoincoronare",
    "autoincoronereste": "autoincoronare",
    "autoincoroneresti": "autoincoronare",
    "autoincoronerete": "autoincoronare",
    "autoincoronerà": "autoincoronare",
    "autoincoronerò": "autoincoronare",
    "autoincoroni": "autoincoronare",
    "autoincoroniamo": "autoincoronare",
    "autoincoroniate": "autoincoronare",
    "autoincoronin": "autoincoronare",
    "autoincoronino": "autoincoronare",
    "autoincorono": "autoincoronare",
    "autoincoronò": "autoincoronare",
    "autoindulgenti": "autoindulgente",
    "autoinfligga": "autoinfliggere",
    "autoinfliggan": "autoinfliggere",
    "autoinfliggano": "autoinfliggere",
    "autoinfligge": "autoinfliggere",
    "autoinfliggemmo": "autoinfliggere",
    "autoinfliggendo": "autoinfliggere",
    "autoinfliggente": "autoinfliggere",
    "autoinfliggenti": "autoinfliggere",
    "autoinfligger": "autoinfliggere",
    "autoinfliggerai": "autoinfliggere",
    "autoinfliggeran": "autoinfliggere",
    "autoinfliggeranno": "autoinfliggere",
    "autoinfliggerebbe": "autoinfliggere",
    "autoinfliggerebber": "autoinfliggere",
    "autoinfliggerebbero": "autoinfliggere",
    "autoinfliggerei": "autoinfliggere",
    "autoinfliggeremmo": "autoinfliggere",
    "autoinfliggeremo": "autoinfliggere",
    "autoinfliggereste": "autoinfliggere",
    "autoinfliggeresti": "autoinfliggere",
    "autoinfliggerete": "autoinfliggere",
    "autoinfliggerà": "autoinfliggere",
    "autoinfliggerò": "autoinfliggere",
    "autoinfliggesse": "autoinfliggere",
    "autoinfliggesser": "autoinfliggere",
    "autoinfliggessero": "autoinfliggere",
    "autoinfliggessi": "autoinfliggere",
    "autoinfliggessimo": "autoinfliggere",
    "autoinfliggeste": "autoinfliggere",
    "autoinfliggesti": "autoinfliggere",
    "autoinfliggete": "autoinfliggere",
    "autoinfliggeva": "autoinfliggere",
    "autoinfliggevamo": "autoinfliggere",
    "autoinfliggevan": "autoinfliggere",
    "autoinfliggevano": "autoinfliggere",
    "autoinfliggevate": "autoinfliggere",
    "autoinfliggevi": "autoinfliggere",
    "autoinfliggevo": "autoinfliggere",
    "autoinfliggi": "autoinfliggere",
    "autoinfliggiamo": "autoinfliggere",
    "autoinfliggiate": "autoinfliggere",
    "autoinfliggo": "autoinfliggere",
    "autoinfliggon": "autoinfliggere",
    "autoinfliggono": "autoinfliggere",
    "autoinflisser": "autoinfliggere",
    "autoinflissero": "autoinfliggere",
    "autoinflissi": "autoinfliggere",
    "autoinflissè": "autoinfliggere",
    "autoinflitta": "autoinfliggere",
    "autoinflitte": "autoinfliggere",
    "autoinflitti": "autoinfliggere",
    "autoinflitto": "autoinfliggere",
    "autoinganna": "autoingannare",
    "autoingannai": "autoingannare",
    "autoingannammo": "autoingannare",
    "autoingannan": "autoingannare",
    "autoingannando": "autoingannare",
    "autoingannano": "autoingannare",
    "autoingannante": "autoingannare",
    "autoingannanti": "autoingannare",
    "autoingannar": "autoingannare",
    "autoingannaron": "autoingannare",
    "autoingannarono": "autoingannare",
    "autoingannasse": "autoingannare",
    "autoingannasser": "autoingannare",
    "autoingannassero": "autoingannare",
    "autoingannassi": "autoingannare",
    "autoingannassimo": "autoingannare",
    "autoingannaste": "autoingannare",
    "autoingannasti": "autoingannare",
    "autoingannata": "autoingannare",
    "autoingannate": "autoingannare",
    "autoingannati": "autoingannare",
    "autoingannato": "autoingannare",
    "autoingannava": "autoingannare",
    "autoingannavamo": "autoingannare",
    "autoingannavan": "autoingannare",
    "autoingannavano": "autoingannare",
    "autoingannavate": "autoingannare",
    "autoingannavi": "autoingannare",
    "autoingannavo": "autoingannare",
    "autoingannerai": "autoingannare",
    "autoinganneran": "autoingannare",
    "autoinganneranno": "autoingannare",
    "autoingannerebbe": "autoingannare",
    "autoingannerebber": "autoingannare",
    "autoingannerebbero": "autoingannare",
    "autoingannerei": "autoingannare",
    "autoinganneremmo": "autoingannare",
    "autoinganneremo": "autoingannare",
    "autoingannereste": "autoingannare",
    "autoinganneresti": "autoingannare",
    "autoingannerete": "autoingannare",
    "autoingannerà": "autoingannare",
    "autoingannerò": "autoingannare",
    "autoinganni": "autoingannare",
    "autoinganniamo": "autoingannare",
    "autoinganniate": "autoingannare",
    "autoingannin": "autoingannare",
    "autoingannino": "autoingannare",
    "autoinganno": "autoingannare",
    "autoingannò": "autoingannare",
    "autoinorgogla": "autoinorgoglire",
    "autoinorgoglan": "autoinorgoglire",
    "autoinorgoglano": "autoinorgoglire",
    "autoinorgogle": "autoinorgoglire",
    "autoinorgoglendo": "autoinorgoglire",
    "autoinorgoglente": "autoinorgoglire",
    "autoinorgoglenti": "autoinorgoglire",
    "autoinorgogli": "autoinorgoglire",
    "autoinorgogliamo": "autoinorgoglire",
    "autoinorgogliate": "autoinorgoglire",
    "autoinorgoglii": "autoinorgoglire",
    "autoinorgoglimmo": "autoinorgoglire",
    "autoinorgoglir": "autoinorgoglire",
    "autoinorgoglirai": "autoinorgoglire",
    "autoinorgogliran": "autoinorgoglire",
    "autoinorgogliranno": "autoinorgoglire",
    "autoinorgoglirebbe": "autoinorgoglire",
    "autoinorgoglirebber": "autoinorgoglire",
    "autoinorgoglirebbero": "autoinorgoglire",
    "autoinorgoglirei": "autoinorgoglire",
    "autoinorgogliremmo": "autoinorgoglire",
    "autoinorgogliremo": "autoinorgoglire",
    "autoinorgoglireste": "autoinorgoglire",
    "autoinorgogliresti": "autoinorgoglire",
    "autoinorgoglirete": "autoinorgoglire",
    "autoinorgogliron": "autoinorgoglire",
    "autoinorgoglirono": "autoinorgoglire",
    "autoinorgoglirà": "autoinorgoglire",
    "autoinorgoglirò": "autoinorgoglire",
    "autoinorgoglisse": "autoinorgoglire",
    "autoinorgoglisser": "autoinorgoglire",
    "autoinorgoglissero": "autoinorgoglire",
    "autoinorgoglissi": "autoinorgoglire",
    "autoinorgoglissimo": "autoinorgoglire",
    "autoinorgogliste": "autoinorgoglire",
    "autoinorgoglisti": "autoinorgoglire",
    "autoinorgoglita": "autoinorgoglire",
    "autoinorgoglite": "autoinorgoglire",
    "autoinorgogliti": "autoinorgoglire",
    "autoinorgoglito": "autoinorgoglire",
    "autoinorgogliva": "autoinorgoglire",
    "autoinorgoglivamo": "autoinorgoglire",
    "autoinorgoglivan": "autoinorgoglire",
    "autoinorgoglivano": "autoinorgoglire",
    "autoinorgoglivate": "autoinorgoglire",
    "autoinorgoglivi": "autoinorgoglire",
    "autoinorgoglivo": "autoinorgoglire",
    "autoinorgoglo": "autoinorgoglire",
    "autoinorgoglon": "autoinorgoglire",
    "autoinorgoglono": "autoinorgoglire",
    "autoinorgoglì": "autoinorgoglire",
    "autoinstalla": "autoinstallare",
    "autoinstallai": "autoinstallare",
    "autoinstallammo": "autoinstallare",
    "autoinstallan": "autoinstallare",
    "autoinstallando": "autoinstallare",
    "autoinstallano": "autoinstallare",
    "autoinstallante": "autoinstallare",
    "autoinstallanti": "autoinstallare",
    "autoinstallar": "autoinstallare",
    "autoinstallaron": "autoinstallare",
    "autoinstallarono": "autoinstallare",
    "autoinstallasse": "autoinstallare",
    "autoinstallasser": "autoinstallare",
    "autoinstallassero": "autoinstallare",
    "autoinstallassi": "autoinstallare",
    "autoinstallassimo": "autoinstallare",
    "autoinstallaste": "autoinstallare",
    "autoinstallasti": "autoinstallare",
    "autoinstallata": "autoinstallare",
    "autoinstallate": "autoinstallare",
    "autoinstallati": "autoinstallare",
    "autoinstallato": "autoinstallare",
    "autoinstallava": "autoinstallare",
    "autoinstallavamo": "autoinstallare",
    "autoinstallavan": "autoinstallare",
    "autoinstallavano": "autoinstallare",
    "autoinstallavate": "autoinstallare",
    "autoinstallavi": "autoinstallare",
    "autoinstallavo": "autoinstallare",
    "autoinstallerai": "autoinstallare",
    "autoinstalleran": "autoinstallare",
    "autoinstalleranno": "autoinstallare",
    "autoinstallerebbe": "autoinstallare",
    "autoinstallerebber": "autoinstallare",
    "autoinstallerebbero": "autoinstallare",
    "autoinstallerei": "autoinstallare",
    "autoinstalleremmo": "autoinstallare",
    "autoinstalleremo": "autoinstallare",
    "autoinstallereste": "autoinstallare",
    "autoinstalleresti": "autoinstallare",
    "autoinstallerete": "autoinstallare",
    "autoinstallerà": "autoinstallare",
    "autoinstallerò": "autoinstallare",
    "autoinstalli": "autoinstallare",
    "autoinstalliamo": "autoinstallare",
    "autoinstalliate": "autoinstallare",
    "autoinstallin": "autoinstallare",
    "autoinstallino": "autoinstallare",
    "autoinstallo": "autoinstallare",
    "autoinstallò": "autoinstallare",
    "autointerroga": "autointerrogare",
    "autointerrogai": "autointerrogare",
    "autointerrogammo": "autointerrogare",
    "autointerrogan": "autointerrogare",
    "autointerrogando": "autointerrogare",
    "autointerrogano": "autointerrogare",
    "autointerrogante": "autointerrogare",
    "autointerroganti": "autointerrogare",
    "autointerrogar": "autointerrogare",
    "autointerrogaron": "autointerrogare",
    "autointerrogarono": "autointerrogare",
    "autointerrogasse": "autointerrogare",
    "autointerrogasser": "autointerrogare",
    "autointerrogassero": "autointerrogare",
    "autointerrogassi": "autointerrogare",
    "autointerrogassimo": "autointerrogare",
    "autointerrogaste": "autointerrogare",
    "autointerrogasti": "autointerrogare",
    "autointerrogata": "autointerrogare",
    "autointerrogate": "autointerrogare",
    "autointerrogati": "autointerrogare",
    "autointerrogato": "autointerrogare",
    "autointerrogava": "autointerrogare",
    "autointerrogavamo": "autointerrogare",
    "autointerrogavan": "autointerrogare",
    "autointerrogavano": "autointerrogare",
    "autointerrogavate": "autointerrogare",
    "autointerrogavi": "autointerrogare",
    "autointerrogavo": "autointerrogare",
    "autointerrogherai": "autointerrogare",
    "autointerrogheran": "autointerrogare",
    "autointerrogheranno": "autointerrogare",
    "autointerrogherebbe": "autointerrogare",
    "autointerrogherebber": "autointerrogare",
    "autointerrogherebbero": "autointerrogare",
    "autointerrogherei": "autointerrogare",
    "autointerrogheremmo": "autointerrogare",
    "autointerrogheremo": "autointerrogare",
    "autointerroghereste": "autointerrogare",
    "autointerrogheresti": "autointerrogare",
    "autointerrogherete": "autointerrogare",
    "autointerrogherà": "autointerrogare",
    "autointerrogherò": "autointerrogare",
    "autointerroghi": "autointerrogare",
    "autointerroghiamo": "autointerrogare",
    "autointerroghiate": "autointerrogare",
    "autointerroghin": "autointerrogare",
    "autointerroghino": "autointerrogare",
    "autointerrogo": "autointerrogare",
    "autointerrogò": "autointerrogare",
    "autoironica": "autoironico",
    "autoironiche": "autoironico",
    "autoironici": "autoironico",
    "autoironie": "autoironia",
    "autoironizza": "autoironizzare",
    "autoironizzai": "autoironizzare",
    "autoironizzammo": "autoironizzare",
    "autoironizzan": "autoironizzare",
    "autoironizzando": "autoironizzare",
    "autoironizzano": "autoironizzare",
    "autoironizzante": "autoironizzare",
    "autoironizzanti": "autoironizzare",
    "autoironizzar": "autoironizzare",
    "autoironizzaron": "autoironizzare",
    "autoironizzarono": "autoironizzare",
    "autoironizzasse": "autoironizzare",
    "autoironizzasser": "autoironizzare",
    "autoironizzassero": "autoironizzare",
    "autoironizzassi": "autoironizzare",
    "autoironizzassimo": "autoironizzare",
    "autoironizzaste": "autoironizzare",
    "autoironizzasti": "autoironizzare",
    "autoironizzata": "autoironizzare",
    "autoironizzate": "autoironizzare",
    "autoironizzati": "autoironizzare",
    "autoironizzato": "autoironizzare",
    "autoironizzava": "autoironizzare",
    "autoironizzavamo": "autoironizzare",
    "autoironizzavan": "autoironizzare",
    "autoironizzavano": "autoironizzare",
    "autoironizzavate": "autoironizzare",
    "autoironizzavi": "autoironizzare",
    "autoironizzavo": "autoironizzare",
    "autoironizzerai": "autoironizzare",
    "autoironizzeran": "autoironizzare",
    "autoironizzeranno": "autoironizzare",
    "autoironizzerebbe": "autoironizzare",
    "autoironizzerebber": "autoironizzare",
    "autoironizzerebbero": "autoironizzare",
    "autoironizzerei": "autoironizzare",
    "autoironizzeremmo": "autoironizzare",
    "autoironizzeremo": "autoironizzare",
    "autoironizzereste": "autoironizzare",
    "autoironizzeresti": "autoironizzare",
    "autoironizzerete": "autoironizzare",
    "autoironizzerà": "autoironizzare",
    "autoironizzerò": "autoironizzare",
    "autoironizzi": "autoironizzare",
    "autoironizziamo": "autoironizzare",
    "autoironizziate": "autoironizzare",
    "autoironizzin": "autoironizzare",
    "autoironizzino": "autoironizzare",
    "autoironizzo": "autoironizzare",
    "autoironizzò": "autoironizzare",
    "autoisola": "autoisolare",
    "autoisolai": "autoisolare",
    "autoisolammo": "autoisolare",
    "autoisolan": "autoisolare",
    "autoisolando": "autoisolare",
    "autoisolano": "autoisolare",
    "autoisolante": "autoisolare",
    "autoisolanti": "autoisolare",
    "autoisolar": "autoisolare",
    "autoisolaron": "autoisolare",
    "autoisolarono": "autoisolare",
    "autoisolasse": "autoisolare",
    "autoisolasser": "autoisolare",
    "autoisolassero": "autoisolare",
    "autoisolassi": "autoisolare",
    "autoisolassimo": "autoisolare",
    "autoisolaste": "autoisolare",
    "autoisolasti": "autoisolare",
    "autoisolata": "autoisolare",
    "autoisolate": "autoisolare",
    "autoisolati": "autoisolare",
    "autoisolato": "autoisolare",
    "autoisolava": "autoisolare",
    "autoisolavamo": "autoisolare",
    "autoisolavan": "autoisolare",
    "autoisolavano": "autoisolare",
    "autoisolavate": "autoisolare",
    "autoisolavi": "autoisolare",
    "autoisolavo": "autoisolare",
    "autoisolerai": "autoisolare",
    "autoisoleran": "autoisolare",
    "autoisoleranno": "autoisolare",
    "autoisolerebbe": "autoisolare",
    "autoisolerebber": "autoisolare",
    "autoisolerebbero": "autoisolare",
    "autoisolerei": "autoisolare",
    "autoisoleremmo": "autoisolare",
    "autoisoleremo": "autoisolare",
    "autoisolereste": "autoisolare",
    "autoisoleresti": "autoisolare",
    "autoisolerete": "autoisolare",
    "autoisolerà": "autoisolare",
    "autoisolerò": "autoisolare",
    "autoisoli": "autoisolare",
    "autoisoliamo": "autoisolare",
    "autoisoliate": "autoisolare",
    "autoisolin": "autoisolare",
    "autoisolino": "autoisolare",
    "autoisolo": "autoisolare",
    "autoisolò": "autoisolare",
    "autolava": "autolavare",
    "autolavai": "autolavare",
    "autolavammo": "autolavare",
    "autolavan": "autolavare",
    "autolavando": "autolavare",
    "autolavano": "autolavare",
    "autolavante": "autolavare",
    "autolavanti": "autolavare",
    "autolavar": "autolavare",
    "autolavaron": "autolavare",
    "autolavarono": "autolavare",
    "autolavasse": "autolavare",
    "autolavasser": "autolavare",
    "autolavassero": "autolavare",
    "autolavassi": "autolavare",
    "autolavassimo": "autolavare",
    "autolavaste": "autolavare",
    "autolavasti": "autolavare",
    "autolavata": "autolavare",
    "autolavate": "autolavare",
    "autolavati": "autolavare",
    "autolavato": "autolavare",
    "autolavava": "autolavare",
    "autolavavamo": "autolavare",
    "autolavavan": "autolavare",
    "autolavavano": "autolavare",
    "autolavavate": "autolavare",
    "autolavavi": "autolavare",
    "autolavavo": "autolavare",
    "autolaverai": "autolavare",
    "autolaveran": "autolavare",
    "autolaveranno": "autolavare",
    "autolaverebbe": "autolavare",
    "autolaverebber": "autolavare",
    "autolaverebbero": "autolavare",
    "autolaverei": "autolavare",
    "autolaveremmo": "autolavare",
    "autolaveremo": "autolavare",
    "autolavereste": "autolavare",
    "autolaveresti": "autolavare",
    "autolaverete": "autolavare",
    "autolaverà": "autolavare",
    "autolaverò": "autolavare",
    "autolavi": "autolavare",
    "autolaviamo": "autolavare",
    "autolaviate": "autolavare",
    "autolavin": "autolavare",
    "autolavino": "autolavare",
    "autolavo": "autolavare",
    "autolavò": "autolavare",
    "autolegittimanti": "autolegittimante",
    "autolesiona": "autolesionare",
    "autolesionai": "autolesionare",
    "autolesionammo": "autolesionare",
    "autolesionan": "autolesionare",
    "autolesionando": "autolesionare",
    "autolesionano": "autolesionare",
    "autolesionante": "autolesionare",
    "autolesionanti": "autolesionare",
    "autolesionar": "autolesionare",
    "autolesionaron": "autolesionare",
    "autolesionarono": "autolesionare",
    "autolesionasse": "autolesionare",
    "autolesionasser": "autolesionare",
    "autolesionassero": "autolesionare",
    "autolesionassi": "autolesionare",
    "autolesionassimo": "autolesionare",
    "autolesionaste": "autolesionare",
    "autolesionasti": "autolesionare",
    "autolesionata": "autolesionare",
    "autolesionate": "autolesionare",
    "autolesionati": "autolesionare",
    "autolesionato": "autolesionare",
    "autolesionava": "autolesionare",
    "autolesionavamo": "autolesionare",
    "autolesionavan": "autolesionare",
    "autolesionavano": "autolesionare",
    "autolesionavate": "autolesionare",
    "autolesionavi": "autolesionare",
    "autolesionavo": "autolesionare",
    "autolesionerai": "autolesionare",
    "autolesioneran": "autolesionare",
    "autolesioneranno": "autolesionare",
    "autolesionerebbe": "autolesionare",
    "autolesionerebber": "autolesionare",
    "autolesionerebbero": "autolesionare",
    "autolesionerei": "autolesionare",
    "autolesioneremmo": "autolesionare",
    "autolesioneremo": "autolesionare",
    "autolesionereste": "autolesionare",
    "autolesioneresti": "autolesionare",
    "autolesionerete": "autolesionare",
    "autolesionerà": "autolesionare",
    "autolesionerò": "autolesionare",
    "autolesioni": "autolesionare",
    "autolesioniamo": "autolesionare",
    "autolesioniate": "autolesionare",
    "autolesionin": "autolesionare",
    "autolesionino": "autolesionare",
    "autolesioniste": "autolesionista",
    "autolesionisti": "autolesionista",
    "autolesiono": "autolesionare",
    "autolesionò": "autolesionare",
    "autolimita": "autolimitare",
    "autolimitai": "autolimitare",
    "autolimitammo": "autolimitare",
    "autolimitan": "autolimitare",
    "autolimitando": "autolimitare",
    "autolimitano": "autolimitare",
    "autolimitante": "autolimitare",
    "autolimitanti": "autolimitare",
    "autolimitar": "autolimitare",
    "autolimitaron": "autolimitare",
    "autolimitarono": "autolimitare",
    "autolimitasse": "autolimitare",
    "autolimitasser": "autolimitare",
    "autolimitassero": "autolimitare",
    "autolimitassi": "autolimitare",
    "autolimitassimo": "autolimitare",
    "autolimitaste": "autolimitare",
    "autolimitasti": "autolimitare",
    "autolimitata": "autolimitare",
    "autolimitate": "autolimitare",
    "autolimitati": "autolimitare",
    "autolimitato": "autolimitare",
    "autolimitava": "autolimitare",
    "autolimitavamo": "autolimitare",
    "autolimitavan": "autolimitare",
    "autolimitavano": "autolimitare",
    "autolimitavate": "autolimitare",
    "autolimitavi": "autolimitare",
    "autolimitavo": "autolimitare",
    "autolimitazioni": "autolimitazione",
    "autolimiterai": "autolimitare",
    "autolimiteran": "autolimitare",
    "autolimiteranno": "autolimitare",
    "autolimiterebbe": "autolimitare",
    "autolimiterebber": "autolimitare",
    "autolimiterebbero": "autolimitare",
    "autolimiterei": "autolimitare",
    "autolimiteremmo": "autolimitare",
    "autolimiteremo": "autolimitare",
    "autolimitereste": "autolimitare",
    "autolimiteresti": "autolimitare",
    "autolimiterete": "autolimitare",
    "autolimiterà": "autolimitare",
    "autolimiterò": "autolimitare",
    "autolimiti": "autolimitare",
    "autolimitiamo": "autolimitare",
    "autolimitiate": "autolimitare",
    "autolimitin": "autolimitare",
    "autolimitino": "autolimitare",
    "autolimito": "autolimitare",
    "autolimitò": "autolimitare",
    "autoliquida": "autoliquidare",
    "autoliquidai": "autoliquidare",
    "autoliquidammo": "autoliquidare",
    "autoliquidan": "autoliquidare",
    "autoliquidando": "autoliquidare",
    "autoliquidano": "autoliquidare",
    "autoliquidante": "autoliquidare",
    "autoliquidanti": "autoliquidare",
    "autoliquidar": "autoliquidare",
    "autoliquidaron": "autoliquidare",
    "autoliquidarono": "autoliquidare",
    "autoliquidasse": "autoliquidare",
    "autoliquidasser": "autoliquidare",
    "autoliquidassero": "autoliquidare",
    "autoliquidassi": "autoliquidare",
    "autoliquidassimo": "autoliquidare",
    "autoliquidaste": "autoliquidare",
    "autoliquidasti": "autoliquidare",
    "autoliquidata": "autoliquidare",
    "autoliquidate": "autoliquidare",
    "autoliquidati": "autoliquidare",
    "autoliquidato": "autoliquidare",
    "autoliquidava": "autoliquidare",
    "autoliquidavamo": "autoliquidare",
    "autoliquidavan": "autoliquidare",
    "autoliquidavano": "autoliquidare",
    "autoliquidavate": "autoliquidare",
    "autoliquidavi": "autoliquidare",
    "autoliquidavo": "autoliquidare",
    "autoliquiderai": "autoliquidare",
    "autoliquideran": "autoliquidare",
    "autoliquideranno": "autoliquidare",
    "autoliquiderebbe": "autoliquidare",
    "autoliquiderebber": "autoliquidare",
    "autoliquiderebbero": "autoliquidare",
    "autoliquiderei": "autoliquidare",
    "autoliquideremmo": "autoliquidare",
    "autoliquideremo": "autoliquidare",
    "autoliquidereste": "autoliquidare",
    "autoliquideresti": "autoliquidare",
    "autoliquiderete": "autoliquidare",
    "autoliquiderà": "autoliquidare",
    "autoliquiderò": "autoliquidare",
    "autoliquidi": "autoliquidare",
    "autoliquidiamo": "autoliquidare",
    "autoliquidiate": "autoliquidare",
    "autoliquidin": "autoliquidare",
    "autoliquidino": "autoliquidare",
    "autoliquido": "autoliquidare",
    "autoliquidò": "autoliquidare",
    "autolivellanti": "autolivellante",
    "autologica": "autologico",
    "autologiche": "autologico",
    "autologici": "autologico",
    "automatica": "automatico",
    "automatiche": "automatico",
    "automatici": "automatico",
    "automatismi": "automatismo",
    "automatizza": "automatizzare",
    "automatizzai": "automatizzare",
    "automatizzammo": "automatizzare",
    "automatizzan": "automatizzare",
    "automatizzando": "automatizzare",
    "automatizzano": "automatizzare",
    "automatizzante": "automatizzare",
    "automatizzanti": "automatizzare",
    "automatizzar": "automatizzare",
    "automatizzaron": "automatizzare",
    "automatizzarono": "automatizzare",
    "automatizzasse": "automatizzare",
    "automatizzasser": "automatizzare",
    "automatizzassero": "automatizzare",
    "automatizzassi": "automatizzare",
    "automatizzassimo": "automatizzare",
    "automatizzaste": "automatizzare",
    "automatizzasti": "automatizzare",
    "automatizzata": "automatizzare",
    "automatizzate": "automatizzare",
    "automatizzati": "automatizzare",
    "automatizzato": "automatizzare",
    "automatizzava": "automatizzare",
    "automatizzavamo": "automatizzare",
    "automatizzavan": "automatizzare",
    "automatizzavano": "automatizzare",
    "automatizzavate": "automatizzare",
    "automatizzavi": "automatizzare",
    "automatizzavo": "automatizzare",
    "automatizzerai": "automatizzare",
    "automatizzeran": "automatizzare",
    "automatizzeranno": "automatizzare",
    "automatizzerebbe": "automatizzare",
    "automatizzerebber": "automatizzare",
    "automatizzerebbero": "automatizzare",
    "automatizzerei": "automatizzare",
    "automatizzeremmo": "automatizzare",
    "automatizzeremo": "automatizzare",
    "automatizzereste": "automatizzare",
    "automatizzeresti": "automatizzare",
    "automatizzerete": "automatizzare",
    "automatizzerà": "automatizzare",
    "automatizzerò": "automatizzare",
    "automatizzi": "automatizzare",
    "automatizziamo": "automatizzare",
    "automatizziate": "automatizzare",
    "automatizzin": "automatizzare",
    "automatizzino": "automatizzare",
    "automatizzo": "automatizzare",
    "automatizzò": "automatizzare",
    "automazioni": "automazione",
    "autombulanze": "autombulanza",
    "automezzi": "automezzo",
    "automi": "automa",
    "automobili": "automobile",
    "automobiline": "automobilina",
    "automobilismi": "automobilismo",
    "automobiliste": "automobilista",
    "automobilisti": "automobilista",
    "automobilistica": "automobilistico",
    "automobilistiche": "automobilistico",
    "automobilistici": "automobilistico",
    "automunita": "automunito",
    "automunite": "automunito",
    "automuniti": "automunito",
    "autonoleggi": "autonoleggio",
    "autonoma": "autonomo",
    "autonome": "autonomo",
    "autonomi": "autonomo",
    "autonomie": "autonomia",
    "autonomina": "autonominare",
    "autonominai": "autonominare",
    "autonominammo": "autonominare",
    "autonominan": "autonominare",
    "autonominando": "autonominare",
    "autonominano": "autonominare",
    "autonominante": "autonominare",
    "autonominanti": "autonominare",
    "autonominar": "autonominare",
    "autonominaron": "autonominare",
    "autonominarono": "autonominare",
    "autonominasse": "autonominare",
    "autonominasser": "autonominare",
    "autonominassero": "autonominare",
    "autonominassi": "autonominare",
    "autonominassimo": "autonominare",
    "autonominaste": "autonominare",
    "autonominasti": "autonominare",
    "autonominata": "autonominare",
    "autonominate": "autonominare",
    "autonominati": "autonominare",
    "autonominato": "autonominare",
    "autonominava": "autonominare",
    "autonominavamo": "autonominare",
    "autonominavan": "autonominare",
    "autonominavano": "autonominare",
    "autonominavate": "autonominare",
    "autonominavi": "autonominare",
    "autonominavo": "autonominare",
    "autonominerai": "autonominare",
    "autonomineran": "autonominare",
    "autonomineranno": "autonominare",
    "autonominerebbe": "autonominare",
    "autonominerebber": "autonominare",
    "autonominerebbero": "autonominare",
    "autonominerei": "autonominare",
    "autonomineremmo": "autonominare",
    "autonomineremo": "autonominare",
    "autonominereste": "autonominare",
    "autonomineresti": "autonominare",
    "autonominerete": "autonominare",
    "autonominerà": "autonominare",
    "autonominerò": "autonominare",
    "autonomini": "autonominare",
    "autonominiamo": "autonominare",
    "autonominiate": "autonominare",
    "autonominin": "autonominare",
    "autonominino": "autonominare",
    "autonomino": "autonominare",
    "autonominò": "autonominare",
    "autonomismi": "autonomismo",
    "autonomiste": "autonomista",
    "autonomisti": "autonomista",
    "autonomistica": "autonomistico",
    "autonomistiche": "autonomistico",
    "autonomistici": "autonomistico",
    "autonomizza": "autonomizzare",
    "autonomizzai": "autonomizzare",
    "autonomizzammo": "autonomizzare",
    "autonomizzan": "autonomizzare",
    "autonomizzando": "autonomizzare",
    "autonomizzano": "autonomizzare",
    "autonomizzante": "autonomizzare",
    "autonomizzanti": "autonomizzare",
    "autonomizzar": "autonomizzare",
    "autonomizzaron": "autonomizzare",
    "autonomizzarono": "autonomizzare",
    "autonomizzasse": "autonomizzare",
    "autonomizzasser": "autonomizzare",
    "autonomizzassero": "autonomizzare",
    "autonomizzassi": "autonomizzare",
    "autonomizzassimo": "autonomizzare",
    "autonomizzaste": "autonomizzare",
    "autonomizzasti": "autonomizzare",
    "autonomizzata": "autonomizzare",
    "autonomizzate": "autonomizzare",
    "autonomizzati": "autonomizzare",
    "autonomizzato": "autonomizzare",
    "autonomizzava": "autonomizzare",
    "autonomizzavamo": "autonomizzare",
    "autonomizzavan": "autonomizzare",
    "autonomizzavano": "autonomizzare",
    "autonomizzavate": "autonomizzare",
    "autonomizzavi": "autonomizzare",
    "autonomizzavo": "autonomizzare",
    "autonomizzerai": "autonomizzare",
    "autonomizzeran": "autonomizzare",
    "autonomizzeranno": "autonomizzare",
    "autonomizzerebbe": "autonomizzare",
    "autonomizzerebber": "autonomizzare",
    "autonomizzerebbero": "autonomizzare",
    "autonomizzerei": "autonomizzare",
    "autonomizzeremmo": "autonomizzare",
    "autonomizzeremo": "autonomizzare",
    "autonomizzereste": "autonomizzare",
    "autonomizzeresti": "autonomizzare",
    "autonomizzerete": "autonomizzare",
    "autonomizzerà": "autonomizzare",
    "autonomizzerò": "autonomizzare",
    "autonomizzi": "autonomizzare",
    "autonomizziamo": "autonomizzare",
    "autonomizziate": "autonomizzare",
    "autonomizzin": "autonomizzare",
    "autonomizzino": "autonomizzare",
    "autonomizzo": "autonomizzare",
    "autonomizzò": "autonomizzare",
    "autoparchi": "autoparco",
    "autopattuglie": "autopattuglia",
    "autopompe": "autopompa",
    "autoproclama": "autoproclamare",
    "autoproclamai": "autoproclamare",
    "autoproclamammo": "autoproclamare",
    "autoproclaman": "autoproclamare",
    "autoproclamando": "autoproclamare",
    "autoproclamano": "autoproclamare",
    "autoproclamante": "autoproclamare",
    "autoproclamanti": "autoproclamare",
    "autoproclamar": "autoproclamare",
    "autoproclamaron": "autoproclamare",
    "autoproclamarono": "autoproclamare",
    "autoproclamasse": "autoproclamare",
    "autoproclamasser": "autoproclamare",
    "autoproclamassero": "autoproclamare",
    "autoproclamassi": "autoproclamare",
    "autoproclamassimo": "autoproclamare",
    "autoproclamaste": "autoproclamare",
    "autoproclamasti": "autoproclamare",
    "autoproclamata": "autoproclamare",
    "autoproclamate": "autoproclamare",
    "autoproclamati": "autoproclamare",
    "autoproclamato": "autoproclamare",
    "autoproclamava": "autoproclamare",
    "autoproclamavamo": "autoproclamare",
    "autoproclamavan": "autoproclamare",
    "autoproclamavano": "autoproclamare",
    "autoproclamavate": "autoproclamare",
    "autoproclamavi": "autoproclamare",
    "autoproclamavo": "autoproclamare",
    "autoproclamerai": "autoproclamare",
    "autoproclameran": "autoproclamare",
    "autoproclameranno": "autoproclamare",
    "autoproclamerebbe": "autoproclamare",
    "autoproclamerebber": "autoproclamare",
    "autoproclamerebbero": "autoproclamare",
    "autoproclamerei": "autoproclamare",
    "autoproclameremmo": "autoproclamare",
    "autoproclameremo": "autoproclamare",
    "autoproclamereste": "autoproclamare",
    "autoproclameresti": "autoproclamare",
    "autoproclamerete": "autoproclamare",
    "autoproclamerà": "autoproclamare",
    "autoproclamerò": "autoproclamare",
    "autoproclami": "autoproclamare",
    "autoproclamiamo": "autoproclamare",
    "autoproclamiate": "autoproclamare",
    "autoproclamin": "autoproclamare",
    "autoproclamino": "autoproclamare",
    "autoproclamo": "autoproclamare",
    "autoproclamò": "autoproclamare",
    "autoproduca": "autoprodurre",
    "autoproducan": "autoprodurre",
    "autoproducano": "autoprodurre",
    "autoproduce": "autoprodurre",
    "autoproducei": "autoprodurre",
    "autoproducemmo": "autoprodurre",
    "autoproducendo": "autoprodurre",
    "autoproducente": "autoprodurre",
    "autoproducenti": "autoprodurre",
    "autoproducerai": "autoprodurre",
    "autoproduceran": "autoprodurre",
    "autoproduceranno": "autoprodurre",
    "autoproducerebbe": "autoprodurre",
    "autoproducerebber": "autoprodurre",
    "autoproducerebbero": "autoprodurre",
    "autoproducerei": "autoprodurre",
    "autoproduceremmo": "autoprodurre",
    "autoproduceremo": "autoprodurre",
    "autoproducereste": "autoprodurre",
    "autoproduceresti": "autoprodurre",
    "autoproducerete": "autoprodurre",
    "autoproduceron": "autoprodurre",
    "autoproducerono": "autoprodurre",
    "autoproducerà": "autoprodurre",
    "autoproducerò": "autoprodurre",
    "autoproducesse": "autoprodurre",
    "autoproducesser": "autoprodurre",
    "autoproducessero": "autoprodurre",
    "autoproducessi": "autoprodurre",
    "autoproducessimo": "autoprodurre",
    "autoproduceste": "autoprodurre",
    "autoproducesti": "autoprodurre",
    "autoproducete": "autoprodurre",
    "autoproduceva": "autoprodurre",
    "autoproducevamo": "autoprodurre",
    "autoproducevan": "autoprodurre",
    "autoproducevano": "autoprodurre",
    "autoproducevate": "autoprodurre",
    "autoproducevi": "autoprodurre",
    "autoproducevo": "autoprodurre",
    "autoproduci": "autoprodurre",
    "autoproduciamo": "autoprodurre",
    "autoproduciate": "autoprodurre",
    "autoproduciuta": "autoprodurre",
    "autoproduciute": "autoprodurre",
    "autoproduciuti": "autoprodurre",
    "autoproduciuto": "autoprodurre",
    "autoproduco": "autoprodurre",
    "autoproducon": "autoprodurre",
    "autoproducono": "autoprodurre",
    "autoproducè": "autoprodurre",
    "autoprodurr": "autoprodurre",
    "autoproduttori": "autoproduttore",
    "autopromozionali": "autopromozionale",
    "autopromuova": "autopromuovere",
    "autopromuovan": "autopromuovere",
    "autopromuovano": "autopromuovere",
    "autopromuove": "autopromuovere",
    "autopromuovei": "autopromuovere",
    "autopromuovemmo": "autopromuovere",
    "autopromuovendo": "autopromuovere",
    "autopromuovente": "autopromuovere",
    "autopromuoventi": "autopromuovere",
    "autopromuover": "autopromuovere",
    "autopromuoverai": "autopromuovere",
    "autopromuoveran": "autopromuovere",
    "autopromuoveranno": "autopromuovere",
    "autopromuoverebbe": "autopromuovere",
    "autopromuoverebber": "autopromuovere",
    "autopromuoverebbero": "autopromuovere",
    "autopromuoverei": "autopromuovere",
    "autopromuoveremmo": "autopromuovere",
    "autopromuoveremo": "autopromuovere",
    "autopromuovereste": "autopromuovere",
    "autopromuoveresti": "autopromuovere",
    "autopromuoverete": "autopromuovere",
    "autopromuoveron": "autopromuovere",
    "autopromuoverono": "autopromuovere",
    "autopromuoverà": "autopromuovere",
    "autopromuoverò": "autopromuovere",
    "autopromuovesse": "autopromuovere",
    "autopromuovesser": "autopromuovere",
    "autopromuovessero": "autopromuovere",
    "autopromuovessi": "autopromuovere",
    "autopromuovessimo": "autopromuovere",
    "autopromuoveste": "autopromuovere",
    "autopromuovesti": "autopromuovere",
    "autopromuovete": "autopromuovere",
    "autopromuoveva": "autopromuovere",
    "autopromuovevamo": "autopromuovere",
    "autopromuovevan": "autopromuovere",
    "autopromuovevano": "autopromuovere",
    "autopromuovevate": "autopromuovere",
    "autopromuovevi": "autopromuovere",
    "autopromuovevo": "autopromuovere",
    "autopromuovi": "autopromuovere",
    "autopromuoviamo": "autopromuovere",
    "autopromuoviate": "autopromuovere",
    "autopromuovo": "autopromuovere",
    "autopromuovon": "autopromuovere",
    "autopromuovono": "autopromuovere",
    "autopromuovuta": "autopromuovere",
    "autopromuovute": "autopromuovere",
    "autopromuovuti": "autopromuovere",
    "autopromuovuto": "autopromuovere",
    "autopromuovè": "autopromuovere",
    "autopropone": "autoproporre",
    "autoproponei": "autoproporre",
    "autoproponemmo": "autoproporre",
    "autoproponendo": "autoproporre",
    "autoproponente": "autoproporre",
    "autoproponenti": "autoproporre",
    "autoproponerai": "autoproporre",
    "autoproponeran": "autoproporre",
    "autoproponeranno": "autoproporre",
    "autoproponerebbe": "autoproporre",
    "autoproponerebber": "autoproporre",
    "autoproponerebbero": "autoproporre",
    "autoproponerei": "autoproporre",
    "autoproponeremmo": "autoproporre",
    "autoproponeremo": "autoproporre",
    "autoproponereste": "autoproporre",
    "autoproponeresti": "autoproporre",
    "autoproponerete": "autoproporre",
    "autoproponeron": "autoproporre",
    "autoproponerono": "autoproporre",
    "autoproponerà": "autoproporre",
    "autoproponerò": "autoproporre",
    "autoproponesse": "autoproporre",
    "autoproponesser": "autoproporre",
    "autoproponessero": "autoproporre",
    "autoproponessi": "autoproporre",
    "autoproponessimo": "autoproporre",
    "autoproponeste": "autoproporre",
    "autoproponesti": "autoproporre",
    "autoproponete": "autoproporre",
    "autoproponeva": "autoproporre",
    "autoproponevamo": "autoproporre",
    "autoproponevan": "autoproporre",
    "autoproponevano": "autoproporre",
    "autoproponevate": "autoproporre",
    "autoproponevi": "autoproporre",
    "autoproponevo": "autoproporre",
    "autoproponga": "autoproporre",
    "autopropongan": "autoproporre",
    "autopropongano": "autoproporre",
    "autopropongo": "autoproporre",
    "autopropongon": "autoproporre",
    "autopropongono": "autoproporre",
    "autoproponi": "autoproporre",
    "autoproponiamo": "autoproporre",
    "autoproponiate": "autoproporre",
    "autoproponuta": "autoproporre",
    "autoproponute": "autoproporre",
    "autoproponuti": "autoproporre",
    "autoproponuto": "autoproporre",
    "autoproponè": "autoproporre",
    "autoproporr": "autoproporre",
    "autopropulsiva": "autopropulsivo",
    "autopropulsive": "autopropulsivo",
    "autopropulsivi": "autopropulsivo",
    "autopsie": "autopsia",
    "autopula": "autopulire",
    "autopulan": "autopulire",
    "autopulano": "autopulire",
    "autopule": "autopulire",
    "autopulendo": "autopulire",
    "autopulente": "autopulire",
    "autopulenti": "autopulire",
    "autopuli": "autopulire",
    "autopuliamo": "autopulire",
    "autopuliate": "autopulire",
    "autopulii": "autopulire",
    "autopulimmo": "autopulire",
    "autopulir": "autopulire",
    "autopulirai": "autopulire",
    "autopuliran": "autopulire",
    "autopuliranno": "autopulire",
    "autopulirebbe": "autopulire",
    "autopulirebber": "autopulire",
    "autopulirebbero": "autopulire",
    "autopulirei": "autopulire",
    "autopuliremmo": "autopulire",
    "autopuliremo": "autopulire",
    "autopulireste": "autopulire",
    "autopuliresti": "autopulire",
    "autopulirete": "autopulire",
    "autopuliron": "autopulire",
    "autopulirono": "autopulire",
    "autopulirà": "autopulire",
    "autopulirò": "autopulire",
    "autopulisse": "autopulire",
    "autopulisser": "autopulire",
    "autopulissero": "autopulire",
    "autopulissi": "autopulire",
    "autopulissimo": "autopulire",
    "autopuliste": "autopulire",
    "autopulisti": "autopulire",
    "autopulita": "autopulire",
    "autopulite": "autopulire",
    "autopuliti": "autopulire",
    "autopulito": "autopulire",
    "autopuliva": "autopulire",
    "autopulivamo": "autopulire",
    "autopulivan": "autopulire",
    "autopulivano": "autopulire",
    "autopulivate": "autopulire",
    "autopulivi": "autopulire",
    "autopulivo": "autopulire",
    "autopulo": "autopulire",
    "autopulon": "autopulire",
    "autopulono": "autopulire",
    "autopulì": "autopulire",
    "autopurificanti": "autopurificante",
    "autoqualifica": "autoqualificare",
    "autoqualificai": "autoqualificare",
    "autoqualificammo": "autoqualificare",
    "autoqualifican": "autoqualificare",
    "autoqualificando": "autoqualificare",
    "autoqualificano": "autoqualificare",
    "autoqualificante": "autoqualificare",
    "autoqualificanti": "autoqualificare",
    "autoqualificar": "autoqualificare",
    "autoqualificaron": "autoqualificare",
    "autoqualificarono": "autoqualificare",
    "autoqualificasse": "autoqualificare",
    "autoqualificasser": "autoqualificare",
    "autoqualificassero": "autoqualificare",
    "autoqualificassi": "autoqualificare",
    "autoqualificassimo": "autoqualificare",
    "autoqualificaste": "autoqualificare",
    "autoqualificasti": "autoqualificare",
    "autoqualificata": "autoqualificare",
    "autoqualificate": "autoqualificare",
    "autoqualificati": "autoqualificare",
    "autoqualificato": "autoqualificare",
    "autoqualificava": "autoqualificare",
    "autoqualificavamo": "autoqualificare",
    "autoqualificavan": "autoqualificare",
    "autoqualificavano": "autoqualificare",
    "autoqualificavate": "autoqualificare",
    "autoqualificavi": "autoqualificare",
    "autoqualificavo": "autoqualificare",
    "autoqualificherai": "autoqualificare",
    "autoqualificheran": "autoqualificare",
    "autoqualificheranno": "autoqualificare",
    "autoqualificherebbe": "autoqualificare",
    "autoqualificherebber": "autoqualificare",
    "autoqualificherebbero": "autoqualificare",
    "autoqualificherei": "autoqualificare",
    "autoqualificheremmo": "autoqualificare",
    "autoqualificheremo": "autoqualificare",
    "autoqualifichereste": "autoqualificare",
    "autoqualificheresti": "autoqualificare",
    "autoqualificherete": "autoqualificare",
    "autoqualificherà": "autoqualificare",
    "autoqualificherò": "autoqualificare",
    "autoqualifichi": "autoqualificare",
    "autoqualifichiamo": "autoqualificare",
    "autoqualifichiate": "autoqualificare",
    "autoqualifichin": "autoqualificare",
    "autoqualifichino": "autoqualificare",
    "autoqualifico": "autoqualificare",
    "autoqualificò": "autoqualificare",
    "autoracconta": "autoraccontare",
    "autoraccontai": "autoraccontare",
    "autoraccontammo": "autoraccontare",
    "autoraccontan": "autoraccontare",
    "autoraccontando": "autoraccontare",
    "autoraccontano": "autoraccontare",
    "autoraccontante": "autoraccontare",
    "autoraccontanti": "autoraccontare",
    "autoraccontar": "autoraccontare",
    "autoraccontaron": "autoraccontare",
    "autoraccontarono": "autoraccontare",
    "autoraccontasse": "autoraccontare",
    "autoraccontasser": "autoraccontare",
    "autoraccontassero": "autoraccontare",
    "autoraccontassi": "autoraccontare",
    "autoraccontassimo": "autoraccontare",
    "autoraccontaste": "autoraccontare",
    "autoraccontasti": "autoraccontare",
    "autoraccontata": "autoraccontare",
    "autoraccontate": "autoraccontare",
    "autoraccontati": "autoraccontare",
    "autoraccontato": "autoraccontare",
    "autoraccontava": "autoraccontare",
    "autoraccontavamo": "autoraccontare",
    "autoraccontavan": "autoraccontare",
    "autoraccontavano": "autoraccontare",
    "autoraccontavate": "autoraccontare",
    "autoraccontavi": "autoraccontare",
    "autoraccontavo": "autoraccontare",
    "autoracconterai": "autoraccontare",
    "autoracconteran": "autoraccontare",
    "autoracconteranno": "autoraccontare",
    "autoracconterebbe": "autoraccontare",
    "autoracconterebber": "autoraccontare",
    "autoracconterebbero": "autoraccontare",
    "autoracconterei": "autoraccontare",
    "autoracconteremmo": "autoraccontare",
    "autoracconteremo": "autoraccontare",
    "autoraccontereste": "autoraccontare",
    "autoracconteresti": "autoraccontare",
    "autoracconterete": "autoraccontare",
    "autoracconterà": "autoraccontare",
    "autoracconterò": "autoraccontare",
    "autoracconti": "autoraccontare",
    "autoraccontiamo": "autoraccontare",
    "autoraccontiate": "autoraccontare",
    "autoraccontin": "autoraccontare",
    "autoraccontino": "autoraccontare",
    "autoracconto": "autoraccontare",
    "autoraccontò": "autoraccontare",
    "autoraffigura": "autoraffigurare",
    "autoraffigurai": "autoraffigurare",
    "autoraffigurammo": "autoraffigurare",
    "autoraffiguran": "autoraffigurare",
    "autoraffigurando": "autoraffigurare",
    "autoraffigurano": "autoraffigurare",
    "autoraffigurante": "autoraffigurare",
    "autoraffiguranti": "autoraffigurare",
    "autoraffigurar": "autoraffigurare",
    "autoraffiguraron": "autoraffigurare",
    "autoraffigurarono": "autoraffigurare",
    "autoraffigurasse": "autoraffigurare",
    "autoraffigurasser": "autoraffigurare",
    "autoraffigurassero": "autoraffigurare",
    "autoraffigurassi": "autoraffigurare",
    "autoraffigurassimo": "autoraffigurare",
    "autoraffiguraste": "autoraffigurare",
    "autoraffigurasti": "autoraffigurare",
    "autoraffigurata": "autoraffigurare",
    "autoraffigurate": "autoraffigurare",
    "autoraffigurati": "autoraffigurare",
    "autoraffigurato": "autoraffigurare",
    "autoraffigurava": "autoraffigurare",
    "autoraffiguravamo": "autoraffigurare",
    "autoraffiguravan": "autoraffigurare",
    "autoraffiguravano": "autoraffigurare",
    "autoraffiguravate": "autoraffigurare",
    "autoraffiguravi": "autoraffigurare",
    "autoraffiguravo": "autoraffigurare",
    "autoraffigurerai": "autoraffigurare",
    "autoraffigureran": "autoraffigurare",
    "autoraffigureranno": "autoraffigurare",
    "autoraffigurerebbe": "autoraffigurare",
    "autoraffigurerebber": "autoraffigurare",
    "autoraffigurerebbero": "autoraffigurare",
    "autoraffigurerei": "autoraffigurare",
    "autoraffigureremmo": "autoraffigurare",
    "autoraffigureremo": "autoraffigurare",
    "autoraffigurereste": "autoraffigurare",
    "autoraffigureresti": "autoraffigurare",
    "autoraffigurerete": "autoraffigurare",
    "autoraffigurerà": "autoraffigurare",
    "autoraffigurerò": "autoraffigurare",
    "autoraffiguri": "autoraffigurare",
    "autoraffiguriamo": "autoraffigurare",
    "autoraffiguriate": "autoraffigurare",
    "autoraffigurin": "autoraffigurare",
    "autoraffigurino": "autoraffigurare",
    "autoraffiguro": "autoraffigurare",
    "autoraffigurò": "autoraffigurare",
    "autorappresenta": "autorappresentare",
    "autorappresentai": "autorappresentare",
    "autorappresentammo": "autorappresentare",
    "autorappresentan": "autorappresentare",
    "autorappresentando": "autorappresentare",
    "autorappresentano": "autorappresentare",
    "autorappresentante": "autorappresentare",
    "autorappresentanti": "autorappresentare",
    "autorappresentar": "autorappresentare",
    "autorappresentaron": "autorappresentare",
    "autorappresentarono": "autorappresentare",
    "autorappresentasse": "autorappresentare",
    "autorappresentasser": "autorappresentare",
    "autorappresentassero": "autorappresentare",
    "autorappresentassi": "autorappresentare",
    "autorappresentassimo": "autorappresentare",
    "autorappresentaste": "autorappresentare",
    "autorappresentasti": "autorappresentare",
    "autorappresentata": "autorappresentare",
    "autorappresentate": "autorappresentare",
    "autorappresentati": "autorappresentare",
    "autorappresentato": "autorappresentare",
    "autorappresentava": "autorappresentare",
    "autorappresentavamo": "autorappresentare",
    "autorappresentavan": "autorappresentare",
    "autorappresentavano": "autorappresentare",
    "autorappresentavate": "autorappresentare",
    "autorappresentavi": "autorappresentare",
    "autorappresentavo": "autorappresentare",
    "autorappresenterai": "autorappresentare",
    "autorappresenteran": "autorappresentare",
    "autorappresenteranno": "autorappresentare",
    "autorappresenterebbe": "autorappresentare",
    "autorappresenterebber": "autorappresentare",
    "autorappresenterebbero": "autorappresentare",
    "autorappresenterei": "autorappresentare",
    "autorappresenteremmo": "autorappresentare",
    "autorappresenteremo": "autorappresentare",
    "autorappresentereste": "autorappresentare",
    "autorappresenteresti": "autorappresentare",
    "autorappresenterete": "autorappresentare",
    "autorappresenterà": "autorappresentare",
    "autorappresenterò": "autorappresentare",
    "autorappresenti": "autorappresentare",
    "autorappresentiamo": "autorappresentare",
    "autorappresentiate": "autorappresentare",
    "autorappresentin": "autorappresentare",
    "autorappresentino": "autorappresentare",
    "autorappresento": "autorappresentare",
    "autorappresentò": "autorappresentare",
    "autoredima": "autoredimere",
    "autorediman": "autoredimere",
    "autoredimano": "autoredimere",
    "autoredime": "autoredimere",
    "autoredimei": "autoredimere",
    "autoredimemmo": "autoredimere",
    "autoredimendo": "autoredimere",
    "autoredimente": "autoredimere",
    "autoredimenti": "autoredimere",
    "autoredimer": "autoredimere",
    "autoredimerai": "autoredimere",
    "autoredimeran": "autoredimere",
    "autoredimeranno": "autoredimere",
    "autoredimerebbe": "autoredimere",
    "autoredimerebber": "autoredimere",
    "autoredimerebbero": "autoredimere",
    "autoredimerei": "autoredimere",
    "autoredimeremmo": "autoredimere",
    "autoredimeremo": "autoredimere",
    "autoredimereste": "autoredimere",
    "autoredimeresti": "autoredimere",
    "autoredimerete": "autoredimere",
    "autoredimeron": "autoredimere",
    "autoredimerono": "autoredimere",
    "autoredimerà": "autoredimere",
    "autoredimerò": "autoredimere",
    "autoredimesse": "autoredimere",
    "autoredimesser": "autoredimere",
    "autoredimessero": "autoredimere",
    "autoredimessi": "autoredimere",
    "autoredimessimo": "autoredimere",
    "autoredimeste": "autoredimere",
    "autoredimesti": "autoredimere",
    "autoredimete": "autoredimere",
    "autoredimeva": "autoredimere",
    "autoredimevamo": "autoredimere",
    "autoredimevan": "autoredimere",
    "autoredimevano": "autoredimere",
    "autoredimevate": "autoredimere",
    "autoredimevi": "autoredimere",
    "autoredimevo": "autoredimere",
    "autoredimi": "autoredimere",
    "autoredimiamo": "autoredimere",
    "autoredimiate": "autoredimere",
    "autoredimo": "autoredimere",
    "autoredimon": "autoredimere",
    "autoredimono": "autoredimere",
    "autoredimuta": "autoredimere",
    "autoredimute": "autoredimere",
    "autoredimuti": "autoredimere",
    "autoredimuto": "autoredimere",
    "autoredimè": "autoredimere",
    "autoreferenziali": "autoreferenziale",
    "autoreggenti": "autoreggente",
    "autoregola": "autoregolare",
    "autoregolai": "autoregolare",
    "autoregolamenta": "autoregolamentare",
    "autoregolamentai": "autoregolamentare",
    "autoregolamentammo": "autoregolamentare",
    "autoregolamentan": "autoregolamentare",
    "autoregolamentando": "autoregolamentare",
    "autoregolamentano": "autoregolamentare",
    "autoregolamentante": "autoregolamentare",
    "autoregolamentanti": "autoregolamentare",
    "autoregolamentar": "autoregolamentare",
    "autoregolamentaron": "autoregolamentare",
    "autoregolamentarono": "autoregolamentare",
    "autoregolamentasse": "autoregolamentare",
    "autoregolamentasser": "autoregolamentare",
    "autoregolamentassero": "autoregolamentare",
    "autoregolamentassi": "autoregolamentare",
    "autoregolamentassimo": "autoregolamentare",
    "autoregolamentaste": "autoregolamentare",
    "autoregolamentasti": "autoregolamentare",
    "autoregolamentata": "autoregolamentare",
    "autoregolamentate": "autoregolamentare",
    "autoregolamentati": "autoregolamentare",
    "autoregolamentato": "autoregolamentare",
    "autoregolamentava": "autoregolamentare",
    "autoregolamentavamo": "autoregolamentare",
    "autoregolamentavan": "autoregolamentare",
    "autoregolamentavano": "autoregolamentare",
    "autoregolamentavate": "autoregolamentare",
    "autoregolamentavi": "autoregolamentare",
    "autoregolamentavo": "autoregolamentare",
    "autoregolamentazioni": "autoregolamentazione",
    "autoregolamenterai": "autoregolamentare",
    "autoregolamenteran": "autoregolamentare",
    "autoregolamenteranno": "autoregolamentare",
    "autoregolamenterebbe": "autoregolamentare",
    "autoregolamenterebber": "autoregolamentare",
    "autoregolamenterebbero": "autoregolamentare",
    "autoregolamenterei": "autoregolamentare",
    "autoregolamenteremmo": "autoregolamentare",
    "autoregolamenteremo": "autoregolamentare",
    "autoregolamentereste": "autoregolamentare",
    "autoregolamenteresti": "autoregolamentare",
    "autoregolamenterete": "autoregolamentare",
    "autoregolamenterà": "autoregolamentare",
    "autoregolamenterò": "autoregolamentare",
    "autoregolamenti": "autoregolamentare",
    "autoregolamentiamo": "autoregolamentare",
    "autoregolamentiate": "autoregolamentare",
    "autoregolamentin": "autoregolamentare",
    "autoregolamentino": "autoregolamentare",
    "autoregolamento": "autoregolamentare",
    "autoregolamentò": "autoregolamentare",
    "autoregolammo": "autoregolare",
    "autoregolan": "autoregolare",
    "autoregolando": "autoregolare",
    "autoregolano": "autoregolare",
    "autoregolante": "autoregolare",
    "autoregolanti": "autoregolare",
    "autoregolar": "autoregolare",
    "autoregolaron": "autoregolare",
    "autoregolarono": "autoregolare",
    "autoregolasse": "autoregolare",
    "autoregolasser": "autoregolare",
    "autoregolassero": "autoregolare",
    "autoregolassi": "autoregolare",
    "autoregolassimo": "autoregolare",
    "autoregolaste": "autoregolare",
    "autoregolasti": "autoregolare",
    "autoregolata": "autoregolare",
    "autoregolate": "autoregolare",
    "autoregolati": "autoregolare",
    "autoregolato": "autoregolare",
    "autoregolava": "autoregolare",
    "autoregolavamo": "autoregolare",
    "autoregolavan": "autoregolare",
    "autoregolavano": "autoregolare",
    "autoregolavate": "autoregolare",
    "autoregolavi": "autoregolare",
    "autoregolavo": "autoregolare",
    "autoregolerai": "autoregolare",
    "autoregoleran": "autoregolare",
    "autoregoleranno": "autoregolare",
    "autoregolerebbe": "autoregolare",
    "autoregolerebber": "autoregolare",
    "autoregolerebbero": "autoregolare",
    "autoregolerei": "autoregolare",
    "autoregoleremmo": "autoregolare",
    "autoregoleremo": "autoregolare",
    "autoregolereste": "autoregolare",
    "autoregoleresti": "autoregolare",
    "autoregolerete": "autoregolare",
    "autoregolerà": "autoregolare",
    "autoregolerò": "autoregolare",
    "autoregoli": "autoregolare",
    "autoregoliamo": "autoregolare",
    "autoregoliate": "autoregolare",
    "autoregolin": "autoregolare",
    "autoregolino": "autoregolare",
    "autoregolo": "autoregolare",
    "autoregolò": "autoregolare",
    "autoreplica": "autoreplicare",
    "autoreplicai": "autoreplicare",
    "autoreplicammo": "autoreplicare",
    "autoreplican": "autoreplicare",
    "autoreplicando": "autoreplicare",
    "autoreplicano": "autoreplicare",
    "autoreplicante": "autoreplicare",
    "autoreplicanti": "autoreplicare",
    "autoreplicar": "autoreplicare",
    "autoreplicaron": "autoreplicare",
    "autoreplicarono": "autoreplicare",
    "autoreplicasse": "autoreplicare",
    "autoreplicasser": "autoreplicare",
    "autoreplicassero": "autoreplicare",
    "autoreplicassi": "autoreplicare",
    "autoreplicassimo": "autoreplicare",
    "autoreplicaste": "autoreplicare",
    "autoreplicasti": "autoreplicare",
    "autoreplicata": "autoreplicare",
    "autoreplicate": "autoreplicare",
    "autoreplicati": "autoreplicare",
    "autoreplicato": "autoreplicare",
    "autoreplicava": "autoreplicare",
    "autoreplicavamo": "autoreplicare",
    "autoreplicavan": "autoreplicare",
    "autoreplicavano": "autoreplicare",
    "autoreplicavate": "autoreplicare",
    "autoreplicavi": "autoreplicare",
    "autoreplicavo": "autoreplicare",
    "autoreplicherai": "autoreplicare",
    "autoreplicheran": "autoreplicare",
    "autoreplicheranno": "autoreplicare",
    "autoreplicherebbe": "autoreplicare",
    "autoreplicherebber": "autoreplicare",
    "autoreplicherebbero": "autoreplicare",
    "autoreplicherei": "autoreplicare",
    "autoreplicheremmo": "autoreplicare",
    "autoreplicheremo": "autoreplicare",
    "autoreplichereste": "autoreplicare",
    "autoreplicheresti": "autoreplicare",
    "autoreplicherete": "autoreplicare",
    "autoreplicherà": "autoreplicare",
    "autoreplicherò": "autoreplicare",
    "autoreplichi": "autoreplicare",
    "autoreplichiamo": "autoreplicare",
    "autoreplichiate": "autoreplicare",
    "autoreplichin": "autoreplicare",
    "autoreplichino": "autoreplicare",
    "autoreplico": "autoreplicare",
    "autoreplicò": "autoreplicare",
    "autorepressa": "autorepresso",
    "autorepresse": "autorepresso",
    "autorepressi": "autorepresso",
    "autorevoli": "autorevole",
    "autori": "autore",
    "autoriduca": "autoridurre",
    "autoriducan": "autoridurre",
    "autoriducano": "autoridurre",
    "autoriduce": "autoridurre",
    "autoriducei": "autoridurre",
    "autoriducemmo": "autoridurre",
    "autoriducendo": "autoridurre",
    "autoriducente": "autoridurre",
    "autoriducenti": "autoridurre",
    "autoriducerai": "autoridurre",
    "autoriduceran": "autoridurre",
    "autoriduceranno": "autoridurre",
    "autoriducerebbe": "autoridurre",
    "autoriducerebber": "autoridurre",
    "autoriducerebbero": "autoridurre",
    "autoriducerei": "autoridurre",
    "autoriduceremmo": "autoridurre",
    "autoriduceremo": "autoridurre",
    "autoriducereste": "autoridurre",
    "autoriduceresti": "autoridurre",
    "autoriducerete": "autoridurre",
    "autoriduceron": "autoridurre",
    "autoriducerono": "autoridurre",
    "autoriducerà": "autoridurre",
    "autoriducerò": "autoridurre",
    "autoriducesse": "autoridurre",
    "autoriducesser": "autoridurre",
    "autoriducessero": "autoridurre",
    "autoriducessi": "autoridurre",
    "autoriducessimo": "autoridurre",
    "autoriduceste": "autoridurre",
    "autoriducesti": "autoridurre",
    "autoriducete": "autoridurre",
    "autoriduceva": "autoridurre",
    "autoriducevamo": "autoridurre",
    "autoriducevan": "autoridurre",
    "autoriducevano": "autoridurre",
    "autoriducevate": "autoridurre",
    "autoriducevi": "autoridurre",
    "autoriducevo": "autoridurre",
    "autoriduci": "autoridurre",
    "autoriduciamo": "autoridurre",
    "autoriduciate": "autoridurre",
    "autoriduciuta": "autoridurre",
    "autoriduciute": "autoridurre",
    "autoriduciuti": "autoridurre",
    "autoriduciuto": "autoridurre",
    "autoriduco": "autoridurre",
    "autoriducon": "autoridurre",
    "autoriducono": "autoridurre",
    "autoriducè": "autoridurre",
    "autoridurr": "autoridurre",
    "autoriforma": "autoriformare",
    "autoriformai": "autoriformare",
    "autoriformammo": "autoriformare",
    "autoriforman": "autoriformare",
    "autoriformando": "autoriformare",
    "autoriformano": "autoriformare",
    "autoriformante": "autoriformare",
    "autoriformanti": "autoriformare",
    "autoriformar": "autoriformare",
    "autoriformaron": "autoriformare",
    "autoriformarono": "autoriformare",
    "autoriformasse": "autoriformare",
    "autoriformasser": "autoriformare",
    "autoriformassero": "autoriformare",
    "autoriformassi": "autoriformare",
    "autoriformassimo": "autoriformare",
    "autoriformaste": "autoriformare",
    "autoriformasti": "autoriformare",
    "autoriformata": "autoriformare",
    "autoriformate": "autoriformare",
    "autoriformati": "autoriformare",
    "autoriformato": "autoriformare",
    "autoriformava": "autoriformare",
    "autoriformavamo": "autoriformare",
    "autoriformavan": "autoriformare",
    "autoriformavano": "autoriformare",
    "autoriformavate": "autoriformare",
    "autoriformavi": "autoriformare",
    "autoriformavo": "autoriformare",
    "autoriforme": "autoriforma",
    "autoriformerai": "autoriformare",
    "autoriformeran": "autoriformare",
    "autoriformeranno": "autoriformare",
    "autoriformerebbe": "autoriformare",
    "autoriformerebber": "autoriformare",
    "autoriformerebbero": "autoriformare",
    "autoriformerei": "autoriformare",
    "autoriformeremmo": "autoriformare",
    "autoriformeremo": "autoriformare",
    "autoriformereste": "autoriformare",
    "autoriformeresti": "autoriformare",
    "autoriformerete": "autoriformare",
    "autoriformerà": "autoriformare",
    "autoriformerò": "autoriformare",
    "autoriformi": "autoriformare",
    "autoriformiamo": "autoriformare",
    "autoriformiate": "autoriformare",
    "autoriformin": "autoriformare",
    "autoriformino": "autoriformare",
    "autoriformo": "autoriformare",
    "autoriformò": "autoriformare",
    "autorimesse": "autorimessa",
    "autoriproduca": "autoriprodurre",
    "autoriproducan": "autoriprodurre",
    "autoriproducano": "autoriprodurre",
    "autoriproduce": "autoriprodurre",
    "autoriproducei": "autoriprodurre",
    "autoriproducemmo": "autoriprodurre",
    "autoriproducendo": "autoriprodurre",
    "autoriproducente": "autoriprodurre",
    "autoriproducenti": "autoriprodurre",
    "autoriproducerai": "autoriprodurre",
    "autoriproduceran": "autoriprodurre",
    "autoriproduceranno": "autoriprodurre",
    "autoriproducerebbe": "autoriprodurre",
    "autoriproducerebber": "autoriprodurre",
    "autoriproducerebbero": "autoriprodurre",
    "autoriproducerei": "autoriprodurre",
    "autoriproduceremmo": "autoriprodurre",
    "autoriproduceremo": "autoriprodurre",
    "autoriproducereste": "autoriprodurre",
    "autoriproduceresti": "autoriprodurre",
    "autoriproducerete": "autoriprodurre",
    "autoriproduceron": "autoriprodurre",
    "autoriproducerono": "autoriprodurre",
    "autoriproducerà": "autoriprodurre",
    "autoriproducerò": "autoriprodurre",
    "autoriproducesse": "autoriprodurre",
    "autoriproducesser": "autoriprodurre",
    "autoriproducessero": "autoriprodurre",
    "autoriproducessi": "autoriprodurre",
    "autoriproducessimo": "autoriprodurre",
    "autoriproduceste": "autoriprodurre",
    "autoriproducesti": "autoriprodurre",
    "autoriproducete": "autoriprodurre",
    "autoriproduceva": "autoriprodurre",
    "autoriproducevamo": "autoriprodurre",
    "autoriproducevan": "autoriprodurre",
    "autoriproducevano": "autoriprodurre",
    "autoriproducevate": "autoriprodurre",
    "autoriproducevi": "autoriprodurre",
    "autoriproducevo": "autoriprodurre",
    "autoriproduci": "autoriprodurre",
    "autoriproduciamo": "autoriprodurre",
    "autoriproduciate": "autoriprodurre",
    "autoriproduciuta": "autoriprodurre",
    "autoriproduciute": "autoriprodurre",
    "autoriproduciuti": "autoriprodurre",
    "autoriproduciuto": "autoriprodurre",
    "autoriproduco": "autoriprodurre",
    "autoriproducon": "autoriprodurre",
    "autoriproducono": "autoriprodurre",
    "autoriproducè": "autoriprodurre",
    "autoriprodurr": "autoriprodurre",
    "autoritari": "autoritario",
    "autoritaria": "autoritario",
    "autoritarie": "autoritario",
    "autoritarismi": "autoritarismo",
    "autoritaristica": "autoritaristico",
    "autoritaristiche": "autoritaristico",
    "autoritaristici": "autoritaristico",
    "autoritrasmetta": "autoritrasmettere",
    "autoritrasmettan": "autoritrasmettere",
    "autoritrasmettano": "autoritrasmettere",
    "autoritrasmette": "autoritrasmettere",
    "autoritrasmettei": "autoritrasmettere",
    "autoritrasmettemmo": "autoritrasmettere",
    "autoritrasmettendo": "autoritrasmettere",
    "autoritrasmettente": "autoritrasmettere",
    "autoritrasmettenti": "autoritrasmettere",
    "autoritrasmetter": "autoritrasmettere",
    "autoritrasmetterai": "autoritrasmettere",
    "autoritrasmetteran": "autoritrasmettere",
    "autoritrasmetteranno": "autoritrasmettere",
    "autoritrasmetterebbe": "autoritrasmettere",
    "autoritrasmetterebber": "autoritrasmettere",
    "autoritrasmetterebbero": "autoritrasmettere",
    "autoritrasmetterei": "autoritrasmettere",
    "autoritrasmetteremmo": "autoritrasmettere",
    "autoritrasmetteremo": "autoritrasmettere",
    "autoritrasmettereste": "autoritrasmettere",
    "autoritrasmetteresti": "autoritrasmettere",
    "autoritrasmetterete": "autoritrasmettere",
    "autoritrasmetteron": "autoritrasmettere",
    "autoritrasmetterono": "autoritrasmettere",
    "autoritrasmetterà": "autoritrasmettere",
    "autoritrasmetterò": "autoritrasmettere",
    "autoritrasmettesse": "autoritrasmettere",
    "autoritrasmettesser": "autoritrasmettere",
    "autoritrasmettessero": "autoritrasmettere",
    "autoritrasmettessi": "autoritrasmettere",
    "autoritrasmettessimo": "autoritrasmettere",
    "autoritrasmetteste": "autoritrasmettere",
    "autoritrasmettesti": "autoritrasmettere",
    "autoritrasmettete": "autoritrasmettere",
    "autoritrasmetteva": "autoritrasmettere",
    "autoritrasmettevamo": "autoritrasmettere",
    "autoritrasmettevan": "autoritrasmettere",
    "autoritrasmettevano": "autoritrasmettere",
    "autoritrasmettevate": "autoritrasmettere",
    "autoritrasmettevi": "autoritrasmettere",
    "autoritrasmettevo": "autoritrasmettere",
    "autoritrasmetti": "autoritrasmettere",
    "autoritrasmettiamo": "autoritrasmettere",
    "autoritrasmettiate": "autoritrasmettere",
    "autoritrasmetto": "autoritrasmettere",
    "autoritrasmetton": "autoritrasmettere",
    "autoritrasmettono": "autoritrasmettere",
    "autoritrasmettuta": "autoritrasmettere",
    "autoritrasmettute": "autoritrasmettere",
    "autoritrasmettuti": "autoritrasmettere",
    "autoritrasmettuto": "autoritrasmettere",
    "autoritrasmettè": "autoritrasmettere",
    "autoritratti": "autoritratto",
    "autorizza": "autorizzare",
    "autorizzabili": "autorizzabile",
    "autorizzai": "autorizzare",
    "autorizzammo": "autorizzare",
    "autorizzan": "autorizzare",
    "autorizzando": "autorizzare",
    "autorizzano": "autorizzare",
    "autorizzante": "autorizzare",
    "autorizzanti": "autorizzare",
    "autorizzar": "autorizzare",
    "autorizzaron": "autorizzare",
    "autorizzarono": "autorizzare",
    "autorizzasse": "autorizzare",
    "autorizzasser": "autorizzare",
    "autorizzassero": "autorizzare",
    "autorizzassi": "autorizzare",
    "autorizzassimo": "autorizzare",
    "autorizzaste": "autorizzare",
    "autorizzasti": "autorizzare",
    "autorizzata": "autorizzare",
    "autorizzate": "autorizzare",
    "autorizzati": "autorizzare",
    "autorizzativa": "autorizzativo",
    "autorizzative": "autorizzativo",
    "autorizzativi": "autorizzativo",
    "autorizzato": "autorizzare",
    "autorizzatori": "autorizzatorio",
    "autorizzatoria": "autorizzatorio",
    "autorizzatorie": "autorizzatorio",
    "autorizzava": "autorizzare",
    "autorizzavamo": "autorizzare",
    "autorizzavan": "autorizzare",
    "autorizzavano": "autorizzare",
    "autorizzavate": "autorizzare",
    "autorizzavi": "autorizzare",
    "autorizzavo": "autorizzare",
    "autorizzazioni": "autorizzazione",
    "autorizzerai": "autorizzare",
    "autorizzeran": "autorizzare",
    "autorizzeranno": "autorizzare",
    "autorizzerebbe": "autorizzare",
    "autorizzerebber": "autorizzare",
    "autorizzerebbero": "autorizzare",
    "autorizzerei": "autorizzare",
    "autorizzeremmo": "autorizzare",
    "autorizzeremo": "autorizzare",
    "autorizzereste": "autorizzare",
    "autorizzeresti": "autorizzare",
    "autorizzerete": "autorizzare",
    "autorizzerà": "autorizzare",
    "autorizzerò": "autorizzare",
    "autorizzi": "autorizzare",
    "autorizziamo": "autorizzare",
    "autorizziate": "autorizzare",
    "autorizzin": "autorizzare",
    "autorizzino": "autorizzare",
    "autorizzo": "autorizzare",
    "autorizzò": "autorizzare",
    "autorottama": "autorottamare",
    "autorottamai": "autorottamare",
    "autorottamammo": "autorottamare",
    "autorottaman": "autorottamare",
    "autorottamando": "autorottamare",
    "autorottamano": "autorottamare",
    "autorottamante": "autorottamare",
    "autorottamanti": "autorottamare",
    "autorottamar": "autorottamare",
    "autorottamaron": "autorottamare",
    "autorottamarono": "autorottamare",
    "autorottamasse": "autorottamare",
    "autorottamasser": "autorottamare",
    "autorottamassero": "autorottamare",
    "autorottamassi": "autorottamare",
    "autorottamassimo": "autorottamare",
    "autorottamaste": "autorottamare",
    "autorottamasti": "autorottamare",
    "autorottamata": "autorottamare",
    "autorottamate": "autorottamare",
    "autorottamati": "autorottamare",
    "autorottamato": "autorottamare",
    "autorottamava": "autorottamare",
    "autorottamavamo": "autorottamare",
    "autorottamavan": "autorottamare",
    "autorottamavano": "autorottamare",
    "autorottamavate": "autorottamare",
    "autorottamavi": "autorottamare",
    "autorottamavo": "autorottamare",
    "autorottamerai": "autorottamare",
    "autorottameran": "autorottamare",
    "autorottameranno": "autorottamare",
    "autorottamerebbe": "autorottamare",
    "autorottamerebber": "autorottamare",
    "autorottamerebbero": "autorottamare",
    "autorottamerei": "autorottamare",
    "autorottameremmo": "autorottamare",
    "autorottameremo": "autorottamare",
    "autorottamereste": "autorottamare",
    "autorottameresti": "autorottamare",
    "autorottamerete": "autorottamare",
    "autorottamerà": "autorottamare",
    "autorottamerò": "autorottamare",
    "autorottami": "autorottamare",
    "autorottamiamo": "autorottamare",
    "autorottamiate": "autorottamare",
    "autorottamin": "autorottamare",
    "autorottamino": "autorottamare",
    "autorottamo": "autorottamare",
    "autorottamò": "autorottamare",
    "autorovina": "autorovinare",
    "autorovinai": "autorovinare",
    "autorovinammo": "autorovinare",
    "autorovinan": "autorovinare",
    "autorovinando": "autorovinare",
    "autorovinano": "autorovinare",
    "autorovinante": "autorovinare",
    "autorovinanti": "autorovinare",
    "autorovinar": "autorovinare",
    "autorovinaron": "autorovinare",
    "autorovinarono": "autorovinare",
    "autorovinasse": "autorovinare",
    "autorovinasser": "autorovinare",
    "autorovinassero": "autorovinare",
    "autorovinassi": "autorovinare",
    "autorovinassimo": "autorovinare",
    "autorovinaste": "autorovinare",
    "autorovinasti": "autorovinare",
    "autorovinata": "autorovinare",
    "autorovinate": "autorovinare",
    "autorovinati": "autorovinare",
    "autorovinato": "autorovinare",
    "autorovinava": "autorovinare",
    "autorovinavamo": "autorovinare",
    "autorovinavan": "autorovinare",
    "autorovinavano": "autorovinare",
    "autorovinavate": "autorovinare",
    "autorovinavi": "autorovinare",
    "autorovinavo": "autorovinare",
    "autorovinerai": "autorovinare",
    "autorovineran": "autorovinare",
    "autorovineranno": "autorovinare",
    "autorovinerebbe": "autorovinare",
    "autorovinerebber": "autorovinare",
    "autorovinerebbero": "autorovinare",
    "autorovinerei": "autorovinare",
    "autorovineremmo": "autorovinare",
    "autorovineremo": "autorovinare",
    "autorovinereste": "autorovinare",
    "autorovineresti": "autorovinare",
    "autorovinerete": "autorovinare",
    "autorovinerà": "autorovinare",
    "autorovinerò": "autorovinare",
    "autorovini": "autorovinare",
    "autoroviniamo": "autorovinare",
    "autoroviniate": "autorovinare",
    "autorovinin": "autorovinare",
    "autorovinino": "autorovinare",
    "autorovino": "autorovinare",
    "autorovinò": "autorovinare",
    "autosaloni": "autosalone",
    "autosciogli": "autosciogliere",
    "autosciogliamo": "autosciogliere",
    "autosciogliate": "autosciogliere",
    "autoscioglie": "autosciogliere",
    "autosciogliemmo": "autosciogliere",
    "autosciogliendo": "autosciogliere",
    "autosciogliente": "autosciogliere",
    "autoscioglienti": "autosciogliere",
    "autoscioglier": "autosciogliere",
    "autoscioglierai": "autosciogliere",
    "autoscioglieran": "autosciogliere",
    "autoscioglieranno": "autosciogliere",
    "autoscioglierebbe": "autosciogliere",
    "autoscioglierebber": "autosciogliere",
    "autoscioglierebbero": "autosciogliere",
    "autoscioglierei": "autosciogliere",
    "autoscioglieremmo": "autosciogliere",
    "autoscioglieremo": "autosciogliere",
    "autosciogliereste": "autosciogliere",
    "autoscioglieresti": "autosciogliere",
    "autoscioglierete": "autosciogliere",
    "autoscioglierà": "autosciogliere",
    "autoscioglierò": "autosciogliere",
    "autosciogliesse": "autosciogliere",
    "autosciogliesser": "autosciogliere",
    "autosciogliessero": "autosciogliere",
    "autosciogliessi": "autosciogliere",
    "autosciogliessimo": "autosciogliere",
    "autoscioglieste": "autosciogliere",
    "autosciogliesti": "autosciogliere",
    "autosciogliete": "autosciogliere",
    "autoscioglieva": "autosciogliere",
    "autoscioglievamo": "autosciogliere",
    "autoscioglievan": "autosciogliere",
    "autoscioglievano": "autosciogliere",
    "autoscioglievate": "autosciogliere",
    "autoscioglievi": "autosciogliere",
    "autoscioglievo": "autosciogliere",
    "autosciolga": "autosciogliere",
    "autosciolgan": "autosciogliere",
    "autosciolgano": "autosciogliere",
    "autosciolgo": "autosciogliere",
    "autosciolgon": "autosciogliere",
    "autosciolgono": "autosciogliere",
    "autosciolser": "autosciogliere",
    "autosciolsero": "autosciogliere",
    "autosciolsi": "autosciogliere",
    "autosciolsè": "autosciogliere",
    "autosciolta": "autosciogliere",
    "autosciolte": "autosciogliere",
    "autosciolti": "autosciogliere",
    "autosciolto": "autosciogliere",
    "autoscontri": "autoscontro",
    "autoscuole": "autoscuola",
    "autosegrega": "autosegregare",
    "autosegregai": "autosegregare",
    "autosegregammo": "autosegregare",
    "autosegregan": "autosegregare",
    "autosegregando": "autosegregare",
    "autosegregano": "autosegregare",
    "autosegregante": "autosegregare",
    "autosegreganti": "autosegregare",
    "autosegregar": "autosegregare",
    "autosegregaron": "autosegregare",
    "autosegregarono": "autosegregare",
    "autosegregasse": "autosegregare",
    "autosegregasser": "autosegregare",
    "autosegregassero": "autosegregare",
    "autosegregassi": "autosegregare",
    "autosegregassimo": "autosegregare",
    "autosegregaste": "autosegregare",
    "autosegregasti": "autosegregare",
    "autosegregata": "autosegregare",
    "autosegregate": "autosegregare",
    "autosegregati": "autosegregare",
    "autosegregato": "autosegregare",
    "autosegregava": "autosegregare",
    "autosegregavamo": "autosegregare",
    "autosegregavan": "autosegregare",
    "autosegregavano": "autosegregare",
    "autosegregavate": "autosegregare",
    "autosegregavi": "autosegregare",
    "autosegregavo": "autosegregare",
    "autosegregherai": "autosegregare",
    "autosegregheran": "autosegregare",
    "autosegregheranno": "autosegregare",
    "autosegregherebbe": "autosegregare",
    "autosegregherebber": "autosegregare",
    "autosegregherebbero": "autosegregare",
    "autosegregherei": "autosegregare",
    "autosegregheremmo": "autosegregare",
    "autosegregheremo": "autosegregare",
    "autosegreghereste": "autosegregare",
    "autosegregheresti": "autosegregare",
    "autosegregherete": "autosegregare",
    "autosegregherà": "autosegregare",
    "autosegregherò": "autosegregare",
    "autosegreghi": "autosegregare",
    "autosegreghiamo": "autosegregare",
    "autosegreghiate": "autosegregare",
    "autosegreghin": "autosegregare",
    "autosegreghino": "autosegregare",
    "autosegrego": "autosegregare",
    "autosegregò": "autosegregare",
    "autoseppella": "autoseppellire",
    "autoseppellan": "autoseppellire",
    "autoseppellano": "autoseppellire",
    "autoseppelle": "autoseppellire",
    "autoseppellendo": "autoseppellire",
    "autoseppellente": "autoseppellire",
    "autoseppellenti": "autoseppellire",
    "autoseppelli": "autoseppellire",
    "autoseppelliamo": "autoseppellire",
    "autoseppelliate": "autoseppellire",
    "autoseppellii": "autoseppellire",
    "autoseppellimmo": "autoseppellire",
    "autoseppellir": "autoseppellire",
    "autoseppellirai": "autoseppellire",
    "autoseppelliran": "autoseppellire",
    "autoseppelliranno": "autoseppellire",
    "autoseppellirebbe": "autoseppellire",
    "autoseppellirebber": "autoseppellire",
    "autoseppellirebbero": "autoseppellire",
    "autoseppellirei": "autoseppellire",
    "autoseppelliremmo": "autoseppellire",
    "autoseppelliremo": "autoseppellire",
    "autoseppellireste": "autoseppellire",
    "autoseppelliresti": "autoseppellire",
    "autoseppellirete": "autoseppellire",
    "autoseppelliron": "autoseppellire",
    "autoseppellirono": "autoseppellire",
    "autoseppellirà": "autoseppellire",
    "autoseppellirò": "autoseppellire",
    "autoseppellisse": "autoseppellire",
    "autoseppellisser": "autoseppellire",
    "autoseppellissero": "autoseppellire",
    "autoseppellissi": "autoseppellire",
    "autoseppellissimo": "autoseppellire",
    "autoseppelliste": "autoseppellire",
    "autoseppellisti": "autoseppellire",
    "autoseppellita": "autoseppellire",
    "autoseppellite": "autoseppellire",
    "autoseppelliti": "autoseppellire",
    "autoseppellito": "autoseppellire",
    "autoseppelliva": "autoseppellire",
    "autoseppellivamo": "autoseppellire",
    "autoseppellivan": "autoseppellire",
    "autoseppellivano": "autoseppellire",
    "autoseppellivate": "autoseppellire",
    "autoseppellivi": "autoseppellire",
    "autoseppellivo": "autoseppellire",
    "autoseppello": "autoseppellire",
    "autoseppellon": "autoseppellire",
    "autoseppellono": "autoseppellire",
    "autoseppellì": "autoseppellire",
    "autosigilla": "autosigillare",
    "autosigillai": "autosigillare",
    "autosigillammo": "autosigillare",
    "autosigillan": "autosigillare",
    "autosigillando": "autosigillare",
    "autosigillano": "autosigillare",
    "autosigillante": "autosigillare",
    "autosigillanti": "autosigillare",
    "autosigillar": "autosigillare",
    "autosigillaron": "autosigillare",
    "autosigillarono": "autosigillare",
    "autosigillasse": "autosigillare",
    "autosigillasser": "autosigillare",
    "autosigillassero": "autosigillare",
    "autosigillassi": "autosigillare",
    "autosigillassimo": "autosigillare",
    "autosigillaste": "autosigillare",
    "autosigillasti": "autosigillare",
    "autosigillata": "autosigillare",
    "autosigillate": "autosigillare",
    "autosigillati": "autosigillare",
    "autosigillato": "autosigillare",
    "autosigillava": "autosigillare",
    "autosigillavamo": "autosigillare",
    "autosigillavan": "autosigillare",
    "autosigillavano": "autosigillare",
    "autosigillavate": "autosigillare",
    "autosigillavi": "autosigillare",
    "autosigillavo": "autosigillare",
    "autosigillerai": "autosigillare",
    "autosigilleran": "autosigillare",
    "autosigilleranno": "autosigillare",
    "autosigillerebbe": "autosigillare",
    "autosigillerebber": "autosigillare",
    "autosigillerebbero": "autosigillare",
    "autosigillerei": "autosigillare",
    "autosigilleremmo": "autosigillare",
    "autosigilleremo": "autosigillare",
    "autosigillereste": "autosigillare",
    "autosigilleresti": "autosigillare",
    "autosigillerete": "autosigillare",
    "autosigillerà": "autosigillare",
    "autosigillerò": "autosigillare",
    "autosigilli": "autosigillare",
    "autosigilliamo": "autosigillare",
    "autosigilliate": "autosigillare",
    "autosigillin": "autosigillare",
    "autosigillino": "autosigillare",
    "autosigillo": "autosigillare",
    "autosigillò": "autosigillare",
    "autosmenta": "autosmentire",
    "autosmentan": "autosmentire",
    "autosmentano": "autosmentire",
    "autosmente": "autosmentire",
    "autosmentendo": "autosmentire",
    "autosmentente": "autosmentire",
    "autosmententi": "autosmentire",
    "autosmenti": "autosmentire",
    "autosmentiamo": "autosmentire",
    "autosmentiate": "autosmentire",
    "autosmentii": "autosmentire",
    "autosmentimmo": "autosmentire",
    "autosmentir": "autosmentire",
    "autosmentirai": "autosmentire",
    "autosmentiran": "autosmentire",
    "autosmentiranno": "autosmentire",
    "autosmentirebbe": "autosmentire",
    "autosmentirebber": "autosmentire",
    "autosmentirebbero": "autosmentire",
    "autosmentirei": "autosmentire",
    "autosmentiremmo": "autosmentire",
    "autosmentiremo": "autosmentire",
    "autosmentireste": "autosmentire",
    "autosmentiresti": "autosmentire",
    "autosmentirete": "autosmentire",
    "autosmentiron": "autosmentire",
    "autosmentirono": "autosmentire",
    "autosmentirà": "autosmentire",
    "autosmentirò": "autosmentire",
    "autosmentisse": "autosmentire",
    "autosmentisser": "autosmentire",
    "autosmentissero": "autosmentire",
    "autosmentissi": "autosmentire",
    "autosmentissimo": "autosmentire",
    "autosmentiste": "autosmentire",
    "autosmentisti": "autosmentire",
    "autosmentita": "autosmentire",
    "autosmentite": "autosmentire",
    "autosmentiti": "autosmentire",
    "autosmentito": "autosmentire",
    "autosmentiva": "autosmentire",
    "autosmentivamo": "autosmentire",
    "autosmentivan": "autosmentire",
    "autosmentivano": "autosmentire",
    "autosmentivate": "autosmentire",
    "autosmentivi": "autosmentire",
    "autosmentivo": "autosmentire",
    "autosmento": "autosmentire",
    "autosmenton": "autosmentire",
    "autosmentono": "autosmentire",
    "autosmentì": "autosmentire",
    "autosospenda": "autosospendere",
    "autosospendan": "autosospendere",
    "autosospendano": "autosospendere",
    "autosospende": "autosospendere",
    "autosospendemmo": "autosospendere",
    "autosospendendo": "autosospendere",
    "autosospendente": "autosospendere",
    "autosospendenti": "autosospendere",
    "autosospender": "autosospendere",
    "autosospenderai": "autosospendere",
    "autosospenderan": "autosospendere",
    "autosospenderanno": "autosospendere",
    "autosospenderebbe": "autosospendere",
    "autosospenderebber": "autosospendere",
    "autosospenderebbero": "autosospendere",
    "autosospenderei": "autosospendere",
    "autosospenderemmo": "autosospendere",
    "autosospenderemo": "autosospendere",
    "autosospendereste": "autosospendere",
    "autosospenderesti": "autosospendere",
    "autosospenderete": "autosospendere",
    "autosospenderà": "autosospendere",
    "autosospenderò": "autosospendere",
    "autosospendesse": "autosospendere",
    "autosospendesser": "autosospendere",
    "autosospendessero": "autosospendere",
    "autosospendessi": "autosospendere",
    "autosospendessimo": "autosospendere",
    "autosospendeste": "autosospendere",
    "autosospendesti": "autosospendere",
    "autosospendete": "autosospendere",
    "autosospendeva": "autosospendere",
    "autosospendevamo": "autosospendere",
    "autosospendevan": "autosospendere",
    "autosospendevano": "autosospendere",
    "autosospendevate": "autosospendere",
    "autosospendevi": "autosospendere",
    "autosospendevo": "autosospendere",
    "autosospendi": "autosospendere",
    "autosospendiamo": "autosospendere",
    "autosospendiate": "autosospendere",
    "autosospendo": "autosospendere",
    "autosospendon": "autosospendere",
    "autosospendono": "autosospendere",
    "autosospesa": "autosospendere",
    "autosospese": "autosospendere",
    "autosospeser": "autosospendere",
    "autosospesero": "autosospendere",
    "autosospesi": "autosospendere",
    "autosospeso": "autosospendere",
    "autosospesè": "autosospendere",
    "autosostene": "autosostenere",
    "autosostenei": "autosostenere",
    "autosostenemmo": "autosostenere",
    "autosostenendo": "autosostenere",
    "autosostenente": "autosostenere",
    "autosostenenti": "autosostenere",
    "autosostener": "autosostenere",
    "autosostenerai": "autosostenere",
    "autososteneran": "autosostenere",
    "autososteneranno": "autosostenere",
    "autosostenerebbe": "autosostenere",
    "autosostenerebber": "autosostenere",
    "autosostenerebbero": "autosostenere",
    "autosostenerei": "autosostenere",
    "autososteneremmo": "autosostenere",
    "autososteneremo": "autosostenere",
    "autosostenereste": "autosostenere",
    "autososteneresti": "autosostenere",
    "autosostenerete": "autosostenere",
    "autososteneron": "autosostenere",
    "autosostenerono": "autosostenere",
    "autosostenerà": "autosostenere",
    "autosostenerò": "autosostenere",
    "autosostenesse": "autosostenere",
    "autosostenesser": "autosostenere",
    "autosostenessero": "autosostenere",
    "autosostenessi": "autosostenere",
    "autosostenessimo": "autosostenere",
    "autososteneste": "autosostenere",
    "autosostenesti": "autosostenere",
    "autosostenete": "autosostenere",
    "autososteneva": "autosostenere",
    "autosostenevamo": "autosostenere",
    "autosostenevan": "autosostenere",
    "autosostenevano": "autosostenere",
    "autosostenevate": "autosostenere",
    "autosostenevi": "autosostenere",
    "autosostenevo": "autosostenere",
    "autosostenga": "autosostenere",
    "autosostengan": "autosostenere",
    "autosostengano": "autosostenere",
    "autosostengo": "autosostenere",
    "autosostengon": "autosostenere",
    "autosostengono": "autosostenere",
    "autososteni": "autosostenere",
    "autososteniamo": "autosostenere",
    "autososteniate": "autosostenere",
    "autosostenuta": "autosostenere",
    "autosostenute": "autosostenere",
    "autosostenuti": "autosostenere",
    "autosostenuto": "autosostenere",
    "autosostenè": "autosostenere",
    "autospeda": "autospedire",
    "autospedan": "autospedire",
    "autospedano": "autospedire",
    "autospede": "autospedire",
    "autospedendo": "autospedire",
    "autospedente": "autospedire",
    "autospedenti": "autospedire",
    "autospedi": "autospedire",
    "autospediamo": "autospedire",
    "autospediate": "autospedire",
    "autospedii": "autospedire",
    "autospedimmo": "autospedire",
    "autospedir": "autospedire",
    "autospedirai": "autospedire",
    "autospediran": "autospedire",
    "autospediranno": "autospedire",
    "autospedirebbe": "autospedire",
    "autospedirebber": "autospedire",
    "autospedirebbero": "autospedire",
    "autospedirei": "autospedire",
    "autospediremmo": "autospedire",
    "autospediremo": "autospedire",
    "autospedireste": "autospedire",
    "autospediresti": "autospedire",
    "autospedirete": "autospedire",
    "autospediron": "autospedire",
    "autospedirono": "autospedire",
    "autospedirà": "autospedire",
    "autospedirò": "autospedire",
    "autospedisse": "autospedire",
    "autospedisser": "autospedire",
    "autospedissero": "autospedire",
    "autospedissi": "autospedire",
    "autospedissimo": "autospedire",
    "autospediste": "autospedire",
    "autospedisti": "autospedire",
    "autospedita": "autospedire",
    "autospedite": "autospedire",
    "autospediti": "autospedire",
    "autospedito": "autospedire",
    "autospediva": "autospedire",
    "autospedivamo": "autospedire",
    "autospedivan": "autospedire",
    "autospedivano": "autospedire",
    "autospedivate": "autospedire",
    "autospedivi": "autospedire",
    "autospedivo": "autospedire",
    "autospedo": "autospedire",
    "autospedon": "autospedire",
    "autospedono": "autospedire",
    "autospedì": "autospedire",
    "autospenda": "autospendere",
    "autospendan": "autospendere",
    "autospendano": "autospendere",
    "autospende": "autospendere",
    "autospendemmo": "autospendere",
    "autospendendo": "autospendere",
    "autospendente": "autospendere",
    "autospendenti": "autospendere",
    "autospender": "autospendere",
    "autospenderai": "autospendere",
    "autospenderan": "autospendere",
    "autospenderanno": "autospendere",
    "autospenderebbe": "autospendere",
    "autospenderebber": "autospendere",
    "autospenderebbero": "autospendere",
    "autospenderei": "autospendere",
    "autospenderemmo": "autospendere",
    "autospenderemo": "autospendere",
    "autospendereste": "autospendere",
    "autospenderesti": "autospendere",
    "autospenderete": "autospendere",
    "autospenderà": "autospendere",
    "autospenderò": "autospendere",
    "autospendesse": "autospendere",
    "autospendesser": "autospendere",
    "autospendessero": "autospendere",
    "autospendessi": "autospendere",
    "autospendessimo": "autospendere",
    "autospendeste": "autospendere",
    "autospendesti": "autospendere",
    "autospendete": "autospendere",
    "autospendeva": "autospendere",
    "autospendevamo": "autospendere",
    "autospendevan": "autospendere",
    "autospendevano": "autospendere",
    "autospendevate": "autospendere",
    "autospendevi": "autospendere",
    "autospendevo": "autospendere",
    "autospendi": "autospendere",
    "autospendiamo": "autospendere",
    "autospendiate": "autospendere",
    "autospendo": "autospendere",
    "autospendon": "autospendere",
    "autospendono": "autospendere",
    "autospernacchi": "autospernacchiare",
    "autospernacchia": "autospernacchiare",
    "autospernacchiai": "autospernacchiare",
    "autospernacchiammo": "autospernacchiare",
    "autospernacchiamo": "autospernacchiare",
    "autospernacchian": "autospernacchiare",
    "autospernacchiando": "autospernacchiare",
    "autospernacchiano": "autospernacchiare",
    "autospernacchiante": "autospernacchiare",
    "autospernacchianti": "autospernacchiare",
    "autospernacchiar": "autospernacchiare",
    "autospernacchiaron": "autospernacchiare",
    "autospernacchiarono": "autospernacchiare",
    "autospernacchiasse": "autospernacchiare",
    "autospernacchiasser": "autospernacchiare",
    "autospernacchiassero": "autospernacchiare",
    "autospernacchiassi": "autospernacchiare",
    "autospernacchiassimo": "autospernacchiare",
    "autospernacchiaste": "autospernacchiare",
    "autospernacchiasti": "autospernacchiare",
    "autospernacchiata": "autospernacchiare",
    "autospernacchiate": "autospernacchiare",
    "autospernacchiati": "autospernacchiare",
    "autospernacchiato": "autospernacchiare",
    "autospernacchiava": "autospernacchiare",
    "autospernacchiavamo": "autospernacchiare",
    "autospernacchiavan": "autospernacchiare",
    "autospernacchiavano": "autospernacchiare",
    "autospernacchiavate": "autospernacchiare",
    "autospernacchiavi": "autospernacchiare",
    "autospernacchiavo": "autospernacchiare",
    "autospernacchierai": "autospernacchiare",
    "autospernacchieran": "autospernacchiare",
    "autospernacchieranno": "autospernacchiare",
    "autospernacchierebbe": "autospernacchiare",
    "autospernacchierebber": "autospernacchiare",
    "autospernacchierebbero": "autospernacchiare",
    "autospernacchierei": "autospernacchiare",
    "autospernacchieremmo": "autospernacchiare",
    "autospernacchieremo": "autospernacchiare",
    "autospernacchiereste": "autospernacchiare",
    "autospernacchieresti": "autospernacchiare",
    "autospernacchierete": "autospernacchiare",
    "autospernacchierà": "autospernacchiare",
    "autospernacchierò": "autospernacchiare",
    "autospernacchin": "autospernacchiare",
    "autospernacchino": "autospernacchiare",
    "autospernacchio": "autospernacchiare",
    "autospernacchiò": "autospernacchiare",
    "autospesa": "autospendere",
    "autospese": "autospendere",
    "autospeser": "autospendere",
    "autospesero": "autospendere",
    "autospesi": "autospendere",
    "autospeso": "autospendere",
    "autospesè": "autospendere",
    "autosponsorizzata": "autosponsorizzato",
    "autosponsorizzate": "autosponsorizzato",
    "autosponsorizzati": "autosponsorizzato",
    "autostimola": "autostimolare",
    "autostimolai": "autostimolare",
    "autostimolammo": "autostimolare",
    "autostimolan": "autostimolare",
    "autostimolando": "autostimolare",
    "autostimolano": "autostimolare",
    "autostimolante": "autostimolare",
    "autostimolanti": "autostimolare",
    "autostimolar": "autostimolare",
    "autostimolaron": "autostimolare",
    "autostimolarono": "autostimolare",
    "autostimolasse": "autostimolare",
    "autostimolasser": "autostimolare",
    "autostimolassero": "autostimolare",
    "autostimolassi": "autostimolare",
    "autostimolassimo": "autostimolare",
    "autostimolaste": "autostimolare",
    "autostimolasti": "autostimolare",
    "autostimolata": "autostimolare",
    "autostimolate": "autostimolare",
    "autostimolati": "autostimolare",
    "autostimolato": "autostimolare",
    "autostimolava": "autostimolare",
    "autostimolavamo": "autostimolare",
    "autostimolavan": "autostimolare",
    "autostimolavano": "autostimolare",
    "autostimolavate": "autostimolare",
    "autostimolavi": "autostimolare",
    "autostimolavo": "autostimolare",
    "autostimolerai": "autostimolare",
    "autostimoleran": "autostimolare",
    "autostimoleranno": "autostimolare",
    "autostimolerebbe": "autostimolare",
    "autostimolerebber": "autostimolare",
    "autostimolerebbero": "autostimolare",
    "autostimolerei": "autostimolare",
    "autostimoleremmo": "autostimolare",
    "autostimoleremo": "autostimolare",
    "autostimolereste": "autostimolare",
    "autostimoleresti": "autostimolare",
    "autostimolerete": "autostimolare",
    "autostimolerà": "autostimolare",
    "autostimolerò": "autostimolare",
    "autostimoli": "autostimolare",
    "autostimoliamo": "autostimolare",
    "autostimoliate": "autostimolare",
    "autostimolin": "autostimolare",
    "autostimolino": "autostimolare",
    "autostimolo": "autostimolare",
    "autostimolò": "autostimolare",
    "autostradali": "autostradale",
    "autostrade": "autostrada",
    "autostrangola": "autostrangolare",
    "autostrangolai": "autostrangolare",
    "autostrangolammo": "autostrangolare",
    "autostrangolan": "autostrangolare",
    "autostrangolando": "autostrangolare",
    "autostrangolano": "autostrangolare",
    "autostrangolante": "autostrangolare",
    "autostrangolanti": "autostrangolare",
    "autostrangolar": "autostrangolare",
    "autostrangolaron": "autostrangolare",
    "autostrangolarono": "autostrangolare",
    "autostrangolasse": "autostrangolare",
    "autostrangolasser": "autostrangolare",
    "autostrangolassero": "autostrangolare",
    "autostrangolassi": "autostrangolare",
    "autostrangolassimo": "autostrangolare",
    "autostrangolaste": "autostrangolare",
    "autostrangolasti": "autostrangolare",
    "autostrangolata": "autostrangolare",
    "autostrangolate": "autostrangolare",
    "autostrangolati": "autostrangolare",
    "autostrangolato": "autostrangolare",
    "autostrangolava": "autostrangolare",
    "autostrangolavamo": "autostrangolare",
    "autostrangolavan": "autostrangolare",
    "autostrangolavano": "autostrangolare",
    "autostrangolavate": "autostrangolare",
    "autostrangolavi": "autostrangolare",
    "autostrangolavo": "autostrangolare",
    "autostrangolerai": "autostrangolare",
    "autostrangoleran": "autostrangolare",
    "autostrangoleranno": "autostrangolare",
    "autostrangolerebbe": "autostrangolare",
    "autostrangolerebber": "autostrangolare",
    "autostrangolerebbero": "autostrangolare",
    "autostrangolerei": "autostrangolare",
    "autostrangoleremmo": "autostrangolare",
    "autostrangoleremo": "autostrangolare",
    "autostrangolereste": "autostrangolare",
    "autostrangoleresti": "autostrangolare",
    "autostrangolerete": "autostrangolare",
    "autostrangolerà": "autostrangolare",
    "autostrangolerò": "autostrangolare",
    "autostrangoli": "autostrangolare",
    "autostrangoliamo": "autostrangolare",
    "autostrangoliate": "autostrangolare",
    "autostrangolin": "autostrangolare",
    "autostrangolino": "autostrangolare",
    "autostrangolo": "autostrangolare",
    "autostrangolò": "autostrangolare",
    "autosufficienti": "autosufficiente",
    "autosufficienze": "autosufficienza",
    "autotassa": "autotassare",
    "autotassai": "autotassare",
    "autotassammo": "autotassare",
    "autotassan": "autotassare",
    "autotassando": "autotassare",
    "autotassano": "autotassare",
    "autotassante": "autotassare",
    "autotassanti": "autotassare",
    "autotassar": "autotassare",
    "autotassaron": "autotassare",
    "autotassarono": "autotassare",
    "autotassasse": "autotassare",
    "autotassasser": "autotassare",
    "autotassassero": "autotassare",
    "autotassassi": "autotassare",
    "autotassassimo": "autotassare",
    "autotassaste": "autotassare",
    "autotassasti": "autotassare",
    "autotassata": "autotassare",
    "autotassate": "autotassare",
    "autotassati": "autotassare",
    "autotassato": "autotassare",
    "autotassava": "autotassare",
    "autotassavamo": "autotassare",
    "autotassavan": "autotassare",
    "autotassavano": "autotassare",
    "autotassavate": "autotassare",
    "autotassavi": "autotassare",
    "autotassavo": "autotassare",
    "autotasserai": "autotassare",
    "autotasseran": "autotassare",
    "autotasseranno": "autotassare",
    "autotasserebbe": "autotassare",
    "autotasserebber": "autotassare",
    "autotasserebbero": "autotassare",
    "autotasserei": "autotassare",
    "autotasseremmo": "autotassare",
    "autotasseremo": "autotassare",
    "autotassereste": "autotassare",
    "autotasseresti": "autotassare",
    "autotasserete": "autotassare",
    "autotasserà": "autotassare",
    "autotasserò": "autotassare",
    "autotassi": "autotassare",
    "autotassiamo": "autotassare",
    "autotassiate": "autotassare",
    "autotassin": "autotassare",
    "autotassino": "autotassare",
    "autotasso": "autotassare",
    "autotassò": "autotassare",
    "autotrapiantata": "autotrapiantato",
    "autotrapiantate": "autotrapiantato",
    "autotrapiantati": "autotrapiantato",
    "autotrasportatori": "autotrasportatore",
    "autotreni": "autotreno",
    "autotutela": "autotutelare",
    "autotutelai": "autotutelare",
    "autotutelammo": "autotutelare",
    "autotutelan": "autotutelare",
    "autotutelando": "autotutelare",
    "autotutelano": "autotutelare",
    "autotutelante": "autotutelare",
    "autotutelanti": "autotutelare",
    "autotutelar": "autotutelare",
    "autotutelaron": "autotutelare",
    "autotutelarono": "autotutelare",
    "autotutelasse": "autotutelare",
    "autotutelasser": "autotutelare",
    "autotutelassero": "autotutelare",
    "autotutelassi": "autotutelare",
    "autotutelassimo": "autotutelare",
    "autotutelaste": "autotutelare",
    "autotutelasti": "autotutelare",
    "autotutelata": "autotutelare",
    "autotutelate": "autotutelare",
    "autotutelati": "autotutelare",
    "autotutelato": "autotutelare",
    "autotutelava": "autotutelare",
    "autotutelavamo": "autotutelare",
    "autotutelavan": "autotutelare",
    "autotutelavano": "autotutelare",
    "autotutelavate": "autotutelare",
    "autotutelavi": "autotutelare",
    "autotutelavo": "autotutelare",
    "autotutelerai": "autotutelare",
    "autotuteleran": "autotutelare",
    "autotuteleranno": "autotutelare",
    "autotutelerebbe": "autotutelare",
    "autotutelerebber": "autotutelare",
    "autotutelerebbero": "autotutelare",
    "autotutelerei": "autotutelare",
    "autotuteleremmo": "autotutelare",
    "autotuteleremo": "autotutelare",
    "autotutelereste": "autotutelare",
    "autotuteleresti": "autotutelare",
    "autotutelerete": "autotutelare",
    "autotutelerà": "autotutelare",
    "autotutelerò": "autotutelare",
    "autotuteli": "autotutelare",
    "autotuteliamo": "autotutelare",
    "autotuteliate": "autotutelare",
    "autotutelin": "autotutelare",
    "autotutelino": "autotutelare",
    "autotutelo": "autotutelare",
    "autotutelò": "autotutelare",
    "autovaluta": "autovalutare",
    "autovalutai": "autovalutare",
    "autovalutammo": "autovalutare",
    "autovalutan": "autovalutare",
    "autovalutando": "autovalutare",
    "autovalutano": "autovalutare",
    "autovalutante": "autovalutare",
    "autovalutanti": "autovalutare",
    "autovalutar": "autovalutare",
    "autovalutaron": "autovalutare",
    "autovalutarono": "autovalutare",
    "autovalutasse": "autovalutare",
    "autovalutasser": "autovalutare",
    "autovalutassero": "autovalutare",
    "autovalutassi": "autovalutare",
    "autovalutassimo": "autovalutare",
    "autovalutaste": "autovalutare",
    "autovalutasti": "autovalutare",
    "autovalutata": "autovalutare",
    "autovalutate": "autovalutare",
    "autovalutati": "autovalutare",
    "autovalutato": "autovalutare",
    "autovalutava": "autovalutare",
    "autovalutavamo": "autovalutare",
    "autovalutavan": "autovalutare",
    "autovalutavano": "autovalutare",
    "autovalutavate": "autovalutare",
    "autovalutavi": "autovalutare",
    "autovalutavo": "autovalutare",
    "autovaluterai": "autovalutare",
    "autovaluteran": "autovalutare",
    "autovaluteranno": "autovalutare",
    "autovaluterebbe": "autovalutare",
    "autovaluterebber": "autovalutare",
    "autovaluterebbero": "autovalutare",
    "autovaluterei": "autovalutare",
    "autovaluteremmo": "autovalutare",
    "autovaluteremo": "autovalutare",
    "autovalutereste": "autovalutare",
    "autovaluteresti": "autovalutare",
    "autovaluterete": "autovalutare",
    "autovaluterà": "autovalutare",
    "autovaluterò": "autovalutare",
    "autovaluti": "autovalutare",
    "autovalutiamo": "autovalutare",
    "autovalutiate": "autovalutare",
    "autovalutin": "autovalutare",
    "autovalutino": "autovalutare",
    "autovaluto": "autovalutare",
    "autovalutò": "autovalutare",
    "autoveicoli": "autoveicolo",
    "autoveicolistica": "autoveicolistico",
    "autoveicolistiche": "autoveicolistico",
    "autoveicolistici": "autoveicolistico",
    "autovetture": "autovettura",
    "autrici": "autrice",
    "autunnali": "autunnale",
    "autunni": "autunno",
    "avalla": "avallare",
    "avallai": "avallare",
    "avallammo": "avallare",
    "avallan": "avallare",
    "avallando": "avallare",
    "avallano": "avallare",
    "avallante": "avallare",
    "avallanti": "avallare",
    "avallar": "avallare",
    "avallaron": "avallare",
    "avallarono": "avallare",
    "avallasse": "avallare",
    "avallasser": "avallare",
    "avallassero": "avallare",
    "avallassi": "avallare",
    "avallassimo": "avallare",
    "avallaste": "avallare",
    "avallasti": "avallare",
    "avallata": "avallare",
    "avallate": "avallare",
    "avallati": "avallare",
    "avallato": "avallare",
    "avallava": "avallare",
    "avallavamo": "avallare",
    "avallavan": "avallare",
    "avallavano": "avallare",
    "avallavate": "avallare",
    "avallavi": "avallare",
    "avallavo": "avallare",
    "avallerai": "avallare",
    "avalleran": "avallare",
    "avalleranno": "avallare",
    "avallerebbe": "avallare",
    "avallerebber": "avallare",
    "avallerebbero": "avallare",
    "avallerei": "avallare",
    "avalleremmo": "avallare",
    "avalleremo": "avallare",
    "avallereste": "avallare",
    "avalleresti": "avallare",
    "avallerete": "avallare",
    "avallerà": "avallare",
    "avallerò": "avallare",
    "avalli": "avallo",
    "avalliamo": "avallare",
    "avalliate": "avallare",
    "avallin": "avallare",
    "avallino": "avallare",
    "avallo": "avallare",
    "avallò": "avallare",
    "avambracci": "avambraccio",
    "avamposti": "avamposto",
    "avanguardie": "avanguardia",
    "avanguardismi": "avanguardismo",
    "avanguardisti": "avanguardista",
    "avanguardistica": "avanguardistico",
    "avanguardistiche": "avanguardistico",
    "avanguardistici": "avanguardistico",
    "avanspettacoli": "avanspettacolo",
    "avanza": "avanzare",
    "avanzai": "avanzare",
    "avanzamenti": "avanzamento",
    "avanzammo": "avanzare",
    "avanzan": "avanzare",
    "avanzando": "avanzare",
    "avanzano": "avanzare",
    "avanzante": "avanzare",
    "avanzanti": "avanzare",
    "avanzar": "avanzare",
    "avanzaron": "avanzare",
    "avanzarono": "avanzare",
    "avanzasse": "avanzare",
    "avanzasser": "avanzare",
    "avanzassero": "avanzare",
    "avanzassi": "avanzare",
    "avanzassimo": "avanzare",
    "avanzaste": "avanzare",
    "avanzasti": "avanzare",
    "avanzata": "avanzato",
    "avanzate": "avanzato",
    "avanzati": "avanzato",
    "avanzato": "avanzare",
    "avanzava": "avanzare",
    "avanzavamo": "avanzare",
    "avanzavan": "avanzare",
    "avanzavano": "avanzare",
    "avanzavate": "avanzare",
    "avanzavi": "avanzare",
    "avanzavo": "avanzare",
    "avanzerai": "avanzare",
    "avanzeran": "avanzare",
    "avanzeranno": "avanzare",
    "avanzerebbe": "avanzare",
    "avanzerebber": "avanzare",
    "avanzerebbero": "avanzare",
    "avanzerei": "avanzare",
    "avanzeremmo": "avanzare",
    "avanzeremo": "avanzare",
    "avanzereste": "avanzare",
    "avanzeresti": "avanzare",
    "avanzerete": "avanzare",
    "avanzerà": "avanzare",
    "avanzerò": "avanzare",
    "avanzi": "avanzo",
    "avanziamo": "avanzare",
    "avanziate": "avanzare",
    "avanzin": "avanzare",
    "avanzino": "avanzare",
    "avanzo": "avanzare",
    "avanzò": "avanzare",
    "avara": "avaro",
    "avare": "avaro",
    "avari": "avaro",
    "avaria": "avariare",
    "avariai": "avariare",
    "avariammo": "avariare",
    "avariamo": "avariare",
    "avarian": "avariare",
    "avariando": "avariare",
    "avariano": "avariare",
    "avariante": "avariare",
    "avarianti": "avariare",
    "avariar": "avariare",
    "avariaron": "avariare",
    "avariarono": "avariare",
    "avariasse": "avariare",
    "avariasser": "avariare",
    "avariassero": "avariare",
    "avariassi": "avariare",
    "avariassimo": "avariare",
    "avariaste": "avariare",
    "avariasti": "avariare",
    "avariata": "avariare",
    "avariate": "avariare",
    "avariati": "avariare",
    "avariato": "avariare",
    "avariava": "avariare",
    "avariavamo": "avariare",
    "avariavan": "avariare",
    "avariavano": "avariare",
    "avariavate": "avariare",
    "avariavi": "avariare",
    "avariavo": "avariare",
    "avarie": "avaria",
    "avarierai": "avariare",
    "avarieran": "avariare",
    "avarieranno": "avariare",
    "avarierebbe": "avariare",
    "avarierebber": "avariare",
    "avarierebbero": "avariare",
    "avarierei": "avariare",
    "avarieremmo": "avariare",
    "avarieremo": "avariare",
    "avariereste": "avariare",
    "avarieresti": "avariare",
    "avarierete": "avariare",
    "avarierà": "avariare",
    "avarierò": "avariare",
    "avarin": "avariare",
    "avarino": "avariare",
    "avario": "avariare",
    "avarizie": "avarizia",
    "avariò": "avariare",
    "avella": "avellere",
    "avellan": "avellere",
    "avellano": "avellere",
    "avelle": "avellere",
    "avellei": "avellere",
    "avellemmo": "avellere",
    "avellendo": "avellere",
    "avellente": "avellere",
    "avellenti": "avellere",
    "aveller": "avellere",
    "avellerai": "avellere",
    "avelleran": "avellere",
    "avelleranno": "avellere",
    "avellerebbe": "avellere",
    "avellerebber": "avellere",
    "avellerebbero": "avellere",
    "avellerei": "avellere",
    "avelleremmo": "avellere",
    "avelleremo": "avellere",
    "avellereste": "avellere",
    "avelleresti": "avellere",
    "avellerete": "avellere",
    "avelleron": "avellere",
    "avellerono": "avellere",
    "avellerà": "avellere",
    "avellerò": "avellere",
    "avellesse": "avellere",
    "avellesser": "avellere",
    "avellessero": "avellere",
    "avellessi": "avellere",
    "avellessimo": "avellere",
    "avelleste": "avellere",
    "avellesti": "avellere",
    "avellete": "avellere",
    "avelleva": "avellere",
    "avellevamo": "avellere",
    "avellevan": "avellere",
    "avellevano": "avellere",
    "avellevate": "avellere",
    "avellevi": "avellere",
    "avellevo": "avellere",
    "avelli": "avellere",
    "avelliamo": "avellere",
    "avelliate": "avellere",
    "avello": "avellere",
    "avellon": "avellere",
    "avellono": "avellere",
    "avelluta": "avellere",
    "avellute": "avellere",
    "avelluti": "avellere",
    "avelluto": "avellere",
    "avellè": "avellere",
    "avemmo": "avere",
    "avendo": "avere",
    "avente": "avere",
    "aventi": "avere",
    "aver": "avere",
    "averi": "avere",
    "avesse": "avere",
    "avesser": "avere",
    "avessero": "avere",
    "avessi": "avere",
    "avessimo": "avere",
    "aveste": "avere",
    "avesti": "avere",
    "avete": "avere",
    "aveva": "avere",
    "avevamo": "avere",
    "avevan": "avere",
    "avevano": "avere",
    "avevate": "avere",
    "avevi": "avere",
    "avevo": "avere",
    "avi": "avo",
    "aviatori": "aviatore",
    "aviazioni": "aviazione",
    "avida": "avido",
    "avide": "avido",
    "avidi": "avido",
    "avieri": "aviere",
    "aviogetti": "aviogetto",
    "aviomotoristica": "aviomotoristico",
    "aviomotoristiche": "aviomotoristico",
    "aviomotoristici": "aviomotoristico",
    "avocazioni": "avocazione",
    "avori": "avorio",
    "avrai": "avere",
    "avran": "avere",
    "avranno": "avere",
    "avrebbe": "avere",
    "avrebber": "avere",
    "avrebbero": "avere",
    "avrei": "avere",
    "avremmo": "avere",
    "avremo": "avere",
    "avreste": "avere",
    "avresti": "avere",
    "avrete": "avere",
    "avrà": "avere",
    "avrò": "avere",
    "avuta": "avere",
    "avute": "avere",
    "avuti": "avere",
    "avuto": "avere",
    "avvale": "avvalere",
    "avvalemmo": "avvalere",
    "avvalendo": "avvalere",
    "avvaler": "avvalere",
    "avvalesse": "avvalere",
    "avvalesser": "avvalere",
    "avvalessero": "avvalere",
    "avvalessi": "avvalere",
    "avvalessimo": "avvalere",
    "avvaleste": "avvalere",
    "avvalesti": "avvalere",
    "avvalete": "avvalere",
    "avvaleva": "avvalere",
    "avvalevamo": "avvalere",
    "avvalevan": "avvalere",
    "avvalevano": "avvalere",
    "avvalevate": "avvalere",
    "avvalevi": "avvalere",
    "avvalevo": "avvalere",
    "avvalga": "avvalere",
    "avvalgan": "avvalere",
    "avvalgano": "avvalere",
    "avvalgo": "avvalere",
    "avvalgon": "avvalere",
    "avvalgono": "avvalere",
    "avvali": "avvalere",
    "avvaliamo": "avvalere",
    "avvaliate": "avvalere",
    "avvalla": "avvallare",
    "avvallai": "avvallare",
    "avvallamenti": "avvallamento",
    "avvallammo": "avvallare",
    "avvallan": "avvallare",
    "avvallando": "avvallare",
    "avvallano": "avvallare",
    "avvallante": "avvallare",
    "avvallanti": "avvallare",
    "avvallar": "avvallare",
    "avvallaron": "avvallare",
    "avvallarono": "avvallare",
    "avvallasse": "avvallare",
    "avvallasser": "avvallare",
    "avvallassero": "avvallare",
    "avvallassi": "avvallare",
    "avvallassimo": "avvallare",
    "avvallaste": "avvallare",
    "avvallasti": "avvallare",
    "avvallata": "avvallare",
    "avvallate": "avvallare",
    "avvallati": "avvallare",
    "avvallato": "avvallare",
    "avvallava": "avvallare",
    "avvallavamo": "avvallare",
    "avvallavan": "avvallare",
    "avvallavano": "avvallare",
    "avvallavate": "avvallare",
    "avvallavi": "avvallare",
    "avvallavo": "avvallare",
    "avvallerai": "avvallare",
    "avvalleran": "avvallare",
    "avvalleranno": "avvallare",
    "avvallerebbe": "avvallare",
    "avvallerebber": "avvallare",
    "avvallerebbero": "avvallare",
    "avvallerei": "avvallare",
    "avvalleremmo": "avvallare",
    "avvalleremo": "avvallare",
    "avvallereste": "avvallare",
    "avvalleresti": "avvallare",
    "avvallerete": "avvallare",
    "avvallerà": "avvallare",
    "avvallerò": "avvallare",
    "avvalli": "avvallare",
    "avvalliamo": "avvallare",
    "avvalliate": "avvallare",
    "avvallin": "avvallare",
    "avvallino": "avvallare",
    "avvallo": "avvallare",
    "avvallò": "avvallare",
    "avvalora": "avvalorare",
    "avvalorai": "avvalorare",
    "avvalorammo": "avvalorare",
    "avvaloran": "avvalorare",
    "avvalorando": "avvalorare",
    "avvalorano": "avvalorare",
    "avvalorante": "avvalorare",
    "avvaloranti": "avvalorare",
    "avvalorar": "avvalorare",
    "avvaloraron": "avvalorare",
    "avvalorarono": "avvalorare",
    "avvalorasse": "avvalorare",
    "avvalorasser": "avvalorare",
    "avvalorassero": "avvalorare",
    "avvalorassi": "avvalorare",
    "avvalorassimo": "avvalorare",
    "avvaloraste": "avvalorare",
    "avvalorasti": "avvalorare",
    "avvalorata": "avvalorare",
    "avvalorate": "avvalorare",
    "avvalorati": "avvalorare",
    "avvalorato": "avvalorare",
    "avvalorava": "avvalorare",
    "avvaloravamo": "avvalorare",
    "avvaloravan": "avvalorare",
    "avvaloravano": "avvalorare",
    "avvaloravate": "avvalorare",
    "avvaloravi": "avvalorare",
    "avvaloravo": "avvalorare",
    "avvalorerai": "avvalorare",
    "avvaloreran": "avvalorare",
    "avvaloreranno": "avvalorare",
    "avvalorerebbe": "avvalorare",
    "avvalorerebber": "avvalorare",
    "avvalorerebbero": "avvalorare",
    "avvalorerei": "avvalorare",
    "avvaloreremmo": "avvalorare",
    "avvaloreremo": "avvalorare",
    "avvalorereste": "avvalorare",
    "avvaloreresti": "avvalorare",
    "avvalorerete": "avvalorare",
    "avvalorerà": "avvalorare",
    "avvalorerò": "avvalorare",
    "avvalori": "avvalorare",
    "avvaloriamo": "avvalorare",
    "avvaloriate": "avvalorare",
    "avvalorin": "avvalorare",
    "avvalorino": "avvalorare",
    "avvaloro": "avvalorare",
    "avvalorò": "avvalorare",
    "avvalsa": "avvalere",
    "avvalse": "avvalere",
    "avvalser": "avvalere",
    "avvalsero": "avvalere",
    "avvalsi": "avvalere",
    "avvalso": "avvalere",
    "avvampa": "avvampare",
    "avvampai": "avvampare",
    "avvampammo": "avvampare",
    "avvampan": "avvampare",
    "avvampando": "avvampare",
    "avvampano": "avvampare",
    "avvampante": "avvampare",
    "avvampanti": "avvampare",
    "avvampar": "avvampare",
    "avvamparon": "avvampare",
    "avvamparono": "avvampare",
    "avvampasse": "avvampare",
    "avvampasser": "avvampare",
    "avvampassero": "avvampare",
    "avvampassi": "avvampare",
    "avvampassimo": "avvampare",
    "avvampaste": "avvampare",
    "avvampasti": "avvampare",
    "avvampata": "avvampare",
    "avvampate": "avvampare",
    "avvampati": "avvampare",
    "avvampato": "avvampare",
    "avvampava": "avvampare",
    "avvampavamo": "avvampare",
    "avvampavan": "avvampare",
    "avvampavano": "avvampare",
    "avvampavate": "avvampare",
    "avvampavi": "avvampare",
    "avvampavo": "avvampare",
    "avvamperai": "avvampare",
    "avvamperan": "avvampare",
    "avvamperanno": "avvampare",
    "avvamperebbe": "avvampare",
    "avvamperebber": "avvampare",
    "avvamperebbero": "avvampare",
    "avvamperei": "avvampare",
    "avvamperemmo": "avvampare",
    "avvamperemo": "avvampare",
    "avvampereste": "avvampare",
    "avvamperesti": "avvampare",
    "avvamperete": "avvampare",
    "avvamperà": "avvampare",
    "avvamperò": "avvampare",
    "avvampi": "avvampare",
    "avvampiamo": "avvampare",
    "avvampiate": "avvampare",
    "avvampin": "avvampare",
    "avvampino": "avvampare",
    "avvampo": "avvampare",
    "avvampò": "avvampare",
    "avvantaggerai": "avvantaggiare",
    "avvantaggeran": "avvantaggiare",
    "avvantaggeranno": "avvantaggiare",
    "avvantaggerebbe": "avvantaggiare",
    "avvantaggerebber": "avvantaggiare",
    "avvantaggerebbero": "avvantaggiare",
    "avvantaggerei": "avvantaggiare",
    "avvantaggeremmo": "avvantaggiare",
    "avvantaggeremo": "avvantaggiare",
    "avvantaggereste": "avvantaggiare",
    "avvantaggeresti": "avvantaggiare",
    "avvantaggerete": "avvantaggiare",
    "avvantaggerà": "avvantaggiare",
    "avvantaggerò": "avvantaggiare",
    "avvantaggi": "avvantaggiare",
    "avvantaggia": "avvantaggiare",
    "avvantaggiai": "avvantaggiare",
    "avvantaggiammo": "avvantaggiare",
    "avvantaggiamo": "avvantaggiare",
    "avvantaggian": "avvantaggiare",
    "avvantaggiando": "avvantaggiare",
    "avvantaggiano": "avvantaggiare",
    "avvantaggiante": "avvantaggiare",
    "avvantaggianti": "avvantaggiare",
    "avvantaggiar": "avvantaggiare",
    "avvantaggiaron": "avvantaggiare",
    "avvantaggiarono": "avvantaggiare",
    "avvantaggiasse": "avvantaggiare",
    "avvantaggiasser": "avvantaggiare",
    "avvantaggiassero": "avvantaggiare",
    "avvantaggiassi": "avvantaggiare",
    "avvantaggiassimo": "avvantaggiare",
    "avvantaggiaste": "avvantaggiare",
    "avvantaggiasti": "avvantaggiare",
    "avvantaggiata": "avvantaggiare",
    "avvantaggiate": "avvantaggiare",
    "avvantaggiati": "avvantaggiare",
    "avvantaggiato": "avvantaggiare",
    "avvantaggiava": "avvantaggiare",
    "avvantaggiavamo": "avvantaggiare",
    "avvantaggiavan": "avvantaggiare",
    "avvantaggiavano": "avvantaggiare",
    "avvantaggiavate": "avvantaggiare",
    "avvantaggiavi": "avvantaggiare",
    "avvantaggiavo": "avvantaggiare",
    "avvantaggin": "avvantaggiare",
    "avvantaggino": "avvantaggiare",
    "avvantaggio": "avvantaggiare",
    "avvantaggiò": "avvantaggiare",
    "avvarrai": "avvalere",
    "avvarran": "avvalere",
    "avvarranno": "avvalere",
    "avvarrebbe": "avvalere",
    "avvarrebber": "avvalere",
    "avvarrebbero": "avvalere",
    "avvarrei": "avvalere",
    "avvarremmo": "avvalere",
    "avvarremo": "avvalere",
    "avvarreste": "avvalere",
    "avvarresti": "avvalere",
    "avvarrete": "avvalere",
    "avvarrà": "avvalere",
    "avvarrò": "avvalere",
    "avveda": "avvedere",
    "avvedan": "avvedere",
    "avvedano": "avvedere",
    "avvede": "avvedere",
    "avvedemmo": "avvedere",
    "avvedendo": "avvedere",
    "avveder": "avvedere",
    "avvedesse": "avvedere",
    "avvedesser": "avvedere",
    "avvedessero": "avvedere",
    "avvedessi": "avvedere",
    "avvedessimo": "avvedere",
    "avvedeste": "avvedere",
    "avvedesti": "avvedere",
    "avvedete": "avvedere",
    "avvedeva": "avvedere",
    "avvedevamo": "avvedere",
    "avvedevan": "avvedere",
    "avvedevano": "avvedere",
    "avvedevate": "avvedere",
    "avvedevi": "avvedere",
    "avvedevo": "avvedere",
    "avvedi": "avvedere",
    "avvediamo": "avvedere",
    "avvediate": "avvedere",
    "avvedo": "avvedere",
    "avvedon": "avvedere",
    "avvedono": "avvedere",
    "avvedrai": "avvedere",
    "avvedran": "avvedere",
    "avvedranno": "avvedere",
    "avvedrebbe": "avvedere",
    "avvedrebber": "avvedere",
    "avvedrebbero": "avvedere",
    "avvedrei": "avvedere",
    "avvedremmo": "avvedere",
    "avvedremo": "avvedere",
    "avvedreste": "avvedere",
    "avvedresti": "avvedere",
    "avvedrete": "avvedere",
    "avvedrà": "avvedere",
    "avvedrò": "avvedere",
    "avveduta": "avvedere",
    "avvedute": "avvedere",
    "avveduti": "avvedere",
    "avveduto": "avvedere",
    "avvelena": "avvelenare",
    "avvelenai": "avvelenare",
    "avvelenamenti": "avvelenamento",
    "avvelenammo": "avvelenare",
    "avvelenan": "avvelenare",
    "avvelenando": "avvelenare",
    "avvelenano": "avvelenare",
    "avvelenante": "avvelenare",
    "avvelenanti": "avvelenare",
    "avvelenar": "avvelenare",
    "avvelenaron": "avvelenare",
    "avvelenarono": "avvelenare",
    "avvelenasse": "avvelenare",
    "avvelenasser": "avvelenare",
    "avvelenassero": "avvelenare",
    "avvelenassi": "avvelenare",
    "avvelenassimo": "avvelenare",
    "avvelenaste": "avvelenare",
    "avvelenasti": "avvelenare",
    "avvelenata": "avvelenare",
    "avvelenate": "avvelenare",
    "avvelenati": "avvelenare",
    "avvelenato": "avvelenare",
    "avvelenatori": "avvelenatore",
    "avvelenava": "avvelenare",
    "avvelenavamo": "avvelenare",
    "avvelenavan": "avvelenare",
    "avvelenavano": "avvelenare",
    "avvelenavate": "avvelenare",
    "avvelenavi": "avvelenare",
    "avvelenavo": "avvelenare",
    "avvelenerai": "avvelenare",
    "avveleneran": "avvelenare",
    "avveleneranno": "avvelenare",
    "avvelenerebbe": "avvelenare",
    "avvelenerebber": "avvelenare",
    "avvelenerebbero": "avvelenare",
    "avvelenerei": "avvelenare",
    "avveleneremmo": "avvelenare",
    "avveleneremo": "avvelenare",
    "avvelenereste": "avvelenare",
    "avveleneresti": "avvelenare",
    "avvelenerete": "avvelenare",
    "avvelenerà": "avvelenare",
    "avvelenerò": "avvelenare",
    "avveleni": "avvelenare",
    "avveleniamo": "avvelenare",
    "avveleniate": "avvelenare",
    "avvelenin": "avvelenare",
    "avvelenino": "avvelenare",
    "avveleno": "avvelenare",
    "avvelenò": "avvelenare",
    "avvenendo": "avvenire",
    "avvenente": "avvenire",
    "avvenenti": "avvenire",
    "avvenenze": "avvenenza",
    "avvenga": "avvenire",
    "avvengan": "avvenire",
    "avvengano": "avvenire",
    "avvengo": "avvenire",
    "avvengon": "avvenire",
    "avvengono": "avvenire",
    "avveniamo": "avvenire",
    "avveniate": "avvenire",
    "avvenimenti": "avvenimento",
    "avvenimmo": "avvenire",
    "avvenir": "avvenire",
    "avveniristica": "avveniristico",
    "avveniristiche": "avveniristico",
    "avveniristici": "avveniristico",
    "avvenisse": "avvenire",
    "avvenisser": "avvenire",
    "avvenissero": "avvenire",
    "avvenissi": "avvenire",
    "avvenissimo": "avvenire",
    "avveniste": "avvenire",
    "avvenisti": "avvenire",
    "avvenite": "avvenire",
    "avveniva": "avvenire",
    "avvenivamo": "avvenire",
    "avvenivan": "avvenire",
    "avvenivano": "avvenire",
    "avvenivate": "avvenire",
    "avvenivi": "avvenire",
    "avvenivo": "avvenire",
    "avvenne": "avvenire",
    "avvenner": "avvenire",
    "avvennero": "avvenire",
    "avvenni": "avvenire",
    "avventa": "avventare",
    "avventai": "avventare",
    "avventammo": "avventare",
    "avventan": "avventare",
    "avventando": "avventare",
    "avventano": "avventare",
    "avventante": "avventare",
    "avventanti": "avventare",
    "avventar": "avventare",
    "avventaron": "avventare",
    "avventarono": "avventare",
    "avventasse": "avventare",
    "avventasser": "avventare",
    "avventassero": "avventare",
    "avventassi": "avventare",
    "avventassimo": "avventare",
    "avventaste": "avventare",
    "avventasti": "avventare",
    "avventata": "avventato",
    "avventate": "avventato",
    "avventati": "avventato",
    "avventato": "avventare",
    "avventava": "avventare",
    "avventavamo": "avventare",
    "avventavan": "avventare",
    "avventavano": "avventare",
    "avventavate": "avventare",
    "avventavi": "avventare",
    "avventavo": "avventare",
    "avventerai": "avventare",
    "avventeran": "avventare",
    "avventeranno": "avventare",
    "avventerebbe": "avventare",
    "avventerebber": "avventare",
    "avventerebbero": "avventare",
    "avventerei": "avventare",
    "avventeremmo": "avventare",
    "avventeremo": "avventare",
    "avventereste": "avventare",
    "avventeresti": "avventare",
    "avventerete": "avventare",
    "avventerà": "avventare",
    "avventerò": "avventare",
    "avventi": "avvento",
    "avventiamo": "avventare",
    "avventiate": "avventare",
    "avventin": "avventare",
    "avventino": "avventare",
    "avvento": "avventare",
    "avventori": "avventore",
    "avventura": "avventurare",
    "avventurai": "avventurare",
    "avventurammo": "avventurare",
    "avventuran": "avventurare",
    "avventurando": "avventurare",
    "avventurano": "avventurare",
    "avventurante": "avventurare",
    "avventuranti": "avventurare",
    "avventurar": "avventurare",
    "avventuraron": "avventurare",
    "avventurarono": "avventurare",
    "avventurasse": "avventurare",
    "avventurasser": "avventurare",
    "avventurassero": "avventurare",
    "avventurassi": "avventurare",
    "avventurassimo": "avventurare",
    "avventuraste": "avventurare",
    "avventurasti": "avventurare",
    "avventurata": "avventurare",
    "avventurate": "avventurare",
    "avventurati": "avventurare",
    "avventurato": "avventurare",
    "avventurava": "avventurare",
    "avventuravamo": "avventurare",
    "avventuravan": "avventurare",
    "avventuravano": "avventurare",
    "avventuravate": "avventurare",
    "avventuravi": "avventurare",
    "avventuravo": "avventurare",
    "avventure": "avventura",
    "avventurerai": "avventurare",
    "avventureran": "avventurare",
    "avventureranno": "avventurare",
    "avventurerebbe": "avventurare",
    "avventurerebber": "avventurare",
    "avventurerebbero": "avventurare",
    "avventurerei": "avventurare",
    "avventureremmo": "avventurare",
    "avventureremo": "avventurare",
    "avventurereste": "avventurare",
    "avventureresti": "avventurare",
    "avventurerete": "avventurare",
    "avventurerà": "avventurare",
    "avventurerò": "avventurare",
    "avventuri": "avventurare",
    "avventuriamo": "avventurare",
    "avventuriate": "avventurare",
    "avventurieri": "avventuriero",
    "avventurin": "avventurare",
    "avventurino": "avventurare",
    "avventurismi": "avventurismo",
    "avventuro": "avventurare",
    "avventurosa": "avventuroso",
    "avventurose": "avventuroso",
    "avventurosi": "avventuroso",
    "avventurò": "avventurare",
    "avventò": "avventare",
    "avvenuta": "avvenire",
    "avvenute": "avvenire",
    "avvenuti": "avvenire",
    "avvenuto": "avvenire",
    "avvera": "avverare",
    "avverai": "avverare",
    "avverammo": "avverare",
    "avveran": "avverare",
    "avverando": "avverare",
    "avverano": "avverare",
    "avverante": "avverare",
    "avveranti": "avverare",
    "avverar": "avverare",
    "avveraron": "avverare",
    "avverarono": "avverare",
    "avverasse": "avverare",
    "avverasser": "avverare",
    "avverassero": "avverare",
    "avverassi": "avverare",
    "avverassimo": "avverare",
    "avveraste": "avverare",
    "avverasti": "avverare",
    "avverata": "avverare",
    "avverate": "avverare",
    "avverati": "avverare",
    "avverato": "avverare",
    "avverava": "avverare",
    "avveravamo": "avverare",
    "avveravan": "avverare",
    "avveravano": "avverare",
    "avveravate": "avverare",
    "avveravi": "avverare",
    "avveravo": "avverare",
    "avverbi": "avverbio",
    "avvererai": "avverare",
    "avvereran": "avverare",
    "avvereranno": "avverare",
    "avvererebbe": "avverare",
    "avvererebber": "avverare",
    "avvererebbero": "avverare",
    "avvererei": "avverare",
    "avvereremmo": "avverare",
    "avvereremo": "avverare",
    "avverereste": "avverare",
    "avvereresti": "avverare",
    "avvererete": "avverare",
    "avvererà": "avverare",
    "avvererò": "avverare",
    "avveri": "avverare",
    "avveriamo": "avverare",
    "avveriate": "avverare",
    "avverin": "avverare",
    "avverino": "avverare",
    "avvero": "avverare",
    "avverrai": "avvenire",
    "avverran": "avvenire",
    "avverranno": "avvenire",
    "avverrebbe": "avvenire",
    "avverrebber": "avvenire",
    "avverrebbero": "avvenire",
    "avverrei": "avvenire",
    "avverremmo": "avvenire",
    "avverremo": "avvenire",
    "avverreste": "avvenire",
    "avverresti": "avvenire",
    "avverrete": "avvenire",
    "avverrà": "avvenire",
    "avverrò": "avvenire",
    "avversa": "avversare",
    "avversai": "avversare",
    "avversammo": "avversare",
    "avversan": "avversare",
    "avversando": "avversare",
    "avversano": "avversare",
    "avversante": "avversare",
    "avversanti": "avversare",
    "avversar": "avversare",
    "avversari": "avversario",
    "avversarie": "avversaria",
    "avversaron": "avversare",
    "avversarono": "avversare",
    "avversasse": "avversare",
    "avversasser": "avversare",
    "avversassero": "avversare",
    "avversassi": "avversare",
    "avversassimo": "avversare",
    "avversaste": "avversare",
    "avversasti": "avversare",
    "avversata": "avversare",
    "avversate": "avversare",
    "avversati": "avversare",
    "avversato": "avversare",
    "avversava": "avversare",
    "avversavamo": "avversare",
    "avversavan": "avversare",
    "avversavano": "avversare",
    "avversavate": "avversare",
    "avversavi": "avversare",
    "avversavo": "avversare",
    "avverserai": "avversare",
    "avverseran": "avversare",
    "avverseranno": "avversare",
    "avverserebbe": "avversare",
    "avverserebber": "avversare",
    "avverserebbero": "avversare",
    "avverserei": "avversare",
    "avverseremmo": "avversare",
    "avverseremo": "avversare",
    "avversereste": "avversare",
    "avverseresti": "avversare",
    "avverserete": "avversare",
    "avverserà": "avversare",
    "avverserò": "avversare",
    "avversi": "avversare",
    "avversiamo": "avversare",
    "avversiate": "avversare",
    "avversin": "avversare",
    "avversino": "avversare",
    "avversioni": "avversione",
    "avverso": "avversare",
    "avversò": "avversare",
    "avverta": "avvertire",
    "avvertan": "avvertire",
    "avvertano": "avvertire",
    "avverte": "avvertire",
    "avvertendo": "avvertire",
    "avvertente": "avvertire",
    "avvertenti": "avvertire",
    "avvertenze": "avvertenza",
    "avverti": "avvertire",
    "avvertiamo": "avvertire",
    "avvertiate": "avvertire",
    "avvertibili": "avvertibile",
    "avvertii": "avvertire",
    "avvertimenti": "avvertimento",
    "avvertimmo": "avvertire",
    "avvertir": "avvertire",
    "avvertirai": "avvertire",
    "avvertiran": "avvertire",
    "avvertiranno": "avvertire",
    "avvertirebbe": "avvertire",
    "avvertirebber": "avvertire",
    "avvertirebbero": "avvertire",
    "avvertirei": "avvertire",
    "avvertiremmo": "avvertire",
    "avvertiremo": "avvertire",
    "avvertireste": "avvertire",
    "avvertiresti": "avvertire",
    "avvertirete": "avvertire",
    "avvertiron": "avvertire",
    "avvertirono": "avvertire",
    "avvertirà": "avvertire",
    "avvertirò": "avvertire",
    "avvertisse": "avvertire",
    "avvertisser": "avvertire",
    "avvertissero": "avvertire",
    "avvertissi": "avvertire",
    "avvertissimo": "avvertire",
    "avvertiste": "avvertire",
    "avvertisti": "avvertire",
    "avvertita": "avvertire",
    "avvertite": "avvertire",
    "avvertiti": "avvertire",
    "avvertito": "avvertire",
    "avvertiva": "avvertire",
    "avvertivamo": "avvertire",
    "avvertivan": "avvertire",
    "avvertivano": "avvertire",
    "avvertivate": "avvertire",
    "avvertivi": "avvertire",
    "avvertivo": "avvertire",
    "avverto": "avvertire",
    "avverton": "avvertire",
    "avvertono": "avvertire",
    "avvertì": "avvertire",
    "avverò": "avverare",
    "avvezza": "avvezzare",
    "avvezzai": "avvezzare",
    "avvezzammo": "avvezzare",
    "avvezzan": "avvezzare",
    "avvezzando": "avvezzare",
    "avvezzano": "avvezzare",
    "avvezzante": "avvezzare",
    "avvezzanti": "avvezzare",
    "avvezzar": "avvezzare",
    "avvezzaron": "avvezzare",
    "avvezzarono": "avvezzare",
    "avvezzasse": "avvezzare",
    "avvezzasser": "avvezzare",
    "avvezzassero": "avvezzare",
    "avvezzassi": "avvezzare",
    "avvezzassimo": "avvezzare",
    "avvezzaste": "avvezzare",
    "avvezzasti": "avvezzare",
    "avvezzata": "avvezzare",
    "avvezzate": "avvezzare",
    "avvezzati": "avvezzare",
    "avvezzato": "avvezzare",
    "avvezzava": "avvezzare",
    "avvezzavamo": "avvezzare",
    "avvezzavan": "avvezzare",
    "avvezzavano": "avvezzare",
    "avvezzavate": "avvezzare",
    "avvezzavi": "avvezzare",
    "avvezzavo": "avvezzare",
    "avvezzerai": "avvezzare",
    "avvezzeran": "avvezzare",
    "avvezzeranno": "avvezzare",
    "avvezzerebbe": "avvezzare",
    "avvezzerebber": "avvezzare",
    "avvezzerebbero": "avvezzare",
    "avvezzerei": "avvezzare",
    "avvezzeremmo": "avvezzare",
    "avvezzeremo": "avvezzare",
    "avvezzereste": "avvezzare",
    "avvezzeresti": "avvezzare",
    "avvezzerete": "avvezzare",
    "avvezzerà": "avvezzare",
    "avvezzerò": "avvezzare",
    "avvezzi": "avvezzare",
    "avvezziamo": "avvezzare",
    "avvezziate": "avvezzare",
    "avvezzin": "avvezzare",
    "avvezzino": "avvezzare",
    "avvezzo": "avvezzare",
    "avvezzò": "avvezzare",
    "avvia": "avviare",
    "avviai": "avviare",
    "avviamenti": "avviamento",
    "avviammo": "avviare",
    "avviamo": "avviare",
    "avvian": "avviare",
    "avviando": "avviare",
    "avviano": "avviare",
    "avviante": "avviare",
    "avvianti": "avviare",
    "avviar": "avviare",
    "avviaron": "avviare",
    "avviarono": "avviare",
    "avviasse": "avviare",
    "avviasser": "avviare",
    "avviassero": "avviare",
    "avviassi": "avviare",
    "avviassimo": "avviare",
    "avviaste": "avviare",
    "avviasti": "avviare",
    "avviata": "avviato",
    "avviate": "avviato",
    "avviati": "avviato",
    "avviato": "avviare",
    "avviava": "avviare",
    "avviavamo": "avviare",
    "avviavan": "avviare",
    "avviavano": "avviare",
    "avviavate": "avviare",
    "avviavi": "avviare",
    "avviavo": "avviare",
    "avvicenda": "avvicendare",
    "avvicendai": "avvicendare",
    "avvicendamenti": "avvicendamento",
    "avvicendammo": "avvicendare",
    "avvicendan": "avvicendare",
    "avvicendando": "avvicendare",
    "avvicendano": "avvicendare",
    "avvicendante": "avvicendare",
    "avvicendanti": "avvicendare",
    "avvicendar": "avvicendare",
    "avvicendaron": "avvicendare",
    "avvicendarono": "avvicendare",
    "avvicendasse": "avvicendare",
    "avvicendasser": "avvicendare",
    "avvicendassero": "avvicendare",
    "avvicendassi": "avvicendare",
    "avvicendassimo": "avvicendare",
    "avvicendaste": "avvicendare",
    "avvicendasti": "avvicendare",
    "avvicendata": "avvicendare",
    "avvicendate": "avvicendare",
    "avvicendati": "avvicendare",
    "avvicendato": "avvicendare",
    "avvicendava": "avvicendare",
    "avvicendavamo": "avvicendare",
    "avvicendavan": "avvicendare",
    "avvicendavano": "avvicendare",
    "avvicendavate": "avvicendare",
    "avvicendavi": "avvicendare",
    "avvicendavo": "avvicendare",
    "avvicenderai": "avvicendare",
    "avvicenderan": "avvicendare",
    "avvicenderanno": "avvicendare",
    "avvicenderebbe": "avvicendare",
    "avvicenderebber": "avvicendare",
    "avvicenderebbero": "avvicendare",
    "avvicenderei": "avvicendare",
    "avvicenderemmo": "avvicendare",
    "avvicenderemo": "avvicendare",
    "avvicendereste": "avvicendare",
    "avvicenderesti": "avvicendare",
    "avvicenderete": "avvicendare",
    "avvicenderà": "avvicendare",
    "avvicenderò": "avvicendare",
    "avvicendi": "avvicendare",
    "avvicendiamo": "avvicendare",
    "avvicendiate": "avvicendare",
    "avvicendin": "avvicendare",
    "avvicendino": "avvicendare",
    "avvicendo": "avvicendare",
    "avvicendò": "avvicendare",
    "avvicina": "avvicinare",
    "avvicinabili": "avvicinabile",
    "avvicinai": "avvicinare",
    "avvicinamenti": "avvicinamento",
    "avvicinammo": "avvicinare",
    "avvicinan": "avvicinare",
    "avvicinando": "avvicinare",
    "avvicinano": "avvicinare",
    "avvicinante": "avvicinare",
    "avvicinanti": "avvicinare",
    "avvicinar": "avvicinare",
    "avvicinaron": "avvicinare",
    "avvicinarono": "avvicinare",
    "avvicinasse": "avvicinare",
    "avvicinasser": "avvicinare",
    "avvicinassero": "avvicinare",
    "avvicinassi": "avvicinare",
    "avvicinassimo": "avvicinare",
    "avvicinaste": "avvicinare",
    "avvicinasti": "avvicinare",
    "avvicinata": "avvicinare",
    "avvicinate": "avvicinare",
    "avvicinati": "avvicinare",
    "avvicinato": "avvicinare",
    "avvicinava": "avvicinare",
    "avvicinavamo": "avvicinare",
    "avvicinavan": "avvicinare",
    "avvicinavano": "avvicinare",
    "avvicinavate": "avvicinare",
    "avvicinavi": "avvicinare",
    "avvicinavo": "avvicinare",
    "avvicinerai": "avvicinare",
    "avvicineran": "avvicinare",
    "avvicineranno": "avvicinare",
    "avvicinerebbe": "avvicinare",
    "avvicinerebber": "avvicinare",
    "avvicinerebbero": "avvicinare",
    "avvicinerei": "avvicinare",
    "avvicineremmo": "avvicinare",
    "avvicineremo": "avvicinare",
    "avvicinereste": "avvicinare",
    "avvicineresti": "avvicinare",
    "avvicinerete": "avvicinare",
    "avvicinerà": "avvicinare",
    "avvicinerò": "avvicinare",
    "avvicini": "avvicinare",
    "avviciniamo": "avvicinare",
    "avviciniate": "avvicinare",
    "avvicinin": "avvicinare",
    "avvicinino": "avvicinare",
    "avvicino": "avvicinare",
    "avvicinò": "avvicinare",
    "avvide": "avvedere",
    "avvider": "avvedere",
    "avvidero": "avvedere",
    "avvidi": "avvedere",
    "avviene": "avvenire",
    "avvieni": "avvenire",
    "avvierai": "avviare",
    "avvieran": "avviare",
    "avvieranno": "avviare",
    "avvierebbe": "avviare",
    "avvierebber": "avviare",
    "avvierebbero": "avviare",
    "avvierei": "avviare",
    "avvieremmo": "avviare",
    "avvieremo": "avviare",
    "avviereste": "avviare",
    "avvieresti": "avviare",
    "avvierete": "avviare",
    "avvierà": "avviare",
    "avvierò": "avviare",
    "avvii": "avvio",
    "avviin": "avviare",
    "avviino": "avviare",
    "avvilendo": "avvilire",
    "avvilente": "avvilire",
    "avvilenti": "avvilire",
    "avviliamo": "avvilire",
    "avviliate": "avvilire",
    "avvilii": "avvilire",
    "avvilimenti": "avvilimento",
    "avvilimmo": "avvilire",
    "avvilir": "avvilire",
    "avvilirai": "avvilire",
    "avviliran": "avvilire",
    "avviliranno": "avvilire",
    "avvilirebbe": "avvilire",
    "avvilirebber": "avvilire",
    "avvilirebbero": "avvilire",
    "avvilirei": "avvilire",
    "avviliremmo": "avvilire",
    "avviliremo": "avvilire",
    "avvilireste": "avvilire",
    "avviliresti": "avvilire",
    "avvilirete": "avvilire",
    "avviliron": "avvilire",
    "avvilirono": "avvilire",
    "avvilirà": "avvilire",
    "avvilirò": "avvilire",
    "avvilisca": "avvilire",
    "avviliscan": "avvilire",
    "avviliscano": "avvilire",
    "avvilisce": "avvilire",
    "avvilisci": "avvilire",
    "avvilisco": "avvilire",
    "avviliscon": "avvilire",
    "avviliscono": "avvilire",
    "avvilisse": "avvilire",
    "avvilisser": "avvilire",
    "avvilissero": "avvilire",
    "avvilissi": "avvilire",
    "avvilissimo": "avvilire",
    "avviliste": "avvilire",
    "avvilisti": "avvilire",
    "avvilita": "avvilire",
    "avvilite": "avvilire",
    "avviliti": "avvilire",
    "avvilito": "avvilire",
    "avviliva": "avvilire",
    "avvilivamo": "avvilire",
    "avvilivan": "avvilire",
    "avvilivano": "avvilire",
    "avvilivate": "avvilire",
    "avvilivi": "avvilire",
    "avvilivo": "avvilire",
    "avviluppa": "avviluppare",
    "avviluppai": "avviluppare",
    "avviluppammo": "avviluppare",
    "avviluppan": "avviluppare",
    "avviluppando": "avviluppare",
    "avviluppano": "avviluppare",
    "avviluppante": "avviluppare",
    "avviluppanti": "avviluppare",
    "avviluppar": "avviluppare",
    "avvilupparon": "avviluppare",
    "avvilupparono": "avviluppare",
    "avviluppasse": "avviluppare",
    "avviluppasser": "avviluppare",
    "avviluppassero": "avviluppare",
    "avviluppassi": "avviluppare",
    "avviluppassimo": "avviluppare",
    "avviluppaste": "avviluppare",
    "avviluppasti": "avviluppare",
    "avviluppata": "avviluppare",
    "avviluppate": "avviluppare",
    "avviluppati": "avviluppare",
    "avviluppato": "avviluppare",
    "avviluppava": "avviluppare",
    "avviluppavamo": "avviluppare",
    "avviluppavan": "avviluppare",
    "avviluppavano": "avviluppare",
    "avviluppavate": "avviluppare",
    "avviluppavi": "avviluppare",
    "avviluppavo": "avviluppare",
    "avvilupperai": "avviluppare",
    "avvilupperan": "avviluppare",
    "avvilupperanno": "avviluppare",
    "avvilupperebbe": "avviluppare",
    "avvilupperebber": "avviluppare",
    "avvilupperebbero": "avviluppare",
    "avvilupperei": "avviluppare",
    "avvilupperemmo": "avviluppare",
    "avvilupperemo": "avviluppare",
    "avviluppereste": "avviluppare",
    "avvilupperesti": "avviluppare",
    "avvilupperete": "avviluppare",
    "avvilupperà": "avviluppare",
    "avvilupperò": "avviluppare",
    "avviluppi": "avviluppare",
    "avviluppiamo": "avviluppare",
    "avviluppiate": "avviluppare",
    "avviluppin": "avviluppare",
    "avviluppino": "avviluppare",
    "avviluppo": "avviluppare",
    "avviluppò": "avviluppare",
    "avvilì": "avvilire",
    "avvinca": "avvincere",
    "avvincan": "avvincere",
    "avvincano": "avvincere",
    "avvince": "avvincere",
    "avvincemmo": "avvincere",
    "avvincendo": "avvincere",
    "avvincente": "avvincere",
    "avvincenti": "avvincere",
    "avvincer": "avvincere",
    "avvincerai": "avvincere",
    "avvinceran": "avvincere",
    "avvinceranno": "avvincere",
    "avvincerebbe": "avvincere",
    "avvincerebber": "avvincere",
    "avvincerebbero": "avvincere",
    "avvincerei": "avvincere",
    "avvinceremmo": "avvincere",
    "avvinceremo": "avvincere",
    "avvincereste": "avvincere",
    "avvinceresti": "avvincere",
    "avvincerete": "avvincere",
    "avvincerà": "avvincere",
    "avvincerò": "avvincere",
    "avvincesse": "avvincere",
    "avvincesser": "avvincere",
    "avvincessero": "avvincere",
    "avvincessi": "avvincere",
    "avvincessimo": "avvincere",
    "avvinceste": "avvincere",
    "avvincesti": "avvincere",
    "avvincete": "avvincere",
    "avvinceva": "avvincere",
    "avvincevamo": "avvincere",
    "avvincevan": "avvincere",
    "avvincevano": "avvincere",
    "avvincevate": "avvincere",
    "avvincevi": "avvincere",
    "avvincevo": "avvincere",
    "avvinci": "avvincere",
    "avvinciamo": "avvincere",
    "avvinciate": "avvincere",
    "avvinco": "avvincere",
    "avvincon": "avvincere",
    "avvincono": "avvincere",
    "avvinghi": "avvinghiare",
    "avvinghia": "avvinghiare",
    "avvinghiai": "avvinghiare",
    "avvinghiammo": "avvinghiare",
    "avvinghiamo": "avvinghiare",
    "avvinghian": "avvinghiare",
    "avvinghiando": "avvinghiare",
    "avvinghiano": "avvinghiare",
    "avvinghiante": "avvinghiare",
    "avvinghianti": "avvinghiare",
    "avvinghiar": "avvinghiare",
    "avvinghiaron": "avvinghiare",
    "avvinghiarono": "avvinghiare",
    "avvinghiasse": "avvinghiare",
    "avvinghiasser": "avvinghiare",
    "avvinghiassero": "avvinghiare",
    "avvinghiassi": "avvinghiare",
    "avvinghiassimo": "avvinghiare",
    "avvinghiaste": "avvinghiare",
    "avvinghiasti": "avvinghiare",
    "avvinghiata": "avvinghiare",
    "avvinghiate": "avvinghiare",
    "avvinghiati": "avvinghiare",
    "avvinghiato": "avvinghiare",
    "avvinghiava": "avvinghiare",
    "avvinghiavamo": "avvinghiare",
    "avvinghiavan": "avvinghiare",
    "avvinghiavano": "avvinghiare",
    "avvinghiavate": "avvinghiare",
    "avvinghiavi": "avvinghiare",
    "avvinghiavo": "avvinghiare",
    "avvinghierai": "avvinghiare",
    "avvinghieran": "avvinghiare",
    "avvinghieranno": "avvinghiare",
    "avvinghierebbe": "avvinghiare",
    "avvinghierebber": "avvinghiare",
    "avvinghierebbero": "avvinghiare",
    "avvinghierei": "avvinghiare",
    "avvinghieremmo": "avvinghiare",
    "avvinghieremo": "avvinghiare",
    "avvinghiereste": "avvinghiare",
    "avvinghieresti": "avvinghiare",
    "avvinghierete": "avvinghiare",
    "avvinghierà": "avvinghiare",
    "avvinghierò": "avvinghiare",
    "avvinghin": "avvinghiare",
    "avvinghino": "avvinghiare",
    "avvinghio": "avvinghiare",
    "avvinghiò": "avvinghiare",
    "avvinse": "avvincere",
    "avvinser": "avvincere",
    "avvinsero": "avvincere",
    "avvinsi": "avvincere",
    "avvinta": "avvincere",
    "avvinte": "avvincere",
    "avvinti": "avvincere",
    "avvinto": "avvincere",
    "avvio": "avviare",
    "avvisa": "avvisare",
    "avvisaglie": "avvisaglia",
    "avvisai": "avvisare",
    "avvisammo": "avvisare",
    "avvisan": "avvisare",
    "avvisando": "avvisare",
    "avvisano": "avvisare",
    "avvisante": "avvisare",
    "avvisanti": "avvisare",
    "avvisar": "avvisare",
    "avvisaron": "avvisare",
    "avvisarono": "avvisare",
    "avvisasse": "avvisare",
    "avvisasser": "avvisare",
    "avvisassero": "avvisare",
    "avvisassi": "avvisare",
    "avvisassimo": "avvisare",
    "avvisaste": "avvisare",
    "avvisasti": "avvisare",
    "avvisata": "avvisare",
    "avvisate": "avvisare",
    "avvisati": "avvisare",
    "avvisato": "avvisare",
    "avvisatori": "avvisatore",
    "avvisava": "avvisare",
    "avvisavamo": "avvisare",
    "avvisavan": "avvisare",
    "avvisavano": "avvisare",
    "avvisavate": "avvisare",
    "avvisavi": "avvisare",
    "avvisavo": "avvisare",
    "avviserai": "avvisare",
    "avviseran": "avvisare",
    "avviseranno": "avvisare",
    "avviserebbe": "avvisare",
    "avviserebber": "avvisare",
    "avviserebbero": "avvisare",
    "avviserei": "avvisare",
    "avviseremmo": "avvisare",
    "avviseremo": "avvisare",
    "avvisereste": "avvisare",
    "avviseresti": "avvisare",
    "avviserete": "avvisare",
    "avviserà": "avvisare",
    "avviserò": "avvisare",
    "avvisi": "avviso",
    "avvisiamo": "avvisare",
    "avvisiate": "avvisare",
    "avvisin": "avvisare",
    "avvisino": "avvisare",
    "avviso": "avvisare",
    "avvista": "avvistare",
    "avvistai": "avvistare",
    "avvistamenti": "avvistamento",
    "avvistammo": "avvistare",
    "avvistan": "avvistare",
    "avvistando": "avvistare",
    "avvistano": "avvistare",
    "avvistante": "avvistare",
    "avvistanti": "avvistare",
    "avvistar": "avvistare",
    "avvistaron": "avvistare",
    "avvistarono": "avvistare",
    "avvistasse": "avvistare",
    "avvistasser": "avvistare",
    "avvistassero": "avvistare",
    "avvistassi": "avvistare",
    "avvistassimo": "avvistare",
    "avvistaste": "avvistare",
    "avvistasti": "avvistare",
    "avvistata": "avvistare",
    "avvistate": "avvistare",
    "avvistati": "avvistare",
    "avvistato": "avvistare",
    "avvistava": "avvistare",
    "avvistavamo": "avvistare",
    "avvistavan": "avvistare",
    "avvistavano": "avvistare",
    "avvistavate": "avvistare",
    "avvistavi": "avvistare",
    "avvistavo": "avvistare",
    "avvisterai": "avvistare",
    "avvisteran": "avvistare",
    "avvisteranno": "avvistare",
    "avvisterebbe": "avvistare",
    "avvisterebber": "avvistare",
    "avvisterebbero": "avvistare",
    "avvisterei": "avvistare",
    "avvisteremmo": "avvistare",
    "avvisteremo": "avvistare",
    "avvistereste": "avvistare",
    "avvisteresti": "avvistare",
    "avvisterete": "avvistare",
    "avvisterà": "avvistare",
    "avvisterò": "avvistare",
    "avvisti": "avvistare",
    "avvistiamo": "avvistare",
    "avvistiate": "avvistare",
    "avvistin": "avvistare",
    "avvistino": "avvistare",
    "avvisto": "avvistare",
    "avvistò": "avvistare",
    "avvisò": "avvisare",
    "avvita": "avvitare",
    "avvitai": "avvitare",
    "avvitamenti": "avvitamento",
    "avvitammo": "avvitare",
    "avvitan": "avvitare",
    "avvitando": "avvitare",
    "avvitano": "avvitare",
    "avvitante": "avvitare",
    "avvitanti": "avvitare",
    "avvitar": "avvitare",
    "avvitaron": "avvitare",
    "avvitarono": "avvitare",
    "avvitasse": "avvitare",
    "avvitasser": "avvitare",
    "avvitassero": "avvitare",
    "avvitassi": "avvitare",
    "avvitassimo": "avvitare",
    "avvitaste": "avvitare",
    "avvitasti": "avvitare",
    "avvitata": "avvitare",
    "avvitate": "avvitare",
    "avvitati": "avvitare",
    "avvitato": "avvitare",
    "avvitava": "avvitare",
    "avvitavamo": "avvitare",
    "avvitavan": "avvitare",
    "avvitavano": "avvitare",
    "avvitavate": "avvitare",
    "avvitavi": "avvitare",
    "avvitavo": "avvitare",
    "avviterai": "avvitare",
    "avviteran": "avvitare",
    "avviteranno": "avvitare",
    "avviterebbe": "avvitare",
    "avviterebber": "avvitare",
    "avviterebbero": "avvitare",
    "avviterei": "avvitare",
    "avviteremmo": "avvitare",
    "avviteremo": "avvitare",
    "avvitereste": "avvitare",
    "avviteresti": "avvitare",
    "avviterete": "avvitare",
    "avviterà": "avvitare",
    "avviterò": "avvitare",
    "avviti": "avvitare",
    "avvitiamo": "avvitare",
    "avvitiate": "avvitare",
    "avviticchi": "avviticchiare",
    "avviticchia": "avviticchiare",
    "avviticchiai": "avviticchiare",
    "avviticchiammo": "avviticchiare",
    "avviticchiamo": "avviticchiare",
    "avviticchian": "avviticchiare",
    "avviticchiando": "avviticchiare",
    "avviticchiano": "avviticchiare",
    "avviticchiante": "avviticchiare",
    "avviticchianti": "avviticchiare",
    "avviticchiar": "avviticchiare",
    "avviticchiaron": "avviticchiare",
    "avviticchiarono": "avviticchiare",
    "avviticchiasse": "avviticchiare",
    "avviticchiasser": "avviticchiare",
    "avviticchiassero": "avviticchiare",
    "avviticchiassi": "avviticchiare",
    "avviticchiassimo": "avviticchiare",
    "avviticchiaste": "avviticchiare",
    "avviticchiasti": "avviticchiare",
    "avviticchiata": "avviticchiare",
    "avviticchiate": "avviticchiare",
    "avviticchiati": "avviticchiare",
    "avviticchiato": "avviticchiare",
    "avviticchiava": "avviticchiare",
    "avviticchiavamo": "avviticchiare",
    "avviticchiavan": "avviticchiare",
    "avviticchiavano": "avviticchiare",
    "avviticchiavate": "avviticchiare",
    "avviticchiavi": "avviticchiare",
    "avviticchiavo": "avviticchiare",
    "avviticchierai": "avviticchiare",
    "avviticchieran": "avviticchiare",
    "avviticchieranno": "avviticchiare",
    "avviticchierebbe": "avviticchiare",
    "avviticchierebber": "avviticchiare",
    "avviticchierebbero": "avviticchiare",
    "avviticchierei": "avviticchiare",
    "avviticchieremmo": "avviticchiare",
    "avviticchieremo": "avviticchiare",
    "avviticchiereste": "avviticchiare",
    "avviticchieresti": "avviticchiare",
    "avviticchierete": "avviticchiare",
    "avviticchierà": "avviticchiare",
    "avviticchierò": "avviticchiare",
    "avviticchin": "avviticchiare",
    "avviticchino": "avviticchiare",
    "avviticchio": "avviticchiare",
    "avviticchiò": "avviticchiare",
    "avvitin": "avvitare",
    "avvitino": "avvitare",
    "avvito": "avvitare",
    "avvitò": "avvitare",
    "avviva": "avvivare",
    "avvivai": "avvivare",
    "avvivammo": "avvivare",
    "avvivan": "avvivare",
    "avvivando": "avvivare",
    "avvivano": "avvivare",
    "avvivante": "avvivare",
    "avvivanti": "avvivare",
    "avvivar": "avvivare",
    "avvivaron": "avvivare",
    "avvivarono": "avvivare",
    "avvivasse": "avvivare",
    "avvivasser": "avvivare",
    "avvivassero": "avvivare",
    "avvivassi": "avvivare",
    "avvivassimo": "avvivare",
    "avvivaste": "avvivare",
    "avvivasti": "avvivare",
    "avvivata": "avvivare",
    "avvivate": "avvivare",
    "avvivati": "avvivare",
    "avvivato": "avvivare",
    "avvivava": "avvivare",
    "avvivavamo": "avvivare",
    "avvivavan": "avvivare",
    "avvivavano": "avvivare",
    "avvivavate": "avvivare",
    "avvivavi": "avvivare",
    "avvivavo": "avvivare",
    "avviverai": "avvivare",
    "avviveran": "avvivare",
    "avviveranno": "avvivare",
    "avviverebbe": "avvivare",
    "avviverebber": "avvivare",
    "avviverebbero": "avvivare",
    "avviverei": "avvivare",
    "avviveremmo": "avvivare",
    "avviveremo": "avvivare",
    "avvivereste": "avvivare",
    "avviveresti": "avvivare",
    "avviverete": "avvivare",
    "avviverà": "avvivare",
    "avviverò": "avvivare",
    "avvivi": "avvivare",
    "avviviamo": "avvivare",
    "avviviate": "avvivare",
    "avvivin": "avvivare",
    "avvivino": "avvivare",
    "avvivo": "avvivare",
    "avvivò": "avvivare",
    "avvizzendo": "avvizzire",
    "avvizzente": "avvizzire",
    "avvizzenti": "avvizzire",
    "avvizziamo": "avvizzire",
    "avvizziate": "avvizzire",
    "avvizzii": "avvizzire",
    "avvizzimmo": "avvizzire",
    "avvizzir": "avvizzire",
    "avvizzirai": "avvizzire",
    "avvizziran": "avvizzire",
    "avvizziranno": "avvizzire",
    "avvizzirebbe": "avvizzire",
    "avvizzirebber": "avvizzire",
    "avvizzirebbero": "avvizzire",
    "avvizzirei": "avvizzire",
    "avvizziremmo": "avvizzire",
    "avvizziremo": "avvizzire",
    "avvizzireste": "avvizzire",
    "avvizziresti": "avvizzire",
    "avvizzirete": "avvizzire",
    "avvizziron": "avvizzire",
    "avvizzirono": "avvizzire",
    "avvizzirà": "avvizzire",
    "avvizzirò": "avvizzire",
    "avvizzisca": "avvizzire",
    "avvizziscan": "avvizzire",
    "avvizziscano": "avvizzire",
    "avvizzisce": "avvizzire",
    "avvizzisci": "avvizzire",
    "avvizzisco": "avvizzire",
    "avvizziscon": "avvizzire",
    "avvizziscono": "avvizzire",
    "avvizzisse": "avvizzire",
    "avvizzisser": "avvizzire",
    "avvizzissero": "avvizzire",
    "avvizzissi": "avvizzire",
    "avvizzissimo": "avvizzire",
    "avvizziste": "avvizzire",
    "avvizzisti": "avvizzire",
    "avvizzita": "avvizzire",
    "avvizzite": "avvizzire",
    "avvizziti": "avvizzire",
    "avvizzito": "avvizzire",
    "avvizziva": "avvizzire",
    "avvizzivamo": "avvizzire",
    "avvizzivan": "avvizzire",
    "avvizzivano": "avvizzire",
    "avvizzivate": "avvizzire",
    "avvizzivi": "avvizzire",
    "avvizzivo": "avvizzire",
    "avvizzì": "avvizzire",
    "avviò": "avviare",
    "avvocatesse": "avvocatessa",
    "avvocati": "avvocato",
    "avvolga": "avvolgere",
    "avvolgan": "avvolgere",
    "avvolgano": "avvolgere",
    "avvolge": "avvolgere",
    "avvolgemmo": "avvolgere",
    "avvolgendo": "avvolgere",
    "avvolgente": "avvolgere",
    "avvolgenti": "avvolgere",
    "avvolger": "avvolgere",
    "avvolgerai": "avvolgere",
    "avvolgeran": "avvolgere",
    "avvolgeranno": "avvolgere",
    "avvolgerebbe": "avvolgere",
    "avvolgerebber": "avvolgere",
    "avvolgerebbero": "avvolgere",
    "avvolgerei": "avvolgere",
    "avvolgeremmo": "avvolgere",
    "avvolgeremo": "avvolgere",
    "avvolgereste": "avvolgere",
    "avvolgeresti": "avvolgere",
    "avvolgerete": "avvolgere",
    "avvolgerà": "avvolgere",
    "avvolgerò": "avvolgere",
    "avvolgesse": "avvolgere",
    "avvolgesser": "avvolgere",
    "avvolgessero": "avvolgere",
    "avvolgessi": "avvolgere",
    "avvolgessimo": "avvolgere",
    "avvolgeste": "avvolgere",
    "avvolgesti": "avvolgere",
    "avvolgete": "avvolgere",
    "avvolgeva": "avvolgere",
    "avvolgevamo": "avvolgere",
    "avvolgevan": "avvolgere",
    "avvolgevano": "avvolgere",
    "avvolgevate": "avvolgere",
    "avvolgevi": "avvolgere",
    "avvolgevo": "avvolgere",
    "avvolgi": "avvolgere",
    "avvolgiamo": "avvolgere",
    "avvolgiate": "avvolgere",
    "avvolgimenti": "avvolgimento",
    "avvolgo": "avvolgere",
    "avvolgon": "avvolgere",
    "avvolgono": "avvolgere",
    "avvolse": "avvolgere",
    "avvolser": "avvolgere",
    "avvolsero": "avvolgere",
    "avvolsi": "avvolgere",
    "avvolta": "avvolgere",
    "avvolte": "avvolgere",
    "avvolti": "avvolgere",
    "avvolto": "avvolgere",
    "avvoltoi": "avvoltoio",
    "ayurvedica": "ayurvedico",
    "ayurvediche": "ayurvedico",
    "ayurvedici": "ayurvedico",
    "azalee": "azalea",
    "azera": "azero",
    "azerbaigiana": "azerbaigiano",
    "azerbaigiane": "azerbaigiano",
    "azerbaigiani": "azerbaigiano",
    "azere": "azero",
    "azeri": "azero",
    "aziende": "azienda",
    "aziendine": "aziendina",
    "azima": "azimo",
    "azime": "azimo",
    "azimi": "azimo",
    "aziona": "azionare",
    "azionai": "azionare",
    "azionamenti": "azionamento",
    "azionammo": "azionare",
    "azionan": "azionare",
    "azionando": "azionare",
    "azionano": "azionare",
    "azionante": "azionare",
    "azionanti": "azionare",
    "azionar": "azionare",
    "azionariati": "azionariato",
    "azionaron": "azionare",
    "azionarono": "azionare",
    "azionasse": "azionare",
    "azionasser": "azionare",
    "azionassero": "azionare",
    "azionassi": "azionare",
    "azionassimo": "azionare",
    "azionaste": "azionare",
    "azionasti": "azionare",
    "azionata": "azionare",
    "azionate": "azionare",
    "azionati": "azionare",
    "azionato": "azionare",
    "azionava": "azionare",
    "azionavamo": "azionare",
    "azionavan": "azionare",
    "azionavano": "azionare",
    "azionavate": "azionare",
    "azionavi": "azionare",
    "azionavo": "azionare",
    "azionerai": "azionare",
    "azioneran": "azionare",
    "azioneranno": "azionare",
    "azionerebbe": "azionare",
    "azionerebber": "azionare",
    "azionerebbero": "azionare",
    "azionerei": "azionare",
    "azioneremmo": "azionare",
    "azioneremo": "azionare",
    "azionereste": "azionare",
    "azioneresti": "azionare",
    "azionerete": "azionare",
    "azionerà": "azionare",
    "azionerò": "azionare",
    "azioni": "azione",
    "azioniamo": "azionare",
    "azioniate": "azionare",
    "azionin": "azionare",
    "azionino": "azionare",
    "azioniste": "azionista",
    "azionisti": "azionista",
    "aziono": "azionare",
    "azionò": "azionare",
    "azzanna": "azzannare",
    "azzannai": "azzannare",
    "azzannammo": "azzannare",
    "azzannan": "azzannare",
    "azzannando": "azzannare",
    "azzannano": "azzannare",
    "azzannante": "azzannare",
    "azzannanti": "azzannare",
    "azzannar": "azzannare",
    "azzannaron": "azzannare",
    "azzannarono": "azzannare",
    "azzannasse": "azzannare",
    "azzannasser": "azzannare",
    "azzannassero": "azzannare",
    "azzannassi": "azzannare",
    "azzannassimo": "azzannare",
    "azzannaste": "azzannare",
    "azzannasti": "azzannare",
    "azzannata": "azzannare",
    "azzannate": "azzannare",
    "azzannati": "azzannare",
    "azzannato": "azzannare",
    "azzannava": "azzannare",
    "azzannavamo": "azzannare",
    "azzannavan": "azzannare",
    "azzannavano": "azzannare",
    "azzannavate": "azzannare",
    "azzannavi": "azzannare",
    "azzannavo": "azzannare",
    "azzannerai": "azzannare",
    "azzanneran": "azzannare",
    "azzanneranno": "azzannare",
    "azzannerebbe": "azzannare",
    "azzannerebber": "azzannare",
    "azzannerebbero": "azzannare",
    "azzannerei": "azzannare",
    "azzanneremmo": "azzannare",
    "azzanneremo": "azzannare",
    "azzannereste": "azzannare",
    "azzanneresti": "azzannare",
    "azzannerete": "azzannare",
    "azzannerà": "azzannare",
    "azzannerò": "azzannare",
    "azzanni": "azzannare",
    "azzanniamo": "azzannare",
    "azzanniate": "azzannare",
    "azzannin": "azzannare",
    "azzannino": "azzannare",
    "azzanno": "azzannare",
    "azzannò": "azzannare",
    "azzarda": "azzardare",
    "azzardai": "azzardare",
    "azzardammo": "azzardare",
    "azzardan": "azzardare",
    "azzardando": "azzardare",
    "azzardano": "azzardare",
    "azzardante": "azzardare",
    "azzardanti": "azzardare",
    "azzardar": "azzardare",
    "azzardaron": "azzardare",
    "azzardarono": "azzardare",
    "azzardasse": "azzardare",
    "azzardasser": "azzardare",
    "azzardassero": "azzardare",
    "azzardassi": "azzardare",
    "azzardassimo": "azzardare",
    "azzardaste": "azzardare",
    "azzardasti": "azzardare",
    "azzardata": "azzardato",
    "azzardate": "azzardato",
    "azzardati": "azzardato",
    "azzardato": "azzardare",
    "azzardava": "azzardare",
    "azzardavamo": "azzardare",
    "azzardavan": "azzardare",
    "azzardavano": "azzardare",
    "azzardavate": "azzardare",
    "azzardavi": "azzardare",
    "azzardavo": "azzardare",
    "azzarderai": "azzardare",
    "azzarderan": "azzardare",
    "azzarderanno": "azzardare",
    "azzarderebbe": "azzardare",
    "azzarderebber": "azzardare",
    "azzarderebbero": "azzardare",
    "azzarderei": "azzardare",
    "azzarderemmo": "azzardare",
    "azzarderemo": "azzardare",
    "azzardereste": "azzardare",
    "azzarderesti": "azzardare",
    "azzarderete": "azzardare",
    "azzarderà": "azzardare",
    "azzarderò": "azzardare",
    "azzardi": "azzardo",
    "azzardiamo": "azzardare",
    "azzardiate": "azzardare",
    "azzardin": "azzardare",
    "azzardino": "azzardare",
    "azzardo": "azzardare",
    "azzardò": "azzardare",
    "azzecca": "azzeccare",
    "azzeccai": "azzeccare",
    "azzeccammo": "azzeccare",
    "azzeccan": "azzeccare",
    "azzeccando": "azzeccare",
    "azzeccano": "azzeccare",
    "azzeccante": "azzeccare",
    "azzeccanti": "azzeccare",
    "azzeccar": "azzeccare",
    "azzeccaron": "azzeccare",
    "azzeccarono": "azzeccare",
    "azzeccasse": "azzeccare",
    "azzeccasser": "azzeccare",
    "azzeccassero": "azzeccare",
    "azzeccassi": "azzeccare",
    "azzeccassimo": "azzeccare",
    "azzeccaste": "azzeccare",
    "azzeccasti": "azzeccare",
    "azzeccata": "azzeccato",
    "azzeccate": "azzeccato",
    "azzeccati": "azzeccato",
    "azzeccato": "azzeccare",
    "azzeccava": "azzeccare",
    "azzeccavamo": "azzeccare",
    "azzeccavan": "azzeccare",
    "azzeccavano": "azzeccare",
    "azzeccavate": "azzeccare",
    "azzeccavi": "azzeccare",
    "azzeccavo": "azzeccare",
    "azzeccherai": "azzeccare",
    "azzeccheran": "azzeccare",
    "azzeccheranno": "azzeccare",
    "azzeccherebbe": "azzeccare",
    "azzeccherebber": "azzeccare",
    "azzeccherebbero": "azzeccare",
    "azzeccherei": "azzeccare",
    "azzeccheremmo": "azzeccare",
    "azzeccheremo": "azzeccare",
    "azzecchereste": "azzeccare",
    "azzeccheresti": "azzeccare",
    "azzeccherete": "azzeccare",
    "azzeccherà": "azzeccare",
    "azzeccherò": "azzeccare",
    "azzecchi": "azzeccare",
    "azzecchiamo": "azzeccare",
    "azzecchiate": "azzeccare",
    "azzecchin": "azzeccare",
    "azzecchino": "azzeccare",
    "azzecco": "azzeccare",
    "azzeccò": "azzeccare",
    "azzera": "azzerare",
    "azzerabili": "azzerabile",
    "azzerai": "azzerare",
    "azzeramenti": "azzeramento",
    "azzerammo": "azzerare",
    "azzeran": "azzerare",
    "azzerando": "azzerare",
    "azzerano": "azzerare",
    "azzerante": "azzerare",
    "azzeranti": "azzerare",
    "azzerar": "azzerare",
    "azzeraron": "azzerare",
    "azzerarono": "azzerare",
    "azzerasse": "azzerare",
    "azzerasser": "azzerare",
    "azzerassero": "azzerare",
    "azzerassi": "azzerare",
    "azzerassimo": "azzerare",
    "azzeraste": "azzerare",
    "azzerasti": "azzerare",
    "azzerata": "azzerare",
    "azzerate": "azzerare",
    "azzerati": "azzerare",
    "azzerato": "azzerare",
    "azzerava": "azzerare",
    "azzeravamo": "azzerare",
    "azzeravan": "azzerare",
    "azzeravano": "azzerare",
    "azzeravate": "azzerare",
    "azzeravi": "azzerare",
    "azzeravo": "azzerare",
    "azzererai": "azzerare",
    "azzereran": "azzerare",
    "azzereranno": "azzerare",
    "azzererebbe": "azzerare",
    "azzererebber": "azzerare",
    "azzererebbero": "azzerare",
    "azzererei": "azzerare",
    "azzereremmo": "azzerare",
    "azzereremo": "azzerare",
    "azzerereste": "azzerare",
    "azzereresti": "azzerare",
    "azzererete": "azzerare",
    "azzererà": "azzerare",
    "azzererò": "azzerare",
    "azzeri": "azzerare",
    "azzeriamo": "azzerare",
    "azzeriate": "azzerare",
    "azzerin": "azzerare",
    "azzerino": "azzerare",
    "azzero": "azzerare",
    "azzerò": "azzerare",
    "azzima": "azzimare",
    "azzimai": "azzimare",
    "azzimammo": "azzimare",
    "azziman": "azzimare",
    "azzimando": "azzimare",
    "azzimano": "azzimare",
    "azzimante": "azzimare",
    "azzimanti": "azzimare",
    "azzimar": "azzimare",
    "azzimaron": "azzimare",
    "azzimarono": "azzimare",
    "azzimasse": "azzimare",
    "azzimasser": "azzimare",
    "azzimassero": "azzimare",
    "azzimassi": "azzimare",
    "azzimassimo": "azzimare",
    "azzimaste": "azzimare",
    "azzimasti": "azzimare",
    "azzimata": "azzimare",
    "azzimate": "azzimare",
    "azzimati": "azzimare",
    "azzimato": "azzimare",
    "azzimava": "azzimare",
    "azzimavamo": "azzimare",
    "azzimavan": "azzimare",
    "azzimavano": "azzimare",
    "azzimavate": "azzimare",
    "azzimavi": "azzimare",
    "azzimavo": "azzimare",
    "azzimerai": "azzimare",
    "azzimeran": "azzimare",
    "azzimeranno": "azzimare",
    "azzimerebbe": "azzimare",
    "azzimerebber": "azzimare",
    "azzimerebbero": "azzimare",
    "azzimerei": "azzimare",
    "azzimeremmo": "azzimare",
    "azzimeremo": "azzimare",
    "azzimereste": "azzimare",
    "azzimeresti": "azzimare",
    "azzimerete": "azzimare",
    "azzimerà": "azzimare",
    "azzimerò": "azzimare",
    "azzimi": "azzimare",
    "azzimiamo": "azzimare",
    "azzimiate": "azzimare",
    "azzimin": "azzimare",
    "azzimino": "azzimare",
    "azzimo": "azzimare",
    "azzimò": "azzimare",
    "azzitta": "azzittire",
    "azzittan": "azzittire",
    "azzittano": "azzittire",
    "azzitte": "azzittire",
    "azzittendo": "azzittire",
    "azzittente": "azzittire",
    "azzittenti": "azzittire",
    "azzitti": "azzittire",
    "azzittiamo": "azzittire",
    "azzittiate": "azzittire",
    "azzittii": "azzittire",
    "azzittimmo": "azzittire",
    "azzittir": "azzittire",
    "azzittirai": "azzittire",
    "azzittiran": "azzittire",
    "azzittiranno": "azzittire",
    "azzittirebbe": "azzittire",
    "azzittirebber": "azzittire",
    "azzittirebbero": "azzittire",
    "azzittirei": "azzittire",
    "azzittiremmo": "azzittire",
    "azzittiremo": "azzittire",
    "azzittireste": "azzittire",
    "azzittiresti": "azzittire",
    "azzittirete": "azzittire",
    "azzittiron": "azzittire",
    "azzittirono": "azzittire",
    "azzittirà": "azzittire",
    "azzittirò": "azzittire",
    "azzittisse": "azzittire",
    "azzittisser": "azzittire",
    "azzittissero": "azzittire",
    "azzittissi": "azzittire",
    "azzittissimo": "azzittire",
    "azzittiste": "azzittire",
    "azzittisti": "azzittire",
    "azzittita": "azzittire",
    "azzittite": "azzittire",
    "azzittiti": "azzittire",
    "azzittito": "azzittire",
    "azzittiva": "azzittire",
    "azzittivamo": "azzittire",
    "azzittivan": "azzittire",
    "azzittivano": "azzittire",
    "azzittivate": "azzittire",
    "azzittivi": "azzittire",
    "azzittivo": "azzittire",
    "azzitto": "azzittire",
    "azzitton": "azzittire",
    "azzittono": "azzittire",
    "azzittì": "azzittire",
    "azzoppa": "azzoppare",
    "azzoppai": "azzoppare",
    "azzoppammo": "azzoppare",
    "azzoppan": "azzoppare",
    "azzoppando": "azzoppare",
    "azzoppano": "azzoppare",
    "azzoppante": "azzoppare",
    "azzoppanti": "azzoppare",
    "azzoppar": "azzoppare",
    "azzopparon": "azzoppare",
    "azzopparono": "azzoppare",
    "azzoppasse": "azzoppare",
    "azzoppasser": "azzoppare",
    "azzoppassero": "azzoppare",
    "azzoppassi": "azzoppare",
    "azzoppassimo": "azzoppare",
    "azzoppaste": "azzoppare",
    "azzoppasti": "azzoppare",
    "azzoppata": "azzoppare",
    "azzoppate": "azzoppare",
    "azzoppati": "azzoppare",
    "azzoppato": "azzoppare",
    "azzoppava": "azzoppare",
    "azzoppavamo": "azzoppare",
    "azzoppavan": "azzoppare",
    "azzoppavano": "azzoppare",
    "azzoppavate": "azzoppare",
    "azzoppavi": "azzoppare",
    "azzoppavo": "azzoppare",
    "azzopperai": "azzoppare",
    "azzopperan": "azzoppare",
    "azzopperanno": "azzoppare",
    "azzopperebbe": "azzoppare",
    "azzopperebber": "azzoppare",
    "azzopperebbero": "azzoppare",
    "azzopperei": "azzoppare",
    "azzopperemmo": "azzoppare",
    "azzopperemo": "azzoppare",
    "azzoppereste": "azzoppare",
    "azzopperesti": "azzoppare",
    "azzopperete": "azzoppare",
    "azzopperà": "azzoppare",
    "azzopperò": "azzoppare",
    "azzoppi": "azzoppare",
    "azzoppiamo": "azzoppare",
    "azzoppiate": "azzoppare",
    "azzoppin": "azzoppare",
    "azzoppino": "azzoppare",
    "azzoppo": "azzoppare",
    "azzoppò": "azzoppare",
    "azzuffa": "azzuffare",
    "azzuffai": "azzuffare",
    "azzuffammo": "azzuffare",
    "azzuffan": "azzuffare",
    "azzuffando": "azzuffare",
    "azzuffano": "azzuffare",
    "azzuffante": "azzuffare",
    "azzuffanti": "azzuffare",
    "azzuffar": "azzuffare",
    "azzuffaron": "azzuffare",
    "azzuffarono": "azzuffare",
    "azzuffasse": "azzuffare",
    "azzuffasser": "azzuffare",
    "azzuffassero": "azzuffare",
    "azzuffassi": "azzuffare",
    "azzuffassimo": "azzuffare",
    "azzuffaste": "azzuffare",
    "azzuffasti": "azzuffare",
    "azzuffata": "azzuffare",
    "azzuffate": "azzuffare",
    "azzuffati": "azzuffare",
    "azzuffato": "azzuffare",
    "azzuffava": "azzuffare",
    "azzuffavamo": "azzuffare",
    "azzuffavan": "azzuffare",
    "azzuffavano": "azzuffare",
    "azzuffavate": "azzuffare",
    "azzuffavi": "azzuffare",
    "azzuffavo": "azzuffare",
    "azzufferai": "azzuffare",
    "azzufferan": "azzuffare",
    "azzufferanno": "azzuffare",
    "azzufferebbe": "azzuffare",
    "azzufferebber": "azzuffare",
    "azzufferebbero": "azzuffare",
    "azzufferei": "azzuffare",
    "azzufferemmo": "azzuffare",
    "azzufferemo": "azzuffare",
    "azzuffereste": "azzuffare",
    "azzufferesti": "azzuffare",
    "azzufferete": "azzuffare",
    "azzufferà": "azzuffare",
    "azzufferò": "azzuffare",
    "azzuffi": "azzuffare",
    "azzuffiamo": "azzuffare",
    "azzuffiate": "azzuffare",
    "azzuffin": "azzuffare",
    "azzuffino": "azzuffare",
    "azzuffo": "azzuffare",
    "azzuffò": "azzuffare",
    "azzurra": "azzurro",
    "azzurrai": "azzurrare",
    "azzurrammo": "azzurrare",
    "azzurran": "azzurrare",
    "azzurrando": "azzurrare",
    "azzurrano": "azzurrare",
    "azzurrante": "azzurrare",
    "azzurranti": "azzurrare",
    "azzurrar": "azzurrare",
    "azzurraron": "azzurrare",
    "azzurrarono": "azzurrare",
    "azzurrasse": "azzurrare",
    "azzurrasser": "azzurrare",
    "azzurrassero": "azzurrare",
    "azzurrassi": "azzurrare",
    "azzurrassimo": "azzurrare",
    "azzurraste": "azzurrare",
    "azzurrasti": "azzurrare",
    "azzurrata": "azzurrare",
    "azzurrate": "azzurrare",
    "azzurrati": "azzurrare",
    "azzurrato": "azzurrare",
    "azzurrava": "azzurrare",
    "azzurravamo": "azzurrare",
    "azzurravan": "azzurrare",
    "azzurravano": "azzurrare",
    "azzurravate": "azzurrare",
    "azzurravi": "azzurrare",
    "azzurravo": "azzurrare",
    "azzurre": "azzurro",
    "azzurrerai": "azzurrare",
    "azzurreran": "azzurrare",
    "azzurreranno": "azzurrare",
    "azzurrerebbe": "azzurrare",
    "azzurrerebber": "azzurrare",
    "azzurrerebbero": "azzurrare",
    "azzurrerei": "azzurrare",
    "azzurreremmo": "azzurrare",
    "azzurreremo": "azzurrare",
    "azzurrereste": "azzurrare",
    "azzurreresti": "azzurrare",
    "azzurrerete": "azzurrare",
    "azzurrerà": "azzurrare",
    "azzurrerò": "azzurrare",
    "azzurri": "azzurro",
    "azzurriamo": "azzurrare",
    "azzurriate": "azzurrare",
    "azzurrin": "azzurrare",
    "azzurrina": "azzurrino",
    "azzurrine": "azzurrino",
    "azzurrini": "azzurrino",
    "azzurrino": "azzurrare",
    "azzurro": "azzurrare",
    "azzurrò": "azzurrare",
    "babbei": "babbeo",
    "babbi": "babbo",
    "babbuini": "babbuino",
    "babeli": "babele",
    "baby-calciatori": "baby-calciatore",
    "baca": "bacare",
    "bacai": "bacare",
    "bacammo": "bacare",
    "bacan": "bacare",
    "bacando": "bacare",
    "bacano": "bacare",
    "bacante": "bacare",
    "bacanti": "bacare",
    "bacar": "bacare",
    "bacaron": "bacare",
    "bacarono": "bacare",
    "bacasse": "bacare",
    "bacasser": "bacare",
    "bacassero": "bacare",
    "bacassi": "bacare",
    "bacassimo": "bacare",
    "bacaste": "bacare",
    "bacasti": "bacare",
    "bacata": "bacare",
    "bacate": "bacare",
    "bacati": "bacare",
    "bacato": "bacare",
    "bacava": "bacare",
    "bacavamo": "bacare",
    "bacavan": "bacare",
    "bacavano": "bacare",
    "bacavate": "bacare",
    "bacavi": "bacare",
    "bacavo": "bacare",
    "baccagli": "baccagliare",
    "baccaglia": "baccagliare",
    "baccagliai": "baccagliare",
    "baccagliammo": "baccagliare",
    "baccagliamo": "baccagliare",
    "baccaglian": "baccagliare",
    "baccagliando": "baccagliare",
    "baccagliano": "baccagliare",
    "baccagliante": "baccagliare",
    "baccaglianti": "baccagliare",
    "baccagliar": "baccagliare",
    "baccagliaron": "baccagliare",
    "baccagliarono": "baccagliare",
    "baccagliasse": "baccagliare",
    "baccagliasser": "baccagliare",
    "baccagliassero": "baccagliare",
    "baccagliassi": "baccagliare",
    "baccagliassimo": "baccagliare",
    "baccagliaste": "baccagliare",
    "baccagliasti": "baccagliare",
    "baccagliata": "baccagliare",
    "baccagliate": "baccagliare",
    "baccagliati": "baccagliare",
    "baccagliato": "baccagliare",
    "baccagliava": "baccagliare",
    "baccagliavamo": "baccagliare",
    "baccagliavan": "baccagliare",
    "baccagliavano": "baccagliare",
    "baccagliavate": "baccagliare",
    "baccagliavi": "baccagliare",
    "baccagliavo": "baccagliare",
    "baccaglierai": "baccagliare",
    "baccaglieran": "baccagliare",
    "baccaglieranno": "baccagliare",
    "baccaglierebbe": "baccagliare",
    "baccaglierebber": "baccagliare",
    "baccaglierebbero": "baccagliare",
    "baccaglierei": "baccagliare",
    "baccaglieremmo": "baccagliare",
    "baccaglieremo": "baccagliare",
    "baccagliereste": "baccagliare",
    "baccaglieresti": "baccagliare",
    "baccaglierete": "baccagliare",
    "baccaglierà": "baccagliare",
    "baccaglierò": "baccagliare",
    "baccaglin": "baccagliare",
    "baccaglino": "baccagliare",
    "baccaglio": "baccagliare",
    "baccagliò": "baccagliare",
    "baccanali": "baccanale",
    "baccani": "baccano",
    "baccanti": "baccante",
    "bacche": "bacca",
    "bacchetta": "bacchettare",
    "bacchettai": "bacchettare",
    "bacchettammo": "bacchettare",
    "bacchettan": "bacchettare",
    "bacchettando": "bacchettare",
    "bacchettano": "bacchettare",
    "bacchettante": "bacchettare",
    "bacchettanti": "bacchettare",
    "bacchettar": "bacchettare",
    "bacchettaron": "bacchettare",
    "bacchettarono": "bacchettare",
    "bacchettasse": "bacchettare",
    "bacchettasser": "bacchettare",
    "bacchettassero": "bacchettare",
    "bacchettassi": "bacchettare",
    "bacchettassimo": "bacchettare",
    "bacchettaste": "bacchettare",
    "bacchettasti": "bacchettare",
    "bacchettata": "bacchettare",
    "bacchettate": "bacchettata",
    "bacchettati": "bacchettare",
    "bacchettato": "bacchettare",
    "bacchettava": "bacchettare",
    "bacchettavamo": "bacchettare",
    "bacchettavan": "bacchettare",
    "bacchettavano": "bacchettare",
    "bacchettavate": "bacchettare",
    "bacchettavi": "bacchettare",
    "bacchettavo": "bacchettare",
    "bacchette": "bacchetta",
    "bacchetterai": "bacchettare",
    "bacchetteran": "bacchettare",
    "bacchetteranno": "bacchettare",
    "bacchetterebbe": "bacchettare",
    "bacchetterebber": "bacchettare",
    "bacchetterebbero": "bacchettare",
    "bacchetterei": "bacchettare",
    "bacchetteremmo": "bacchettare",
    "bacchetteremo": "bacchettare",
    "bacchettereste": "bacchettare",
    "bacchetteresti": "bacchettare",
    "bacchetterete": "bacchettare",
    "bacchetterà": "bacchettare",
    "bacchetterò": "bacchettare",
    "bacchetti": "bacchettare",
    "bacchettiamo": "bacchettare",
    "bacchettiate": "bacchettare",
    "bacchettin": "bacchettare",
    "bacchettino": "bacchettare",
    "bacchetto": "bacchettare",
    "bacchettoni": "bacchettone",
    "bacchettò": "bacchettare",
    "bacchi": "bacchiare",
    "bacchia": "bacchiare",
    "bacchiai": "bacchiare",
    "bacchiammo": "bacchiare",
    "bacchiamo": "bacchiare",
    "bacchian": "bacchiare",
    "bacchiando": "bacchiare",
    "bacchiano": "bacchiare",
    "bacchiante": "bacchiare",
    "bacchianti": "bacchiare",
    "bacchiar": "bacchiare",
    "bacchiaron": "bacchiare",
    "bacchiarono": "bacchiare",
    "bacchiasse": "bacchiare",
    "bacchiasser": "bacchiare",
    "bacchiassero": "bacchiare",
    "bacchiassi": "bacchiare",
    "bacchiassimo": "bacchiare",
    "bacchiaste": "bacchiare",
    "bacchiasti": "bacchiare",
    "bacchiata": "bacchiare",
    "bacchiate": "bacchiare",
    "bacchiati": "bacchiare",
    "bacchiato": "bacchiare",
    "bacchiava": "bacchiare",
    "bacchiavamo": "bacchiare",
    "bacchiavan": "bacchiare",
    "bacchiavano": "bacchiare",
    "bacchiavate": "bacchiare",
    "bacchiavi": "bacchiare",
    "bacchiavo": "bacchiare",
    "bacchierai": "bacchiare",
    "bacchieran": "bacchiare",
    "bacchieranno": "bacchiare",
    "bacchierebbe": "bacchiare",
    "bacchierebber": "bacchiare",
    "bacchierebbero": "bacchiare",
    "bacchierei": "bacchiare",
    "bacchieremmo": "bacchiare",
    "bacchieremo": "bacchiare",
    "bacchiereste": "bacchiare",
    "bacchieresti": "bacchiare",
    "bacchierete": "bacchiare",
    "bacchierà": "bacchiare",
    "bacchierò": "bacchiare",
    "bacchin": "bacchiare",
    "bacchino": "bacchiare",
    "bacchio": "bacchiare",
    "bacchiò": "bacchiare",
    "bacerai": "baciare",
    "baceran": "baciare",
    "baceranno": "baciare",
    "bacerebbe": "baciare",
    "bacerebber": "baciare",
    "bacerebbero": "baciare",
    "bacerei": "baciare",
    "baceremmo": "baciare",
    "baceremo": "baciare",
    "bacereste": "baciare",
    "baceresti": "baciare",
    "bacerete": "baciare",
    "bacerà": "baciare",
    "bacerò": "baciare",
    "bacetti": "bacetto",
    "bacheche": "bacheca",
    "bacherai": "bacare",
    "bacheran": "bacare",
    "bacheranno": "bacare",
    "bacherebbe": "bacare",
    "bacherebber": "bacare",
    "bacherebbero": "bacare",
    "bacherei": "bacare",
    "bacheremmo": "bacare",
    "bacheremo": "bacare",
    "bachereste": "bacare",
    "bacheresti": "bacare",
    "bacherete": "bacare",
    "bacherà": "bacare",
    "bacherò": "bacare",
    "bachi": "baco",
    "bachiamo": "bacare",
    "bachiate": "bacare",
    "bachin": "bacare",
    "bachino": "bacare",
    "baci": "bacio",
    "bacia": "baciare",
    "baciai": "baciare",
    "baciammo": "baciare",
    "baciamo": "baciare",
    "bacian": "baciare",
    "baciando": "baciare",
    "baciano": "baciare",
    "baciante": "baciare",
    "bacianti": "baciare",
    "baciar": "baciare",
    "baciaron": "baciare",
    "baciarono": "baciare",
    "baciasse": "baciare",
    "baciasser": "baciare",
    "baciassero": "baciare",
    "baciassi": "baciare",
    "baciassimo": "baciare",
    "baciaste": "baciare",
    "baciasti": "baciare",
    "baciata": "baciare",
    "baciate": "baciare",
    "baciati": "baciare",
    "baciato": "baciare",
    "baciava": "baciare",
    "baciavamo": "baciare",
    "baciavan": "baciare",
    "baciavano": "baciare",
    "baciavate": "baciare",
    "baciavi": "baciare",
    "baciavo": "baciare",
    "bacilla": "bacillare",
    "bacillai": "bacillare",
    "bacillammo": "bacillare",
    "bacillan": "bacillare",
    "bacillando": "bacillare",
    "bacillano": "bacillare",
    "bacillante": "bacillare",
    "bacillanti": "bacillare",
    "bacillar": "bacillare",
    "bacillaron": "bacillare",
    "bacillarono": "bacillare",
    "bacillasse": "bacillare",
    "bacillasser": "bacillare",
    "bacillassero": "bacillare",
    "bacillassi": "bacillare",
    "bacillassimo": "bacillare",
    "bacillaste": "bacillare",
    "bacillasti": "bacillare",
    "bacillata": "bacillare",
    "bacillate": "bacillare",
    "bacillati": "bacillare",
    "bacillato": "bacillare",
    "bacillava": "bacillare",
    "bacillavamo": "bacillare",
    "bacillavan": "bacillare",
    "bacillavano": "bacillare",
    "bacillavate": "bacillare",
    "bacillavi": "bacillare",
    "bacillavo": "bacillare",
    "bacillerai": "bacillare",
    "bacilleran": "bacillare",
    "bacilleranno": "bacillare",
    "bacillerebbe": "bacillare",
    "bacillerebber": "bacillare",
    "bacillerebbero": "bacillare",
    "bacillerei": "bacillare",
    "bacilleremmo": "bacillare",
    "bacilleremo": "bacillare",
    "bacillereste": "bacillare",
    "bacilleresti": "bacillare",
    "bacillerete": "bacillare",
    "bacillerà": "bacillare",
    "bacillerò": "bacillare",
    "bacilli": "bacillo",
    "bacilliamo": "bacillare",
    "bacilliate": "bacillare",
    "bacillin": "bacillare",
    "bacillino": "bacillare",
    "bacillo": "bacillare",
    "bacillò": "bacillare",
    "bacin": "baciare",
    "bacinelle": "bacinella",
    "bacini": "bacino",
    "bacino": "baciare",
    "bacio": "baciare",
    "baciò": "baciare",
    "baco": "bacare",
    "bacò": "bacare",
    "bada": "badare",
    "badai": "badare",
    "badammo": "badare",
    "badan": "badare",
    "badando": "badare",
    "badano": "badare",
    "badante": "badare",
    "badanti": "badare",
    "badar": "badare",
    "badaron": "badare",
    "badarono": "badare",
    "badasse": "badare",
    "badasser": "badare",
    "badassero": "badare",
    "badassi": "badare",
    "badassimo": "badare",
    "badaste": "badare",
    "badasti": "badare",
    "badata": "badare",
    "badate": "badare",
    "badati": "badare",
    "badato": "badare",
    "badava": "badare",
    "badavamo": "badare",
    "badavan": "badare",
    "badavano": "badare",
    "badavate": "badare",
    "badavi": "badare",
    "badavo": "badare",
    "baderai": "badare",
    "baderan": "badare",
    "baderanno": "badare",
    "baderebbe": "badare",
    "baderebber": "badare",
    "baderebbero": "badare",
    "baderei": "badare",
    "baderemmo": "badare",
    "baderemo": "badare",
    "badereste": "badare",
    "baderesti": "badare",
    "baderete": "badare",
    "baderà": "badare",
    "baderò": "badare",
    "badesse": "badessa",
    "badi": "badare",
    "badiali": "badiale",
    "badiamo": "badare",
    "badiate": "badare",
    "badin": "badare",
    "badino": "badare",
    "bado": "badare",
    "badò": "badare",
    "baffetti": "baffetto",
    "baffi": "baffo",
    "baffoni": "baffone",
    "baffuta": "baffuto",
    "baffute": "baffuto",
    "baffuti": "baffuto",
    "bagagli": "bagaglio",
    "bagagliai": "bagagliaio",
    "bagaglinesca": "bagaglinesco",
    "bagaglinesche": "bagaglinesco",
    "bagaglineschi": "bagaglinesco",
    "bagarinaggi": "bagarinaggio",
    "bagarini": "bagarino",
    "bagarres": "bagarre",
    "baggianate": "baggianata",
    "bagliori": "bagliore",
    "bagna": "bagnare",
    "bagnai": "bagnare",
    "bagnammo": "bagnare",
    "bagnan": "bagnare",
    "bagnando": "bagnare",
    "bagnano": "bagnare",
    "bagnante": "bagnare",
    "bagnanti": "bagnare",
    "bagnar": "bagnare",
    "bagnaron": "bagnare",
    "bagnarono": "bagnare",
    "bagnasse": "bagnare",
    "bagnasser": "bagnare",
    "bagnassero": "bagnare",
    "bagnassi": "bagnare",
    "bagnassimo": "bagnare",
    "bagnaste": "bagnare",
    "bagnasti": "bagnare",
    "bagnata": "bagnato",
    "bagnate": "bagnato",
    "bagnati": "bagnato",
    "bagnato": "bagnare",
    "bagnava": "bagnare",
    "bagnavamo": "bagnare",
    "bagnavan": "bagnare",
    "bagnavano": "bagnare",
    "bagnavate": "bagnare",
    "bagnavi": "bagnare",
    "bagnavo": "bagnare",
    "bagnerai": "bagnare",
    "bagneran": "bagnare",
    "bagneranno": "bagnare",
    "bagnerebbe": "bagnare",
    "bagnerebber": "bagnare",
    "bagnerebbero": "bagnare",
    "bagnerei": "bagnare",
    "bagneremmo": "bagnare",
    "bagneremo": "bagnare",
    "bagnereste": "bagnare",
    "bagneresti": "bagnare",
    "bagnerete": "bagnare",
    "bagnerà": "bagnare",
    "bagnerò": "bagnare",
    "bagni": "bagno",
    "bagniamo": "bagnare",
    "bagniate": "bagnare",
    "bagnin": "bagnare",
    "bagnini": "bagnino",
    "bagnino": "bagnare",
    "bagno": "bagnare",
    "bagnò": "bagnare",
    "bahiana": "bahiano",
    "bahiane": "bahiano",
    "bahiani": "bahiano",
    "bai": "baio",
    "baia": "baio",
    "baie": "baio",
    "baii": "baio",
    "bailammes": "bailamme",
    "baionette": "baionetta",
    "baite": "baita",
    "balaustre": "balaustra",
    "balba": "balbo",
    "balbe": "balbo",
    "balbetta": "balbettare",
    "balbettai": "balbettare",
    "balbettamenti": "balbettamento",
    "balbettammo": "balbettare",
    "balbettan": "balbettare",
    "balbettando": "balbettare",
    "balbettano": "balbettare",
    "balbettante": "balbettare",
    "balbettanti": "balbettare",
    "balbettar": "balbettare",
    "balbettaron": "balbettare",
    "balbettarono": "balbettare",
    "balbettasse": "balbettare",
    "balbettasser": "balbettare",
    "balbettassero": "balbettare",
    "balbettassi": "balbettare",
    "balbettassimo": "balbettare",
    "balbettaste": "balbettare",
    "balbettasti": "balbettare",
    "balbettata": "balbettare",
    "balbettate": "balbettare",
    "balbettati": "balbettare",
    "balbettato": "balbettare",
    "balbettava": "balbettare",
    "balbettavamo": "balbettare",
    "balbettavan": "balbettare",
    "balbettavano": "balbettare",
    "balbettavate": "balbettare",
    "balbettavi": "balbettare",
    "balbettavo": "balbettare",
    "balbetterai": "balbettare",
    "balbetteran": "balbettare",
    "balbetteranno": "balbettare",
    "balbetterebbe": "balbettare",
    "balbetterebber": "balbettare",
    "balbetterebbero": "balbettare",
    "balbetterei": "balbettare",
    "balbetteremmo": "balbettare",
    "balbetteremo": "balbettare",
    "balbettereste": "balbettare",
    "balbetteresti": "balbettare",
    "balbetterete": "balbettare",
    "balbetterà": "balbettare",
    "balbetterò": "balbettare",
    "balbetti": "balbettare",
    "balbettiamo": "balbettare",
    "balbettiate": "balbettare",
    "balbettii": "balbettio",
    "balbettin": "balbettare",
    "balbettino": "balbettare",
    "balbetto": "balbettare",
    "balbettò": "balbettare",
    "balbi": "balbo",
    "balbuta": "balbutire",
    "balbutan": "balbutire",
    "balbutano": "balbutire",
    "balbute": "balbutire",
    "balbutendo": "balbutire",
    "balbutente": "balbutire",
    "balbutenti": "balbutire",
    "balbuti": "balbutire",
    "balbutiamo": "balbutire",
    "balbutiate": "balbutire",
    "balbutii": "balbutire",
    "balbutimmo": "balbutire",
    "balbutir": "balbutire",
    "balbutirai": "balbutire",
    "balbutiran": "balbutire",
    "balbutiranno": "balbutire",
    "balbutirebbe": "balbutire",
    "balbutirebber": "balbutire",
    "balbutirebbero": "balbutire",
    "balbutirei": "balbutire",
    "balbutiremmo": "balbutire",
    "balbutiremo": "balbutire",
    "balbutireste": "balbutire",
    "balbutiresti": "balbutire",
    "balbutirete": "balbutire",
    "balbutiron": "balbutire",
    "balbutirono": "balbutire",
    "balbutirà": "balbutire",
    "balbutirò": "balbutire",
    "balbutisse": "balbutire",
    "balbutisser": "balbutire",
    "balbutissero": "balbutire",
    "balbutissi": "balbutire",
    "balbutissimo": "balbutire",
    "balbutiste": "balbutire",
    "balbutisti": "balbutire",
    "balbutita": "balbutire",
    "balbutite": "balbutire",
    "balbutiti": "balbutire",
    "balbutito": "balbutire",
    "balbutiva": "balbutire",
    "balbutivamo": "balbutire",
    "balbutivan": "balbutire",
    "balbutivano": "balbutire",
    "balbutivate": "balbutire",
    "balbutivi": "balbutire",
    "balbutivo": "balbutire",
    "balbuto": "balbutire",
    "balbuton": "balbutire",
    "balbutono": "balbutire",
    "balbutì": "balbutire",
    "balbuzienti": "balbuziente",
    "balcanica": "balcanico",
    "balcaniche": "balcanico",
    "balcanici": "balcanico",
    "balcanizzazioni": "balcanizzazione",
    "balconate": "balconata",
    "balconcini": "balconcino",
    "balconi": "balcone",
    "balda": "baldo",
    "baldacchini": "baldacchino",
    "baldanze": "baldanza",
    "baldanzosa": "baldanzoso",
    "baldanzose": "baldanzoso",
    "baldanzosi": "baldanzoso",
    "balde": "baldo",
    "baldi": "baldo",
    "baldorie": "baldoria",
    "balena": "balenare",
    "balenai": "balenare",
    "balenammo": "balenare",
    "balenan": "balenare",
    "balenando": "balenare",
    "balenano": "balenare",
    "balenante": "balenare",
    "balenanti": "balenare",
    "balenar": "balenare",
    "balenaron": "balenare",
    "balenarono": "balenare",
    "balenasse": "balenare",
    "balenasser": "balenare",
    "balenassero": "balenare",
    "balenassi": "balenare",
    "balenassimo": "balenare",
    "balenaste": "balenare",
    "balenasti": "balenare",
    "balenata": "balenare",
    "balenate": "balenare",
    "balenati": "balenare",
    "balenato": "balenare",
    "balenava": "balenare",
    "balenavamo": "balenare",
    "balenavan": "balenare",
    "balenavano": "balenare",
    "balenavate": "balenare",
    "balenavi": "balenare",
    "balenavo": "balenare",
    "balene": "balena",
    "balenerai": "balenare",
    "baleneran": "balenare",
    "baleneranno": "balenare",
    "balenerebbe": "balenare",
    "balenerebber": "balenare",
    "balenerebbero": "balenare",
    "balenerei": "balenare",
    "baleneremmo": "balenare",
    "baleneremo": "balenare",
    "balenereste": "balenare",
    "baleneresti": "balenare",
    "balenerete": "balenare",
    "balenerà": "balenare",
    "balenerò": "balenare",
    "baleni": "balenare",
    "baleniamo": "balenare",
    "baleniate": "balenare",
    "baleniera": "baleniero",
    "baleniere": "baleniero",
    "balenieri": "baleniero",
    "balenin": "balenare",
    "balenino": "balenare",
    "baleno": "balenare",
    "balenò": "balenare",
    "balere": "balera",
    "balestra": "balestrare",
    "balestrai": "balestrare",
    "balestrammo": "balestrare",
    "balestran": "balestrare",
    "balestrando": "balestrare",
    "balestrano": "balestrare",
    "balestrante": "balestrare",
    "balestranti": "balestrare",
    "balestrar": "balestrare",
    "balestraron": "balestrare",
    "balestrarono": "balestrare",
    "balestrasse": "balestrare",
    "balestrasser": "balestrare",
    "balestrassero": "balestrare",
    "balestrassi": "balestrare",
    "balestrassimo": "balestrare",
    "balestraste": "balestrare",
    "balestrasti": "balestrare",
    "balestrata": "balestrare",
    "balestrate": "balestrare",
    "balestrati": "balestrare",
    "balestrato": "balestrare",
    "balestrava": "balestrare",
    "balestravamo": "balestrare",
    "balestravan": "balestrare",
    "balestravano": "balestrare",
    "balestravate": "balestrare",
    "balestravi": "balestrare",
    "balestravo": "balestrare",
    "balestrerai": "balestrare",
    "balestreran": "balestrare",
    "balestreranno": "balestrare",
    "balestrerebbe": "balestrare",
    "balestrerebber": "balestrare",
    "balestrerebbero": "balestrare",
    "balestrerei": "balestrare",
    "balestreremmo": "balestrare",
    "balestreremo": "balestrare",
    "balestrereste": "balestrare",
    "balestreresti": "balestrare",
    "balestrerete": "balestrare",
    "balestrerà": "balestrare",
    "balestrerò": "balestrare",
    "balestri": "balestrare",
    "balestriamo": "balestrare",
    "balestriate": "balestrare",
    "balestrin": "balestrare",
    "balestrino": "balestrare",
    "balestro": "balestrare",
    "balestrò": "balestrare",
    "balie": "balia",
    "balistica": "balistico",
    "balistiche": "balistico",
    "balistici": "balistico",
    "balla": "ballare",
    "ballabili": "ballabile",
    "ballai": "ballare",
    "ballammo": "ballare",
    "ballan": "ballare",
    "ballando": "ballare",
    "ballano": "ballare",
    "ballante": "ballare",
    "ballanti": "ballare",
    "ballar": "ballare",
    "ballaron": "ballare",
    "ballarono": "ballare",
    "ballasse": "ballare",
    "ballasser": "ballare",
    "ballassero": "ballare",
    "ballassi": "ballare",
    "ballassimo": "ballare",
    "ballaste": "ballare",
    "ballasti": "ballare",
    "ballata": "ballare",
    "ballate": "ballata",
    "ballati": "ballare",
    "ballato": "ballare",
    "ballatoi": "ballatoio",
    "ballava": "ballare",
    "ballavamo": "ballare",
    "ballavan": "ballare",
    "ballavano": "ballare",
    "ballavate": "ballare",
    "ballavi": "ballare",
    "ballavo": "ballare",
    "balle": "balla",
    "ballerai": "ballare",
    "balleran": "ballare",
    "balleranno": "ballare",
    "ballerebbe": "ballare",
    "ballerebber": "ballare",
    "ballerebbero": "ballare",
    "ballerei": "ballare",
    "balleremmo": "ballare",
    "balleremo": "ballare",
    "ballereste": "ballare",
    "balleresti": "ballare",
    "ballerete": "ballare",
    "ballerina": "ballerino",
    "ballerine": "ballerino",
    "ballerini": "ballerino",
    "ballerà": "ballare",
    "ballerò": "ballare",
    "balletti": "balletto",
    "balli": "ballo",
    "balliamo": "ballare",
    "balliate": "ballare",
    "ballin": "ballare",
    "ballino": "ballare",
    "ballo": "ballare",
    "ballonzola": "ballonzolare",
    "ballonzolai": "ballonzolare",
    "ballonzolammo": "ballonzolare",
    "ballonzolan": "ballonzolare",
    "ballonzolando": "ballonzolare",
    "ballonzolano": "ballonzolare",
    "ballonzolante": "ballonzolare",
    "ballonzolanti": "ballonzolare",
    "ballonzolar": "ballonzolare",
    "ballonzolaron": "ballonzolare",
    "ballonzolarono": "ballonzolare",
    "ballonzolasse": "ballonzolare",
    "ballonzolasser": "ballonzolare",
    "ballonzolassero": "ballonzolare",
    "ballonzolassi": "ballonzolare",
    "ballonzolassimo": "ballonzolare",
    "ballonzolaste": "ballonzolare",
    "ballonzolasti": "ballonzolare",
    "ballonzolata": "ballonzolare",
    "ballonzolate": "ballonzolare",
    "ballonzolati": "ballonzolare",
    "ballonzolato": "ballonzolare",
    "ballonzolava": "ballonzolare",
    "ballonzolavamo": "ballonzolare",
    "ballonzolavan": "ballonzolare",
    "ballonzolavano": "ballonzolare",
    "ballonzolavate": "ballonzolare",
    "ballonzolavi": "ballonzolare",
    "ballonzolavo": "ballonzolare",
    "ballonzolerai": "ballonzolare",
    "ballonzoleran": "ballonzolare",
    "ballonzoleranno": "ballonzolare",
    "ballonzolerebbe": "ballonzolare",
    "ballonzolerebber": "ballonzolare",
    "ballonzolerebbero": "ballonzolare",
    "ballonzolerei": "ballonzolare",
    "ballonzoleremmo": "ballonzolare",
    "ballonzoleremo": "ballonzolare",
    "ballonzolereste": "ballonzolare",
    "ballonzoleresti": "ballonzolare",
    "ballonzolerete": "ballonzolare",
    "ballonzolerà": "ballonzolare",
    "ballonzolerò": "ballonzolare",
    "ballonzoli": "ballonzolare",
    "ballonzoliamo": "ballonzolare",
    "ballonzoliate": "ballonzolare",
    "ballonzolin": "ballonzolare",
    "ballonzolino": "ballonzolare",
    "ballonzolo": "ballonzolare",
    "ballonzolò": "ballonzolare",
    "ballotaggi": "ballotaggio",
    "ballotta": "ballottare",
    "ballottaggi": "ballottaggio",
    "ballottai": "ballottare",
    "ballottammo": "ballottare",
    "ballottan": "ballottare",
    "ballottando": "ballottare",
    "ballottano": "ballottare",
    "ballottante": "ballottare",
    "ballottanti": "ballottare",
    "ballottar": "ballottare",
    "ballottaron": "ballottare",
    "ballottarono": "ballottare",
    "ballottasse": "ballottare",
    "ballottasser": "ballottare",
    "ballottassero": "ballottare",
    "ballottassi": "ballottare",
    "ballottassimo": "ballottare",
    "ballottaste": "ballottare",
    "ballottasti": "ballottare",
    "ballottata": "ballottare",
    "ballottate": "ballottare",
    "ballottati": "ballottare",
    "ballottato": "ballottare",
    "ballottava": "ballottare",
    "ballottavamo": "ballottare",
    "ballottavan": "ballottare",
    "ballottavano": "ballottare",
    "ballottavate": "ballottare",
    "ballottavi": "ballottare",
    "ballottavo": "ballottare",
    "ballotterai": "ballottare",
    "ballotteran": "ballottare",
    "ballotteranno": "ballottare",
    "ballotterebbe": "ballottare",
    "ballotterebber": "ballottare",
    "ballotterebbero": "ballottare",
    "ballotterei": "ballottare",
    "ballotteremmo": "ballottare",
    "ballotteremo": "ballottare",
    "ballottereste": "ballottare",
    "ballotteresti": "ballottare",
    "ballotterete": "ballottare",
    "ballotterà": "ballottare",
    "ballotterò": "ballottare",
    "ballotti": "ballottare",
    "ballottiamo": "ballottare",
    "ballottiate": "ballottare",
    "ballottin": "ballottare",
    "ballottino": "ballottare",
    "ballotto": "ballottare",
    "ballottò": "ballottare",
    "ballò": "ballare",
    "balnea": "balneare",
    "balneai": "balneare",
    "balneammo": "balneare",
    "balnean": "balneare",
    "balneando": "balneare",
    "balneano": "balneare",
    "balneante": "balneare",
    "balneanti": "balneare",
    "balnear": "balneare",
    "balneari": "balneare",
    "balnearon": "balneare",
    "balnearono": "balneare",
    "balneasse": "balneare",
    "balneasser": "balneare",
    "balneassero": "balneare",
    "balneassi": "balneare",
    "balneassimo": "balneare",
    "balneaste": "balneare",
    "balneasti": "balneare",
    "balneata": "balneare",
    "balneate": "balneare",
    "balneati": "balneare",
    "balneato": "balneare",
    "balneava": "balneare",
    "balneavamo": "balneare",
    "balneavan": "balneare",
    "balneavano": "balneare",
    "balneavate": "balneare",
    "balneavi": "balneare",
    "balneavo": "balneare",
    "balneazioni": "balneazione",
    "balneerai": "balneare",
    "balneeran": "balneare",
    "balneeranno": "balneare",
    "balneerebbe": "balneare",
    "balneerebber": "balneare",
    "balneerebbero": "balneare",
    "balneerei": "balneare",
    "balneeremmo": "balneare",
    "balneeremo": "balneare",
    "balneereste": "balneare",
    "balneeresti": "balneare",
    "balneerete": "balneare",
    "balneerà": "balneare",
    "balneerò": "balneare",
    "balnei": "balneare",
    "balneiamo": "balneare",
    "balneiate": "balneare",
    "balnein": "balneare",
    "balneino": "balneare",
    "balneo": "balneare",
    "balneò": "balneare",
    "balocca": "baloccare",
    "baloccai": "baloccare",
    "baloccammo": "baloccare",
    "baloccan": "baloccare",
    "baloccando": "baloccare",
    "baloccano": "baloccare",
    "baloccante": "baloccare",
    "baloccanti": "baloccare",
    "baloccar": "baloccare",
    "baloccaron": "baloccare",
    "baloccarono": "baloccare",
    "baloccasse": "baloccare",
    "baloccasser": "baloccare",
    "baloccassero": "baloccare",
    "baloccassi": "baloccare",
    "baloccassimo": "baloccare",
    "baloccaste": "baloccare",
    "baloccasti": "baloccare",
    "baloccata": "baloccare",
    "baloccate": "baloccare",
    "baloccati": "baloccare",
    "baloccato": "baloccare",
    "baloccava": "baloccare",
    "baloccavamo": "baloccare",
    "baloccavan": "baloccare",
    "baloccavano": "baloccare",
    "baloccavate": "baloccare",
    "baloccavi": "baloccare",
    "baloccavo": "baloccare",
    "baloccherai": "baloccare",
    "baloccheran": "baloccare",
    "baloccheranno": "baloccare",
    "baloccherebbe": "baloccare",
    "baloccherebber": "baloccare",
    "baloccherebbero": "baloccare",
    "baloccherei": "baloccare",
    "baloccheremmo": "baloccare",
    "baloccheremo": "baloccare",
    "balocchereste": "baloccare",
    "baloccheresti": "baloccare",
    "baloccherete": "baloccare",
    "baloccherà": "baloccare",
    "baloccherò": "baloccare",
    "balocchi": "balocco",
    "balocchiamo": "baloccare",
    "balocchiate": "baloccare",
    "balocchin": "baloccare",
    "balocchino": "baloccare",
    "balocco": "baloccare",
    "baloccò": "baloccare",
    "balorda": "balordo",
    "balorde": "balordo",
    "balordi": "balordo",
    "balsami": "balsamo",
    "balsamica": "balsamico",
    "balsamiche": "balsamico",
    "balsamici": "balsamico",
    "baltici": "baltico",
    "baluardi": "baluardo",
    "balugina": "baluginare",
    "baluginai": "baluginare",
    "baluginammo": "baluginare",
    "baluginan": "baluginare",
    "baluginando": "baluginare",
    "baluginano": "baluginare",
    "baluginante": "baluginare",
    "baluginanti": "baluginare",
    "baluginar": "baluginare",
    "baluginaron": "baluginare",
    "baluginarono": "baluginare",
    "baluginasse": "baluginare",
    "baluginasser": "baluginare",
    "baluginassero": "baluginare",
    "baluginassi": "baluginare",
    "baluginassimo": "baluginare",
    "baluginaste": "baluginare",
    "baluginasti": "baluginare",
    "baluginata": "baluginare",
    "baluginate": "baluginare",
    "baluginati": "baluginare",
    "baluginato": "baluginare",
    "baluginava": "baluginare",
    "baluginavamo": "baluginare",
    "baluginavan": "baluginare",
    "baluginavano": "baluginare",
    "baluginavate": "baluginare",
    "baluginavi": "baluginare",
    "baluginavo": "baluginare",
    "baluginerai": "baluginare",
    "balugineran": "baluginare",
    "balugineranno": "baluginare",
    "baluginerebbe": "baluginare",
    "baluginerebber": "baluginare",
    "baluginerebbero": "baluginare",
    "baluginerei": "baluginare",
    "balugineremmo": "baluginare",
    "balugineremo": "baluginare",
    "baluginereste": "baluginare",
    "balugineresti": "baluginare",
    "baluginerete": "baluginare",
    "baluginerà": "baluginare",
    "baluginerò": "baluginare",
    "balugini": "baluginare",
    "baluginiamo": "baluginare",
    "baluginiate": "baluginare",
    "baluginin": "baluginare",
    "baluginino": "baluginare",
    "balugino": "baluginare",
    "baluginò": "baluginare",
    "balza": "balzare",
    "balzai": "balzare",
    "balzammo": "balzare",
    "balzan": "balzare",
    "balzana": "balzano",
    "balzando": "balzare",
    "balzane": "balzano",
    "balzani": "balzano",
    "balzano": "balzare",
    "balzante": "balzare",
    "balzanti": "balzare",
    "balzar": "balzare",
    "balzaron": "balzare",
    "balzarono": "balzare",
    "balzasse": "balzare",
    "balzasser": "balzare",
    "balzassero": "balzare",
    "balzassi": "balzare",
    "balzassimo": "balzare",
    "balzaste": "balzare",
    "balzasti": "balzare",
    "balzata": "balzare",
    "balzate": "balzare",
    "balzati": "balzare",
    "balzato": "balzare",
    "balzava": "balzare",
    "balzavamo": "balzare",
    "balzavan": "balzare",
    "balzavano": "balzare",
    "balzavate": "balzare",
    "balzavi": "balzare",
    "balzavo": "balzare",
    "balzella": "balzellare",
    "balzellai": "balzellare",
    "balzellammo": "balzellare",
    "balzellan": "balzellare",
    "balzellando": "balzellare",
    "balzellano": "balzellare",
    "balzellante": "balzellare",
    "balzellanti": "balzellare",
    "balzellar": "balzellare",
    "balzellaron": "balzellare",
    "balzellarono": "balzellare",
    "balzellasse": "balzellare",
    "balzellasser": "balzellare",
    "balzellassero": "balzellare",
    "balzellassi": "balzellare",
    "balzellassimo": "balzellare",
    "balzellaste": "balzellare",
    "balzellasti": "balzellare",
    "balzellata": "balzellare",
    "balzellate": "balzellare",
    "balzellati": "balzellare",
    "balzellato": "balzellare",
    "balzellava": "balzellare",
    "balzellavamo": "balzellare",
    "balzellavan": "balzellare",
    "balzellavano": "balzellare",
    "balzellavate": "balzellare",
    "balzellavi": "balzellare",
    "balzellavo": "balzellare",
    "balzellerai": "balzellare",
    "balzelleran": "balzellare",
    "balzelleranno": "balzellare",
    "balzellerebbe": "balzellare",
    "balzellerebber": "balzellare",
    "balzellerebbero": "balzellare",
    "balzellerei": "balzellare",
    "balzelleremmo": "balzellare",
    "balzelleremo": "balzellare",
    "balzellereste": "balzellare",
    "balzelleresti": "balzellare",
    "balzellerete": "balzellare",
    "balzellerà": "balzellare",
    "balzellerò": "balzellare",
    "balzelli": "balzello",
    "balzelliamo": "balzellare",
    "balzelliate": "balzellare",
    "balzellin": "balzellare",
    "balzellino": "balzellare",
    "balzello": "balzellare",
    "balzellò": "balzellare",
    "balzerai": "balzare",
    "balzeran": "balzare",
    "balzeranno": "balzare",
    "balzerebbe": "balzare",
    "balzerebber": "balzare",
    "balzerebbero": "balzare",
    "balzerei": "balzare",
    "balzeremmo": "balzare",
    "balzeremo": "balzare",
    "balzereste": "balzare",
    "balzeresti": "balzare",
    "balzerete": "balzare",
    "balzerà": "balzare",
    "balzerò": "balzare",
    "balzi": "balzo",
    "balziamo": "balzare",
    "balziate": "balzare",
    "balzin": "balzare",
    "balzino": "balzare",
    "balzo": "balzare",
    "balzò": "balzare",
    "bambinacce": "bambinaccia",
    "bambinacci": "bambinaccio",
    "bambinaie": "bambinaia",
    "bambine": "bambina",
    "bambineggerai": "bambineggiare",
    "bambineggeran": "bambineggiare",
    "bambineggeranno": "bambineggiare",
    "bambineggerebbe": "bambineggiare",
    "bambineggerebber": "bambineggiare",
    "bambineggerebbero": "bambineggiare",
    "bambineggerei": "bambineggiare",
    "bambineggeremmo": "bambineggiare",
    "bambineggeremo": "bambineggiare",
    "bambineggereste": "bambineggiare",
    "bambineggeresti": "bambineggiare",
    "bambineggerete": "bambineggiare",
    "bambineggerà": "bambineggiare",
    "bambineggerò": "bambineggiare",
    "bambineggi": "bambineggiare",
    "bambineggia": "bambineggiare",
    "bambineggiai": "bambineggiare",
    "bambineggiammo": "bambineggiare",
    "bambineggiamo": "bambineggiare",
    "bambineggian": "bambineggiare",
    "bambineggiando": "bambineggiare",
    "bambineggiano": "bambineggiare",
    "bambineggiante": "bambineggiare",
    "bambineggianti": "bambineggiare",
    "bambineggiar": "bambineggiare",
    "bambineggiaron": "bambineggiare",
    "bambineggiarono": "bambineggiare",
    "bambineggiasse": "bambineggiare",
    "bambineggiasser": "bambineggiare",
    "bambineggiassero": "bambineggiare",
    "bambineggiassi": "bambineggiare",
    "bambineggiassimo": "bambineggiare",
    "bambineggiaste": "bambineggiare",
    "bambineggiasti": "bambineggiare",
    "bambineggiata": "bambineggiare",
    "bambineggiate": "bambineggiare",
    "bambineggiati": "bambineggiare",
    "bambineggiato": "bambineggiare",
    "bambineggiava": "bambineggiare",
    "bambineggiavamo": "bambineggiare",
    "bambineggiavan": "bambineggiare",
    "bambineggiavano": "bambineggiare",
    "bambineggiavate": "bambineggiare",
    "bambineggiavi": "bambineggiare",
    "bambineggiavo": "bambineggiare",
    "bambineggin": "bambineggiare",
    "bambineggino": "bambineggiare",
    "bambineggio": "bambineggiare",
    "bambineggiò": "bambineggiare",
    "bambinelli": "bambinello",
    "bambinesca": "bambinesco",
    "bambinesche": "bambinesco",
    "bambineschi": "bambinesco",
    "bambinette": "bambinetta",
    "bambini": "bambino",
    "bambinoni": "bambinone",
    "bambocci": "bamboccio",
    "bambole": "bambola",
    "bamboleggerai": "bamboleggiare",
    "bamboleggeran": "bamboleggiare",
    "bamboleggeranno": "bamboleggiare",
    "bamboleggerebbe": "bamboleggiare",
    "bamboleggerebber": "bamboleggiare",
    "bamboleggerebbero": "bamboleggiare",
    "bamboleggerei": "bamboleggiare",
    "bamboleggeremmo": "bamboleggiare",
    "bamboleggeremo": "bamboleggiare",
    "bamboleggereste": "bamboleggiare",
    "bamboleggeresti": "bamboleggiare",
    "bamboleggerete": "bamboleggiare",
    "bamboleggerà": "bamboleggiare",
    "bamboleggerò": "bamboleggiare",
    "bamboleggi": "bamboleggiare",
    "bamboleggia": "bamboleggiare",
    "bamboleggiai": "bamboleggiare",
    "bamboleggiamenti": "bamboleggiamento",
    "bamboleggiammo": "bamboleggiare",
    "bamboleggiamo": "bamboleggiare",
    "bamboleggian": "bamboleggiare",
    "bamboleggiando": "bamboleggiare",
    "bamboleggiano": "bamboleggiare",
    "bamboleggiante": "bamboleggiare",
    "bamboleggianti": "bamboleggiare",
    "bamboleggiar": "bamboleggiare",
    "bamboleggiaron": "bamboleggiare",
    "bamboleggiarono": "bamboleggiare",
    "bamboleggiasse": "bamboleggiare",
    "bamboleggiasser": "bamboleggiare",
    "bamboleggiassero": "bamboleggiare",
    "bamboleggiassi": "bamboleggiare",
    "bamboleggiassimo": "bamboleggiare",
    "bamboleggiaste": "bamboleggiare",
    "bamboleggiasti": "bamboleggiare",
    "bamboleggiata": "bamboleggiare",
    "bamboleggiate": "bamboleggiare",
    "bamboleggiati": "bamboleggiare",
    "bamboleggiato": "bamboleggiare",
    "bamboleggiava": "bamboleggiare",
    "bamboleggiavamo": "bamboleggiare",
    "bamboleggiavan": "bamboleggiare",
    "bamboleggiavano": "bamboleggiare",
    "bamboleggiavate": "bamboleggiare",
    "bamboleggiavi": "bamboleggiare",
    "bamboleggiavo": "bamboleggiare",
    "bamboleggin": "bamboleggiare",
    "bamboleggino": "bamboleggiare",
    "bamboleggio": "bamboleggiare",
    "bamboleggiò": "bamboleggiare",
    "bambolette": "bamboletta",
    "bamboline": "bambolina",
    "bambolone": "bambolona",
    "bambolotti": "bambolotto",
    "banali": "banale",
    "banalizza": "banalizzare",
    "banalizzai": "banalizzare",
    "banalizzammo": "banalizzare",
    "banalizzan": "banalizzare",
    "banalizzando": "banalizzare",
    "banalizzano": "banalizzare",
    "banalizzante": "banalizzare",
    "banalizzanti": "banalizzare",
    "banalizzar": "banalizzare",
    "banalizzaron": "banalizzare",
    "banalizzarono": "banalizzare",
    "banalizzasse": "banalizzare",
    "banalizzasser": "banalizzare",
    "banalizzassero": "banalizzare",
    "banalizzassi": "banalizzare",
    "banalizzassimo": "banalizzare",
    "banalizzaste": "banalizzare",
    "banalizzasti": "banalizzare",
    "banalizzata": "banalizzare",
    "banalizzate": "banalizzare",
    "banalizzati": "banalizzare",
    "banalizzato": "banalizzare",
    "banalizzava": "banalizzare",
    "banalizzavamo": "banalizzare",
    "banalizzavan": "banalizzare",
    "banalizzavano": "banalizzare",
    "banalizzavate": "banalizzare",
    "banalizzavi": "banalizzare",
    "banalizzavo": "banalizzare",
    "banalizzazioni": "banalizzazione",
    "banalizzerai": "banalizzare",
    "banalizzeran": "banalizzare",
    "banalizzeranno": "banalizzare",
    "banalizzerebbe": "banalizzare",
    "banalizzerebber": "banalizzare",
    "banalizzerebbero": "banalizzare",
    "banalizzerei": "banalizzare",
    "banalizzeremmo": "banalizzare",
    "banalizzeremo": "banalizzare",
    "banalizzereste": "banalizzare",
    "banalizzeresti": "banalizzare",
    "banalizzerete": "banalizzare",
    "banalizzerà": "banalizzare",
    "banalizzerò": "banalizzare",
    "banalizzi": "banalizzare",
    "banalizziamo": "banalizzare",
    "banalizziate": "banalizzare",
    "banalizzin": "banalizzare",
    "banalizzino": "banalizzare",
    "banalizzo": "banalizzare",
    "banalizzò": "banalizzare",
    "banane": "banana",
    "banani": "banano",
    "bananiera": "bananiero",
    "bananiere": "bananiero",
    "bananieri": "bananiero",
    "bancarelle": "bancarella",
    "bancari": "bancario",
    "bancaria": "bancario",
    "bancarie": "bancario",
    "bancarotte": "bancarotta",
    "bancarottieri": "bancarottiere",
    "banche": "banca",
    "banche-dati": "banca-dati",
    "banchetta": "banchettare",
    "banchettai": "banchettare",
    "banchettammo": "banchettare",
    "banchettan": "banchettare",
    "banchettando": "banchettare",
    "banchettano": "banchettare",
    "banchettante": "banchettare",
    "banchettanti": "banchettare",
    "banchettar": "banchettare",
    "banchettaron": "banchettare",
    "banchettarono": "banchettare",
    "banchettasse": "banchettare",
    "banchettasser": "banchettare",
    "banchettassero": "banchettare",
    "banchettassi": "banchettare",
    "banchettassimo": "banchettare",
    "banchettaste": "banchettare",
    "banchettasti": "banchettare",
    "banchettata": "banchettare",
    "banchettate": "banchettare",
    "banchettati": "banchettare",
    "banchettato": "banchettare",
    "banchettava": "banchettare",
    "banchettavamo": "banchettare",
    "banchettavan": "banchettare",
    "banchettavano": "banchettare",
    "banchettavate": "banchettare",
    "banchettavi": "banchettare",
    "banchettavo": "banchettare",
    "banchetterai": "banchettare",
    "banchetteran": "banchettare",
    "banchetteranno": "banchettare",
    "banchetterebbe": "banchettare",
    "banchetterebber": "banchettare",
    "banchetterebbero": "banchettare",
    "banchetterei": "banchettare",
    "banchetteremmo": "banchettare",
    "banchetteremo": "banchettare",
    "banchettereste": "banchettare",
    "banchetteresti": "banchettare",
    "banchetterete": "banchettare",
    "banchetterà": "banchettare",
    "banchetterò": "banchettare",
    "banchetti": "banchetto",
    "banchettiamo": "banchettare",
    "banchettiate": "banchettare",
    "banchettin": "banchettare",
    "banchettino": "banchettare",
    "banchetto": "banchettare",
    "banchettò": "banchettare",
    "banchi": "banco",
    "banchieri": "banchiere",
    "banchine": "banchina",
    "banconi": "bancone",
    "banconote": "banconota",
    "bandane": "bandana",
    "bande": "banda",
    "bandendo": "bandire",
    "bandente": "bandire",
    "bandenti": "bandire",
    "banderuole": "banderuola",
    "bandi": "bando",
    "bandiamo": "bandire",
    "bandiate": "bandire",
    "bandiere": "bandiera",
    "bandierine": "bandierina",
    "bandieroni": "bandierone",
    "bandii": "bandire",
    "bandimmo": "bandire",
    "bandir": "bandire",
    "bandirai": "bandire",
    "bandiran": "bandire",
    "bandiranno": "bandire",
    "bandirebbe": "bandire",
    "bandirebber": "bandire",
    "bandirebbero": "bandire",
    "bandirei": "bandire",
    "bandiremmo": "bandire",
    "bandiremo": "bandire",
    "bandireste": "bandire",
    "bandiresti": "bandire",
    "bandirete": "bandire",
    "bandiron": "bandire",
    "bandirono": "bandire",
    "bandirà": "bandire",
    "bandirò": "bandire",
    "bandisca": "bandire",
    "bandiscan": "bandire",
    "bandiscano": "bandire",
    "bandisce": "bandire",
    "bandisci": "bandire",
    "bandisco": "bandire",
    "bandiscon": "bandire",
    "bandiscono": "bandire",
    "bandisse": "bandire",
    "bandisser": "bandire",
    "bandissero": "bandire",
    "bandissi": "bandire",
    "bandissimo": "bandire",
    "bandiste": "bandire",
    "bandisti": "bandire",
    "bandita": "bandire",
    "bandite": "bandire",
    "banditi": "bandito",
    "banditismi": "banditismo",
    "bandito": "bandire",
    "banditori": "banditore",
    "bandiva": "bandire",
    "bandivamo": "bandire",
    "bandivan": "bandire",
    "bandivano": "bandire",
    "bandivate": "bandire",
    "bandivi": "bandire",
    "bandivo": "bandire",
    "bandoli": "bandolo",
    "bandì": "bandire",
    "bara": "barare",
    "baracche": "baracca",
    "baracchette": "baracchetta",
    "baracchini": "baracchino",
    "baracconate": "baracconata",
    "baracconi": "baraccone",
    "barai": "barare",
    "barammo": "barare",
    "baran": "barare",
    "barando": "barare",
    "barano": "barare",
    "barante": "barare",
    "baranti": "barare",
    "baraonde": "baraonda",
    "barar": "barare",
    "bararon": "barare",
    "bararono": "barare",
    "barasse": "barare",
    "barasser": "barare",
    "barassero": "barare",
    "barassi": "barare",
    "barassimo": "barare",
    "baraste": "barare",
    "barasti": "barare",
    "barata": "barare",
    "barate": "barare",
    "barati": "barare",
    "barato": "barare",
    "baratri": "baratro",
    "baratta": "barattare",
    "barattai": "barattare",
    "barattammo": "barattare",
    "barattan": "barattare",
    "barattando": "barattare",
    "barattano": "barattare",
    "barattante": "barattare",
    "barattanti": "barattare",
    "barattar": "barattare",
    "barattaron": "barattare",
    "barattarono": "barattare",
    "barattasse": "barattare",
    "barattasser": "barattare",
    "barattassero": "barattare",
    "barattassi": "barattare",
    "barattassimo": "barattare",
    "barattaste": "barattare",
    "barattasti": "barattare",
    "barattata": "barattare",
    "barattate": "barattare",
    "barattati": "barattare",
    "barattato": "barattare",
    "barattava": "barattare",
    "barattavamo": "barattare",
    "barattavan": "barattare",
    "barattavano": "barattare",
    "barattavate": "barattare",
    "barattavi": "barattare",
    "barattavo": "barattare",
    "baratterai": "barattare",
    "baratteran": "barattare",
    "baratteranno": "barattare",
    "baratterebbe": "barattare",
    "baratterebber": "barattare",
    "baratterebbero": "barattare",
    "baratterei": "barattare",
    "baratteremmo": "barattare",
    "baratteremo": "barattare",
    "barattereste": "barattare",
    "baratteresti": "barattare",
    "baratterete": "barattare",
    "baratterà": "barattare",
    "baratterò": "barattare",
    "baratti": "baratto",
    "barattiamo": "barattare",
    "barattiate": "barattare",
    "barattin": "barattare",
    "barattino": "barattare",
    "baratto": "barattare",
    "barattoli": "barattolo",
    "barattò": "barattare",
    "barava": "barare",
    "baravamo": "barare",
    "baravan": "barare",
    "baravano": "barare",
    "baravate": "barare",
    "baravi": "barare",
    "baravo": "barare",
    "barbabietole": "barbabietola",
    "barbagli": "barbaglio",
    "barbara": "barbaro",
    "barbare": "barbaro",
    "barbaresca": "barbaresco",
    "barbaresche": "barbaresco",
    "barbareschi": "barbaresco",
    "barbari": "barbaro",
    "barbarica": "barbarico",
    "barbariche": "barbarico",
    "barbarici": "barbarico",
    "barbarismi": "barbarismo",
    "barbata": "barbato",
    "barbate": "barbato",
    "barbati": "barbato",
    "barbe": "barba",
    "barbette": "barbetta",
    "barbieri": "barbiere",
    "barbina": "barbino",
    "barbine": "barbino",
    "barbini": "barbino",
    "barbiturici": "barbiturico",
    "barboncini": "barboncino",
    "barbone": "barbona",
    "barboni": "barbone",
    "barbosa": "barboso",
    "barbose": "barboso",
    "barbosi": "barboso",
    "barbugli": "barbugliare",
    "barbuglia": "barbugliare",
    "barbugliai": "barbugliare",
    "barbugliammo": "barbugliare",
    "barbugliamo": "barbugliare",
    "barbuglian": "barbugliare",
    "barbugliando": "barbugliare",
    "barbugliano": "barbugliare",
    "barbugliante": "barbugliare",
    "barbuglianti": "barbugliare",
    "barbugliar": "barbugliare",
    "barbugliaron": "barbugliare",
    "barbugliarono": "barbugliare",
    "barbugliasse": "barbugliare",
    "barbugliasser": "barbugliare",
    "barbugliassero": "barbugliare",
    "barbugliassi": "barbugliare",
    "barbugliassimo": "barbugliare",
    "barbugliaste": "barbugliare",
    "barbugliasti": "barbugliare",
    "barbugliata": "barbugliare",
    "barbugliate": "barbugliare",
    "barbugliati": "barbugliare",
    "barbugliato": "barbugliare",
    "barbugliava": "barbugliare",
    "barbugliavamo": "barbugliare",
    "barbugliavan": "barbugliare",
    "barbugliavano": "barbugliare",
    "barbugliavate": "barbugliare",
    "barbugliavi": "barbugliare",
    "barbugliavo": "barbugliare",
    "barbuglierai": "barbugliare",
    "barbuglieran": "barbugliare",
    "barbuglieranno": "barbugliare",
    "barbuglierebbe": "barbugliare",
    "barbuglierebber": "barbugliare",
    "barbuglierebbero": "barbugliare",
    "barbuglierei": "barbugliare",
    "barbuglieremmo": "barbugliare",
    "barbuglieremo": "barbugliare",
    "barbugliereste": "barbugliare",
    "barbuglieresti": "barbugliare",
    "barbuglierete": "barbugliare",
    "barbuglierà": "barbugliare",
    "barbuglierò": "barbugliare",
    "barbuglin": "barbugliare",
    "barbuglino": "barbugliare",
    "barbuglio": "barbugliare",
    "barbugliò": "barbugliare",
    "barbuta": "barbuto",
    "barbute": "barbuto",
    "barbuti": "barbuto",
    "barcaioli": "barcaiolo",
    "barcamena": "barcamenare",
    "barcamenai": "barcamenare",
    "barcamenammo": "barcamenare",
    "barcamenan": "barcamenare",
    "barcamenando": "barcamenare",
    "barcamenano": "barcamenare",
    "barcamenar": "barcamenare",
    "barcamenaron": "barcamenare",
    "barcamenarono": "barcamenare",
    "barcamenasse": "barcamenare",
    "barcamenasser": "barcamenare",
    "barcamenassero": "barcamenare",
    "barcamenassi": "barcamenare",
    "barcamenassimo": "barcamenare",
    "barcamenaste": "barcamenare",
    "barcamenasti": "barcamenare",
    "barcamenata": "barcamenare",
    "barcamenate": "barcamenare",
    "barcamenati": "barcamenare",
    "barcamenato": "barcamenare",
    "barcamenava": "barcamenare",
    "barcamenavamo": "barcamenare",
    "barcamenavan": "barcamenare",
    "barcamenavano": "barcamenare",
    "barcamenavate": "barcamenare",
    "barcamenavi": "barcamenare",
    "barcamenavo": "barcamenare",
    "barcamenerai": "barcamenare",
    "barcameneran": "barcamenare",
    "barcameneranno": "barcamenare",
    "barcamenerebbe": "barcamenare",
    "barcamenerebber": "barcamenare",
    "barcamenerebbero": "barcamenare",
    "barcamenerei": "barcamenare",
    "barcameneremmo": "barcamenare",
    "barcameneremo": "barcamenare",
    "barcamenereste": "barcamenare",
    "barcameneresti": "barcamenare",
    "barcamenerete": "barcamenare",
    "barcamenerà": "barcamenare",
    "barcamenerò": "barcamenare",
    "barcameni": "barcamenare",
    "barcameniamo": "barcamenare",
    "barcameniate": "barcamenare",
    "barcamenin": "barcamenare",
    "barcamenino": "barcamenare",
    "barcameno": "barcamenare",
    "barcamenò": "barcamenare",
    "barcelloneggianti": "barcelloneggiante",
    "barche": "barca",
    "barchette": "barchetta",
    "barchini": "barchino",
    "barcolla": "barcollare",
    "barcollai": "barcollare",
    "barcollammo": "barcollare",
    "barcollan": "barcollare",
    "barcollando": "barcollare",
    "barcollano": "barcollare",
    "barcollante": "barcollare",
    "barcollanti": "barcollare",
    "barcollar": "barcollare",
    "barcollaron": "barcollare",
    "barcollarono": "barcollare",
    "barcollasse": "barcollare",
    "barcollasser": "barcollare",
    "barcollassero": "barcollare",
    "barcollassi": "barcollare",
    "barcollassimo": "barcollare",
    "barcollaste": "barcollare",
    "barcollasti": "barcollare",
    "barcollata": "barcollare",
    "barcollate": "barcollare",
    "barcollati": "barcollare",
    "barcollato": "barcollare",
    "barcollava": "barcollare",
    "barcollavamo": "barcollare",
    "barcollavan": "barcollare",
    "barcollavano": "barcollare",
    "barcollavate": "barcollare",
    "barcollavi": "barcollare",
    "barcollavo": "barcollare",
    "barcollerai": "barcollare",
    "barcolleran": "barcollare",
    "barcolleranno": "barcollare",
    "barcollerebbe": "barcollare",
    "barcollerebber": "barcollare",
    "barcollerebbero": "barcollare",
    "barcollerei": "barcollare",
    "barcolleremmo": "barcollare",
    "barcolleremo": "barcollare",
    "barcollereste": "barcollare",
    "barcolleresti": "barcollare",
    "barcollerete": "barcollare",
    "barcollerà": "barcollare",
    "barcollerò": "barcollare",
    "barcolli": "barcollare",
    "barcolliamo": "barcollare",
    "barcolliate": "barcollare",
    "barcollin": "barcollare",
    "barcollino": "barcollare",
    "barcollo": "barcollare",
    "barcollò": "barcollare",
    "barconi": "barcone",
    "barda": "bardare",
    "bardai": "bardare",
    "bardammo": "bardare",
    "bardan": "bardare",
    "bardando": "bardare",
    "bardano": "bardare",
    "bardante": "bardare",
    "bardanti": "bardare",
    "bardar": "bardare",
    "bardaron": "bardare",
    "bardarono": "bardare",
    "bardasse": "bardare",
    "bardasser": "bardare",
    "bardassero": "bardare",
    "bardassi": "bardare",
    "bardassimo": "bardare",
    "bardaste": "bardare",
    "bardasti": "bardare",
    "bardata": "bardare",
    "bardate": "bardare",
    "bardati": "bardare",
    "bardato": "bardare",
    "bardature": "bardatura",
    "bardava": "bardare",
    "bardavamo": "bardare",
    "bardavan": "bardare",
    "bardavano": "bardare",
    "bardavate": "bardare",
    "bardavi": "bardare",
    "bardavo": "bardare",
    "barderai": "bardare",
    "barderan": "bardare",
    "barderanno": "bardare",
    "barderebbe": "bardare",
    "barderebber": "bardare",
    "barderebbero": "bardare",
    "barderei": "bardare",
    "barderemmo": "bardare",
    "barderemo": "bardare",
    "bardereste": "bardare",
    "barderesti": "bardare",
    "barderete": "bardare",
    "barderà": "bardare",
    "barderò": "bardare",
    "bardi": "bardo",
    "bardiamo": "bardare",
    "bardiate": "bardare",
    "bardin": "bardare",
    "bardino": "bardare",
    "bardo": "bardare",
    "bardò": "bardare",
    "bare": "bara",
    "barella": "barellare",
    "barellai": "barellare",
    "barellammo": "barellare",
    "barellan": "barellare",
    "barellando": "barellare",
    "barellano": "barellare",
    "barellante": "barellare",
    "barellanti": "barellare",
    "barellar": "barellare",
    "barellaron": "barellare",
    "barellarono": "barellare",
    "barellasse": "barellare",
    "barellasser": "barellare",
    "barellassero": "barellare",
    "barellassi": "barellare",
    "barellassimo": "barellare",
    "barellaste": "barellare",
    "barellasti": "barellare",
    "barellata": "barellare",
    "barellate": "barellare",
    "barellati": "barellare",
    "barellato": "barellare",
    "barellava": "barellare",
    "barellavamo": "barellare",
    "barellavan": "barellare",
    "barellavano": "barellare",
    "barellavate": "barellare",
    "barellavi": "barellare",
    "barellavo": "barellare",
    "barelle": "barella",
    "barellerai": "barellare",
    "barelleran": "barellare",
    "barelleranno": "barellare",
    "barellerebbe": "barellare",
    "barellerebber": "barellare",
    "barellerebbero": "barellare",
    "barellerei": "barellare",
    "barelleremmo": "barellare",
    "barelleremo": "barellare",
    "barellereste": "barellare",
    "barelleresti": "barellare",
    "barellerete": "barellare",
    "barellerà": "barellare",
    "barellerò": "barellare",
    "barelli": "barellare",
    "barelliamo": "barellare",
    "barelliate": "barellare",
    "barellieri": "barelliere",
    "barellin": "barellare",
    "barellino": "barellare",
    "barello": "barellare",
    "barellò": "barellare",
    "barerai": "barare",
    "bareran": "barare",
    "bareranno": "barare",
    "barerebbe": "barare",
    "barerebber": "barare",
    "barerebbero": "barare",
    "barerei": "barare",
    "bareremmo": "barare",
    "bareremo": "barare",
    "barereste": "barare",
    "bareresti": "barare",
    "barerete": "barare",
    "barerà": "barare",
    "barerò": "barare",
    "baresi": "barese",
    "baretti": "baretto",
    "bari": "baro",
    "bariamo": "barare",
    "bariate": "barare",
    "barica": "barico",
    "baricentri": "baricentro",
    "bariche": "barico",
    "barici": "barico",
    "barili": "barile",
    "barin": "barare",
    "barino": "barare",
    "bariste": "barista",
    "baristi": "barista",
    "baritonali": "baritonale",
    "baritoni": "baritono",
    "barlumi": "barlume",
    "baro": "barare",
    "barocca": "barocco",
    "barocche": "barocco",
    "barocchi": "barocco",
    "barocchismi": "barocchismo",
    "barometri": "barometro",
    "baronesse": "baronessa",
    "baronetti": "baronetto",
    "baroni": "barone",
    "baronie": "baronia",
    "barra": "barrare",
    "barrai": "barrare",
    "barrammo": "barrare",
    "barran": "barrare",
    "barrando": "barrare",
    "barrano": "barrare",
    "barrante": "barrare",
    "barranti": "barrare",
    "barrar": "barrare",
    "barraron": "barrare",
    "barrarono": "barrare",
    "barrasse": "barrare",
    "barrasser": "barrare",
    "barrassero": "barrare",
    "barrassi": "barrare",
    "barrassimo": "barrare",
    "barraste": "barrare",
    "barrasti": "barrare",
    "barrata": "barrare",
    "barrate": "barrare",
    "barrati": "barrare",
    "barrato": "barrare",
    "barrava": "barrare",
    "barravamo": "barrare",
    "barravan": "barrare",
    "barravano": "barrare",
    "barravate": "barrare",
    "barravi": "barrare",
    "barravo": "barrare",
    "barre": "barra",
    "barrendo": "barrire",
    "barrente": "barrire",
    "barrenti": "barrire",
    "barrerai": "barrare",
    "barreran": "barrare",
    "barreranno": "barrare",
    "barrerebbe": "barrare",
    "barrerebber": "barrare",
    "barrerebbero": "barrare",
    "barrerei": "barrare",
    "barreremmo": "barrare",
    "barreremo": "barrare",
    "barrereste": "barrare",
    "barreresti": "barrare",
    "barrerete": "barrare",
    "barrerà": "barrare",
    "barrerò": "barrare",
    "barrette": "barretta",
    "barri": "barrare",
    "barriamo": "barrire",
    "barriate": "barrire",
    "barrica": "barricare",
    "barricai": "barricare",
    "barricammo": "barricare",
    "barrican": "barricare",
    "barricando": "barricare",
    "barricano": "barricare",
    "barricante": "barricare",
    "barricanti": "barricare",
    "barricar": "barricare",
    "barricaron": "barricare",
    "barricarono": "barricare",
    "barricasse": "barricare",
    "barricasser": "barricare",
    "barricassero": "barricare",
    "barricassi": "barricare",
    "barricassimo": "barricare",
    "barricaste": "barricare",
    "barricasti": "barricare",
    "barricata": "barricare",
    "barricate": "barricata",
    "barricati": "barricare",
    "barricato": "barricare",
    "barricava": "barricare",
    "barricavamo": "barricare",
    "barricavan": "barricare",
    "barricavano": "barricare",
    "barricavate": "barricare",
    "barricavi": "barricare",
    "barricavo": "barricare",
    "barricherai": "barricare",
    "barricheran": "barricare",
    "barricheranno": "barricare",
    "barricherebbe": "barricare",
    "barricherebber": "barricare",
    "barricherebbero": "barricare",
    "barricherei": "barricare",
    "barricheremmo": "barricare",
    "barricheremo": "barricare",
    "barrichereste": "barricare",
    "barricheresti": "barricare",
    "barricherete": "barricare",
    "barricherà": "barricare",
    "barricherò": "barricare",
    "barrichi": "barricare",
    "barrichiamo": "barricare",
    "barrichiate": "barricare",
    "barrichin": "barricare",
    "barrichino": "barricare",
    "barrico": "barricare",
    "barricò": "barricare",
    "barriere": "barriera",
    "barrii": "barrire",
    "barrimmo": "barrire",
    "barrin": "barrare",
    "barrino": "barrare",
    "barrios": "barrio",
    "barrir": "barrire",
    "barrirai": "barrire",
    "barriran": "barrire",
    "barriranno": "barrire",
    "barrirebbe": "barrire",
    "barrirebber": "barrire",
    "barrirebbero": "barrire",
    "barrirei": "barrire",
    "barriremmo": "barrire",
    "barriremo": "barrire",
    "barrireste": "barrire",
    "barriresti": "barrire",
    "barrirete": "barrire",
    "barriron": "barrire",
    "barrirono": "barrire",
    "barrirà": "barrire",
    "barrirò": "barrire",
    "barrisca": "barrire",
    "barriscan": "barrire",
    "barriscano": "barrire",
    "barrisce": "barrire",
    "barrisci": "barrire",
    "barrisco": "barrire",
    "barriscon": "barrire",
    "barriscono": "barrire",
    "barrisse": "barrire",
    "barrisser": "barrire",
    "barrissero": "barrire",
    "barrissi": "barrire",
    "barrissimo": "barrire",
    "barriste": "barrire",
    "barristi": "barrire",
    "barrita": "barrire",
    "barrite": "barrire",
    "barriti": "barrire",
    "barrito": "barrire",
    "barriva": "barrire",
    "barrivamo": "barrire",
    "barrivan": "barrire",
    "barrivano": "barrire",
    "barrivate": "barrire",
    "barrivi": "barrire",
    "barrivo": "barrire",
    "barro": "barrare",
    "barrì": "barrire",
    "barrò": "barrare",
    "bartaliana": "bartaliano",
    "bartaliane": "bartaliano",
    "bartaliani": "bartaliano",
    "baruffa": "baruffare",
    "baruffai": "baruffare",
    "baruffammo": "baruffare",
    "baruffan": "baruffare",
    "baruffando": "baruffare",
    "baruffano": "baruffare",
    "baruffante": "baruffare",
    "baruffanti": "baruffare",
    "baruffar": "baruffare",
    "baruffaron": "baruffare",
    "baruffarono": "baruffare",
    "baruffasse": "baruffare",
    "baruffasser": "baruffare",
    "baruffassero": "baruffare",
    "baruffassi": "baruffare",
    "baruffassimo": "baruffare",
    "baruffaste": "baruffare",
    "baruffasti": "baruffare",
    "baruffata": "baruffare",
    "baruffate": "baruffare",
    "baruffati": "baruffare",
    "baruffato": "baruffare",
    "baruffava": "baruffare",
    "baruffavamo": "baruffare",
    "baruffavan": "baruffare",
    "baruffavano": "baruffare",
    "baruffavate": "baruffare",
    "baruffavi": "baruffare",
    "baruffavo": "baruffare",
    "baruffe": "baruffa",
    "barufferai": "baruffare",
    "barufferan": "baruffare",
    "barufferanno": "baruffare",
    "barufferebbe": "baruffare",
    "barufferebber": "baruffare",
    "barufferebbero": "baruffare",
    "barufferei": "baruffare",
    "barufferemmo": "baruffare",
    "barufferemo": "baruffare",
    "baruffereste": "baruffare",
    "barufferesti": "baruffare",
    "barufferete": "baruffare",
    "barufferà": "baruffare",
    "barufferò": "baruffare",
    "baruffi": "baruffare",
    "baruffiamo": "baruffare",
    "baruffiate": "baruffare",
    "baruffin": "baruffare",
    "baruffino": "baruffare",
    "baruffo": "baruffare",
    "baruffò": "baruffare",
    "barzellette": "barzelletta",
    "barò": "barare",
    "basa": "basire",
    "basai": "basare",
    "basamenti": "basamento",
    "basammo": "basare",
    "basan": "basire",
    "basando": "basare",
    "basano": "basire",
    "basante": "basare",
    "basanti": "basare",
    "basar": "basare",
    "basaron": "basare",
    "basarono": "basare",
    "basasse": "basare",
    "basasser": "basare",
    "basassero": "basare",
    "basassi": "basare",
    "basassimo": "basare",
    "basaste": "basare",
    "basasti": "basare",
    "basata": "basare",
    "basate": "basare",
    "basati": "basare",
    "basato": "basare",
    "basava": "basare",
    "basavamo": "basare",
    "basavan": "basare",
    "basavano": "basare",
    "basavate": "basare",
    "basavi": "basare",
    "basavo": "basare",
    "basca": "basco",
    "basche": "basco",
    "baschi": "basco",
    "bascula": "basculare",
    "basculai": "basculare",
    "basculammo": "basculare",
    "basculan": "basculare",
    "basculando": "basculare",
    "basculano": "basculare",
    "basculante": "basculare",
    "basculanti": "basculare",
    "bascular": "basculare",
    "bascularon": "basculare",
    "bascularono": "basculare",
    "basculasse": "basculare",
    "basculasser": "basculare",
    "basculassero": "basculare",
    "basculassi": "basculare",
    "basculassimo": "basculare",
    "basculaste": "basculare",
    "basculasti": "basculare",
    "basculata": "basculare",
    "basculate": "basculare",
    "basculati": "basculare",
    "basculato": "basculare",
    "basculava": "basculare",
    "basculavamo": "basculare",
    "basculavan": "basculare",
    "basculavano": "basculare",
    "basculavate": "basculare",
    "basculavi": "basculare",
    "basculavo": "basculare",
    "basculerai": "basculare",
    "basculeran": "basculare",
    "basculeranno": "basculare",
    "basculerebbe": "basculare",
    "basculerebber": "basculare",
    "basculerebbero": "basculare",
    "basculerei": "basculare",
    "basculeremmo": "basculare",
    "basculeremo": "basculare",
    "basculereste": "basculare",
    "basculeresti": "basculare",
    "basculerete": "basculare",
    "basculerà": "basculare",
    "basculerò": "basculare",
    "basculi": "basculare",
    "basculiamo": "basculare",
    "basculiate": "basculare",
    "basculin": "basculare",
    "basculino": "basculare",
    "basculo": "basculare",
    "basculò": "basculare",
    "base": "basire",
    "basendo": "basire",
    "basente": "basire",
    "basenti": "basire",
    "baserai": "basare",
    "baseran": "basare",
    "baseranno": "basare",
    "baserebbe": "basare",
    "baserebber": "basare",
    "baserebbero": "basare",
    "baserei": "basare",
    "baseremmo": "basare",
    "baseremo": "basare",
    "basereste": "basare",
    "baseresti": "basare",
    "baserete": "basare",
    "baserà": "basare",
    "baserò": "basare",
    "basette": "basetta",
    "basi": "basire",
    "basiamo": "basire",
    "basiate": "basire",
    "basica": "basico",
    "basiche": "basico",
    "basici": "basico",
    "basii": "basire",
    "basila": "basilare",
    "basilai": "basilare",
    "basilammo": "basilare",
    "basilan": "basilare",
    "basilando": "basilare",
    "basilano": "basilare",
    "basilante": "basilare",
    "basilanti": "basilare",
    "basilar": "basilare",
    "basilari": "basilare",
    "basilaron": "basilare",
    "basilarono": "basilare",
    "basilasse": "basilare",
    "basilasser": "basilare",
    "basilassero": "basilare",
    "basilassi": "basilare",
    "basilassimo": "basilare",
    "basilaste": "basilare",
    "basilasti": "basilare",
    "basilata": "basilare",
    "basilate": "basilare",
    "basilati": "basilare",
    "basilato": "basilare",
    "basilava": "basilare",
    "basilavamo": "basilare",
    "basilavan": "basilare",
    "basilavano": "basilare",
    "basilavate": "basilare",
    "basilavi": "basilare",
    "basilavo": "basilare",
    "basilerai": "basilare",
    "basileran": "basilare",
    "basileranno": "basilare",
    "basilerebbe": "basilare",
    "basilerebber": "basilare",
    "basilerebbero": "basilare",
    "basilerei": "basilare",
    "basileremmo": "basilare",
    "basileremo": "basilare",
    "basilereste": "basilare",
    "basileresti": "basilare",
    "basilerete": "basilare",
    "basilerà": "basilare",
    "basilerò": "basilare",
    "basili": "basilare",
    "basiliamo": "basilare",
    "basiliate": "basilare",
    "basilica": "basilico",
    "basiliche": "basilico",
    "basilici": "basilico",
    "basilin": "basilare",
    "basilino": "basilare",
    "basilischi": "basilisco",
    "basilo": "basilare",
    "basilò": "basilare",
    "basimmo": "basire",
    "basin": "basare",
    "basino": "basare",
    "basir": "basire",
    "basirai": "basire",
    "basiran": "basire",
    "basiranno": "basire",
    "basirebbe": "basire",
    "basirebber": "basire",
    "basirebbero": "basire",
    "basirei": "basire",
    "basiremmo": "basire",
    "basiremo": "basire",
    "basireste": "basire",
    "basiresti": "basire",
    "basirete": "basire",
    "basiron": "basire",
    "basirono": "basire",
    "basirà": "basire",
    "basirò": "basire",
    "basisse": "basire",
    "basisser": "basire",
    "basissero": "basire",
    "basissi": "basire",
    "basissimo": "basire",
    "basiste": "basire",
    "basisti": "basista",
    "basita": "basire",
    "basite": "basire",
    "basiti": "basire",
    "basito": "basire",
    "basiva": "basire",
    "basivamo": "basire",
    "basivan": "basire",
    "basivano": "basire",
    "basivate": "basire",
    "basivi": "basire",
    "basivo": "basire",
    "baso": "basire",
    "bason": "basire",
    "basono": "basire",
    "bassa": "basso",
    "basse": "basso",
    "bassezze": "bassezza",
    "bassi": "basso",
    "bassifondi": "bassofondo",
    "bassisti": "bassista",
    "bassorilievi": "bassorilievo",
    "bassosassoni": "bassosassone",
    "bassotti": "bassotto",
    "bassure": "bassura",
    "basta": "bastare",
    "bastai": "bastare",
    "bastammo": "bastare",
    "bastan": "bastare",
    "bastando": "bastare",
    "bastano": "bastare",
    "bastante": "bastare",
    "bastanti": "bastare",
    "bastar": "bastare",
    "bastarda": "bastardo",
    "bastarde": "bastardo",
    "bastardi": "bastardo",
    "bastaron": "bastare",
    "bastarono": "bastare",
    "bastasse": "bastare",
    "bastasser": "bastare",
    "bastassero": "bastare",
    "bastassi": "bastare",
    "bastassimo": "bastare",
    "bastaste": "bastare",
    "bastasti": "bastare",
    "bastata": "bastare",
    "bastate": "bastare",
    "bastati": "bastare",
    "bastato": "bastare",
    "bastava": "bastare",
    "bastavamo": "bastare",
    "bastavan": "bastare",
    "bastavano": "bastare",
    "bastavate": "bastare",
    "bastavi": "bastare",
    "bastavo": "bastare",
    "basterai": "bastare",
    "basteran": "bastare",
    "basteranno": "bastare",
    "basterebbe": "bastare",
    "basterebber": "bastare",
    "basterebbero": "bastare",
    "basterei": "bastare",
    "basteremmo": "bastare",
    "basteremo": "bastare",
    "bastereste": "bastare",
    "basteresti": "bastare",
    "basterete": "bastare",
    "basterà": "bastare",
    "basterò": "bastare",
    "basti": "bastare",
    "bastiamo": "bastare",
    "bastian": "bastiano",
    "bastiate": "bastare",
    "bastimenti": "bastimento",
    "bastin": "bastare",
    "bastino": "bastare",
    "bastioni": "bastione",
    "basto": "bastare",
    "bastona": "bastonare",
    "bastonai": "bastonare",
    "bastonammo": "bastonare",
    "bastonan": "bastonare",
    "bastonando": "bastonare",
    "bastonano": "bastonare",
    "bastonante": "bastonare",
    "bastonanti": "bastonare",
    "bastonar": "bastonare",
    "bastonaron": "bastonare",
    "bastonarono": "bastonare",
    "bastonasse": "bastonare",
    "bastonasser": "bastonare",
    "bastonassero": "bastonare",
    "bastonassi": "bastonare",
    "bastonassimo": "bastonare",
    "bastonaste": "bastonare",
    "bastonasti": "bastonare",
    "bastonata": "bastonare",
    "bastonate": "bastonata",
    "bastonati": "bastonare",
    "bastonato": "bastonare",
    "bastonature": "bastonatura",
    "bastonava": "bastonare",
    "bastonavamo": "bastonare",
    "bastonavan": "bastonare",
    "bastonavano": "bastonare",
    "bastonavate": "bastonare",
    "bastonavi": "bastonare",
    "bastonavo": "bastonare",
    "bastoncelli": "bastoncello",
    "bastoncini": "bastoncino",
    "bastonerai": "bastonare",
    "bastoneran": "bastonare",
    "bastoneranno": "bastonare",
    "bastonerebbe": "bastonare",
    "bastonerebber": "bastonare",
    "bastonerebbero": "bastonare",
    "bastonerei": "bastonare",
    "bastoneremmo": "bastonare",
    "bastoneremo": "bastonare",
    "bastonereste": "bastonare",
    "bastoneresti": "bastonare",
    "bastonerete": "bastonare",
    "bastonerà": "bastonare",
    "bastonerò": "bastonare",
    "bastoni": "bastone",
    "bastoniamo": "bastonare",
    "bastoniate": "bastonare",
    "bastonin": "bastonare",
    "bastonino": "bastonare",
    "bastono": "bastonare",
    "bastonò": "bastonare",
    "bastò": "bastare",
    "basì": "basire",
    "basò": "basare",
    "batavi": "batavo",
    "batoste": "batosta",
    "batta": "battere",
    "battages": "battage",
    "battaglie": "battaglia",
    "battagliera": "battagliero",
    "battagliere": "battagliero",
    "battaglieri": "battagliero",
    "battaglioni": "battaglione",
    "battan": "battere",
    "battano": "battere",
    "batte": "battere",
    "battei": "battere",
    "battelli": "battello",
    "battemmo": "battere",
    "battendo": "battere",
    "battente": "battere",
    "battenti": "battere",
    "batter": "battere",
    "batterai": "battere",
    "batteran": "battere",
    "batteranno": "battere",
    "batterebbe": "battere",
    "batterebber": "battere",
    "batterebbero": "battere",
    "batterei": "battere",
    "batteremmo": "battere",
    "batteremo": "battere",
    "battereste": "battere",
    "batteresti": "battere",
    "batterete": "battere",
    "batteri": "batterio",
    "batterica": "batterico",
    "batteriche": "batterico",
    "batterici": "batterico",
    "battericide": "battericida",
    "battericidi": "battericida",
    "batterie": "batteria",
    "batteriologica": "batteriologico",
    "batteriologiche": "batteriologico",
    "batteriologici": "batteriologico",
    "batteristi": "batterista",
    "batteron": "battere",
    "batterono": "battere",
    "batterà": "battere",
    "batterò": "battere",
    "battesimali": "battesimale",
    "battesimi": "battesimo",
    "battesse": "battere",
    "battesser": "battere",
    "battessero": "battere",
    "battessi": "battere",
    "battessimo": "battere",
    "batteste": "battere",
    "battesti": "battere",
    "battete": "battere",
    "batteva": "battere",
    "battevamo": "battere",
    "battevan": "battere",
    "battevano": "battere",
    "battevate": "battere",
    "battevi": "battere",
    "battevo": "battere",
    "battezza": "battezzare",
    "battezzai": "battezzare",
    "battezzammo": "battezzare",
    "battezzan": "battezzare",
    "battezzando": "battezzare",
    "battezzano": "battezzare",
    "battezzante": "battezzare",
    "battezzanti": "battezzare",
    "battezzar": "battezzare",
    "battezzaron": "battezzare",
    "battezzarono": "battezzare",
    "battezzasse": "battezzare",
    "battezzasser": "battezzare",
    "battezzassero": "battezzare",
    "battezzassi": "battezzare",
    "battezzassimo": "battezzare",
    "battezzaste": "battezzare",
    "battezzasti": "battezzare",
    "battezzata": "battezzare",
    "battezzate": "battezzare",
    "battezzati": "battezzato",
    "battezzato": "battezzare",
    "battezzava": "battezzare",
    "battezzavamo": "battezzare",
    "battezzavan": "battezzare",
    "battezzavano": "battezzare",
    "battezzavate": "battezzare",
    "battezzavi": "battezzare",
    "battezzavo": "battezzare",
    "battezzerai": "battezzare",
    "battezzeran": "battezzare",
    "battezzeranno": "battezzare",
    "battezzerebbe": "battezzare",
    "battezzerebber": "battezzare",
    "battezzerebbero": "battezzare",
    "battezzerei": "battezzare",
    "battezzeremmo": "battezzare",
    "battezzeremo": "battezzare",
    "battezzereste": "battezzare",
    "battezzeresti": "battezzare",
    "battezzerete": "battezzare",
    "battezzerà": "battezzare",
    "battezzerò": "battezzare",
    "battezzi": "battezzare",
    "battezziamo": "battezzare",
    "battezziate": "battezzare",
    "battezzin": "battezzare",
    "battezzino": "battezzare",
    "battezzo": "battezzare",
    "battezzò": "battezzare",
    "batti": "battere",
    "battiamo": "battere",
    "battiate": "battere",
    "battibecchi": "battibecco",
    "batticuori": "batticuore",
    "battige": "battigia",
    "battimani": "battimano",
    "battiste": "battista",
    "battisti": "battista",
    "battistiana": "battistiano",
    "battistiane": "battistiano",
    "battistiani": "battistiano",
    "battiti": "battito",
    "battitori": "battitore",
    "batto": "battere",
    "batton": "battere",
    "battono": "battere",
    "battuta": "battuto",
    "battutacce": "battutaccia",
    "battute": "battuto",
    "battuti": "battuto",
    "battutine": "battutina",
    "battuto": "battere",
    "battè": "battere",
    "batuffoli": "batuffolo",
    "baudiana": "baudiano",
    "baudiane": "baudiano",
    "baudiani": "baudiano",
    "bauli": "baule",
    "bavagli": "bavaglio",
    "bavaresi": "bavarese",
    "bave": "bava",
    "baveri": "bavero",
    "bazzecole": "bazzecola",
    "bazzica": "bazzicare",
    "bazzicai": "bazzicare",
    "bazzicammo": "bazzicare",
    "bazzican": "bazzicare",
    "bazzicando": "bazzicare",
    "bazzicano": "bazzicare",
    "bazzicante": "bazzicare",
    "bazzicanti": "bazzicare",
    "bazzicar": "bazzicare",
    "bazzicaron": "bazzicare",
    "bazzicarono": "bazzicare",
    "bazzicasse": "bazzicare",
    "bazzicasser": "bazzicare",
    "bazzicassero": "bazzicare",
    "bazzicassi": "bazzicare",
    "bazzicassimo": "bazzicare",
    "bazzicaste": "bazzicare",
    "bazzicasti": "bazzicare",
    "bazzicata": "bazzicare",
    "bazzicate": "bazzicare",
    "bazzicati": "bazzicare",
    "bazzicato": "bazzicare",
    "bazzicava": "bazzicare",
    "bazzicavamo": "bazzicare",
    "bazzicavan": "bazzicare",
    "bazzicavano": "bazzicare",
    "bazzicavate": "bazzicare",
    "bazzicavi": "bazzicare",
    "bazzicavo": "bazzicare",
    "bazzicherai": "bazzicare",
    "bazzicheran": "bazzicare",
    "bazzicheranno": "bazzicare",
    "bazzicherebbe": "bazzicare",
    "bazzicherebber": "bazzicare",
    "bazzicherebbero": "bazzicare",
    "bazzicherei": "bazzicare",
    "bazzicheremmo": "bazzicare",
    "bazzicheremo": "bazzicare",
    "bazzichereste": "bazzicare",
    "bazzicheresti": "bazzicare",
    "bazzicherete": "bazzicare",
    "bazzicherà": "bazzicare",
    "bazzicherò": "bazzicare",
    "bazzichi": "bazzicare",
    "bazzichiamo": "bazzicare",
    "bazzichiate": "bazzicare",
    "bazzichin": "bazzicare",
    "bazzichino": "bazzicare",
    "bazzico": "bazzicare",
    "bazzicò": "bazzicare",
    "bea": "beare",
    "beai": "beare",
    "beammo": "beare",
    "bean": "beare",
    "beando": "beare",
    "beano": "beare",
    "beante": "beare",
    "beanti": "beare",
    "bear": "beare",
    "bearon": "beare",
    "bearono": "beare",
    "bearzottiana": "bearzottiano",
    "bearzottiane": "bearzottiano",
    "bearzottiani": "bearzottiano",
    "beasse": "beare",
    "beasser": "beare",
    "beassero": "beare",
    "beassi": "beare",
    "beassimo": "beare",
    "beaste": "beare",
    "beasti": "beare",
    "beata": "beato",
    "beate": "beato",
    "beati": "beato",
    "beatifica": "beatificare",
    "beatificai": "beatificare",
    "beatificammo": "beatificare",
    "beatifican": "beatificare",
    "beatificando": "beatificare",
    "beatificano": "beatificare",
    "beatificante": "beatificare",
    "beatificanti": "beatificare",
    "beatificar": "beatificare",
    "beatificaron": "beatificare",
    "beatificarono": "beatificare",
    "beatificasse": "beatificare",
    "beatificasser": "beatificare",
    "beatificassero": "beatificare",
    "beatificassi": "beatificare",
    "beatificassimo": "beatificare",
    "beatificaste": "beatificare",
    "beatificasti": "beatificare",
    "beatificata": "beatificare",
    "beatificate": "beatificare",
    "beatificati": "beatificare",
    "beatificato": "beatificare",
    "beatificava": "beatificare",
    "beatificavamo": "beatificare",
    "beatificavan": "beatificare",
    "beatificavano": "beatificare",
    "beatificavate": "beatificare",
    "beatificavi": "beatificare",
    "beatificavo": "beatificare",
    "beatificazioni": "beatificazione",
    "beatificherai": "beatificare",
    "beatificheran": "beatificare",
    "beatificheranno": "beatificare",
    "beatificherebbe": "beatificare",
    "beatificherebber": "beatificare",
    "beatificherebbero": "beatificare",
    "beatificherei": "beatificare",
    "beatificheremmo": "beatificare",
    "beatificheremo": "beatificare",
    "beatifichereste": "beatificare",
    "beatificheresti": "beatificare",
    "beatificherete": "beatificare",
    "beatificherà": "beatificare",
    "beatificherò": "beatificare",
    "beatifichi": "beatificare",
    "beatifichiamo": "beatificare",
    "beatifichiate": "beatificare",
    "beatifichin": "beatificare",
    "beatifichino": "beatificare",
    "beatifico": "beatificare",
    "beatificò": "beatificare",
    "beatitudini": "beatitudine",
    "beatlesiana": "beatlesiano",
    "beatlesiane": "beatlesiano",
    "beatlesiani": "beatlesiano",
    "beato": "beare",
    "beava": "beare",
    "beavamo": "beare",
    "beavan": "beare",
    "beavano": "beare",
    "beavate": "beare",
    "beavi": "beare",
    "beavo": "beare",
    "becca": "beccare",
    "beccaccini": "beccaccino",
    "beccai": "beccare",
    "beccammo": "beccare",
    "beccan": "beccare",
    "beccando": "beccare",
    "beccano": "beccare",
    "beccante": "beccare",
    "beccanti": "beccare",
    "beccar": "beccare",
    "beccaron": "beccare",
    "beccarono": "beccare",
    "beccasse": "beccare",
    "beccasser": "beccare",
    "beccassero": "beccare",
    "beccassi": "beccare",
    "beccassimo": "beccare",
    "beccaste": "beccare",
    "beccasti": "beccare",
    "beccata": "beccare",
    "beccate": "beccare",
    "beccati": "beccare",
    "beccato": "beccare",
    "beccava": "beccare",
    "beccavamo": "beccare",
    "beccavan": "beccare",
    "beccavano": "beccare",
    "beccavate": "beccare",
    "beccavi": "beccare",
    "beccavo": "beccare",
    "beccheggerai": "beccheggiare",
    "beccheggeran": "beccheggiare",
    "beccheggeranno": "beccheggiare",
    "beccheggerebbe": "beccheggiare",
    "beccheggerebber": "beccheggiare",
    "beccheggerebbero": "beccheggiare",
    "beccheggerei": "beccheggiare",
    "beccheggeremmo": "beccheggiare",
    "beccheggeremo": "beccheggiare",
    "beccheggereste": "beccheggiare",
    "beccheggeresti": "beccheggiare",
    "beccheggerete": "beccheggiare",
    "beccheggerà": "beccheggiare",
    "beccheggerò": "beccheggiare",
    "beccheggi": "beccheggiare",
    "beccheggia": "beccheggiare",
    "beccheggiai": "beccheggiare",
    "beccheggiammo": "beccheggiare",
    "beccheggiamo": "beccheggiare",
    "beccheggian": "beccheggiare",
    "beccheggiando": "beccheggiare",
    "beccheggiano": "beccheggiare",
    "beccheggiante": "beccheggiare",
    "beccheggianti": "beccheggiare",
    "beccheggiar": "beccheggiare",
    "beccheggiaron": "beccheggiare",
    "beccheggiarono": "beccheggiare",
    "beccheggiasse": "beccheggiare",
    "beccheggiasser": "beccheggiare",
    "beccheggiassero": "beccheggiare",
    "beccheggiassi": "beccheggiare",
    "beccheggiassimo": "beccheggiare",
    "beccheggiaste": "beccheggiare",
    "beccheggiasti": "beccheggiare",
    "beccheggiata": "beccheggiare",
    "beccheggiate": "beccheggiare",
    "beccheggiati": "beccheggiare",
    "beccheggiato": "beccheggiare",
    "beccheggiava": "beccheggiare",
    "beccheggiavamo": "beccheggiare",
    "beccheggiavan": "beccheggiare",
    "beccheggiavano": "beccheggiare",
    "beccheggiavate": "beccheggiare",
    "beccheggiavi": "beccheggiare",
    "beccheggiavo": "beccheggiare",
    "beccheggin": "beccheggiare",
    "beccheggino": "beccheggiare",
    "beccheggio": "beccheggiare",
    "beccheggiò": "beccheggiare",
    "beccherai": "beccare",
    "beccheran": "beccare",
    "beccheranno": "beccare",
    "beccherebbe": "beccare",
    "beccherebber": "beccare",
    "beccherebbero": "beccare",
    "beccherei": "beccare",
    "beccheremmo": "beccare",
    "beccheremo": "beccare",
    "becchereste": "beccare",
    "beccheresti": "beccare",
    "beccherete": "beccare",
    "beccherà": "beccare",
    "beccherò": "beccare",
    "becchetta": "becchettare",
    "becchettai": "becchettare",
    "becchettammo": "becchettare",
    "becchettan": "becchettare",
    "becchettando": "becchettare",
    "becchettano": "becchettare",
    "becchettante": "becchettare",
    "becchettanti": "becchettare",
    "becchettar": "becchettare",
    "becchettaron": "becchettare",
    "becchettarono": "becchettare",
    "becchettasse": "becchettare",
    "becchettasser": "becchettare",
    "becchettassero": "becchettare",
    "becchettassi": "becchettare",
    "becchettassimo": "becchettare",
    "becchettaste": "becchettare",
    "becchettasti": "becchettare",
    "becchettata": "becchettare",
    "becchettate": "becchettare",
    "becchettati": "becchettare",
    "becchettato": "becchettare",
    "becchettava": "becchettare",
    "becchettavamo": "becchettare",
    "becchettavan": "becchettare",
    "becchettavano": "becchettare",
    "becchettavate": "becchettare",
    "becchettavi": "becchettare",
    "becchettavo": "becchettare",
    "becchetterai": "becchettare",
    "becchetteran": "becchettare",
    "becchetteranno": "becchettare",
    "becchetterebbe": "becchettare",
    "becchetterebber": "becchettare",
    "becchetterebbero": "becchettare",
    "becchetterei": "becchettare",
    "becchetteremmo": "becchettare",
    "becchetteremo": "becchettare",
    "becchettereste": "becchettare",
    "becchetteresti": "becchettare",
    "becchetterete": "becchettare",
    "becchetterà": "becchettare",
    "becchetterò": "becchettare",
    "becchetti": "becchettare",
    "becchettiamo": "becchettare",
    "becchettiate": "becchettare",
    "becchettin": "becchettare",
    "becchettino": "becchettare",
    "becchetto": "becchettare",
    "becchettò": "becchettare",
    "becchi": "becco",
    "becchiamo": "beccare",
    "becchiate": "beccare",
    "becchin": "beccare",
    "becchini": "becchino",
    "becchino": "beccare",
    "becco": "beccare",
    "beccò": "beccare",
    "becera": "becero",
    "becere": "becero",
    "beceri": "becero",
    "beckettiana": "beckettiano",
    "beckettiane": "beckettiano",
    "beckettiani": "beckettiano",
    "beduini": "beduino",
    "beerai": "beare",
    "beeran": "beare",
    "beeranno": "beare",
    "beerebbe": "beare",
    "beerebber": "beare",
    "beerebbero": "beare",
    "beerei": "beare",
    "beeremmo": "beare",
    "beeremo": "beare",
    "beereste": "beare",
    "beeresti": "beare",
    "beerete": "beare",
    "beerà": "beare",
    "beerò": "beare",
    "befane": "befana",
    "beffa": "beffare",
    "beffai": "beffare",
    "beffammo": "beffare",
    "beffan": "beffare",
    "beffando": "beffare",
    "beffano": "beffare",
    "beffante": "beffare",
    "beffanti": "beffare",
    "beffar": "beffare",
    "beffarda": "beffardo",
    "beffarde": "beffardo",
    "beffardi": "beffardo",
    "beffaron": "beffare",
    "beffarono": "beffare",
    "beffasse": "beffare",
    "beffasser": "beffare",
    "beffassero": "beffare",
    "beffassi": "beffare",
    "beffassimo": "beffare",
    "beffaste": "beffare",
    "beffasti": "beffare",
    "beffata": "beffare",
    "beffate": "beffare",
    "beffati": "beffare",
    "beffato": "beffare",
    "beffava": "beffare",
    "beffavamo": "beffare",
    "beffavan": "beffare",
    "beffavano": "beffare",
    "beffavate": "beffare",
    "beffavi": "beffare",
    "beffavo": "beffare",
    "beffe": "beffa",
    "beffeggerai": "beffeggiare",
    "beffeggeran": "beffeggiare",
    "beffeggeranno": "beffeggiare",
    "beffeggerebbe": "beffeggiare",
    "beffeggerebber": "beffeggiare",
    "beffeggerebbero": "beffeggiare",
    "beffeggerei": "beffeggiare",
    "beffeggeremmo": "beffeggiare",
    "beffeggeremo": "beffeggiare",
    "beffeggereste": "beffeggiare",
    "beffeggeresti": "beffeggiare",
    "beffeggerete": "beffeggiare",
    "beffeggerà": "beffeggiare",
    "beffeggerò": "beffeggiare",
    "beffeggi": "beffeggiare",
    "beffeggia": "beffeggiare",
    "beffeggiai": "beffeggiare",
    "beffeggiammo": "beffeggiare",
    "beffeggiamo": "beffeggiare",
    "beffeggian": "beffeggiare",
    "beffeggiando": "beffeggiare",
    "beffeggiano": "beffeggiare",
    "beffeggiante": "beffeggiare",
    "beffeggianti": "beffeggiare",
    "beffeggiar": "beffeggiare",
    "beffeggiaron": "beffeggiare",
    "beffeggiarono": "beffeggiare",
    "beffeggiasse": "beffeggiare",
    "beffeggiasser": "beffeggiare",
    "beffeggiassero": "beffeggiare",
    "beffeggiassi": "beffeggiare",
    "beffeggiassimo": "beffeggiare",
    "beffeggiaste": "beffeggiare",
    "beffeggiasti": "beffeggiare",
    "beffeggiata": "beffeggiare",
    "beffeggiate": "beffeggiare",
    "beffeggiati": "beffeggiare",
    "beffeggiato": "beffeggiare",
    "beffeggiava": "beffeggiare",
    "beffeggiavamo": "beffeggiare",
    "beffeggiavan": "beffeggiare",
    "beffeggiavano": "beffeggiare",
    "beffeggiavate": "beffeggiare",
    "beffeggiavi": "beffeggiare",
    "beffeggiavo": "beffeggiare",
    "beffeggin": "beffeggiare",
    "beffeggino": "beffeggiare",
    "beffeggio": "beffeggiare",
    "beffeggiò": "beffeggiare",
    "befferai": "beffare",
    "befferan": "beffare",
    "befferanno": "beffare",
    "befferebbe": "beffare",
    "befferebber": "beffare",
    "befferebbero": "beffare",
    "befferei": "beffare",
    "befferemmo": "beffare",
    "befferemo": "beffare",
    "beffereste": "beffare",
    "befferesti": "beffare",
    "befferete": "beffare",
    "befferà": "beffare",
    "befferò": "beffare",
    "beffi": "beffare",
    "beffiamo": "beffare",
    "beffiate": "beffare",
    "beffin": "beffare",
    "beffino": "beffare",
    "beffo": "beffare",
    "beffò": "beffare",
    "beghe": "bega",
    "bei": "beare",
    "beiamo": "beare",
    "beiate": "beare",
    "beiges": "beige",
    "beigi": "beige",
    "bein": "beare",
    "beino": "beare",
    "bejartiana": "bejartiano",
    "bejartiane": "bejartiano",
    "bejartiani": "bejartiano",
    "bela": "belare",
    "belai": "belare",
    "belammo": "belare",
    "belan": "belare",
    "belando": "belare",
    "belano": "belare",
    "belante": "belare",
    "belanti": "belare",
    "belar": "belare",
    "belaron": "belare",
    "belarono": "belare",
    "belasse": "belare",
    "belasser": "belare",
    "belassero": "belare",
    "belassi": "belare",
    "belassimo": "belare",
    "belaste": "belare",
    "belasti": "belare",
    "belata": "belare",
    "belate": "belare",
    "belati": "belare",
    "belato": "belare",
    "belava": "belare",
    "belavamo": "belare",
    "belavan": "belare",
    "belavano": "belare",
    "belavate": "belare",
    "belavi": "belare",
    "belavo": "belare",
    "belcanti": "belcanto",
    "belerai": "belare",
    "beleran": "belare",
    "beleranno": "belare",
    "belerebbe": "belare",
    "belerebber": "belare",
    "belerebbero": "belare",
    "belerei": "belare",
    "beleremmo": "belare",
    "beleremo": "belare",
    "belereste": "belare",
    "beleresti": "belare",
    "belerete": "belare",
    "belerà": "belare",
    "belerò": "belare",
    "belghe": "belga",
    "belgi": "belga",
    "beli": "belare",
    "beliamo": "belare",
    "beliate": "belare",
    "belin": "belare",
    "belino": "belare",
    "bella": "bello",
    "belle": "bello",
    "belletti": "belletto",
    "bellezze": "bellezza",
    "belli": "bello",
    "bellica": "bellico",
    "belliche": "bellico",
    "bellici": "bellico",
    "bellicosa": "bellicoso",
    "bellicose": "bellicoso",
    "bellicosi": "bellicoso",
    "belligeranti": "belligerante",
    "bellimbusti": "bellimbusto",
    "belliniana": "belliniano",
    "belliniane": "belliniano",
    "belliniani": "belliniano",
    "bellocce": "belloccio",
    "bellocci": "belloccio",
    "belloccia": "belloccio",
    "bellone": "bellona",
    "belloriana": "belloriano",
    "belloriane": "belloriano",
    "belloriani": "belloriano",
    "belluina": "belluino",
    "belluine": "belluino",
    "belluini": "belluino",
    "bellunesi": "bellunese",
    "bellurie": "belluria",
    "belo": "belare",
    "belve": "belva",
    "belò": "belare",
    "benamata": "benamato",
    "benamate": "benamato",
    "benamati": "benamato",
    "benarrivata": "benarrivato",
    "benarrivate": "benarrivato",
    "benarrivati": "benarrivato",
    "benda": "bendare",
    "bendaggi": "bendaggio",
    "bendai": "bendare",
    "bendammo": "bendare",
    "bendan": "bendare",
    "bendando": "bendare",
    "bendano": "bendare",
    "bendante": "bendare",
    "bendanti": "bendare",
    "bendar": "bendare",
    "bendaron": "bendare",
    "bendarono": "bendare",
    "bendasse": "bendare",
    "bendasser": "bendare",
    "bendassero": "bendare",
    "bendassi": "bendare",
    "bendassimo": "bendare",
    "bendaste": "bendare",
    "bendasti": "bendare",
    "bendata": "bendare",
    "bendate": "bendare",
    "bendati": "bendare",
    "bendato": "bendare",
    "bendava": "bendare",
    "bendavamo": "bendare",
    "bendavan": "bendare",
    "bendavano": "bendare",
    "bendavate": "bendare",
    "bendavi": "bendare",
    "bendavo": "bendare",
    "bende": "benda",
    "benderai": "bendare",
    "benderan": "bendare",
    "benderanno": "bendare",
    "benderebbe": "bendare",
    "benderebber": "bendare",
    "benderebbero": "bendare",
    "benderei": "bendare",
    "benderemmo": "bendare",
    "benderemo": "bendare",
    "bendereste": "bendare",
    "benderesti": "bendare",
    "benderete": "bendare",
    "benderà": "bendare",
    "benderò": "bendare",
    "bendi": "bendare",
    "bendiamo": "bendare",
    "bendiate": "bendare",
    "bendin": "bendare",
    "bendino": "bendare",
    "bendisposta": "bendisposto",
    "bendisposte": "bendisposto",
    "bendisposti": "bendisposto",
    "bendo": "bendare",
    "bendò": "bendare",
    "benedetta": "benedire",
    "benedette": "benedire",
    "benedetti": "benedire",
    "benedettina": "benedettino",
    "benedettine": "benedettino",
    "benedettini": "benedettino",
    "benedetto": "benedire",
    "benedica": "benedire",
    "benedican": "benedire",
    "benedicano": "benedire",
    "benedice": "benedire",
    "benedicemmo": "benedire",
    "benedicendo": "benedire",
    "benedicente": "benedire",
    "benedicenti": "benedire",
    "benedicesse": "benedire",
    "benedicesser": "benedire",
    "benedicessero": "benedire",
    "benedicessi": "benedire",
    "benedicessimo": "benedire",
    "benediceste": "benedire",
    "benedicesti": "benedire",
    "benediceva": "benedire",
    "benedicevamo": "benedire",
    "benedicevan": "benedire",
    "benedicevano": "benedire",
    "benedicevate": "benedire",
    "benedicevi": "benedire",
    "benedicevo": "benedire",
    "benedici": "benedire",
    "benediciamo": "benedire",
    "benediciate": "benedire",
    "benedico": "benedire",
    "benedicon": "benedire",
    "benedicono": "benedire",
    "benedir": "benedire",
    "benedirai": "benedire",
    "benediran": "benedire",
    "benediranno": "benedire",
    "benedirebbe": "benedire",
    "benedirebber": "benedire",
    "benedirebbero": "benedire",
    "benedirei": "benedire",
    "benediremmo": "benedire",
    "benediremo": "benedire",
    "benedireste": "benedire",
    "benediresti": "benedire",
    "benedirete": "benedire",
    "benedirà": "benedire",
    "benedirò": "benedire",
    "benedisse": "benedire",
    "benedisser": "benedire",
    "benedissero": "benedire",
    "benedissi": "benedire",
    "benedite": "benedire",
    "benedizioni": "benedizione",
    "beneducata": "beneducato",
    "beneducate": "beneducato",
    "beneducati": "beneducato",
    "benefattori": "benefattore",
    "benefattrice": "benefattore",
    "benefattrici": "benefattrice",
    "benefica": "benefico",
    "beneficai": "beneficare",
    "beneficammo": "beneficare",
    "benefican": "beneficare",
    "beneficando": "beneficare",
    "beneficano": "beneficare",
    "beneficante": "beneficare",
    "beneficanti": "beneficare",
    "beneficar": "beneficare",
    "beneficaron": "beneficare",
    "beneficarono": "beneficare",
    "beneficasse": "beneficare",
    "beneficasser": "beneficare",
    "beneficassero": "beneficare",
    "beneficassi": "beneficare",
    "beneficassimo": "beneficare",
    "beneficaste": "beneficare",
    "beneficasti": "beneficare",
    "beneficata": "beneficare",
    "beneficate": "beneficare",
    "beneficati": "beneficare",
    "beneficato": "beneficare",
    "beneficava": "beneficare",
    "beneficavamo": "beneficare",
    "beneficavan": "beneficare",
    "beneficavano": "beneficare",
    "beneficavate": "beneficare",
    "beneficavi": "beneficare",
    "beneficavo": "beneficare",
    "beneficenze": "beneficenza",
    "beneficerai": "beneficiare",
    "beneficeran": "beneficiare",
    "beneficeranno": "beneficiare",
    "beneficerebbe": "beneficiare",
    "beneficerebber": "beneficiare",
    "beneficerebbero": "beneficiare",
    "beneficerei": "beneficiare",
    "beneficeremmo": "beneficiare",
    "beneficeremo": "beneficiare",
    "beneficereste": "beneficiare",
    "beneficeresti": "beneficiare",
    "beneficerete": "beneficiare",
    "beneficerà": "beneficiare",
    "beneficerò": "beneficiare",
    "benefiche": "benefico",
    "beneficherai": "beneficare",
    "beneficheran": "beneficare",
    "beneficheranno": "beneficare",
    "beneficherebbe": "beneficare",
    "beneficherebber": "beneficare",
    "beneficherebbero": "beneficare",
    "beneficherei": "beneficare",
    "beneficheremmo": "beneficare",
    "beneficheremo": "beneficare",
    "benefichereste": "beneficare",
    "beneficheresti": "beneficare",
    "beneficherete": "beneficare",
    "beneficherà": "beneficare",
    "beneficherò": "beneficare",
    "benefichi": "beneficare",
    "benefichiamo": "beneficare",
    "benefichiate": "beneficare",
    "benefichin": "beneficare",
    "benefichino": "beneficare",
    "benefici": "benefico",
    "beneficia": "beneficiare",
    "beneficiai": "beneficiare",
    "beneficiammo": "beneficiare",
    "beneficiamo": "beneficiare",
    "benefician": "beneficiare",
    "beneficiando": "beneficiare",
    "beneficiano": "beneficiare",
    "beneficiante": "beneficiare",
    "beneficianti": "beneficiare",
    "beneficiar": "beneficiare",
    "beneficiari": "beneficiario",
    "beneficiaria": "beneficiario",
    "beneficiarie": "beneficiario",
    "beneficiaron": "beneficiare",
    "beneficiarono": "beneficiare",
    "beneficiasse": "beneficiare",
    "beneficiasser": "beneficiare",
    "beneficiassero": "beneficiare",
    "beneficiassi": "beneficiare",
    "beneficiassimo": "beneficiare",
    "beneficiaste": "beneficiare",
    "beneficiasti": "beneficiare",
    "beneficiata": "beneficiare",
    "beneficiate": "beneficiare",
    "beneficiati": "beneficiato",
    "beneficiato": "beneficiare",
    "beneficiava": "beneficiare",
    "beneficiavamo": "beneficiare",
    "beneficiavan": "beneficiare",
    "beneficiavano": "beneficiare",
    "beneficiavate": "beneficiare",
    "beneficiavi": "beneficiare",
    "beneficiavo": "beneficiare",
    "beneficin": "beneficiare",
    "beneficino": "beneficiare",
    "beneficio": "beneficiare",
    "beneficiò": "beneficiare",
    "benefico": "beneficare",
    "beneficò": "beneficare",
    "benemerenze": "benemerenza",
    "benemerita": "benemerito",
    "benemerite": "benemerito",
    "benemeriti": "benemerito",
    "beneplaciti": "beneplacito",
    "benesseri": "benessere",
    "benestanti": "benestante",
    "beneventani": "beneventano",
    "benevola": "benevolo",
    "benevole": "benevolo",
    "benevolenze": "benevolenza",
    "benevoli": "benevolo",
    "bengalesi": "bengalese",
    "beni": "bene",
    "beniamine": "beniamina",
    "beniamini": "beniamino",
    "benigna": "benigno",
    "benigne": "benigno",
    "benigni": "benigno",
    "benjaminiana": "benjaminiano",
    "benjaminiane": "benjaminiano",
    "benjaminiani": "benjaminiano",
    "bennata": "bennato",
    "bennate": "bennato",
    "bennati": "bennato",
    "benne": "benna",
    "benpensanti": "benpensante",
    "benserviti": "benservito",
    "benvenuta": "benvenuto",
    "benvenute": "benvenuto",
    "benvenuti": "benvenuto",
    "benvista": "benvisto",
    "benviste": "benvisto",
    "benvisti": "benvisto",
    "benvoglia": "benvolere",
    "benvogliamo": "benvolere",
    "benvoglian": "benvolere",
    "benvogliano": "benvolere",
    "benvogliate": "benvolere",
    "benvoglio": "benvolere",
    "benvoglion": "benvolere",
    "benvogliono": "benvolere",
    "benvolemmo": "benvolere",
    "benvolendo": "benvolere",
    "benvolente": "benvolere",
    "benvolenti": "benvolere",
    "benvoler": "benvolere",
    "benvolesse": "benvolere",
    "benvolesser": "benvolere",
    "benvolessero": "benvolere",
    "benvolessi": "benvolere",
    "benvolessimo": "benvolere",
    "benvoleste": "benvolere",
    "benvolesti": "benvolere",
    "benvolete": "benvolere",
    "benvoleva": "benvolere",
    "benvolevamo": "benvolere",
    "benvolevan": "benvolere",
    "benvolevano": "benvolere",
    "benvolevate": "benvolere",
    "benvolevi": "benvolere",
    "benvolevo": "benvolere",
    "benvolle": "benvolere",
    "benvoller": "benvolere",
    "benvollero": "benvolere",
    "benvolli": "benvolere",
    "benvoluta": "benvolere",
    "benvolute": "benvolere",
    "benvoluti": "benvolere",
    "benvoluto": "benvolere",
    "benvorrai": "benvolere",
    "benvorran": "benvolere",
    "benvorranno": "benvolere",
    "benvorrebbe": "benvolere",
    "benvorrebber": "benvolere",
    "benvorrebbero": "benvolere",
    "benvorrei": "benvolere",
    "benvorremmo": "benvolere",
    "benvorremo": "benvolere",
    "benvorreste": "benvolere",
    "benvorresti": "benvolere",
    "benvorrete": "benvolere",
    "benvorrà": "benvolere",
    "benvorrò": "benvolere",
    "benvuoi": "benvolere",
    "benvuole": "benvolere",
    "benzeni": "benzene",
    "benziana": "benziano",
    "benziane": "benziano",
    "benziani": "benziano",
    "benzinai": "benzinaio",
    "benzine": "benzina",
    "beo": "beare",
    "ber": "bere",
    "berbera": "berbero",
    "berbere": "berbero",
    "berberi": "berbero",
    "bercerai": "berciare",
    "berceran": "berciare",
    "berceranno": "berciare",
    "bercerebbe": "berciare",
    "bercerebber": "berciare",
    "bercerebbero": "berciare",
    "bercerei": "berciare",
    "berceremmo": "berciare",
    "berceremo": "berciare",
    "bercereste": "berciare",
    "berceresti": "berciare",
    "bercerete": "berciare",
    "bercerà": "berciare",
    "bercerò": "berciare",
    "berci": "berciare",
    "bercia": "berciare",
    "berciai": "berciare",
    "berciammo": "berciare",
    "berciamo": "berciare",
    "bercian": "berciare",
    "berciando": "berciare",
    "berciano": "berciare",
    "berciante": "berciare",
    "bercianti": "berciare",
    "berciar": "berciare",
    "berciaron": "berciare",
    "berciarono": "berciare",
    "berciasse": "berciare",
    "berciasser": "berciare",
    "berciassero": "berciare",
    "berciassi": "berciare",
    "berciassimo": "berciare",
    "berciaste": "berciare",
    "berciasti": "berciare",
    "berciata": "berciare",
    "berciate": "berciare",
    "berciati": "berciare",
    "berciato": "berciare",
    "berciava": "berciare",
    "berciavamo": "berciare",
    "berciavan": "berciare",
    "berciavano": "berciare",
    "berciavate": "berciare",
    "berciavi": "berciare",
    "berciavo": "berciare",
    "bercin": "berciare",
    "bercino": "berciare",
    "bercio": "berciare",
    "berciò": "berciare",
    "bergamasca": "bergamasco",
    "bergamasche": "bergamasco",
    "bergamaschi": "bergamasco",
    "bergmaniana": "bergmaniano",
    "bergmaniane": "bergmaniano",
    "bergmaniani": "bergmaniano",
    "berline": "berlina",
    "berlinesi": "berlinese",
    "berlinette": "berlinetta",
    "berlusconiani": "berlusconiano",
    "berlusconismi": "berlusconismo",
    "berlusconizzata": "berlusconizzato",
    "berlusconizzate": "berlusconizzato",
    "berlusconizzati": "berlusconizzato",
    "bernhardiana": "bernhardiano",
    "bernhardiane": "bernhardiano",
    "bernhardiani": "bernhardiano",
    "bernoccoli": "bernoccolo",
    "berrai": "bere",
    "berran": "bere",
    "berranno": "bere",
    "berrebbe": "bere",
    "berrebber": "bere",
    "berrebbero": "bere",
    "berrei": "bere",
    "berremmo": "bere",
    "berremo": "bere",
    "berreste": "bere",
    "berresti": "bere",
    "berrete": "bere",
    "berrette": "berretta",
    "berretti": "berretto",
    "berrettini": "berrettino",
    "berrà": "bere",
    "berrò": "bere",
    "bersagli": "bersaglio",
    "bersaglia": "bersagliare",
    "bersagliai": "bersagliare",
    "bersagliammo": "bersagliare",
    "bersagliamo": "bersagliare",
    "bersaglian": "bersagliare",
    "bersagliando": "bersagliare",
    "bersagliano": "bersagliare",
    "bersagliante": "bersagliare",
    "bersaglianti": "bersagliare",
    "bersagliar": "bersagliare",
    "bersagliaron": "bersagliare",
    "bersagliarono": "bersagliare",
    "bersagliasse": "bersagliare",
    "bersagliasser": "bersagliare",
    "bersagliassero": "bersagliare",
    "bersagliassi": "bersagliare",
    "bersagliassimo": "bersagliare",
    "bersagliaste": "bersagliare",
    "bersagliasti": "bersagliare",
    "bersagliata": "bersagliare",
    "bersagliate": "bersagliare",
    "bersagliati": "bersagliare",
    "bersagliato": "bersagliare",
    "bersagliava": "bersagliare",
    "bersagliavamo": "bersagliare",
    "bersagliavan": "bersagliare",
    "bersagliavano": "bersagliare",
    "bersagliavate": "bersagliare",
    "bersagliavi": "bersagliare",
    "bersagliavo": "bersagliare",
    "bersaglierai": "bersagliare",
    "bersaglieran": "bersagliare",
    "bersaglieranno": "bersagliare",
    "bersaglierebbe": "bersagliare",
    "bersaglierebber": "bersagliare",
    "bersaglierebbero": "bersagliare",
    "bersaglierei": "bersagliare",
    "bersaglieremmo": "bersagliare",
    "bersaglieremo": "bersagliare",
    "bersagliereste": "bersagliare",
    "bersaglieresti": "bersagliare",
    "bersaglierete": "bersagliare",
    "bersaglieri": "bersagliere",
    "bersaglierà": "bersagliare",
    "bersaglierò": "bersagliare",
    "bersaglin": "bersagliare",
    "bersaglino": "bersagliare",
    "bersaglio": "bersagliare",
    "bersagliò": "bersagliare",
    "bertinottiana": "bertinottiano",
    "bertinottiane": "bertinottiano",
    "bertinottiani": "bertinottiano",
    "best-sellers": "best-seller",
    "bestemmi": "bestemmiare",
    "bestemmia": "bestemmiare",
    "bestemmiai": "bestemmiare",
    "bestemmiammo": "bestemmiare",
    "bestemmiamo": "bestemmiare",
    "bestemmian": "bestemmiare",
    "bestemmiando": "bestemmiare",
    "bestemmiano": "bestemmiare",
    "bestemmiante": "bestemmiare",
    "bestemmianti": "bestemmiare",
    "bestemmiar": "bestemmiare",
    "bestemmiaron": "bestemmiare",
    "bestemmiarono": "bestemmiare",
    "bestemmiasse": "bestemmiare",
    "bestemmiasser": "bestemmiare",
    "bestemmiassero": "bestemmiare",
    "bestemmiassi": "bestemmiare",
    "bestemmiassimo": "bestemmiare",
    "bestemmiaste": "bestemmiare",
    "bestemmiasti": "bestemmiare",
    "bestemmiata": "bestemmiare",
    "bestemmiate": "bestemmiare",
    "bestemmiati": "bestemmiare",
    "bestemmiato": "bestemmiare",
    "bestemmiatori": "bestemmiatore",
    "bestemmiava": "bestemmiare",
    "bestemmiavamo": "bestemmiare",
    "bestemmiavan": "bestemmiare",
    "bestemmiavano": "bestemmiare",
    "bestemmiavate": "bestemmiare",
    "bestemmiavi": "bestemmiare",
    "bestemmiavo": "bestemmiare",
    "bestemmie": "bestemmia",
    "bestemmierai": "bestemmiare",
    "bestemmieran": "bestemmiare",
    "bestemmieranno": "bestemmiare",
    "bestemmierebbe": "bestemmiare",
    "bestemmierebber": "bestemmiare",
    "bestemmierebbero": "bestemmiare",
    "bestemmierei": "bestemmiare",
    "bestemmieremmo": "bestemmiare",
    "bestemmieremo": "bestemmiare",
    "bestemmiereste": "bestemmiare",
    "bestemmieresti": "bestemmiare",
    "bestemmierete": "bestemmiare",
    "bestemmierà": "bestemmiare",
    "bestemmierò": "bestemmiare",
    "bestemmin": "bestemmiare",
    "bestemmino": "bestemmiare",
    "bestemmio": "bestemmiare",
    "bestemmiò": "bestemmiare",
    "bestiacce": "bestiaccia",
    "bestiali": "bestiale",
    "bestiami": "bestiame",
    "bestiari": "bestiario",
    "bestie": "bestia",
    "bestiole": "bestiola",
    "bestioline": "bestiolina",
    "bestioni": "bestione",
    "bestsellers": "bestseller",
    "betoniere": "betoniera",
    "bettole": "bettola",
    "betulle": "betulla",
    "beva": "bere",
    "bevan": "bere",
    "bevande": "bevanda",
    "bevano": "bere",
    "beve": "bere",
    "bevemmo": "bere",
    "bevendo": "bere",
    "bevente": "bere",
    "beventi": "bere",
    "beveroni": "beverone",
    "bevesse": "bere",
    "bevesser": "bere",
    "bevessero": "bere",
    "bevessi": "bere",
    "bevessimo": "bere",
    "beveste": "bere",
    "bevesti": "bere",
    "bevete": "bere",
    "beveva": "bere",
    "bevevamo": "bere",
    "bevevan": "bere",
    "bevevano": "bere",
    "bevevate": "bere",
    "bevevi": "bere",
    "bevevo": "bere",
    "bevi": "bere",
    "beviamo": "bere",
    "beviate": "bere",
    "bevicchi": "bevicchiare",
    "bevicchia": "bevicchiare",
    "bevicchiai": "bevicchiare",
    "bevicchiammo": "bevicchiare",
    "bevicchiamo": "bevicchiare",
    "bevicchian": "bevicchiare",
    "bevicchiando": "bevicchiare",
    "bevicchiano": "bevicchiare",
    "bevicchiante": "bevicchiare",
    "bevicchianti": "bevicchiare",
    "bevicchiar": "bevicchiare",
    "bevicchiaron": "bevicchiare",
    "bevicchiarono": "bevicchiare",
    "bevicchiasse": "bevicchiare",
    "bevicchiasser": "bevicchiare",
    "bevicchiassero": "bevicchiare",
    "bevicchiassi": "bevicchiare",
    "bevicchiassimo": "bevicchiare",
    "bevicchiaste": "bevicchiare",
    "bevicchiasti": "bevicchiare",
    "bevicchiata": "bevicchiare",
    "bevicchiate": "bevicchiare",
    "bevicchiati": "bevicchiare",
    "bevicchiato": "bevicchiare",
    "bevicchiava": "bevicchiare",
    "bevicchiavamo": "bevicchiare",
    "bevicchiavan": "bevicchiare",
    "bevicchiavano": "bevicchiare",
    "bevicchiavate": "bevicchiare",
    "bevicchiavi": "bevicchiare",
    "bevicchiavo": "bevicchiare",
    "bevicchierai": "bevicchiare",
    "bevicchieran": "bevicchiare",
    "bevicchieranno": "bevicchiare",
    "bevicchierebbe": "bevicchiare",
    "bevicchierebber": "bevicchiare",
    "bevicchierebbero": "bevicchiare",
    "bevicchierei": "bevicchiare",
    "bevicchieremmo": "bevicchiare",
    "bevicchieremo": "bevicchiare",
    "bevicchiereste": "bevicchiare",
    "bevicchieresti": "bevicchiare",
    "bevicchierete": "bevicchiare",
    "bevicchierà": "bevicchiare",
    "bevicchierò": "bevicchiare",
    "bevicchin": "bevicchiare",
    "bevicchino": "bevicchiare",
    "bevicchio": "bevicchiare",
    "bevicchiò": "bevicchiare",
    "bevitori": "bevitore",
    "bevo": "bere",
    "bevon": "bere",
    "bevono": "bere",
    "bevuta": "bere",
    "bevute": "bevuta",
    "bevuti": "bere",
    "bevuto": "bere",
    "bevve": "bere",
    "bevver": "bere",
    "bevvero": "bere",
    "bevvi": "bere",
    "beò": "beare",
    "bianca": "bianco",
    "biancastra": "biancastro",
    "biancastre": "biancastro",
    "biancastri": "biancastro",
    "biancazzurri": "biancazzurro",
    "biancha": "bianchire",
    "bianchan": "bianchire",
    "bianchano": "bianchire",
    "bianche": "bianco",
    "biancheggerai": "biancheggiare",
    "biancheggeran": "biancheggiare",
    "biancheggeranno": "biancheggiare",
    "biancheggerebbe": "biancheggiare",
    "biancheggerebber": "biancheggiare",
    "biancheggerebbero": "biancheggiare",
    "biancheggerei": "biancheggiare",
    "biancheggeremmo": "biancheggiare",
    "biancheggeremo": "biancheggiare",
    "biancheggereste": "biancheggiare",
    "biancheggeresti": "biancheggiare",
    "biancheggerete": "biancheggiare",
    "biancheggerà": "biancheggiare",
    "biancheggerò": "biancheggiare",
    "biancheggi": "biancheggiare",
    "biancheggia": "biancheggiare",
    "biancheggiai": "biancheggiare",
    "biancheggiammo": "biancheggiare",
    "biancheggiamo": "biancheggiare",
    "biancheggian": "biancheggiare",
    "biancheggiando": "biancheggiare",
    "biancheggiano": "biancheggiare",
    "biancheggiante": "biancheggiare",
    "biancheggianti": "biancheggiare",
    "biancheggiar": "biancheggiare",
    "biancheggiaron": "biancheggiare",
    "biancheggiarono": "biancheggiare",
    "biancheggiasse": "biancheggiare",
    "biancheggiasser": "biancheggiare",
    "biancheggiassero": "biancheggiare",
    "biancheggiassi": "biancheggiare",
    "biancheggiassimo": "biancheggiare",
    "biancheggiaste": "biancheggiare",
    "biancheggiasti": "biancheggiare",
    "biancheggiata": "biancheggiare",
    "biancheggiate": "biancheggiare",
    "biancheggiati": "biancheggiare",
    "biancheggiato": "biancheggiare",
    "biancheggiava": "biancheggiare",
    "biancheggiavamo": "biancheggiare",
    "biancheggiavan": "biancheggiare",
    "biancheggiavano": "biancheggiare",
    "biancheggiavate": "biancheggiare",
    "biancheggiavi": "biancheggiare",
    "biancheggiavo": "biancheggiare",
    "biancheggin": "biancheggiare",
    "biancheggino": "biancheggiare",
    "biancheggio": "biancheggiare",
    "biancheggiò": "biancheggiare",
    "bianchendo": "bianchire",
    "bianchente": "bianchire",
    "bianchenti": "bianchire",
    "biancherie": "biancheria",
    "bianchetta": "bianchetto",
    "bianchette": "bianchetto",
    "bianchetti": "bianchetto",
    "bianchi": "bianco",
    "bianchiamo": "bianchire",
    "bianchiate": "bianchire",
    "bianchii": "bianchire",
    "bianchimmo": "bianchire",
    "bianchir": "bianchire",
    "bianchirai": "bianchire",
    "bianchiran": "bianchire",
    "bianchiranno": "bianchire",
    "bianchirebbe": "bianchire",
    "bianchirebber": "bianchire",
    "bianchirebbero": "bianchire",
    "bianchirei": "bianchire",
    "bianchiremmo": "bianchire",
    "bianchiremo": "bianchire",
    "bianchireste": "bianchire",
    "bianchiresti": "bianchire",
    "bianchirete": "bianchire",
    "bianchiron": "bianchire",
    "bianchirono": "bianchire",
    "bianchirà": "bianchire",
    "bianchirò": "bianchire",
    "bianchisse": "bianchire",
    "bianchisser": "bianchire",
    "bianchissero": "bianchire",
    "bianchissi": "bianchire",
    "bianchissimo": "bianchire",
    "bianchiste": "bianchire",
    "bianchisti": "bianchire",
    "bianchita": "bianchire",
    "bianchite": "bianchire",
    "bianchiti": "bianchire",
    "bianchito": "bianchire",
    "bianchiva": "bianchire",
    "bianchivamo": "bianchire",
    "bianchivan": "bianchire",
    "bianchivano": "bianchire",
    "bianchivate": "bianchire",
    "bianchivi": "bianchire",
    "bianchivo": "bianchire",
    "biancho": "bianchire",
    "bianchon": "bianchire",
    "bianchono": "bianchire",
    "bianchì": "bianchire",
    "biancocelesti": "biancoceleste",
    "bianconeri": "bianconero",
    "biancori": "biancore",
    "biancorossi": "biancorosso",
    "biascerai": "biasciare",
    "biasceran": "biasciare",
    "biasceranno": "biasciare",
    "biascerebbe": "biasciare",
    "biascerebber": "biasciare",
    "biascerebbero": "biasciare",
    "biascerei": "biasciare",
    "biasceremmo": "biasciare",
    "biasceremo": "biasciare",
    "biascereste": "biasciare",
    "biasceresti": "biasciare",
    "biascerete": "biasciare",
    "biascerà": "biasciare",
    "biascerò": "biasciare",
    "biasci": "biasciare",
    "biascia": "biasciare",
    "biasciai": "biasciare",
    "biasciammo": "biasciare",
    "biasciamo": "biasciare",
    "biascian": "biasciare",
    "biasciando": "biasciare",
    "biasciano": "biasciare",
    "biasciante": "biasciare",
    "biascianti": "biasciare",
    "biasciar": "biasciare",
    "biasciaron": "biasciare",
    "biasciarono": "biasciare",
    "biasciasse": "biasciare",
    "biasciasser": "biasciare",
    "biasciassero": "biasciare",
    "biasciassi": "biasciare",
    "biasciassimo": "biasciare",
    "biasciaste": "biasciare",
    "biasciasti": "biasciare",
    "biasciata": "biasciare",
    "biasciate": "biasciare",
    "biasciati": "biasciare",
    "biasciato": "biasciare",
    "biasciava": "biasciare",
    "biasciavamo": "biasciare",
    "biasciavan": "biasciare",
    "biasciavano": "biasciare",
    "biasciavate": "biasciare",
    "biasciavi": "biasciare",
    "biasciavo": "biasciare",
    "biascica": "biascicare",
    "biascicai": "biascicare",
    "biascicammo": "biascicare",
    "biascican": "biascicare",
    "biascicando": "biascicare",
    "biascicano": "biascicare",
    "biascicante": "biascicare",
    "biascicanti": "biascicare",
    "biascicar": "biascicare",
    "biascicaron": "biascicare",
    "biascicarono": "biascicare",
    "biascicasse": "biascicare",
    "biascicasser": "biascicare",
    "biascicassero": "biascicare",
    "biascicassi": "biascicare",
    "biascicassimo": "biascicare",
    "biascicaste": "biascicare",
    "biascicasti": "biascicare",
    "biascicata": "biascicare",
    "biascicate": "biascicare",
    "biascicati": "biascicare",
    "biascicato": "biascicare",
    "biascicava": "biascicare",
    "biascicavamo": "biascicare",
    "biascicavan": "biascicare",
    "biascicavano": "biascicare",
    "biascicavate": "biascicare",
    "biascicavi": "biascicare",
    "biascicavo": "biascicare",
    "biascicherai": "biascicare",
    "biascicheran": "biascicare",
    "biascicheranno": "biascicare",
    "biascicherebbe": "biascicare",
    "biascicherebber": "biascicare",
    "biascicherebbero": "biascicare",
    "biascicherei": "biascicare",
    "biascicheremmo": "biascicare",
    "biascicheremo": "biascicare",
    "biascichereste": "biascicare",
    "biascicheresti": "biascicare",
    "biascicherete": "biascicare",
    "biascicherà": "biascicare",
    "biascicherò": "biascicare",
    "biascichi": "biascicare",
    "biascichiamo": "biascicare",
    "biascichiate": "biascicare",
    "biascichin": "biascicare",
    "biascichino": "biascicare",
    "biascico": "biascicare",
    "biascicò": "biascicare",
    "biascin": "biasciare",
    "biascino": "biasciare",
    "biascio": "biasciare",
    "biasciò": "biasciare",
    "biasima": "biasimare",
    "biasimai": "biasimare",
    "biasimammo": "biasimare",
    "biasiman": "biasimare",
    "biasimando": "biasimare",
    "biasimano": "biasimare",
    "biasimante": "biasimare",
    "biasimanti": "biasimare",
    "biasimar": "biasimare",
    "biasimaron": "biasimare",
    "biasimarono": "biasimare",
    "biasimasse": "biasimare",
    "biasimasser": "biasimare",
    "biasimassero": "biasimare",
    "biasimassi": "biasimare",
    "biasimassimo": "biasimare",
    "biasimaste": "biasimare",
    "biasimasti": "biasimare",
    "biasimata": "biasimare",
    "biasimate": "biasimare",
    "biasimati": "biasimare",
    "biasimato": "biasimare",
    "biasimava": "biasimare",
    "biasimavamo": "biasimare",
    "biasimavan": "biasimare",
    "biasimavano": "biasimare",
    "biasimavate": "biasimare",
    "biasimavi": "biasimare",
    "biasimavo": "biasimare",
    "biasimerai": "biasimare",
    "biasimeran": "biasimare",
    "biasimeranno": "biasimare",
    "biasimerebbe": "biasimare",
    "biasimerebber": "biasimare",
    "biasimerebbero": "biasimare",
    "biasimerei": "biasimare",
    "biasimeremmo": "biasimare",
    "biasimeremo": "biasimare",
    "biasimereste": "biasimare",
    "biasimeresti": "biasimare",
    "biasimerete": "biasimare",
    "biasimerà": "biasimare",
    "biasimerò": "biasimare",
    "biasimevoli": "biasimevole",
    "biasimi": "biasimare",
    "biasimiamo": "biasimare",
    "biasimiate": "biasimare",
    "biasimin": "biasimare",
    "biasimino": "biasimare",
    "biasimo": "biasimare",
    "biasimò": "biasimare",
    "bibite": "bibita",
    "biblica": "biblico",
    "bibliche": "biblico",
    "biblici": "biblico",
    "bibliofila": "bibliofilo",
    "bibliofile": "bibliofilo",
    "bibliofili": "bibliofilo",
    "bibliografica": "bibliografico",
    "bibliografiche": "bibliografico",
    "bibliografici": "bibliografico",
    "bibliografie": "bibliografia",
    "bibliotecari": "bibliotecario",
    "biblioteche": "biblioteca",
    "biblisti": "biblista",
    "bicamerali": "bicamerale",
    "bicameralismi": "bicameralismo",
    "bicampioni": "bicampione",
    "bicchieri": "bicchiere",
    "bicchierini": "bicchierino",
    "bicefala": "bicefalo",
    "bicefale": "bicefalo",
    "bicefali": "bicefalo",
    "bicentenari": "bicentenario",
    "biciclette": "bicicletta",
    "bicilindrica": "bicilindrico",
    "bicilindriche": "bicilindrico",
    "bicilindrici": "bicilindrico",
    "bicipiti": "bicipite",
    "bicolori": "bicolore",
    "bidelle": "bidella",
    "bidelli": "bidello",
    "bidona": "bidonare",
    "bidonai": "bidonare",
    "bidonammo": "bidonare",
    "bidonan": "bidonare",
    "bidonando": "bidonare",
    "bidonano": "bidonare",
    "bidonante": "bidonare",
    "bidonanti": "bidonare",
    "bidonar": "bidonare",
    "bidonaron": "bidonare",
    "bidonarono": "bidonare",
    "bidonasse": "bidonare",
    "bidonasser": "bidonare",
    "bidonassero": "bidonare",
    "bidonassi": "bidonare",
    "bidonassimo": "bidonare",
    "bidonaste": "bidonare",
    "bidonasti": "bidonare",
    "bidonata": "bidonare",
    "bidonate": "bidonare",
    "bidonati": "bidonare",
    "bidonato": "bidonare",
    "bidonava": "bidonare",
    "bidonavamo": "bidonare",
    "bidonavan": "bidonare",
    "bidonavano": "bidonare",
    "bidonavate": "bidonare",
    "bidonavi": "bidonare",
    "bidonavo": "bidonare",
    "bidonerai": "bidonare",
    "bidoneran": "bidonare",
    "bidoneranno": "bidonare",
    "bidonerebbe": "bidonare",
    "bidonerebber": "bidonare",
    "bidonerebbero": "bidonare",
    "bidonerei": "bidonare",
    "bidoneremmo": "bidonare",
    "bidoneremo": "bidonare",
    "bidonereste": "bidonare",
    "bidoneresti": "bidonare",
    "bidonerete": "bidonare",
    "bidonerà": "bidonare",
    "bidonerò": "bidonare",
    "bidoni": "bidone",
    "bidoniamo": "bidonare",
    "bidoniate": "bidonare",
    "bidonin": "bidonare",
    "bidonino": "bidonare",
    "bidono": "bidonare",
    "bidonò": "bidonare",
    "bieca": "bieco",
    "bieche": "bieco",
    "biechi": "bieco",
    "biellesi": "biellese",
    "bielorussa": "bielorusso",
    "bielorusse": "bielorusso",
    "bielorussi": "bielorusso",
    "biennali": "biennale",
    "bienni": "biennio",
    "bietole": "bietola",
    "biffa": "biffare",
    "biffai": "biffare",
    "biffammo": "biffare",
    "biffan": "biffare",
    "biffando": "biffare",
    "biffano": "biffare",
    "biffante": "biffare",
    "biffanti": "biffare",
    "biffar": "biffare",
    "biffaron": "biffare",
    "biffarono": "biffare",
    "biffasse": "biffare",
    "biffasser": "biffare",
    "biffassero": "biffare",
    "biffassi": "biffare",
    "biffassimo": "biffare",
    "biffaste": "biffare",
    "biffasti": "biffare",
    "biffata": "biffare",
    "biffate": "biffare",
    "biffati": "biffare",
    "biffato": "biffare",
    "biffava": "biffare",
    "biffavamo": "biffare",
    "biffavan": "biffare",
    "biffavano": "biffare",
    "biffavate": "biffare",
    "biffavi": "biffare",
    "biffavo": "biffare",
    "bifferai": "biffare",
    "bifferan": "biffare",
    "bifferanno": "biffare",
    "bifferebbe": "biffare",
    "bifferebber": "biffare",
    "bifferebbero": "biffare",
    "bifferei": "biffare",
    "bifferemmo": "biffare",
    "bifferemo": "biffare",
    "biffereste": "biffare",
    "bifferesti": "biffare",
    "bifferete": "biffare",
    "bifferà": "biffare",
    "bifferò": "biffare",
    "biffi": "biffare",
    "biffiamo": "biffare",
    "biffiate": "biffare",
    "biffin": "biffare",
    "biffino": "biffare",
    "biffo": "biffare",
    "biffò": "biffare",
    "bifilari": "bifilare",
    "biforca": "biforcare",
    "biforcai": "biforcare",
    "biforcammo": "biforcare",
    "biforcan": "biforcare",
    "biforcando": "biforcare",
    "biforcano": "biforcare",
    "biforcante": "biforcare",
    "biforcanti": "biforcare",
    "biforcar": "biforcare",
    "biforcaron": "biforcare",
    "biforcarono": "biforcare",
    "biforcasse": "biforcare",
    "biforcasser": "biforcare",
    "biforcassero": "biforcare",
    "biforcassi": "biforcare",
    "biforcassimo": "biforcare",
    "biforcaste": "biforcare",
    "biforcasti": "biforcare",
    "biforcata": "biforcare",
    "biforcate": "biforcare",
    "biforcati": "biforcare",
    "biforcato": "biforcare",
    "biforcava": "biforcare",
    "biforcavamo": "biforcare",
    "biforcavan": "biforcare",
    "biforcavano": "biforcare",
    "biforcavate": "biforcare",
    "biforcavi": "biforcare",
    "biforcavo": "biforcare",
    "biforcazioni": "biforcazione",
    "biforcherai": "biforcare",
    "biforcheran": "biforcare",
    "biforcheranno": "biforcare",
    "biforcherebbe": "biforcare",
    "biforcherebber": "biforcare",
    "biforcherebbero": "biforcare",
    "biforcherei": "biforcare",
    "biforcheremmo": "biforcare",
    "biforcheremo": "biforcare",
    "biforchereste": "biforcare",
    "biforcheresti": "biforcare",
    "biforcherete": "biforcare",
    "biforcherà": "biforcare",
    "biforcherò": "biforcare",
    "biforchi": "biforcare",
    "biforchiamo": "biforcare",
    "biforchiate": "biforcare",
    "biforchin": "biforcare",
    "biforchino": "biforcare",
    "biforco": "biforcare",
    "biforcuta": "biforcuto",
    "biforcute": "biforcuto",
    "biforcuti": "biforcuto",
    "biforcò": "biforcare",
    "bifronti": "bifronte",
    "bigerai": "bigiare",
    "bigeran": "bigiare",
    "bigeranno": "bigiare",
    "bigerebbe": "bigiare",
    "bigerebber": "bigiare",
    "bigerebbero": "bigiare",
    "bigerei": "bigiare",
    "bigeremmo": "bigiare",
    "bigeremo": "bigiare",
    "bigereste": "bigiare",
    "bigeresti": "bigiare",
    "bigerete": "bigiare",
    "bigerà": "bigiare",
    "bigerò": "bigiare",
    "bighe": "biga",
    "bighellona": "bighellonare",
    "bighellonai": "bighellonare",
    "bighellonammo": "bighellonare",
    "bighellonan": "bighellonare",
    "bighellonando": "bighellonare",
    "bighellonano": "bighellonare",
    "bighellonante": "bighellonare",
    "bighellonanti": "bighellonare",
    "bighellonar": "bighellonare",
    "bighellonaron": "bighellonare",
    "bighellonarono": "bighellonare",
    "bighellonasse": "bighellonare",
    "bighellonasser": "bighellonare",
    "bighellonassero": "bighellonare",
    "bighellonassi": "bighellonare",
    "bighellonassimo": "bighellonare",
    "bighellonaste": "bighellonare",
    "bighellonasti": "bighellonare",
    "bighellonata": "bighellonare",
    "bighellonate": "bighellonare",
    "bighellonati": "bighellonare",
    "bighellonato": "bighellonare",
    "bighellonava": "bighellonare",
    "bighellonavamo": "bighellonare",
    "bighellonavan": "bighellonare",
    "bighellonavano": "bighellonare",
    "bighellonavate": "bighellonare",
    "bighellonavi": "bighellonare",
    "bighellonavo": "bighellonare",
    "bighellonerai": "bighellonare",
    "bighelloneran": "bighellonare",
    "bighelloneranno": "bighellonare",
    "bighellonerebbe": "bighellonare",
    "bighellonerebber": "bighellonare",
    "bighellonerebbero": "bighellonare",
    "bighellonerei": "bighellonare",
    "bighelloneremmo": "bighellonare",
    "bighelloneremo": "bighellonare",
    "bighellonereste": "bighellonare",
    "bighelloneresti": "bighellonare",
    "bighellonerete": "bighellonare",
    "bighellonerà": "bighellonare",
    "bighellonerò": "bighellonare",
    "bighelloni": "bighellonare",
    "bighelloniamo": "bighellonare",
    "bighelloniate": "bighellonare",
    "bighellonin": "bighellonare",
    "bighellonino": "bighellonare",
    "bighellono": "bighellonare",
    "bighellonò": "bighellonare",
    "bigi": "bigio",
    "bigia": "bigio",
    "bigiai": "bigiare",
    "bigiammo": "bigiare",
    "bigiamo": "bigiare",
    "bigian": "bigiare",
    "bigiando": "bigiare",
    "bigiano": "bigiare",
    "bigiante": "bigiare",
    "bigianti": "bigiare",
    "bigiar": "bigiare",
    "bigiaron": "bigiare",
    "bigiarono": "bigiare",
    "bigiasse": "bigiare",
    "bigiasser": "bigiare",
    "bigiassero": "bigiare",
    "bigiassi": "bigiare",
    "bigiassimo": "bigiare",
    "bigiaste": "bigiare",
    "bigiasti": "bigiare",
    "bigiata": "bigiare",
    "bigiate": "bigiare",
    "bigiati": "bigiare",
    "bigiato": "bigiare",
    "bigiava": "bigiare",
    "bigiavamo": "bigiare",
    "bigiavan": "bigiare",
    "bigiavano": "bigiare",
    "bigiavate": "bigiare",
    "bigiavi": "bigiare",
    "bigiavo": "bigiare",
    "bigie": "bigio",
    "bigin": "bigiare",
    "bigino": "bigiare",
    "bigio": "bigiare",
    "bigiotterie": "bigiotteria",
    "bigiò": "bigiare",
    "biglie": "biglia",
    "bigliettai": "bigliettaio",
    "biglietterie": "biglietteria",
    "biglietti": "biglietto",
    "bigliettini": "bigliettino",
    "bigotta": "bigotto",
    "bigotte": "bigotto",
    "bigotti": "bigotto",
    "bigottismi": "bigottismo",
    "bilance": "bilancia",
    "bilancerai": "bilanciare",
    "bilanceran": "bilanciare",
    "bilanceranno": "bilanciare",
    "bilancerebbe": "bilanciare",
    "bilancerebber": "bilanciare",
    "bilancerebbero": "bilanciare",
    "bilancerei": "bilanciare",
    "bilanceremmo": "bilanciare",
    "bilanceremo": "bilanciare",
    "bilancereste": "bilanciare",
    "bilanceresti": "bilanciare",
    "bilancerete": "bilanciare",
    "bilancerà": "bilanciare",
    "bilancerò": "bilanciare",
    "bilanci": "bilancio",
    "bilancia": "bilanciare",
    "bilanciai": "bilanciare",
    "bilanciamenti": "bilanciamento",
    "bilanciammo": "bilanciare",
    "bilanciamo": "bilanciare",
    "bilancian": "bilanciare",
    "bilanciando": "bilanciare",
    "bilanciano": "bilanciare",
    "bilanciante": "bilanciare",
    "bilancianti": "bilanciare",
    "bilanciar": "bilanciare",
    "bilanciaron": "bilanciare",
    "bilanciarono": "bilanciare",
    "bilanciasse": "bilanciare",
    "bilanciasser": "bilanciare",
    "bilanciassero": "bilanciare",
    "bilanciassi": "bilanciare",
    "bilanciassimo": "bilanciare",
    "bilanciaste": "bilanciare",
    "bilanciasti": "bilanciare",
    "bilanciata": "bilanciato",
    "bilanciate": "bilanciato",
    "bilanciati": "bilanciato",
    "bilanciato": "bilanciare",
    "bilanciava": "bilanciare",
    "bilanciavamo": "bilanciare",
    "bilanciavan": "bilanciare",
    "bilanciavano": "bilanciare",
    "bilanciavate": "bilanciare",
    "bilanciavi": "bilanciare",
    "bilanciavo": "bilanciare",
    "bilancieri": "bilanciere",
    "bilancin": "bilanciare",
    "bilancini": "bilancino",
    "bilancino": "bilanciare",
    "bilancio": "bilanciare",
    "bilanciò": "bilanciare",
    "bilaterali": "bilaterale",
    "bili": "bile",
    "biliardi": "biliardo",
    "biliardini": "biliardino",
    "biliari": "biliare",
    "bilingui": "bilingue",
    "bilinguismi": "bilinguismo",
    "biliosa": "bilioso",
    "biliose": "bilioso",
    "biliosi": "bilioso",
    "bilocali": "bilocale",
    "bimana": "bimano",
    "bimane": "bimano",
    "bimani": "bimano",
    "bimbe": "bimba",
    "bimbette": "bimbetta",
    "bimbetti": "bimbetto",
    "bimbi": "bimbo",
    "bimestrali": "bimestrale",
    "bimillenari": "bimillenario",
    "bimotori": "bimotore",
    "bimotrice": "bimotore",
    "bimotrici": "bimotore",
    "binari": "binario",
    "binaria": "binario",
    "binarie": "binario",
    "binata": "binato",
    "binate": "binato",
    "binati": "binato",
    "binocoli": "binocolo",
    "binomi": "binomio",
    "binomia": "binomio",
    "binomie": "binomio",
    "biochimica": "biochimico",
    "biochimiche": "biochimico",
    "biochimici": "biochimico",
    "biodegradabili": "biodegradabile",
    "bioetica": "bioetico",
    "bioetiche": "bioetico",
    "bioetici": "bioetico",
    "biografi": "biografo",
    "biografica": "biografico",
    "biografiche": "biografico",
    "biografici": "biografico",
    "biografie": "biografia",
    "bioingegneri": "bioingegnere",
    "bioingegnerie": "bioingegneria",
    "biologhe": "biologa",
    "biologi": "biologo",
    "biologica": "biologico",
    "biologiche": "biologico",
    "biologici": "biologico",
    "biologie": "biologia",
    "biomasse": "biomassa",
    "biomeccanici": "biomeccanico",
    "biomedica": "biomedico",
    "biomediche": "biomedico",
    "biomedici": "biomedico",
    "bionda": "biondo",
    "biondastra": "biondastro",
    "biondastre": "biondastro",
    "biondastri": "biondastro",
    "bionde": "biondo",
    "biondi": "biondo",
    "biondicca": "biondicco",
    "biondicce": "biondiccio",
    "biondicche": "biondicco",
    "biondicchi": "biondicco",
    "biondicci": "biondiccio",
    "biondiccia": "biondiccio",
    "biondine": "biondina",
    "biopsie": "biopsia",
    "bioritmi": "bioritmo",
    "biosfere": "biosfera",
    "biossidi": "biossido",
    "biotecnologica": "biotecnologico",
    "biotecnologiche": "biotecnologico",
    "biotecnologici": "biotecnologico",
    "biotecnologie": "biotecnologia",
    "biparta": "bipartire",
    "bipartan": "bipartire",
    "bipartano": "bipartire",
    "biparte": "bipartire",
    "bipartendo": "bipartire",
    "bipartente": "bipartire",
    "bipartenti": "bipartire",
    "biparti": "bipartire",
    "bipartiamo": "bipartire",
    "bipartiate": "bipartire",
    "bipartii": "bipartire",
    "bipartimmo": "bipartire",
    "bipartir": "bipartire",
    "bipartirai": "bipartire",
    "bipartiran": "bipartire",
    "bipartiranno": "bipartire",
    "bipartirebbe": "bipartire",
    "bipartirebber": "bipartire",
    "bipartirebbero": "bipartire",
    "bipartirei": "bipartire",
    "bipartiremmo": "bipartire",
    "bipartiremo": "bipartire",
    "bipartireste": "bipartire",
    "bipartiresti": "bipartire",
    "bipartirete": "bipartire",
    "bipartiron": "bipartire",
    "bipartirono": "bipartire",
    "bipartirà": "bipartire",
    "bipartirò": "bipartire",
    "bipartisse": "bipartire",
    "bipartisser": "bipartire",
    "bipartissero": "bipartire",
    "bipartissi": "bipartire",
    "bipartissimo": "bipartire",
    "bipartiste": "bipartire",
    "bipartisti": "bipartire",
    "bipartita": "bipartire",
    "bipartite": "bipartire",
    "bipartiti": "bipartire",
    "bipartitismi": "bipartitismo",
    "bipartito": "bipartire",
    "bipartiva": "bipartire",
    "bipartivamo": "bipartire",
    "bipartivan": "bipartire",
    "bipartivano": "bipartire",
    "bipartivate": "bipartire",
    "bipartivi": "bipartire",
    "bipartivo": "bipartire",
    "biparto": "bipartire",
    "biparton": "bipartire",
    "bipartono": "bipartire",
    "bipartì": "bipartire",
    "bipedi": "bipede",
    "biplana": "biplano",
    "biplane": "biplano",
    "biplani": "biplano",
    "bipolari": "bipolare",
    "bipolarismi": "bipolarismo",
    "biposta": "biposto",
    "biposte": "biposto",
    "biposti": "biposto",
    "birboni": "birbone",
    "bireattori": "bireattore",
    "bireattrice": "bireattore",
    "bireattrici": "bireattore",
    "birichina": "birichino",
    "birichine": "birichino",
    "birichini": "birichino",
    "birilli": "birillo",
    "birmana": "birmano",
    "birmane": "birmano",
    "birmani": "birmano",
    "birrai": "birraio",
    "birre": "birra",
    "birrerie": "birreria",
    "bisacce": "bisaccia",
    "bisbetica": "bisbetico",
    "bisbetiche": "bisbetico",
    "bisbetici": "bisbetico",
    "bisbigli": "bisbiglio",
    "bisbiglia": "bisbigliare",
    "bisbigliai": "bisbigliare",
    "bisbigliammo": "bisbigliare",
    "bisbigliamo": "bisbigliare",
    "bisbiglian": "bisbigliare",
    "bisbigliando": "bisbigliare",
    "bisbigliano": "bisbigliare",
    "bisbigliante": "bisbigliare",
    "bisbiglianti": "bisbigliare",
    "bisbigliar": "bisbigliare",
    "bisbigliaron": "bisbigliare",
    "bisbigliarono": "bisbigliare",
    "bisbigliasse": "bisbigliare",
    "bisbigliasser": "bisbigliare",
    "bisbigliassero": "bisbigliare",
    "bisbigliassi": "bisbigliare",
    "bisbigliassimo": "bisbigliare",
    "bisbigliaste": "bisbigliare",
    "bisbigliasti": "bisbigliare",
    "bisbigliata": "bisbigliare",
    "bisbigliate": "bisbigliare",
    "bisbigliati": "bisbigliare",
    "bisbigliato": "bisbigliare",
    "bisbigliava": "bisbigliare",
    "bisbigliavamo": "bisbigliare",
    "bisbigliavan": "bisbigliare",
    "bisbigliavano": "bisbigliare",
    "bisbigliavate": "bisbigliare",
    "bisbigliavi": "bisbigliare",
    "bisbigliavo": "bisbigliare",
    "bisbiglierai": "bisbigliare",
    "bisbiglieran": "bisbigliare",
    "bisbiglieranno": "bisbigliare",
    "bisbiglierebbe": "bisbigliare",
    "bisbiglierebber": "bisbigliare",
    "bisbiglierebbero": "bisbigliare",
    "bisbiglierei": "bisbigliare",
    "bisbiglieremmo": "bisbigliare",
    "bisbiglieremo": "bisbigliare",
    "bisbigliereste": "bisbigliare",
    "bisbiglieresti": "bisbigliare",
    "bisbiglierete": "bisbigliare",
    "bisbiglierà": "bisbigliare",
    "bisbiglierò": "bisbigliare",
    "bisbiglin": "bisbigliare",
    "bisbiglino": "bisbigliare",
    "bisbiglio": "bisbigliare",
    "bisbigliò": "bisbigliare",
    "bisboccerai": "bisbocciare",
    "bisbocceran": "bisbocciare",
    "bisbocceranno": "bisbocciare",
    "bisboccerebbe": "bisbocciare",
    "bisboccerebber": "bisbocciare",
    "bisboccerebbero": "bisbocciare",
    "bisboccerei": "bisbocciare",
    "bisbocceremmo": "bisbocciare",
    "bisbocceremo": "bisbocciare",
    "bisboccereste": "bisbocciare",
    "bisbocceresti": "bisbocciare",
    "bisboccerete": "bisbocciare",
    "bisboccerà": "bisbocciare",
    "bisboccerò": "bisbocciare",
    "bisbocci": "bisbocciare",
    "bisboccia": "bisbocciare",
    "bisbocciai": "bisbocciare",
    "bisbocciammo": "bisbocciare",
    "bisbocciamo": "bisbocciare",
    "bisboccian": "bisbocciare",
    "bisbocciando": "bisbocciare",
    "bisbocciano": "bisbocciare",
    "bisbocciante": "bisbocciare",
    "bisboccianti": "bisbocciare",
    "bisbocciar": "bisbocciare",
    "bisbocciaron": "bisbocciare",
    "bisbocciarono": "bisbocciare",
    "bisbocciasse": "bisbocciare",
    "bisbocciasser": "bisbocciare",
    "bisbocciassero": "bisbocciare",
    "bisbocciassi": "bisbocciare",
    "bisbocciassimo": "bisbocciare",
    "bisbocciaste": "bisbocciare",
    "bisbocciasti": "bisbocciare",
    "bisbocciata": "bisbocciare",
    "bisbocciate": "bisbocciare",
    "bisbocciati": "bisbocciare",
    "bisbocciato": "bisbocciare",
    "bisbocciava": "bisbocciare",
    "bisbocciavamo": "bisbocciare",
    "bisbocciavan": "bisbocciare",
    "bisbocciavano": "bisbocciare",
    "bisbocciavate": "bisbocciare",
    "bisbocciavi": "bisbocciare",
    "bisbocciavo": "bisbocciare",
    "bisboccin": "bisbocciare",
    "bisboccino": "bisbocciare",
    "bisboccio": "bisbocciare",
    "bisbocciò": "bisbocciare",
    "biscazzieri": "biscazziere",
    "bische": "bisca",
    "bischeri": "bischero",
    "biscioni": "biscione",
    "biscotta": "biscottare",
    "biscottai": "biscottare",
    "biscottammo": "biscottare",
    "biscottan": "biscottare",
    "biscottando": "biscottare",
    "biscottano": "biscottare",
    "biscottante": "biscottare",
    "biscottanti": "biscottare",
    "biscottar": "biscottare",
    "biscottaron": "biscottare",
    "biscottarono": "biscottare",
    "biscottasse": "biscottare",
    "biscottasser": "biscottare",
    "biscottassero": "biscottare",
    "biscottassi": "biscottare",
    "biscottassimo": "biscottare",
    "biscottaste": "biscottare",
    "biscottasti": "biscottare",
    "biscottata": "biscottare",
    "biscottate": "biscottare",
    "biscottati": "biscottare",
    "biscottato": "biscottare",
    "biscottava": "biscottare",
    "biscottavamo": "biscottare",
    "biscottavan": "biscottare",
    "biscottavano": "biscottare",
    "biscottavate": "biscottare",
    "biscottavi": "biscottare",
    "biscottavo": "biscottare",
    "biscotterai": "biscottare",
    "biscotteran": "biscottare",
    "biscotteranno": "biscottare",
    "biscotterebbe": "biscottare",
    "biscotterebber": "biscottare",
    "biscotterebbero": "biscottare",
    "biscotterei": "biscottare",
    "biscotteremmo": "biscottare",
    "biscotteremo": "biscottare",
    "biscottereste": "biscottare",
    "biscotteresti": "biscottare",
    "biscotterete": "biscottare",
    "biscotterà": "biscottare",
    "biscotterò": "biscottare",
    "biscotti": "biscotto",
    "biscottiamo": "biscottare",
    "biscottiate": "biscottare",
    "biscottin": "biscottare",
    "biscottini": "biscottino",
    "biscottino": "biscottare",
    "biscotto": "biscottare",
    "biscottò": "biscottare",
    "bisecola": "bisecolare",
    "bisecolai": "bisecolare",
    "bisecolammo": "bisecolare",
    "bisecolan": "bisecolare",
    "bisecolando": "bisecolare",
    "bisecolano": "bisecolare",
    "bisecolante": "bisecolare",
    "bisecolanti": "bisecolare",
    "bisecolar": "bisecolare",
    "bisecolaron": "bisecolare",
    "bisecolarono": "bisecolare",
    "bisecolasse": "bisecolare",
    "bisecolasser": "bisecolare",
    "bisecolassero": "bisecolare",
    "bisecolassi": "bisecolare",
    "bisecolassimo": "bisecolare",
    "bisecolaste": "bisecolare",
    "bisecolasti": "bisecolare",
    "bisecolata": "bisecolare",
    "bisecolate": "bisecolare",
    "bisecolati": "bisecolare",
    "bisecolato": "bisecolare",
    "bisecolava": "bisecolare",
    "bisecolavamo": "bisecolare",
    "bisecolavan": "bisecolare",
    "bisecolavano": "bisecolare",
    "bisecolavate": "bisecolare",
    "bisecolavi": "bisecolare",
    "bisecolavo": "bisecolare",
    "bisecolerai": "bisecolare",
    "bisecoleran": "bisecolare",
    "bisecoleranno": "bisecolare",
    "bisecolerebbe": "bisecolare",
    "bisecolerebber": "bisecolare",
    "bisecolerebbero": "bisecolare",
    "bisecolerei": "bisecolare",
    "bisecoleremmo": "bisecolare",
    "bisecoleremo": "bisecolare",
    "bisecolereste": "bisecolare",
    "bisecoleresti": "bisecolare",
    "bisecolerete": "bisecolare",
    "bisecolerà": "bisecolare",
    "bisecolerò": "bisecolare",
    "bisecoli": "bisecolare",
    "bisecoliamo": "bisecolare",
    "bisecoliate": "bisecolare",
    "bisecolin": "bisecolare",
    "bisecolino": "bisecolare",
    "bisecolo": "bisecolare",
    "bisecolò": "bisecolare",
    "bisessuali": "bisessuale",
    "bisettimanali": "bisettimanale",
    "bislacca": "bislacco",
    "bislacche": "bislacco",
    "bislacchi": "bislacco",
    "bisnipoti": "bisnipote",
    "bisnonne": "bisnonna",
    "bisnonni": "bisnonno",
    "bisogna": "bisognare",
    "bisognai": "bisognare",
    "bisognammo": "bisognare",
    "bisognan": "bisognare",
    "bisognando": "bisognare",
    "bisognano": "bisognare",
    "bisognante": "bisognare",
    "bisognanti": "bisognare",
    "bisognar": "bisognare",
    "bisognaron": "bisognare",
    "bisognarono": "bisognare",
    "bisognasse": "bisognare",
    "bisognasser": "bisognare",
    "bisognassero": "bisognare",
    "bisognassi": "bisognare",
    "bisognassimo": "bisognare",
    "bisognaste": "bisognare",
    "bisognasti": "bisognare",
    "bisognata": "bisognare",
    "bisognate": "bisognare",
    "bisognati": "bisognare",
    "bisognato": "bisognare",
    "bisognava": "bisognare",
    "bisognavamo": "bisognare",
    "bisognavan": "bisognare",
    "bisognavano": "bisognare",
    "bisognavate": "bisognare",
    "bisognavi": "bisognare",
    "bisognavo": "bisognare",
    "bisognerai": "bisognare",
    "bisogneran": "bisognare",
    "bisogneranno": "bisognare",
    "bisognerebbe": "bisognare",
    "bisognerebber": "bisognare",
    "bisognerebbero": "bisognare",
    "bisognerei": "bisognare",
    "bisogneremmo": "bisognare",
    "bisogneremo": "bisognare",
    "bisognereste": "bisognare",
    "bisogneresti": "bisognare",
    "bisognerete": "bisognare",
    "bisognerà": "bisognare",
    "bisognerò": "bisognare",
    "bisogni": "bisogno",
    "bisogniamo": "bisognare",
    "bisogniate": "bisognare",
    "bisognin": "bisognare",
    "bisognino": "bisognare",
    "bisogno": "bisognare",
    "bisognosa": "bisognoso",
    "bisognose": "bisognoso",
    "bisognosi": "bisognoso",
    "bisognò": "bisognare",
    "bisonti": "bisonte",
    "bissa": "bissare",
    "bissai": "bissare",
    "bissammo": "bissare",
    "bissan": "bissare",
    "bissando": "bissare",
    "bissano": "bissare",
    "bissante": "bissare",
    "bissanti": "bissare",
    "bissar": "bissare",
    "bissaron": "bissare",
    "bissarono": "bissare",
    "bissasse": "bissare",
    "bissasser": "bissare",
    "bissassero": "bissare",
    "bissassi": "bissare",
    "bissassimo": "bissare",
    "bissaste": "bissare",
    "bissasti": "bissare",
    "bissata": "bissare",
    "bissate": "bissare",
    "bissati": "bissare",
    "bissato": "bissare",
    "bissava": "bissare",
    "bissavamo": "bissare",
    "bissavan": "bissare",
    "bissavano": "bissare",
    "bissavate": "bissare",
    "bissavi": "bissare",
    "bissavo": "bissare",
    "bisserai": "bissare",
    "bisseran": "bissare",
    "bisseranno": "bissare",
    "bisserebbe": "bissare",
    "bisserebber": "bissare",
    "bisserebbero": "bissare",
    "bisserei": "bissare",
    "bisseremmo": "bissare",
    "bisseremo": "bissare",
    "bissereste": "bissare",
    "bisseresti": "bissare",
    "bisserete": "bissare",
    "bisserà": "bissare",
    "bisserò": "bissare",
    "bissi": "bissare",
    "bissiamo": "bissare",
    "bissiate": "bissare",
    "bissin": "bissare",
    "bissino": "bissare",
    "bisso": "bissare",
    "bissò": "bissare",
    "bistecche": "bistecca",
    "bisticcerai": "bisticciare",
    "bisticceran": "bisticciare",
    "bisticceranno": "bisticciare",
    "bisticcerebbe": "bisticciare",
    "bisticcerebber": "bisticciare",
    "bisticcerebbero": "bisticciare",
    "bisticcerei": "bisticciare",
    "bisticceremmo": "bisticciare",
    "bisticceremo": "bisticciare",
    "bisticcereste": "bisticciare",
    "bisticceresti": "bisticciare",
    "bisticcerete": "bisticciare",
    "bisticcerà": "bisticciare",
    "bisticcerò": "bisticciare",
    "bisticci": "bisticcio",
    "bisticcia": "bisticciare",
    "bisticciai": "bisticciare",
    "bisticciammo": "bisticciare",
    "bisticciamo": "bisticciare",
    "bisticcian": "bisticciare",
    "bisticciando": "bisticciare",
    "bisticciano": "bisticciare",
    "bisticciante": "bisticciare",
    "bisticcianti": "bisticciare",
    "bisticciar": "bisticciare",
    "bisticciaron": "bisticciare",
    "bisticciarono": "bisticciare",
    "bisticciasse": "bisticciare",
    "bisticciasser": "bisticciare",
    "bisticciassero": "bisticciare",
    "bisticciassi": "bisticciare",
    "bisticciassimo": "bisticciare",
    "bisticciaste": "bisticciare",
    "bisticciasti": "bisticciare",
    "bisticciata": "bisticciare",
    "bisticciate": "bisticciare",
    "bisticciati": "bisticciare",
    "bisticciato": "bisticciare",
    "bisticciava": "bisticciare",
    "bisticciavamo": "bisticciare",
    "bisticciavan": "bisticciare",
    "bisticciavano": "bisticciare",
    "bisticciavate": "bisticciare",
    "bisticciavi": "bisticciare",
    "bisticciavo": "bisticciare",
    "bisticcin": "bisticciare",
    "bisticcino": "bisticciare",
    "bisticcio": "bisticciare",
    "bisticciò": "bisticciare",
    "bistra": "bistrare",
    "bistrai": "bistrare",
    "bistrammo": "bistrare",
    "bistran": "bistrare",
    "bistrando": "bistrare",
    "bistrano": "bistrare",
    "bistrante": "bistrare",
    "bistranti": "bistrare",
    "bistrar": "bistrare",
    "bistraron": "bistrare",
    "bistrarono": "bistrare",
    "bistrasse": "bistrare",
    "bistrasser": "bistrare",
    "bistrassero": "bistrare",
    "bistrassi": "bistrare",
    "bistrassimo": "bistrare",
    "bistraste": "bistrare",
    "bistrasti": "bistrare",
    "bistrata": "bistrato",
    "bistrate": "bistrato",
    "bistrati": "bistrato",
    "bistrato": "bistrare",
    "bistratta": "bistrattare",
    "bistrattai": "bistrattare",
    "bistrattammo": "bistrattare",
    "bistrattan": "bistrattare",
    "bistrattando": "bistrattare",
    "bistrattano": "bistrattare",
    "bistrattante": "bistrattare",
    "bistrattanti": "bistrattare",
    "bistrattar": "bistrattare",
    "bistrattaron": "bistrattare",
    "bistrattarono": "bistrattare",
    "bistrattasse": "bistrattare",
    "bistrattasser": "bistrattare",
    "bistrattassero": "bistrattare",
    "bistrattassi": "bistrattare",
    "bistrattassimo": "bistrattare",
    "bistrattaste": "bistrattare",
    "bistrattasti": "bistrattare",
    "bistrattata": "bistrattare",
    "bistrattate": "bistrattare",
    "bistrattati": "bistrattare",
    "bistrattato": "bistrattare",
    "bistrattava": "bistrattare",
    "bistrattavamo": "bistrattare",
    "bistrattavan": "bistrattare",
    "bistrattavano": "bistrattare",
    "bistrattavate": "bistrattare",
    "bistrattavi": "bistrattare",
    "bistrattavo": "bistrattare",
    "bistratterai": "bistrattare",
    "bistratteran": "bistrattare",
    "bistratteranno": "bistrattare",
    "bistratterebbe": "bistrattare",
    "bistratterebber": "bistrattare",
    "bistratterebbero": "bistrattare",
    "bistratterei": "bistrattare",
    "bistratteremmo": "bistrattare",
    "bistratteremo": "bistrattare",
    "bistrattereste": "bistrattare",
    "bistratteresti": "bistrattare",
    "bistratterete": "bistrattare",
    "bistratterà": "bistrattare",
    "bistratterò": "bistrattare",
    "bistratti": "bistrattare",
    "bistrattiamo": "bistrattare",
    "bistrattiate": "bistrattare",
    "bistrattin": "bistrattare",
    "bistrattino": "bistrattare",
    "bistratto": "bistrattare",
    "bistrattò": "bistrattare",
    "bistrava": "bistrare",
    "bistravamo": "bistrare",
    "bistravan": "bistrare",
    "bistravano": "bistrare",
    "bistravate": "bistrare",
    "bistravi": "bistrare",
    "bistravo": "bistrare",
    "bistrerai": "bistrare",
    "bistreran": "bistrare",
    "bistreranno": "bistrare",
    "bistrerebbe": "bistrare",
    "bistrerebber": "bistrare",
    "bistrerebbero": "bistrare",
    "bistrerei": "bistrare",
    "bistreremmo": "bistrare",
    "bistreremo": "bistrare",
    "bistrereste": "bistrare",
    "bistreresti": "bistrare",
    "bistrerete": "bistrare",
    "bistrerà": "bistrare",
    "bistrerò": "bistrare",
    "bistri": "bistrare",
    "bistriamo": "bistrare",
    "bistriate": "bistrare",
    "bistrin": "bistrare",
    "bistrino": "bistrare",
    "bistro": "bistrare",
    "bistrò": "bistrare",
    "bisunta": "bisunto",
    "bisunte": "bisunto",
    "bisunti": "bisunto",
    "bitorzoluta": "bitorzoluto",
    "bitorzolute": "bitorzoluto",
    "bitorzoluti": "bitorzoluto",
    "bituma": "bitumare",
    "bitumai": "bitumare",
    "bitumammo": "bitumare",
    "bituman": "bitumare",
    "bitumando": "bitumare",
    "bitumano": "bitumare",
    "bitumante": "bitumare",
    "bitumanti": "bitumare",
    "bitumar": "bitumare",
    "bitumaron": "bitumare",
    "bitumarono": "bitumare",
    "bitumasse": "bitumare",
    "bitumasser": "bitumare",
    "bitumassero": "bitumare",
    "bitumassi": "bitumare",
    "bitumassimo": "bitumare",
    "bitumaste": "bitumare",
    "bitumasti": "bitumare",
    "bitumata": "bitumare",
    "bitumate": "bitumare",
    "bitumati": "bitumare",
    "bitumato": "bitumare",
    "bitumava": "bitumare",
    "bitumavamo": "bitumare",
    "bitumavan": "bitumare",
    "bitumavano": "bitumare",
    "bitumavate": "bitumare",
    "bitumavi": "bitumare",
    "bitumavo": "bitumare",
    "bitumerai": "bitumare",
    "bitumeran": "bitumare",
    "bitumeranno": "bitumare",
    "bitumerebbe": "bitumare",
    "bitumerebber": "bitumare",
    "bitumerebbero": "bitumare",
    "bitumerei": "bitumare",
    "bitumeremmo": "bitumare",
    "bitumeremo": "bitumare",
    "bitumereste": "bitumare",
    "bitumeresti": "bitumare",
    "bitumerete": "bitumare",
    "bitumerà": "bitumare",
    "bitumerò": "bitumare",
    "bitumi": "bitume",
    "bitumiamo": "bitumare",
    "bitumiate": "bitumare",
    "bitumin": "bitumare",
    "bitumino": "bitumare",
    "bitumo": "bitumare",
    "bitumò": "bitumare",
    "bivacca": "bivaccare",
    "bivaccai": "bivaccare",
    "bivaccammo": "bivaccare",
    "bivaccan": "bivaccare",
    "bivaccando": "bivaccare",
    "bivaccano": "bivaccare",
    "bivaccante": "bivaccare",
    "bivaccanti": "bivaccare",
    "bivaccar": "bivaccare",
    "bivaccaron": "bivaccare",
    "bivaccarono": "bivaccare",
    "bivaccasse": "bivaccare",
    "bivaccasser": "bivaccare",
    "bivaccassero": "bivaccare",
    "bivaccassi": "bivaccare",
    "bivaccassimo": "bivaccare",
    "bivaccaste": "bivaccare",
    "bivaccasti": "bivaccare",
    "bivaccata": "bivaccare",
    "bivaccate": "bivaccare",
    "bivaccati": "bivaccare",
    "bivaccato": "bivaccare",
    "bivaccava": "bivaccare",
    "bivaccavamo": "bivaccare",
    "bivaccavan": "bivaccare",
    "bivaccavano": "bivaccare",
    "bivaccavate": "bivaccare",
    "bivaccavi": "bivaccare",
    "bivaccavo": "bivaccare",
    "bivaccherai": "bivaccare",
    "bivaccheran": "bivaccare",
    "bivaccheranno": "bivaccare",
    "bivaccherebbe": "bivaccare",
    "bivaccherebber": "bivaccare",
    "bivaccherebbero": "bivaccare",
    "bivaccherei": "bivaccare",
    "bivaccheremmo": "bivaccare",
    "bivaccheremo": "bivaccare",
    "bivacchereste": "bivaccare",
    "bivaccheresti": "bivaccare",
    "bivaccherete": "bivaccare",
    "bivaccherà": "bivaccare",
    "bivaccherò": "bivaccare",
    "bivacchi": "bivacco",
    "bivacchiamo": "bivaccare",
    "bivacchiate": "bivaccare",
    "bivacchin": "bivaccare",
    "bivacchino": "bivaccare",
    "bivacco": "bivaccare",
    "bivaccò": "bivaccare",
    "bivalvi": "bivalve",
    "bivii": "bivio",
    "bizantina": "bizantino",
    "bizantine": "bizantino",
    "bizantini": "bizantino",
    "bizantinismi": "bizantinismo",
    "bizzarra": "bizzarro",
    "bizzarre": "bizzarro",
    "bizzarri": "bizzarro",
    "bizzarrie": "bizzarria",
    "bizzarrìe": "bizzarrìa",
    "bizze": "bizza",
    "bizzosa": "bizzoso",
    "bizzose": "bizzoso",
    "bizzosi": "bizzoso",
    "blanda": "blando",
    "blande": "blando",
    "blandendo": "blandire",
    "blandente": "blandire",
    "blandenti": "blandire",
    "blandi": "blando",
    "blandiamo": "blandire",
    "blandiate": "blandire",
    "blandii": "blandire",
    "blandimmo": "blandire",
    "blandir": "blandire",
    "blandirai": "blandire",
    "blandiran": "blandire",
    "blandiranno": "blandire",
    "blandirebbe": "blandire",
    "blandirebber": "blandire",
    "blandirebbero": "blandire",
    "blandirei": "blandire",
    "blandiremmo": "blandire",
    "blandiremo": "blandire",
    "blandireste": "blandire",
    "blandiresti": "blandire",
    "blandirete": "blandire",
    "blandiron": "blandire",
    "blandirono": "blandire",
    "blandirà": "blandire",
    "blandirò": "blandire",
    "blandisca": "blandire",
    "blandiscan": "blandire",
    "blandiscano": "blandire",
    "blandisce": "blandire",
    "blandisci": "blandire",
    "blandisco": "blandire",
    "blandiscon": "blandire",
    "blandiscono": "blandire",
    "blandisse": "blandire",
    "blandisser": "blandire",
    "blandissero": "blandire",
    "blandissi": "blandire",
    "blandissimo": "blandire",
    "blandiste": "blandire",
    "blandisti": "blandire",
    "blandita": "blandire",
    "blandite": "blandire",
    "blanditi": "blandire",
    "blandito": "blandire",
    "blandiva": "blandire",
    "blandivamo": "blandire",
    "blandivan": "blandire",
    "blandivano": "blandire",
    "blandivate": "blandire",
    "blandivi": "blandire",
    "blandivo": "blandire",
    "blandì": "blandire",
    "blasfema": "blasfemo",
    "blasfeme": "blasfemo",
    "blasfemi": "blasfemo",
    "blasona": "blasonare",
    "blasonai": "blasonare",
    "blasonammo": "blasonare",
    "blasonan": "blasonare",
    "blasonando": "blasonare",
    "blasonano": "blasonare",
    "blasonante": "blasonare",
    "blasonanti": "blasonare",
    "blasonar": "blasonare",
    "blasonaron": "blasonare",
    "blasonarono": "blasonare",
    "blasonasse": "blasonare",
    "blasonasser": "blasonare",
    "blasonassero": "blasonare",
    "blasonassi": "blasonare",
    "blasonassimo": "blasonare",
    "blasonaste": "blasonare",
    "blasonasti": "blasonare",
    "blasonata": "blasonato",
    "blasonate": "blasonato",
    "blasonati": "blasonato",
    "blasonato": "blasonare",
    "blasonava": "blasonare",
    "blasonavamo": "blasonare",
    "blasonavan": "blasonare",
    "blasonavano": "blasonare",
    "blasonavate": "blasonare",
    "blasonavi": "blasonare",
    "blasonavo": "blasonare",
    "blasonerai": "blasonare",
    "blasoneran": "blasonare",
    "blasoneranno": "blasonare",
    "blasonerebbe": "blasonare",
    "blasonerebber": "blasonare",
    "blasonerebbero": "blasonare",
    "blasonerei": "blasonare",
    "blasoneremmo": "blasonare",
    "blasoneremo": "blasonare",
    "blasonereste": "blasonare",
    "blasoneresti": "blasonare",
    "blasonerete": "blasonare",
    "blasonerà": "blasonare",
    "blasonerò": "blasonare",
    "blasoni": "blasone",
    "blasoniamo": "blasonare",
    "blasoniate": "blasonare",
    "blasonin": "blasonare",
    "blasonino": "blasonare",
    "blasono": "blasonare",
    "blasonò": "blasonare",
    "blatera": "blaterare",
    "blaterai": "blaterare",
    "blaterammo": "blaterare",
    "blateran": "blaterare",
    "blaterando": "blaterare",
    "blaterano": "blaterare",
    "blaterante": "blaterare",
    "blateranti": "blaterare",
    "blaterar": "blaterare",
    "blateraron": "blaterare",
    "blaterarono": "blaterare",
    "blaterasse": "blaterare",
    "blaterasser": "blaterare",
    "blaterassero": "blaterare",
    "blaterassi": "blaterare",
    "blaterassimo": "blaterare",
    "blateraste": "blaterare",
    "blaterasti": "blaterare",
    "blaterata": "blaterare",
    "blaterate": "blaterare",
    "blaterati": "blaterare",
    "blaterato": "blaterare",
    "blaterava": "blaterare",
    "blateravamo": "blaterare",
    "blateravan": "blaterare",
    "blateravano": "blaterare",
    "blateravate": "blaterare",
    "blateravi": "blaterare",
    "blateravo": "blaterare",
    "blatererai": "blaterare",
    "blatereran": "blaterare",
    "blatereranno": "blaterare",
    "blatererebbe": "blaterare",
    "blatererebber": "blaterare",
    "blatererebbero": "blaterare",
    "blatererei": "blaterare",
    "blatereremmo": "blaterare",
    "blatereremo": "blaterare",
    "blaterereste": "blaterare",
    "blatereresti": "blaterare",
    "blatererete": "blaterare",
    "blatererà": "blaterare",
    "blatererò": "blaterare",
    "blateri": "blaterare",
    "blateriamo": "blaterare",
    "blateriate": "blaterare",
    "blaterin": "blaterare",
    "blaterino": "blaterare",
    "blatero": "blaterare",
    "blaterò": "blaterare",
    "blatte": "blatta",
    "blesa": "bleso",
    "blese": "bleso",
    "blesi": "bleso",
    "blinda": "blindare",
    "blindai": "blindare",
    "blindammo": "blindare",
    "blindan": "blindare",
    "blindando": "blindare",
    "blindano": "blindare",
    "blindante": "blindare",
    "blindanti": "blindare",
    "blindar": "blindare",
    "blindaron": "blindare",
    "blindarono": "blindare",
    "blindasse": "blindare",
    "blindasser": "blindare",
    "blindassero": "blindare",
    "blindassi": "blindare",
    "blindassimo": "blindare",
    "blindaste": "blindare",
    "blindasti": "blindare",
    "blindata": "blindato",
    "blindate": "blindato",
    "blindati": "blindato",
    "blindato": "blindare",
    "blindature": "blindatura",
    "blindava": "blindare",
    "blindavamo": "blindare",
    "blindavan": "blindare",
    "blindavano": "blindare",
    "blindavate": "blindare",
    "blindavi": "blindare",
    "blindavo": "blindare",
    "blinderai": "blindare",
    "blinderan": "blindare",
    "blinderanno": "blindare",
    "blinderebbe": "blindare",
    "blinderebber": "blindare",
    "blinderebbero": "blindare",
    "blinderei": "blindare",
    "blinderemmo": "blindare",
    "blinderemo": "blindare",
    "blindereste": "blindare",
    "blinderesti": "blindare",
    "blinderete": "blindare",
    "blinderà": "blindare",
    "blinderò": "blindare",
    "blindi": "blindare",
    "blindiamo": "blindare",
    "blindiate": "blindare",
    "blindin": "blindare",
    "blindino": "blindare",
    "blindo": "blindare",
    "blindò": "blindare",
    "blocca": "bloccare",
    "bloccaggi": "bloccaggio",
    "bloccai": "bloccare",
    "bloccammo": "bloccare",
    "bloccan": "bloccare",
    "bloccando": "bloccare",
    "bloccano": "bloccare",
    "bloccante": "bloccare",
    "bloccanti": "bloccare",
    "bloccar": "bloccare",
    "bloccaron": "bloccare",
    "bloccarono": "bloccare",
    "bloccasse": "bloccare",
    "bloccasser": "bloccare",
    "bloccassero": "bloccare",
    "bloccassi": "bloccare",
    "bloccassimo": "bloccare",
    "bloccaste": "bloccare",
    "bloccasti": "bloccare",
    "bloccata": "bloccare",
    "bloccate": "bloccare",
    "bloccati": "bloccare",
    "bloccato": "bloccare",
    "bloccava": "bloccare",
    "bloccavamo": "bloccare",
    "bloccavan": "bloccare",
    "bloccavano": "bloccare",
    "bloccavate": "bloccare",
    "bloccavi": "bloccare",
    "bloccavo": "bloccare",
    "bloccherai": "bloccare",
    "bloccheran": "bloccare",
    "bloccheranno": "bloccare",
    "bloccherebbe": "bloccare",
    "bloccherebber": "bloccare",
    "bloccherebbero": "bloccare",
    "bloccherei": "bloccare",
    "bloccheremmo": "bloccare",
    "bloccheremo": "bloccare",
    "blocchereste": "bloccare",
    "bloccheresti": "bloccare",
    "bloccherete": "bloccare",
    "bloccherà": "bloccare",
    "bloccherò": "bloccare",
    "blocchetti": "blocchetto",
    "blocchi": "blocco",
    "blocchiamo": "bloccare",
    "blocchiate": "bloccare",
    "blocchin": "bloccare",
    "blocchino": "bloccare",
    "blocco": "bloccare",
    "bloccò": "bloccare",
    "bluastra": "bluastro",
    "bluastre": "bluastro",
    "bluastri": "bluastro",
    "blucerchiati": "blucerchiato",
    "bluffa": "bluffare",
    "bluffai": "bluffare",
    "bluffammo": "bluffare",
    "bluffan": "bluffare",
    "bluffando": "bluffare",
    "bluffano": "bluffare",
    "bluffante": "bluffare",
    "bluffanti": "bluffare",
    "bluffar": "bluffare",
    "bluffaron": "bluffare",
    "bluffarono": "bluffare",
    "bluffasse": "bluffare",
    "bluffasser": "bluffare",
    "bluffassero": "bluffare",
    "bluffassi": "bluffare",
    "bluffassimo": "bluffare",
    "bluffaste": "bluffare",
    "bluffasti": "bluffare",
    "bluffata": "bluffare",
    "bluffate": "bluffare",
    "bluffati": "bluffare",
    "bluffato": "bluffare",
    "bluffava": "bluffare",
    "bluffavamo": "bluffare",
    "bluffavan": "bluffare",
    "bluffavano": "bluffare",
    "bluffavate": "bluffare",
    "bluffavi": "bluffare",
    "bluffavo": "bluffare",
    "blufferai": "bluffare",
    "blufferan": "bluffare",
    "blufferanno": "bluffare",
    "blufferebbe": "bluffare",
    "blufferebber": "bluffare",
    "blufferebbero": "bluffare",
    "blufferei": "bluffare",
    "blufferemmo": "bluffare",
    "blufferemo": "bluffare",
    "bluffereste": "bluffare",
    "blufferesti": "bluffare",
    "blufferete": "bluffare",
    "blufferà": "bluffare",
    "blufferò": "bluffare",
    "bluffi": "bluffare",
    "bluffiamo": "bluffare",
    "bluffiate": "bluffare",
    "bluffin": "bluffare",
    "bluffino": "bluffare",
    "bluffo": "bluffare",
    "bluffò": "bluffare",
    "bluse": "blusa",
    "boara": "boaro",
    "boare": "boaro",
    "boari": "boaro",
    "boaria": "boario",
    "boarie": "boario",
    "boati": "boato",
    "bobine": "bobina",
    "boccacce": "boccaccia",
    "boccaccesca": "boccaccesco",
    "boccaccesche": "boccaccesco",
    "boccacceschi": "boccaccesco",
    "boccali": "boccale",
    "boccaporti": "boccaporto",
    "boccate": "boccata",
    "bocce": "boccia",
    "boccerai": "bocciare",
    "bocceran": "bocciare",
    "bocceranno": "bocciare",
    "boccerebbe": "bocciare",
    "boccerebber": "bocciare",
    "boccerebbero": "bocciare",
    "boccerei": "bocciare",
    "bocceremmo": "bocciare",
    "bocceremo": "bocciare",
    "boccereste": "bocciare",
    "bocceresti": "bocciare",
    "boccerete": "bocciare",
    "boccerà": "bocciare",
    "boccerò": "bocciare",
    "boccette": "boccetta",
    "bocche": "bocca",
    "boccheggerai": "boccheggiare",
    "boccheggeran": "boccheggiare",
    "boccheggeranno": "boccheggiare",
    "boccheggerebbe": "boccheggiare",
    "boccheggerebber": "boccheggiare",
    "boccheggerebbero": "boccheggiare",
    "boccheggerei": "boccheggiare",
    "boccheggeremmo": "boccheggiare",
    "boccheggeremo": "boccheggiare",
    "boccheggereste": "boccheggiare",
    "boccheggeresti": "boccheggiare",
    "boccheggerete": "boccheggiare",
    "boccheggerà": "boccheggiare",
    "boccheggerò": "boccheggiare",
    "boccheggi": "boccheggiare",
    "boccheggia": "boccheggiare",
    "boccheggiai": "boccheggiare",
    "boccheggiammo": "boccheggiare",
    "boccheggiamo": "boccheggiare",
    "boccheggian": "boccheggiare",
    "boccheggiando": "boccheggiare",
    "boccheggiano": "boccheggiare",
    "boccheggiante": "boccheggiare",
    "boccheggianti": "boccheggiare",
    "boccheggiar": "boccheggiare",
    "boccheggiaron": "boccheggiare",
    "boccheggiarono": "boccheggiare",
    "boccheggiasse": "boccheggiare",
    "boccheggiasser": "boccheggiare",
    "boccheggiassero": "boccheggiare",
    "boccheggiassi": "boccheggiare",
    "boccheggiassimo": "boccheggiare",
    "boccheggiaste": "boccheggiare",
    "boccheggiasti": "boccheggiare",
    "boccheggiata": "boccheggiare",
    "boccheggiate": "boccheggiare",
    "boccheggiati": "boccheggiare",
    "boccheggiato": "boccheggiare",
    "boccheggiava": "boccheggiare",
    "boccheggiavamo": "boccheggiare",
    "boccheggiavan": "boccheggiare",
    "boccheggiavano": "boccheggiare",
    "boccheggiavate": "boccheggiare",
    "boccheggiavi": "boccheggiare",
    "boccheggiavo": "boccheggiare",
    "boccheggin": "boccheggiare",
    "boccheggino": "boccheggiare",
    "boccheggio": "boccheggiare",
    "boccheggiò": "boccheggiare",
    "bocchettoni": "bocchettone",
    "bocchini": "bocchino",
    "bocci": "bocciare",
    "boccia": "bocciare",
    "bocciai": "bocciare",
    "bocciammo": "bocciare",
    "bocciamo": "bocciare",
    "boccian": "bocciare",
    "bocciando": "bocciare",
    "bocciano": "bocciare",
    "bocciante": "bocciare",
    "boccianti": "bocciare",
    "bocciar": "bocciare",
    "bocciaron": "bocciare",
    "bocciarono": "bocciare",
    "bocciasse": "bocciare",
    "bocciasser": "bocciare",
    "bocciassero": "bocciare",
    "bocciassi": "bocciare",
    "bocciassimo": "bocciare",
    "bocciaste": "bocciare",
    "bocciasti": "bocciare",
    "bocciata": "bocciare",
    "bocciate": "bocciare",
    "bocciati": "bocciare",
    "bocciato": "bocciare",
    "bocciature": "bocciatura",
    "bocciava": "bocciare",
    "bocciavamo": "bocciare",
    "bocciavan": "bocciare",
    "bocciavano": "bocciare",
    "bocciavate": "bocciare",
    "bocciavi": "bocciare",
    "bocciavo": "bocciare",
    "boccin": "bocciare",
    "boccino": "bocciare",
    "boccio": "bocciare",
    "bocciofila": "bocciofilo",
    "bocciofile": "bocciofilo",
    "bocciofili": "bocciofilo",
    "boccioli": "bocciolo",
    "bocciò": "bocciare",
    "boccoli": "boccolo",
    "bocconcini": "bocconcino",
    "bocconi": "boccone",
    "boe": "boa",
    "boera": "boero",
    "boere": "boero",
    "boeri": "boero",
    "bofonchi": "bofonchiare",
    "bofonchia": "bofonchiare",
    "bofonchiai": "bofonchiare",
    "bofonchiammo": "bofonchiare",
    "bofonchiamo": "bofonchiare",
    "bofonchian": "bofonchiare",
    "bofonchiando": "bofonchiare",
    "bofonchiano": "bofonchiare",
    "bofonchiante": "bofonchiare",
    "bofonchianti": "bofonchiare",
    "bofonchiar": "bofonchiare",
    "bofonchiaron": "bofonchiare",
    "bofonchiarono": "bofonchiare",
    "bofonchiasse": "bofonchiare",
    "bofonchiasser": "bofonchiare",
    "bofonchiassero": "bofonchiare",
    "bofonchiassi": "bofonchiare",
    "bofonchiassimo": "bofonchiare",
    "bofonchiaste": "bofonchiare",
    "bofonchiasti": "bofonchiare",
    "bofonchiata": "bofonchiare",
    "bofonchiate": "bofonchiare",
    "bofonchiati": "bofonchiare",
    "bofonchiato": "bofonchiare",
    "bofonchiava": "bofonchiare",
    "bofonchiavamo": "bofonchiare",
    "bofonchiavan": "bofonchiare",
    "bofonchiavano": "bofonchiare",
    "bofonchiavate": "bofonchiare",
    "bofonchiavi": "bofonchiare",
    "bofonchiavo": "bofonchiare",
    "bofonchierai": "bofonchiare",
    "bofonchieran": "bofonchiare",
    "bofonchieranno": "bofonchiare",
    "bofonchierebbe": "bofonchiare",
    "bofonchierebber": "bofonchiare",
    "bofonchierebbero": "bofonchiare",
    "bofonchierei": "bofonchiare",
    "bofonchieremmo": "bofonchiare",
    "bofonchieremo": "bofonchiare",
    "bofonchiereste": "bofonchiare",
    "bofonchieresti": "bofonchiare",
    "bofonchierete": "bofonchiare",
    "bofonchierà": "bofonchiare",
    "bofonchierò": "bofonchiare",
    "bofonchin": "bofonchiare",
    "bofonchino": "bofonchiare",
    "bofonchio": "bofonchiare",
    "bofonchiò": "bofonchiare",
    "bohèmes": "bohème",
    "boiardi": "boiardo",
    "boicotta": "boicottare",
    "boicottaggi": "boicottaggio",
    "boicottai": "boicottare",
    "boicottammo": "boicottare",
    "boicottan": "boicottare",
    "boicottando": "boicottare",
    "boicottano": "boicottare",
    "boicottante": "boicottare",
    "boicottanti": "boicottare",
    "boicottar": "boicottare",
    "boicottaron": "boicottare",
    "boicottarono": "boicottare",
    "boicottasse": "boicottare",
    "boicottasser": "boicottare",
    "boicottassero": "boicottare",
    "boicottassi": "boicottare",
    "boicottassimo": "boicottare",
    "boicottaste": "boicottare",
    "boicottasti": "boicottare",
    "boicottata": "boicottare",
    "boicottate": "boicottare",
    "boicottati": "boicottare",
    "boicottato": "boicottare",
    "boicottava": "boicottare",
    "boicottavamo": "boicottare",
    "boicottavan": "boicottare",
    "boicottavano": "boicottare",
    "boicottavate": "boicottare",
    "boicottavi": "boicottare",
    "boicottavo": "boicottare",
    "boicotterai": "boicottare",
    "boicotteran": "boicottare",
    "boicotteranno": "boicottare",
    "boicotterebbe": "boicottare",
    "boicotterebber": "boicottare",
    "boicotterebbero": "boicottare",
    "boicotterei": "boicottare",
    "boicotteremmo": "boicottare",
    "boicotteremo": "boicottare",
    "boicottereste": "boicottare",
    "boicotteresti": "boicottare",
    "boicotterete": "boicottare",
    "boicotterà": "boicottare",
    "boicotterò": "boicottare",
    "boicotti": "boicottare",
    "boicottiamo": "boicottare",
    "boicottiate": "boicottare",
    "boicottin": "boicottare",
    "boicottino": "boicottare",
    "boicotto": "boicottare",
    "boicottò": "boicottare",
    "boleri": "bolero",
    "bolge": "bolgia",
    "bolidi": "bolide",
    "boliviana": "boliviano",
    "boliviane": "boliviano",
    "boliviani": "boliviano",
    "bolla": "bollire",
    "bollai": "bollare",
    "bollammo": "bollare",
    "bollan": "bollire",
    "bollando": "bollare",
    "bollano": "bollire",
    "bollante": "bollare",
    "bollanti": "bollare",
    "bollar": "bollare",
    "bollaron": "bollare",
    "bollarono": "bollare",
    "bollasse": "bollare",
    "bollasser": "bollare",
    "bollassero": "bollare",
    "bollassi": "bollare",
    "bollassimo": "bollare",
    "bollaste": "bollare",
    "bollasti": "bollare",
    "bollata": "bollato",
    "bollate": "bollato",
    "bollati": "bollato",
    "bollato": "bollare",
    "bollava": "bollare",
    "bollavamo": "bollare",
    "bollavan": "bollare",
    "bollavano": "bollare",
    "bollavate": "bollare",
    "bollavi": "bollare",
    "bollavo": "bollare",
    "bolle": "bollire",
    "bollendo": "bollire",
    "bollente": "bollire",
    "bollenti": "bollire",
    "bollerai": "bollare",
    "bolleran": "bollare",
    "bolleranno": "bollare",
    "bollerebbe": "bollare",
    "bollerebber": "bollare",
    "bollerebbero": "bollare",
    "bollerei": "bollare",
    "bolleremmo": "bollare",
    "bolleremo": "bollare",
    "bollereste": "bollare",
    "bolleresti": "bollare",
    "bollerete": "bollare",
    "bollerà": "bollare",
    "bollerò": "bollare",
    "bollette": "bolletta",
    "bollettini": "bollettino",
    "bolli": "bollo",
    "bolliamo": "bollire",
    "bolliate": "bollire",
    "bollicine": "bollicina",
    "bollii": "bollire",
    "bollimmo": "bollire",
    "bollin": "bollare",
    "bollini": "bollino",
    "bollino": "bollare",
    "bollir": "bollire",
    "bollirai": "bollire",
    "bolliran": "bollire",
    "bolliranno": "bollire",
    "bollirebbe": "bollire",
    "bollirebber": "bollire",
    "bollirebbero": "bollire",
    "bollirei": "bollire",
    "bolliremmo": "bollire",
    "bolliremo": "bollire",
    "bollireste": "bollire",
    "bolliresti": "bollire",
    "bollirete": "bollire",
    "bolliron": "bollire",
    "bollirono": "bollire",
    "bollirà": "bollire",
    "bollirò": "bollire",
    "bollisse": "bollire",
    "bollisser": "bollire",
    "bollissero": "bollire",
    "bollissi": "bollire",
    "bollissimo": "bollire",
    "bolliste": "bollire",
    "bollisti": "bollire",
    "bollita": "bollito",
    "bollite": "bollito",
    "bolliti": "bollito",
    "bollito": "bollire",
    "bollitori": "bollitore",
    "bolliva": "bollire",
    "bollivamo": "bollire",
    "bollivan": "bollire",
    "bollivano": "bollire",
    "bollivate": "bollire",
    "bollivi": "bollire",
    "bollivo": "bollire",
    "bollo": "bollire",
    "bollon": "bollire",
    "bollono": "bollire",
    "bollori": "bollore",
    "bollì": "bollire",
    "bollò": "bollare",
    "bolognesi": "bolognese",
    "bolsa": "bolso",
    "bolscevica": "bolscevico",
    "bolsceviche": "bolscevico",
    "bolscevichi": "bolscevico",
    "bolscevici": "bolscevico",
    "bolscevismi": "bolscevismo",
    "bolscevizza": "bolscevizzare",
    "bolscevizzai": "bolscevizzare",
    "bolscevizzammo": "bolscevizzare",
    "bolscevizzan": "bolscevizzare",
    "bolscevizzando": "bolscevizzare",
    "bolscevizzano": "bolscevizzare",
    "bolscevizzante": "bolscevizzare",
    "bolscevizzanti": "bolscevizzare",
    "bolscevizzar": "bolscevizzare",
    "bolscevizzaron": "bolscevizzare",
    "bolscevizzarono": "bolscevizzare",
    "bolscevizzasse": "bolscevizzare",
    "bolscevizzasser": "bolscevizzare",
    "bolscevizzassero": "bolscevizzare",
    "bolscevizzassi": "bolscevizzare",
    "bolscevizzassimo": "bolscevizzare",
    "bolscevizzaste": "bolscevizzare",
    "bolscevizzasti": "bolscevizzare",
    "bolscevizzata": "bolscevizzare",
    "bolscevizzate": "bolscevizzare",
    "bolscevizzati": "bolscevizzare",
    "bolscevizzato": "bolscevizzare",
    "bolscevizzava": "bolscevizzare",
    "bolscevizzavamo": "bolscevizzare",
    "bolscevizzavan": "bolscevizzare",
    "bolscevizzavano": "bolscevizzare",
    "bolscevizzavate": "bolscevizzare",
    "bolscevizzavi": "bolscevizzare",
    "bolscevizzavo": "bolscevizzare",
    "bolscevizzerai": "bolscevizzare",
    "bolscevizzeran": "bolscevizzare",
    "bolscevizzeranno": "bolscevizzare",
    "bolscevizzerebbe": "bolscevizzare",
    "bolscevizzerebber": "bolscevizzare",
    "bolscevizzerebbero": "bolscevizzare",
    "bolscevizzerei": "bolscevizzare",
    "bolscevizzeremmo": "bolscevizzare",
    "bolscevizzeremo": "bolscevizzare",
    "bolscevizzereste": "bolscevizzare",
    "bolscevizzeresti": "bolscevizzare",
    "bolscevizzerete": "bolscevizzare",
    "bolscevizzerà": "bolscevizzare",
    "bolscevizzerò": "bolscevizzare",
    "bolscevizzi": "bolscevizzare",
    "bolscevizziamo": "bolscevizzare",
    "bolscevizziate": "bolscevizzare",
    "bolscevizzin": "bolscevizzare",
    "bolscevizzino": "bolscevizzare",
    "bolscevizzo": "bolscevizzare",
    "bolscevizzò": "bolscevizzare",
    "bolse": "bolso",
    "bolsi": "bolso",
    "bolzanini": "bolzanino",
    "bomba": "bombare",
    "bombai": "bombare",
    "bombammo": "bombare",
    "bomban": "bombare",
    "bombando": "bombare",
    "bombano": "bombare",
    "bombante": "bombare",
    "bombanti": "bombare",
    "bombar": "bombare",
    "bombarda": "bombardare",
    "bombardai": "bombardare",
    "bombardamenti": "bombardamento",
    "bombardammo": "bombardare",
    "bombardan": "bombardare",
    "bombardando": "bombardare",
    "bombardano": "bombardare",
    "bombardante": "bombardare",
    "bombardanti": "bombardare",
    "bombardar": "bombardare",
    "bombardaron": "bombardare",
    "bombardarono": "bombardare",
    "bombardasse": "bombardare",
    "bombardasser": "bombardare",
    "bombardassero": "bombardare",
    "bombardassi": "bombardare",
    "bombardassimo": "bombardare",
    "bombardaste": "bombardare",
    "bombardasti": "bombardare",
    "bombardata": "bombardare",
    "bombardate": "bombardare",
    "bombardati": "bombardare",
    "bombardato": "bombardare",
    "bombardava": "bombardare",
    "bombardavamo": "bombardare",
    "bombardavan": "bombardare",
    "bombardavano": "bombardare",
    "bombardavate": "bombardare",
    "bombardavi": "bombardare",
    "bombardavo": "bombardare",
    "bombarderai": "bombardare",
    "bombarderan": "bombardare",
    "bombarderanno": "bombardare",
    "bombarderebbe": "bombardare",
    "bombarderebber": "bombardare",
    "bombarderebbero": "bombardare",
    "bombarderei": "bombardare",
    "bombarderemmo": "bombardare",
    "bombarderemo": "bombardare",
    "bombardereste": "bombardare",
    "bombarderesti": "bombardare",
    "bombarderete": "bombardare",
    "bombarderà": "bombardare",
    "bombarderò": "bombardare",
    "bombardi": "bombardare",
    "bombardiamo": "bombardare",
    "bombardiate": "bombardare",
    "bombardieri": "bombardiere",
    "bombardin": "bombardare",
    "bombardino": "bombardare",
    "bombardo": "bombardare",
    "bombardò": "bombardare",
    "bombaroli": "bombarolo",
    "bombaron": "bombare",
    "bombarono": "bombare",
    "bombasse": "bombare",
    "bombasser": "bombare",
    "bombassero": "bombare",
    "bombassi": "bombare",
    "bombassimo": "bombare",
    "bombaste": "bombare",
    "bombasti": "bombare",
    "bombata": "bombare",
    "bombate": "bombare",
    "bombati": "bombare",
    "bombato": "bombare",
    "bombava": "bombare",
    "bombavamo": "bombare",
    "bombavan": "bombare",
    "bombavano": "bombare",
    "bombavate": "bombare",
    "bombavi": "bombare",
    "bombavo": "bombare",
    "bombe": "bomba",
    "bomberai": "bombare",
    "bomberan": "bombare",
    "bomberanno": "bombare",
    "bomberebbe": "bombare",
    "bomberebber": "bombare",
    "bomberebbero": "bombare",
    "bomberei": "bombare",
    "bomberemmo": "bombare",
    "bomberemo": "bombare",
    "bombereste": "bombare",
    "bomberesti": "bombare",
    "bomberete": "bombare",
    "bomberà": "bombare",
    "bomberò": "bombare",
    "bombette": "bombetta",
    "bombi": "bombare",
    "bombiamo": "bombare",
    "bombiate": "bombare",
    "bombin": "bombare",
    "bombino": "bombare",
    "bombo": "bombare",
    "bombole": "bombola",
    "bombolette": "bomboletta",
    "bomboniere": "bomboniera",
    "bombò": "bombare",
    "bonacce": "bonaccia",
    "bonaccioni": "bonaccione",
    "bonari": "bonario",
    "bonaria": "bonario",
    "bonarie": "bonario",
    "bonifica": "bonificare",
    "bonificai": "bonificare",
    "bonificammo": "bonificare",
    "bonifican": "bonificare",
    "bonificando": "bonificare",
    "bonificano": "bonificare",
    "bonificante": "bonificare",
    "bonificanti": "bonificare",
    "bonificar": "bonificare",
    "bonificaron": "bonificare",
    "bonificarono": "bonificare",
    "bonificasse": "bonificare",
    "bonificasser": "bonificare",
    "bonificassero": "bonificare",
    "bonificassi": "bonificare",
    "bonificassimo": "bonificare",
    "bonificaste": "bonificare",
    "bonificasti": "bonificare",
    "bonificata": "bonificare",
    "bonificate": "bonificare",
    "bonificati": "bonificare",
    "bonificato": "bonificare",
    "bonificava": "bonificare",
    "bonificavamo": "bonificare",
    "bonificavan": "bonificare",
    "bonificavano": "bonificare",
    "bonificavate": "bonificare",
    "bonificavi": "bonificare",
    "bonificavo": "bonificare",
    "bonifiche": "bonifica",
    "bonificherai": "bonificare",
    "bonificheran": "bonificare",
    "bonificheranno": "bonificare",
    "bonificherebbe": "bonificare",
    "bonificherebber": "bonificare",
    "bonificherebbero": "bonificare",
    "bonificherei": "bonificare",
    "bonificheremmo": "bonificare",
    "bonificheremo": "bonificare",
    "bonifichereste": "bonificare",
    "bonificheresti": "bonificare",
    "bonificherete": "bonificare",
    "bonificherà": "bonificare",
    "bonificherò": "bonificare",
    "bonifichi": "bonificare",
    "bonifichiamo": "bonificare",
    "bonifichiate": "bonificare",
    "bonifichin": "bonificare",
    "bonifichino": "bonificare",
    "bonifici": "bonifico",
    "bonifico": "bonificare",
    "bonificò": "bonificare",
    "bonomie": "bonomia",
    "bonzi": "bonzo",
    "bookmakers": "bookmaker",
    "borbonica": "borbonico",
    "borboniche": "borbonico",
    "borbonici": "borbonico",
    "borbotta": "borbottare",
    "borbottai": "borbottare",
    "borbottammo": "borbottare",
    "borbottan": "borbottare",
    "borbottando": "borbottare",
    "borbottano": "borbottare",
    "borbottante": "borbottare",
    "borbottanti": "borbottare",
    "borbottar": "borbottare",
    "borbottaron": "borbottare",
    "borbottarono": "borbottare",
    "borbottasse": "borbottare",
    "borbottasser": "borbottare",
    "borbottassero": "borbottare",
    "borbottassi": "borbottare",
    "borbottassimo": "borbottare",
    "borbottaste": "borbottare",
    "borbottasti": "borbottare",
    "borbottata": "borbottare",
    "borbottate": "borbottare",
    "borbottati": "borbottare",
    "borbottato": "borbottare",
    "borbottava": "borbottare",
    "borbottavamo": "borbottare",
    "borbottavan": "borbottare",
    "borbottavano": "borbottare",
    "borbottavate": "borbottare",
    "borbottavi": "borbottare",
    "borbottavo": "borbottare",
    "borbotterai": "borbottare",
    "borbotteran": "borbottare",
    "borbotteranno": "borbottare",
    "borbotterebbe": "borbottare",
    "borbotterebber": "borbottare",
    "borbotterebbero": "borbottare",
    "borbotterei": "borbottare",
    "borbotteremmo": "borbottare",
    "borbotteremo": "borbottare",
    "borbottereste": "borbottare",
    "borbotteresti": "borbottare",
    "borbotterete": "borbottare",
    "borbotterà": "borbottare",
    "borbotterò": "borbottare",
    "borbotti": "borbottare",
    "borbottiamo": "borbottare",
    "borbottiate": "borbottare",
    "borbottii": "borbottio",
    "borbottin": "borbottare",
    "borbottino": "borbottare",
    "borbotto": "borbottare",
    "borbottò": "borbottare",
    "borchie": "borchia",
    "borda": "bordare",
    "bordai": "bordare",
    "bordammo": "bordare",
    "bordan": "bordare",
    "bordando": "bordare",
    "bordano": "bordare",
    "bordante": "bordare",
    "bordanti": "bordare",
    "bordar": "bordare",
    "bordaron": "bordare",
    "bordarono": "bordare",
    "bordasse": "bordare",
    "bordasser": "bordare",
    "bordassero": "bordare",
    "bordassi": "bordare",
    "bordassimo": "bordare",
    "bordaste": "bordare",
    "bordasti": "bordare",
    "bordata": "bordare",
    "bordate": "bordata",
    "bordati": "bordare",
    "bordato": "bordare",
    "bordava": "bordare",
    "bordavamo": "bordare",
    "bordavan": "bordare",
    "bordavano": "bordare",
    "bordavate": "bordare",
    "bordavi": "bordare",
    "bordavo": "bordare",
    "bordeggerai": "bordeggiare",
    "bordeggeran": "bordeggiare",
    "bordeggeranno": "bordeggiare",
    "bordeggerebbe": "bordeggiare",
    "bordeggerebber": "bordeggiare",
    "bordeggerebbero": "bordeggiare",
    "bordeggerei": "bordeggiare",
    "bordeggeremmo": "bordeggiare",
    "bordeggeremo": "bordeggiare",
    "bordeggereste": "bordeggiare",
    "bordeggeresti": "bordeggiare",
    "bordeggerete": "bordeggiare",
    "bordeggerà": "bordeggiare",
    "bordeggerò": "bordeggiare",
    "bordeggi": "bordeggiare",
    "bordeggia": "bordeggiare",
    "bordeggiai": "bordeggiare",
    "bordeggiammo": "bordeggiare",
    "bordeggiamo": "bordeggiare",
    "bordeggian": "bordeggiare",
    "bordeggiando": "bordeggiare",
    "bordeggiano": "bordeggiare",
    "bordeggiante": "bordeggiare",
    "bordeggianti": "bordeggiare",
    "bordeggiar": "bordeggiare",
    "bordeggiaron": "bordeggiare",
    "bordeggiarono": "bordeggiare",
    "bordeggiasse": "bordeggiare",
    "bordeggiasser": "bordeggiare",
    "bordeggiassero": "bordeggiare",
    "bordeggiassi": "bordeggiare",
    "bordeggiassimo": "bordeggiare",
    "bordeggiaste": "bordeggiare",
    "bordeggiasti": "bordeggiare",
    "bordeggiata": "bordeggiare",
    "bordeggiate": "bordeggiare",
    "bordeggiati": "bordeggiare",
    "bordeggiato": "bordeggiare",
    "bordeggiava": "bordeggiare",
    "bordeggiavamo": "bordeggiare",
    "bordeggiavan": "bordeggiare",
    "bordeggiavano": "bordeggiare",
    "bordeggiavate": "bordeggiare",
    "bordeggiavi": "bordeggiare",
    "bordeggiavo": "bordeggiare",
    "bordeggin": "bordeggiare",
    "bordeggino": "bordeggiare",
    "bordeggio": "bordeggiare",
    "bordeggiò": "bordeggiare",
    "bordelli": "bordello",
    "borderai": "bordare",
    "borderan": "bordare",
    "borderanno": "bordare",
    "borderebbe": "bordare",
    "borderebber": "bordare",
    "borderebbero": "bordare",
    "borderei": "bordare",
    "borderemmo": "bordare",
    "borderemo": "bordare",
    "bordereste": "bordare",
    "borderesti": "bordare",
    "borderete": "bordare",
    "borderà": "bordare",
    "borderò": "bordare",
    "bordi": "bordo",
    "bordiamo": "bordare",
    "bordiate": "bordare",
    "bordin": "bordare",
    "bordino": "bordare",
    "bordo": "bordare",
    "bordolesi": "bordolese",
    "bordure": "bordura",
    "bordò": "bordare",
    "bore": "bora",
    "boreali": "boreale",
    "borgatari": "borgataro",
    "borgate": "borgata",
    "borghesi": "borghese",
    "borghesie": "borghesia",
    "borghi": "borgo",
    "borgognoni": "borgognone",
    "borgomastri": "borgomastro",
    "bori": "boriare",
    "boria": "boriare",
    "boriai": "boriare",
    "boriammo": "boriare",
    "boriamo": "boriare",
    "borian": "boriare",
    "boriando": "boriare",
    "boriano": "boriare",
    "boriante": "boriare",
    "borianti": "boriare",
    "boriar": "boriare",
    "boriaron": "boriare",
    "boriarono": "boriare",
    "boriasse": "boriare",
    "boriasser": "boriare",
    "boriassero": "boriare",
    "boriassi": "boriare",
    "boriassimo": "boriare",
    "boriaste": "boriare",
    "boriasti": "boriare",
    "boriata": "boriare",
    "boriate": "boriare",
    "boriati": "boriare",
    "boriato": "boriare",
    "boriava": "boriare",
    "boriavamo": "boriare",
    "boriavan": "boriare",
    "boriavano": "boriare",
    "boriavate": "boriare",
    "boriavi": "boriare",
    "boriavo": "boriare",
    "borie": "boria",
    "borierai": "boriare",
    "borieran": "boriare",
    "borieranno": "boriare",
    "borierebbe": "boriare",
    "borierebber": "boriare",
    "borierebbero": "boriare",
    "borierei": "boriare",
    "borieremmo": "boriare",
    "borieremo": "boriare",
    "boriereste": "boriare",
    "borieresti": "boriare",
    "borierete": "boriare",
    "borierà": "boriare",
    "borierò": "boriare",
    "borin": "boriare",
    "borino": "boriare",
    "borio": "boriare",
    "boriosa": "borioso",
    "boriose": "borioso",
    "boriosi": "borioso",
    "boriò": "boriare",
    "borra": "borrare",
    "borracce": "borraccia",
    "borrai": "borrare",
    "borrammo": "borrare",
    "borran": "borrare",
    "borrando": "borrare",
    "borrano": "borrare",
    "borrante": "borrare",
    "borranti": "borrare",
    "borrar": "borrare",
    "borraron": "borrare",
    "borrarono": "borrare",
    "borrasse": "borrare",
    "borrasser": "borrare",
    "borrassero": "borrare",
    "borrassi": "borrare",
    "borrassimo": "borrare",
    "borraste": "borrare",
    "borrasti": "borrare",
    "borrata": "borrare",
    "borrate": "borrare",
    "borrati": "borrare",
    "borrato": "borrare",
    "borrava": "borrare",
    "borravamo": "borrare",
    "borravan": "borrare",
    "borravano": "borrare",
    "borravate": "borrare",
    "borravi": "borrare",
    "borravo": "borrare",
    "borrerai": "borrare",
    "borreran": "borrare",
    "borreranno": "borrare",
    "borrerebbe": "borrare",
    "borrerebber": "borrare",
    "borrerebbero": "borrare",
    "borrerei": "borrare",
    "borreremmo": "borrare",
    "borreremo": "borrare",
    "borrereste": "borrare",
    "borreresti": "borrare",
    "borrerete": "borrare",
    "borrerà": "borrare",
    "borrerò": "borrare",
    "borri": "borrare",
    "borriamo": "borrare",
    "borriate": "borrare",
    "borrin": "borrare",
    "borrino": "borrare",
    "borro": "borrare",
    "borrò": "borrare",
    "borsaioli": "borsaiolo",
    "borsari": "borsaro",
    "borse": "borsa",
    "borseggerai": "borseggiare",
    "borseggeran": "borseggiare",
    "borseggeranno": "borseggiare",
    "borseggerebbe": "borseggiare",
    "borseggerebber": "borseggiare",
    "borseggerebbero": "borseggiare",
    "borseggerei": "borseggiare",
    "borseggeremmo": "borseggiare",
    "borseggeremo": "borseggiare",
    "borseggereste": "borseggiare",
    "borseggeresti": "borseggiare",
    "borseggerete": "borseggiare",
    "borseggerà": "borseggiare",
    "borseggerò": "borseggiare",
    "borseggi": "borseggio",
    "borseggia": "borseggiare",
    "borseggiai": "borseggiare",
    "borseggiammo": "borseggiare",
    "borseggiamo": "borseggiare",
    "borseggian": "borseggiare",
    "borseggiando": "borseggiare",
    "borseggiano": "borseggiare",
    "borseggiante": "borseggiare",
    "borseggianti": "borseggiare",
    "borseggiar": "borseggiare",
    "borseggiaron": "borseggiare",
    "borseggiarono": "borseggiare",
    "borseggiasse": "borseggiare",
    "borseggiasser": "borseggiare",
    "borseggiassero": "borseggiare",
    "borseggiassi": "borseggiare",
    "borseggiassimo": "borseggiare",
    "borseggiaste": "borseggiare",
    "borseggiasti": "borseggiare",
    "borseggiata": "borseggiare",
    "borseggiate": "borseggiare",
    "borseggiati": "borseggiare",
    "borseggiato": "borseggiare",
    "borseggiatori": "borseggiatore",
    "borseggiava": "borseggiare",
    "borseggiavamo": "borseggiare",
    "borseggiavan": "borseggiare",
    "borseggiavano": "borseggiare",
    "borseggiavate": "borseggiare",
    "borseggiavi": "borseggiare",
    "borseggiavo": "borseggiare",
    "borseggin": "borseggiare",
    "borseggino": "borseggiare",
    "borseggio": "borseggiare",
    "borseggiò": "borseggiare",
    "borselli": "borsello",
    "borsellini": "borsellino",
    "borsette": "borsetta",
    "borsini": "borsino",
    "borsisti": "borsista",
    "borsistica": "borsistico",
    "borsistiche": "borsistico",
    "borsistici": "borsistico",
    "borsoni": "borsone",
    "boscaglie": "boscaglia",
    "boscaioli": "boscaiolo",
    "boscherecce": "boschereccio",
    "boscherecci": "boschereccio",
    "boschereccia": "boschereccio",
    "boschetti": "boschetto",
    "boschi": "bosco",
    "boschiva": "boschivo",
    "boschive": "boschivo",
    "boschivi": "boschivo",
    "boscosa": "boscoso",
    "boscose": "boscoso",
    "boscosi": "boscoso",
    "bosniache": "bosniaca",
    "bosniaci": "bosniaco",
    "bosse": "bossa",
    "bossi": "bosso",
    "bossoli": "bossolo",
    "botanica": "botanico",
    "botaniche": "botanico",
    "botanici": "botanico",
    "botole": "botola",
    "botoli": "botolo",
    "bottacce": "bottaccio",
    "bottacci": "bottaccio",
    "bottaccia": "bottaccio",
    "botte": "botta",
    "bottegai": "bottegaio",
    "botteghe": "bottega",
    "botteghini": "botteghino",
    "bottegucce": "botteguccia",
    "botti": "botto",
    "botticelliana": "botticelliano",
    "botticelliane": "botticelliano",
    "botticelliani": "botticelliano",
    "bottigliate": "bottigliata",
    "bottiglie": "bottiglia",
    "bottigliette": "bottiglietta",
    "bottiglioni": "bottiglione",
    "bottini": "bottino",
    "bottoncini": "bottoncino",
    "bottoni": "bottone",
    "boutiques": "boutique",
    "bovarismi": "bovarismo",
    "bovina": "bovino",
    "bovine": "bovino",
    "bovini": "bovino",
    "boxa": "boxare",
    "boxai": "boxare",
    "boxammo": "boxare",
    "boxan": "boxare",
    "boxando": "boxare",
    "boxano": "boxare",
    "boxante": "boxare",
    "boxanti": "boxare",
    "boxar": "boxare",
    "boxaron": "boxare",
    "boxarono": "boxare",
    "boxasse": "boxare",
    "boxasser": "boxare",
    "boxassero": "boxare",
    "boxassi": "boxare",
    "boxassimo": "boxare",
    "boxaste": "boxare",
    "boxasti": "boxare",
    "boxata": "boxare",
    "boxate": "boxare",
    "boxati": "boxare",
    "boxato": "boxare",
    "boxava": "boxare",
    "boxavamo": "boxare",
    "boxavan": "boxare",
    "boxavano": "boxare",
    "boxavate": "boxare",
    "boxavi": "boxare",
    "boxavo": "boxare",
    "boxerai": "boxare",
    "boxeran": "boxare",
    "boxeranno": "boxare",
    "boxerebbe": "boxare",
    "boxerebber": "boxare",
    "boxerebbero": "boxare",
    "boxerei": "boxare",
    "boxeremmo": "boxare",
    "boxeremo": "boxare",
    "boxereste": "boxare",
    "boxeresti": "boxare",
    "boxerete": "boxare",
    "boxerà": "boxare",
    "boxerò": "boxare",
    "boxi": "boxare",
    "boxiamo": "boxare",
    "boxiate": "boxare",
    "boxin": "boxare",
    "boxino": "boxare",
    "boxo": "boxare",
    "boxò": "boxare",
    "bozze": "bozza",
    "bozzetti": "bozzetto",
    "bozzettismi": "bozzettismo",
    "bozzi": "bozzo",
    "bozzoli": "bozzolo",
    "bracca": "braccare",
    "braccai": "braccare",
    "braccammo": "braccare",
    "braccan": "braccare",
    "braccando": "braccare",
    "braccano": "braccare",
    "braccante": "braccare",
    "braccanti": "braccare",
    "braccar": "braccare",
    "braccaron": "braccare",
    "braccarono": "braccare",
    "braccasse": "braccare",
    "braccasser": "braccare",
    "braccassero": "braccare",
    "braccassi": "braccare",
    "braccassimo": "braccare",
    "braccaste": "braccare",
    "braccasti": "braccare",
    "braccata": "braccare",
    "braccate": "braccare",
    "braccati": "braccare",
    "braccato": "braccare",
    "braccava": "braccare",
    "braccavamo": "braccare",
    "braccavan": "braccare",
    "braccavano": "braccare",
    "braccavate": "braccare",
    "braccavi": "braccare",
    "braccavo": "braccare",
    "braccetti": "braccetto",
    "braccherai": "braccare",
    "braccheran": "braccare",
    "braccheranno": "braccare",
    "braccherebbe": "braccare",
    "braccherebber": "braccare",
    "braccherebbero": "braccare",
    "braccherei": "braccare",
    "braccheremmo": "braccare",
    "braccheremo": "braccare",
    "bracchereste": "braccare",
    "braccheresti": "braccare",
    "braccherete": "braccare",
    "braccherà": "braccare",
    "braccherò": "braccare",
    "bracchi": "braccare",
    "bracchiamo": "braccare",
    "bracchiate": "braccare",
    "bracchin": "braccare",
    "bracchino": "braccare",
    "bracci": "bracco",
    "braccia": "braccio",
    "braccialetti": "braccialetto",
    "bracciali": "bracciale",
    "braccianti": "bracciante",
    "bracciate": "bracciata",
    "braccioli": "bracciolo",
    "bracco": "braccare",
    "bracconieri": "bracconiere",
    "braccò": "braccare",
    "braci": "brace",
    "bracieri": "braciere",
    "brada": "brado",
    "brade": "brado",
    "bradi": "brado",
    "bradisismi": "bradisismo",
    "braghette": "braghetta",
    "brama": "bramire",
    "bramai": "bramare",
    "bramammo": "bramare",
    "braman": "bramire",
    "bramando": "bramare",
    "bramano": "bramire",
    "bramante": "bramare",
    "bramanti": "bramare",
    "bramar": "bramare",
    "bramaron": "bramare",
    "bramarono": "bramare",
    "bramasse": "bramare",
    "bramasser": "bramare",
    "bramassero": "bramare",
    "bramassi": "bramare",
    "bramassimo": "bramare",
    "bramaste": "bramare",
    "bramasti": "bramare",
    "bramata": "bramare",
    "bramate": "bramare",
    "bramati": "bramare",
    "bramato": "bramare",
    "bramava": "bramare",
    "bramavamo": "bramare",
    "bramavan": "bramare",
    "bramavano": "bramare",
    "bramavate": "bramare",
    "bramavi": "bramare",
    "bramavo": "bramare",
    "brame": "bramire",
    "bramendo": "bramire",
    "bramente": "bramire",
    "bramenti": "bramire",
    "bramerai": "bramare",
    "brameran": "bramare",
    "brameranno": "bramare",
    "bramerebbe": "bramare",
    "bramerebber": "bramare",
    "bramerebbero": "bramare",
    "bramerei": "bramare",
    "brameremmo": "bramare",
    "brameremo": "bramare",
    "bramereste": "bramare",
    "brameresti": "bramare",
    "bramerete": "bramare",
    "bramerà": "bramare",
    "bramerò": "bramare",
    "brami": "bramire",
    "bramiamo": "bramire",
    "bramiate": "bramire",
    "bramii": "bramire",
    "bramimmo": "bramire",
    "bramin": "bramare",
    "bramini": "bramino",
    "bramino": "bramare",
    "bramir": "bramire",
    "bramirai": "bramire",
    "bramiran": "bramire",
    "bramiranno": "bramire",
    "bramirebbe": "bramire",
    "bramirebber": "bramire",
    "bramirebbero": "bramire",
    "bramirei": "bramire",
    "bramiremmo": "bramire",
    "bramiremo": "bramire",
    "bramireste": "bramire",
    "bramiresti": "bramire",
    "bramirete": "bramire",
    "bramiron": "bramire",
    "bramirono": "bramire",
    "bramirà": "bramire",
    "bramirò": "bramire",
    "bramisse": "bramire",
    "bramisser": "bramire",
    "bramissero": "bramire",
    "bramissi": "bramire",
    "bramissimo": "bramire",
    "bramiste": "bramire",
    "bramisti": "bramire",
    "bramita": "bramire",
    "bramite": "bramire",
    "bramiti": "bramire",
    "bramito": "bramire",
    "bramiva": "bramire",
    "bramivamo": "bramire",
    "bramivan": "bramire",
    "bramivano": "bramire",
    "bramivate": "bramire",
    "bramivi": "bramire",
    "bramivo": "bramire",
    "bramo": "bramire",
    "bramon": "bramire",
    "bramono": "bramire",
    "bramosa": "bramoso",
    "bramose": "bramoso",
    "bramosi": "bramoso",
    "bramosie": "bramosia",
    "bramì": "bramire",
    "bramò": "bramare",
    "branche": "branca",
    "branchi": "branco",
    "branchiali": "branchiale",
    "branchie": "branchia",
    "brancica": "brancicare",
    "brancicai": "brancicare",
    "brancicammo": "brancicare",
    "brancican": "brancicare",
    "brancicando": "brancicare",
    "brancicano": "brancicare",
    "brancicante": "brancicare",
    "brancicanti": "brancicare",
    "brancicar": "brancicare",
    "brancicaron": "brancicare",
    "brancicarono": "brancicare",
    "brancicasse": "brancicare",
    "brancicasser": "brancicare",
    "brancicassero": "brancicare",
    "brancicassi": "brancicare",
    "brancicassimo": "brancicare",
    "brancicaste": "brancicare",
    "brancicasti": "brancicare",
    "brancicata": "brancicare",
    "brancicate": "brancicare",
    "brancicati": "brancicare",
    "brancicato": "brancicare",
    "brancicava": "brancicare",
    "brancicavamo": "brancicare",
    "brancicavan": "brancicare",
    "brancicavano": "brancicare",
    "brancicavate": "brancicare",
    "brancicavi": "brancicare",
    "brancicavo": "brancicare",
    "brancicherai": "brancicare",
    "brancicheran": "brancicare",
    "brancicheranno": "brancicare",
    "brancicherebbe": "brancicare",
    "brancicherebber": "brancicare",
    "brancicherebbero": "brancicare",
    "brancicherei": "brancicare",
    "brancicheremmo": "brancicare",
    "brancicheremo": "brancicare",
    "brancichereste": "brancicare",
    "brancicheresti": "brancicare",
    "brancicherete": "brancicare",
    "brancicherà": "brancicare",
    "brancicherò": "brancicare",
    "brancichi": "brancicare",
    "brancichiamo": "brancicare",
    "brancichiate": "brancicare",
    "brancichin": "brancicare",
    "brancichino": "brancicare",
    "brancico": "brancicare",
    "brancicò": "brancicare",
    "brancola": "brancolare",
    "brancolai": "brancolare",
    "brancolammo": "brancolare",
    "brancolan": "brancolare",
    "brancolando": "brancolare",
    "brancolano": "brancolare",
    "brancolante": "brancolare",
    "brancolanti": "brancolare",
    "brancolar": "brancolare",
    "brancolaron": "brancolare",
    "brancolarono": "brancolare",
    "brancolasse": "brancolare",
    "brancolasser": "brancolare",
    "brancolassero": "brancolare",
    "brancolassi": "brancolare",
    "brancolassimo": "brancolare",
    "brancolaste": "brancolare",
    "brancolasti": "brancolare",
    "brancolata": "brancolare",
    "brancolate": "brancolare",
    "brancolati": "brancolare",
    "brancolato": "brancolare",
    "brancolava": "brancolare",
    "brancolavamo": "brancolare",
    "brancolavan": "brancolare",
    "brancolavano": "brancolare",
    "brancolavate": "brancolare",
    "brancolavi": "brancolare",
    "brancolavo": "brancolare",
    "brancolerai": "brancolare",
    "brancoleran": "brancolare",
    "brancoleranno": "brancolare",
    "brancolerebbe": "brancolare",
    "brancolerebber": "brancolare",
    "brancolerebbero": "brancolare",
    "brancolerei": "brancolare",
    "brancoleremmo": "brancolare",
    "brancoleremo": "brancolare",
    "brancolereste": "brancolare",
    "brancoleresti": "brancolare",
    "brancolerete": "brancolare",
    "brancolerà": "brancolare",
    "brancolerò": "brancolare",
    "brancoli": "brancolare",
    "brancoliamo": "brancolare",
    "brancoliate": "brancolare",
    "brancolin": "brancolare",
    "brancolino": "brancolare",
    "brancolo": "brancolare",
    "brancolò": "brancolare",
    "brande": "branda",
    "brandeggerai": "brandeggiare",
    "brandeggeran": "brandeggiare",
    "brandeggeranno": "brandeggiare",
    "brandeggerebbe": "brandeggiare",
    "brandeggerebber": "brandeggiare",
    "brandeggerebbero": "brandeggiare",
    "brandeggerei": "brandeggiare",
    "brandeggeremmo": "brandeggiare",
    "brandeggeremo": "brandeggiare",
    "brandeggereste": "brandeggiare",
    "brandeggeresti": "brandeggiare",
    "brandeggerete": "brandeggiare",
    "brandeggerà": "brandeggiare",
    "brandeggerò": "brandeggiare",
    "brandeggi": "brandeggiare",
    "brandeggia": "brandeggiare",
    "brandeggiai": "brandeggiare",
    "brandeggiammo": "brandeggiare",
    "brandeggiamo": "brandeggiare",
    "brandeggian": "brandeggiare",
    "brandeggiando": "brandeggiare",
    "brandeggiano": "brandeggiare",
    "brandeggiante": "brandeggiare",
    "brandeggianti": "brandeggiare",
    "brandeggiar": "brandeggiare",
    "brandeggiaron": "brandeggiare",
    "brandeggiarono": "brandeggiare",
    "brandeggiasse": "brandeggiare",
    "brandeggiasser": "brandeggiare",
    "brandeggiassero": "brandeggiare",
    "brandeggiassi": "brandeggiare",
    "brandeggiassimo": "brandeggiare",
    "brandeggiaste": "brandeggiare",
    "brandeggiasti": "brandeggiare",
    "brandeggiata": "brandeggiare",
    "brandeggiate": "brandeggiare",
    "brandeggiati": "brandeggiare",
    "brandeggiato": "brandeggiare",
    "brandeggiava": "brandeggiare",
    "brandeggiavamo": "brandeggiare",
    "brandeggiavan": "brandeggiare",
    "brandeggiavano": "brandeggiare",
    "brandeggiavate": "brandeggiare",
    "brandeggiavi": "brandeggiare",
    "brandeggiavo": "brandeggiare",
    "brandeggin": "brandeggiare",
    "brandeggino": "brandeggiare",
    "brandeggio": "brandeggiare",
    "brandeggiò": "brandeggiare",
    "brandelli": "brandello",
    "brandendo": "brandire",
    "brandente": "brandire",
    "brandenti": "brandire",
    "brandiamo": "brandire",
    "brandiate": "brandire",
    "brandii": "brandire",
    "brandimmo": "brandire",
    "brandine": "brandina",
    "brandir": "brandire",
    "brandirai": "brandire",
    "brandiran": "brandire",
    "brandiranno": "brandire",
    "brandirebbe": "brandire",
    "brandirebber": "brandire",
    "brandirebbero": "brandire",
    "brandirei": "brandire",
    "brandiremmo": "brandire",
    "brandiremo": "brandire",
    "brandireste": "brandire",
    "brandiresti": "brandire",
    "brandirete": "brandire",
    "brandiron": "brandire",
    "brandirono": "brandire",
    "brandirà": "brandire",
    "brandirò": "brandire",
    "brandisca": "brandire",
    "brandiscan": "brandire",
    "brandiscano": "brandire",
    "brandisce": "brandire",
    "brandisci": "brandire",
    "brandisco": "brandire",
    "brandiscon": "brandire",
    "brandiscono": "brandire",
    "brandisse": "brandire",
    "brandisser": "brandire",
    "brandissero": "brandire",
    "brandissi": "brandire",
    "brandissimo": "brandire",
    "brandiste": "brandire",
    "brandisti": "brandire",
    "brandita": "brandire",
    "brandite": "brandire",
    "branditi": "brandire",
    "brandito": "brandire",
    "brandiva": "brandire",
    "brandivamo": "brandire",
    "brandivan": "brandire",
    "brandivano": "brandire",
    "brandivate": "brandire",
    "brandivi": "brandire",
    "brandivo": "brandire",
    "brandì": "brandire",
    "brani": "brano",
    "branzini": "branzino",
    "brasa": "brasare",
    "brasai": "brasare",
    "brasammo": "brasare",
    "brasan": "brasare",
    "brasando": "brasare",
    "brasano": "brasare",
    "brasante": "brasare",
    "brasanti": "brasare",
    "brasar": "brasare",
    "brasaron": "brasare",
    "brasarono": "brasare",
    "brasasse": "brasare",
    "brasasser": "brasare",
    "brasassero": "brasare",
    "brasassi": "brasare",
    "brasassimo": "brasare",
    "brasaste": "brasare",
    "brasasti": "brasare",
    "brasata": "brasare",
    "brasate": "brasare",
    "brasati": "brasare",
    "brasato": "brasare",
    "brasava": "brasare",
    "brasavamo": "brasare",
    "brasavan": "brasare",
    "brasavano": "brasare",
    "brasavate": "brasare",
    "brasavi": "brasare",
    "brasavo": "brasare",
    "braserai": "brasare",
    "braseran": "brasare",
    "braseranno": "brasare",
    "braserebbe": "brasare",
    "braserebber": "brasare",
    "braserebbero": "brasare",
    "braserei": "brasare",
    "braseremmo": "brasare",
    "braseremo": "brasare",
    "brasereste": "brasare",
    "braseresti": "brasare",
    "braserete": "brasare",
    "braserà": "brasare",
    "braserò": "brasare",
    "brasi": "brasare",
    "brasiamo": "brasare",
    "brasiate": "brasare",
    "brasiliana": "brasiliano",
    "brasiliane": "brasiliano",
    "brasiliani": "brasiliano",
    "brasin": "brasare",
    "brasino": "brasare",
    "braso": "brasare",
    "brasò": "brasare",
    "brava": "bravo",
    "bravate": "bravata",
    "brave": "bravo",
    "bravi": "bravo",
    "bravure": "bravura",
    "brecce": "breccia",
    "brefotrofi": "brefotrofio",
    "bresciana": "bresciano",
    "bresciane": "bresciano",
    "bresciani": "bresciano",
    "bretelle": "bretella",
    "bretoni": "bretone",
    "breve-medi": "breve-medio",
    "breve-media": "breve-medio",
    "breve-medie": "breve-medio",
    "brevetta": "brevettare",
    "brevettai": "brevettare",
    "brevettammo": "brevettare",
    "brevettan": "brevettare",
    "brevettando": "brevettare",
    "brevettano": "brevettare",
    "brevettante": "brevettare",
    "brevettanti": "brevettare",
    "brevettar": "brevettare",
    "brevettaron": "brevettare",
    "brevettarono": "brevettare",
    "brevettasse": "brevettare",
    "brevettasser": "brevettare",
    "brevettassero": "brevettare",
    "brevettassi": "brevettare",
    "brevettassimo": "brevettare",
    "brevettaste": "brevettare",
    "brevettasti": "brevettare",
    "brevettata": "brevettare",
    "brevettate": "brevettare",
    "brevettati": "brevettare",
    "brevettato": "brevettare",
    "brevettava": "brevettare",
    "brevettavamo": "brevettare",
    "brevettavan": "brevettare",
    "brevettavano": "brevettare",
    "brevettavate": "brevettare",
    "brevettavi": "brevettare",
    "brevettavo": "brevettare",
    "brevetterai": "brevettare",
    "brevetteran": "brevettare",
    "brevetteranno": "brevettare",
    "brevetterebbe": "brevettare",
    "brevetterebber": "brevettare",
    "brevetterebbero": "brevettare",
    "brevetterei": "brevettare",
    "brevetteremmo": "brevettare",
    "brevetteremo": "brevettare",
    "brevettereste": "brevettare",
    "brevetteresti": "brevettare",
    "brevetterete": "brevettare",
    "brevetterà": "brevettare",
    "brevetterò": "brevettare",
    "brevetti": "brevetto",
    "brevettiamo": "brevettare",
    "brevettiate": "brevettare",
    "brevettin": "brevettare",
    "brevettino": "brevettare",
    "brevetto": "brevettare",
    "brevettò": "brevettare",
    "brevi": "breve",
    "breviari": "breviario",
    "brezneviana": "brezneviano",
    "brezneviane": "brezneviano",
    "brezneviani": "brezneviano",
    "breznevismi": "breznevismo",
    "brezze": "brezza",
    "briaca": "briaco",
    "briache": "briaco",
    "briaci": "briaco",
    "brianzoli": "brianzolo",
    "bricchi": "bricco",
    "bricconi": "briccone",
    "briciole": "briciola",
    "briga": "brigare",
    "brigadieri": "brigadiere",
    "brigai": "brigare",
    "brigammo": "brigare",
    "brigan": "brigare",
    "brigando": "brigare",
    "brigano": "brigare",
    "brigantaggi": "brigantaggio",
    "brigante": "brigare",
    "brigantesca": "brigantesco",
    "brigantesche": "brigantesco",
    "briganteschi": "brigantesco",
    "briganti": "brigare",
    "brigar": "brigare",
    "brigaron": "brigare",
    "brigarono": "brigare",
    "brigasse": "brigare",
    "brigasser": "brigare",
    "brigassero": "brigare",
    "brigassi": "brigare",
    "brigassimo": "brigare",
    "brigaste": "brigare",
    "brigasti": "brigare",
    "brigata": "brigare",
    "brigate": "brigata",
    "brigati": "brigare",
    "brigatiste": "brigatista",
    "brigatisti": "brigatista",
    "brigato": "brigare",
    "brigava": "brigare",
    "brigavamo": "brigare",
    "brigavan": "brigare",
    "brigavano": "brigare",
    "brigavate": "brigare",
    "brigavi": "brigare",
    "brigavo": "brigare",
    "brigherai": "brigare",
    "brigheran": "brigare",
    "brigheranno": "brigare",
    "brigherebbe": "brigare",
    "brigherebber": "brigare",
    "brigherebbero": "brigare",
    "brigherei": "brigare",
    "brigheremmo": "brigare",
    "brigheremo": "brigare",
    "brighereste": "brigare",
    "brigheresti": "brigare",
    "brigherete": "brigare",
    "brigherà": "brigare",
    "brigherò": "brigare",
    "brighi": "brigare",
    "brighiamo": "brigare",
    "brighiate": "brigare",
    "brighin": "brigare",
    "brighino": "brigare",
    "briglie": "briglia",
    "brigo": "brigare",
    "brigò": "brigare",
    "brii": "brio",
    "brilla": "brillo",
    "brillai": "brillare",
    "brillammo": "brillare",
    "brillan": "brillare",
    "brillando": "brillare",
    "brillano": "brillare",
    "brillanta": "brillantare",
    "brillantai": "brillantare",
    "brillantammo": "brillantare",
    "brillantan": "brillantare",
    "brillantando": "brillantare",
    "brillantano": "brillantare",
    "brillantante": "brillantare",
    "brillantanti": "brillantare",
    "brillantar": "brillantare",
    "brillantaron": "brillantare",
    "brillantarono": "brillantare",
    "brillantasse": "brillantare",
    "brillantasser": "brillantare",
    "brillantassero": "brillantare",
    "brillantassi": "brillantare",
    "brillantassimo": "brillantare",
    "brillantaste": "brillantare",
    "brillantasti": "brillantare",
    "brillantata": "brillantare",
    "brillantate": "brillantare",
    "brillantati": "brillantare",
    "brillantato": "brillantare",
    "brillantava": "brillantare",
    "brillantavamo": "brillantare",
    "brillantavan": "brillantare",
    "brillantavano": "brillantare",
    "brillantavate": "brillantare",
    "brillantavi": "brillantare",
    "brillantavo": "brillantare",
    "brillante": "brillare",
    "brillanterai": "brillantare",
    "brillanteran": "brillantare",
    "brillanteranno": "brillantare",
    "brillanterebbe": "brillantare",
    "brillanterebber": "brillantare",
    "brillanterebbero": "brillantare",
    "brillanterei": "brillantare",
    "brillanteremmo": "brillantare",
    "brillanteremo": "brillantare",
    "brillantereste": "brillantare",
    "brillanteresti": "brillantare",
    "brillanterete": "brillantare",
    "brillanterà": "brillantare",
    "brillanterò": "brillantare",
    "brillantezze": "brillantezza",
    "brillanti": "brillare",
    "brillantiamo": "brillantare",
    "brillantiate": "brillantare",
    "brillantin": "brillantare",
    "brillantine": "brillantina",
    "brillantini": "brillantino",
    "brillantino": "brillantare",
    "brillanto": "brillantare",
    "brillantò": "brillantare",
    "brillar": "brillare",
    "brillaron": "brillare",
    "brillarono": "brillare",
    "brillasse": "brillare",
    "brillasser": "brillare",
    "brillassero": "brillare",
    "brillassi": "brillare",
    "brillassimo": "brillare",
    "brillaste": "brillare",
    "brillasti": "brillare",
    "brillata": "brillare",
    "brillate": "brillare",
    "brillati": "brillare",
    "brillato": "brillare",
    "brillava": "brillare",
    "brillavamo": "brillare",
    "brillavan": "brillare",
    "brillavano": "brillare",
    "brillavate": "brillare",
    "brillavi": "brillare",
    "brillavo": "brillare",
    "brille": "brillo",
    "brillerai": "brillare",
    "brilleran": "brillare",
    "brilleranno": "brillare",
    "brillerebbe": "brillare",
    "brillerebber": "brillare",
    "brillerebbero": "brillare",
    "brillerei": "brillare",
    "brilleremmo": "brillare",
    "brilleremo": "brillare",
    "brillereste": "brillare",
    "brilleresti": "brillare",
    "brillerete": "brillare",
    "brillerà": "brillare",
    "brillerò": "brillare",
    "brilli": "brillo",
    "brilliamo": "brillare",
    "brilliate": "brillare",
    "brillii": "brillio",
    "brillin": "brillare",
    "brillino": "brillare",
    "brillo": "brillare",
    "brillò": "brillare",
    "brina": "brinare",
    "brinai": "brinare",
    "brinammo": "brinare",
    "brinan": "brinare",
    "brinando": "brinare",
    "brinano": "brinare",
    "brinante": "brinare",
    "brinanti": "brinare",
    "brinar": "brinare",
    "brinaron": "brinare",
    "brinarono": "brinare",
    "brinasse": "brinare",
    "brinasser": "brinare",
    "brinassero": "brinare",
    "brinassi": "brinare",
    "brinassimo": "brinare",
    "brinaste": "brinare",
    "brinasti": "brinare",
    "brinata": "brinare",
    "brinate": "brinare",
    "brinati": "brinare",
    "brinato": "brinare",
    "brinava": "brinare",
    "brinavamo": "brinare",
    "brinavan": "brinare",
    "brinavano": "brinare",
    "brinavate": "brinare",
    "brinavi": "brinare",
    "brinavo": "brinare",
    "brinda": "brindare",
    "brindai": "brindare",
    "brindammo": "brindare",
    "brindan": "brindare",
    "brindando": "brindare",
    "brindano": "brindare",
    "brindante": "brindare",
    "brindanti": "brindare",
    "brindar": "brindare",
    "brindaron": "brindare",
    "brindarono": "brindare",
    "brindasse": "brindare",
    "brindasser": "brindare",
    "brindassero": "brindare",
    "brindassi": "brindare",
    "brindassimo": "brindare",
    "brindaste": "brindare",
    "brindasti": "brindare",
    "brindata": "brindare",
    "brindate": "brindare",
    "brindati": "brindare",
    "brindato": "brindare",
    "brindava": "brindare",
    "brindavamo": "brindare",
    "brindavan": "brindare",
    "brindavano": "brindare",
    "brindavate": "brindare",
    "brindavi": "brindare",
    "brindavo": "brindare",
    "brinderai": "brindare",
    "brinderan": "brindare",
    "brinderanno": "brindare",
    "brinderebbe": "brindare",
    "brinderebber": "brindare",
    "brinderebbero": "brindare",
    "brinderei": "brindare",
    "brinderemmo": "brindare",
    "brinderemo": "brindare",
    "brindereste": "brindare",
    "brinderesti": "brindare",
    "brinderete": "brindare",
    "brinderà": "brindare",
    "brinderò": "brindare",
    "brindi": "brindare",
    "brindiamo": "brindare",
    "brindiate": "brindare",
    "brindin": "brindare",
    "brindino": "brindare",
    "brindisini": "brindisino",
    "brindo": "brindare",
    "brindò": "brindare",
    "brinerai": "brinare",
    "brineran": "brinare",
    "brineranno": "brinare",
    "brinerebbe": "brinare",
    "brinerebber": "brinare",
    "brinerebbero": "brinare",
    "brinerei": "brinare",
    "brineremmo": "brinare",
    "brineremo": "brinare",
    "brinereste": "brinare",
    "brineresti": "brinare",
    "brinerete": "brinare",
    "brinerà": "brinare",
    "brinerò": "brinare",
    "brini": "brinare",
    "briniamo": "brinare",
    "briniate": "brinare",
    "brinin": "brinare",
    "brinino": "brinare",
    "brino": "brinare",
    "brinò": "brinare",
    "brioches": "brioche",
    "briosa": "brioso",
    "briose": "brioso",
    "briosi": "brioso",
    "briscole": "briscola",
    "britanna": "britanno",
    "britanne": "britanno",
    "britanni": "britanno",
    "britannica": "britannico",
    "britanniche": "britannico",
    "britannici": "britannico",
    "brividi": "brivido",
    "brizzolata": "brizzolato",
    "brizzolate": "brizzolato",
    "brizzolati": "brizzolato",
    "brocche": "brocca",
    "brocchi": "brocco",
    "brodi": "brodo",
    "brogli": "broglio",
    "broglia": "brogliare",
    "brogliacci": "brogliaccio",
    "brogliai": "brogliare",
    "brogliammo": "brogliare",
    "brogliamo": "brogliare",
    "broglian": "brogliare",
    "brogliando": "brogliare",
    "brogliano": "brogliare",
    "brogliante": "brogliare",
    "broglianti": "brogliare",
    "brogliar": "brogliare",
    "brogliaron": "brogliare",
    "brogliarono": "brogliare",
    "brogliasse": "brogliare",
    "brogliasser": "brogliare",
    "brogliassero": "brogliare",
    "brogliassi": "brogliare",
    "brogliassimo": "brogliare",
    "brogliaste": "brogliare",
    "brogliasti": "brogliare",
    "brogliata": "brogliare",
    "brogliate": "brogliare",
    "brogliati": "brogliare",
    "brogliato": "brogliare",
    "brogliava": "brogliare",
    "brogliavamo": "brogliare",
    "brogliavan": "brogliare",
    "brogliavano": "brogliare",
    "brogliavate": "brogliare",
    "brogliavi": "brogliare",
    "brogliavo": "brogliare",
    "broglierai": "brogliare",
    "broglieran": "brogliare",
    "broglieranno": "brogliare",
    "broglierebbe": "brogliare",
    "broglierebber": "brogliare",
    "broglierebbero": "brogliare",
    "broglierei": "brogliare",
    "broglieremmo": "brogliare",
    "broglieremo": "brogliare",
    "brogliereste": "brogliare",
    "broglieresti": "brogliare",
    "broglierete": "brogliare",
    "broglierà": "brogliare",
    "broglierò": "brogliare",
    "broglin": "brogliare",
    "broglino": "brogliare",
    "broglio": "brogliare",
    "brogliò": "brogliare",
    "brokeraggi": "brokeraggio",
    "brokers": "broker",
    "bronchi": "bronco",
    "bronchiali": "bronchiale",
    "bronchiti": "bronchite",
    "bronci": "broncio",
    "broncopneumopatie": "broncopneumopatia",
    "broncopolmoniti": "broncopolmonite",
    "brontola": "brontolare",
    "brontolai": "brontolare",
    "brontolammo": "brontolare",
    "brontolan": "brontolare",
    "brontolando": "brontolare",
    "brontolano": "brontolare",
    "brontolante": "brontolare",
    "brontolanti": "brontolare",
    "brontolar": "brontolare",
    "brontolaron": "brontolare",
    "brontolarono": "brontolare",
    "brontolasse": "brontolare",
    "brontolasser": "brontolare",
    "brontolassero": "brontolare",
    "brontolassi": "brontolare",
    "brontolassimo": "brontolare",
    "brontolaste": "brontolare",
    "brontolasti": "brontolare",
    "brontolata": "brontolare",
    "brontolate": "brontolare",
    "brontolati": "brontolare",
    "brontolato": "brontolare",
    "brontolava": "brontolare",
    "brontolavamo": "brontolare",
    "brontolavan": "brontolare",
    "brontolavano": "brontolare",
    "brontolavate": "brontolare",
    "brontolavi": "brontolare",
    "brontolavo": "brontolare",
    "brontolerai": "brontolare",
    "brontoleran": "brontolare",
    "brontoleranno": "brontolare",
    "brontolerebbe": "brontolare",
    "brontolerebber": "brontolare",
    "brontolerebbero": "brontolare",
    "brontolerei": "brontolare",
    "brontoleremmo": "brontolare",
    "brontoleremo": "brontolare",
    "brontolereste": "brontolare",
    "brontoleresti": "brontolare",
    "brontolerete": "brontolare",
    "brontolerà": "brontolare",
    "brontolerò": "brontolare",
    "brontoli": "brontolare",
    "brontoliamo": "brontolare",
    "brontoliate": "brontolare",
    "brontolii": "brontolio",
    "brontolin": "brontolare",
    "brontolino": "brontolare",
    "brontolo": "brontolare",
    "brontoloni": "brontolone",
    "brontolò": "brontolare",
    "bronza": "bronzare",
    "bronzai": "bronzare",
    "bronzammo": "bronzare",
    "bronzan": "bronzare",
    "bronzando": "bronzare",
    "bronzano": "bronzare",
    "bronzante": "bronzare",
    "bronzanti": "bronzare",
    "bronzar": "bronzare",
    "bronzaron": "bronzare",
    "bronzarono": "bronzare",
    "bronzasse": "bronzare",
    "bronzasser": "bronzare",
    "bronzassero": "bronzare",
    "bronzassi": "bronzare",
    "bronzassimo": "bronzare",
    "bronzaste": "bronzare",
    "bronzasti": "bronzare",
    "bronzata": "bronzare",
    "bronzate": "bronzare",
    "bronzati": "bronzare",
    "bronzato": "bronzare",
    "bronzava": "bronzare",
    "bronzavamo": "bronzare",
    "bronzavan": "bronzare",
    "bronzavano": "bronzare",
    "bronzavate": "bronzare",
    "bronzavi": "bronzare",
    "bronzavo": "bronzare",
    "bronzea": "bronzeo",
    "bronzee": "bronzeo",
    "bronzei": "bronzeo",
    "bronzerai": "bronzare",
    "bronzeran": "bronzare",
    "bronzeranno": "bronzare",
    "bronzerebbe": "bronzare",
    "bronzerebber": "bronzare",
    "bronzerebbero": "bronzare",
    "bronzerei": "bronzare",
    "bronzeremmo": "bronzare",
    "bronzeremo": "bronzare",
    "bronzereste": "bronzare",
    "bronzeresti": "bronzare",
    "bronzerete": "bronzare",
    "bronzerà": "bronzare",
    "bronzerò": "bronzare",
    "bronzetti": "bronzetto",
    "bronzi": "bronzo",
    "bronziamo": "bronzare",
    "bronziate": "bronzare",
    "bronzin": "bronzare",
    "bronzino": "bronzare",
    "bronzo": "bronzare",
    "bronzò": "bronzare",
    "bruca": "brucare",
    "brucai": "brucare",
    "brucammo": "brucare",
    "brucan": "brucare",
    "brucando": "brucare",
    "brucano": "brucare",
    "brucante": "brucare",
    "brucanti": "brucare",
    "brucar": "brucare",
    "brucaron": "brucare",
    "brucarono": "brucare",
    "brucasse": "brucare",
    "brucasser": "brucare",
    "brucassero": "brucare",
    "brucassi": "brucare",
    "brucassimo": "brucare",
    "brucaste": "brucare",
    "brucasti": "brucare",
    "brucata": "brucare",
    "brucate": "brucare",
    "brucati": "brucare",
    "brucato": "brucare",
    "brucava": "brucare",
    "brucavamo": "brucare",
    "brucavan": "brucare",
    "brucavano": "brucare",
    "brucavate": "brucare",
    "brucavi": "brucare",
    "brucavo": "brucare",
    "brucerai": "bruciare",
    "bruceran": "bruciare",
    "bruceranno": "bruciare",
    "brucerebbe": "bruciare",
    "brucerebber": "bruciare",
    "brucerebbero": "bruciare",
    "brucerei": "bruciare",
    "bruceremmo": "bruciare",
    "bruceremo": "bruciare",
    "brucereste": "bruciare",
    "bruceresti": "bruciare",
    "brucerete": "bruciare",
    "brucerà": "bruciare",
    "brucerò": "bruciare",
    "brucherai": "brucare",
    "brucheran": "brucare",
    "brucheranno": "brucare",
    "brucherebbe": "brucare",
    "brucherebber": "brucare",
    "brucherebbero": "brucare",
    "brucherei": "brucare",
    "brucheremmo": "brucare",
    "brucheremo": "brucare",
    "bruchereste": "brucare",
    "brucheresti": "brucare",
    "brucherete": "brucare",
    "brucherà": "brucare",
    "brucherò": "brucare",
    "bruchi": "bruco",
    "bruchiamo": "brucare",
    "bruchiate": "brucare",
    "bruchin": "brucare",
    "bruchino": "brucare",
    "bruci": "bruciare",
    "brucia": "bruciare",
    "bruciacchi": "bruciacchiare",
    "bruciacchia": "bruciacchiare",
    "bruciacchiai": "bruciacchiare",
    "bruciacchiammo": "bruciacchiare",
    "bruciacchiamo": "bruciacchiare",
    "bruciacchian": "bruciacchiare",
    "bruciacchiando": "bruciacchiare",
    "bruciacchiano": "bruciacchiare",
    "bruciacchiante": "bruciacchiare",
    "bruciacchianti": "bruciacchiare",
    "bruciacchiar": "bruciacchiare",
    "bruciacchiaron": "bruciacchiare",
    "bruciacchiarono": "bruciacchiare",
    "bruciacchiasse": "bruciacchiare",
    "bruciacchiasser": "bruciacchiare",
    "bruciacchiassero": "bruciacchiare",
    "bruciacchiassi": "bruciacchiare",
    "bruciacchiassimo": "bruciacchiare",
    "bruciacchiaste": "bruciacchiare",
    "bruciacchiasti": "bruciacchiare",
    "bruciacchiata": "bruciacchiare",
    "bruciacchiate": "bruciacchiare",
    "bruciacchiati": "bruciacchiare",
    "bruciacchiato": "bruciacchiare",
    "bruciacchiava": "bruciacchiare",
    "bruciacchiavamo": "bruciacchiare",
    "bruciacchiavan": "bruciacchiare",
    "bruciacchiavano": "bruciacchiare",
    "bruciacchiavate": "bruciacchiare",
    "bruciacchiavi": "bruciacchiare",
    "bruciacchiavo": "bruciacchiare",
    "bruciacchierai": "bruciacchiare",
    "bruciacchieran": "bruciacchiare",
    "bruciacchieranno": "bruciacchiare",
    "bruciacchierebbe": "bruciacchiare",
    "bruciacchierebber": "bruciacchiare",
    "bruciacchierebbero": "bruciacchiare",
    "bruciacchierei": "bruciacchiare",
    "bruciacchieremmo": "bruciacchiare",
    "bruciacchieremo": "bruciacchiare",
    "bruciacchiereste": "bruciacchiare",
    "bruciacchieresti": "bruciacchiare",
    "bruciacchierete": "bruciacchiare",
    "bruciacchierà": "bruciacchiare",
    "bruciacchierò": "bruciacchiare",
    "bruciacchin": "bruciacchiare",
    "bruciacchino": "bruciacchiare",
    "bruciacchio": "bruciacchiare",
    "bruciacchiò": "bruciacchiare",
    "bruciai": "bruciare",
    "bruciammo": "bruciare",
    "bruciamo": "bruciare",
    "brucian": "bruciare",
    "bruciando": "bruciare",
    "bruciano": "bruciare",
    "bruciante": "bruciare",
    "brucianti": "bruciare",
    "bruciar": "bruciare",
    "bruciaron": "bruciare",
    "bruciarono": "bruciare",
    "bruciasse": "bruciare",
    "bruciasser": "bruciare",
    "bruciassero": "bruciare",
    "bruciassi": "bruciare",
    "bruciassimo": "bruciare",
    "bruciaste": "bruciare",
    "bruciasti": "bruciare",
    "bruciata": "bruciato",
    "bruciate": "bruciato",
    "bruciati": "bruciato",
    "bruciato": "bruciare",
    "bruciatori": "bruciatore",
    "bruciature": "bruciatura",
    "bruciava": "bruciare",
    "bruciavamo": "bruciare",
    "bruciavan": "bruciare",
    "bruciavano": "bruciare",
    "bruciavate": "bruciare",
    "bruciavi": "bruciare",
    "bruciavo": "bruciare",
    "brucin": "bruciare",
    "brucino": "bruciare",
    "brucio": "bruciare",
    "bruciori": "bruciore",
    "bruciò": "bruciare",
    "bruco": "brucare",
    "brucò": "brucare",
    "brufoli": "brufolo",
    "brughiere": "brughiera",
    "brulica": "brulicare",
    "brulicai": "brulicare",
    "brulicammo": "brulicare",
    "brulican": "brulicare",
    "brulicando": "brulicare",
    "brulicano": "brulicare",
    "brulicante": "brulicare",
    "brulicanti": "brulicare",
    "brulicar": "brulicare",
    "brulicaron": "brulicare",
    "brulicarono": "brulicare",
    "brulicasse": "brulicare",
    "brulicasser": "brulicare",
    "brulicassero": "brulicare",
    "brulicassi": "brulicare",
    "brulicassimo": "brulicare",
    "brulicaste": "brulicare",
    "brulicasti": "brulicare",
    "brulicata": "brulicare",
    "brulicate": "brulicare",
    "brulicati": "brulicare",
    "brulicato": "brulicare",
    "brulicava": "brulicare",
    "brulicavamo": "brulicare",
    "brulicavan": "brulicare",
    "brulicavano": "brulicare",
    "brulicavate": "brulicare",
    "brulicavi": "brulicare",
    "brulicavo": "brulicare",
    "brulicherai": "brulicare",
    "brulicheran": "brulicare",
    "brulicheranno": "brulicare",
    "brulicherebbe": "brulicare",
    "brulicherebber": "brulicare",
    "brulicherebbero": "brulicare",
    "brulicherei": "brulicare",
    "brulicheremmo": "brulicare",
    "brulicheremo": "brulicare",
    "brulichereste": "brulicare",
    "brulicheresti": "brulicare",
    "brulicherete": "brulicare",
    "brulicherà": "brulicare",
    "brulicherò": "brulicare",
    "brulichi": "brulicare",
    "brulichiamo": "brulicare",
    "brulichiate": "brulicare",
    "brulichii": "brulichio",
    "brulichin": "brulicare",
    "brulichino": "brulicare",
    "brulico": "brulicare",
    "brulicò": "brulicare",
    "brulla": "brullo",
    "brulle": "brullo",
    "brulli": "brullo",
    "brume": "bruma",
    "brumosa": "brumoso",
    "brumose": "brumoso",
    "brumosi": "brumoso",
    "bruna": "bruno",
    "brunan": "brunire",
    "brunano": "brunire",
    "brunastra": "brunastro",
    "brunastre": "brunastro",
    "brunastri": "brunastro",
    "brune": "bruno",
    "brunendo": "brunire",
    "brunente": "brunire",
    "brunenti": "brunire",
    "brunette": "brunetta",
    "bruni": "bruno",
    "bruniamo": "brunire",
    "bruniate": "brunire",
    "brunii": "brunire",
    "brunimmo": "brunire",
    "brunir": "brunire",
    "brunirai": "brunire",
    "bruniran": "brunire",
    "bruniranno": "brunire",
    "brunirebbe": "brunire",
    "brunirebber": "brunire",
    "brunirebbero": "brunire",
    "brunirei": "brunire",
    "bruniremmo": "brunire",
    "bruniremo": "brunire",
    "brunireste": "brunire",
    "bruniresti": "brunire",
    "brunirete": "brunire",
    "bruniron": "brunire",
    "brunirono": "brunire",
    "brunirà": "brunire",
    "brunirò": "brunire",
    "brunisse": "brunire",
    "brunisser": "brunire",
    "brunissero": "brunire",
    "brunissi": "brunire",
    "brunissimo": "brunire",
    "bruniste": "brunire",
    "brunisti": "brunire",
    "brunita": "brunire",
    "brunite": "brunire",
    "bruniti": "brunire",
    "brunito": "brunire",
    "bruniva": "brunire",
    "brunivamo": "brunire",
    "brunivan": "brunire",
    "brunivano": "brunire",
    "brunivate": "brunire",
    "brunivi": "brunire",
    "brunivo": "brunire",
    "bruno": "brunire",
    "brunon": "brunire",
    "brunono": "brunire",
    "brunì": "brunire",
    "brusca": "brusco",
    "brusche": "brusco",
    "bruschi": "brusco",
    "bruschina": "bruschinare",
    "bruschinai": "bruschinare",
    "bruschinammo": "bruschinare",
    "bruschinan": "bruschinare",
    "bruschinando": "bruschinare",
    "bruschinano": "bruschinare",
    "bruschinante": "bruschinare",
    "bruschinanti": "bruschinare",
    "bruschinar": "bruschinare",
    "bruschinaron": "bruschinare",
    "bruschinarono": "bruschinare",
    "bruschinasse": "bruschinare",
    "bruschinasser": "bruschinare",
    "bruschinassero": "bruschinare",
    "bruschinassi": "bruschinare",
    "bruschinassimo": "bruschinare",
    "bruschinaste": "bruschinare",
    "bruschinasti": "bruschinare",
    "bruschinata": "bruschinare",
    "bruschinate": "bruschinare",
    "bruschinati": "bruschinare",
    "bruschinato": "bruschinare",
    "bruschinava": "bruschinare",
    "bruschinavamo": "bruschinare",
    "bruschinavan": "bruschinare",
    "bruschinavano": "bruschinare",
    "bruschinavate": "bruschinare",
    "bruschinavi": "bruschinare",
    "bruschinavo": "bruschinare",
    "bruschinerai": "bruschinare",
    "bruschineran": "bruschinare",
    "bruschineranno": "bruschinare",
    "bruschinerebbe": "bruschinare",
    "bruschinerebber": "bruschinare",
    "bruschinerebbero": "bruschinare",
    "bruschinerei": "bruschinare",
    "bruschineremmo": "bruschinare",
    "bruschineremo": "bruschinare",
    "bruschinereste": "bruschinare",
    "bruschineresti": "bruschinare",
    "bruschinerete": "bruschinare",
    "bruschinerà": "bruschinare",
    "bruschinerò": "bruschinare",
    "bruschini": "bruschinare",
    "bruschiniamo": "bruschinare",
    "bruschiniate": "bruschinare",
    "bruschinin": "bruschinare",
    "bruschinino": "bruschinare",
    "bruschino": "bruschinare",
    "bruschinò": "bruschinare",
    "brusii": "brusio",
    "brusìi": "brusìo",
    "bruta": "bruto",
    "brutali": "brutale",
    "brutalizza": "brutalizzare",
    "brutalizzai": "brutalizzare",
    "brutalizzammo": "brutalizzare",
    "brutalizzan": "brutalizzare",
    "brutalizzando": "brutalizzare",
    "brutalizzano": "brutalizzare",
    "brutalizzante": "brutalizzare",
    "brutalizzanti": "brutalizzare",
    "brutalizzar": "brutalizzare",
    "brutalizzaron": "brutalizzare",
    "brutalizzarono": "brutalizzare",
    "brutalizzasse": "brutalizzare",
    "brutalizzasser": "brutalizzare",
    "brutalizzassero": "brutalizzare",
    "brutalizzassi": "brutalizzare",
    "brutalizzassimo": "brutalizzare",
    "brutalizzaste": "brutalizzare",
    "brutalizzasti": "brutalizzare",
    "brutalizzata": "brutalizzare",
    "brutalizzate": "brutalizzare",
    "brutalizzati": "brutalizzare",
    "brutalizzato": "brutalizzare",
    "brutalizzava": "brutalizzare",
    "brutalizzavamo": "brutalizzare",
    "brutalizzavan": "brutalizzare",
    "brutalizzavano": "brutalizzare",
    "brutalizzavate": "brutalizzare",
    "brutalizzavi": "brutalizzare",
    "brutalizzavo": "brutalizzare",
    "brutalizzerai": "brutalizzare",
    "brutalizzeran": "brutalizzare",
    "brutalizzeranno": "brutalizzare",
    "brutalizzerebbe": "brutalizzare",
    "brutalizzerebber": "brutalizzare",
    "brutalizzerebbero": "brutalizzare",
    "brutalizzerei": "brutalizzare",
    "brutalizzeremmo": "brutalizzare",
    "brutalizzeremo": "brutalizzare",
    "brutalizzereste": "brutalizzare",
    "brutalizzeresti": "brutalizzare",
    "brutalizzerete": "brutalizzare",
    "brutalizzerà": "brutalizzare",
    "brutalizzerò": "brutalizzare",
    "brutalizzi": "brutalizzare",
    "brutalizziamo": "brutalizzare",
    "brutalizziate": "brutalizzare",
    "brutalizzin": "brutalizzare",
    "brutalizzino": "brutalizzare",
    "brutalizzo": "brutalizzare",
    "brutalizzò": "brutalizzare",
    "brute": "bruto",
    "bruti": "bruto",
    "brutta": "brutto",
    "bruttai": "bruttare",
    "bruttammo": "bruttare",
    "bruttan": "bruttare",
    "bruttando": "bruttare",
    "bruttano": "bruttare",
    "bruttante": "bruttare",
    "bruttanti": "bruttare",
    "bruttar": "bruttare",
    "bruttaron": "bruttare",
    "bruttarono": "bruttare",
    "bruttasse": "bruttare",
    "bruttasser": "bruttare",
    "bruttassero": "bruttare",
    "bruttassi": "bruttare",
    "bruttassimo": "bruttare",
    "bruttaste": "bruttare",
    "bruttasti": "bruttare",
    "bruttata": "bruttare",
    "bruttate": "bruttare",
    "bruttati": "bruttare",
    "bruttato": "bruttare",
    "bruttava": "bruttare",
    "bruttavamo": "bruttare",
    "bruttavan": "bruttare",
    "bruttavano": "bruttare",
    "bruttavate": "bruttare",
    "bruttavi": "bruttare",
    "bruttavo": "bruttare",
    "brutte": "brutto",
    "brutterai": "bruttare",
    "brutteran": "bruttare",
    "brutteranno": "bruttare",
    "brutterebbe": "bruttare",
    "brutterebber": "bruttare",
    "brutterebbero": "bruttare",
    "brutterei": "bruttare",
    "brutteremmo": "bruttare",
    "brutteremo": "bruttare",
    "bruttereste": "bruttare",
    "brutteresti": "bruttare",
    "brutterete": "bruttare",
    "brutterà": "bruttare",
    "brutterò": "bruttare",
    "bruttezze": "bruttezza",
    "brutti": "brutto",
    "bruttiamo": "bruttare",
    "bruttiate": "bruttare",
    "bruttin": "bruttare",
    "bruttine": "bruttina",
    "bruttino": "bruttare",
    "brutto": "bruttare",
    "brutture": "bruttura",
    "bruttò": "bruttare",
    "bubbola": "bubbolare",
    "bubbolai": "bubbolare",
    "bubbolammo": "bubbolare",
    "bubbolan": "bubbolare",
    "bubbolando": "bubbolare",
    "bubbolano": "bubbolare",
    "bubbolante": "bubbolare",
    "bubbolanti": "bubbolare",
    "bubbolar": "bubbolare",
    "bubbolaron": "bubbolare",
    "bubbolarono": "bubbolare",
    "bubbolasse": "bubbolare",
    "bubbolasser": "bubbolare",
    "bubbolassero": "bubbolare",
    "bubbolassi": "bubbolare",
    "bubbolassimo": "bubbolare",
    "bubbolaste": "bubbolare",
    "bubbolasti": "bubbolare",
    "bubbolata": "bubbolare",
    "bubbolate": "bubbolare",
    "bubbolati": "bubbolare",
    "bubbolato": "bubbolare",
    "bubbolava": "bubbolare",
    "bubbolavamo": "bubbolare",
    "bubbolavan": "bubbolare",
    "bubbolavano": "bubbolare",
    "bubbolavate": "bubbolare",
    "bubbolavi": "bubbolare",
    "bubbolavo": "bubbolare",
    "bubbole": "bubbola",
    "bubbolerai": "bubbolare",
    "bubboleran": "bubbolare",
    "bubboleranno": "bubbolare",
    "bubbolerebbe": "bubbolare",
    "bubbolerebber": "bubbolare",
    "bubbolerebbero": "bubbolare",
    "bubbolerei": "bubbolare",
    "bubboleremmo": "bubbolare",
    "bubboleremo": "bubbolare",
    "bubbolereste": "bubbolare",
    "bubboleresti": "bubbolare",
    "bubbolerete": "bubbolare",
    "bubbolerà": "bubbolare",
    "bubbolerò": "bubbolare",
    "bubboli": "bubbolare",
    "bubboliamo": "bubbolare",
    "bubboliate": "bubbolare",
    "bubbolin": "bubbolare",
    "bubbolino": "bubbolare",
    "bubbolo": "bubbolare",
    "bubbolò": "bubbolare",
    "bubboni": "bubbone",
    "buca": "bucare",
    "bucai": "bucare",
    "bucammo": "bucare",
    "bucan": "bucare",
    "bucando": "bucare",
    "bucanieri": "bucaniere",
    "bucano": "bucare",
    "bucante": "bucare",
    "bucanti": "bucare",
    "bucar": "bucare",
    "bucaron": "bucare",
    "bucarono": "bucare",
    "bucasse": "bucare",
    "bucasser": "bucare",
    "bucassero": "bucare",
    "bucassi": "bucare",
    "bucassimo": "bucare",
    "bucaste": "bucare",
    "bucasti": "bucare",
    "bucata": "bucare",
    "bucate": "bucare",
    "bucati": "bucare",
    "bucato": "bucare",
    "bucava": "bucare",
    "bucavamo": "bucare",
    "bucavan": "bucare",
    "bucavano": "bucare",
    "bucavate": "bucare",
    "bucavi": "bucare",
    "bucavo": "bucare",
    "bucce": "buccia",
    "buche": "buca",
    "bucherai": "bucare",
    "bucheran": "bucare",
    "bucheranno": "bucare",
    "bucherebbe": "bucare",
    "bucherebber": "bucare",
    "bucherebbero": "bucare",
    "bucherei": "bucare",
    "bucherella": "bucherellare",
    "bucherellai": "bucherellare",
    "bucherellammo": "bucherellare",
    "bucherellan": "bucherellare",
    "bucherellando": "bucherellare",
    "bucherellano": "bucherellare",
    "bucherellante": "bucherellare",
    "bucherellanti": "bucherellare",
    "bucherellar": "bucherellare",
    "bucherellaron": "bucherellare",
    "bucherellarono": "bucherellare",
    "bucherellasse": "bucherellare",
    "bucherellasser": "bucherellare",
    "bucherellassero": "bucherellare",
    "bucherellassi": "bucherellare",
    "bucherellassimo": "bucherellare",
    "bucherellaste": "bucherellare",
    "bucherellasti": "bucherellare",
    "bucherellata": "bucherellare",
    "bucherellate": "bucherellare",
    "bucherellati": "bucherellare",
    "bucherellato": "bucherellare",
    "bucherellava": "bucherellare",
    "bucherellavamo": "bucherellare",
    "bucherellavan": "bucherellare",
    "bucherellavano": "bucherellare",
    "bucherellavate": "bucherellare",
    "bucherellavi": "bucherellare",
    "bucherellavo": "bucherellare",
    "bucherellerai": "bucherellare",
    "bucherelleran": "bucherellare",
    "bucherelleranno": "bucherellare",
    "bucherellerebbe": "bucherellare",
    "bucherellerebber": "bucherellare",
    "bucherellerebbero": "bucherellare",
    "bucherellerei": "bucherellare",
    "bucherelleremmo": "bucherellare",
    "bucherelleremo": "bucherellare",
    "bucherellereste": "bucherellare",
    "bucherelleresti": "bucherellare",
    "bucherellerete": "bucherellare",
    "bucherellerà": "bucherellare",
    "bucherellerò": "bucherellare",
    "bucherelli": "bucherellare",
    "bucherelliamo": "bucherellare",
    "bucherelliate": "bucherellare",
    "bucherellin": "bucherellare",
    "bucherellino": "bucherellare",
    "bucherello": "bucherellare",
    "bucherellò": "bucherellare",
    "bucheremmo": "bucare",
    "bucheremo": "bucare",
    "buchereste": "bucare",
    "bucheresti": "bucare",
    "bucherete": "bucare",
    "bucherà": "bucare",
    "bucherò": "bucare",
    "buchette": "buchetta",
    "buchi": "buco",
    "buchiamo": "bucare",
    "buchiate": "bucare",
    "buchin": "bucare",
    "buchino": "bucare",
    "buco": "bucare",
    "bucolica": "bucolico",
    "bucoliche": "bucolico",
    "bucolici": "bucolico",
    "bucò": "bucare",
    "buddhismi": "buddhismo",
    "buddhiste": "buddhista",
    "buddhisti": "buddhista",
    "buddismi": "buddismo",
    "buddiste": "buddista",
    "buddisti": "buddista",
    "budella": "budello",
    "budini": "budino",
    "bufale": "bufala",
    "bufali": "bufalo",
    "bufere": "bufera",
    "buffa": "buffo",
    "buffai": "buffare",
    "buffammo": "buffare",
    "buffan": "buffare",
    "buffando": "buffare",
    "buffano": "buffare",
    "buffante": "buffare",
    "buffanti": "buffare",
    "buffar": "buffare",
    "buffaron": "buffare",
    "buffarono": "buffare",
    "buffasse": "buffare",
    "buffasser": "buffare",
    "buffassero": "buffare",
    "buffassi": "buffare",
    "buffassimo": "buffare",
    "buffaste": "buffare",
    "buffasti": "buffare",
    "buffata": "buffare",
    "buffate": "buffare",
    "buffati": "buffare",
    "buffato": "buffare",
    "buffava": "buffare",
    "buffavamo": "buffare",
    "buffavan": "buffare",
    "buffavano": "buffare",
    "buffavate": "buffare",
    "buffavi": "buffare",
    "buffavo": "buffare",
    "buffe": "buffo",
    "bufferai": "buffare",
    "bufferan": "buffare",
    "bufferanno": "buffare",
    "bufferebbe": "buffare",
    "bufferebber": "buffare",
    "bufferebbero": "buffare",
    "bufferei": "buffare",
    "bufferemmo": "buffare",
    "bufferemo": "buffare",
    "buffereste": "buffare",
    "bufferesti": "buffare",
    "bufferete": "buffare",
    "bufferà": "buffare",
    "bufferò": "buffare",
    "buffetti": "buffetto",
    "buffi": "buffo",
    "buffiamo": "buffare",
    "buffiate": "buffare",
    "buffin": "buffare",
    "buffino": "buffare",
    "buffo": "buffare",
    "buffonate": "buffonata",
    "buffoneggerai": "buffoneggiare",
    "buffoneggeran": "buffoneggiare",
    "buffoneggeranno": "buffoneggiare",
    "buffoneggerebbe": "buffoneggiare",
    "buffoneggerebber": "buffoneggiare",
    "buffoneggerebbero": "buffoneggiare",
    "buffoneggerei": "buffoneggiare",
    "buffoneggeremmo": "buffoneggiare",
    "buffoneggeremo": "buffoneggiare",
    "buffoneggereste": "buffoneggiare",
    "buffoneggeresti": "buffoneggiare",
    "buffoneggerete": "buffoneggiare",
    "buffoneggerà": "buffoneggiare",
    "buffoneggerò": "buffoneggiare",
    "buffoneggi": "buffoneggiare",
    "buffoneggia": "buffoneggiare",
    "buffoneggiai": "buffoneggiare",
    "buffoneggiammo": "buffoneggiare",
    "buffoneggiamo": "buffoneggiare",
    "buffoneggian": "buffoneggiare",
    "buffoneggiando": "buffoneggiare",
    "buffoneggiano": "buffoneggiare",
    "buffoneggiante": "buffoneggiare",
    "buffoneggianti": "buffoneggiare",
    "buffoneggiar": "buffoneggiare",
    "buffoneggiaron": "buffoneggiare",
    "buffoneggiarono": "buffoneggiare",
    "buffoneggiasse": "buffoneggiare",
    "buffoneggiasser": "buffoneggiare",
    "buffoneggiassero": "buffoneggiare",
    "buffoneggiassi": "buffoneggiare",
    "buffoneggiassimo": "buffoneggiare",
    "buffoneggiaste": "buffoneggiare",
    "buffoneggiasti": "buffoneggiare",
    "buffoneggiata": "buffoneggiare",
    "buffoneggiate": "buffoneggiare",
    "buffoneggiati": "buffoneggiare",
    "buffoneggiato": "buffoneggiare",
    "buffoneggiava": "buffoneggiare",
    "buffoneggiavamo": "buffoneggiare",
    "buffoneggiavan": "buffoneggiare",
    "buffoneggiavano": "buffoneggiare",
    "buffoneggiavate": "buffoneggiare",
    "buffoneggiavi": "buffoneggiare",
    "buffoneggiavo": "buffoneggiare",
    "buffoneggin": "buffoneggiare",
    "buffoneggino": "buffoneggiare",
    "buffoneggio": "buffoneggiare",
    "buffoneggiò": "buffoneggiare",
    "buffonerie": "buffoneria",
    "buffonesca": "buffonesco",
    "buffonesche": "buffonesco",
    "buffoneschi": "buffonesco",
    "buffoni": "buffone",
    "buffò": "buffare",
    "buggera": "buggerare",
    "buggerai": "buggerare",
    "buggerammo": "buggerare",
    "buggeran": "buggerare",
    "buggerando": "buggerare",
    "buggerano": "buggerare",
    "buggerante": "buggerare",
    "buggeranti": "buggerare",
    "buggerar": "buggerare",
    "buggeraron": "buggerare",
    "buggerarono": "buggerare",
    "buggerasse": "buggerare",
    "buggerasser": "buggerare",
    "buggerassero": "buggerare",
    "buggerassi": "buggerare",
    "buggerassimo": "buggerare",
    "buggeraste": "buggerare",
    "buggerasti": "buggerare",
    "buggerata": "buggerare",
    "buggerate": "buggerare",
    "buggerati": "buggerare",
    "buggerato": "buggerare",
    "buggerava": "buggerare",
    "buggeravamo": "buggerare",
    "buggeravan": "buggerare",
    "buggeravano": "buggerare",
    "buggeravate": "buggerare",
    "buggeravi": "buggerare",
    "buggeravo": "buggerare",
    "buggererai": "buggerare",
    "buggereran": "buggerare",
    "buggereranno": "buggerare",
    "buggererebbe": "buggerare",
    "buggererebber": "buggerare",
    "buggererebbero": "buggerare",
    "buggererei": "buggerare",
    "buggereremmo": "buggerare",
    "buggereremo": "buggerare",
    "buggerereste": "buggerare",
    "buggereresti": "buggerare",
    "buggererete": "buggerare",
    "buggererà": "buggerare",
    "buggererò": "buggerare",
    "buggeri": "buggerare",
    "buggeriamo": "buggerare",
    "buggeriate": "buggerare",
    "buggerin": "buggerare",
    "buggerino": "buggerare",
    "buggero": "buggerare",
    "buggerò": "buggerare",
    "bugi": "bugio",
    "bugia": "bugio",
    "bugiarda": "bugiardo",
    "bugiarde": "bugiardo",
    "bugiardi": "bugiardo",
    "bugie": "bugio",
    "bugigattoli": "bugigattolo",
    "bugna": "bugnare",
    "bugnai": "bugnare",
    "bugnammo": "bugnare",
    "bugnan": "bugnare",
    "bugnando": "bugnare",
    "bugnano": "bugnare",
    "bugnante": "bugnare",
    "bugnanti": "bugnare",
    "bugnar": "bugnare",
    "bugnaron": "bugnare",
    "bugnarono": "bugnare",
    "bugnasse": "bugnare",
    "bugnasser": "bugnare",
    "bugnassero": "bugnare",
    "bugnassi": "bugnare",
    "bugnassimo": "bugnare",
    "bugnaste": "bugnare",
    "bugnasti": "bugnare",
    "bugnata": "bugnare",
    "bugnate": "bugnare",
    "bugnati": "bugnare",
    "bugnato": "bugnare",
    "bugnava": "bugnare",
    "bugnavamo": "bugnare",
    "bugnavan": "bugnare",
    "bugnavano": "bugnare",
    "bugnavate": "bugnare",
    "bugnavi": "bugnare",
    "bugnavo": "bugnare",
    "bugnerai": "bugnare",
    "bugneran": "bugnare",
    "bugneranno": "bugnare",
    "bugnerebbe": "bugnare",
    "bugnerebber": "bugnare",
    "bugnerebbero": "bugnare",
    "bugnerei": "bugnare",
    "bugneremmo": "bugnare",
    "bugneremo": "bugnare",
    "bugnereste": "bugnare",
    "bugneresti": "bugnare",
    "bugnerete": "bugnare",
    "bugnerà": "bugnare",
    "bugnerò": "bugnare",
    "bugni": "bugnare",
    "bugniamo": "bugnare",
    "bugniate": "bugnare",
    "bugnin": "bugnare",
    "bugnino": "bugnare",
    "bugno": "bugnare",
    "bugnò": "bugnare",
    "bui": "buio",
    "buia": "buio",
    "buie": "buio",
    "bulbi": "bulbo",
    "bulgara": "bulgaro",
    "bulgare": "bulgaro",
    "bulgari": "bulgaro",
    "bulimici": "bulimico",
    "bulimie": "bulimia",
    "bulina": "bulinare",
    "bulinai": "bulinare",
    "bulinammo": "bulinare",
    "bulinan": "bulinare",
    "bulinando": "bulinare",
    "bulinano": "bulinare",
    "bulinante": "bulinare",
    "bulinanti": "bulinare",
    "bulinar": "bulinare",
    "bulinaron": "bulinare",
    "bulinarono": "bulinare",
    "bulinasse": "bulinare",
    "bulinasser": "bulinare",
    "bulinassero": "bulinare",
    "bulinassi": "bulinare",
    "bulinassimo": "bulinare",
    "bulinaste": "bulinare",
    "bulinasti": "bulinare",
    "bulinata": "bulinare",
    "bulinate": "bulinare",
    "bulinati": "bulinare",
    "bulinato": "bulinare",
    "bulinava": "bulinare",
    "bulinavamo": "bulinare",
    "bulinavan": "bulinare",
    "bulinavano": "bulinare",
    "bulinavate": "bulinare",
    "bulinavi": "bulinare",
    "bulinavo": "bulinare",
    "bulinerai": "bulinare",
    "bulineran": "bulinare",
    "bulineranno": "bulinare",
    "bulinerebbe": "bulinare",
    "bulinerebber": "bulinare",
    "bulinerebbero": "bulinare",
    "bulinerei": "bulinare",
    "bulineremmo": "bulinare",
    "bulineremo": "bulinare",
    "bulinereste": "bulinare",
    "bulineresti": "bulinare",
    "bulinerete": "bulinare",
    "bulinerà": "bulinare",
    "bulinerò": "bulinare",
    "bulini": "bulinare",
    "buliniamo": "bulinare",
    "buliniate": "bulinare",
    "bulinin": "bulinare",
    "bulinino": "bulinare",
    "bulino": "bulinare",
    "bulinò": "bulinare",
    "bulletti": "bulletto",
    "bulli": "bullo",
    "bullona": "bullonare",
    "bullonai": "bullonare",
    "bullonammo": "bullonare",
    "bullonan": "bullonare",
    "bullonando": "bullonare",
    "bullonano": "bullonare",
    "bullonante": "bullonare",
    "bullonanti": "bullonare",
    "bullonar": "bullonare",
    "bullonaron": "bullonare",
    "bullonarono": "bullonare",
    "bullonasse": "bullonare",
    "bullonasser": "bullonare",
    "bullonassero": "bullonare",
    "bullonassi": "bullonare",
    "bullonassimo": "bullonare",
    "bullonaste": "bullonare",
    "bullonasti": "bullonare",
    "bullonata": "bullonare",
    "bullonate": "bullonare",
    "bullonati": "bullonare",
    "bullonato": "bullonare",
    "bullonava": "bullonare",
    "bullonavamo": "bullonare",
    "bullonavan": "bullonare",
    "bullonavano": "bullonare",
    "bullonavate": "bullonare",
    "bullonavi": "bullonare",
    "bullonavo": "bullonare",
    "bullonerai": "bullonare",
    "bulloneran": "bullonare",
    "bulloneranno": "bullonare",
    "bullonerebbe": "bullonare",
    "bullonerebber": "bullonare",
    "bullonerebbero": "bullonare",
    "bullonerei": "bullonare",
    "bulloneremmo": "bullonare",
    "bulloneremo": "bullonare",
    "bullonereste": "bullonare",
    "bulloneresti": "bullonare",
    "bullonerete": "bullonare",
    "bullonerà": "bullonare",
    "bullonerò": "bullonare",
    "bulloni": "bullone",
    "bulloniamo": "bullonare",
    "bulloniate": "bullonare",
    "bullonin": "bullonare",
    "bullonino": "bullonare",
    "bullono": "bullonare",
    "bullonò": "bullonare",
    "buoi": "bue",
    "buona": "buono",
    "buone": "buono",
    "buongiorni": "buongiorno",
    "buongoverni": "buongoverno",
    "buongustai": "buongustaio",
    "buongusti": "buongusto",
    "buoni": "buono",
    "buonismi": "buonismo",
    "buonisti": "buonista",
    "buonsensi": "buonsenso",
    "buontemponi": "buontempone",
    "buonumori": "buonumore",
    "buonuscite": "buonuscita",
    "buratta": "burattare",
    "burattai": "burattare",
    "burattammo": "burattare",
    "burattan": "burattare",
    "burattando": "burattare",
    "burattano": "burattare",
    "burattante": "burattare",
    "burattanti": "burattare",
    "burattar": "burattare",
    "burattaron": "burattare",
    "burattarono": "burattare",
    "burattasse": "burattare",
    "burattasser": "burattare",
    "burattassero": "burattare",
    "burattassi": "burattare",
    "burattassimo": "burattare",
    "burattaste": "burattare",
    "burattasti": "burattare",
    "burattata": "burattare",
    "burattate": "burattare",
    "burattati": "burattare",
    "burattato": "burattare",
    "burattava": "burattare",
    "burattavamo": "burattare",
    "burattavan": "burattare",
    "burattavano": "burattare",
    "burattavate": "burattare",
    "burattavi": "burattare",
    "burattavo": "burattare",
    "buratterai": "burattare",
    "buratteran": "burattare",
    "buratteranno": "burattare",
    "buratterebbe": "burattare",
    "buratterebber": "burattare",
    "buratterebbero": "burattare",
    "buratterei": "burattare",
    "buratteremmo": "burattare",
    "buratteremo": "burattare",
    "burattereste": "burattare",
    "buratteresti": "burattare",
    "buratterete": "burattare",
    "buratterà": "burattare",
    "buratterò": "burattare",
    "buratti": "burattare",
    "burattiamo": "burattare",
    "burattiate": "burattare",
    "burattin": "burattare",
    "burattinai": "burattinaio",
    "burattinesca": "burattinesco",
    "burattinesche": "burattinesco",
    "burattineschi": "burattinesco",
    "burattini": "burattino",
    "burattino": "burattare",
    "buratto": "burattare",
    "burattò": "burattare",
    "burbera": "burbero",
    "burbere": "burbero",
    "burberi": "burbero",
    "buriane": "buriana",
    "burini": "burino",
    "burla": "burlare",
    "burlai": "burlare",
    "burlammo": "burlare",
    "burlan": "burlare",
    "burlando": "burlare",
    "burlano": "burlare",
    "burlante": "burlare",
    "burlanti": "burlare",
    "burlar": "burlare",
    "burlaron": "burlare",
    "burlarono": "burlare",
    "burlasse": "burlare",
    "burlasser": "burlare",
    "burlassero": "burlare",
    "burlassi": "burlare",
    "burlassimo": "burlare",
    "burlaste": "burlare",
    "burlasti": "burlare",
    "burlata": "burlare",
    "burlate": "burlare",
    "burlati": "burlare",
    "burlato": "burlare",
    "burlava": "burlare",
    "burlavamo": "burlare",
    "burlavan": "burlare",
    "burlavano": "burlare",
    "burlavate": "burlare",
    "burlavi": "burlare",
    "burlavo": "burlare",
    "burle": "burla",
    "burlerai": "burlare",
    "burleran": "burlare",
    "burleranno": "burlare",
    "burlerebbe": "burlare",
    "burlerebber": "burlare",
    "burlerebbero": "burlare",
    "burlerei": "burlare",
    "burleremmo": "burlare",
    "burleremo": "burlare",
    "burlereste": "burlare",
    "burleresti": "burlare",
    "burlerete": "burlare",
    "burlerà": "burlare",
    "burlerò": "burlare",
    "burlesca": "burlesco",
    "burlesche": "burlesco",
    "burleschi": "burlesco",
    "burli": "burlare",
    "burliamo": "burlare",
    "burliate": "burlare",
    "burlin": "burlare",
    "burlino": "burlare",
    "burlo": "burlare",
    "burloni": "burlone",
    "burlò": "burlare",
    "burocratesi": "burocratese",
    "burocrati": "burocrate",
    "burocratica": "burocratico",
    "burocratiche": "burocratico",
    "burocratici": "burocratico",
    "burocratismi": "burocratismo",
    "burocratizza": "burocratizzare",
    "burocratizzai": "burocratizzare",
    "burocratizzammo": "burocratizzare",
    "burocratizzan": "burocratizzare",
    "burocratizzando": "burocratizzare",
    "burocratizzano": "burocratizzare",
    "burocratizzante": "burocratizzare",
    "burocratizzanti": "burocratizzare",
    "burocratizzar": "burocratizzare",
    "burocratizzaron": "burocratizzare",
    "burocratizzarono": "burocratizzare",
    "burocratizzasse": "burocratizzare",
    "burocratizzasser": "burocratizzare",
    "burocratizzassero": "burocratizzare",
    "burocratizzassi": "burocratizzare",
    "burocratizzassimo": "burocratizzare",
    "burocratizzaste": "burocratizzare",
    "burocratizzasti": "burocratizzare",
    "burocratizzata": "burocratizzare",
    "burocratizzate": "burocratizzare",
    "burocratizzati": "burocratizzare",
    "burocratizzato": "burocratizzare",
    "burocratizzava": "burocratizzare",
    "burocratizzavamo": "burocratizzare",
    "burocratizzavan": "burocratizzare",
    "burocratizzavano": "burocratizzare",
    "burocratizzavate": "burocratizzare",
    "burocratizzavi": "burocratizzare",
    "burocratizzavo": "burocratizzare",
    "burocratizzazioni": "burocratizzazione",
    "burocratizzerai": "burocratizzare",
    "burocratizzeran": "burocratizzare",
    "burocratizzeranno": "burocratizzare",
    "burocratizzerebbe": "burocratizzare",
    "burocratizzerebber": "burocratizzare",
    "burocratizzerebbero": "burocratizzare",
    "burocratizzerei": "burocratizzare",
    "burocratizzeremmo": "burocratizzare",
    "burocratizzeremo": "burocratizzare",
    "burocratizzereste": "burocratizzare",
    "burocratizzeresti": "burocratizzare",
    "burocratizzerete": "burocratizzare",
    "burocratizzerà": "burocratizzare",
    "burocratizzerò": "burocratizzare",
    "burocratizzi": "burocratizzare",
    "burocratizziamo": "burocratizzare",
    "burocratizziate": "burocratizzare",
    "burocratizzin": "burocratizzare",
    "burocratizzino": "burocratizzare",
    "burocratizzo": "burocratizzare",
    "burocratizzò": "burocratizzare",
    "burocrazie": "burocrazia",
    "burrasche": "burrasca",
    "burrascosa": "burrascoso",
    "burrascose": "burrascoso",
    "burrascosi": "burrascoso",
    "burri": "burro",
    "burroni": "burrone",
    "burrosa": "burroso",
    "burrose": "burroso",
    "burrosi": "burroso",
    "busca": "buscare",
    "buscai": "buscare",
    "buscammo": "buscare",
    "buscan": "buscare",
    "buscando": "buscare",
    "buscano": "buscare",
    "buscante": "buscare",
    "buscanti": "buscare",
    "buscar": "buscare",
    "buscaron": "buscare",
    "buscarono": "buscare",
    "buscasse": "buscare",
    "buscasser": "buscare",
    "buscassero": "buscare",
    "buscassi": "buscare",
    "buscassimo": "buscare",
    "buscaste": "buscare",
    "buscasti": "buscare",
    "buscata": "buscare",
    "buscate": "buscare",
    "buscati": "buscare",
    "buscato": "buscare",
    "buscava": "buscare",
    "buscavamo": "buscare",
    "buscavan": "buscare",
    "buscavano": "buscare",
    "buscavate": "buscare",
    "buscavi": "buscare",
    "buscavo": "buscare",
    "buschera": "buscherare",
    "buscherai": "buscherare",
    "buscherammo": "buscherare",
    "buscheran": "buscherare",
    "buscherando": "buscherare",
    "buscheranno": "buscare",
    "buscherano": "buscherare",
    "buscherante": "buscherare",
    "buscheranti": "buscherare",
    "buscherar": "buscherare",
    "buscheraron": "buscherare",
    "buscherarono": "buscherare",
    "buscherasse": "buscherare",
    "buscherasser": "buscherare",
    "buscherassero": "buscherare",
    "buscherassi": "buscherare",
    "buscherassimo": "buscherare",
    "buscheraste": "buscherare",
    "buscherasti": "buscherare",
    "buscherata": "buscherare",
    "buscherate": "buscherare",
    "buscherati": "buscherare",
    "buscherato": "buscherare",
    "buscherava": "buscherare",
    "buscheravamo": "buscherare",
    "buscheravan": "buscherare",
    "buscheravano": "buscherare",
    "buscheravate": "buscherare",
    "buscheravi": "buscherare",
    "buscheravo": "buscherare",
    "buscherebbe": "buscare",
    "buscherebber": "buscare",
    "buscherebbero": "buscare",
    "buscherei": "buscare",
    "buscheremmo": "buscare",
    "buscheremo": "buscare",
    "buschererai": "buscherare",
    "buschereran": "buscherare",
    "buschereranno": "buscherare",
    "buschererebbe": "buscherare",
    "buschererebber": "buscherare",
    "buschererebbero": "buscherare",
    "buschererei": "buscherare",
    "buschereremmo": "buscherare",
    "buschereremo": "buscherare",
    "buscherereste": "buscherare",
    "buschereresti": "buscherare",
    "buschererete": "buscherare",
    "buschererà": "buscherare",
    "buschererò": "buscherare",
    "buschereste": "buscare",
    "buscheresti": "buscare",
    "buscherete": "buscare",
    "buscheri": "buscherare",
    "buscheriamo": "buscherare",
    "buscheriate": "buscherare",
    "buscherin": "buscherare",
    "buscherino": "buscherare",
    "buschero": "buscherare",
    "buscherà": "buscare",
    "buscherò": "buscherare",
    "buschi": "buscare",
    "buschiamo": "buscare",
    "buschiate": "buscare",
    "buschin": "buscare",
    "buschino": "buscare",
    "busco": "buscare",
    "buscò": "buscare",
    "businessmen": "businessman",
    "bussa": "bussare",
    "bussai": "bussare",
    "bussammo": "bussare",
    "bussan": "bussare",
    "bussando": "bussare",
    "bussano": "bussare",
    "bussante": "bussare",
    "bussanti": "bussare",
    "bussar": "bussare",
    "bussaron": "bussare",
    "bussarono": "bussare",
    "bussasse": "bussare",
    "bussasser": "bussare",
    "bussassero": "bussare",
    "bussassi": "bussare",
    "bussassimo": "bussare",
    "bussaste": "bussare",
    "bussasti": "bussare",
    "bussata": "bussare",
    "bussate": "bussare",
    "bussati": "bussare",
    "bussato": "bussare",
    "bussava": "bussare",
    "bussavamo": "bussare",
    "bussavan": "bussare",
    "bussavano": "bussare",
    "bussavate": "bussare",
    "bussavi": "bussare",
    "bussavo": "bussare",
    "busserai": "bussare",
    "busseran": "bussare",
    "busseranno": "bussare",
    "busserebbe": "bussare",
    "busserebber": "bussare",
    "busserebbero": "bussare",
    "busserei": "bussare",
    "busseremmo": "bussare",
    "busseremo": "bussare",
    "bussereste": "bussare",
    "busseresti": "bussare",
    "busserete": "bussare",
    "busserà": "bussare",
    "busserò": "bussare",
    "bussi": "bussare",
    "bussiamo": "bussare",
    "bussiate": "bussare",
    "bussin": "bussare",
    "bussino": "bussare",
    "busso": "bussare",
    "bussole": "bussola",
    "bussolotti": "bussolotto",
    "bussò": "bussare",
    "bustarelle": "bustarella",
    "buste": "busta",
    "buste-paga": "busta-paga",
    "busti": "busto",
    "bustine": "bustina",
    "bustini": "bustino",
    "butta": "buttare",
    "buttai": "buttare",
    "buttammo": "buttare",
    "buttan": "buttare",
    "buttando": "buttare",
    "buttano": "buttare",
    "buttante": "buttare",
    "buttanti": "buttare",
    "buttar": "buttare",
    "buttaron": "buttare",
    "buttarono": "buttare",
    "buttasse": "buttare",
    "buttasser": "buttare",
    "buttassero": "buttare",
    "buttassi": "buttare",
    "buttassimo": "buttare",
    "buttaste": "buttare",
    "buttasti": "buttare",
    "buttata": "buttare",
    "buttate": "buttare",
    "buttati": "buttare",
    "buttato": "buttare",
    "buttava": "buttare",
    "buttavamo": "buttare",
    "buttavan": "buttare",
    "buttavano": "buttare",
    "buttavate": "buttare",
    "buttavi": "buttare",
    "buttavo": "buttare",
    "butterai": "buttare",
    "butteran": "buttare",
    "butteranno": "buttare",
    "butterata": "butterato",
    "butterate": "butterato",
    "butterati": "butterato",
    "butterebbe": "buttare",
    "butterebber": "buttare",
    "butterebbero": "buttare",
    "butterei": "buttare",
    "butteremmo": "buttare",
    "butteremo": "buttare",
    "buttereste": "buttare",
    "butteresti": "buttare",
    "butterete": "buttare",
    "butteri": "buttero",
    "butterà": "buttare",
    "butterò": "buttare",
    "butti": "buttare",
    "buttiamo": "buttare",
    "buttiate": "buttare",
    "buttin": "buttare",
    "buttino": "buttare",
    "butto": "buttare",
    "buttò": "buttare",
    "buvettes": "buvette",
    "bypassa": "bypassare",
    "bypassai": "bypassare",
    "bypassammo": "bypassare",
    "bypassan": "bypassare",
    "bypassando": "bypassare",
    "bypassano": "bypassare",
    "bypassante": "bypassare",
    "bypassanti": "bypassare",
    "bypassar": "bypassare",
    "bypassaron": "bypassare",
    "bypassarono": "bypassare",
    "bypassasse": "bypassare",
    "bypassasser": "bypassare",
    "bypassassero": "bypassare",
    "bypassassi": "bypassare",
    "bypassassimo": "bypassare",
    "bypassaste": "bypassare",
    "bypassasti": "bypassare",
    "bypassata": "bypassare",
    "bypassate": "bypassare",
    "bypassati": "bypassare",
    "bypassato": "bypassare",
    "bypassava": "bypassare",
    "bypassavamo": "bypassare",
    "bypassavan": "bypassare",
    "bypassavano": "bypassare",
    "bypassavate": "bypassare",
    "bypassavi": "bypassare",
    "bypassavo": "bypassare",
    "bypasserai": "bypassare",
    "bypasseran": "bypassare",
    "bypasseranno": "bypassare",
    "bypasserebbe": "bypassare",
    "bypasserebber": "bypassare",
    "bypasserebbero": "bypassare",
    "bypasserei": "bypassare",
    "bypasseremmo": "bypassare",
    "bypasseremo": "bypassare",
    "bypassereste": "bypassare",
    "bypasseresti": "bypassare",
    "bypasserete": "bypassare",
    "bypasserà": "bypassare",
    "bypasserò": "bypassare",
    "bypassi": "bypassare",
    "bypassiamo": "bypassare",
    "bypassiate": "bypassare",
    "bypassin": "bypassare",
    "bypassino": "bypassare",
    "bypasso": "bypassare",
    "bypassò": "bypassare",
    "cabale": "cabala",
    "cabalette": "cabaletta",
    "cabalisti": "cabalista",
    "cabalistica": "cabalistico",
    "cabalistiche": "cabalistico",
    "cabalistici": "cabalistico",
    "cabarettisti": "cabarettista",
    "cabinata": "cabinato",
    "cabinate": "cabinato",
    "cabinati": "cabinato",
    "cabine": "cabina",
    "cabla": "cablare",
    "cablaggi": "cablaggio",
    "cablai": "cablare",
    "cablammo": "cablare",
    "cablan": "cablare",
    "cablando": "cablare",
    "cablano": "cablare",
    "cablante": "cablare",
    "cablanti": "cablare",
    "cablar": "cablare",
    "cablaron": "cablare",
    "cablarono": "cablare",
    "cablasse": "cablare",
    "cablasser": "cablare",
    "cablassero": "cablare",
    "cablassi": "cablare",
    "cablassimo": "cablare",
    "cablaste": "cablare",
    "cablasti": "cablare",
    "cablata": "cablare",
    "cablate": "cablare",
    "cablati": "cablare",
    "cablato": "cablare",
    "cablature": "cablatura",
    "cablava": "cablare",
    "cablavamo": "cablare",
    "cablavan": "cablare",
    "cablavano": "cablare",
    "cablavate": "cablare",
    "cablavi": "cablare",
    "cablavo": "cablare",
    "cablerai": "cablare",
    "cableran": "cablare",
    "cableranno": "cablare",
    "cablerebbe": "cablare",
    "cablerebber": "cablare",
    "cablerebbero": "cablare",
    "cablerei": "cablare",
    "cableremmo": "cablare",
    "cableremo": "cablare",
    "cablereste": "cablare",
    "cableresti": "cablare",
    "cablerete": "cablare",
    "cablerà": "cablare",
    "cablerò": "cablare",
    "cabli": "cablare",
    "cabliamo": "cablare",
    "cabliate": "cablare",
    "cablin": "cablare",
    "cablino": "cablare",
    "cablo": "cablare",
    "cablò": "cablare",
    "cabota": "cabotare",
    "cabotaggi": "cabotaggio",
    "cabotai": "cabotare",
    "cabotammo": "cabotare",
    "cabotan": "cabotare",
    "cabotando": "cabotare",
    "cabotano": "cabotare",
    "cabotante": "cabotare",
    "cabotanti": "cabotare",
    "cabotar": "cabotare",
    "cabotaron": "cabotare",
    "cabotarono": "cabotare",
    "cabotasse": "cabotare",
    "cabotasser": "cabotare",
    "cabotassero": "cabotare",
    "cabotassi": "cabotare",
    "cabotassimo": "cabotare",
    "cabotaste": "cabotare",
    "cabotasti": "cabotare",
    "cabotata": "cabotare",
    "cabotate": "cabotare",
    "cabotati": "cabotare",
    "cabotato": "cabotare",
    "cabotava": "cabotare",
    "cabotavamo": "cabotare",
    "cabotavan": "cabotare",
    "cabotavano": "cabotare",
    "cabotavate": "cabotare",
    "cabotavi": "cabotare",
    "cabotavo": "cabotare",
    "caboterai": "cabotare",
    "caboteran": "cabotare",
    "caboteranno": "cabotare",
    "caboterebbe": "cabotare",
    "caboterebber": "cabotare",
    "caboterebbero": "cabotare",
    "caboterei": "cabotare",
    "caboteremmo": "cabotare",
    "caboteremo": "cabotare",
    "cabotereste": "cabotare",
    "caboteresti": "cabotare",
    "caboterete": "cabotare",
    "caboterà": "cabotare",
    "caboterò": "cabotare",
    "caboti": "cabotare",
    "cabotiamo": "cabotare",
    "cabotiate": "cabotare",
    "cabotin": "cabotare",
    "cabotino": "cabotare",
    "caboto": "cabotare",
    "cabotò": "cabotare",
    "cabra": "cabrare",
    "cabrai": "cabrare",
    "cabrammo": "cabrare",
    "cabran": "cabrare",
    "cabrando": "cabrare",
    "cabrano": "cabrare",
    "cabrante": "cabrare",
    "cabranti": "cabrare",
    "cabrar": "cabrare",
    "cabraron": "cabrare",
    "cabrarono": "cabrare",
    "cabrasse": "cabrare",
    "cabrasser": "cabrare",
    "cabrassero": "cabrare",
    "cabrassi": "cabrare",
    "cabrassimo": "cabrare",
    "cabraste": "cabrare",
    "cabrasti": "cabrare",
    "cabrata": "cabrare",
    "cabrate": "cabrare",
    "cabrati": "cabrare",
    "cabrato": "cabrare",
    "cabrava": "cabrare",
    "cabravamo": "cabrare",
    "cabravan": "cabrare",
    "cabravano": "cabrare",
    "cabravate": "cabrare",
    "cabravi": "cabrare",
    "cabravo": "cabrare",
    "cabrerai": "cabrare",
    "cabreran": "cabrare",
    "cabreranno": "cabrare",
    "cabrerebbe": "cabrare",
    "cabrerebber": "cabrare",
    "cabrerebbero": "cabrare",
    "cabrerei": "cabrare",
    "cabreremmo": "cabrare",
    "cabreremo": "cabrare",
    "cabrereste": "cabrare",
    "cabreresti": "cabrare",
    "cabrerete": "cabrare",
    "cabrerà": "cabrare",
    "cabrerò": "cabrare",
    "cabri": "cabrare",
    "cabriamo": "cabrare",
    "cabriate": "cabrare",
    "cabrin": "cabrare",
    "cabrino": "cabrare",
    "cabro": "cabrare",
    "cabrò": "cabrare",
    "caca": "cacare",
    "cacai": "cacare",
    "cacammo": "cacare",
    "cacan": "cacare",
    "cacando": "cacare",
    "cacano": "cacare",
    "cacante": "cacare",
    "cacanti": "cacare",
    "cacar": "cacare",
    "cacaron": "cacare",
    "cacarono": "cacare",
    "cacasse": "cacare",
    "cacasser": "cacare",
    "cacassero": "cacare",
    "cacassi": "cacare",
    "cacassimo": "cacare",
    "cacaste": "cacare",
    "cacasti": "cacare",
    "cacata": "cacare",
    "cacate": "cacare",
    "cacati": "cacare",
    "cacato": "cacare",
    "cacava": "cacare",
    "cacavamo": "cacare",
    "cacavan": "cacare",
    "cacavano": "cacare",
    "cacavate": "cacare",
    "cacavi": "cacare",
    "cacavo": "cacare",
    "cacce": "caccia",
    "caccerai": "cacciare",
    "cacceran": "cacciare",
    "cacceranno": "cacciare",
    "caccerebbe": "cacciare",
    "caccerebber": "cacciare",
    "caccerebbero": "cacciare",
    "caccerei": "cacciare",
    "cacceremmo": "cacciare",
    "cacceremo": "cacciare",
    "caccereste": "cacciare",
    "cacceresti": "cacciare",
    "caccerete": "cacciare",
    "caccerà": "cacciare",
    "caccerò": "cacciare",
    "cacche": "cacca",
    "cacci": "cacciare",
    "caccia": "cacciare",
    "caccia-bombardieri": "caccia-bombardiere",
    "cacciabombardieri": "cacciabombardiere",
    "cacciai": "cacciare",
    "cacciammo": "cacciare",
    "cacciamo": "cacciare",
    "caccian": "cacciare",
    "cacciando": "cacciare",
    "cacciano": "cacciare",
    "cacciante": "cacciare",
    "caccianti": "cacciare",
    "cacciar": "cacciare",
    "cacciaron": "cacciare",
    "cacciarono": "cacciare",
    "cacciasse": "cacciare",
    "cacciasser": "cacciare",
    "cacciassero": "cacciare",
    "cacciassi": "cacciare",
    "cacciassimo": "cacciare",
    "cacciaste": "cacciare",
    "cacciasti": "cacciare",
    "cacciata": "cacciare",
    "cacciate": "cacciata",
    "cacciati": "cacciare",
    "cacciato": "cacciare",
    "cacciatori": "cacciatore",
    "cacciatorpedinieri": "cacciatorpediniere",
    "cacciatrici": "cacciatrice",
    "cacciava": "cacciare",
    "cacciavamo": "cacciare",
    "cacciavan": "cacciare",
    "cacciavano": "cacciare",
    "cacciavate": "cacciare",
    "cacciavi": "cacciare",
    "cacciaviti": "cacciavite",
    "cacciavo": "cacciare",
    "caccin": "cacciare",
    "caccino": "cacciare",
    "caccio": "cacciare",
    "cacciò": "cacciare",
    "cacherai": "cacare",
    "cacheran": "cacare",
    "cacheranno": "cacare",
    "cacherebbe": "cacare",
    "cacherebber": "cacare",
    "cacherebbero": "cacare",
    "cacherei": "cacare",
    "cacheremmo": "cacare",
    "cacheremo": "cacare",
    "cachereste": "cacare",
    "cacheresti": "cacare",
    "cacherete": "cacare",
    "cacherà": "cacare",
    "cacherò": "cacare",
    "cachi": "caco",
    "cachiamo": "cacare",
    "cachiate": "cacare",
    "cachin": "cacare",
    "cachino": "cacare",
    "cacicchi": "cacicco",
    "caco": "cacare",
    "cacofonica": "cacofonico",
    "cacofoniche": "cacofonico",
    "cacofonici": "cacofonico",
    "cacofonie": "cacofonia",
    "cacò": "cacare",
    "cada": "cadere",
    "cadan": "cadere",
    "cadano": "cadere",
    "cadauna": "cadauno",
    "cadaune": "cadauno",
    "cadauni": "cadauno",
    "cadaveri": "cadavere",
    "cadaverica": "cadaverico",
    "cadaveriche": "cadaverico",
    "cadaverici": "cadaverico",
    "cadaverini": "cadaverino",
    "cadde": "cadere",
    "cadder": "cadere",
    "caddero": "cadere",
    "caddi": "cadere",
    "cade": "cadere",
    "cademmo": "cadere",
    "cadendo": "cadere",
    "cadente": "cadere",
    "cadenti": "cadere",
    "cadenza": "cadenzare",
    "cadenzai": "cadenzare",
    "cadenzammo": "cadenzare",
    "cadenzan": "cadenzare",
    "cadenzando": "cadenzare",
    "cadenzano": "cadenzare",
    "cadenzante": "cadenzare",
    "cadenzanti": "cadenzare",
    "cadenzar": "cadenzare",
    "cadenzaron": "cadenzare",
    "cadenzarono": "cadenzare",
    "cadenzasse": "cadenzare",
    "cadenzasser": "cadenzare",
    "cadenzassero": "cadenzare",
    "cadenzassi": "cadenzare",
    "cadenzassimo": "cadenzare",
    "cadenzaste": "cadenzare",
    "cadenzasti": "cadenzare",
    "cadenzata": "cadenzare",
    "cadenzate": "cadenzare",
    "cadenzati": "cadenzare",
    "cadenzato": "cadenzare",
    "cadenzava": "cadenzare",
    "cadenzavamo": "cadenzare",
    "cadenzavan": "cadenzare",
    "cadenzavano": "cadenzare",
    "cadenzavate": "cadenzare",
    "cadenzavi": "cadenzare",
    "cadenzavo": "cadenzare",
    "cadenze": "cadenza",
    "cadenzerai": "cadenzare",
    "cadenzeran": "cadenzare",
    "cadenzeranno": "cadenzare",
    "cadenzerebbe": "cadenzare",
    "cadenzerebber": "cadenzare",
    "cadenzerebbero": "cadenzare",
    "cadenzerei": "cadenzare",
    "cadenzeremmo": "cadenzare",
    "cadenzeremo": "cadenzare",
    "cadenzereste": "cadenzare",
    "cadenzeresti": "cadenzare",
    "cadenzerete": "cadenzare",
    "cadenzerà": "cadenzare",
    "cadenzerò": "cadenzare",
    "cadenzi": "cadenzare",
    "cadenziamo": "cadenzare",
    "cadenziate": "cadenzare",
    "cadenzin": "cadenzare",
    "cadenzino": "cadenzare",
    "cadenzo": "cadenzare",
    "cadenzò": "cadenzare",
    "cader": "cadere",
    "cadesse": "cadere",
    "cadesser": "cadere",
    "cadessero": "cadere",
    "cadessi": "cadere",
    "cadessimo": "cadere",
    "cadeste": "cadere",
    "cadesti": "cadere",
    "cadete": "cadere",
    "cadetta": "cadetto",
    "cadette": "cadetto",
    "cadetti": "cadetto",
    "cadeva": "cadere",
    "cadevamo": "cadere",
    "cadevan": "cadere",
    "cadevano": "cadere",
    "cadevate": "cadere",
    "cadevi": "cadere",
    "cadevo": "cadere",
    "cadi": "cadere",
    "cadiamo": "cadere",
    "cadiate": "cadere",
    "cado": "cadere",
    "cadon": "cadere",
    "cadono": "cadere",
    "cadrai": "cadere",
    "cadran": "cadere",
    "cadranno": "cadere",
    "cadrebbe": "cadere",
    "cadrebber": "cadere",
    "cadrebbero": "cadere",
    "cadrei": "cadere",
    "cadremmo": "cadere",
    "cadremo": "cadere",
    "cadreste": "cadere",
    "cadresti": "cadere",
    "cadrete": "cadere",
    "cadrà": "cadere",
    "cadrò": "cadere",
    "caduca": "caduco",
    "caduche": "caduco",
    "caduci": "caduco",
    "caduta": "cadere",
    "cadute": "caduta",
    "caduti": "cadere",
    "caduto": "cadere",
    "caffa": "caffo",
    "caffe": "caffo",
    "caffeine": "caffeina",
    "caffetterie": "caffetteria",
    "caffettiere": "caffettiera",
    "caffi": "caffo",
    "cafonesca": "cafonesco",
    "cafonesche": "cafonesco",
    "cafoneschi": "cafonesco",
    "cafoni": "cafone",
    "caftani": "caftano",
    "caga": "cagare",
    "cagai": "cagare",
    "cagammo": "cagare",
    "cagan": "cagare",
    "cagando": "cagare",
    "cagano": "cagare",
    "cagante": "cagare",
    "caganti": "cagare",
    "cagar": "cagare",
    "cagaron": "cagare",
    "cagarono": "cagare",
    "cagasse": "cagare",
    "cagasser": "cagare",
    "cagassero": "cagare",
    "cagassi": "cagare",
    "cagassimo": "cagare",
    "cagaste": "cagare",
    "cagasti": "cagare",
    "cagata": "cagare",
    "cagate": "cagare",
    "cagati": "cagare",
    "cagato": "cagare",
    "cagava": "cagare",
    "cagavamo": "cagare",
    "cagavan": "cagare",
    "cagavano": "cagare",
    "cagavate": "cagare",
    "cagavi": "cagare",
    "cagavo": "cagare",
    "cagherai": "cagare",
    "cagheran": "cagare",
    "cagheranno": "cagare",
    "cagherebbe": "cagare",
    "cagherebber": "cagare",
    "cagherebbero": "cagare",
    "cagherei": "cagare",
    "cagheremmo": "cagare",
    "cagheremo": "cagare",
    "caghereste": "cagare",
    "cagheresti": "cagare",
    "cagherete": "cagare",
    "cagherà": "cagare",
    "cagherò": "cagare",
    "caghi": "cagare",
    "caghiamo": "cagare",
    "caghiate": "cagare",
    "caghin": "cagare",
    "caghino": "cagare",
    "cagiona": "cagionare",
    "cagionai": "cagionare",
    "cagionammo": "cagionare",
    "cagionan": "cagionare",
    "cagionando": "cagionare",
    "cagionano": "cagionare",
    "cagionante": "cagionare",
    "cagionanti": "cagionare",
    "cagionar": "cagionare",
    "cagionaron": "cagionare",
    "cagionarono": "cagionare",
    "cagionasse": "cagionare",
    "cagionasser": "cagionare",
    "cagionassero": "cagionare",
    "cagionassi": "cagionare",
    "cagionassimo": "cagionare",
    "cagionaste": "cagionare",
    "cagionasti": "cagionare",
    "cagionata": "cagionare",
    "cagionate": "cagionare",
    "cagionati": "cagionare",
    "cagionato": "cagionare",
    "cagionava": "cagionare",
    "cagionavamo": "cagionare",
    "cagionavan": "cagionare",
    "cagionavano": "cagionare",
    "cagionavate": "cagionare",
    "cagionavi": "cagionare",
    "cagionavo": "cagionare",
    "cagionerai": "cagionare",
    "cagioneran": "cagionare",
    "cagioneranno": "cagionare",
    "cagionerebbe": "cagionare",
    "cagionerebber": "cagionare",
    "cagionerebbero": "cagionare",
    "cagionerei": "cagionare",
    "cagioneremmo": "cagionare",
    "cagioneremo": "cagionare",
    "cagionereste": "cagionare",
    "cagioneresti": "cagionare",
    "cagionerete": "cagionare",
    "cagionerà": "cagionare",
    "cagionerò": "cagionare",
    "cagionevoli": "cagionevole",
    "cagioni": "cagionare",
    "cagioniamo": "cagionare",
    "cagioniate": "cagionare",
    "cagionin": "cagionare",
    "cagionino": "cagionare",
    "cagiono": "cagionare",
    "cagionò": "cagionare",
    "cagli": "cagliare",
    "caglia": "cagliare",
    "cagliai": "cagliare",
    "cagliammo": "cagliare",
    "cagliamo": "cagliare",
    "caglian": "cagliare",
    "cagliando": "cagliare",
    "cagliano": "cagliare",
    "cagliante": "cagliare",
    "caglianti": "cagliare",
    "cagliar": "cagliare",
    "cagliaritana": "cagliaritano",
    "cagliaritane": "cagliaritano",
    "cagliaritani": "cagliaritano",
    "cagliaron": "cagliare",
    "cagliarono": "cagliare",
    "cagliasse": "cagliare",
    "cagliasser": "cagliare",
    "cagliassero": "cagliare",
    "cagliassi": "cagliare",
    "cagliassimo": "cagliare",
    "cagliaste": "cagliare",
    "cagliasti": "cagliare",
    "cagliata": "cagliare",
    "cagliate": "cagliare",
    "cagliati": "cagliare",
    "cagliato": "cagliare",
    "cagliava": "cagliare",
    "cagliavamo": "cagliare",
    "cagliavan": "cagliare",
    "cagliavano": "cagliare",
    "cagliavate": "cagliare",
    "cagliavi": "cagliare",
    "cagliavo": "cagliare",
    "caglierai": "cagliare",
    "caglieran": "cagliare",
    "caglieranno": "cagliare",
    "caglierebbe": "cagliare",
    "caglierebber": "cagliare",
    "caglierebbero": "cagliare",
    "caglierei": "cagliare",
    "caglieremmo": "cagliare",
    "caglieremo": "cagliare",
    "cagliereste": "cagliare",
    "caglieresti": "cagliare",
    "caglierete": "cagliare",
    "caglierà": "cagliare",
    "caglierò": "cagliare",
    "caglin": "cagliare",
    "caglino": "cagliare",
    "caglio": "cagliare",
    "cagliò": "cagliare",
    "cagne": "cagna",
    "cagnesca": "cagnesco",
    "cagnesche": "cagnesco",
    "cagneschi": "cagnesco",
    "cagnette": "cagnetta",
    "cagnetti": "cagnetto",
    "cagnolini": "cagnolino",
    "cagnoni": "cagnone",
    "cago": "cagare",
    "cagò": "cagare",
    "caimani": "caimano",
    "cairote": "cairota",
    "cairoti": "cairota",
    "cala": "calere",
    "calabra": "calabro",
    "calabre": "calabro",
    "calabresi": "calabrese",
    "calabri": "calabro",
    "calabroni": "calabrone",
    "calafata": "calafatare",
    "calafatai": "calafatare",
    "calafatammo": "calafatare",
    "calafatan": "calafatare",
    "calafatando": "calafatare",
    "calafatano": "calafatare",
    "calafatante": "calafatare",
    "calafatanti": "calafatare",
    "calafatar": "calafatare",
    "calafataron": "calafatare",
    "calafatarono": "calafatare",
    "calafatasse": "calafatare",
    "calafatasser": "calafatare",
    "calafatassero": "calafatare",
    "calafatassi": "calafatare",
    "calafatassimo": "calafatare",
    "calafataste": "calafatare",
    "calafatasti": "calafatare",
    "calafatata": "calafatare",
    "calafatate": "calafatare",
    "calafatati": "calafatare",
    "calafatato": "calafatare",
    "calafatava": "calafatare",
    "calafatavamo": "calafatare",
    "calafatavan": "calafatare",
    "calafatavano": "calafatare",
    "calafatavate": "calafatare",
    "calafatavi": "calafatare",
    "calafatavo": "calafatare",
    "calafaterai": "calafatare",
    "calafateran": "calafatare",
    "calafateranno": "calafatare",
    "calafaterebbe": "calafatare",
    "calafaterebber": "calafatare",
    "calafaterebbero": "calafatare",
    "calafaterei": "calafatare",
    "calafateremmo": "calafatare",
    "calafateremo": "calafatare",
    "calafatereste": "calafatare",
    "calafateresti": "calafatare",
    "calafaterete": "calafatare",
    "calafaterà": "calafatare",
    "calafaterò": "calafatare",
    "calafati": "calafatare",
    "calafatiamo": "calafatare",
    "calafatiate": "calafatare",
    "calafatin": "calafatare",
    "calafatino": "calafatare",
    "calafato": "calafatare",
    "calafatò": "calafatare",
    "calai": "calare",
    "calamai": "calamaio",
    "calamari": "calamaro",
    "calamita": "calamitare",
    "calamitai": "calamitare",
    "calamitammo": "calamitare",
    "calamitan": "calamitare",
    "calamitando": "calamitare",
    "calamitano": "calamitare",
    "calamitante": "calamitare",
    "calamitanti": "calamitare",
    "calamitar": "calamitare",
    "calamitaron": "calamitare",
    "calamitarono": "calamitare",
    "calamitasse": "calamitare",
    "calamitasser": "calamitare",
    "calamitassero": "calamitare",
    "calamitassi": "calamitare",
    "calamitassimo": "calamitare",
    "calamitaste": "calamitare",
    "calamitasti": "calamitare",
    "calamitata": "calamitato",
    "calamitate": "calamitato",
    "calamitati": "calamitato",
    "calamitato": "calamitare",
    "calamitava": "calamitare",
    "calamitavamo": "calamitare",
    "calamitavan": "calamitare",
    "calamitavano": "calamitare",
    "calamitavate": "calamitare",
    "calamitavi": "calamitare",
    "calamitavo": "calamitare",
    "calamite": "calamita",
    "calamiterai": "calamitare",
    "calamiteran": "calamitare",
    "calamiteranno": "calamitare",
    "calamiterebbe": "calamitare",
    "calamiterebber": "calamitare",
    "calamiterebbero": "calamitare",
    "calamiterei": "calamitare",
    "calamiteremmo": "calamitare",
    "calamiteremo": "calamitare",
    "calamitereste": "calamitare",
    "calamiteresti": "calamitare",
    "calamiterete": "calamitare",
    "calamiterà": "calamitare",
    "calamiterò": "calamitare",
    "calamiti": "calamitare",
    "calamitiamo": "calamitare",
    "calamitiate": "calamitare",
    "calamitin": "calamitare",
    "calamitino": "calamitare",
    "calamito": "calamitare",
    "calamitosa": "calamitoso",
    "calamitose": "calamitoso",
    "calamitosi": "calamitoso",
    "calamitò": "calamitare",
    "calammo": "calare",
    "calan": "calere",
    "calando": "calare",
    "calandra": "calandrare",
    "calandrai": "calandrare",
    "calandrammo": "calandrare",
    "calandran": "calandrare",
    "calandrando": "calandrare",
    "calandrano": "calandrare",
    "calandrante": "calandrare",
    "calandranti": "calandrare",
    "calandrar": "calandrare",
    "calandraron": "calandrare",
    "calandrarono": "calandrare",
    "calandrasse": "calandrare",
    "calandrasser": "calandrare",
    "calandrassero": "calandrare",
    "calandrassi": "calandrare",
    "calandrassimo": "calandrare",
    "calandraste": "calandrare",
    "calandrasti": "calandrare",
    "calandrata": "calandrare",
    "calandrate": "calandrare",
    "calandrati": "calandrare",
    "calandrato": "calandrare",
    "calandrava": "calandrare",
    "calandravamo": "calandrare",
    "calandravan": "calandrare",
    "calandravano": "calandrare",
    "calandravate": "calandrare",
    "calandravi": "calandrare",
    "calandravo": "calandrare",
    "calandre": "calandra",
    "calandrerai": "calandrare",
    "calandreran": "calandrare",
    "calandreranno": "calandrare",
    "calandrerebbe": "calandrare",
    "calandrerebber": "calandrare",
    "calandrerebbero": "calandrare",
    "calandrerei": "calandrare",
    "calandreremmo": "calandrare",
    "calandreremo": "calandrare",
    "calandrereste": "calandrare",
    "calandreresti": "calandrare",
    "calandrerete": "calandrare",
    "calandrerà": "calandrare",
    "calandrerò": "calandrare",
    "calandri": "calandrare",
    "calandriamo": "calandrare",
    "calandriate": "calandrare",
    "calandrin": "calandrare",
    "calandrino": "calandrare",
    "calandro": "calandrare",
    "calandrò": "calandrare",
    "calano": "calere",
    "calante": "calare",
    "calanti": "calare",
    "calar": "calare",
    "calaron": "calare",
    "calarono": "calare",
    "calasse": "calare",
    "calasser": "calare",
    "calassero": "calare",
    "calassi": "calare",
    "calassimo": "calare",
    "calaste": "calare",
    "calasti": "calare",
    "calata": "calare",
    "calate": "calata",
    "calati": "calare",
    "calato": "calare",
    "calava": "calare",
    "calavamo": "calare",
    "calavan": "calare",
    "calavano": "calare",
    "calavate": "calare",
    "calavi": "calare",
    "calavo": "calare",
    "calca": "calcare",
    "calcagna": "calcagno",
    "calcagni": "calcagno",
    "calcai": "calcare",
    "calcammo": "calcare",
    "calcan": "calcare",
    "calcando": "calcare",
    "calcano": "calcare",
    "calcante": "calcare",
    "calcanti": "calcare",
    "calcar": "calcare",
    "calcarea": "calcareo",
    "calcaree": "calcareo",
    "calcarei": "calcareo",
    "calcaron": "calcare",
    "calcarono": "calcare",
    "calcasse": "calcare",
    "calcasser": "calcare",
    "calcassero": "calcare",
    "calcassi": "calcare",
    "calcassimo": "calcare",
    "calcaste": "calcare",
    "calcasti": "calcare",
    "calcata": "calcare",
    "calcate": "calcare",
    "calcati": "calcare",
    "calcato": "calcare",
    "calcava": "calcare",
    "calcavamo": "calcare",
    "calcavan": "calcare",
    "calcavano": "calcare",
    "calcavate": "calcare",
    "calcavi": "calcare",
    "calcavo": "calcare",
    "calcerai": "calciare",
    "calceran": "calciare",
    "calceranno": "calciare",
    "calcerebbe": "calciare",
    "calcerebber": "calciare",
    "calcerebbero": "calciare",
    "calcerei": "calciare",
    "calceremmo": "calciare",
    "calceremo": "calciare",
    "calcereste": "calciare",
    "calceresti": "calciare",
    "calcerete": "calciare",
    "calcerà": "calciare",
    "calcerò": "calciare",
    "calcestruzzi": "calcestruzzo",
    "calcetti": "calcetto",
    "calche": "calca",
    "calcherai": "calcare",
    "calcheran": "calcare",
    "calcheranno": "calcare",
    "calcherebbe": "calcare",
    "calcherebber": "calcare",
    "calcherebbero": "calcare",
    "calcherei": "calcare",
    "calcheremmo": "calcare",
    "calcheremo": "calcare",
    "calchereste": "calcare",
    "calcheresti": "calcare",
    "calcherete": "calcare",
    "calcherà": "calcare",
    "calcherò": "calcare",
    "calchi": "calco",
    "calchiamo": "calcare",
    "calchiate": "calcare",
    "calchin": "calcare",
    "calchino": "calcare",
    "calci": "calcio",
    "calcia": "calciare",
    "calciai": "calciare",
    "calciammo": "calciare",
    "calciamo": "calciare",
    "calcian": "calciare",
    "calciando": "calciare",
    "calciano": "calciare",
    "calciante": "calciare",
    "calcianti": "calciare",
    "calciar": "calciare",
    "calciaron": "calciare",
    "calciarono": "calciare",
    "calciasse": "calciare",
    "calciasser": "calciare",
    "calciassero": "calciare",
    "calciassi": "calciare",
    "calciassimo": "calciare",
    "calciaste": "calciare",
    "calciasti": "calciare",
    "calciata": "calciare",
    "calciate": "calciare",
    "calciati": "calciare",
    "calciato": "calciare",
    "calciatori": "calciatore",
    "calciatrici": "calciatrice",
    "calciava": "calciare",
    "calciavamo": "calciare",
    "calciavan": "calciare",
    "calciavano": "calciare",
    "calciavate": "calciare",
    "calciavi": "calciare",
    "calciavo": "calciare",
    "calcifica": "calcificare",
    "calcificai": "calcificare",
    "calcificammo": "calcificare",
    "calcifican": "calcificare",
    "calcificando": "calcificare",
    "calcificano": "calcificare",
    "calcificante": "calcificare",
    "calcificanti": "calcificare",
    "calcificar": "calcificare",
    "calcificaron": "calcificare",
    "calcificarono": "calcificare",
    "calcificasse": "calcificare",
    "calcificasser": "calcificare",
    "calcificassero": "calcificare",
    "calcificassi": "calcificare",
    "calcificassimo": "calcificare",
    "calcificaste": "calcificare",
    "calcificasti": "calcificare",
    "calcificata": "calcificare",
    "calcificate": "calcificare",
    "calcificati": "calcificare",
    "calcificato": "calcificare",
    "calcificava": "calcificare",
    "calcificavamo": "calcificare",
    "calcificavan": "calcificare",
    "calcificavano": "calcificare",
    "calcificavate": "calcificare",
    "calcificavi": "calcificare",
    "calcificavo": "calcificare",
    "calcificazioni": "calcificazione",
    "calcificherai": "calcificare",
    "calcificheran": "calcificare",
    "calcificheranno": "calcificare",
    "calcificherebbe": "calcificare",
    "calcificherebber": "calcificare",
    "calcificherebbero": "calcificare",
    "calcificherei": "calcificare",
    "calcificheremmo": "calcificare",
    "calcificheremo": "calcificare",
    "calcifichereste": "calcificare",
    "calcificheresti": "calcificare",
    "calcificherete": "calcificare",
    "calcificherà": "calcificare",
    "calcificherò": "calcificare",
    "calcifichi": "calcificare",
    "calcifichiamo": "calcificare",
    "calcifichiate": "calcificare",
    "calcifichin": "calcificare",
    "calcifichino": "calcificare",
    "calcifico": "calcificare",
    "calcificò": "calcificare",
    "calcin": "calciare",
    "calcina": "calcinare",
    "calcinacci": "calcinaccio",
    "calcinai": "calcinare",
    "calcinammo": "calcinare",
    "calcinan": "calcinare",
    "calcinando": "calcinare",
    "calcinano": "calcinare",
    "calcinante": "calcinare",
    "calcinanti": "calcinare",
    "calcinar": "calcinare",
    "calcinaron": "calcinare",
    "calcinarono": "calcinare",
    "calcinasse": "calcinare",
    "calcinasser": "calcinare",
    "calcinassero": "calcinare",
    "calcinassi": "calcinare",
    "calcinassimo": "calcinare",
    "calcinaste": "calcinare",
    "calcinasti": "calcinare",
    "calcinata": "calcinato",
    "calcinate": "calcinato",
    "calcinati": "calcinato",
    "calcinato": "calcinare",
    "calcinava": "calcinare",
    "calcinavamo": "calcinare",
    "calcinavan": "calcinare",
    "calcinavano": "calcinare",
    "calcinavate": "calcinare",
    "calcinavi": "calcinare",
    "calcinavo": "calcinare",
    "calcinerai": "calcinare",
    "calcineran": "calcinare",
    "calcineranno": "calcinare",
    "calcinerebbe": "calcinare",
    "calcinerebber": "calcinare",
    "calcinerebbero": "calcinare",
    "calcinerei": "calcinare",
    "calcineremmo": "calcinare",
    "calcineremo": "calcinare",
    "calcinereste": "calcinare",
    "calcineresti": "calcinare",
    "calcinerete": "calcinare",
    "calcinerà": "calcinare",
    "calcinerò": "calcinare",
    "calcini": "calcinare",
    "calciniamo": "calcinare",
    "calciniate": "calcinare",
    "calcinin": "calcinare",
    "calcinino": "calcinare",
    "calcino": "calcinare",
    "calcinò": "calcinare",
    "calcio": "calciare",
    "calciofili": "calciofilo",
    "calciomercati": "calciomercato",
    "calcioni": "calcione",
    "calcistica": "calcistico",
    "calcistiche": "calcistico",
    "calcistici": "calcistico",
    "calciò": "calciare",
    "calco": "calcare",
    "calcografica": "calcografico",
    "calcografiche": "calcografico",
    "calcografici": "calcografico",
    "calcola": "calcolare",
    "calcolabili": "calcolabile",
    "calcolai": "calcolare",
    "calcolammo": "calcolare",
    "calcolan": "calcolare",
    "calcolando": "calcolare",
    "calcolano": "calcolare",
    "calcolante": "calcolare",
    "calcolanti": "calcolare",
    "calcolar": "calcolare",
    "calcolaron": "calcolare",
    "calcolarono": "calcolare",
    "calcolasse": "calcolare",
    "calcolasser": "calcolare",
    "calcolassero": "calcolare",
    "calcolassi": "calcolare",
    "calcolassimo": "calcolare",
    "calcolaste": "calcolare",
    "calcolasti": "calcolare",
    "calcolata": "calcolare",
    "calcolate": "calcolare",
    "calcolati": "calcolare",
    "calcolato": "calcolare",
    "calcolatori": "calcolatore",
    "calcolatrice": "calcolatore",
    "calcolatrici": "calcolatrice",
    "calcolava": "calcolare",
    "calcolavamo": "calcolare",
    "calcolavan": "calcolare",
    "calcolavano": "calcolare",
    "calcolavate": "calcolare",
    "calcolavi": "calcolare",
    "calcolavo": "calcolare",
    "calcolerai": "calcolare",
    "calcoleran": "calcolare",
    "calcoleranno": "calcolare",
    "calcolerebbe": "calcolare",
    "calcolerebber": "calcolare",
    "calcolerebbero": "calcolare",
    "calcolerei": "calcolare",
    "calcoleremmo": "calcolare",
    "calcoleremo": "calcolare",
    "calcolereste": "calcolare",
    "calcoleresti": "calcolare",
    "calcolerete": "calcolare",
    "calcolerà": "calcolare",
    "calcolerò": "calcolare",
    "calcoli": "calcolo",
    "calcoliamo": "calcolare",
    "calcoliate": "calcolare",
    "calcolin": "calcolare",
    "calcolino": "calcolare",
    "calcolo": "calcolare",
    "calcolò": "calcolare",
    "calcò": "calcare",
    "calda": "caldo",
    "caldaie": "caldaia",
    "calde": "caldo",
    "caldeggerai": "caldeggiare",
    "caldeggeran": "caldeggiare",
    "caldeggeranno": "caldeggiare",
    "caldeggerebbe": "caldeggiare",
    "caldeggerebber": "caldeggiare",
    "caldeggerebbero": "caldeggiare",
    "caldeggerei": "caldeggiare",
    "caldeggeremmo": "caldeggiare",
    "caldeggeremo": "caldeggiare",
    "caldeggereste": "caldeggiare",
    "caldeggeresti": "caldeggiare",
    "caldeggerete": "caldeggiare",
    "caldeggerà": "caldeggiare",
    "caldeggerò": "caldeggiare",
    "caldeggi": "caldeggiare",
    "caldeggia": "caldeggiare",
    "caldeggiai": "caldeggiare",
    "caldeggiammo": "caldeggiare",
    "caldeggiamo": "caldeggiare",
    "caldeggian": "caldeggiare",
    "caldeggiando": "caldeggiare",
    "caldeggiano": "caldeggiare",
    "caldeggiante": "caldeggiare",
    "caldeggianti": "caldeggiare",
    "caldeggiar": "caldeggiare",
    "caldeggiaron": "caldeggiare",
    "caldeggiarono": "caldeggiare",
    "caldeggiasse": "caldeggiare",
    "caldeggiasser": "caldeggiare",
    "caldeggiassero": "caldeggiare",
    "caldeggiassi": "caldeggiare",
    "caldeggiassimo": "caldeggiare",
    "caldeggiaste": "caldeggiare",
    "caldeggiasti": "caldeggiare",
    "caldeggiata": "caldeggiare",
    "caldeggiate": "caldeggiare",
    "caldeggiati": "caldeggiare",
    "caldeggiato": "caldeggiare",
    "caldeggiava": "caldeggiare",
    "caldeggiavamo": "caldeggiare",
    "caldeggiavan": "caldeggiare",
    "caldeggiavano": "caldeggiare",
    "caldeggiavate": "caldeggiare",
    "caldeggiavi": "caldeggiare",
    "caldeggiavo": "caldeggiare",
    "caldeggin": "caldeggiare",
    "caldeggino": "caldeggiare",
    "caldeggio": "caldeggiare",
    "caldeggiò": "caldeggiare",
    "calderoni": "calderone",
    "caldi": "caldo",
    "cale": "calere",
    "calei": "calere",
    "caleidoscopi": "caleidoscopio",
    "calemmo": "calere",
    "calendari": "calendario",
    "calendarizza": "calendarizzare",
    "calendarizzai": "calendarizzare",
    "calendarizzammo": "calendarizzare",
    "calendarizzan": "calendarizzare",
    "calendarizzando": "calendarizzare",
    "calendarizzano": "calendarizzare",
    "calendarizzante": "calendarizzare",
    "calendarizzanti": "calendarizzare",
    "calendarizzar": "calendarizzare",
    "calendarizzaron": "calendarizzare",
    "calendarizzarono": "calendarizzare",
    "calendarizzasse": "calendarizzare",
    "calendarizzasser": "calendarizzare",
    "calendarizzassero": "calendarizzare",
    "calendarizzassi": "calendarizzare",
    "calendarizzassimo": "calendarizzare",
    "calendarizzaste": "calendarizzare",
    "calendarizzasti": "calendarizzare",
    "calendarizzata": "calendarizzare",
    "calendarizzate": "calendarizzare",
    "calendarizzati": "calendarizzare",
    "calendarizzato": "calendarizzare",
    "calendarizzava": "calendarizzare",
    "calendarizzavamo": "calendarizzare",
    "calendarizzavan": "calendarizzare",
    "calendarizzavano": "calendarizzare",
    "calendarizzavate": "calendarizzare",
    "calendarizzavi": "calendarizzare",
    "calendarizzavo": "calendarizzare",
    "calendarizzerai": "calendarizzare",
    "calendarizzeran": "calendarizzare",
    "calendarizzeranno": "calendarizzare",
    "calendarizzerebbe": "calendarizzare",
    "calendarizzerebber": "calendarizzare",
    "calendarizzerebbero": "calendarizzare",
    "calendarizzerei": "calendarizzare",
    "calendarizzeremmo": "calendarizzare",
    "calendarizzeremo": "calendarizzare",
    "calendarizzereste": "calendarizzare",
    "calendarizzeresti": "calendarizzare",
    "calendarizzerete": "calendarizzare",
    "calendarizzerà": "calendarizzare",
    "calendarizzerò": "calendarizzare",
    "calendarizzi": "calendarizzare",
    "calendarizziamo": "calendarizzare",
    "calendarizziate": "calendarizzare",
    "calendarizzin": "calendarizzare",
    "calendarizzino": "calendarizzare",
    "calendarizzo": "calendarizzare",
    "calendarizzò": "calendarizzare",
    "calendo": "calere",
    "calente": "calere",
    "calenti": "calere",
    "caler": "calere",
    "calerai": "calere",
    "caleran": "calere",
    "caleranno": "calere",
    "calerebbe": "calere",
    "calerebber": "calere",
    "calerebbero": "calere",
    "calerei": "calere",
    "caleremmo": "calere",
    "caleremo": "calere",
    "calereste": "calere",
    "caleresti": "calere",
    "calerete": "calere",
    "caleron": "calere",
    "calerono": "calere",
    "calerà": "calere",
    "calerò": "calere",
    "calesse": "calere",
    "calesser": "calere",
    "calessero": "calere",
    "calessi": "calesse",
    "calessimo": "calere",
    "caleste": "calere",
    "calesti": "calere",
    "calete": "calere",
    "caletta": "calettare",
    "calettai": "calettare",
    "calettammo": "calettare",
    "calettan": "calettare",
    "calettando": "calettare",
    "calettano": "calettare",
    "calettante": "calettare",
    "calettanti": "calettare",
    "calettar": "calettare",
    "calettaron": "calettare",
    "calettarono": "calettare",
    "calettasse": "calettare",
    "calettasser": "calettare",
    "calettassero": "calettare",
    "calettassi": "calettare",
    "calettassimo": "calettare",
    "calettaste": "calettare",
    "calettasti": "calettare",
    "calettata": "calettare",
    "calettate": "calettare",
    "calettati": "calettare",
    "calettato": "calettare",
    "calettava": "calettare",
    "calettavamo": "calettare",
    "calettavan": "calettare",
    "calettavano": "calettare",
    "calettavate": "calettare",
    "calettavi": "calettare",
    "calettavo": "calettare",
    "calette": "caletta",
    "caletterai": "calettare",
    "caletteran": "calettare",
    "caletteranno": "calettare",
    "caletterebbe": "calettare",
    "caletterebber": "calettare",
    "caletterebbero": "calettare",
    "caletterei": "calettare",
    "caletteremmo": "calettare",
    "caletteremo": "calettare",
    "calettereste": "calettare",
    "caletteresti": "calettare",
    "caletterete": "calettare",
    "caletterà": "calettare",
    "caletterò": "calettare",
    "caletti": "calettare",
    "calettiamo": "calettare",
    "calettiate": "calettare",
    "calettin": "calettare",
    "calettino": "calettare",
    "caletto": "calettare",
    "calettò": "calettare",
    "caleva": "calere",
    "calevamo": "calere",
    "calevan": "calere",
    "calevano": "calere",
    "calevate": "calere",
    "calevi": "calere",
    "calevo": "calere",
    "cali": "calo",
    "caliamo": "calere",
    "caliate": "calere",
    "calibra": "calibrare",
    "calibrai": "calibrare",
    "calibrammo": "calibrare",
    "calibran": "calibrare",
    "calibrando": "calibrare",
    "calibrano": "calibrare",
    "calibrante": "calibrare",
    "calibranti": "calibrare",
    "calibrar": "calibrare",
    "calibraron": "calibrare",
    "calibrarono": "calibrare",
    "calibrasse": "calibrare",
    "calibrasser": "calibrare",
    "calibrassero": "calibrare",
    "calibrassi": "calibrare",
    "calibrassimo": "calibrare",
    "calibraste": "calibrare",
    "calibrasti": "calibrare",
    "calibrata": "calibrare",
    "calibrate": "calibrare",
    "calibrati": "calibrare",
    "calibrato": "calibrare",
    "calibrava": "calibrare",
    "calibravamo": "calibrare",
    "calibravan": "calibrare",
    "calibravano": "calibrare",
    "calibravate": "calibrare",
    "calibravi": "calibrare",
    "calibravo": "calibrare",
    "calibrerai": "calibrare",
    "calibreran": "calibrare",
    "calibreranno": "calibrare",
    "calibrerebbe": "calibrare",
    "calibrerebber": "calibrare",
    "calibrerebbero": "calibrare",
    "calibrerei": "calibrare",
    "calibreremmo": "calibrare",
    "calibreremo": "calibrare",
    "calibrereste": "calibrare",
    "calibreresti": "calibrare",
    "calibrerete": "calibrare",
    "calibrerà": "calibrare",
    "calibrerò": "calibrare",
    "calibri": "calibro",
    "calibriamo": "calibrare",
    "calibriate": "calibrare",
    "calibrin": "calibrare",
    "calibrino": "calibrare",
    "calibro": "calibrare",
    "calibrò": "calibrare",
    "calici": "calice",
    "califfi": "califfo",
    "californiana": "californiano",
    "californiane": "californiano",
    "californiani": "californiano",
    "caliginosa": "caliginoso",
    "caliginose": "caliginoso",
    "caliginosi": "caliginoso",
    "calin": "calare",
    "calino": "calare",
    "calli": "callo",
    "calligrafi": "calligrafo",
    "calligrafica": "calligrafico",
    "calligrafiche": "calligrafico",
    "calligrafici": "calligrafico",
    "calligrafie": "calligrafia",
    "calma": "calmo",
    "calmai": "calmare",
    "calmammo": "calmare",
    "calman": "calmare",
    "calmando": "calmare",
    "calmano": "calmare",
    "calmante": "calmare",
    "calmanti": "calmare",
    "calmar": "calmare",
    "calmaron": "calmare",
    "calmarono": "calmare",
    "calmasse": "calmare",
    "calmasser": "calmare",
    "calmassero": "calmare",
    "calmassi": "calmare",
    "calmassimo": "calmare",
    "calmaste": "calmare",
    "calmasti": "calmare",
    "calmata": "calmare",
    "calmate": "calmare",
    "calmati": "calmare",
    "calmato": "calmare",
    "calmava": "calmare",
    "calmavamo": "calmare",
    "calmavan": "calmare",
    "calmavano": "calmare",
    "calmavate": "calmare",
    "calmavi": "calmare",
    "calmavo": "calmare",
    "calme": "calmo",
    "calmerai": "calmare",
    "calmeran": "calmare",
    "calmeranno": "calmare",
    "calmerebbe": "calmare",
    "calmerebber": "calmare",
    "calmerebbero": "calmare",
    "calmerei": "calmare",
    "calmeremmo": "calmare",
    "calmeremo": "calmare",
    "calmereste": "calmare",
    "calmeresti": "calmare",
    "calmerete": "calmare",
    "calmerà": "calmare",
    "calmerò": "calmare",
    "calmi": "calmo",
    "calmiamo": "calmare",
    "calmiate": "calmare",
    "calmiera": "calmierare",
    "calmierai": "calmierare",
    "calmierammo": "calmierare",
    "calmieran": "calmierare",
    "calmierando": "calmierare",
    "calmierano": "calmierare",
    "calmierante": "calmierare",
    "calmieranti": "calmierare",
    "calmierar": "calmierare",
    "calmieraron": "calmierare",
    "calmierarono": "calmierare",
    "calmierasse": "calmierare",
    "calmierasser": "calmierare",
    "calmierassero": "calmierare",
    "calmierassi": "calmierare",
    "calmierassimo": "calmierare",
    "calmieraste": "calmierare",
    "calmierasti": "calmierare",
    "calmierata": "calmierare",
    "calmierate": "calmierare",
    "calmierati": "calmierare",
    "calmierato": "calmierare",
    "calmierava": "calmierare",
    "calmieravamo": "calmierare",
    "calmieravan": "calmierare",
    "calmieravano": "calmierare",
    "calmieravate": "calmierare",
    "calmieravi": "calmierare",
    "calmieravo": "calmierare",
    "calmiererai": "calmierare",
    "calmiereran": "calmierare",
    "calmiereranno": "calmierare",
    "calmiererebbe": "calmierare",
    "calmiererebber": "calmierare",
    "calmiererebbero": "calmierare",
    "calmiererei": "calmierare",
    "calmiereremmo": "calmierare",
    "calmiereremo": "calmierare",
    "calmierereste": "calmierare",
    "calmiereresti": "calmierare",
    "calmiererete": "calmierare",
    "calmiererà": "calmierare",
    "calmiererò": "calmierare",
    "calmieri": "calmiere",
    "calmieriamo": "calmierare",
    "calmieriate": "calmierare",
    "calmierin": "calmierare",
    "calmierino": "calmierare",
    "calmiero": "calmierare",
    "calmierò": "calmierare",
    "calmin": "calmare",
    "calmino": "calmare",
    "calmo": "calmare",
    "calmò": "calmare",
    "calo": "calere",
    "calon": "calere",
    "calono": "calere",
    "calori": "calore",
    "calorica": "calorico",
    "caloriche": "calorico",
    "calorici": "calorico",
    "calorie": "caloria",
    "caloriferi": "calorifero",
    "calorosa": "caloroso",
    "calorose": "caloroso",
    "calorosi": "caloroso",
    "calotte": "calotta",
    "calpesta": "calpestare",
    "calpestai": "calpestare",
    "calpestammo": "calpestare",
    "calpestan": "calpestare",
    "calpestando": "calpestare",
    "calpestano": "calpestare",
    "calpestante": "calpestare",
    "calpestanti": "calpestare",
    "calpestar": "calpestare",
    "calpestaron": "calpestare",
    "calpestarono": "calpestare",
    "calpestasse": "calpestare",
    "calpestasser": "calpestare",
    "calpestassero": "calpestare",
    "calpestassi": "calpestare",
    "calpestassimo": "calpestare",
    "calpestaste": "calpestare",
    "calpestasti": "calpestare",
    "calpestata": "calpestare",
    "calpestate": "calpestare",
    "calpestati": "calpestare",
    "calpestato": "calpestare",
    "calpestava": "calpestare",
    "calpestavamo": "calpestare",
    "calpestavan": "calpestare",
    "calpestavano": "calpestare",
    "calpestavate": "calpestare",
    "calpestavi": "calpestare",
    "calpestavo": "calpestare",
    "calpesterai": "calpestare",
    "calpesteran": "calpestare",
    "calpesteranno": "calpestare",
    "calpesterebbe": "calpestare",
    "calpesterebber": "calpestare",
    "calpesterebbero": "calpestare",
    "calpesterei": "calpestare",
    "calpesteremmo": "calpestare",
    "calpesteremo": "calpestare",
    "calpestereste": "calpestare",
    "calpesteresti": "calpestare",
    "calpesterete": "calpestare",
    "calpesterà": "calpestare",
    "calpesterò": "calpestare",
    "calpesti": "calpestare",
    "calpestiamo": "calpestare",
    "calpestiate": "calpestare",
    "calpestin": "calpestare",
    "calpestino": "calpestare",
    "calpesto": "calpestare",
    "calpestò": "calpestare",
    "calunni": "calunniare",
    "calunnia": "calunniare",
    "calunniai": "calunniare",
    "calunniammo": "calunniare",
    "calunniamo": "calunniare",
    "calunnian": "calunniare",
    "calunniando": "calunniare",
    "calunniano": "calunniare",
    "calunniante": "calunniare",
    "calunnianti": "calunniare",
    "calunniar": "calunniare",
    "calunniaron": "calunniare",
    "calunniarono": "calunniare",
    "calunniasse": "calunniare",
    "calunniasser": "calunniare",
    "calunniassero": "calunniare",
    "calunniassi": "calunniare",
    "calunniassimo": "calunniare",
    "calunniaste": "calunniare",
    "calunniasti": "calunniare",
    "calunniata": "calunniare",
    "calunniate": "calunniare",
    "calunniati": "calunniare",
    "calunniato": "calunniare",
    "calunniatori": "calunniatore",
    "calunniatrice": "calunniatore",
    "calunniatrici": "calunniatore",
    "calunniava": "calunniare",
    "calunniavamo": "calunniare",
    "calunniavan": "calunniare",
    "calunniavano": "calunniare",
    "calunniavate": "calunniare",
    "calunniavi": "calunniare",
    "calunniavo": "calunniare",
    "calunnie": "calunnia",
    "calunnierai": "calunniare",
    "calunnieran": "calunniare",
    "calunnieranno": "calunniare",
    "calunnierebbe": "calunniare",
    "calunnierebber": "calunniare",
    "calunnierebbero": "calunniare",
    "calunnierei": "calunniare",
    "calunnieremmo": "calunniare",
    "calunnieremo": "calunniare",
    "calunniereste": "calunniare",
    "calunnieresti": "calunniare",
    "calunnierete": "calunniare",
    "calunnierà": "calunniare",
    "calunnierò": "calunniare",
    "calunnin": "calunniare",
    "calunnino": "calunniare",
    "calunnio": "calunniare",
    "calunniosa": "calunnioso",
    "calunniose": "calunnioso",
    "calunniosi": "calunnioso",
    "calunniò": "calunniare",
    "calure": "calura",
    "caluta": "calere",
    "calute": "calere",
    "caluti": "calere",
    "caluto": "calere",
    "calva": "calvo",
    "calvari": "calvario",
    "calve": "calvo",
    "calvi": "calvo",
    "calviniste": "calvinista",
    "calvinisti": "calvinista",
    "calza": "calzare",
    "calzai": "calzare",
    "calzamaglie": "calzamaglia",
    "calzammo": "calzare",
    "calzan": "calzare",
    "calzando": "calzare",
    "calzano": "calzare",
    "calzante": "calzare",
    "calzanti": "calzare",
    "calzar": "calzare",
    "calzaron": "calzare",
    "calzarono": "calzare",
    "calzasse": "calzare",
    "calzasser": "calzare",
    "calzassero": "calzare",
    "calzassi": "calzare",
    "calzassimo": "calzare",
    "calzaste": "calzare",
    "calzasti": "calzare",
    "calzata": "calzare",
    "calzate": "calzare",
    "calzati": "calzare",
    "calzato": "calzare",
    "calzature": "calzatura",
    "calzaturiera": "calzaturiero",
    "calzaturiere": "calzaturiero",
    "calzaturieri": "calzaturiero",
    "calzaturifici": "calzaturificio",
    "calzava": "calzare",
    "calzavamo": "calzare",
    "calzavan": "calzare",
    "calzavano": "calzare",
    "calzavate": "calzare",
    "calzavi": "calzare",
    "calzavo": "calzare",
    "calze": "calza",
    "calzerai": "calzare",
    "calzeran": "calzare",
    "calzeranno": "calzare",
    "calzerebbe": "calzare",
    "calzerebber": "calzare",
    "calzerebbero": "calzare",
    "calzerei": "calzare",
    "calzeremmo": "calzare",
    "calzeremo": "calzare",
    "calzereste": "calzare",
    "calzeresti": "calzare",
    "calzerete": "calzare",
    "calzerotti": "calzerotto",
    "calzerà": "calzare",
    "calzerò": "calzare",
    "calzette": "calzetta",
    "calzettoni": "calzettone",
    "calzi": "calzare",
    "calziamo": "calzare",
    "calziate": "calzare",
    "calzin": "calzare",
    "calzini": "calzino",
    "calzino": "calzare",
    "calzo": "calzare",
    "calzolai": "calzolaio",
    "calzoncini": "calzoncino",
    "calzoni": "calzone",
    "calzò": "calzare",
    "calè": "calere",
    "calò": "calare",
    "camaldolesi": "camaldolese",
    "camaleonti": "camaleonte",
    "camaleontica": "camaleontico",
    "camaleontiche": "camaleontico",
    "camaleontici": "camaleontico",
    "camalli": "camallo",
    "camarille": "camarilla",
    "cambi": "cambio",
    "cambia": "cambiare",
    "cambiai": "cambiare",
    "cambiali": "cambiale",
    "cambiamenti": "cambiamento",
    "cambiammo": "cambiare",
    "cambiamo": "cambiare",
    "cambian": "cambiare",
    "cambiando": "cambiare",
    "cambiano": "cambiare",
    "cambiante": "cambiare",
    "cambianti": "cambiare",
    "cambiar": "cambiare",
    "cambiari": "cambiario",
    "cambiaria": "cambiario",
    "cambiarie": "cambiario",
    "cambiaron": "cambiare",
    "cambiarono": "cambiare",
    "cambiasse": "cambiare",
    "cambiasser": "cambiare",
    "cambiassero": "cambiare",
    "cambiassi": "cambiare",
    "cambiassimo": "cambiare",
    "cambiaste": "cambiare",
    "cambiasti": "cambiare",
    "cambiata": "cambiare",
    "cambiate": "cambiare",
    "cambiati": "cambiare",
    "cambiato": "cambiare",
    "cambiava": "cambiare",
    "cambiavamo": "cambiare",
    "cambiavan": "cambiare",
    "cambiavano": "cambiare",
    "cambiavate": "cambiare",
    "cambiavi": "cambiare",
    "cambiavo": "cambiare",
    "cambierai": "cambiare",
    "cambieran": "cambiare",
    "cambieranno": "cambiare",
    "cambierebbe": "cambiare",
    "cambierebber": "cambiare",
    "cambierebbero": "cambiare",
    "cambierei": "cambiare",
    "cambieremmo": "cambiare",
    "cambieremo": "cambiare",
    "cambiereste": "cambiare",
    "cambieresti": "cambiare",
    "cambierete": "cambiare",
    "cambierà": "cambiare",
    "cambierò": "cambiare",
    "cambin": "cambiare",
    "cambino": "cambiare",
    "cambio": "cambiare",
    "cambisti": "cambista",
    "cambiò": "cambiare",
    "cambogiana": "cambogiano",
    "cambogiane": "cambogiano",
    "cambogiani": "cambogiano",
    "camei": "cameo",
    "camelie": "camelia",
    "camerali": "camerale",
    "camerate": "camerata",
    "cameratesca": "cameratesco",
    "cameratesche": "cameratesco",
    "camerateschi": "cameratesco",
    "cameratismi": "cameratismo",
    "camere": "camera",
    "camerette": "cameretta",
    "cameriere": "cameriera",
    "camerieri": "cameriere",
    "camerini": "camerino",
    "cameristica": "cameristico",
    "cameristiche": "cameristico",
    "cameristici": "cameristico",
    "cameroni": "camerone",
    "camerunensi": "camerunense",
    "camerunesi": "camerunese",
    "camice": "camicia",
    "camicette": "camicetta",
    "camici": "camice",
    "camicie": "camicia",
    "camiciole": "camiciola",
    "camicioni": "camicione",
    "caminetti": "caminetto",
    "camini": "camino",
    "camionabili": "camionabile",
    "camionali": "camionale",
    "camioncini": "camioncino",
    "camionette": "camionetta",
    "camionisti": "camionista",
    "cammei": "cammeo",
    "cammelli": "cammello",
    "cammellieri": "cammelliere",
    "cammina": "camminare",
    "camminai": "camminare",
    "camminamenti": "camminamento",
    "camminammo": "camminare",
    "camminan": "camminare",
    "camminando": "camminare",
    "camminano": "camminare",
    "camminante": "camminare",
    "camminanti": "camminare",
    "camminar": "camminare",
    "camminaron": "camminare",
    "camminarono": "camminare",
    "camminasse": "camminare",
    "camminasser": "camminare",
    "camminassero": "camminare",
    "camminassi": "camminare",
    "camminassimo": "camminare",
    "camminaste": "camminare",
    "camminasti": "camminare",
    "camminata": "camminare",
    "camminate": "camminata",
    "camminati": "camminare",
    "camminato": "camminare",
    "camminatori": "camminatore",
    "camminava": "camminare",
    "camminavamo": "camminare",
    "camminavan": "camminare",
    "camminavano": "camminare",
    "camminavate": "camminare",
    "camminavi": "camminare",
    "camminavo": "camminare",
    "camminerai": "camminare",
    "cammineran": "camminare",
    "cammineranno": "camminare",
    "camminerebbe": "camminare",
    "camminerebber": "camminare",
    "camminerebbero": "camminare",
    "camminerei": "camminare",
    "cammineremmo": "camminare",
    "cammineremo": "camminare",
    "camminereste": "camminare",
    "cammineresti": "camminare",
    "camminerete": "camminare",
    "camminerà": "camminare",
    "camminerò": "camminare",
    "cammini": "cammino",
    "camminiamo": "camminare",
    "camminiate": "camminare",
    "camminin": "camminare",
    "camminino": "camminare",
    "cammino": "camminare",
    "camminò": "camminare",
    "camomille": "camomilla",
    "camorre": "camorra",
    "camorristi": "camorrista",
    "camosci": "camoscio",
    "campa": "campire",
    "campagne": "campagna",
    "campagne-acquisti": "campagna-acquisti",
    "campagnola": "campagnolo",
    "campagnole": "campagnolo",
    "campagnoli": "campagnolo",
    "campai": "campare",
    "campali": "campale",
    "campammo": "campare",
    "campan": "campire",
    "campana": "campano",
    "campanacci": "campanaccio",
    "campanari": "campanaro",
    "campanaria": "campanario",
    "campanarie": "campanario",
    "campando": "campare",
    "campane": "campano",
    "campanelle": "campanella",
    "campanelli": "campanello",
    "campanellini": "campanellino",
    "campani": "campano",
    "campanili": "campanile",
    "campanilismi": "campanilismo",
    "campanilistica": "campanilistico",
    "campanilistiche": "campanilistico",
    "campanilistici": "campanilistico",
    "campano": "campire",
    "campante": "campare",
    "campanti": "campare",
    "campar": "campare",
    "camparon": "campare",
    "camparono": "campare",
    "campasse": "campare",
    "campasser": "campare",
    "campassero": "campare",
    "campassi": "campare",
    "campassimo": "campare",
    "campaste": "campare",
    "campasti": "campare",
    "campata": "campato",
    "campate": "campato",
    "campati": "campato",
    "campato": "campare",
    "campava": "campare",
    "campavamo": "campare",
    "campavan": "campare",
    "campavano": "campare",
    "campavate": "campare",
    "campavi": "campare",
    "campavo": "campare",
    "campe": "campire",
    "campeggerai": "campeggiare",
    "campeggeran": "campeggiare",
    "campeggeranno": "campeggiare",
    "campeggerebbe": "campeggiare",
    "campeggerebber": "campeggiare",
    "campeggerebbero": "campeggiare",
    "campeggerei": "campeggiare",
    "campeggeremmo": "campeggiare",
    "campeggeremo": "campeggiare",
    "campeggereste": "campeggiare",
    "campeggeresti": "campeggiare",
    "campeggerete": "campeggiare",
    "campeggerà": "campeggiare",
    "campeggerò": "campeggiare",
    "campeggi": "campeggio",
    "campeggia": "campeggiare",
    "campeggiai": "campeggiare",
    "campeggiammo": "campeggiare",
    "campeggiamo": "campeggiare",
    "campeggian": "campeggiare",
    "campeggiando": "campeggiare",
    "campeggiano": "campeggiare",
    "campeggiante": "campeggiare",
    "campeggianti": "campeggiare",
    "campeggiar": "campeggiare",
    "campeggiaron": "campeggiare",
    "campeggiarono": "campeggiare",
    "campeggiasse": "campeggiare",
    "campeggiasser": "campeggiare",
    "campeggiassero": "campeggiare",
    "campeggiassi": "campeggiare",
    "campeggiassimo": "campeggiare",
    "campeggiaste": "campeggiare",
    "campeggiasti": "campeggiare",
    "campeggiata": "campeggiare",
    "campeggiate": "campeggiare",
    "campeggiati": "campeggiare",
    "campeggiato": "campeggiare",
    "campeggiatori": "campeggiatore",
    "campeggiava": "campeggiare",
    "campeggiavamo": "campeggiare",
    "campeggiavan": "campeggiare",
    "campeggiavano": "campeggiare",
    "campeggiavate": "campeggiare",
    "campeggiavi": "campeggiare",
    "campeggiavo": "campeggiare",
    "campeggin": "campeggiare",
    "campeggino": "campeggiare",
    "campeggio": "campeggiare",
    "campeggiò": "campeggiare",
    "campendo": "campire",
    "campente": "campire",
    "campenti": "campire",
    "camperai": "campare",
    "camperan": "campare",
    "camperanno": "campare",
    "camperebbe": "campare",
    "camperebber": "campare",
    "camperebbero": "campare",
    "camperei": "campare",
    "camperemmo": "campare",
    "camperemo": "campare",
    "campereste": "campare",
    "camperesti": "campare",
    "camperete": "campare",
    "camperà": "campare",
    "camperò": "campare",
    "campesinos": "campesino",
    "campestri": "campestre",
    "campetti": "campetto",
    "campi": "campo",
    "campiamo": "campire",
    "campiate": "campire",
    "campicchi": "campicchiare",
    "campicchia": "campicchiare",
    "campicchiai": "campicchiare",
    "campicchiammo": "campicchiare",
    "campicchiamo": "campicchiare",
    "campicchian": "campicchiare",
    "campicchiando": "campicchiare",
    "campicchiano": "campicchiare",
    "campicchiante": "campicchiare",
    "campicchianti": "campicchiare",
    "campicchiar": "campicchiare",
    "campicchiaron": "campicchiare",
    "campicchiarono": "campicchiare",
    "campicchiasse": "campicchiare",
    "campicchiasser": "campicchiare",
    "campicchiassero": "campicchiare",
    "campicchiassi": "campicchiare",
    "campicchiassimo": "campicchiare",
    "campicchiaste": "campicchiare",
    "campicchiasti": "campicchiare",
    "campicchiata": "campicchiare",
    "campicchiate": "campicchiare",
    "campicchiati": "campicchiare",
    "campicchiato": "campicchiare",
    "campicchiava": "campicchiare",
    "campicchiavamo": "campicchiare",
    "campicchiavan": "campicchiare",
    "campicchiavano": "campicchiare",
    "campicchiavate": "campicchiare",
    "campicchiavi": "campicchiare",
    "campicchiavo": "campicchiare",
    "campicchierai": "campicchiare",
    "campicchieran": "campicchiare",
    "campicchieranno": "campicchiare",
    "campicchierebbe": "campicchiare",
    "campicchierebber": "campicchiare",
    "campicchierebbero": "campicchiare",
    "campicchierei": "campicchiare",
    "campicchieremmo": "campicchiare",
    "campicchieremo": "campicchiare",
    "campicchiereste": "campicchiare",
    "campicchieresti": "campicchiare",
    "campicchierete": "campicchiare",
    "campicchierà": "campicchiare",
    "campicchierò": "campicchiare",
    "campicchin": "campicchiare",
    "campicchino": "campicchiare",
    "campicchio": "campicchiare",
    "campicchiò": "campicchiare",
    "campielli": "campiello",
    "campii": "campire",
    "campimmo": "campire",
    "campin": "campare",
    "campino": "campare",
    "campiona": "campionare",
    "campionai": "campionare",
    "campionamenti": "campionamento",
    "campionammo": "campionare",
    "campionan": "campionare",
    "campionando": "campionare",
    "campionano": "campionare",
    "campionante": "campionare",
    "campionanti": "campionare",
    "campionar": "campionare",
    "campionari": "campionario",
    "campionaria": "campionario",
    "campionarie": "campionario",
    "campionaron": "campionare",
    "campionarono": "campionare",
    "campionasse": "campionare",
    "campionasser": "campionare",
    "campionassero": "campionare",
    "campionassi": "campionare",
    "campionassimo": "campionare",
    "campionaste": "campionare",
    "campionasti": "campionare",
    "campionata": "campionare",
    "campionate": "campionare",
    "campionati": "campionato",
    "campionato": "campionare",
    "campionatori": "campionatore",
    "campionature": "campionatura",
    "campionava": "campionare",
    "campionavamo": "campionare",
    "campionavan": "campionare",
    "campionavano": "campionare",
    "campionavate": "campionare",
    "campionavi": "campionare",
    "campionavo": "campionare",
    "campioncini": "campioncino",
    "campionerai": "campionare",
    "campioneran": "campionare",
    "campioneranno": "campionare",
    "campionerebbe": "campionare",
    "campionerebber": "campionare",
    "campionerebbero": "campionare",
    "campionerei": "campionare",
    "campioneremmo": "campionare",
    "campioneremo": "campionare",
    "campionereste": "campionare",
    "campioneresti": "campionare",
    "campionerete": "campionare",
    "campionerà": "campionare",
    "campionerò": "campionare",
    "campionesse": "campionessa",
    "campioni": "campione",
    "campioniamo": "campionare",
    "campioniate": "campionare",
    "campionin": "campionare",
    "campionino": "campionare",
    "campiono": "campionare",
    "campionò": "campionare",
    "campir": "campire",
    "campirai": "campire",
    "campiran": "campire",
    "campiranno": "campire",
    "campirebbe": "campire",
    "campirebber": "campire",
    "campirebbero": "campire",
    "campirei": "campire",
    "campiremmo": "campire",
    "campiremo": "campire",
    "campireste": "campire",
    "campiresti": "campire",
    "campirete": "campire",
    "campiron": "campire",
    "campirono": "campire",
    "campirà": "campire",
    "campirò": "campire",
    "campisse": "campire",
    "campisser": "campire",
    "campissero": "campire",
    "campissi": "campire",
    "campissimo": "campire",
    "campiste": "campire",
    "campisti": "campire",
    "campita": "campire",
    "campite": "campire",
    "campiti": "campire",
    "campito": "campire",
    "campiva": "campire",
    "campivamo": "campire",
    "campivan": "campire",
    "campivano": "campire",
    "campivate": "campire",
    "campivi": "campire",
    "campivo": "campire",
    "campo": "campire",
    "campon": "campire",
    "campono": "campire",
    "camposanti": "camposanto",
    "campì": "campire",
    "campò": "campare",
    "camuffa": "camuffare",
    "camuffai": "camuffare",
    "camuffamenti": "camuffamento",
    "camuffammo": "camuffare",
    "camuffan": "camuffare",
    "camuffando": "camuffare",
    "camuffano": "camuffare",
    "camuffante": "camuffare",
    "camuffanti": "camuffare",
    "camuffar": "camuffare",
    "camuffaron": "camuffare",
    "camuffarono": "camuffare",
    "camuffasse": "camuffare",
    "camuffasser": "camuffare",
    "camuffassero": "camuffare",
    "camuffassi": "camuffare",
    "camuffassimo": "camuffare",
    "camuffaste": "camuffare",
    "camuffasti": "camuffare",
    "camuffata": "camuffare",
    "camuffate": "camuffare",
    "camuffati": "camuffare",
    "camuffato": "camuffare",
    "camuffava": "camuffare",
    "camuffavamo": "camuffare",
    "camuffavan": "camuffare",
    "camuffavano": "camuffare",
    "camuffavate": "camuffare",
    "camuffavi": "camuffare",
    "camuffavo": "camuffare",
    "camufferai": "camuffare",
    "camufferan": "camuffare",
    "camufferanno": "camuffare",
    "camufferebbe": "camuffare",
    "camufferebber": "camuffare",
    "camufferebbero": "camuffare",
    "camufferei": "camuffare",
    "camufferemmo": "camuffare",
    "camufferemo": "camuffare",
    "camuffereste": "camuffare",
    "camufferesti": "camuffare",
    "camufferete": "camuffare",
    "camufferà": "camuffare",
    "camufferò": "camuffare",
    "camuffi": "camuffare",
    "camuffiamo": "camuffare",
    "camuffiate": "camuffare",
    "camuffin": "camuffare",
    "camuffino": "camuffare",
    "camuffo": "camuffare",
    "camuffò": "camuffare",
    "camusa": "camuso",
    "camuse": "camuso",
    "camusi": "camuso",
    "canadesi": "canadese",
    "canagliate": "canagliata",
    "canaglie": "canaglia",
    "canali": "canale",
    "canaline": "canalina",
    "canalini": "canalino",
    "canalizza": "canalizzare",
    "canalizzai": "canalizzare",
    "canalizzammo": "canalizzare",
    "canalizzan": "canalizzare",
    "canalizzando": "canalizzare",
    "canalizzano": "canalizzare",
    "canalizzante": "canalizzare",
    "canalizzanti": "canalizzare",
    "canalizzar": "canalizzare",
    "canalizzaron": "canalizzare",
    "canalizzarono": "canalizzare",
    "canalizzasse": "canalizzare",
    "canalizzasser": "canalizzare",
    "canalizzassero": "canalizzare",
    "canalizzassi": "canalizzare",
    "canalizzassimo": "canalizzare",
    "canalizzaste": "canalizzare",
    "canalizzasti": "canalizzare",
    "canalizzata": "canalizzare",
    "canalizzate": "canalizzare",
    "canalizzati": "canalizzare",
    "canalizzato": "canalizzare",
    "canalizzava": "canalizzare",
    "canalizzavamo": "canalizzare",
    "canalizzavan": "canalizzare",
    "canalizzavano": "canalizzare",
    "canalizzavate": "canalizzare",
    "canalizzavi": "canalizzare",
    "canalizzavo": "canalizzare",
    "canalizzazioni": "canalizzazione",
    "canalizzerai": "canalizzare",
    "canalizzeran": "canalizzare",
    "canalizzeranno": "canalizzare",
    "canalizzerebbe": "canalizzare",
    "canalizzerebber": "canalizzare",
    "canalizzerebbero": "canalizzare",
    "canalizzerei": "canalizzare",
    "canalizzeremmo": "canalizzare",
    "canalizzeremo": "canalizzare",
    "canalizzereste": "canalizzare",
    "canalizzeresti": "canalizzare",
    "canalizzerete": "canalizzare",
    "canalizzerà": "canalizzare",
    "canalizzerò": "canalizzare",
    "canalizzi": "canalizzare",
    "canalizziamo": "canalizzare",
    "canalizziate": "canalizzare",
    "canalizzin": "canalizzare",
    "canalizzino": "canalizzare",
    "canalizzo": "canalizzare",
    "canalizzò": "canalizzare",
    "canaloni": "canalone",
    "canape": "canapa",
    "canapi": "canapo",
    "canapiera": "canapiero",
    "canapiere": "canapiero",
    "canapieri": "canapiero",
    "canarina": "canarino",
    "canarine": "canarino",
    "canarini": "canarino",
    "cancella": "cancellare",
    "cancellai": "cancellare",
    "cancellammo": "cancellare",
    "cancellan": "cancellare",
    "cancellando": "cancellare",
    "cancellano": "cancellare",
    "cancellante": "cancellare",
    "cancellanti": "cancellare",
    "cancellar": "cancellare",
    "cancellaron": "cancellare",
    "cancellarono": "cancellare",
    "cancellasse": "cancellare",
    "cancellasser": "cancellare",
    "cancellassero": "cancellare",
    "cancellassi": "cancellare",
    "cancellassimo": "cancellare",
    "cancellaste": "cancellare",
    "cancellasti": "cancellare",
    "cancellata": "cancellare",
    "cancellate": "cancellata",
    "cancellati": "cancellare",
    "cancellato": "cancellare",
    "cancellature": "cancellatura",
    "cancellava": "cancellare",
    "cancellavamo": "cancellare",
    "cancellavan": "cancellare",
    "cancellavano": "cancellare",
    "cancellavate": "cancellare",
    "cancellavi": "cancellare",
    "cancellavo": "cancellare",
    "cancellazioni": "cancellazione",
    "cancellerai": "cancellare",
    "cancelleran": "cancellare",
    "cancelleranno": "cancellare",
    "cancellerebbe": "cancellare",
    "cancellerebber": "cancellare",
    "cancellerebbero": "cancellare",
    "cancellerei": "cancellare",
    "cancelleremmo": "cancellare",
    "cancelleremo": "cancellare",
    "cancellereste": "cancellare",
    "cancelleresti": "cancellare",
    "cancellerete": "cancellare",
    "cancellerie": "cancelleria",
    "cancellerà": "cancellare",
    "cancellerò": "cancellare",
    "cancelletti": "cancelletto",
    "cancelli": "cancello",
    "cancelliamo": "cancellare",
    "cancelliate": "cancellare",
    "cancellierati": "cancellierato",
    "cancellieri": "cancelliere",
    "cancellin": "cancellare",
    "cancellino": "cancellare",
    "cancello": "cancellare",
    "cancellò": "cancellare",
    "cancerogena": "cancerogeno",
    "cancerogene": "cancerogeno",
    "cancerogeni": "cancerogeno",
    "cancerosa": "canceroso",
    "cancerose": "canceroso",
    "cancerosi": "canceroso",
    "cancrene": "cancrena",
    "cancri": "cancro",
    "canda": "candire",
    "candan": "candire",
    "candano": "candire",
    "cande": "candire",
    "candeggerai": "candeggiare",
    "candeggeran": "candeggiare",
    "candeggeranno": "candeggiare",
    "candeggerebbe": "candeggiare",
    "candeggerebber": "candeggiare",
    "candeggerebbero": "candeggiare",
    "candeggerei": "candeggiare",
    "candeggeremmo": "candeggiare",
    "candeggeremo": "candeggiare",
    "candeggereste": "candeggiare",
    "candeggeresti": "candeggiare",
    "candeggerete": "candeggiare",
    "candeggerà": "candeggiare",
    "candeggerò": "candeggiare",
    "candeggi": "candeggiare",
    "candeggia": "candeggiare",
    "candeggiai": "candeggiare",
    "candeggiammo": "candeggiare",
    "candeggiamo": "candeggiare",
    "candeggian": "candeggiare",
    "candeggiando": "candeggiare",
    "candeggiano": "candeggiare",
    "candeggiante": "candeggiare",
    "candeggianti": "candeggiare",
    "candeggiar": "candeggiare",
    "candeggiaron": "candeggiare",
    "candeggiarono": "candeggiare",
    "candeggiasse": "candeggiare",
    "candeggiasser": "candeggiare",
    "candeggiassero": "candeggiare",
    "candeggiassi": "candeggiare",
    "candeggiassimo": "candeggiare",
    "candeggiaste": "candeggiare",
    "candeggiasti": "candeggiare",
    "candeggiata": "candeggiare",
    "candeggiate": "candeggiare",
    "candeggiati": "candeggiare",
    "candeggiato": "candeggiare",
    "candeggiava": "candeggiare",
    "candeggiavamo": "candeggiare",
    "candeggiavan": "candeggiare",
    "candeggiavano": "candeggiare",
    "candeggiavate": "candeggiare",
    "candeggiavi": "candeggiare",
    "candeggiavo": "candeggiare",
    "candeggin": "candeggiare",
    "candeggino": "candeggiare",
    "candeggio": "candeggiare",
    "candeggiò": "candeggiare",
    "candelabri": "candelabro",
    "candele": "candela",
    "candelieri": "candeliere",
    "candeline": "candelina",
    "candelotti": "candelotto",
    "candendo": "candire",
    "candente": "candire",
    "candenti": "candire",
    "candi": "candire",
    "candiamo": "candire",
    "candiate": "candire",
    "candida": "candido",
    "candidai": "candidare",
    "candidammo": "candidare",
    "candidan": "candidare",
    "candidando": "candidare",
    "candidano": "candidare",
    "candidante": "candidare",
    "candidanti": "candidare",
    "candidar": "candidare",
    "candidaron": "candidare",
    "candidarono": "candidare",
    "candidasse": "candidare",
    "candidasser": "candidare",
    "candidassero": "candidare",
    "candidassi": "candidare",
    "candidassimo": "candidare",
    "candidaste": "candidare",
    "candidasti": "candidare",
    "candidata": "candidare",
    "candidate": "candidata",
    "candidati": "candidato",
    "candidato": "candidare",
    "candidature": "candidatura",
    "candidava": "candidare",
    "candidavamo": "candidare",
    "candidavan": "candidare",
    "candidavano": "candidare",
    "candidavate": "candidare",
    "candidavi": "candidare",
    "candidavo": "candidare",
    "candide": "candido",
    "candiderai": "candidare",
    "candideran": "candidare",
    "candideranno": "candidare",
    "candiderebbe": "candidare",
    "candiderebber": "candidare",
    "candiderebbero": "candidare",
    "candiderei": "candidare",
    "candideremmo": "candidare",
    "candideremo": "candidare",
    "candidereste": "candidare",
    "candideresti": "candidare",
    "candiderete": "candidare",
    "candiderà": "candidare",
    "candiderò": "candidare",
    "candidi": "candido",
    "candidiamo": "candidare",
    "candidiate": "candidare",
    "candidin": "candidare",
    "candidino": "candidare",
    "candido": "candidare",
    "candidò": "candidare",
    "candii": "candire",
    "candimmo": "candire",
    "candir": "candire",
    "candirai": "candire",
    "candiran": "candire",
    "candiranno": "candire",
    "candirebbe": "candire",
    "candirebber": "candire",
    "candirebbero": "candire",
    "candirei": "candire",
    "candiremmo": "candire",
    "candiremo": "candire",
    "candireste": "candire",
    "candiresti": "candire",
    "candirete": "candire",
    "candiron": "candire",
    "candirono": "candire",
    "candirà": "candire",
    "candirò": "candire",
    "candisse": "candire",
    "candisser": "candire",
    "candissero": "candire",
    "candissi": "candire",
    "candissimo": "candire",
    "candiste": "candire",
    "candisti": "candire",
    "candita": "candire",
    "candite": "candire",
    "canditi": "candito",
    "candito": "candire",
    "candiva": "candire",
    "candivamo": "candire",
    "candivan": "candire",
    "candivano": "candire",
    "candivate": "candire",
    "candivi": "candire",
    "candivo": "candire",
    "cando": "candire",
    "candon": "candire",
    "candono": "candire",
    "candori": "candore",
    "candì": "candire",
    "canestri": "canestro",
    "cangerai": "cangiare",
    "cangeran": "cangiare",
    "cangeranno": "cangiare",
    "cangerebbe": "cangiare",
    "cangerebber": "cangiare",
    "cangerebbero": "cangiare",
    "cangerei": "cangiare",
    "cangeremmo": "cangiare",
    "cangeremo": "cangiare",
    "cangereste": "cangiare",
    "cangeresti": "cangiare",
    "cangerete": "cangiare",
    "cangerà": "cangiare",
    "cangerò": "cangiare",
    "cangi": "cangiare",
    "cangia": "cangiare",
    "cangiai": "cangiare",
    "cangiammo": "cangiare",
    "cangiamo": "cangiare",
    "cangian": "cangiare",
    "cangiando": "cangiare",
    "cangiano": "cangiare",
    "cangiante": "cangiare",
    "cangianti": "cangiare",
    "cangiar": "cangiare",
    "cangiaron": "cangiare",
    "cangiarono": "cangiare",
    "cangiasse": "cangiare",
    "cangiasser": "cangiare",
    "cangiassero": "cangiare",
    "cangiassi": "cangiare",
    "cangiassimo": "cangiare",
    "cangiaste": "cangiare",
    "cangiasti": "cangiare",
    "cangiata": "cangiare",
    "cangiate": "cangiare",
    "cangiati": "cangiare",
    "cangiato": "cangiare",
    "cangiava": "cangiare",
    "cangiavamo": "cangiare",
    "cangiavan": "cangiare",
    "cangiavano": "cangiare",
    "cangiavate": "cangiare",
    "cangiavi": "cangiare",
    "cangiavo": "cangiare",
    "cangin": "cangiare",
    "cangino": "cangiare",
    "cangio": "cangiare",
    "cangiò": "cangiare",
    "cani": "cane",
    "canicolari": "canicolare",
    "canicole": "canicola",
    "canina": "canino",
    "canine": "canino",
    "canini": "canino",
    "canne": "canna",
    "canneti": "canneto",
    "cannibalesca": "cannibalesco",
    "cannibalesche": "cannibalesco",
    "cannibaleschi": "cannibalesco",
    "cannibali": "cannibale",
    "cannibalismi": "cannibalismo",
    "cannibalizza": "cannibalizzare",
    "cannibalizzai": "cannibalizzare",
    "cannibalizzammo": "cannibalizzare",
    "cannibalizzan": "cannibalizzare",
    "cannibalizzando": "cannibalizzare",
    "cannibalizzano": "cannibalizzare",
    "cannibalizzante": "cannibalizzare",
    "cannibalizzanti": "cannibalizzare",
    "cannibalizzar": "cannibalizzare",
    "cannibalizzaron": "cannibalizzare",
    "cannibalizzarono": "cannibalizzare",
    "cannibalizzasse": "cannibalizzare",
    "cannibalizzasser": "cannibalizzare",
    "cannibalizzassero": "cannibalizzare",
    "cannibalizzassi": "cannibalizzare",
    "cannibalizzassimo": "cannibalizzare",
    "cannibalizzaste": "cannibalizzare",
    "cannibalizzasti": "cannibalizzare",
    "cannibalizzata": "cannibalizzare",
    "cannibalizzate": "cannibalizzare",
    "cannibalizzati": "cannibalizzare",
    "cannibalizzato": "cannibalizzare",
    "cannibalizzava": "cannibalizzare",
    "cannibalizzavamo": "cannibalizzare",
    "cannibalizzavan": "cannibalizzare",
    "cannibalizzavano": "cannibalizzare",
    "cannibalizzavate": "cannibalizzare",
    "cannibalizzavi": "cannibalizzare",
    "cannibalizzavo": "cannibalizzare",
    "cannibalizzerai": "cannibalizzare",
    "cannibalizzeran": "cannibalizzare",
    "cannibalizzeranno": "cannibalizzare",
    "cannibalizzerebbe": "cannibalizzare",
    "cannibalizzerebber": "cannibalizzare",
    "cannibalizzerebbero": "cannibalizzare",
    "cannibalizzerei": "cannibalizzare",
    "cannibalizzeremmo": "cannibalizzare",
    "cannibalizzeremo": "cannibalizzare",
    "cannibalizzereste": "cannibalizzare",
    "cannibalizzeresti": "cannibalizzare",
    "cannibalizzerete": "cannibalizzare",
    "cannibalizzerà": "cannibalizzare",
    "cannibalizzerò": "cannibalizzare",
    "cannibalizzi": "cannibalizzare",
    "cannibalizziamo": "cannibalizzare",
    "cannibalizziate": "cannibalizzare",
    "cannibalizzin": "cannibalizzare",
    "cannibalizzino": "cannibalizzare",
    "cannibalizzo": "cannibalizzare",
    "cannibalizzò": "cannibalizzare",
    "cannocchiali": "cannocchiale",
    "cannoli": "cannolo",
    "cannonate": "cannonata",
    "cannoncini": "cannoncino",
    "cannoneggerai": "cannoneggiare",
    "cannoneggeran": "cannoneggiare",
    "cannoneggeranno": "cannoneggiare",
    "cannoneggerebbe": "cannoneggiare",
    "cannoneggerebber": "cannoneggiare",
    "cannoneggerebbero": "cannoneggiare",
    "cannoneggerei": "cannoneggiare",
    "cannoneggeremmo": "cannoneggiare",
    "cannoneggeremo": "cannoneggiare",
    "cannoneggereste": "cannoneggiare",
    "cannoneggeresti": "cannoneggiare",
    "cannoneggerete": "cannoneggiare",
    "cannoneggerà": "cannoneggiare",
    "cannoneggerò": "cannoneggiare",
    "cannoneggi": "cannoneggiare",
    "cannoneggia": "cannoneggiare",
    "cannoneggiai": "cannoneggiare",
    "cannoneggiamenti": "cannoneggiamento",
    "cannoneggiammo": "cannoneggiare",
    "cannoneggiamo": "cannoneggiare",
    "cannoneggian": "cannoneggiare",
    "cannoneggiando": "cannoneggiare",
    "cannoneggiano": "cannoneggiare",
    "cannoneggiante": "cannoneggiare",
    "cannoneggianti": "cannoneggiare",
    "cannoneggiar": "cannoneggiare",
    "cannoneggiaron": "cannoneggiare",
    "cannoneggiarono": "cannoneggiare",
    "cannoneggiasse": "cannoneggiare",
    "cannoneggiasser": "cannoneggiare",
    "cannoneggiassero": "cannoneggiare",
    "cannoneggiassi": "cannoneggiare",
    "cannoneggiassimo": "cannoneggiare",
    "cannoneggiaste": "cannoneggiare",
    "cannoneggiasti": "cannoneggiare",
    "cannoneggiata": "cannoneggiare",
    "cannoneggiate": "cannoneggiare",
    "cannoneggiati": "cannoneggiare",
    "cannoneggiato": "cannoneggiare",
    "cannoneggiava": "cannoneggiare",
    "cannoneggiavamo": "cannoneggiare",
    "cannoneggiavan": "cannoneggiare",
    "cannoneggiavano": "cannoneggiare",
    "cannoneggiavate": "cannoneggiare",
    "cannoneggiavi": "cannoneggiare",
    "cannoneggiavo": "cannoneggiare",
    "cannoneggin": "cannoneggiare",
    "cannoneggino": "cannoneggiare",
    "cannoneggio": "cannoneggiare",
    "cannoneggiò": "cannoneggiare",
    "cannoni": "cannone",
    "cannoniere": "cannoniera",
    "cannonieri": "cannoniere",
    "cannule": "cannula",
    "canoe": "canoa",
    "canoisti": "canoista",
    "canoni": "canone",
    "canonica": "canonico",
    "canoniche": "canonico",
    "canonici": "canonico",
    "canonizza": "canonizzare",
    "canonizzai": "canonizzare",
    "canonizzammo": "canonizzare",
    "canonizzan": "canonizzare",
    "canonizzando": "canonizzare",
    "canonizzano": "canonizzare",
    "canonizzante": "canonizzare",
    "canonizzanti": "canonizzare",
    "canonizzar": "canonizzare",
    "canonizzaron": "canonizzare",
    "canonizzarono": "canonizzare",
    "canonizzasse": "canonizzare",
    "canonizzasser": "canonizzare",
    "canonizzassero": "canonizzare",
    "canonizzassi": "canonizzare",
    "canonizzassimo": "canonizzare",
    "canonizzaste": "canonizzare",
    "canonizzasti": "canonizzare",
    "canonizzata": "canonizzare",
    "canonizzate": "canonizzare",
    "canonizzati": "canonizzare",
    "canonizzato": "canonizzare",
    "canonizzava": "canonizzare",
    "canonizzavamo": "canonizzare",
    "canonizzavan": "canonizzare",
    "canonizzavano": "canonizzare",
    "canonizzavate": "canonizzare",
    "canonizzavi": "canonizzare",
    "canonizzavo": "canonizzare",
    "canonizzazioni": "canonizzazione",
    "canonizzerai": "canonizzare",
    "canonizzeran": "canonizzare",
    "canonizzeranno": "canonizzare",
    "canonizzerebbe": "canonizzare",
    "canonizzerebber": "canonizzare",
    "canonizzerebbero": "canonizzare",
    "canonizzerei": "canonizzare",
    "canonizzeremmo": "canonizzare",
    "canonizzeremo": "canonizzare",
    "canonizzereste": "canonizzare",
    "canonizzeresti": "canonizzare",
    "canonizzerete": "canonizzare",
    "canonizzerà": "canonizzare",
    "canonizzerò": "canonizzare",
    "canonizzi": "canonizzare",
    "canonizziamo": "canonizzare",
    "canonizziate": "canonizzare",
    "canonizzin": "canonizzare",
    "canonizzino": "canonizzare",
    "canonizzo": "canonizzare",
    "canonizzò": "canonizzare",
    "canora": "canoro",
    "canore": "canoro",
    "canori": "canoro",
    "canottaggi": "canottaggio",
    "canotte": "canotta",
    "canotti": "canotto",
    "canottiere": "canottiera",
    "canottieri": "canottiere",
    "canovacci": "canovaccio",
    "canta": "cantare",
    "cantabili": "cantabile",
    "cantai": "cantare",
    "cantammo": "cantare",
    "cantan": "cantare",
    "cantando": "cantare",
    "cantano": "cantare",
    "cantante": "cantare",
    "cantanti": "cantare",
    "cantar": "cantare",
    "cantaron": "cantare",
    "cantarono": "cantare",
    "cantasse": "cantare",
    "cantasser": "cantare",
    "cantassero": "cantare",
    "cantassi": "cantare",
    "cantassimo": "cantare",
    "cantaste": "cantare",
    "cantasti": "cantare",
    "cantata": "cantare",
    "cantate": "cantata",
    "cantati": "cantare",
    "cantato": "cantare",
    "cantatrici": "cantatrice",
    "cantautori": "cantautore",
    "cantautrici": "cantautrice",
    "cantava": "cantare",
    "cantavamo": "cantare",
    "cantavan": "cantare",
    "cantavano": "cantare",
    "cantavate": "cantare",
    "cantavi": "cantare",
    "cantavo": "cantare",
    "canterai": "cantare",
    "canteran": "cantare",
    "canteranno": "cantare",
    "canterebbe": "cantare",
    "canterebber": "cantare",
    "canterebbero": "cantare",
    "canterei": "cantare",
    "canterella": "canterellare",
    "canterellai": "canterellare",
    "canterellammo": "canterellare",
    "canterellan": "canterellare",
    "canterellando": "canterellare",
    "canterellano": "canterellare",
    "canterellante": "canterellare",
    "canterellanti": "canterellare",
    "canterellar": "canterellare",
    "canterellaron": "canterellare",
    "canterellarono": "canterellare",
    "canterellasse": "canterellare",
    "canterellasser": "canterellare",
    "canterellassero": "canterellare",
    "canterellassi": "canterellare",
    "canterellassimo": "canterellare",
    "canterellaste": "canterellare",
    "canterellasti": "canterellare",
    "canterellata": "canterellare",
    "canterellate": "canterellare",
    "canterellati": "canterellare",
    "canterellato": "canterellare",
    "canterellava": "canterellare",
    "canterellavamo": "canterellare",
    "canterellavan": "canterellare",
    "canterellavano": "canterellare",
    "canterellavate": "canterellare",
    "canterellavi": "canterellare",
    "canterellavo": "canterellare",
    "canterellerai": "canterellare",
    "canterelleran": "canterellare",
    "canterelleranno": "canterellare",
    "canterellerebbe": "canterellare",
    "canterellerebber": "canterellare",
    "canterellerebbero": "canterellare",
    "canterellerei": "canterellare",
    "canterelleremmo": "canterellare",
    "canterelleremo": "canterellare",
    "canterellereste": "canterellare",
    "canterelleresti": "canterellare",
    "canterellerete": "canterellare",
    "canterellerà": "canterellare",
    "canterellerò": "canterellare",
    "canterelli": "canterellare",
    "canterelliamo": "canterellare",
    "canterelliate": "canterellare",
    "canterellin": "canterellare",
    "canterellino": "canterellare",
    "canterello": "canterellare",
    "canterellò": "canterellare",
    "canteremmo": "cantare",
    "canteremo": "cantare",
    "cantereste": "cantare",
    "canteresti": "cantare",
    "canterete": "cantare",
    "canterina": "canterino",
    "canterine": "canterino",
    "canterini": "canterino",
    "canterà": "cantare",
    "canterò": "cantare",
    "canti": "canto",
    "cantiamo": "cantare",
    "cantiate": "cantare",
    "canticchi": "canticchiare",
    "canticchia": "canticchiare",
    "canticchiai": "canticchiare",
    "canticchiammo": "canticchiare",
    "canticchiamo": "canticchiare",
    "canticchian": "canticchiare",
    "canticchiando": "canticchiare",
    "canticchiano": "canticchiare",
    "canticchiante": "canticchiare",
    "canticchianti": "canticchiare",
    "canticchiar": "canticchiare",
    "canticchiaron": "canticchiare",
    "canticchiarono": "canticchiare",
    "canticchiasse": "canticchiare",
    "canticchiasser": "canticchiare",
    "canticchiassero": "canticchiare",
    "canticchiassi": "canticchiare",
    "canticchiassimo": "canticchiare",
    "canticchiaste": "canticchiare",
    "canticchiasti": "canticchiare",
    "canticchiata": "canticchiare",
    "canticchiate": "canticchiare",
    "canticchiati": "canticchiare",
    "canticchiato": "canticchiare",
    "canticchiava": "canticchiare",
    "canticchiavamo": "canticchiare",
    "canticchiavan": "canticchiare",
    "canticchiavano": "canticchiare",
    "canticchiavate": "canticchiare",
    "canticchiavi": "canticchiare",
    "canticchiavo": "canticchiare",
    "canticchierai": "canticchiare",
    "canticchieran": "canticchiare",
    "canticchieranno": "canticchiare",
    "canticchierebbe": "canticchiare",
    "canticchierebber": "canticchiare",
    "canticchierebbero": "canticchiare",
    "canticchierei": "canticchiare",
    "canticchieremmo": "canticchiare",
    "canticchieremo": "canticchiare",
    "canticchiereste": "canticchiare",
    "canticchieresti": "canticchiare",
    "canticchierete": "canticchiare",
    "canticchierà": "canticchiare",
    "canticchierò": "canticchiare",
    "canticchin": "canticchiare",
    "canticchino": "canticchiare",
    "canticchio": "canticchiare",
    "canticchiò": "canticchiare",
    "cantiche": "cantica",
    "cantieri": "cantiere",
    "cantieristica": "cantieristico",
    "cantieristiche": "cantieristico",
    "cantieristici": "cantieristico",
    "cantilena": "cantilenare",
    "cantilenai": "cantilenare",
    "cantilenammo": "cantilenare",
    "cantilenan": "cantilenare",
    "cantilenando": "cantilenare",
    "cantilenano": "cantilenare",
    "cantilenante": "cantilenare",
    "cantilenanti": "cantilenare",
    "cantilenar": "cantilenare",
    "cantilenaron": "cantilenare",
    "cantilenarono": "cantilenare",
    "cantilenasse": "cantilenare",
    "cantilenasser": "cantilenare",
    "cantilenassero": "cantilenare",
    "cantilenassi": "cantilenare",
    "cantilenassimo": "cantilenare",
    "cantilenaste": "cantilenare",
    "cantilenasti": "cantilenare",
    "cantilenata": "cantilenare",
    "cantilenate": "cantilenare",
    "cantilenati": "cantilenare",
    "cantilenato": "cantilenare",
    "cantilenava": "cantilenare",
    "cantilenavamo": "cantilenare",
    "cantilenavan": "cantilenare",
    "cantilenavano": "cantilenare",
    "cantilenavate": "cantilenare",
    "cantilenavi": "cantilenare",
    "cantilenavo": "cantilenare",
    "cantilene": "cantilena",
    "cantilenerai": "cantilenare",
    "cantileneran": "cantilenare",
    "cantileneranno": "cantilenare",
    "cantilenerebbe": "cantilenare",
    "cantilenerebber": "cantilenare",
    "cantilenerebbero": "cantilenare",
    "cantilenerei": "cantilenare",
    "cantileneremmo": "cantilenare",
    "cantileneremo": "cantilenare",
    "cantilenereste": "cantilenare",
    "cantileneresti": "cantilenare",
    "cantilenerete": "cantilenare",
    "cantilenerà": "cantilenare",
    "cantilenerò": "cantilenare",
    "cantileni": "cantilenare",
    "cantileniamo": "cantilenare",
    "cantileniate": "cantilenare",
    "cantilenin": "cantilenare",
    "cantilenino": "cantilenare",
    "cantileno": "cantilenare",
    "cantilenò": "cantilenare",
    "cantin": "cantare",
    "cantine": "cantina",
    "cantino": "cantare",
    "canto": "cantare",
    "cantonali": "cantonale",
    "cantonate": "cantonata",
    "cantoni": "cantone",
    "cantoniera": "cantoniero",
    "cantoniere": "cantoniero",
    "cantonieri": "cantoniero",
    "cantori": "cantore",
    "cantrice": "cantore",
    "cantrici": "cantore",
    "cantucci": "cantuccio",
    "canturini": "canturino",
    "cantò": "cantare",
    "canuta": "canuto",
    "canute": "canuto",
    "canuti": "canuto",
    "canzona": "canzonare",
    "canzonacce": "canzonaccia",
    "canzonai": "canzonare",
    "canzonammo": "canzonare",
    "canzonan": "canzonare",
    "canzonando": "canzonare",
    "canzonano": "canzonare",
    "canzonante": "canzonare",
    "canzonanti": "canzonare",
    "canzonar": "canzonare",
    "canzonaron": "canzonare",
    "canzonarono": "canzonare",
    "canzonasse": "canzonare",
    "canzonasser": "canzonare",
    "canzonassero": "canzonare",
    "canzonassi": "canzonare",
    "canzonassimo": "canzonare",
    "canzonaste": "canzonare",
    "canzonasti": "canzonare",
    "canzonata": "canzonare",
    "canzonate": "canzonare",
    "canzonati": "canzonare",
    "canzonato": "canzonare",
    "canzonatori": "canzonatorio",
    "canzonatoria": "canzonatorio",
    "canzonatorie": "canzonatorio",
    "canzonava": "canzonare",
    "canzonavamo": "canzonare",
    "canzonavan": "canzonare",
    "canzonavano": "canzonare",
    "canzonavate": "canzonare",
    "canzonavi": "canzonare",
    "canzonavo": "canzonare",
    "canzoncine": "canzoncina",
    "canzonerai": "canzonare",
    "canzoneran": "canzonare",
    "canzoneranno": "canzonare",
    "canzonerebbe": "canzonare",
    "canzonerebber": "canzonare",
    "canzonerebbero": "canzonare",
    "canzonerei": "canzonare",
    "canzoneremmo": "canzonare",
    "canzoneremo": "canzonare",
    "canzonereste": "canzonare",
    "canzoneresti": "canzonare",
    "canzonerete": "canzonare",
    "canzonerà": "canzonare",
    "canzonerò": "canzonare",
    "canzonette": "canzonetta",
    "canzonettistica": "canzonettistico",
    "canzonettistiche": "canzonettistico",
    "canzonettistici": "canzonettistico",
    "canzoni": "canzone",
    "canzoniamo": "canzonare",
    "canzoniate": "canzonare",
    "canzonieri": "canzoniere",
    "canzonin": "canzonare",
    "canzonino": "canzonare",
    "canzono": "canzonare",
    "canzonò": "canzonare",
    "caotica": "caotico",
    "caotiche": "caotico",
    "caotici": "caotico",
    "capa": "capere",
    "capaci": "capace",
    "capacita": "capacitare",
    "capacitai": "capacitare",
    "capacitammo": "capacitare",
    "capacitan": "capacitare",
    "capacitando": "capacitare",
    "capacitano": "capacitare",
    "capacitante": "capacitare",
    "capacitanti": "capacitare",
    "capacitar": "capacitare",
    "capacitaron": "capacitare",
    "capacitarono": "capacitare",
    "capacitasse": "capacitare",
    "capacitasser": "capacitare",
    "capacitassero": "capacitare",
    "capacitassi": "capacitare",
    "capacitassimo": "capacitare",
    "capacitaste": "capacitare",
    "capacitasti": "capacitare",
    "capacitata": "capacitare",
    "capacitate": "capacitare",
    "capacitati": "capacitare",
    "capacitato": "capacitare",
    "capacitava": "capacitare",
    "capacitavamo": "capacitare",
    "capacitavan": "capacitare",
    "capacitavano": "capacitare",
    "capacitavate": "capacitare",
    "capacitavi": "capacitare",
    "capacitavo": "capacitare",
    "capaciterai": "capacitare",
    "capaciteran": "capacitare",
    "capaciteranno": "capacitare",
    "capaciterebbe": "capacitare",
    "capaciterebber": "capacitare",
    "capaciterebbero": "capacitare",
    "capaciterei": "capacitare",
    "capaciteremmo": "capacitare",
    "capaciteremo": "capacitare",
    "capacitereste": "capacitare",
    "capaciteresti": "capacitare",
    "capaciterete": "capacitare",
    "capaciterà": "capacitare",
    "capaciterò": "capacitare",
    "capaciti": "capacitare",
    "capacitiamo": "capacitare",
    "capacitiate": "capacitare",
    "capacitin": "capacitare",
    "capacitino": "capacitare",
    "capacito": "capacitare",
    "capacitò": "capacitare",
    "capan": "capere",
    "capanne": "capanna",
    "capannelli": "capannello",
    "capanni": "capanno",
    "capannoni": "capannone",
    "capano": "capere",
    "caparbi": "caparbio",
    "caparbia": "caparbio",
    "caparbie": "caparbio",
    "caparre": "caparra",
    "capatine": "capatina",
    "cape": "capere",
    "capeggerai": "capeggiare",
    "capeggeran": "capeggiare",
    "capeggeranno": "capeggiare",
    "capeggerebbe": "capeggiare",
    "capeggerebber": "capeggiare",
    "capeggerebbero": "capeggiare",
    "capeggerei": "capeggiare",
    "capeggeremmo": "capeggiare",
    "capeggeremo": "capeggiare",
    "capeggereste": "capeggiare",
    "capeggeresti": "capeggiare",
    "capeggerete": "capeggiare",
    "capeggerà": "capeggiare",
    "capeggerò": "capeggiare",
    "capeggi": "capeggiare",
    "capeggia": "capeggiare",
    "capeggiai": "capeggiare",
    "capeggiammo": "capeggiare",
    "capeggiamo": "capeggiare",
    "capeggian": "capeggiare",
    "capeggiando": "capeggiare",
    "capeggiano": "capeggiare",
    "capeggiante": "capeggiare",
    "capeggianti": "capeggiare",
    "capeggiar": "capeggiare",
    "capeggiaron": "capeggiare",
    "capeggiarono": "capeggiare",
    "capeggiasse": "capeggiare",
    "capeggiasser": "capeggiare",
    "capeggiassero": "capeggiare",
    "capeggiassi": "capeggiare",
    "capeggiassimo": "capeggiare",
    "capeggiaste": "capeggiare",
    "capeggiasti": "capeggiare",
    "capeggiata": "capeggiare",
    "capeggiate": "capeggiare",
    "capeggiati": "capeggiare",
    "capeggiato": "capeggiare",
    "capeggiava": "capeggiare",
    "capeggiavamo": "capeggiare",
    "capeggiavan": "capeggiare",
    "capeggiavano": "capeggiare",
    "capeggiavate": "capeggiare",
    "capeggiavi": "capeggiare",
    "capeggiavo": "capeggiare",
    "capeggin": "capeggiare",
    "capeggino": "capeggiare",
    "capeggio": "capeggiare",
    "capeggiò": "capeggiare",
    "capei": "capere",
    "capelli": "capello",
    "capelloni": "capellone",
    "capelluta": "capelluto",
    "capellute": "capelluto",
    "capelluti": "capelluto",
    "capemmo": "capere",
    "capendo": "capire",
    "capente": "capire",
    "capenti": "capire",
    "caper": "capere",
    "caperai": "capere",
    "caperan": "capere",
    "caperanno": "capere",
    "caperebbe": "capere",
    "caperebber": "capere",
    "caperebbero": "capere",
    "caperei": "capere",
    "caperemmo": "capere",
    "caperemo": "capere",
    "capereste": "capere",
    "caperesti": "capere",
    "caperete": "capere",
    "caperon": "capere",
    "caperono": "capere",
    "caperà": "capere",
    "caperò": "capere",
    "capesse": "capere",
    "capesser": "capere",
    "capessero": "capere",
    "capessi": "capere",
    "capessimo": "capere",
    "capeste": "capere",
    "capesti": "capere",
    "capete": "capere",
    "capetti": "capetto",
    "capeva": "capere",
    "capevamo": "capere",
    "capevan": "capere",
    "capevano": "capere",
    "capevate": "capere",
    "capevi": "capere",
    "capevo": "capere",
    "capezzali": "capezzale",
    "capezzoli": "capezzolo",
    "capi": "capo",
    "capiamo": "capire",
    "capiate": "capire",
    "capibanda": "capobanda",
    "capiclan": "capoclan",
    "capicorrente": "capocorrente",
    "capicosca": "capocosca",
    "capidelegazione": "capodelegazione",
    "capienti": "capiente",
    "capienze": "capienza",
    "capifamiglia": "capofamiglia",
    "capigabinetto": "capogabinetto",
    "capigliature": "capigliatura",
    "capigruppo": "capogruppo",
    "capii": "capire",
    "capilista": "capolista",
    "capillari": "capillare",
    "capimafia": "capomafia",
    "capimmo": "capire",
    "capinere": "capinera",
    "capipattuglia": "capopattuglia",
    "capipopolo": "capopopolo",
    "capir": "capire",
    "capirai": "capire",
    "capiran": "capire",
    "capiranno": "capire",
    "capirebbe": "capire",
    "capirebber": "capire",
    "capirebbero": "capire",
    "capirei": "capire",
    "capiremmo": "capire",
    "capiremo": "capire",
    "capireparto": "caporeparto",
    "capireste": "capire",
    "capiresti": "capire",
    "capirete": "capire",
    "capiron": "capire",
    "capirono": "capire",
    "capirà": "capire",
    "capirò": "capire",
    "capisca": "capire",
    "capiscan": "capire",
    "capiscano": "capire",
    "capisce": "capire",
    "capisci": "capire",
    "capisco": "capire",
    "capiscon": "capire",
    "capiscono": "capire",
    "capiscuola": "caposcuola",
    "capiservizio": "caposervizio",
    "capisquadra": "caposquadra",
    "capisse": "capire",
    "capisser": "capire",
    "capissero": "capire",
    "capissi": "capire",
    "capissimo": "capire",
    "capistazione": "capostazione",
    "capiste": "capire",
    "capisti": "capire",
    "capistruttura": "capostruttura",
    "capita": "capitare",
    "capitai": "capitare",
    "capitali": "capitale",
    "capitaline": "capitalina",
    "capitalismi": "capitalismo",
    "capitaliste": "capitalista",
    "capitalisti": "capitalista",
    "capitalistica": "capitalistico",
    "capitalistiche": "capitalistico",
    "capitalistici": "capitalistico",
    "capitalizza": "capitalizzare",
    "capitalizzai": "capitalizzare",
    "capitalizzammo": "capitalizzare",
    "capitalizzan": "capitalizzare",
    "capitalizzando": "capitalizzare",
    "capitalizzano": "capitalizzare",
    "capitalizzante": "capitalizzare",
    "capitalizzanti": "capitalizzare",
    "capitalizzar": "capitalizzare",
    "capitalizzaron": "capitalizzare",
    "capitalizzarono": "capitalizzare",
    "capitalizzasse": "capitalizzare",
    "capitalizzasser": "capitalizzare",
    "capitalizzassero": "capitalizzare",
    "capitalizzassi": "capitalizzare",
    "capitalizzassimo": "capitalizzare",
    "capitalizzaste": "capitalizzare",
    "capitalizzasti": "capitalizzare",
    "capitalizzata": "capitalizzare",
    "capitalizzate": "capitalizzare",
    "capitalizzati": "capitalizzare",
    "capitalizzato": "capitalizzare",
    "capitalizzava": "capitalizzare",
    "capitalizzavamo": "capitalizzare",
    "capitalizzavan": "capitalizzare",
    "capitalizzavano": "capitalizzare",
    "capitalizzavate": "capitalizzare",
    "capitalizzavi": "capitalizzare",
    "capitalizzavo": "capitalizzare",
    "capitalizzazioni": "capitalizzazione",
    "capitalizzerai": "capitalizzare",
    "capitalizzeran": "capitalizzare",
    "capitalizzeranno": "capitalizzare",
    "capitalizzerebbe": "capitalizzare",
    "capitalizzerebber": "capitalizzare",
    "capitalizzerebbero": "capitalizzare",
    "capitalizzerei": "capitalizzare",
    "capitalizzeremmo": "capitalizzare",
    "capitalizzeremo": "capitalizzare",
    "capitalizzereste": "capitalizzare",
    "capitalizzeresti": "capitalizzare",
    "capitalizzerete": "capitalizzare",
    "capitalizzerà": "capitalizzare",
    "capitalizzerò": "capitalizzare",
    "capitalizzi": "capitalizzare",
    "capitalizziamo": "capitalizzare",
    "capitalizziate": "capitalizzare",
    "capitalizzin": "capitalizzare",
    "capitalizzino": "capitalizzare",
    "capitalizzo": "capitalizzare",
    "capitalizzò": "capitalizzare",
    "capitammo": "capitare",
    "capitan": "capitare",
    "capitana": "capitanare",
    "capitanai": "capitanare",
    "capitanammo": "capitanare",
    "capitanan": "capitanare",
    "capitanando": "capitanare",
    "capitanano": "capitanare",
    "capitanante": "capitanare",
    "capitananti": "capitanare",
    "capitanar": "capitanare",
    "capitanaron": "capitanare",
    "capitanarono": "capitanare",
    "capitanasse": "capitanare",
    "capitanasser": "capitanare",
    "capitanassero": "capitanare",
    "capitanassi": "capitanare",
    "capitanassimo": "capitanare",
    "capitanaste": "capitanare",
    "capitanasti": "capitanare",
    "capitanata": "capitanare",
    "capitanate": "capitanare",
    "capitanati": "capitanare",
    "capitanato": "capitanare",
    "capitanava": "capitanare",
    "capitanavamo": "capitanare",
    "capitanavan": "capitanare",
    "capitanavano": "capitanare",
    "capitanavate": "capitanare",
    "capitanavi": "capitanare",
    "capitanavo": "capitanare",
    "capitando": "capitare",
    "capitanerai": "capitanare",
    "capitaneran": "capitanare",
    "capitaneranno": "capitanare",
    "capitanerebbe": "capitanare",
    "capitanerebber": "capitanare",
    "capitanerebbero": "capitanare",
    "capitanerei": "capitanare",
    "capitaneremmo": "capitanare",
    "capitaneremo": "capitanare",
    "capitanereste": "capitanare",
    "capitaneresti": "capitanare",
    "capitanerete": "capitanare",
    "capitanerie": "capitaneria",
    "capitanerà": "capitanare",
    "capitanerò": "capitanare",
    "capitani": "capitano",
    "capitaniamo": "capitanare",
    "capitaniate": "capitanare",
    "capitanin": "capitanare",
    "capitanino": "capitanare",
    "capitano": "capitare",
    "capitante": "capitare",
    "capitanti": "capitare",
    "capitanò": "capitanare",
    "capitar": "capitare",
    "capitaron": "capitare",
    "capitarono": "capitare",
    "capitasse": "capitare",
    "capitasser": "capitare",
    "capitassero": "capitare",
    "capitassi": "capitare",
    "capitassimo": "capitare",
    "capitaste": "capitare",
    "capitasti": "capitare",
    "capitata": "capitare",
    "capitate": "capitare",
    "capitati": "capitare",
    "capitato": "capitare",
    "capitava": "capitare",
    "capitavamo": "capitare",
    "capitavan": "capitare",
    "capitavano": "capitare",
    "capitavate": "capitare",
    "capitavi": "capitare",
    "capitavo": "capitare",
    "capite": "capire",
    "capitelli": "capitello",
    "capiterai": "capitare",
    "capiteran": "capitare",
    "capiteranno": "capitare",
    "capiterebbe": "capitare",
    "capiterebber": "capitare",
    "capiterebbero": "capitare",
    "capiterei": "capitare",
    "capiteremmo": "capitare",
    "capiteremo": "capitare",
    "capitereste": "capitare",
    "capiteresti": "capitare",
    "capiterete": "capitare",
    "capiterà": "capitare",
    "capiterò": "capitare",
    "capiti": "capitare",
    "capitiamo": "capitare",
    "capitiate": "capitare",
    "capitin": "capitare",
    "capitino": "capitare",
    "capito": "capitare",
    "capitola": "capitolare",
    "capitolai": "capitolare",
    "capitolammo": "capitolare",
    "capitolan": "capitolare",
    "capitolando": "capitolare",
    "capitolano": "capitolare",
    "capitolante": "capitolare",
    "capitolanti": "capitolare",
    "capitolar": "capitolare",
    "capitolari": "capitolare",
    "capitolaron": "capitolare",
    "capitolarono": "capitolare",
    "capitolasse": "capitolare",
    "capitolasser": "capitolare",
    "capitolassero": "capitolare",
    "capitolassi": "capitolare",
    "capitolassimo": "capitolare",
    "capitolaste": "capitolare",
    "capitolasti": "capitolare",
    "capitolata": "capitolare",
    "capitolate": "capitolare",
    "capitolati": "capitolato",
    "capitolato": "capitolare",
    "capitolava": "capitolare",
    "capitolavamo": "capitolare",
    "capitolavan": "capitolare",
    "capitolavano": "capitolare",
    "capitolavate": "capitolare",
    "capitolavi": "capitolare",
    "capitolavo": "capitolare",
    "capitolazioni": "capitolazione",
    "capitolerai": "capitolare",
    "capitoleran": "capitolare",
    "capitoleranno": "capitolare",
    "capitolerebbe": "capitolare",
    "capitolerebber": "capitolare",
    "capitolerebbero": "capitolare",
    "capitolerei": "capitolare",
    "capitoleremmo": "capitolare",
    "capitoleremo": "capitolare",
    "capitolereste": "capitolare",
    "capitoleresti": "capitolare",
    "capitolerete": "capitolare",
    "capitolerà": "capitolare",
    "capitolerò": "capitolare",
    "capitoletti": "capitoletto",
    "capitoli": "capitolo",
    "capitoliamo": "capitolare",
    "capitoliate": "capitolare",
    "capitolin": "capitolare",
    "capitolina": "capitolino",
    "capitoline": "capitolino",
    "capitolini": "capitolino",
    "capitolino": "capitolare",
    "capitolo": "capitolare",
    "capitolò": "capitolare",
    "capitombola": "capitombolare",
    "capitombolai": "capitombolare",
    "capitombolammo": "capitombolare",
    "capitombolan": "capitombolare",
    "capitombolando": "capitombolare",
    "capitombolano": "capitombolare",
    "capitombolante": "capitombolare",
    "capitombolanti": "capitombolare",
    "capitombolar": "capitombolare",
    "capitombolaron": "capitombolare",
    "capitombolarono": "capitombolare",
    "capitombolasse": "capitombolare",
    "capitombolasser": "capitombolare",
    "capitombolassero": "capitombolare",
    "capitombolassi": "capitombolare",
    "capitombolassimo": "capitombolare",
    "capitombolaste": "capitombolare",
    "capitombolasti": "capitombolare",
    "capitombolata": "capitombolare",
    "capitombolate": "capitombolare",
    "capitombolati": "capitombolare",
    "capitombolato": "capitombolare",
    "capitombolava": "capitombolare",
    "capitombolavamo": "capitombolare",
    "capitombolavan": "capitombolare",
    "capitombolavano": "capitombolare",
    "capitombolavate": "capitombolare",
    "capitombolavi": "capitombolare",
    "capitombolavo": "capitombolare",
    "capitombolerai": "capitombolare",
    "capitomboleran": "capitombolare",
    "capitomboleranno": "capitombolare",
    "capitombolerebbe": "capitombolare",
    "capitombolerebber": "capitombolare",
    "capitombolerebbero": "capitombolare",
    "capitombolerei": "capitombolare",
    "capitomboleremmo": "capitombolare",
    "capitomboleremo": "capitombolare",
    "capitombolereste": "capitombolare",
    "capitomboleresti": "capitombolare",
    "capitombolerete": "capitombolare",
    "capitombolerà": "capitombolare",
    "capitombolerò": "capitombolare",
    "capitomboli": "capitombolo",
    "capitomboliamo": "capitombolare",
    "capitomboliate": "capitombolare",
    "capitombolin": "capitombolare",
    "capitombolino": "capitombolare",
    "capitombolo": "capitombolare",
    "capitombolò": "capitombolare",
    "capitoni": "capitone",
    "capitò": "capitare",
    "capiufficio": "capoufficio",
    "capiva": "capire",
    "capivamo": "capire",
    "capivan": "capire",
    "capivano": "capire",
    "capivate": "capire",
    "capivi": "capire",
    "capivo": "capire",
    "capo": "capere",
    "capocannonieri": "capocannoniere",
    "capocciate": "capocciata",
    "capoccioni": "capoccione",
    "capocomici": "capocomico",
    "capodanni": "capodanno",
    "capofitta": "capofitto",
    "capofitte": "capofitto",
    "capofitti": "capofitto",
    "capogiri": "capogiro",
    "capolavori": "capolavoro",
    "capoluoghi": "capoluogo",
    "capon": "capere",
    "capono": "capere",
    "caporalati": "caporalato",
    "caporali": "caporale",
    "caporedattori": "caporedattore",
    "caporioni": "caporione",
    "caposaldi": "caposaldo",
    "capostipiti": "capostipite",
    "capota": "capotare",
    "capotai": "capotare",
    "capotammo": "capotare",
    "capotan": "capotare",
    "capotando": "capotare",
    "capotano": "capotare",
    "capotante": "capotare",
    "capotanti": "capotare",
    "capotar": "capotare",
    "capotaron": "capotare",
    "capotarono": "capotare",
    "capotasse": "capotare",
    "capotasser": "capotare",
    "capotassero": "capotare",
    "capotassi": "capotare",
    "capotassimo": "capotare",
    "capotaste": "capotare",
    "capotasti": "capotare",
    "capotata": "capotare",
    "capotate": "capotare",
    "capotati": "capotare",
    "capotato": "capotare",
    "capotava": "capotare",
    "capotavamo": "capotare",
    "capotavan": "capotare",
    "capotavano": "capotare",
    "capotavate": "capotare",
    "capotavi": "capotare",
    "capotavo": "capotare",
    "capoterai": "capotare",
    "capoteran": "capotare",
    "capoteranno": "capotare",
    "capoterebbe": "capotare",
    "capoterebber": "capotare",
    "capoterebbero": "capotare",
    "capoterei": "capotare",
    "capoteremmo": "capotare",
    "capoteremo": "capotare",
    "capotereste": "capotare",
    "capoteresti": "capotare",
    "capoterete": "capotare",
    "capoterà": "capotare",
    "capoterò": "capotare",
    "capoti": "capotare",
    "capotiamo": "capotare",
    "capotiate": "capotare",
    "capotin": "capotare",
    "capotino": "capotare",
    "capoto": "capotare",
    "capotreni": "capotreno",
    "capotta": "capottare",
    "capottai": "capottare",
    "capottammo": "capottare",
    "capottan": "capottare",
    "capottando": "capottare",
    "capottano": "capottare",
    "capottante": "capottare",
    "capottanti": "capottare",
    "capottar": "capottare",
    "capottaron": "capottare",
    "capottarono": "capottare",
    "capottasse": "capottare",
    "capottasser": "capottare",
    "capottassero": "capottare",
    "capottassi": "capottare",
    "capottassimo": "capottare",
    "capottaste": "capottare",
    "capottasti": "capottare",
    "capottata": "capottare",
    "capottate": "capottare",
    "capottati": "capottare",
    "capottato": "capottare",
    "capottava": "capottare",
    "capottavamo": "capottare",
    "capottavan": "capottare",
    "capottavano": "capottare",
    "capottavate": "capottare",
    "capottavi": "capottare",
    "capottavo": "capottare",
    "capotterai": "capottare",
    "capotteran": "capottare",
    "capotteranno": "capottare",
    "capotterebbe": "capottare",
    "capotterebber": "capottare",
    "capotterebbero": "capottare",
    "capotterei": "capottare",
    "capotteremmo": "capottare",
    "capotteremo": "capottare",
    "capottereste": "capottare",
    "capotteresti": "capottare",
    "capotterete": "capottare",
    "capotterà": "capottare",
    "capotterò": "capottare",
    "capotti": "capottare",
    "capottiamo": "capottare",
    "capottiate": "capottare",
    "capottin": "capottare",
    "capottino": "capottare",
    "capotto": "capottare",
    "capottò": "capottare",
    "capotò": "capotare",
    "capovolga": "capovolgere",
    "capovolgan": "capovolgere",
    "capovolgano": "capovolgere",
    "capovolge": "capovolgere",
    "capovolgemmo": "capovolgere",
    "capovolgendo": "capovolgere",
    "capovolgente": "capovolgere",
    "capovolgenti": "capovolgere",
    "capovolger": "capovolgere",
    "capovolgerai": "capovolgere",
    "capovolgeran": "capovolgere",
    "capovolgeranno": "capovolgere",
    "capovolgerebbe": "capovolgere",
    "capovolgerebber": "capovolgere",
    "capovolgerebbero": "capovolgere",
    "capovolgerei": "capovolgere",
    "capovolgeremmo": "capovolgere",
    "capovolgeremo": "capovolgere",
    "capovolgereste": "capovolgere",
    "capovolgeresti": "capovolgere",
    "capovolgerete": "capovolgere",
    "capovolgerà": "capovolgere",
    "capovolgerò": "capovolgere",
    "capovolgesse": "capovolgere",
    "capovolgesser": "capovolgere",
    "capovolgessero": "capovolgere",
    "capovolgessi": "capovolgere",
    "capovolgessimo": "capovolgere",
    "capovolgeste": "capovolgere",
    "capovolgesti": "capovolgere",
    "capovolgete": "capovolgere",
    "capovolgeva": "capovolgere",
    "capovolgevamo": "capovolgere",
    "capovolgevan": "capovolgere",
    "capovolgevano": "capovolgere",
    "capovolgevate": "capovolgere",
    "capovolgevi": "capovolgere",
    "capovolgevo": "capovolgere",
    "capovolgi": "capovolgere",
    "capovolgiamo": "capovolgere",
    "capovolgiate": "capovolgere",
    "capovolgimenti": "capovolgimento",
    "capovolgo": "capovolgere",
    "capovolgon": "capovolgere",
    "capovolgono": "capovolgere",
    "capovolse": "capovolgere",
    "capovolser": "capovolgere",
    "capovolsero": "capovolgere",
    "capovolsi": "capovolgere",
    "capovolta": "capovolgere",
    "capovolte": "capovolgere",
    "capovolti": "capovolgere",
    "capovolto": "capovolgere",
    "cappe": "cappa",
    "cappellacci": "cappellaccio",
    "cappellani": "cappellano",
    "cappelle": "cappella",
    "cappelletti": "cappelletto",
    "cappelli": "cappello",
    "cappellini": "cappellino",
    "cappelloni": "cappellone",
    "cappellucci": "cappelluccio",
    "capperi": "cappero",
    "cappi": "cappio",
    "cappona": "capponare",
    "capponai": "capponare",
    "capponammo": "capponare",
    "capponan": "capponare",
    "capponando": "capponare",
    "capponano": "capponare",
    "capponante": "capponare",
    "capponanti": "capponare",
    "capponar": "capponare",
    "capponaron": "capponare",
    "capponarono": "capponare",
    "capponasse": "capponare",
    "capponasser": "capponare",
    "capponassero": "capponare",
    "capponassi": "capponare",
    "capponassimo": "capponare",
    "capponaste": "capponare",
    "capponasti": "capponare",
    "capponata": "capponare",
    "capponate": "capponare",
    "capponati": "capponare",
    "capponato": "capponare",
    "capponava": "capponare",
    "capponavamo": "capponare",
    "capponavan": "capponare",
    "capponavano": "capponare",
    "capponavate": "capponare",
    "capponavi": "capponare",
    "capponavo": "capponare",
    "capponerai": "capponare",
    "capponeran": "capponare",
    "capponeranno": "capponare",
    "capponerebbe": "capponare",
    "capponerebber": "capponare",
    "capponerebbero": "capponare",
    "capponerei": "capponare",
    "capponeremmo": "capponare",
    "capponeremo": "capponare",
    "capponereste": "capponare",
    "capponeresti": "capponare",
    "capponerete": "capponare",
    "capponerà": "capponare",
    "capponerò": "capponare",
    "capponi": "cappone",
    "capponiamo": "capponare",
    "capponiate": "capponare",
    "capponin": "capponare",
    "capponino": "capponare",
    "cappono": "capponare",
    "capponò": "capponare",
    "cappotta": "cappottare",
    "cappottai": "cappottare",
    "cappottammo": "cappottare",
    "cappottan": "cappottare",
    "cappottando": "cappottare",
    "cappottano": "cappottare",
    "cappottante": "cappottare",
    "cappottanti": "cappottare",
    "cappottar": "cappottare",
    "cappottaron": "cappottare",
    "cappottarono": "cappottare",
    "cappottasse": "cappottare",
    "cappottasser": "cappottare",
    "cappottassero": "cappottare",
    "cappottassi": "cappottare",
    "cappottassimo": "cappottare",
    "cappottaste": "cappottare",
    "cappottasti": "cappottare",
    "cappottata": "cappottare",
    "cappottate": "cappottare",
    "cappottati": "cappottare",
    "cappottato": "cappottare",
    "cappottava": "cappottare",
    "cappottavamo": "cappottare",
    "cappottavan": "cappottare",
    "cappottavano": "cappottare",
    "cappottavate": "cappottare",
    "cappottavi": "cappottare",
    "cappottavo": "cappottare",
    "cappotterai": "cappottare",
    "cappotteran": "cappottare",
    "cappotteranno": "cappottare",
    "cappotterebbe": "cappottare",
    "cappotterebber": "cappottare",
    "cappotterebbero": "cappottare",
    "cappotterei": "cappottare",
    "cappotteremmo": "cappottare",
    "cappotteremo": "cappottare",
    "cappottereste": "cappottare",
    "cappotteresti": "cappottare",
    "cappotterete": "cappottare",
    "cappotterà": "cappottare",
    "cappotterò": "cappottare",
    "cappotti": "cappotto",
    "cappottiamo": "cappottare",
    "cappottiate": "cappottare",
    "cappottin": "cappottare",
    "cappottini": "cappottino",
    "cappottino": "cappottare",
    "cappotto": "cappottare",
    "cappottoni": "cappottone",
    "cappottò": "cappottare",
    "cappucce": "cappuccio",
    "cappucci": "cappuccio",
    "cappuccia": "cappuccio",
    "cappuccini": "cappuccino",
    "capresi": "caprese",
    "caprette": "capretta",
    "capretti": "capretto",
    "capri": "caprio",
    "capricci": "capriccio",
    "capricciosa": "capriccioso",
    "capricciose": "capriccioso",
    "capricciosi": "capriccioso",
    "caprina": "caprino",
    "caprine": "caprino",
    "caprini": "caprino",
    "capriole": "capriola",
    "caprioli": "capriolo",
    "caproni": "caprone",
    "capsule": "capsula",
    "capta": "captare",
    "captai": "captare",
    "captammo": "captare",
    "captan": "captare",
    "captando": "captare",
    "captano": "captare",
    "captante": "captare",
    "captanti": "captare",
    "captar": "captare",
    "captaron": "captare",
    "captarono": "captare",
    "captasse": "captare",
    "captasser": "captare",
    "captassero": "captare",
    "captassi": "captare",
    "captassimo": "captare",
    "captaste": "captare",
    "captasti": "captare",
    "captata": "captare",
    "captate": "captare",
    "captati": "captare",
    "captato": "captare",
    "captava": "captare",
    "captavamo": "captare",
    "captavan": "captare",
    "captavano": "captare",
    "captavate": "captare",
    "captavi": "captare",
    "captavo": "captare",
    "capterai": "captare",
    "capteran": "captare",
    "capteranno": "captare",
    "capterebbe": "captare",
    "capterebber": "captare",
    "capterebbero": "captare",
    "capterei": "captare",
    "capteremmo": "captare",
    "capteremo": "captare",
    "captereste": "captare",
    "capteresti": "captare",
    "capterete": "captare",
    "capterà": "captare",
    "capterò": "captare",
    "capti": "captare",
    "captiamo": "captare",
    "captiate": "captare",
    "captin": "captare",
    "captino": "captare",
    "capto": "captare",
    "captò": "captare",
    "caputa": "capere",
    "capute": "capere",
    "caputi": "capere",
    "caputo": "capere",
    "capziosa": "capzioso",
    "capziose": "capzioso",
    "capziosi": "capzioso",
    "capè": "capere",
    "capì": "capire",
    "cara": "caro",
    "carabine": "carabina",
    "carabineros": "carabinero",
    "carabinieri": "carabiniere",
    "caracolla": "caracollare",
    "caracollai": "caracollare",
    "caracollammo": "caracollare",
    "caracollan": "caracollare",
    "caracollando": "caracollare",
    "caracollano": "caracollare",
    "caracollante": "caracollare",
    "caracollanti": "caracollare",
    "caracollar": "caracollare",
    "caracollaron": "caracollare",
    "caracollarono": "caracollare",
    "caracollasse": "caracollare",
    "caracollasser": "caracollare",
    "caracollassero": "caracollare",
    "caracollassi": "caracollare",
    "caracollassimo": "caracollare",
    "caracollaste": "caracollare",
    "caracollasti": "caracollare",
    "caracollata": "caracollare",
    "caracollate": "caracollare",
    "caracollati": "caracollare",
    "caracollato": "caracollare",
    "caracollava": "caracollare",
    "caracollavamo": "caracollare",
    "caracollavan": "caracollare",
    "caracollavano": "caracollare",
    "caracollavate": "caracollare",
    "caracollavi": "caracollare",
    "caracollavo": "caracollare",
    "caracollerai": "caracollare",
    "caracolleran": "caracollare",
    "caracolleranno": "caracollare",
    "caracollerebbe": "caracollare",
    "caracollerebber": "caracollare",
    "caracollerebbero": "caracollare",
    "caracollerei": "caracollare",
    "caracolleremmo": "caracollare",
    "caracolleremo": "caracollare",
    "caracollereste": "caracollare",
    "caracolleresti": "caracollare",
    "caracollerete": "caracollare",
    "caracollerà": "caracollare",
    "caracollerò": "caracollare",
    "caracolli": "caracollare",
    "caracolliamo": "caracollare",
    "caracolliate": "caracollare",
    "caracollin": "caracollare",
    "caracollino": "caracollare",
    "caracollo": "caracollare",
    "caracollò": "caracollare",
    "carambola": "carambolare",
    "carambolai": "carambolare",
    "carambolammo": "carambolare",
    "carambolan": "carambolare",
    "carambolando": "carambolare",
    "carambolano": "carambolare",
    "carambolante": "carambolare",
    "carambolanti": "carambolare",
    "carambolar": "carambolare",
    "carambolaron": "carambolare",
    "carambolarono": "carambolare",
    "carambolasse": "carambolare",
    "carambolasser": "carambolare",
    "carambolassero": "carambolare",
    "carambolassi": "carambolare",
    "carambolassimo": "carambolare",
    "carambolaste": "carambolare",
    "carambolasti": "carambolare",
    "carambolata": "carambolare",
    "carambolate": "carambolare",
    "carambolati": "carambolare",
    "carambolato": "carambolare",
    "carambolava": "carambolare",
    "carambolavamo": "carambolare",
    "carambolavan": "carambolare",
    "carambolavano": "carambolare",
    "carambolavate": "carambolare",
    "carambolavi": "carambolare",
    "carambolavo": "carambolare",
    "carambole": "carambola",
    "carambolerai": "carambolare",
    "caramboleran": "carambolare",
    "caramboleranno": "carambolare",
    "carambolerebbe": "carambolare",
    "carambolerebber": "carambolare",
    "carambolerebbero": "carambolare",
    "carambolerei": "carambolare",
    "caramboleremmo": "carambolare",
    "caramboleremo": "carambolare",
    "carambolereste": "carambolare",
    "caramboleresti": "carambolare",
    "carambolerete": "carambolare",
    "carambolerà": "carambolare",
    "carambolerò": "carambolare",
    "caramboli": "carambolare",
    "caramboliamo": "carambolare",
    "caramboliate": "carambolare",
    "carambolin": "carambolare",
    "carambolino": "carambolare",
    "carambolo": "carambolare",
    "carambolò": "carambolare",
    "caramella": "caramellare",
    "caramellai": "caramellare",
    "caramellammo": "caramellare",
    "caramellan": "caramellare",
    "caramellando": "caramellare",
    "caramellano": "caramellare",
    "caramellante": "caramellare",
    "caramellanti": "caramellare",
    "caramellar": "caramellare",
    "caramellaron": "caramellare",
    "caramellarono": "caramellare",
    "caramellasse": "caramellare",
    "caramellasser": "caramellare",
    "caramellassero": "caramellare",
    "caramellassi": "caramellare",
    "caramellassimo": "caramellare",
    "caramellaste": "caramellare",
    "caramellasti": "caramellare",
    "caramellata": "caramellare",
    "caramellate": "caramellare",
    "caramellati": "caramellare",
    "caramellato": "caramellare",
    "caramellava": "caramellare",
    "caramellavamo": "caramellare",
    "caramellavan": "caramellare",
    "caramellavano": "caramellare",
    "caramellavate": "caramellare",
    "caramellavi": "caramellare",
    "caramellavo": "caramellare",
    "caramelle": "caramella",
    "caramellerai": "caramellare",
    "caramelleran": "caramellare",
    "caramelleranno": "caramellare",
    "caramellerebbe": "caramellare",
    "caramellerebber": "caramellare",
    "caramellerebbero": "caramellare",
    "caramellerei": "caramellare",
    "caramelleremmo": "caramellare",
    "caramelleremo": "caramellare",
    "caramellereste": "caramellare",
    "caramelleresti": "caramellare",
    "caramellerete": "caramellare",
    "caramellerà": "caramellare",
    "caramellerò": "caramellare",
    "caramelli": "caramellare",
    "caramelliamo": "caramellare",
    "caramelliate": "caramellare",
    "caramellin": "caramellare",
    "caramellino": "caramellare",
    "caramello": "caramellare",
    "caramellosa": "caramelloso",
    "caramellose": "caramelloso",
    "caramellosi": "caramelloso",
    "caramellò": "caramellare",
    "carata": "caratare",
    "caratai": "caratare",
    "caratammo": "caratare",
    "caratan": "caratare",
    "caratando": "caratare",
    "caratano": "caratare",
    "caratante": "caratare",
    "caratanti": "caratare",
    "caratar": "caratare",
    "carataron": "caratare",
    "caratarono": "caratare",
    "caratasse": "caratare",
    "caratasser": "caratare",
    "caratassero": "caratare",
    "caratassi": "caratare",
    "caratassimo": "caratare",
    "carataste": "caratare",
    "caratasti": "caratare",
    "caratata": "caratare",
    "caratate": "caratare",
    "caratati": "caratare",
    "caratato": "caratare",
    "caratava": "caratare",
    "caratavamo": "caratare",
    "caratavan": "caratare",
    "caratavano": "caratare",
    "caratavate": "caratare",
    "caratavi": "caratare",
    "caratavo": "caratare",
    "caraterai": "caratare",
    "carateran": "caratare",
    "carateranno": "caratare",
    "caraterebbe": "caratare",
    "caraterebber": "caratare",
    "caraterebbero": "caratare",
    "caraterei": "caratare",
    "carateremmo": "caratare",
    "carateremo": "caratare",
    "caratereste": "caratare",
    "carateresti": "caratare",
    "caraterete": "caratare",
    "caraterà": "caratare",
    "caraterò": "caratare",
    "carati": "caratare",
    "caratiamo": "caratare",
    "caratiate": "caratare",
    "caratin": "caratare",
    "caratino": "caratare",
    "carato": "caratare",
    "caratteracci": "caratteraccio",
    "caratteri": "carattere",
    "caratteriali": "caratteriale",
    "caratterini": "caratterino",
    "caratteristi": "caratterista",
    "caratteristica": "caratteristico",
    "caratteristiche": "caratteristico",
    "caratteristici": "caratteristico",
    "caratterizza": "caratterizzare",
    "caratterizzai": "caratterizzare",
    "caratterizzammo": "caratterizzare",
    "caratterizzan": "caratterizzare",
    "caratterizzando": "caratterizzare",
    "caratterizzano": "caratterizzare",
    "caratterizzante": "caratterizzare",
    "caratterizzanti": "caratterizzare",
    "caratterizzar": "caratterizzare",
    "caratterizzaron": "caratterizzare",
    "caratterizzarono": "caratterizzare",
    "caratterizzasse": "caratterizzare",
    "caratterizzasser": "caratterizzare",
    "caratterizzassero": "caratterizzare",
    "caratterizzassi": "caratterizzare",
    "caratterizzassimo": "caratterizzare",
    "caratterizzaste": "caratterizzare",
    "caratterizzasti": "caratterizzare",
    "caratterizzata": "caratterizzare",
    "caratterizzate": "caratterizzare",
    "caratterizzati": "caratterizzare",
    "caratterizzato": "caratterizzare",
    "caratterizzava": "caratterizzare",
    "caratterizzavamo": "caratterizzare",
    "caratterizzavan": "caratterizzare",
    "caratterizzavano": "caratterizzare",
    "caratterizzavate": "caratterizzare",
    "caratterizzavi": "caratterizzare",
    "caratterizzavo": "caratterizzare",
    "caratterizzazioni": "caratterizzazione",
    "caratterizzerai": "caratterizzare",
    "caratterizzeran": "caratterizzare",
    "caratterizzeranno": "caratterizzare",
    "caratterizzerebbe": "caratterizzare",
    "caratterizzerebber": "caratterizzare",
    "caratterizzerebbero": "caratterizzare",
    "caratterizzerei": "caratterizzare",
    "caratterizzeremmo": "caratterizzare",
    "caratterizzeremo": "caratterizzare",
    "caratterizzereste": "caratterizzare",
    "caratterizzeresti": "caratterizzare",
    "caratterizzerete": "caratterizzare",
    "caratterizzerà": "caratterizzare",
    "caratterizzerò": "caratterizzare",
    "caratterizzi": "caratterizzare",
    "caratterizziamo": "caratterizzare",
    "caratterizziate": "caratterizzare",
    "caratterizzin": "caratterizzare",
    "caratterizzino": "caratterizzare",
    "caratterizzo": "caratterizzare",
    "caratterizzò": "caratterizzare",
    "carature": "caratura",
    "caratò": "caratare",
    "caravanserragli": "caravanserraglio",
    "caravelle": "caravella",
    "carboidrati": "carboidrato",
    "carbonara": "carbonaro",
    "carbonare": "carbonaro",
    "carbonari": "carbonaro",
    "carboncini": "carboncino",
    "carboni": "carbone",
    "carbonica": "carbonico",
    "carboniche": "carbonico",
    "carbonici": "carbonico",
    "carbonifera": "carbonifero",
    "carbonifere": "carbonifero",
    "carboniferi": "carbonifero",
    "carbonii": "carbonio",
    "carbonizza": "carbonizzare",
    "carbonizzai": "carbonizzare",
    "carbonizzammo": "carbonizzare",
    "carbonizzan": "carbonizzare",
    "carbonizzando": "carbonizzare",
    "carbonizzano": "carbonizzare",
    "carbonizzante": "carbonizzare",
    "carbonizzanti": "carbonizzare",
    "carbonizzar": "carbonizzare",
    "carbonizzaron": "carbonizzare",
    "carbonizzarono": "carbonizzare",
    "carbonizzasse": "carbonizzare",
    "carbonizzasser": "carbonizzare",
    "carbonizzassero": "carbonizzare",
    "carbonizzassi": "carbonizzare",
    "carbonizzassimo": "carbonizzare",
    "carbonizzaste": "carbonizzare",
    "carbonizzasti": "carbonizzare",
    "carbonizzata": "carbonizzare",
    "carbonizzate": "carbonizzare",
    "carbonizzati": "carbonizzare",
    "carbonizzato": "carbonizzare",
    "carbonizzava": "carbonizzare",
    "carbonizzavamo": "carbonizzare",
    "carbonizzavan": "carbonizzare",
    "carbonizzavano": "carbonizzare",
    "carbonizzavate": "carbonizzare",
    "carbonizzavi": "carbonizzare",
    "carbonizzavo": "carbonizzare",
    "carbonizzerai": "carbonizzare",
    "carbonizzeran": "carbonizzare",
    "carbonizzeranno": "carbonizzare",
    "carbonizzerebbe": "carbonizzare",
    "carbonizzerebber": "carbonizzare",
    "carbonizzerebbero": "carbonizzare",
    "carbonizzerei": "carbonizzare",
    "carbonizzeremmo": "carbonizzare",
    "carbonizzeremo": "carbonizzare",
    "carbonizzereste": "carbonizzare",
    "carbonizzeresti": "carbonizzare",
    "carbonizzerete": "carbonizzare",
    "carbonizzerà": "carbonizzare",
    "carbonizzerò": "carbonizzare",
    "carbonizzi": "carbonizzare",
    "carbonizziamo": "carbonizzare",
    "carbonizziate": "carbonizzare",
    "carbonizzin": "carbonizzare",
    "carbonizzino": "carbonizzare",
    "carbonizzo": "carbonizzare",
    "carbonizzò": "carbonizzare",
    "carbura": "carburare",
    "carburai": "carburare",
    "carburammo": "carburare",
    "carburan": "carburare",
    "carburando": "carburare",
    "carburano": "carburare",
    "carburante": "carburare",
    "carburanti": "carburare",
    "carburar": "carburare",
    "carburaron": "carburare",
    "carburarono": "carburare",
    "carburasse": "carburare",
    "carburasser": "carburare",
    "carburassero": "carburare",
    "carburassi": "carburare",
    "carburassimo": "carburare",
    "carburaste": "carburare",
    "carburasti": "carburare",
    "carburata": "carburare",
    "carburate": "carburare",
    "carburati": "carburare",
    "carburato": "carburare",
    "carburatori": "carburatore",
    "carburava": "carburare",
    "carburavamo": "carburare",
    "carburavan": "carburare",
    "carburavano": "carburare",
    "carburavate": "carburare",
    "carburavi": "carburare",
    "carburavo": "carburare",
    "carburerai": "carburare",
    "carbureran": "carburare",
    "carbureranno": "carburare",
    "carburerebbe": "carburare",
    "carburerebber": "carburare",
    "carburerebbero": "carburare",
    "carburerei": "carburare",
    "carbureremmo": "carburare",
    "carbureremo": "carburare",
    "carburereste": "carburare",
    "carbureresti": "carburare",
    "carburerete": "carburare",
    "carburerà": "carburare",
    "carburerò": "carburare",
    "carburi": "carburare",
    "carburiamo": "carburare",
    "carburiate": "carburare",
    "carburin": "carburare",
    "carburino": "carburare",
    "carburo": "carburare",
    "carburò": "carburare",
    "carcasse": "carcassa",
    "carcera": "carcerare",
    "carcerai": "carcerare",
    "carcerammo": "carcerare",
    "carceran": "carcerare",
    "carcerando": "carcerare",
    "carcerano": "carcerare",
    "carcerante": "carcerare",
    "carceranti": "carcerare",
    "carcerar": "carcerare",
    "carcerari": "carcerario",
    "carceraria": "carcerario",
    "carcerarie": "carcerario",
    "carceraron": "carcerare",
    "carcerarono": "carcerare",
    "carcerasse": "carcerare",
    "carcerasser": "carcerare",
    "carcerassero": "carcerare",
    "carcerassi": "carcerare",
    "carcerassimo": "carcerare",
    "carceraste": "carcerare",
    "carcerasti": "carcerare",
    "carcerata": "carcerato",
    "carcerate": "carcerato",
    "carcerati": "carcerato",
    "carcerato": "carcerare",
    "carcerava": "carcerare",
    "carceravamo": "carcerare",
    "carceravan": "carcerare",
    "carceravano": "carcerare",
    "carceravate": "carcerare",
    "carceravi": "carcerare",
    "carceravo": "carcerare",
    "carcerazioni": "carcerazione",
    "carcererai": "carcerare",
    "carcereran": "carcerare",
    "carcereranno": "carcerare",
    "carcererebbe": "carcerare",
    "carcererebber": "carcerare",
    "carcererebbero": "carcerare",
    "carcererei": "carcerare",
    "carcereremmo": "carcerare",
    "carcereremo": "carcerare",
    "carcerereste": "carcerare",
    "carcereresti": "carcerare",
    "carcererete": "carcerare",
    "carcererà": "carcerare",
    "carcererò": "carcerare",
    "carceri": "carcere",
    "carceriamo": "carcerare",
    "carceriate": "carcerare",
    "carcerieri": "carceriere",
    "carcerin": "carcerare",
    "carcerino": "carcerare",
    "carcero": "carcerare",
    "carcerò": "carcerare",
    "carcinomi": "carcinoma",
    "carciofi": "carciofo",
    "carda": "cardare",
    "cardai": "cardare",
    "cardammo": "cardare",
    "cardan": "cardare",
    "cardando": "cardare",
    "cardano": "cardare",
    "cardante": "cardare",
    "cardanti": "cardare",
    "cardar": "cardare",
    "cardaron": "cardare",
    "cardarono": "cardare",
    "cardasse": "cardare",
    "cardasser": "cardare",
    "cardassero": "cardare",
    "cardassi": "cardare",
    "cardassimo": "cardare",
    "cardaste": "cardare",
    "cardasti": "cardare",
    "cardata": "cardare",
    "cardate": "cardare",
    "cardati": "cardare",
    "cardato": "cardare",
    "cardava": "cardare",
    "cardavamo": "cardare",
    "cardavan": "cardare",
    "cardavano": "cardare",
    "cardavate": "cardare",
    "cardavi": "cardare",
    "cardavo": "cardare",
    "carderai": "cardare",
    "carderan": "cardare",
    "carderanno": "cardare",
    "carderebbe": "cardare",
    "carderebber": "cardare",
    "carderebbero": "cardare",
    "carderei": "cardare",
    "carderemmo": "cardare",
    "carderemo": "cardare",
    "cardereste": "cardare",
    "carderesti": "cardare",
    "carderete": "cardare",
    "carderà": "cardare",
    "carderò": "cardare",
    "cardi": "cardo",
    "cardiaca": "cardiaco",
    "cardiache": "cardiaco",
    "cardiaci": "cardiaco",
    "cardiamo": "cardare",
    "cardiate": "cardare",
    "cardin": "cardare",
    "cardinal": "cardinale",
    "cardinali": "cardinale",
    "cardinalizi": "cardinalizio",
    "cardinalizia": "cardinalizio",
    "cardinalizie": "cardinalizio",
    "cardini": "cardine",
    "cardino": "cardare",
    "cardiochirurghi": "cardiochirurgo",
    "cardiochirurgie": "cardiochirurgia",
    "cardiocircolatori": "cardiocircolatorio",
    "cardiocircolatoria": "cardiocircolatorio",
    "cardiocircolatorie": "cardiocircolatorio",
    "cardiologi": "cardiologo",
    "cardiopatica": "cardiopatico",
    "cardiopatiche": "cardiopatico",
    "cardiopatici": "cardiopatico",
    "cardiopatie": "cardiopatia",
    "cardiovascolari": "cardiovascolare",
    "cardo": "cardare",
    "cardò": "cardare",
    "care": "caro",
    "carena": "carenare",
    "carenai": "carenare",
    "carenammo": "carenare",
    "carenan": "carenare",
    "carenando": "carenare",
    "carenano": "carenare",
    "carenante": "carenare",
    "carenanti": "carenare",
    "carenar": "carenare",
    "carenaron": "carenare",
    "carenarono": "carenare",
    "carenasse": "carenare",
    "carenasser": "carenare",
    "carenassero": "carenare",
    "carenassi": "carenare",
    "carenassimo": "carenare",
    "carenaste": "carenare",
    "carenasti": "carenare",
    "carenata": "carenato",
    "carenate": "carenato",
    "carenati": "carenato",
    "carenato": "carenare",
    "carenava": "carenare",
    "carenavamo": "carenare",
    "carenavan": "carenare",
    "carenavano": "carenare",
    "carenavate": "carenare",
    "carenavi": "carenare",
    "carenavo": "carenare",
    "carene": "carena",
    "carenerai": "carenare",
    "careneran": "carenare",
    "careneranno": "carenare",
    "carenerebbe": "carenare",
    "carenerebber": "carenare",
    "carenerebbero": "carenare",
    "carenerei": "carenare",
    "careneremmo": "carenare",
    "careneremo": "carenare",
    "carenereste": "carenare",
    "careneresti": "carenare",
    "carenerete": "carenare",
    "carenerà": "carenare",
    "carenerò": "carenare",
    "careni": "carenare",
    "careniamo": "carenare",
    "careniate": "carenare",
    "carenin": "carenare",
    "carenino": "carenare",
    "careno": "carenare",
    "carenti": "carente",
    "carenze": "carenza",
    "carenò": "carenare",
    "carestie": "carestia",
    "carezza": "carezzare",
    "carezzai": "carezzare",
    "carezzammo": "carezzare",
    "carezzan": "carezzare",
    "carezzando": "carezzare",
    "carezzano": "carezzare",
    "carezzante": "carezzare",
    "carezzanti": "carezzare",
    "carezzar": "carezzare",
    "carezzaron": "carezzare",
    "carezzarono": "carezzare",
    "carezzasse": "carezzare",
    "carezzasser": "carezzare",
    "carezzassero": "carezzare",
    "carezzassi": "carezzare",
    "carezzassimo": "carezzare",
    "carezzaste": "carezzare",
    "carezzasti": "carezzare",
    "carezzata": "carezzare",
    "carezzate": "carezzare",
    "carezzati": "carezzare",
    "carezzato": "carezzare",
    "carezzava": "carezzare",
    "carezzavamo": "carezzare",
    "carezzavan": "carezzare",
    "carezzavano": "carezzare",
    "carezzavate": "carezzare",
    "carezzavi": "carezzare",
    "carezzavo": "carezzare",
    "carezze": "carezza",
    "carezzerai": "carezzare",
    "carezzeran": "carezzare",
    "carezzeranno": "carezzare",
    "carezzerebbe": "carezzare",
    "carezzerebber": "carezzare",
    "carezzerebbero": "carezzare",
    "carezzerei": "carezzare",
    "carezzeremmo": "carezzare",
    "carezzeremo": "carezzare",
    "carezzereste": "carezzare",
    "carezzeresti": "carezzare",
    "carezzerete": "carezzare",
    "carezzerà": "carezzare",
    "carezzerò": "carezzare",
    "carezzevoli": "carezzevole",
    "carezzi": "carezzare",
    "carezziamo": "carezzare",
    "carezziate": "carezzare",
    "carezzin": "carezzare",
    "carezzino": "carezzare",
    "carezzo": "carezzare",
    "carezzò": "carezzare",
    "cari": "caro",
    "cari-petrolio": "caro-petrolio",
    "caria": "cariare",
    "cariai": "cariare",
    "cariammo": "cariare",
    "cariamo": "cariare",
    "carian": "cariare",
    "cariando": "cariare",
    "cariano": "cariare",
    "cariante": "cariare",
    "carianti": "cariare",
    "cariar": "cariare",
    "cariaron": "cariare",
    "cariarono": "cariare",
    "cariasse": "cariare",
    "cariasser": "cariare",
    "cariassero": "cariare",
    "cariassi": "cariare",
    "cariassimo": "cariare",
    "cariaste": "cariare",
    "cariasti": "cariare",
    "cariata": "cariare",
    "cariate": "cariare",
    "cariati": "cariare",
    "cariatidi": "cariatide",
    "cariato": "cariare",
    "cariava": "cariare",
    "cariavamo": "cariare",
    "cariavan": "cariare",
    "cariavano": "cariare",
    "cariavate": "cariare",
    "cariavi": "cariare",
    "cariavo": "cariare",
    "carica": "carico",
    "caricai": "caricare",
    "caricamenti": "caricamento",
    "caricammo": "caricare",
    "carican": "caricare",
    "caricando": "caricare",
    "caricano": "caricare",
    "caricante": "caricare",
    "caricanti": "caricare",
    "caricar": "caricare",
    "caricaron": "caricare",
    "caricarono": "caricare",
    "caricasse": "caricare",
    "caricasser": "caricare",
    "caricassero": "caricare",
    "caricassi": "caricare",
    "caricassimo": "caricare",
    "caricaste": "caricare",
    "caricasti": "caricare",
    "caricata": "caricato",
    "caricate": "caricato",
    "caricati": "caricato",
    "caricato": "caricare",
    "caricatori": "caricatore",
    "caricatrice": "caricatore",
    "caricatrici": "caricatore",
    "caricaturali": "caricaturale",
    "caricature": "caricatura",
    "caricaturisti": "caricaturista",
    "caricava": "caricare",
    "caricavamo": "caricare",
    "caricavan": "caricare",
    "caricavano": "caricare",
    "caricavate": "caricare",
    "caricavi": "caricare",
    "caricavo": "caricare",
    "cariche": "carico",
    "caricherai": "caricare",
    "caricheran": "caricare",
    "caricheranno": "caricare",
    "caricherebbe": "caricare",
    "caricherebber": "caricare",
    "caricherebbero": "caricare",
    "caricherei": "caricare",
    "caricheremmo": "caricare",
    "caricheremo": "caricare",
    "carichereste": "caricare",
    "caricheresti": "caricare",
    "caricherete": "caricare",
    "caricherà": "caricare",
    "caricherò": "caricare",
    "carichi": "carico",
    "carichiamo": "caricare",
    "carichiate": "caricare",
    "carichin": "caricare",
    "carichino": "caricare",
    "carico": "caricare",
    "caricò": "caricare",
    "carierai": "cariare",
    "carieran": "cariare",
    "carieranno": "cariare",
    "carierebbe": "cariare",
    "carierebber": "cariare",
    "carierebbero": "cariare",
    "carierei": "cariare",
    "carieremmo": "cariare",
    "carieremo": "cariare",
    "cariereste": "cariare",
    "carieresti": "cariare",
    "carierete": "cariare",
    "carierà": "cariare",
    "carierò": "cariare",
    "carin": "cariare",
    "carina": "carino",
    "carine": "carino",
    "carinerie": "carineria",
    "carini": "carino",
    "carino": "cariare",
    "cario": "cariare",
    "carismatica": "carismatico",
    "carismatiche": "carismatico",
    "carismatici": "carismatico",
    "carismi": "carisma",
    "caritatevoli": "caritatevole",
    "cariò": "cariare",
    "carmelitana": "carmelitano",
    "carmelitane": "carmelitano",
    "carmelitani": "carmelitano",
    "carnagioni": "carnagione",
    "carnai": "carnaio",
    "carnali": "carnale",
    "carneadi": "carneade",
    "carnefici": "carnefice",
    "carneficine": "carneficina",
    "carnevalate": "carnevalata",
    "carnevalesca": "carnevalesco",
    "carnevalesche": "carnevalesco",
    "carnevaleschi": "carnevalesco",
    "carnevali": "carnevale",
    "carni": "carne",
    "carnicina": "carnicino",
    "carnicine": "carnicino",
    "carnicini": "carnicino",
    "carnieri": "carniere",
    "carnivora": "carnivoro",
    "carnivore": "carnivoro",
    "carnivori": "carnivoro",
    "carnosa": "carnoso",
    "carnose": "carnoso",
    "carnosi": "carnoso",
    "carognate": "carognata",
    "carogne": "carogna",
    "carognesca": "carognesco",
    "carognesche": "carognesco",
    "carogneschi": "carognesco",
    "caroselli": "carosello",
    "carota": "carotare",
    "carotaggi": "carotaggio",
    "carotai": "carotare",
    "carotammo": "carotare",
    "carotan": "carotare",
    "carotando": "carotare",
    "carotano": "carotare",
    "carotante": "carotare",
    "carotanti": "carotare",
    "carotar": "carotare",
    "carotaron": "carotare",
    "carotarono": "carotare",
    "carotasse": "carotare",
    "carotasser": "carotare",
    "carotassero": "carotare",
    "carotassi": "carotare",
    "carotassimo": "carotare",
    "carotaste": "carotare",
    "carotasti": "carotare",
    "carotata": "carotare",
    "carotate": "carotare",
    "carotati": "carotare",
    "carotato": "carotare",
    "carotava": "carotare",
    "carotavamo": "carotare",
    "carotavan": "carotare",
    "carotavano": "carotare",
    "carotavate": "carotare",
    "carotavi": "carotare",
    "carotavo": "carotare",
    "carote": "carota",
    "caroterai": "carotare",
    "caroteran": "carotare",
    "caroteranno": "carotare",
    "caroterebbe": "carotare",
    "caroterebber": "carotare",
    "caroterebbero": "carotare",
    "caroterei": "carotare",
    "caroteremmo": "carotare",
    "caroteremo": "carotare",
    "carotereste": "carotare",
    "caroteresti": "carotare",
    "caroterete": "carotare",
    "caroterà": "carotare",
    "caroterò": "carotare",
    "caroti": "carotare",
    "carotiamo": "carotare",
    "carotiate": "carotare",
    "carotin": "carotare",
    "carotino": "carotare",
    "caroto": "carotare",
    "carotò": "carotare",
    "carovane": "carovana",
    "carovaniera": "carovaniero",
    "carovaniere": "carovaniero",
    "carovanieri": "carovaniero",
    "carpe": "carpa",
    "carpendo": "carpire",
    "carpente": "carpire",
    "carpenterie": "carpenteria",
    "carpenti": "carpire",
    "carpentieri": "carpentiere",
    "carpiamo": "carpire",
    "carpiate": "carpire",
    "carpii": "carpire",
    "carpimmo": "carpire",
    "carpir": "carpire",
    "carpirai": "carpire",
    "carpiran": "carpire",
    "carpiranno": "carpire",
    "carpirebbe": "carpire",
    "carpirebber": "carpire",
    "carpirebbero": "carpire",
    "carpirei": "carpire",
    "carpiremmo": "carpire",
    "carpiremo": "carpire",
    "carpireste": "carpire",
    "carpiresti": "carpire",
    "carpirete": "carpire",
    "carpiron": "carpire",
    "carpirono": "carpire",
    "carpirà": "carpire",
    "carpirò": "carpire",
    "carpisca": "carpire",
    "carpiscan": "carpire",
    "carpiscano": "carpire",
    "carpisce": "carpire",
    "carpisci": "carpire",
    "carpisco": "carpire",
    "carpiscon": "carpire",
    "carpiscono": "carpire",
    "carpisse": "carpire",
    "carpisser": "carpire",
    "carpissero": "carpire",
    "carpissi": "carpire",
    "carpissimo": "carpire",
    "carpiste": "carpire",
    "carpisti": "carpire",
    "carpita": "carpire",
    "carpite": "carpire",
    "carpiti": "carpire",
    "carpito": "carpire",
    "carpiva": "carpire",
    "carpivamo": "carpire",
    "carpivan": "carpire",
    "carpivano": "carpire",
    "carpivate": "carpire",
    "carpivi": "carpire",
    "carpivo": "carpire",
    "carpì": "carpire",
    "carrai": "carraio",
    "carraia": "carraio",
    "carraie": "carraio",
    "carraresi": "carrarese",
    "carrarmati": "carrarmato",
    "carreggerai": "carreggiare",
    "carreggeran": "carreggiare",
    "carreggeranno": "carreggiare",
    "carreggerebbe": "carreggiare",
    "carreggerebber": "carreggiare",
    "carreggerebbero": "carreggiare",
    "carreggerei": "carreggiare",
    "carreggeremmo": "carreggiare",
    "carreggeremo": "carreggiare",
    "carreggereste": "carreggiare",
    "carreggeresti": "carreggiare",
    "carreggerete": "carreggiare",
    "carreggerà": "carreggiare",
    "carreggerò": "carreggiare",
    "carreggi": "carreggiare",
    "carreggia": "carreggiare",
    "carreggiai": "carreggiare",
    "carreggiammo": "carreggiare",
    "carreggiamo": "carreggiare",
    "carreggian": "carreggiare",
    "carreggiando": "carreggiare",
    "carreggiano": "carreggiare",
    "carreggiante": "carreggiare",
    "carreggianti": "carreggiare",
    "carreggiar": "carreggiare",
    "carreggiaron": "carreggiare",
    "carreggiarono": "carreggiare",
    "carreggiasse": "carreggiare",
    "carreggiasser": "carreggiare",
    "carreggiassero": "carreggiare",
    "carreggiassi": "carreggiare",
    "carreggiassimo": "carreggiare",
    "carreggiaste": "carreggiare",
    "carreggiasti": "carreggiare",
    "carreggiata": "carreggiare",
    "carreggiate": "carreggiata",
    "carreggiati": "carreggiare",
    "carreggiato": "carreggiare",
    "carreggiava": "carreggiare",
    "carreggiavamo": "carreggiare",
    "carreggiavan": "carreggiare",
    "carreggiavano": "carreggiare",
    "carreggiavate": "carreggiare",
    "carreggiavi": "carreggiare",
    "carreggiavo": "carreggiare",
    "carreggin": "carreggiare",
    "carreggino": "carreggiare",
    "carreggio": "carreggiare",
    "carreggiò": "carreggiare",
    "carrella": "carrellare",
    "carrellai": "carrellare",
    "carrellammo": "carrellare",
    "carrellan": "carrellare",
    "carrellando": "carrellare",
    "carrellano": "carrellare",
    "carrellante": "carrellare",
    "carrellanti": "carrellare",
    "carrellar": "carrellare",
    "carrellaron": "carrellare",
    "carrellarono": "carrellare",
    "carrellasse": "carrellare",
    "carrellasser": "carrellare",
    "carrellassero": "carrellare",
    "carrellassi": "carrellare",
    "carrellassimo": "carrellare",
    "carrellaste": "carrellare",
    "carrellasti": "carrellare",
    "carrellata": "carrellare",
    "carrellate": "carrellata",
    "carrellati": "carrellare",
    "carrellato": "carrellare",
    "carrellava": "carrellare",
    "carrellavamo": "carrellare",
    "carrellavan": "carrellare",
    "carrellavano": "carrellare",
    "carrellavate": "carrellare",
    "carrellavi": "carrellare",
    "carrellavo": "carrellare",
    "carrellerai": "carrellare",
    "carrelleran": "carrellare",
    "carrelleranno": "carrellare",
    "carrellerebbe": "carrellare",
    "carrellerebber": "carrellare",
    "carrellerebbero": "carrellare",
    "carrellerei": "carrellare",
    "carrelleremmo": "carrellare",
    "carrelleremo": "carrellare",
    "carrellereste": "carrellare",
    "carrelleresti": "carrellare",
    "carrellerete": "carrellare",
    "carrellerà": "carrellare",
    "carrellerò": "carrellare",
    "carrelli": "carrello",
    "carrelliamo": "carrellare",
    "carrelliate": "carrellare",
    "carrellin": "carrellare",
    "carrellino": "carrellare",
    "carrello": "carrellare",
    "carrellò": "carrellare",
    "carrette": "carretta",
    "carretti": "carretto",
    "carrettini": "carrettino",
    "carri": "carro",
    "carriere": "carriera",
    "carrierismi": "carrierismo",
    "carrieristi": "carrierista",
    "carriole": "carriola",
    "carristi": "carrista",
    "carrocci": "carroccio",
    "carrozza": "carrozzare",
    "carrozzabili": "carrozzabile",
    "carrozzai": "carrozzare",
    "carrozzammo": "carrozzare",
    "carrozzan": "carrozzare",
    "carrozzando": "carrozzare",
    "carrozzano": "carrozzare",
    "carrozzante": "carrozzare",
    "carrozzanti": "carrozzare",
    "carrozzar": "carrozzare",
    "carrozzaron": "carrozzare",
    "carrozzarono": "carrozzare",
    "carrozzasse": "carrozzare",
    "carrozzasser": "carrozzare",
    "carrozzassero": "carrozzare",
    "carrozzassi": "carrozzare",
    "carrozzassimo": "carrozzare",
    "carrozzaste": "carrozzare",
    "carrozzasti": "carrozzare",
    "carrozzata": "carrozzare",
    "carrozzate": "carrozzare",
    "carrozzati": "carrozzare",
    "carrozzato": "carrozzare",
    "carrozzava": "carrozzare",
    "carrozzavamo": "carrozzare",
    "carrozzavan": "carrozzare",
    "carrozzavano": "carrozzare",
    "carrozzavate": "carrozzare",
    "carrozzavi": "carrozzare",
    "carrozzavo": "carrozzare",
    "carrozze": "carrozza",
    "carrozzelle": "carrozzella",
    "carrozzerai": "carrozzare",
    "carrozzeran": "carrozzare",
    "carrozzeranno": "carrozzare",
    "carrozzerebbe": "carrozzare",
    "carrozzerebber": "carrozzare",
    "carrozzerebbero": "carrozzare",
    "carrozzerei": "carrozzare",
    "carrozzeremmo": "carrozzare",
    "carrozzeremo": "carrozzare",
    "carrozzereste": "carrozzare",
    "carrozzeresti": "carrozzare",
    "carrozzerete": "carrozzare",
    "carrozzerie": "carrozzeria",
    "carrozzerà": "carrozzare",
    "carrozzerò": "carrozzare",
    "carrozzi": "carrozzare",
    "carrozziamo": "carrozzare",
    "carrozziate": "carrozzare",
    "carrozzieri": "carrozziere",
    "carrozzin": "carrozzare",
    "carrozzine": "carrozzina",
    "carrozzino": "carrozzare",
    "carrozzo": "carrozzare",
    "carrozzoni": "carrozzone",
    "carrozzò": "carrozzare",
    "carrubi": "carrubo",
    "carrucola": "carrucolare",
    "carrucolai": "carrucolare",
    "carrucolammo": "carrucolare",
    "carrucolan": "carrucolare",
    "carrucolando": "carrucolare",
    "carrucolano": "carrucolare",
    "carrucolante": "carrucolare",
    "carrucolanti": "carrucolare",
    "carrucolar": "carrucolare",
    "carrucolaron": "carrucolare",
    "carrucolarono": "carrucolare",
    "carrucolasse": "carrucolare",
    "carrucolasser": "carrucolare",
    "carrucolassero": "carrucolare",
    "carrucolassi": "carrucolare",
    "carrucolassimo": "carrucolare",
    "carrucolaste": "carrucolare",
    "carrucolasti": "carrucolare",
    "carrucolata": "carrucolare",
    "carrucolate": "carrucolare",
    "carrucolati": "carrucolare",
    "carrucolato": "carrucolare",
    "carrucolava": "carrucolare",
    "carrucolavamo": "carrucolare",
    "carrucolavan": "carrucolare",
    "carrucolavano": "carrucolare",
    "carrucolavate": "carrucolare",
    "carrucolavi": "carrucolare",
    "carrucolavo": "carrucolare",
    "carrucole": "carrucola",
    "carrucolerai": "carrucolare",
    "carrucoleran": "carrucolare",
    "carrucoleranno": "carrucolare",
    "carrucolerebbe": "carrucolare",
    "carrucolerebber": "carrucolare",
    "carrucolerebbero": "carrucolare",
    "carrucolerei": "carrucolare",
    "carrucoleremmo": "carrucolare",
    "carrucoleremo": "carrucolare",
    "carrucolereste": "carrucolare",
    "carrucoleresti": "carrucolare",
    "carrucolerete": "carrucolare",
    "carrucolerà": "carrucolare",
    "carrucolerò": "carrucolare",
    "carrucoli": "carrucolare",
    "carrucoliamo": "carrucolare",
    "carrucoliate": "carrucolare",
    "carrucolin": "carrucolare",
    "carrucolino": "carrucolare",
    "carrucolo": "carrucolare",
    "carrucolò": "carrucolare",
    "carsica": "carsico",
    "carsiche": "carsico",
    "carsici": "carsico",
    "cartacce": "cartaccia",
    "cartacea": "cartaceo",
    "cartacee": "cartaceo",
    "cartacei": "cartaceo",
    "cartapeste": "cartapesta",
    "cartari": "cartario",
    "cartaria": "cartario",
    "cartarie": "cartario",
    "carte": "carta",
    "carteggi": "carteggio",
    "cartelle": "cartella",
    "cartellette": "cartelletta",
    "cartelli": "cartello",
    "cartelline": "cartellina",
    "cartellini": "cartellino",
    "cartelloni": "cartellone",
    "cartellonisti": "cartellonista",
    "cartesiana": "cartesiano",
    "cartesiane": "cartesiano",
    "cartesiani": "cartesiano",
    "cartiere": "cartiera",
    "cartigli": "cartiglio",
    "cartilagini": "cartilagine",
    "cartine": "cartina",
    "cartocci": "cartoccio",
    "cartografi": "cartografo",
    "cartografica": "cartografico",
    "cartografiche": "cartografico",
    "cartografici": "cartografico",
    "cartografie": "cartografia",
    "cartola": "cartolare",
    "cartolai": "cartolare",
    "cartolammo": "cartolare",
    "cartolan": "cartolare",
    "cartolando": "cartolare",
    "cartolano": "cartolare",
    "cartolante": "cartolare",
    "cartolanti": "cartolare",
    "cartolar": "cartolare",
    "cartolari": "cartolario",
    "cartolaria": "cartolario",
    "cartolarie": "cartolario",
    "cartolaron": "cartolare",
    "cartolarono": "cartolare",
    "cartolasse": "cartolare",
    "cartolasser": "cartolare",
    "cartolassero": "cartolare",
    "cartolassi": "cartolare",
    "cartolassimo": "cartolare",
    "cartolaste": "cartolare",
    "cartolasti": "cartolare",
    "cartolata": "cartolare",
    "cartolate": "cartolare",
    "cartolati": "cartolare",
    "cartolato": "cartolare",
    "cartolava": "cartolare",
    "cartolavamo": "cartolare",
    "cartolavan": "cartolare",
    "cartolavano": "cartolare",
    "cartolavate": "cartolare",
    "cartolavi": "cartolare",
    "cartolavo": "cartolare",
    "cartolerai": "cartolare",
    "cartoleran": "cartolare",
    "cartoleranno": "cartolare",
    "cartolerebbe": "cartolare",
    "cartolerebber": "cartolare",
    "cartolerebbero": "cartolare",
    "cartolerei": "cartolare",
    "cartoleremmo": "cartolare",
    "cartoleremo": "cartolare",
    "cartolereste": "cartolare",
    "cartoleresti": "cartolare",
    "cartolerete": "cartolare",
    "cartolerie": "cartoleria",
    "cartolerà": "cartolare",
    "cartolerò": "cartolare",
    "cartoli": "cartolare",
    "cartoliamo": "cartolare",
    "cartoliate": "cartolare",
    "cartolibrerie": "cartolibreria",
    "cartolin": "cartolare",
    "cartoline": "cartolina",
    "cartolino": "cartolare",
    "cartolo": "cartolare",
    "cartolò": "cartolare",
    "cartomanti": "cartomante",
    "cartona": "cartonare",
    "cartonai": "cartonare",
    "cartonammo": "cartonare",
    "cartonan": "cartonare",
    "cartonando": "cartonare",
    "cartonano": "cartonare",
    "cartonante": "cartonare",
    "cartonanti": "cartonare",
    "cartonar": "cartonare",
    "cartonaron": "cartonare",
    "cartonarono": "cartonare",
    "cartonasse": "cartonare",
    "cartonasser": "cartonare",
    "cartonassero": "cartonare",
    "cartonassi": "cartonare",
    "cartonassimo": "cartonare",
    "cartonaste": "cartonare",
    "cartonasti": "cartonare",
    "cartonata": "cartonare",
    "cartonate": "cartonare",
    "cartonati": "cartonare",
    "cartonato": "cartonare",
    "cartonava": "cartonare",
    "cartonavamo": "cartonare",
    "cartonavan": "cartonare",
    "cartonavano": "cartonare",
    "cartonavate": "cartonare",
    "cartonavi": "cartonare",
    "cartonavo": "cartonare",
    "cartoncini": "cartoncino",
    "cartonerai": "cartonare",
    "cartoneran": "cartonare",
    "cartoneranno": "cartonare",
    "cartonerebbe": "cartonare",
    "cartonerebber": "cartonare",
    "cartonerebbero": "cartonare",
    "cartonerei": "cartonare",
    "cartoneremmo": "cartonare",
    "cartoneremo": "cartonare",
    "cartonereste": "cartonare",
    "cartoneresti": "cartonare",
    "cartonerete": "cartonare",
    "cartonerà": "cartonare",
    "cartonerò": "cartonare",
    "cartoni": "cartone",
    "cartoniamo": "cartonare",
    "cartoniate": "cartonare",
    "cartonin": "cartonare",
    "cartonino": "cartonare",
    "cartono": "cartonare",
    "cartonò": "cartonare",
    "cartotecnica": "cartotecnico",
    "cartotecniche": "cartotecnico",
    "cartotecnici": "cartotecnico",
    "cartucce": "cartuccia",
    "casacche": "casacca",
    "casali": "casale",
    "casalinga": "casalingo",
    "casalinghe": "casalingo",
    "casalinghi": "casalingo",
    "casamenti": "casamento",
    "casarecce": "casareccio",
    "casarecci": "casareccio",
    "casareccia": "casareccio",
    "casate": "casata",
    "casati": "casato",
    "casca": "cascare",
    "cascai": "cascare",
    "cascami": "cascame",
    "cascammo": "cascare",
    "cascan": "cascare",
    "cascando": "cascare",
    "cascano": "cascare",
    "cascante": "cascare",
    "cascanti": "cascare",
    "cascar": "cascare",
    "cascaron": "cascare",
    "cascarono": "cascare",
    "cascasse": "cascare",
    "cascasser": "cascare",
    "cascassero": "cascare",
    "cascassi": "cascare",
    "cascassimo": "cascare",
    "cascaste": "cascare",
    "cascasti": "cascare",
    "cascata": "cascare",
    "cascate": "cascata",
    "cascati": "cascare",
    "cascato": "cascare",
    "cascatori": "cascatore",
    "cascava": "cascare",
    "cascavamo": "cascare",
    "cascavan": "cascare",
    "cascavano": "cascare",
    "cascavate": "cascare",
    "cascavi": "cascare",
    "cascavo": "cascare",
    "cascherai": "cascare",
    "cascheran": "cascare",
    "cascheranno": "cascare",
    "cascherebbe": "cascare",
    "cascherebber": "cascare",
    "cascherebbero": "cascare",
    "cascherei": "cascare",
    "cascheremmo": "cascare",
    "cascheremo": "cascare",
    "caschereste": "cascare",
    "cascheresti": "cascare",
    "cascherete": "cascare",
    "cascherà": "cascare",
    "cascherò": "cascare",
    "caschetti": "caschetto",
    "caschi": "casco",
    "caschiamo": "cascare",
    "caschiate": "cascare",
    "caschin": "cascare",
    "caschino": "cascare",
    "cascinali": "cascinale",
    "cascine": "cascina",
    "casco": "cascare",
    "cascò": "cascare",
    "case": "casa",
    "case-madri": "casa-madre",
    "case-museo": "casa-museo",
    "caseari": "caseario",
    "casearia": "caseario",
    "casearie": "caseario",
    "caseggiati": "caseggiato",
    "caseifici": "caseificio",
    "casellanti": "casellante",
    "casellari": "casellario",
    "casellaria": "casellario",
    "casellarie": "casellario",
    "caselle": "casella",
    "caselli": "casello",
    "caselline": "casellina",
    "caserecce": "casereccio",
    "caserecci": "casereccio",
    "casereccia": "casereccio",
    "caserme": "caserma",
    "casermette": "casermetta",
    "casermoni": "casermone",
    "casertana": "casertano",
    "casertane": "casertano",
    "casertani": "casertano",
    "casette": "casetta",
    "casi": "caso",
    "casine": "casina",
    "casini": "casino",
    "casistiche": "casistica",
    "casola": "casolare",
    "casolai": "casolare",
    "casolammo": "casolare",
    "casolan": "casolare",
    "casolando": "casolare",
    "casolano": "casolare",
    "casolante": "casolare",
    "casolanti": "casolare",
    "casolar": "casolare",
    "casolari": "casolare",
    "casolaron": "casolare",
    "casolarono": "casolare",
    "casolasse": "casolare",
    "casolasser": "casolare",
    "casolassero": "casolare",
    "casolassi": "casolare",
    "casolassimo": "casolare",
    "casolaste": "casolare",
    "casolasti": "casolare",
    "casolata": "casolare",
    "casolate": "casolare",
    "casolati": "casolare",
    "casolato": "casolare",
    "casolava": "casolare",
    "casolavamo": "casolare",
    "casolavan": "casolare",
    "casolavano": "casolare",
    "casolavate": "casolare",
    "casolavi": "casolare",
    "casolavo": "casolare",
    "casolerai": "casolare",
    "casoleran": "casolare",
    "casoleranno": "casolare",
    "casolerebbe": "casolare",
    "casolerebber": "casolare",
    "casolerebbero": "casolare",
    "casolerei": "casolare",
    "casoleremmo": "casolare",
    "casoleremo": "casolare",
    "casolereste": "casolare",
    "casoleresti": "casolare",
    "casolerete": "casolare",
    "casolerà": "casolare",
    "casolerò": "casolare",
    "casoli": "casolare",
    "casoliamo": "casolare",
    "casoliate": "casolare",
    "casolin": "casolare",
    "casolino": "casolare",
    "casolo": "casolare",
    "casolò": "casolare",
    "casoni": "casone",
    "casotti": "casotto",
    "cassa": "cassare",
    "cassaforti": "cassaforte",
    "cassai": "cassare",
    "cassammo": "cassare",
    "cassan": "cassare",
    "cassando": "cassare",
    "cassano": "cassare",
    "cassante": "cassare",
    "cassanti": "cassare",
    "cassar": "cassare",
    "cassaron": "cassare",
    "cassarono": "cassare",
    "cassasse": "cassare",
    "cassasser": "cassare",
    "cassassero": "cassare",
    "cassassi": "cassare",
    "cassassimo": "cassare",
    "cassaste": "cassare",
    "cassasti": "cassare",
    "cassata": "cassare",
    "cassate": "cassare",
    "cassati": "cassare",
    "cassato": "cassare",
    "cassava": "cassare",
    "cassavamo": "cassare",
    "cassavan": "cassare",
    "cassavano": "cassare",
    "cassavate": "cassare",
    "cassavi": "cassare",
    "cassavo": "cassare",
    "cassazioni": "cassazione",
    "casse": "cassa",
    "casseforti": "cassaforte",
    "casserai": "cassare",
    "casseran": "cassare",
    "casseranno": "cassare",
    "casserebbe": "cassare",
    "casserebber": "cassare",
    "casserebbero": "cassare",
    "casserei": "cassare",
    "casseremmo": "cassare",
    "casseremo": "cassare",
    "cassereste": "cassare",
    "casseresti": "cassare",
    "casserete": "cassare",
    "casserà": "cassare",
    "casserò": "cassare",
    "cassette": "cassetta",
    "cassetti": "cassetto",
    "cassettisti": "cassettista",
    "cassettoni": "cassettone",
    "cassi": "cassare",
    "cassiamo": "cassare",
    "cassiate": "cassare",
    "cassiere": "cassiera",
    "cassieri": "cassiere",
    "cassin": "cassare",
    "cassino": "cassare",
    "cassintegrati": "cassintegrato",
    "casso": "cassare",
    "cassonetti": "cassonetto",
    "cassoni": "cassone",
    "cassò": "cassare",
    "casta": "casto",
    "castagne": "castagna",
    "castagni": "castagno",
    "castana": "castano",
    "castane": "castano",
    "castani": "castano",
    "caste": "casto",
    "castellana": "castellano",
    "castellane": "castellano",
    "castellani": "castellano",
    "castelli": "castello",
    "casti": "casto",
    "castiga": "castigare",
    "castigai": "castigare",
    "castigammo": "castigare",
    "castigan": "castigare",
    "castigando": "castigare",
    "castigano": "castigare",
    "castigante": "castigare",
    "castiganti": "castigare",
    "castigar": "castigare",
    "castigaron": "castigare",
    "castigarono": "castigare",
    "castigasse": "castigare",
    "castigasser": "castigare",
    "castigassero": "castigare",
    "castigassi": "castigare",
    "castigassimo": "castigare",
    "castigaste": "castigare",
    "castigasti": "castigare",
    "castigata": "castigato",
    "castigate": "castigato",
    "castigati": "castigato",
    "castigato": "castigare",
    "castigava": "castigare",
    "castigavamo": "castigare",
    "castigavan": "castigare",
    "castigavano": "castigare",
    "castigavate": "castigare",
    "castigavi": "castigare",
    "castigavo": "castigare",
    "castigherai": "castigare",
    "castigheran": "castigare",
    "castigheranno": "castigare",
    "castigherebbe": "castigare",
    "castigherebber": "castigare",
    "castigherebbero": "castigare",
    "castigherei": "castigare",
    "castigheremmo": "castigare",
    "castigheremo": "castigare",
    "castighereste": "castigare",
    "castigheresti": "castigare",
    "castigherete": "castigare",
    "castigherà": "castigare",
    "castigherò": "castigare",
    "castighi": "castigo",
    "castighiamo": "castigare",
    "castighiate": "castigare",
    "castighin": "castigare",
    "castighino": "castigare",
    "castigliana": "castigliano",
    "castigliane": "castigliano",
    "castigliani": "castigliano",
    "castigo": "castigare",
    "castigò": "castigare",
    "castori": "castoro",
    "castra": "castrare",
    "castrai": "castrare",
    "castrammo": "castrare",
    "castran": "castrare",
    "castrando": "castrare",
    "castrano": "castrare",
    "castrante": "castrare",
    "castranti": "castrare",
    "castrar": "castrare",
    "castraron": "castrare",
    "castrarono": "castrare",
    "castrasse": "castrare",
    "castrasser": "castrare",
    "castrassero": "castrare",
    "castrassi": "castrare",
    "castrassimo": "castrare",
    "castraste": "castrare",
    "castrasti": "castrare",
    "castrata": "castrato",
    "castrate": "castrato",
    "castrati": "castrato",
    "castrato": "castrare",
    "castrava": "castrare",
    "castravamo": "castrare",
    "castravan": "castrare",
    "castravano": "castrare",
    "castravate": "castrare",
    "castravi": "castrare",
    "castravo": "castrare",
    "castrazioni": "castrazione",
    "castrensi": "castrense",
    "castrerai": "castrare",
    "castreran": "castrare",
    "castreranno": "castrare",
    "castrerebbe": "castrare",
    "castrerebber": "castrare",
    "castrerebbero": "castrare",
    "castrerei": "castrare",
    "castreremmo": "castrare",
    "castreremo": "castrare",
    "castrereste": "castrare",
    "castreresti": "castrare",
    "castrerete": "castrare",
    "castrerà": "castrare",
    "castrerò": "castrare",
    "castri": "castrare",
    "castriamo": "castrare",
    "castriate": "castrare",
    "castrin": "castrare",
    "castrino": "castrare",
    "castrismi": "castrismo",
    "castro": "castrare",
    "castronerie": "castroneria",
    "castroni": "castrone",
    "castrò": "castrare",
    "casuali": "casuale",
    "casupole": "casupola",
    "cataclismi": "cataclisma",
    "catacombe": "catacomba",
    "catafalchi": "catafalco",
    "catalani": "catalano",
    "catalitica": "catalitico",
    "catalitiche": "catalitico",
    "catalitici": "catalitico",
    "catalizza": "catalizzare",
    "catalizzai": "catalizzare",
    "catalizzammo": "catalizzare",
    "catalizzan": "catalizzare",
    "catalizzando": "catalizzare",
    "catalizzano": "catalizzare",
    "catalizzante": "catalizzare",
    "catalizzanti": "catalizzare",
    "catalizzar": "catalizzare",
    "catalizzaron": "catalizzare",
    "catalizzarono": "catalizzare",
    "catalizzasse": "catalizzare",
    "catalizzasser": "catalizzare",
    "catalizzassero": "catalizzare",
    "catalizzassi": "catalizzare",
    "catalizzassimo": "catalizzare",
    "catalizzaste": "catalizzare",
    "catalizzasti": "catalizzare",
    "catalizzata": "catalizzare",
    "catalizzate": "catalizzare",
    "catalizzati": "catalizzare",
    "catalizzato": "catalizzare",
    "catalizzatori": "catalizzatore",
    "catalizzatrice": "catalizzatore",
    "catalizzatrici": "catalizzatore",
    "catalizzava": "catalizzare",
    "catalizzavamo": "catalizzare",
    "catalizzavan": "catalizzare",
    "catalizzavano": "catalizzare",
    "catalizzavate": "catalizzare",
    "catalizzavi": "catalizzare",
    "catalizzavo": "catalizzare",
    "catalizzerai": "catalizzare",
    "catalizzeran": "catalizzare",
    "catalizzeranno": "catalizzare",
    "catalizzerebbe": "catalizzare",
    "catalizzerebber": "catalizzare",
    "catalizzerebbero": "catalizzare",
    "catalizzerei": "catalizzare",
    "catalizzeremmo": "catalizzare",
    "catalizzeremo": "catalizzare",
    "catalizzereste": "catalizzare",
    "catalizzeresti": "catalizzare",
    "catalizzerete": "catalizzare",
    "catalizzerà": "catalizzare",
    "catalizzerò": "catalizzare",
    "catalizzi": "catalizzare",
    "catalizziamo": "catalizzare",
    "catalizziate": "catalizzare",
    "catalizzin": "catalizzare",
    "catalizzino": "catalizzare",
    "catalizzo": "catalizzare",
    "catalizzò": "catalizzare",
    "cataloga": "catalogare",
    "catalogai": "catalogare",
    "catalogammo": "catalogare",
    "catalogan": "catalogare",
    "catalogando": "catalogare",
    "catalogano": "catalogare",
    "catalogante": "catalogare",
    "cataloganti": "catalogare",
    "catalogar": "catalogare",
    "catalogaron": "catalogare",
    "catalogarono": "catalogare",
    "catalogasse": "catalogare",
    "catalogasser": "catalogare",
    "catalogassero": "catalogare",
    "catalogassi": "catalogare",
    "catalogassimo": "catalogare",
    "catalogaste": "catalogare",
    "catalogasti": "catalogare",
    "catalogata": "catalogare",
    "catalogate": "catalogare",
    "catalogati": "catalogare",
    "catalogato": "catalogare",
    "catalogava": "catalogare",
    "catalogavamo": "catalogare",
    "catalogavan": "catalogare",
    "catalogavano": "catalogare",
    "catalogavate": "catalogare",
    "catalogavi": "catalogare",
    "catalogavo": "catalogare",
    "catalogazioni": "catalogazione",
    "catalogherai": "catalogare",
    "catalogheran": "catalogare",
    "catalogheranno": "catalogare",
    "catalogherebbe": "catalogare",
    "catalogherebber": "catalogare",
    "catalogherebbero": "catalogare",
    "catalogherei": "catalogare",
    "catalogheremmo": "catalogare",
    "catalogheremo": "catalogare",
    "cataloghereste": "catalogare",
    "catalogheresti": "catalogare",
    "catalogherete": "catalogare",
    "catalogherà": "catalogare",
    "catalogherò": "catalogare",
    "cataloghi": "catalogo",
    "cataloghiamo": "catalogare",
    "cataloghiate": "catalogare",
    "cataloghin": "catalogare",
    "cataloghino": "catalogare",
    "catalogo": "catalogare",
    "catalogò": "catalogare",
    "catamarani": "catamarano",
    "catanesi": "catanese",
    "catanzaresi": "catanzarese",
    "catapecchie": "catapecchia",
    "catapulta": "catapultare",
    "catapultai": "catapultare",
    "catapultammo": "catapultare",
    "catapultan": "catapultare",
    "catapultando": "catapultare",
    "catapultano": "catapultare",
    "catapultante": "catapultare",
    "catapultanti": "catapultare",
    "catapultar": "catapultare",
    "catapultaron": "catapultare",
    "catapultarono": "catapultare",
    "catapultasse": "catapultare",
    "catapultasser": "catapultare",
    "catapultassero": "catapultare",
    "catapultassi": "catapultare",
    "catapultassimo": "catapultare",
    "catapultaste": "catapultare",
    "catapultasti": "catapultare",
    "catapultata": "catapultare",
    "catapultate": "catapultare",
    "catapultati": "catapultare",
    "catapultato": "catapultare",
    "catapultava": "catapultare",
    "catapultavamo": "catapultare",
    "catapultavan": "catapultare",
    "catapultavano": "catapultare",
    "catapultavate": "catapultare",
    "catapultavi": "catapultare",
    "catapultavo": "catapultare",
    "catapulte": "catapulta",
    "catapulterai": "catapultare",
    "catapulteran": "catapultare",
    "catapulteranno": "catapultare",
    "catapulterebbe": "catapultare",
    "catapulterebber": "catapultare",
    "catapulterebbero": "catapultare",
    "catapulterei": "catapultare",
    "catapulteremmo": "catapultare",
    "catapulteremo": "catapultare",
    "catapultereste": "catapultare",
    "catapulteresti": "catapultare",
    "catapulterete": "catapultare",
    "catapulterà": "catapultare",
    "catapulterò": "catapultare",
    "catapulti": "catapultare",
    "catapultiamo": "catapultare",
    "catapultiate": "catapultare",
    "catapultin": "catapultare",
    "catapultino": "catapultare",
    "catapulto": "catapultare",
    "catapultò": "catapultare",
    "cataratte": "cataratta",
    "catartica": "catartico",
    "catartiche": "catartico",
    "catartici": "catartico",
    "catastali": "catastale",
    "cataste": "catasta",
    "catasti": "catasto",
    "catastrofi": "catastrofe",
    "catastrofica": "catastrofico",
    "catastrofiche": "catastrofico",
    "catastrofici": "catastrofico",
    "catastrofismi": "catastrofismo",
    "catechismi": "catechismo",
    "catechistica": "catechistico",
    "catechistiche": "catechistico",
    "catechistici": "catechistico",
    "catechizza": "catechizzare",
    "catechizzai": "catechizzare",
    "catechizzammo": "catechizzare",
    "catechizzan": "catechizzare",
    "catechizzando": "catechizzare",
    "catechizzano": "catechizzare",
    "catechizzante": "catechizzare",
    "catechizzanti": "catechizzare",
    "catechizzar": "catechizzare",
    "catechizzaron": "catechizzare",
    "catechizzarono": "catechizzare",
    "catechizzasse": "catechizzare",
    "catechizzasser": "catechizzare",
    "catechizzassero": "catechizzare",
    "catechizzassi": "catechizzare",
    "catechizzassimo": "catechizzare",
    "catechizzaste": "catechizzare",
    "catechizzasti": "catechizzare",
    "catechizzata": "catechizzare",
    "catechizzate": "catechizzare",
    "catechizzati": "catechizzare",
    "catechizzato": "catechizzare",
    "catechizzava": "catechizzare",
    "catechizzavamo": "catechizzare",
    "catechizzavan": "catechizzare",
    "catechizzavano": "catechizzare",
    "catechizzavate": "catechizzare",
    "catechizzavi": "catechizzare",
    "catechizzavo": "catechizzare",
    "catechizzerai": "catechizzare",
    "catechizzeran": "catechizzare",
    "catechizzeranno": "catechizzare",
    "catechizzerebbe": "catechizzare",
    "catechizzerebber": "catechizzare",
    "catechizzerebbero": "catechizzare",
    "catechizzerei": "catechizzare",
    "catechizzeremmo": "catechizzare",
    "catechizzeremo": "catechizzare",
    "catechizzereste": "catechizzare",
    "catechizzeresti": "catechizzare",
    "catechizzerete": "catechizzare",
    "catechizzerà": "catechizzare",
    "catechizzerò": "catechizzare",
    "catechizzi": "catechizzare",
    "catechizziamo": "catechizzare",
    "catechizziate": "catechizzare",
    "catechizzin": "catechizzare",
    "catechizzino": "catechizzare",
    "catechizzo": "catechizzare",
    "catechizzò": "catechizzare",
    "catecumeni": "catecumeno",
    "categorica": "categorico",
    "categoriche": "categorico",
    "categorici": "categorico",
    "categorie": "categoria",
    "catenacce": "catenaccio",
    "catenacci": "catenaccio",
    "catenaccia": "catenaccio",
    "catene": "catena",
    "catenelle": "catenella",
    "catenine": "catenina",
    "caterve": "caterva",
    "cateteri": "catetere",
    "cateterizza": "cateterizzare",
    "cateterizzai": "cateterizzare",
    "cateterizzammo": "cateterizzare",
    "cateterizzan": "cateterizzare",
    "cateterizzando": "cateterizzare",
    "cateterizzano": "cateterizzare",
    "cateterizzante": "cateterizzare",
    "cateterizzanti": "cateterizzare",
    "cateterizzar": "cateterizzare",
    "cateterizzaron": "cateterizzare",
    "cateterizzarono": "cateterizzare",
    "cateterizzasse": "cateterizzare",
    "cateterizzasser": "cateterizzare",
    "cateterizzassero": "cateterizzare",
    "cateterizzassi": "cateterizzare",
    "cateterizzassimo": "cateterizzare",
    "cateterizzaste": "cateterizzare",
    "cateterizzasti": "cateterizzare",
    "cateterizzata": "cateterizzare",
    "cateterizzate": "cateterizzare",
    "cateterizzati": "cateterizzare",
    "cateterizzato": "cateterizzare",
    "cateterizzava": "cateterizzare",
    "cateterizzavamo": "cateterizzare",
    "cateterizzavan": "cateterizzare",
    "cateterizzavano": "cateterizzare",
    "cateterizzavate": "cateterizzare",
    "cateterizzavi": "cateterizzare",
    "cateterizzavo": "cateterizzare",
    "cateterizzerai": "cateterizzare",
    "cateterizzeran": "cateterizzare",
    "cateterizzeranno": "cateterizzare",
    "cateterizzerebbe": "cateterizzare",
    "cateterizzerebber": "cateterizzare",
    "cateterizzerebbero": "cateterizzare",
    "cateterizzerei": "cateterizzare",
    "cateterizzeremmo": "cateterizzare",
    "cateterizzeremo": "cateterizzare",
    "cateterizzereste": "cateterizzare",
    "cateterizzeresti": "cateterizzare",
    "cateterizzerete": "cateterizzare",
    "cateterizzerà": "cateterizzare",
    "cateterizzerò": "cateterizzare",
    "cateterizzi": "cateterizzare",
    "cateterizziamo": "cateterizzare",
    "cateterizziate": "cateterizzare",
    "cateterizzin": "cateterizzare",
    "cateterizzino": "cateterizzare",
    "cateterizzo": "cateterizzare",
    "cateterizzò": "cateterizzare",
    "cateti": "cateto",
    "catini": "catino",
    "catodica": "catodico",
    "catodiche": "catodico",
    "catodici": "catodico",
    "catrama": "catramare",
    "catramai": "catramare",
    "catramammo": "catramare",
    "catraman": "catramare",
    "catramando": "catramare",
    "catramano": "catramare",
    "catramante": "catramare",
    "catramanti": "catramare",
    "catramar": "catramare",
    "catramaron": "catramare",
    "catramarono": "catramare",
    "catramasse": "catramare",
    "catramasser": "catramare",
    "catramassero": "catramare",
    "catramassi": "catramare",
    "catramassimo": "catramare",
    "catramaste": "catramare",
    "catramasti": "catramare",
    "catramata": "catramare",
    "catramate": "catramare",
    "catramati": "catramare",
    "catramato": "catramare",
    "catramava": "catramare",
    "catramavamo": "catramare",
    "catramavan": "catramare",
    "catramavano": "catramare",
    "catramavate": "catramare",
    "catramavi": "catramare",
    "catramavo": "catramare",
    "catramerai": "catramare",
    "catrameran": "catramare",
    "catrameranno": "catramare",
    "catramerebbe": "catramare",
    "catramerebber": "catramare",
    "catramerebbero": "catramare",
    "catramerei": "catramare",
    "catrameremmo": "catramare",
    "catrameremo": "catramare",
    "catramereste": "catramare",
    "catrameresti": "catramare",
    "catramerete": "catramare",
    "catramerà": "catramare",
    "catramerò": "catramare",
    "catrami": "catrame",
    "catramiamo": "catramare",
    "catramiate": "catramare",
    "catramin": "catramare",
    "catramino": "catramare",
    "catramo": "catramare",
    "catramosa": "catramoso",
    "catramose": "catramoso",
    "catramosi": "catramoso",
    "catramò": "catramare",
    "cattedrali": "cattedrale",
    "cattedratica": "cattedratico",
    "cattedratiche": "cattedratico",
    "cattedratici": "cattedratico",
    "cattedre": "cattedra",
    "cattiva": "cattivo",
    "cattivai": "cattivare",
    "cattivammo": "cattivare",
    "cattivan": "cattivare",
    "cattivando": "cattivare",
    "cattivano": "cattivare",
    "cattivante": "cattivare",
    "cattivanti": "cattivare",
    "cattivar": "cattivare",
    "cattivaron": "cattivare",
    "cattivarono": "cattivare",
    "cattivasse": "cattivare",
    "cattivasser": "cattivare",
    "cattivassero": "cattivare",
    "cattivassi": "cattivare",
    "cattivassimo": "cattivare",
    "cattivaste": "cattivare",
    "cattivasti": "cattivare",
    "cattivata": "cattivare",
    "cattivate": "cattivare",
    "cattivati": "cattivare",
    "cattivato": "cattivare",
    "cattivava": "cattivare",
    "cattivavamo": "cattivare",
    "cattivavan": "cattivare",
    "cattivavano": "cattivare",
    "cattivavate": "cattivare",
    "cattivavi": "cattivare",
    "cattivavo": "cattivare",
    "cattive": "cattivo",
    "cattiverai": "cattivare",
    "cattiveran": "cattivare",
    "cattiveranno": "cattivare",
    "cattiverebbe": "cattivare",
    "cattiverebber": "cattivare",
    "cattiverebbero": "cattivare",
    "cattiverei": "cattivare",
    "cattiveremmo": "cattivare",
    "cattiveremo": "cattivare",
    "cattivereste": "cattivare",
    "cattiveresti": "cattivare",
    "cattiverete": "cattivare",
    "cattiverie": "cattiveria",
    "cattiverà": "cattivare",
    "cattiverò": "cattivare",
    "cattivi": "cattivo",
    "cattiviamo": "cattivare",
    "cattiviate": "cattivare",
    "cattivin": "cattivare",
    "cattivino": "cattivare",
    "cattivo": "cattivare",
    "cattivoni": "cattivone",
    "cattivò": "cattivare",
    "cattocomunisti": "cattocomunista",
    "cattolica": "cattolico",
    "cattolicesimi": "cattolicesimo",
    "cattoliche": "cattolico",
    "cattolici": "cattolico",
    "cattura": "catturare",
    "catturai": "catturare",
    "catturammo": "catturare",
    "catturan": "catturare",
    "catturando": "catturare",
    "catturano": "catturare",
    "catturante": "catturare",
    "catturanti": "catturare",
    "catturar": "catturare",
    "catturaron": "catturare",
    "catturarono": "catturare",
    "catturasse": "catturare",
    "catturasser": "catturare",
    "catturassero": "catturare",
    "catturassi": "catturare",
    "catturassimo": "catturare",
    "catturaste": "catturare",
    "catturasti": "catturare",
    "catturata": "catturare",
    "catturate": "catturare",
    "catturati": "catturare",
    "catturato": "catturare",
    "catturava": "catturare",
    "catturavamo": "catturare",
    "catturavan": "catturare",
    "catturavano": "catturare",
    "catturavate": "catturare",
    "catturavi": "catturare",
    "catturavo": "catturare",
    "catture": "cattura",
    "catturerai": "catturare",
    "cattureran": "catturare",
    "cattureranno": "catturare",
    "catturerebbe": "catturare",
    "catturerebber": "catturare",
    "catturerebbero": "catturare",
    "catturerei": "catturare",
    "cattureremmo": "catturare",
    "cattureremo": "catturare",
    "catturereste": "catturare",
    "cattureresti": "catturare",
    "catturerete": "catturare",
    "catturerà": "catturare",
    "catturerò": "catturare",
    "catturi": "catturare",
    "catturiamo": "catturare",
    "catturiate": "catturare",
    "catturin": "catturare",
    "catturino": "catturare",
    "catturo": "catturare",
    "catturò": "catturare",
    "caucasica": "caucasico",
    "caucasiche": "caucasico",
    "caucasici": "caucasico",
    "caudilli": "caudillo",
    "caudina": "caudino",
    "caudine": "caudino",
    "caudini": "caudino",
    "causa": "causare",
    "causai": "causare",
    "causali": "causale",
    "causammo": "causare",
    "causan": "causare",
    "causando": "causare",
    "causano": "causare",
    "causante": "causare",
    "causanti": "causare",
    "causar": "causare",
    "causaron": "causare",
    "causarono": "causare",
    "causasse": "causare",
    "causasser": "causare",
    "causassero": "causare",
    "causassi": "causare",
    "causassimo": "causare",
    "causaste": "causare",
    "causasti": "causare",
    "causata": "causare",
    "causate": "causare",
    "causati": "causare",
    "causato": "causare",
    "causava": "causare",
    "causavamo": "causare",
    "causavan": "causare",
    "causavano": "causare",
    "causavate": "causare",
    "causavi": "causare",
    "causavo": "causare",
    "cause": "causa",
    "causerai": "causare",
    "causeran": "causare",
    "causeranno": "causare",
    "causerebbe": "causare",
    "causerebber": "causare",
    "causerebbero": "causare",
    "causerei": "causare",
    "causeremmo": "causare",
    "causeremo": "causare",
    "causereste": "causare",
    "causeresti": "causare",
    "causerete": "causare",
    "causerà": "causare",
    "causerò": "causare",
    "causi": "causare",
    "causiamo": "causare",
    "causiate": "causare",
    "causin": "causare",
    "causino": "causare",
    "causo": "causare",
    "caustica": "caustico",
    "caustiche": "caustico",
    "caustici": "caustico",
    "causò": "causare",
    "cauta": "cauto",
    "caute": "cauto",
    "cautela": "cautelare",
    "cautelai": "cautelare",
    "cautelammo": "cautelare",
    "cautelan": "cautelare",
    "cautelando": "cautelare",
    "cautelano": "cautelare",
    "cautelante": "cautelare",
    "cautelanti": "cautelare",
    "cautelar": "cautelare",
    "cautelari": "cautelare",
    "cautelaron": "cautelare",
    "cautelarono": "cautelare",
    "cautelasse": "cautelare",
    "cautelasser": "cautelare",
    "cautelassero": "cautelare",
    "cautelassi": "cautelare",
    "cautelassimo": "cautelare",
    "cautelaste": "cautelare",
    "cautelasti": "cautelare",
    "cautelata": "cautelare",
    "cautelate": "cautelare",
    "cautelati": "cautelare",
    "cautelativa": "cautelativo",
    "cautelative": "cautelativo",
    "cautelativi": "cautelativo",
    "cautelato": "cautelare",
    "cautelava": "cautelare",
    "cautelavamo": "cautelare",
    "cautelavan": "cautelare",
    "cautelavano": "cautelare",
    "cautelavate": "cautelare",
    "cautelavi": "cautelare",
    "cautelavo": "cautelare",
    "cautele": "cautela",
    "cautelerai": "cautelare",
    "cauteleran": "cautelare",
    "cauteleranno": "cautelare",
    "cautelerebbe": "cautelare",
    "cautelerebber": "cautelare",
    "cautelerebbero": "cautelare",
    "cautelerei": "cautelare",
    "cauteleremmo": "cautelare",
    "cauteleremo": "cautelare",
    "cautelereste": "cautelare",
    "cauteleresti": "cautelare",
    "cautelerete": "cautelare",
    "cautelerà": "cautelare",
    "cautelerò": "cautelare",
    "cauteli": "cautelare",
    "cauteliamo": "cautelare",
    "cauteliate": "cautelare",
    "cautelin": "cautelare",
    "cautelino": "cautelare",
    "cautelo": "cautelare",
    "cautelò": "cautelare",
    "cauterizza": "cauterizzare",
    "cauterizzai": "cauterizzare",
    "cauterizzammo": "cauterizzare",
    "cauterizzan": "cauterizzare",
    "cauterizzando": "cauterizzare",
    "cauterizzano": "cauterizzare",
    "cauterizzante": "cauterizzare",
    "cauterizzanti": "cauterizzare",
    "cauterizzar": "cauterizzare",
    "cauterizzaron": "cauterizzare",
    "cauterizzarono": "cauterizzare",
    "cauterizzasse": "cauterizzare",
    "cauterizzasser": "cauterizzare",
    "cauterizzassero": "cauterizzare",
    "cauterizzassi": "cauterizzare",
    "cauterizzassimo": "cauterizzare",
    "cauterizzaste": "cauterizzare",
    "cauterizzasti": "cauterizzare",
    "cauterizzata": "cauterizzare",
    "cauterizzate": "cauterizzare",
    "cauterizzati": "cauterizzare",
    "cauterizzato": "cauterizzare",
    "cauterizzava": "cauterizzare",
    "cauterizzavamo": "cauterizzare",
    "cauterizzavan": "cauterizzare",
    "cauterizzavano": "cauterizzare",
    "cauterizzavate": "cauterizzare",
    "cauterizzavi": "cauterizzare",
    "cauterizzavo": "cauterizzare",
    "cauterizzerai": "cauterizzare",
    "cauterizzeran": "cauterizzare",
    "cauterizzeranno": "cauterizzare",
    "cauterizzerebbe": "cauterizzare",
    "cauterizzerebber": "cauterizzare",
    "cauterizzerebbero": "cauterizzare",
    "cauterizzerei": "cauterizzare",
    "cauterizzeremmo": "cauterizzare",
    "cauterizzeremo": "cauterizzare",
    "cauterizzereste": "cauterizzare",
    "cauterizzeresti": "cauterizzare",
    "cauterizzerete": "cauterizzare",
    "cauterizzerà": "cauterizzare",
    "cauterizzerò": "cauterizzare",
    "cauterizzi": "cauterizzare",
    "cauterizziamo": "cauterizzare",
    "cauterizziate": "cauterizzare",
    "cauterizzin": "cauterizzare",
    "cauterizzino": "cauterizzare",
    "cauterizzo": "cauterizzare",
    "cauterizzò": "cauterizzare",
    "cauti": "cauto",
    "cauziona": "cauzionare",
    "cauzionai": "cauzionare",
    "cauzionali": "cauzionale",
    "cauzionammo": "cauzionare",
    "cauzionan": "cauzionare",
    "cauzionando": "cauzionare",
    "cauzionano": "cauzionare",
    "cauzionante": "cauzionare",
    "cauzionanti": "cauzionare",
    "cauzionar": "cauzionare",
    "cauzionaron": "cauzionare",
    "cauzionarono": "cauzionare",
    "cauzionasse": "cauzionare",
    "cauzionasser": "cauzionare",
    "cauzionassero": "cauzionare",
    "cauzionassi": "cauzionare",
    "cauzionassimo": "cauzionare",
    "cauzionaste": "cauzionare",
    "cauzionasti": "cauzionare",
    "cauzionata": "cauzionare",
    "cauzionate": "cauzionare",
    "cauzionati": "cauzionare",
    "cauzionato": "cauzionare",
    "cauzionava": "cauzionare",
    "cauzionavamo": "cauzionare",
    "cauzionavan": "cauzionare",
    "cauzionavano": "cauzionare",
    "cauzionavate": "cauzionare",
    "cauzionavi": "cauzionare",
    "cauzionavo": "cauzionare",
    "cauzionerai": "cauzionare",
    "cauzioneran": "cauzionare",
    "cauzioneranno": "cauzionare",
    "cauzionerebbe": "cauzionare",
    "cauzionerebber": "cauzionare",
    "cauzionerebbero": "cauzionare",
    "cauzionerei": "cauzionare",
    "cauzioneremmo": "cauzionare",
    "cauzioneremo": "cauzionare",
    "cauzionereste": "cauzionare",
    "cauzioneresti": "cauzionare",
    "cauzionerete": "cauzionare",
    "cauzionerà": "cauzionare",
    "cauzionerò": "cauzionare",
    "cauzioni": "cauzione",
    "cauzioniamo": "cauzionare",
    "cauzioniate": "cauzionare",
    "cauzionin": "cauzionare",
    "cauzionino": "cauzionare",
    "cauziono": "cauzionare",
    "cauzionò": "cauzionare",
    "cava": "cavo",
    "cavai": "cavare",
    "cavalca": "cavalcare",
    "cavalcai": "cavalcare",
    "cavalcammo": "cavalcare",
    "cavalcan": "cavalcare",
    "cavalcando": "cavalcare",
    "cavalcano": "cavalcare",
    "cavalcante": "cavalcare",
    "cavalcanti": "cavalcare",
    "cavalcar": "cavalcare",
    "cavalcaron": "cavalcare",
    "cavalcarono": "cavalcare",
    "cavalcasse": "cavalcare",
    "cavalcasser": "cavalcare",
    "cavalcassero": "cavalcare",
    "cavalcassi": "cavalcare",
    "cavalcassimo": "cavalcare",
    "cavalcaste": "cavalcare",
    "cavalcasti": "cavalcare",
    "cavalcata": "cavalcare",
    "cavalcate": "cavalcata",
    "cavalcati": "cavalcare",
    "cavalcato": "cavalcare",
    "cavalcava": "cavalcare",
    "cavalcavamo": "cavalcare",
    "cavalcavan": "cavalcare",
    "cavalcavano": "cavalcare",
    "cavalcavate": "cavalcare",
    "cavalcavi": "cavalcare",
    "cavalcavo": "cavalcare",
    "cavalcherai": "cavalcare",
    "cavalcheran": "cavalcare",
    "cavalcheranno": "cavalcare",
    "cavalcherebbe": "cavalcare",
    "cavalcherebber": "cavalcare",
    "cavalcherebbero": "cavalcare",
    "cavalcherei": "cavalcare",
    "cavalcheremmo": "cavalcare",
    "cavalcheremo": "cavalcare",
    "cavalchereste": "cavalcare",
    "cavalcheresti": "cavalcare",
    "cavalcherete": "cavalcare",
    "cavalcherà": "cavalcare",
    "cavalcherò": "cavalcare",
    "cavalchi": "cavalcare",
    "cavalchiamo": "cavalcare",
    "cavalchiate": "cavalcare",
    "cavalchin": "cavalcare",
    "cavalchino": "cavalcare",
    "cavalco": "cavalcare",
    "cavalcò": "cavalcare",
    "cavalieri": "cavaliere",
    "cavalle": "cavalla",
    "cavalleresca": "cavalleresco",
    "cavalleresche": "cavalleresco",
    "cavallereschi": "cavalleresco",
    "cavallerie": "cavalleria",
    "cavallerizzi": "cavallerizzo",
    "cavallette": "cavalletta",
    "cavalletti": "cavalletto",
    "cavalli": "cavallo",
    "cavallina": "cavallino",
    "cavalline": "cavallino",
    "cavallini": "cavallino",
    "cavalloni": "cavallone",
    "cavallucci": "cavalluccio",
    "cavammo": "cavare",
    "cavan": "cavare",
    "cavando": "cavare",
    "cavano": "cavare",
    "cavante": "cavare",
    "cavanti": "cavare",
    "cavar": "cavare",
    "cavaron": "cavare",
    "cavarono": "cavare",
    "cavasse": "cavare",
    "cavasser": "cavare",
    "cavassero": "cavare",
    "cavassi": "cavare",
    "cavassimo": "cavare",
    "cavaste": "cavare",
    "cavasti": "cavare",
    "cavata": "cavare",
    "cavate": "cavare",
    "cavati": "cavare",
    "cavatine": "cavatina",
    "cavato": "cavare",
    "cavatori": "cavatore",
    "cavava": "cavare",
    "cavavamo": "cavare",
    "cavavan": "cavare",
    "cavavano": "cavare",
    "cavavate": "cavare",
    "cavavi": "cavare",
    "cavavo": "cavare",
    "cave": "cavo",
    "caverai": "cavare",
    "caveran": "cavare",
    "caveranno": "cavare",
    "caverebbe": "cavare",
    "caverebber": "cavare",
    "caverebbero": "cavare",
    "caverei": "cavare",
    "caveremmo": "cavare",
    "caveremo": "cavare",
    "cavereste": "cavare",
    "caveresti": "cavare",
    "caverete": "cavare",
    "cavernicola": "cavernicolo",
    "cavernicole": "cavernicolo",
    "cavernicoli": "cavernicolo",
    "cavernosa": "cavernoso",
    "cavernose": "cavernoso",
    "cavernosi": "cavernoso",
    "caverà": "cavare",
    "caverò": "cavare",
    "cavetti": "cavetto",
    "cavi": "cavo",
    "caviali": "caviale",
    "caviamo": "cavare",
    "caviate": "cavare",
    "cavie": "cavia",
    "caviglie": "caviglia",
    "cavilla": "cavillare",
    "cavillai": "cavillare",
    "cavillammo": "cavillare",
    "cavillan": "cavillare",
    "cavillando": "cavillare",
    "cavillano": "cavillare",
    "cavillante": "cavillare",
    "cavillanti": "cavillare",
    "cavillar": "cavillare",
    "cavillaron": "cavillare",
    "cavillarono": "cavillare",
    "cavillasse": "cavillare",
    "cavillasser": "cavillare",
    "cavillassero": "cavillare",
    "cavillassi": "cavillare",
    "cavillassimo": "cavillare",
    "cavillaste": "cavillare",
    "cavillasti": "cavillare",
    "cavillata": "cavillare",
    "cavillate": "cavillare",
    "cavillati": "cavillare",
    "cavillato": "cavillare",
    "cavillava": "cavillare",
    "cavillavamo": "cavillare",
    "cavillavan": "cavillare",
    "cavillavano": "cavillare",
    "cavillavate": "cavillare",
    "cavillavi": "cavillare",
    "cavillavo": "cavillare",
    "cavillerai": "cavillare",
    "cavilleran": "cavillare",
    "cavilleranno": "cavillare",
    "cavillerebbe": "cavillare",
    "cavillerebber": "cavillare",
    "cavillerebbero": "cavillare",
    "cavillerei": "cavillare",
    "cavilleremmo": "cavillare",
    "cavilleremo": "cavillare",
    "cavillereste": "cavillare",
    "cavilleresti": "cavillare",
    "cavillerete": "cavillare",
    "cavillerà": "cavillare",
    "cavillerò": "cavillare",
    "cavilli": "cavillo",
    "cavilliamo": "cavillare",
    "cavilliate": "cavillare",
    "cavillin": "cavillare",
    "cavillino": "cavillare",
    "cavillo": "cavillare",
    "cavillosa": "cavilloso",
    "cavillose": "cavilloso",
    "cavillosi": "cavilloso",
    "cavillò": "cavillare",
    "cavin": "cavare",
    "cavino": "cavare",
    "cavo": "cavare",
    "cavolfiori": "cavolfiore",
    "cavoli": "cavolo",
    "cavò": "cavare",
    "cazzate": "cazzata",
    "cazzeggerai": "cazzeggiare",
    "cazzeggeran": "cazzeggiare",
    "cazzeggeranno": "cazzeggiare",
    "cazzeggerebbe": "cazzeggiare",
    "cazzeggerebber": "cazzeggiare",
    "cazzeggerebbero": "cazzeggiare",
    "cazzeggerei": "cazzeggiare",
    "cazzeggeremmo": "cazzeggiare",
    "cazzeggeremo": "cazzeggiare",
    "cazzeggereste": "cazzeggiare",
    "cazzeggeresti": "cazzeggiare",
    "cazzeggerete": "cazzeggiare",
    "cazzeggerà": "cazzeggiare",
    "cazzeggerò": "cazzeggiare",
    "cazzeggi": "cazzeggiare",
    "cazzeggia": "cazzeggiare",
    "cazzeggiai": "cazzeggiare",
    "cazzeggiammo": "cazzeggiare",
    "cazzeggiamo": "cazzeggiare",
    "cazzeggian": "cazzeggiare",
    "cazzeggiando": "cazzeggiare",
    "cazzeggiano": "cazzeggiare",
    "cazzeggiante": "cazzeggiare",
    "cazzeggianti": "cazzeggiare",
    "cazzeggiar": "cazzeggiare",
    "cazzeggiaron": "cazzeggiare",
    "cazzeggiarono": "cazzeggiare",
    "cazzeggiasse": "cazzeggiare",
    "cazzeggiasser": "cazzeggiare",
    "cazzeggiassero": "cazzeggiare",
    "cazzeggiassi": "cazzeggiare",
    "cazzeggiassimo": "cazzeggiare",
    "cazzeggiaste": "cazzeggiare",
    "cazzeggiasti": "cazzeggiare",
    "cazzeggiata": "cazzeggiare",
    "cazzeggiate": "cazzeggiare",
    "cazzeggiati": "cazzeggiare",
    "cazzeggiato": "cazzeggiare",
    "cazzeggiava": "cazzeggiare",
    "cazzeggiavamo": "cazzeggiare",
    "cazzeggiavan": "cazzeggiare",
    "cazzeggiavano": "cazzeggiare",
    "cazzeggiavate": "cazzeggiare",
    "cazzeggiavi": "cazzeggiare",
    "cazzeggiavo": "cazzeggiare",
    "cazzeggin": "cazzeggiare",
    "cazzeggino": "cazzeggiare",
    "cazzeggio": "cazzeggiare",
    "cazzeggiò": "cazzeggiare",
    "cazzi": "cazzo",
    "cazzotta": "cazzottare",
    "cazzottai": "cazzottare",
    "cazzottammo": "cazzottare",
    "cazzottan": "cazzottare",
    "cazzottando": "cazzottare",
    "cazzottano": "cazzottare",
    "cazzottante": "cazzottare",
    "cazzottanti": "cazzottare",
    "cazzottar": "cazzottare",
    "cazzottaron": "cazzottare",
    "cazzottarono": "cazzottare",
    "cazzottasse": "cazzottare",
    "cazzottasser": "cazzottare",
    "cazzottassero": "cazzottare",
    "cazzottassi": "cazzottare",
    "cazzottassimo": "cazzottare",
    "cazzottaste": "cazzottare",
    "cazzottasti": "cazzottare",
    "cazzottata": "cazzottare",
    "cazzottate": "cazzottare",
    "cazzottati": "cazzottare",
    "cazzottato": "cazzottare",
    "cazzottava": "cazzottare",
    "cazzottavamo": "cazzottare",
    "cazzottavan": "cazzottare",
    "cazzottavano": "cazzottare",
    "cazzottavate": "cazzottare",
    "cazzottavi": "cazzottare",
    "cazzottavo": "cazzottare",
    "cazzotterai": "cazzottare",
    "cazzotteran": "cazzottare",
    "cazzotteranno": "cazzottare",
    "cazzotterebbe": "cazzottare",
    "cazzotterebber": "cazzottare",
    "cazzotterebbero": "cazzottare",
    "cazzotterei": "cazzottare",
    "cazzotteremmo": "cazzottare",
    "cazzotteremo": "cazzottare",
    "cazzottereste": "cazzottare",
    "cazzotteresti": "cazzottare",
    "cazzotterete": "cazzottare",
    "cazzotterà": "cazzottare",
    "cazzotterò": "cazzottare",
    "cazzotti": "cazzotto",
    "cazzottiamo": "cazzottare",
    "cazzottiate": "cazzottare",
    "cazzottin": "cazzottare",
    "cazzottino": "cazzottare",
    "cazzotto": "cazzottare",
    "cazzottò": "cazzottare",
    "ceca": "ceco",
    "cecchini": "cecchino",
    "cecena": "ceceno",
    "cecene": "ceceno",
    "ceceni": "ceceno",
    "ceche": "ceco",
    "cechi": "ceco",
    "ceci": "ceco",
    "cecoslovacca": "cecoslovacco",
    "cecoslovacche": "cecoslovacco",
    "cecoslovacchi": "cecoslovacco",
    "ceda": "cedere",
    "cedan": "cedere",
    "cedano": "cedere",
    "cede": "cedere",
    "cedemmo": "cedere",
    "cedendo": "cedere",
    "cedente": "cedere",
    "cedenti": "cedere",
    "ceder": "cedere",
    "cederai": "cedere",
    "cederan": "cedere",
    "cederanno": "cedere",
    "cederebbe": "cedere",
    "cederebber": "cedere",
    "cederebbero": "cedere",
    "cederei": "cedere",
    "cederemmo": "cedere",
    "cederemo": "cedere",
    "cedereste": "cedere",
    "cederesti": "cedere",
    "cederete": "cedere",
    "cederà": "cedere",
    "cederò": "cedere",
    "cedesse": "cedere",
    "cedesser": "cedere",
    "cedessero": "cedere",
    "cedessi": "cedere",
    "cedessimo": "cedere",
    "cedeste": "cedere",
    "cedesti": "cedere",
    "cedete": "cedere",
    "cedette": "cedere",
    "cedetter": "cedere",
    "cedettero": "cedere",
    "cedetti": "cedere",
    "cedeva": "cedere",
    "cedevamo": "cedere",
    "cedevan": "cedere",
    "cedevano": "cedere",
    "cedevate": "cedere",
    "cedevi": "cedere",
    "cedevo": "cedere",
    "cedevoli": "cedevole",
    "cedi": "cedere",
    "cediamo": "cedere",
    "cediate": "cedere",
    "cedibili": "cedibile",
    "cedimenti": "cedimento",
    "cedo": "cedere",
    "cedola": "cedolare",
    "cedolai": "cedolare",
    "cedolammo": "cedolare",
    "cedolan": "cedolare",
    "cedolando": "cedolare",
    "cedolano": "cedolare",
    "cedolante": "cedolare",
    "cedolanti": "cedolare",
    "cedolar": "cedolare",
    "cedolari": "cedolare",
    "cedolaron": "cedolare",
    "cedolarono": "cedolare",
    "cedolasse": "cedolare",
    "cedolasser": "cedolare",
    "cedolassero": "cedolare",
    "cedolassi": "cedolare",
    "cedolassimo": "cedolare",
    "cedolaste": "cedolare",
    "cedolasti": "cedolare",
    "cedolata": "cedolare",
    "cedolate": "cedolare",
    "cedolati": "cedolare",
    "cedolato": "cedolare",
    "cedolava": "cedolare",
    "cedolavamo": "cedolare",
    "cedolavan": "cedolare",
    "cedolavano": "cedolare",
    "cedolavate": "cedolare",
    "cedolavi": "cedolare",
    "cedolavo": "cedolare",
    "cedole": "cedola",
    "cedolerai": "cedolare",
    "cedoleran": "cedolare",
    "cedoleranno": "cedolare",
    "cedolerebbe": "cedolare",
    "cedolerebber": "cedolare",
    "cedolerebbero": "cedolare",
    "cedolerei": "cedolare",
    "cedoleremmo": "cedolare",
    "cedoleremo": "cedolare",
    "cedolereste": "cedolare",
    "cedoleresti": "cedolare",
    "cedolerete": "cedolare",
    "cedolerà": "cedolare",
    "cedolerò": "cedolare",
    "cedoli": "cedolare",
    "cedoliamo": "cedolare",
    "cedoliate": "cedolare",
    "cedolin": "cedolare",
    "cedolini": "cedolino",
    "cedolino": "cedolare",
    "cedolo": "cedolare",
    "cedolò": "cedolare",
    "cedon": "cedere",
    "cedono": "cedere",
    "cedri": "cedro",
    "ceduta": "cedere",
    "cedute": "cedere",
    "ceduti": "cedere",
    "ceduto": "cedere",
    "cefalee": "cefalea",
    "ceffi": "ceffo",
    "ceffoni": "ceffone",
    "ceki": "ceko",
    "cela": "celare",
    "celai": "celare",
    "celammo": "celare",
    "celan": "celare",
    "celando": "celare",
    "celano": "celare",
    "celante": "celare",
    "celanti": "celare",
    "celar": "celare",
    "celaron": "celare",
    "celarono": "celare",
    "celasse": "celare",
    "celasser": "celare",
    "celassero": "celare",
    "celassi": "celare",
    "celassimo": "celare",
    "celaste": "celare",
    "celasti": "celare",
    "celata": "celare",
    "celate": "celare",
    "celati": "celare",
    "celato": "celare",
    "celava": "celare",
    "celavamo": "celare",
    "celavan": "celare",
    "celavano": "celare",
    "celavate": "celare",
    "celavi": "celare",
    "celavo": "celare",
    "celeberrima": "celeberrimo",
    "celeberrime": "celeberrimo",
    "celeberrimi": "celeberrimo",
    "celebra": "celebrare",
    "celebrai": "celebrare",
    "celebrammo": "celebrare",
    "celebran": "celebrare",
    "celebrando": "celebrare",
    "celebrano": "celebrare",
    "celebrante": "celebrare",
    "celebranti": "celebrare",
    "celebrar": "celebrare",
    "celebraron": "celebrare",
    "celebrarono": "celebrare",
    "celebrasse": "celebrare",
    "celebrasser": "celebrare",
    "celebrassero": "celebrare",
    "celebrassi": "celebrare",
    "celebrassimo": "celebrare",
    "celebraste": "celebrare",
    "celebrasti": "celebrare",
    "celebrata": "celebrare",
    "celebrate": "celebrare",
    "celebrati": "celebrare",
    "celebrativa": "celebrativo",
    "celebrative": "celebrativo",
    "celebrativi": "celebrativo",
    "celebrato": "celebrare",
    "celebrava": "celebrare",
    "celebravamo": "celebrare",
    "celebravan": "celebrare",
    "celebravano": "celebrare",
    "celebravate": "celebrare",
    "celebravi": "celebrare",
    "celebravo": "celebrare",
    "celebrazioni": "celebrazione",
    "celebrerai": "celebrare",
    "celebreran": "celebrare",
    "celebreranno": "celebrare",
    "celebrerebbe": "celebrare",
    "celebrerebber": "celebrare",
    "celebrerebbero": "celebrare",
    "celebrerei": "celebrare",
    "celebreremmo": "celebrare",
    "celebreremo": "celebrare",
    "celebrereste": "celebrare",
    "celebreresti": "celebrare",
    "celebrerete": "celebrare",
    "celebrerà": "celebrare",
    "celebrerò": "celebrare",
    "celebri": "celebre",
    "celebriamo": "celebrare",
    "celebriate": "celebrare",
    "celebrin": "celebrare",
    "celebrino": "celebrare",
    "celebro": "celebrare",
    "celebrò": "celebrare",
    "celerai": "celare",
    "celeran": "celare",
    "celeranno": "celare",
    "celerebbe": "celare",
    "celerebber": "celare",
    "celerebbero": "celare",
    "celerei": "celare",
    "celeremmo": "celare",
    "celeremo": "celare",
    "celereste": "celare",
    "celeresti": "celare",
    "celerete": "celare",
    "celeri": "celere",
    "celerini": "celerino",
    "celerà": "celare",
    "celerò": "celare",
    "celesti": "celeste",
    "celestiali": "celestiale",
    "celestina": "celestino",
    "celestine": "celestino",
    "celestini": "celestino",
    "celi": "celare",
    "celiamo": "celare",
    "celiate": "celare",
    "celibati": "celibato",
    "celibi": "celibe",
    "celin": "celare",
    "celino": "celare",
    "celle": "cella",
    "cellette": "celletta",
    "cellulari": "cellulare",
    "cellule": "cellula",
    "celluliti": "cellulite",
    "cellulosa": "celluloso",
    "cellulose": "celluloso",
    "cellulosi": "celluloso",
    "celo": "celare",
    "celtica": "celtico",
    "celtiche": "celtico",
    "celtici": "celtico",
    "celò": "celare",
    "cembali": "cembalo",
    "cementa": "cementare",
    "cementai": "cementare",
    "cementammo": "cementare",
    "cementan": "cementare",
    "cementando": "cementare",
    "cementano": "cementare",
    "cementante": "cementare",
    "cementanti": "cementare",
    "cementar": "cementare",
    "cementaron": "cementare",
    "cementarono": "cementare",
    "cementasse": "cementare",
    "cementasser": "cementare",
    "cementassero": "cementare",
    "cementassi": "cementare",
    "cementassimo": "cementare",
    "cementaste": "cementare",
    "cementasti": "cementare",
    "cementata": "cementare",
    "cementate": "cementare",
    "cementati": "cementare",
    "cementato": "cementare",
    "cementava": "cementare",
    "cementavamo": "cementare",
    "cementavan": "cementare",
    "cementavano": "cementare",
    "cementavate": "cementare",
    "cementavi": "cementare",
    "cementavo": "cementare",
    "cementerai": "cementare",
    "cementeran": "cementare",
    "cementeranno": "cementare",
    "cementerebbe": "cementare",
    "cementerebber": "cementare",
    "cementerebbero": "cementare",
    "cementerei": "cementare",
    "cementeremmo": "cementare",
    "cementeremo": "cementare",
    "cementereste": "cementare",
    "cementeresti": "cementare",
    "cementerete": "cementare",
    "cementerie": "cementeria",
    "cementerà": "cementare",
    "cementerò": "cementare",
    "cementi": "cemento",
    "cementiamo": "cementare",
    "cementiate": "cementare",
    "cementiera": "cementiero",
    "cementiere": "cementiero",
    "cementieri": "cementiero",
    "cementifera": "cementifero",
    "cementifere": "cementifero",
    "cementiferi": "cementifero",
    "cementifica": "cementificare",
    "cementificai": "cementificare",
    "cementificammo": "cementificare",
    "cementifican": "cementificare",
    "cementificando": "cementificare",
    "cementificano": "cementificare",
    "cementificante": "cementificare",
    "cementificanti": "cementificare",
    "cementificar": "cementificare",
    "cementificaron": "cementificare",
    "cementificarono": "cementificare",
    "cementificasse": "cementificare",
    "cementificasser": "cementificare",
    "cementificassero": "cementificare",
    "cementificassi": "cementificare",
    "cementificassimo": "cementificare",
    "cementificaste": "cementificare",
    "cementificasti": "cementificare",
    "cementificata": "cementificare",
    "cementificate": "cementificare",
    "cementificati": "cementificare",
    "cementificato": "cementificare",
    "cementificava": "cementificare",
    "cementificavamo": "cementificare",
    "cementificavan": "cementificare",
    "cementificavano": "cementificare",
    "cementificavate": "cementificare",
    "cementificavi": "cementificare",
    "cementificavo": "cementificare",
    "cementificazioni": "cementificazione",
    "cementificherai": "cementificare",
    "cementificheran": "cementificare",
    "cementificheranno": "cementificare",
    "cementificherebbe": "cementificare",
    "cementificherebber": "cementificare",
    "cementificherebbero": "cementificare",
    "cementificherei": "cementificare",
    "cementificheremmo": "cementificare",
    "cementificheremo": "cementificare",
    "cementifichereste": "cementificare",
    "cementificheresti": "cementificare",
    "cementificherete": "cementificare",
    "cementificherà": "cementificare",
    "cementificherò": "cementificare",
    "cementifichi": "cementificare",
    "cementifichiamo": "cementificare",
    "cementifichiate": "cementificare",
    "cementifichin": "cementificare",
    "cementifichino": "cementificare",
    "cementifici": "cementificio",
    "cementifico": "cementificare",
    "cementificò": "cementificare",
    "cementin": "cementare",
    "cementino": "cementare",
    "cemento": "cementare",
    "cementò": "cementare",
    "cena": "cenare",
    "cenacoli": "cenacolo",
    "cenai": "cenare",
    "cenammo": "cenare",
    "cenan": "cenare",
    "cenando": "cenare",
    "cenano": "cenare",
    "cenante": "cenare",
    "cenanti": "cenare",
    "cenar": "cenare",
    "cenaron": "cenare",
    "cenarono": "cenare",
    "cenasse": "cenare",
    "cenasser": "cenare",
    "cenassero": "cenare",
    "cenassi": "cenare",
    "cenassimo": "cenare",
    "cenaste": "cenare",
    "cenasti": "cenare",
    "cenata": "cenare",
    "cenate": "cenare",
    "cenati": "cenare",
    "cenato": "cenare",
    "cenava": "cenare",
    "cenavamo": "cenare",
    "cenavan": "cenare",
    "cenavano": "cenare",
    "cenavate": "cenare",
    "cenavi": "cenare",
    "cenavo": "cenare",
    "cenci": "cencio",
    "cenciosa": "cencioso",
    "cenciose": "cencioso",
    "cenciosi": "cencioso",
    "cene": "cena",
    "cenerai": "cenare",
    "ceneran": "cenare",
    "ceneranno": "cenare",
    "cenerebbe": "cenare",
    "cenerebber": "cenare",
    "cenerebbero": "cenare",
    "cenerei": "cenare",
    "ceneremmo": "cenare",
    "ceneremo": "cenare",
    "cenerentole": "cenerentola",
    "cenereste": "cenare",
    "ceneresti": "cenare",
    "cenerete": "cenare",
    "ceneri": "cenere",
    "cenerà": "cenare",
    "cenerò": "cenare",
    "cenette": "cenetta",
    "ceni": "cenare",
    "ceniamo": "cenare",
    "ceniate": "cenare",
    "cenin": "cenare",
    "cenino": "cenare",
    "cenni": "cenno",
    "ceno": "cenare",
    "cenoni": "cenone",
    "censa": "censire",
    "censan": "censire",
    "censano": "censire",
    "cense": "censire",
    "censendo": "censire",
    "censente": "censire",
    "censenti": "censire",
    "censi": "censo",
    "censiamo": "censire",
    "censiate": "censire",
    "censii": "censire",
    "censimenti": "censimento",
    "censimmo": "censire",
    "censir": "censire",
    "censirai": "censire",
    "censiran": "censire",
    "censiranno": "censire",
    "censirebbe": "censire",
    "censirebber": "censire",
    "censirebbero": "censire",
    "censirei": "censire",
    "censiremmo": "censire",
    "censiremo": "censire",
    "censireste": "censire",
    "censiresti": "censire",
    "censirete": "censire",
    "censiron": "censire",
    "censirono": "censire",
    "censirà": "censire",
    "censirò": "censire",
    "censisse": "censire",
    "censisser": "censire",
    "censissero": "censire",
    "censissi": "censire",
    "censissimo": "censire",
    "censiste": "censire",
    "censisti": "censire",
    "censita": "censito",
    "censite": "censito",
    "censiti": "censito",
    "censito": "censire",
    "censiva": "censire",
    "censivamo": "censire",
    "censivan": "censire",
    "censivano": "censire",
    "censivate": "censire",
    "censivi": "censire",
    "censivo": "censire",
    "censo": "censire",
    "censon": "censire",
    "censono": "censire",
    "censori": "censorio",
    "censoria": "censorio",
    "censorie": "censorio",
    "censuari": "censuario",
    "censuaria": "censuario",
    "censuarie": "censuario",
    "censura": "censurare",
    "censurabili": "censurabile",
    "censurai": "censurare",
    "censurammo": "censurare",
    "censuran": "censurare",
    "censurando": "censurare",
    "censurano": "censurare",
    "censurante": "censurare",
    "censuranti": "censurare",
    "censurar": "censurare",
    "censuraron": "censurare",
    "censurarono": "censurare",
    "censurasse": "censurare",
    "censurasser": "censurare",
    "censurassero": "censurare",
    "censurassi": "censurare",
    "censurassimo": "censurare",
    "censuraste": "censurare",
    "censurasti": "censurare",
    "censurata": "censurare",
    "censurate": "censurare",
    "censurati": "censurare",
    "censurato": "censurare",
    "censurava": "censurare",
    "censuravamo": "censurare",
    "censuravan": "censurare",
    "censuravano": "censurare",
    "censuravate": "censurare",
    "censuravi": "censurare",
    "censuravo": "censurare",
    "censure": "censura",
    "censurerai": "censurare",
    "censureran": "censurare",
    "censureranno": "censurare",
    "censurerebbe": "censurare",
    "censurerebber": "censurare",
    "censurerebbero": "censurare",
    "censurerei": "censurare",
    "censureremmo": "censurare",
    "censureremo": "censurare",
    "censurereste": "censurare",
    "censureresti": "censurare",
    "censurerete": "censurare",
    "censurerà": "censurare",
    "censurerò": "censurare",
    "censuri": "censurare",
    "censuriamo": "censurare",
    "censuriate": "censurare",
    "censurin": "censurare",
    "censurino": "censurare",
    "censuro": "censurare",
    "censurò": "censurare",
    "censì": "censire",
    "centellina": "centellinare",
    "centellinai": "centellinare",
    "centellinammo": "centellinare",
    "centellinan": "centellinare",
    "centellinando": "centellinare",
    "centellinano": "centellinare",
    "centellinante": "centellinare",
    "centellinanti": "centellinare",
    "centellinar": "centellinare",
    "centellinaron": "centellinare",
    "centellinarono": "centellinare",
    "centellinasse": "centellinare",
    "centellinasser": "centellinare",
    "centellinassero": "centellinare",
    "centellinassi": "centellinare",
    "centellinassimo": "centellinare",
    "centellinaste": "centellinare",
    "centellinasti": "centellinare",
    "centellinata": "centellinare",
    "centellinate": "centellinare",
    "centellinati": "centellinare",
    "centellinato": "centellinare",
    "centellinava": "centellinare",
    "centellinavamo": "centellinare",
    "centellinavan": "centellinare",
    "centellinavano": "centellinare",
    "centellinavate": "centellinare",
    "centellinavi": "centellinare",
    "centellinavo": "centellinare",
    "centellinerai": "centellinare",
    "centellineran": "centellinare",
    "centellineranno": "centellinare",
    "centellinerebbe": "centellinare",
    "centellinerebber": "centellinare",
    "centellinerebbero": "centellinare",
    "centellinerei": "centellinare",
    "centellineremmo": "centellinare",
    "centellineremo": "centellinare",
    "centellinereste": "centellinare",
    "centellineresti": "centellinare",
    "centellinerete": "centellinare",
    "centellinerà": "centellinare",
    "centellinerò": "centellinare",
    "centellini": "centellinare",
    "centelliniamo": "centellinare",
    "centelliniate": "centellinare",
    "centellinin": "centellinare",
    "centellinino": "centellinare",
    "centellino": "centellinare",
    "centellinò": "centellinare",
    "centenari": "centenario",
    "centenaria": "centenario",
    "centenarie": "centenario",
    "centesima": "centesimo",
    "centesimali": "centesimale",
    "centesime": "centesimo",
    "centesimi": "centesimo",
    "centimetra": "centimetrare",
    "centimetrai": "centimetrare",
    "centimetrammo": "centimetrare",
    "centimetran": "centimetrare",
    "centimetrando": "centimetrare",
    "centimetrano": "centimetrare",
    "centimetrante": "centimetrare",
    "centimetranti": "centimetrare",
    "centimetrar": "centimetrare",
    "centimetraron": "centimetrare",
    "centimetrarono": "centimetrare",
    "centimetrasse": "centimetrare",
    "centimetrasser": "centimetrare",
    "centimetrassero": "centimetrare",
    "centimetrassi": "centimetrare",
    "centimetrassimo": "centimetrare",
    "centimetraste": "centimetrare",
    "centimetrasti": "centimetrare",
    "centimetrata": "centimetrare",
    "centimetrate": "centimetrare",
    "centimetrati": "centimetrare",
    "centimetrato": "centimetrare",
    "centimetrava": "centimetrare",
    "centimetravamo": "centimetrare",
    "centimetravan": "centimetrare",
    "centimetravano": "centimetrare",
    "centimetravate": "centimetrare",
    "centimetravi": "centimetrare",
    "centimetravo": "centimetrare",
    "centimetrerai": "centimetrare",
    "centimetreran": "centimetrare",
    "centimetreranno": "centimetrare",
    "centimetrerebbe": "centimetrare",
    "centimetrerebber": "centimetrare",
    "centimetrerebbero": "centimetrare",
    "centimetrerei": "centimetrare",
    "centimetreremmo": "centimetrare",
    "centimetreremo": "centimetrare",
    "centimetrereste": "centimetrare",
    "centimetreresti": "centimetrare",
    "centimetrerete": "centimetrare",
    "centimetrerà": "centimetrare",
    "centimetrerò": "centimetrare",
    "centimetri": "centimetro",
    "centimetriamo": "centimetrare",
    "centimetriate": "centimetrare",
    "centimetrin": "centimetrare",
    "centimetrino": "centimetrare",
    "centimetro": "centimetrare",
    "centimetrò": "centimetrare",
    "centina": "centinare",
    "centinai": "centinare",
    "centinaia": "centinaio",
    "centinammo": "centinare",
    "centinan": "centinare",
    "centinando": "centinare",
    "centinano": "centinare",
    "centinante": "centinare",
    "centinanti": "centinare",
    "centinar": "centinare",
    "centinaron": "centinare",
    "centinarono": "centinare",
    "centinasse": "centinare",
    "centinasser": "centinare",
    "centinassero": "centinare",
    "centinassi": "centinare",
    "centinassimo": "centinare",
    "centinaste": "centinare",
    "centinasti": "centinare",
    "centinata": "centinare",
    "centinate": "centinare",
    "centinati": "centinare",
    "centinato": "centinare",
    "centinava": "centinare",
    "centinavamo": "centinare",
    "centinavan": "centinare",
    "centinavano": "centinare",
    "centinavate": "centinare",
    "centinavi": "centinare",
    "centinavo": "centinare",
    "centinerai": "centinare",
    "centineran": "centinare",
    "centineranno": "centinare",
    "centinerebbe": "centinare",
    "centinerebber": "centinare",
    "centinerebbero": "centinare",
    "centinerei": "centinare",
    "centineremmo": "centinare",
    "centineremo": "centinare",
    "centinereste": "centinare",
    "centineresti": "centinare",
    "centinerete": "centinare",
    "centinerà": "centinare",
    "centinerò": "centinare",
    "centini": "centinare",
    "centiniamo": "centinare",
    "centiniate": "centinare",
    "centinin": "centinare",
    "centinino": "centinare",
    "centino": "centinare",
    "centinò": "centinare",
    "centocinquantesima": "centocinquantesimo",
    "centocinquantesime": "centocinquantesimo",
    "centocinquantesimi": "centocinquantesimo",
    "centodecima": "centodecimo",
    "centodecime": "centodecimo",
    "centodecimi": "centodecimo",
    "centometristi": "centometrista",
    "centoni": "centone",
    "centonovantesima": "centonovantesimo",
    "centonovantesime": "centonovantesimo",
    "centonovantesimi": "centonovantesimo",
    "centoquarantesima": "centoquarantesimo",
    "centoquarantesime": "centoquarantesimo",
    "centoquarantesimi": "centoquarantesimo",
    "centosessantesima": "centosessantesimo",
    "centosessantesime": "centosessantesimo",
    "centosessantesimi": "centosessantesimo",
    "centosettantesima": "centosettantesimo",
    "centosettantesime": "centosettantesimo",
    "centosettantesimi": "centosettantesimo",
    "centotrentesima": "centotrentesimo",
    "centotrentesime": "centotrentesimo",
    "centotrentesimi": "centotrentesimo",
    "centottantesima": "centottantesimo",
    "centottantesime": "centottantesimo",
    "centottantesimi": "centottantesimo",
    "centoventesima": "centoventesimo",
    "centoventesime": "centoventesimo",
    "centoventesimi": "centoventesimo",
    "centra": "centrare",
    "centrai": "centrare",
    "centrali": "centrale",
    "centraline": "centralina",
    "centralini": "centralino",
    "centraliniste": "centralinista",
    "centralinisti": "centralinista",
    "centralismi": "centralismo",
    "centralistica": "centralistico",
    "centralistiche": "centralistico",
    "centralistici": "centralistico",
    "centralizza": "centralizzare",
    "centralizzai": "centralizzare",
    "centralizzammo": "centralizzare",
    "centralizzan": "centralizzare",
    "centralizzando": "centralizzare",
    "centralizzano": "centralizzare",
    "centralizzante": "centralizzare",
    "centralizzanti": "centralizzare",
    "centralizzar": "centralizzare",
    "centralizzaron": "centralizzare",
    "centralizzarono": "centralizzare",
    "centralizzasse": "centralizzare",
    "centralizzasser": "centralizzare",
    "centralizzassero": "centralizzare",
    "centralizzassi": "centralizzare",
    "centralizzassimo": "centralizzare",
    "centralizzaste": "centralizzare",
    "centralizzasti": "centralizzare",
    "centralizzata": "centralizzare",
    "centralizzate": "centralizzare",
    "centralizzati": "centralizzare",
    "centralizzato": "centralizzare",
    "centralizzava": "centralizzare",
    "centralizzavamo": "centralizzare",
    "centralizzavan": "centralizzare",
    "centralizzavano": "centralizzare",
    "centralizzavate": "centralizzare",
    "centralizzavi": "centralizzare",
    "centralizzavo": "centralizzare",
    "centralizzazioni": "centralizzazione",
    "centralizzerai": "centralizzare",
    "centralizzeran": "centralizzare",
    "centralizzeranno": "centralizzare",
    "centralizzerebbe": "centralizzare",
    "centralizzerebber": "centralizzare",
    "centralizzerebbero": "centralizzare",
    "centralizzerei": "centralizzare",
    "centralizzeremmo": "centralizzare",
    "centralizzeremo": "centralizzare",
    "centralizzereste": "centralizzare",
    "centralizzeresti": "centralizzare",
    "centralizzerete": "centralizzare",
    "centralizzerà": "centralizzare",
    "centralizzerò": "centralizzare",
    "centralizzi": "centralizzare",
    "centralizziamo": "centralizzare",
    "centralizziate": "centralizzare",
    "centralizzin": "centralizzare",
    "centralizzino": "centralizzare",
    "centralizzo": "centralizzare",
    "centralizzò": "centralizzare",
    "centramericana": "centramericano",
    "centramericane": "centramericano",
    "centramericani": "centramericano",
    "centrammo": "centrare",
    "centran": "centrare",
    "centrando": "centrare",
    "centrano": "centrare",
    "centrante": "centrare",
    "centranti": "centrare",
    "centrar": "centrare",
    "centraron": "centrare",
    "centrarono": "centrare",
    "centrasse": "centrare",
    "centrasser": "centrare",
    "centrassero": "centrare",
    "centrassi": "centrare",
    "centrassimo": "centrare",
    "centraste": "centrare",
    "centrasti": "centrare",
    "centrata": "centrato",
    "centrate": "centrato",
    "centrati": "centrato",
    "centrato": "centrare",
    "centrava": "centrare",
    "centravamo": "centrare",
    "centravan": "centrare",
    "centravano": "centrare",
    "centravate": "centrare",
    "centravi": "centrare",
    "centravo": "centrare",
    "centrerai": "centrare",
    "centreran": "centrare",
    "centreranno": "centrare",
    "centrerebbe": "centrare",
    "centrerebber": "centrare",
    "centrerebbero": "centrare",
    "centrerei": "centrare",
    "centreremmo": "centrare",
    "centreremo": "centrare",
    "centrereste": "centrare",
    "centreresti": "centrare",
    "centrerete": "centrare",
    "centrerà": "centrare",
    "centrerò": "centrare",
    "centri": "centro",
    "centriamo": "centrare",
    "centriate": "centrare",
    "centrifuga": "centrifugo",
    "centrifugai": "centrifugare",
    "centrifugammo": "centrifugare",
    "centrifugan": "centrifugare",
    "centrifugando": "centrifugare",
    "centrifugano": "centrifugare",
    "centrifugante": "centrifugare",
    "centrifuganti": "centrifugare",
    "centrifugar": "centrifugare",
    "centrifugaron": "centrifugare",
    "centrifugarono": "centrifugare",
    "centrifugasse": "centrifugare",
    "centrifugasser": "centrifugare",
    "centrifugassero": "centrifugare",
    "centrifugassi": "centrifugare",
    "centrifugassimo": "centrifugare",
    "centrifugaste": "centrifugare",
    "centrifugasti": "centrifugare",
    "centrifugata": "centrifugare",
    "centrifugate": "centrifugare",
    "centrifugati": "centrifugare",
    "centrifugato": "centrifugare",
    "centrifugava": "centrifugare",
    "centrifugavamo": "centrifugare",
    "centrifugavan": "centrifugare",
    "centrifugavano": "centrifugare",
    "centrifugavate": "centrifugare",
    "centrifugavi": "centrifugare",
    "centrifugavo": "centrifugare",
    "centrifughe": "centrifugo",
    "centrifugherai": "centrifugare",
    "centrifugheran": "centrifugare",
    "centrifugheranno": "centrifugare",
    "centrifugherebbe": "centrifugare",
    "centrifugherebber": "centrifugare",
    "centrifugherebbero": "centrifugare",
    "centrifugherei": "centrifugare",
    "centrifugheremmo": "centrifugare",
    "centrifugheremo": "centrifugare",
    "centrifughereste": "centrifugare",
    "centrifugheresti": "centrifugare",
    "centrifugherete": "centrifugare",
    "centrifugherà": "centrifugare",
    "centrifugherò": "centrifugare",
    "centrifughi": "centrifugo",
    "centrifughiamo": "centrifugare",
    "centrifughiate": "centrifugare",
    "centrifughin": "centrifugare",
    "centrifughino": "centrifugare",
    "centrifugo": "centrifugare",
    "centrifugò": "centrifugare",
    "centrin": "centrare",
    "centrini": "centrino",
    "centrino": "centrare",
    "centripeta": "centripeto",
    "centripete": "centripeto",
    "centripeti": "centripeto",
    "centrismi": "centrismo",
    "centrista": "centristo",
    "centriste": "centristo",
    "centristi": "centristo",
    "centro": "centrare",
    "centro-europea": "centro-europeo",
    "centro-europee": "centro-europeo",
    "centro-europei": "centro-europeo",
    "centro-meridionali": "centro-meridionale",
    "centro-occidentali": "centro-occidentale",
    "centro-orientali": "centro-orientale",
    "centro-settentrionali": "centro-settentrionale",
    "centroamericana": "centroamericano",
    "centroamericane": "centroamericano",
    "centroamericani": "centroamericano",
    "centrocampi": "centrocampo",
    "centrocampisti": "centrocampista",
    "centroeuropea": "centroeuropeo",
    "centroeuropee": "centroeuropeo",
    "centroeuropei": "centroeuropeo",
    "centrorientali": "centrorientale",
    "centrò": "centrare",
    "centuplica": "centuplicare",
    "centuplicai": "centuplicare",
    "centuplicammo": "centuplicare",
    "centuplican": "centuplicare",
    "centuplicando": "centuplicare",
    "centuplicano": "centuplicare",
    "centuplicante": "centuplicare",
    "centuplicanti": "centuplicare",
    "centuplicar": "centuplicare",
    "centuplicaron": "centuplicare",
    "centuplicarono": "centuplicare",
    "centuplicasse": "centuplicare",
    "centuplicasser": "centuplicare",
    "centuplicassero": "centuplicare",
    "centuplicassi": "centuplicare",
    "centuplicassimo": "centuplicare",
    "centuplicaste": "centuplicare",
    "centuplicasti": "centuplicare",
    "centuplicata": "centuplicare",
    "centuplicate": "centuplicare",
    "centuplicati": "centuplicare",
    "centuplicato": "centuplicare",
    "centuplicava": "centuplicare",
    "centuplicavamo": "centuplicare",
    "centuplicavan": "centuplicare",
    "centuplicavano": "centuplicare",
    "centuplicavate": "centuplicare",
    "centuplicavi": "centuplicare",
    "centuplicavo": "centuplicare",
    "centuplicherai": "centuplicare",
    "centuplicheran": "centuplicare",
    "centuplicheranno": "centuplicare",
    "centuplicherebbe": "centuplicare",
    "centuplicherebber": "centuplicare",
    "centuplicherebbero": "centuplicare",
    "centuplicherei": "centuplicare",
    "centuplicheremmo": "centuplicare",
    "centuplicheremo": "centuplicare",
    "centuplichereste": "centuplicare",
    "centuplicheresti": "centuplicare",
    "centuplicherete": "centuplicare",
    "centuplicherà": "centuplicare",
    "centuplicherò": "centuplicare",
    "centuplichi": "centuplicare",
    "centuplichiamo": "centuplicare",
    "centuplichiate": "centuplicare",
    "centuplichin": "centuplicare",
    "centuplichino": "centuplicare",
    "centuplico": "centuplicare",
    "centuplicò": "centuplicare",
    "centurie": "centuria",
    "centurioni": "centurione",
    "cenò": "cenare",
    "ceppi": "ceppo",
    "cera": "cerare",
    "cerai": "cerare",
    "ceramica": "ceramico",
    "ceramiche": "ceramico",
    "ceramici": "ceramico",
    "ceramisti": "ceramista",
    "cerammo": "cerare",
    "ceran": "cerare",
    "cerando": "cerare",
    "cerano": "cerare",
    "cerante": "cerare",
    "ceranti": "cerare",
    "cerar": "cerare",
    "ceraron": "cerare",
    "cerarono": "cerare",
    "cerasse": "cerare",
    "cerasser": "cerare",
    "cerassero": "cerare",
    "cerassi": "cerare",
    "cerassimo": "cerare",
    "ceraste": "cerare",
    "cerasti": "cerare",
    "cerata": "cerato",
    "cerate": "cerato",
    "cerati": "cerato",
    "cerato": "cerare",
    "cerava": "cerare",
    "ceravamo": "cerare",
    "ceravan": "cerare",
    "ceravano": "cerare",
    "ceravate": "cerare",
    "ceravi": "cerare",
    "ceravo": "cerare",
    "cerberi": "cerbero",
    "cerbiatti": "cerbiatto",
    "cerca": "cercare",
    "cercai": "cercare",
    "cercammo": "cercare",
    "cercan": "cercare",
    "cercando": "cercare",
    "cercano": "cercare",
    "cercante": "cercare",
    "cercanti": "cercare",
    "cercar": "cercare",
    "cercaron": "cercare",
    "cercarono": "cercare",
    "cercasse": "cercare",
    "cercasser": "cercare",
    "cercassero": "cercare",
    "cercassi": "cercare",
    "cercassimo": "cercare",
    "cercaste": "cercare",
    "cercasti": "cercare",
    "cercata": "cercare",
    "cercate": "cercare",
    "cercati": "cercare",
    "cercato": "cercare",
    "cercatori": "cercatore",
    "cercatrice": "cercatore",
    "cercatrici": "cercatore",
    "cercava": "cercare",
    "cercavamo": "cercare",
    "cercavan": "cercare",
    "cercavano": "cercare",
    "cercavate": "cercare",
    "cercavi": "cercare",
    "cercavo": "cercare",
    "cercherai": "cercare",
    "cercheran": "cercare",
    "cercheranno": "cercare",
    "cercherebbe": "cercare",
    "cercherebber": "cercare",
    "cercherebbero": "cercare",
    "cercherei": "cercare",
    "cercheremmo": "cercare",
    "cercheremo": "cercare",
    "cerchereste": "cercare",
    "cercheresti": "cercare",
    "cercherete": "cercare",
    "cercherà": "cercare",
    "cercherò": "cercare",
    "cerchi": "cerchio",
    "cerchia": "cerchiare",
    "cerchiai": "cerchiare",
    "cerchiammo": "cerchiare",
    "cerchiamo": "cerchiare",
    "cerchian": "cerchiare",
    "cerchiando": "cerchiare",
    "cerchiano": "cerchiare",
    "cerchiante": "cerchiare",
    "cerchianti": "cerchiare",
    "cerchiar": "cerchiare",
    "cerchiaron": "cerchiare",
    "cerchiarono": "cerchiare",
    "cerchiasse": "cerchiare",
    "cerchiasser": "cerchiare",
    "cerchiassero": "cerchiare",
    "cerchiassi": "cerchiare",
    "cerchiassimo": "cerchiare",
    "cerchiaste": "cerchiare",
    "cerchiasti": "cerchiare",
    "cerchiata": "cerchiato",
    "cerchiate": "cerchiato",
    "cerchiati": "cerchiato",
    "cerchiato": "cerchiare",
    "cerchiava": "cerchiare",
    "cerchiavamo": "cerchiare",
    "cerchiavan": "cerchiare",
    "cerchiavano": "cerchiare",
    "cerchiavate": "cerchiare",
    "cerchiavi": "cerchiare",
    "cerchiavo": "cerchiare",
    "cerchie": "cerchia",
    "cerchierai": "cerchiare",
    "cerchieran": "cerchiare",
    "cerchieranno": "cerchiare",
    "cerchierebbe": "cerchiare",
    "cerchierebber": "cerchiare",
    "cerchierebbero": "cerchiare",
    "cerchierei": "cerchiare",
    "cerchieremmo": "cerchiare",
    "cerchieremo": "cerchiare",
    "cerchiereste": "cerchiare",
    "cerchieresti": "cerchiare",
    "cerchierete": "cerchiare",
    "cerchierà": "cerchiare",
    "cerchierò": "cerchiare",
    "cerchietti": "cerchietto",
    "cerchin": "cerchiare",
    "cerchino": "cerchiare",
    "cerchio": "cerchiare",
    "cerchioni": "cerchione",
    "cerchiò": "cerchiare",
    "cerco": "cercare",
    "cercò": "cercare",
    "cere": "cera",
    "cerea": "cereo",
    "cereali": "cereale",
    "cerealicola": "cerealicolo",
    "cerealicole": "cerealicolo",
    "cerealicoli": "cerealicolo",
    "cerebrali": "cerebrale",
    "cerebro-vascolari": "cerebro-vascolare",
    "ceree": "cereo",
    "cerei": "cereo",
    "cererai": "cerare",
    "cereran": "cerare",
    "cereranno": "cerare",
    "cererebbe": "cerare",
    "cererebber": "cerare",
    "cererebbero": "cerare",
    "cererei": "cerare",
    "cereremmo": "cerare",
    "cereremo": "cerare",
    "cerereste": "cerare",
    "cereresti": "cerare",
    "cererete": "cerare",
    "cererà": "cerare",
    "cererò": "cerare",
    "ceri": "cero",
    "ceriamo": "cerare",
    "ceriate": "cerare",
    "cerimoniali": "cerimoniale",
    "cerimonie": "cerimonia",
    "cerimonieri": "cerimoniere",
    "cerimoniosa": "cerimonioso",
    "cerimoniose": "cerimonioso",
    "cerimoniosi": "cerimonioso",
    "cerin": "cerare",
    "cerini": "cerino",
    "cerino": "cerare",
    "cerna": "cernere",
    "cernan": "cernere",
    "cernano": "cernere",
    "cerne": "cernere",
    "cernei": "cernere",
    "cernemmo": "cernere",
    "cernendo": "cernere",
    "cernente": "cernere",
    "cernenti": "cernere",
    "cerner": "cernere",
    "cernerai": "cernere",
    "cerneran": "cernere",
    "cerneranno": "cernere",
    "cernerebbe": "cernere",
    "cernerebber": "cernere",
    "cernerebbero": "cernere",
    "cernerei": "cernere",
    "cerneremmo": "cernere",
    "cerneremo": "cernere",
    "cernereste": "cernere",
    "cerneresti": "cernere",
    "cernerete": "cernere",
    "cerneron": "cernere",
    "cernerono": "cernere",
    "cernerà": "cernere",
    "cernerò": "cernere",
    "cernesse": "cernere",
    "cernesser": "cernere",
    "cernessero": "cernere",
    "cernessi": "cernere",
    "cernessimo": "cernere",
    "cerneste": "cernere",
    "cernesti": "cernere",
    "cernete": "cernere",
    "cerneva": "cernere",
    "cernevamo": "cernere",
    "cernevan": "cernere",
    "cernevano": "cernere",
    "cernevate": "cernere",
    "cernevi": "cernere",
    "cernevo": "cernere",
    "cerni": "cernere",
    "cerniamo": "cernere",
    "cerniate": "cernere",
    "cerniere": "cerniera",
    "cernite": "cernita",
    "cerno": "cernere",
    "cernon": "cernere",
    "cernono": "cernere",
    "cernè": "cernere",
    "cero": "cerare",
    "ceronettiana": "ceronettiano",
    "ceronettiane": "ceronettiano",
    "ceronettiani": "ceronettiano",
    "ceroni": "cerone",
    "cerotti": "cerotto",
    "certa": "certo",
    "certami": "certame",
    "certe": "certo",
    "certezze": "certezza",
    "certi": "certo",
    "certifica": "certificare",
    "certificabili": "certificabile",
    "certificai": "certificare",
    "certificammo": "certificare",
    "certifican": "certificare",
    "certificando": "certificare",
    "certificano": "certificare",
    "certificante": "certificare",
    "certificanti": "certificare",
    "certificar": "certificare",
    "certificaron": "certificare",
    "certificarono": "certificare",
    "certificasse": "certificare",
    "certificasser": "certificare",
    "certificassero": "certificare",
    "certificassi": "certificare",
    "certificassimo": "certificare",
    "certificaste": "certificare",
    "certificasti": "certificare",
    "certificata": "certificare",
    "certificate": "certificare",
    "certificati": "certificato",
    "certificato": "certificare",
    "certificatori": "certificatore",
    "certificava": "certificare",
    "certificavamo": "certificare",
    "certificavan": "certificare",
    "certificavano": "certificare",
    "certificavate": "certificare",
    "certificavi": "certificare",
    "certificavo": "certificare",
    "certificazioni": "certificazione",
    "certificherai": "certificare",
    "certificheran": "certificare",
    "certificheranno": "certificare",
    "certificherebbe": "certificare",
    "certificherebber": "certificare",
    "certificherebbero": "certificare",
    "certificherei": "certificare",
    "certificheremmo": "certificare",
    "certificheremo": "certificare",
    "certifichereste": "certificare",
    "certificheresti": "certificare",
    "certificherete": "certificare",
    "certificherà": "certificare",
    "certificherò": "certificare",
    "certifichi": "certificare",
    "certifichiamo": "certificare",
    "certifichiate": "certificare",
    "certifichin": "certificare",
    "certifichino": "certificare",
    "certifico": "certificare",
    "certificò": "certificare",
    "certosina": "certosino",
    "certosine": "certosino",
    "certosini": "certosino",
    "cerulea": "ceruleo",
    "cerulee": "ceruleo",
    "cerulei": "ceruleo",
    "cervella": "cervello",
    "cervelli": "cervello",
    "cervellini": "cervellino",
    "cervelloni": "cervellone",
    "cervellotica": "cervellotico",
    "cervellotiche": "cervellotico",
    "cervellotici": "cervellotico",
    "cervi": "cervo",
    "cervicali": "cervicale",
    "cervina": "cervino",
    "cervine": "cervino",
    "cervini": "cervino",
    "cerò": "cerare",
    "cesarea": "cesareo",
    "cesaree": "cesareo",
    "cesarei": "cesareo",
    "cesella": "cesellare",
    "cesellai": "cesellare",
    "cesellammo": "cesellare",
    "cesellan": "cesellare",
    "cesellando": "cesellare",
    "cesellano": "cesellare",
    "cesellante": "cesellare",
    "cesellanti": "cesellare",
    "cesellar": "cesellare",
    "cesellaron": "cesellare",
    "cesellarono": "cesellare",
    "cesellasse": "cesellare",
    "cesellasser": "cesellare",
    "cesellassero": "cesellare",
    "cesellassi": "cesellare",
    "cesellassimo": "cesellare",
    "cesellaste": "cesellare",
    "cesellasti": "cesellare",
    "cesellata": "cesellare",
    "cesellate": "cesellare",
    "cesellati": "cesellare",
    "cesellato": "cesellare",
    "cesellatori": "cesellatore",
    "cesellava": "cesellare",
    "cesellavamo": "cesellare",
    "cesellavan": "cesellare",
    "cesellavano": "cesellare",
    "cesellavate": "cesellare",
    "cesellavi": "cesellare",
    "cesellavo": "cesellare",
    "cesellerai": "cesellare",
    "ceselleran": "cesellare",
    "ceselleranno": "cesellare",
    "cesellerebbe": "cesellare",
    "cesellerebber": "cesellare",
    "cesellerebbero": "cesellare",
    "cesellerei": "cesellare",
    "ceselleremmo": "cesellare",
    "ceselleremo": "cesellare",
    "cesellereste": "cesellare",
    "ceselleresti": "cesellare",
    "cesellerete": "cesellare",
    "cesellerà": "cesellare",
    "cesellerò": "cesellare",
    "ceselli": "cesello",
    "ceselliamo": "cesellare",
    "ceselliate": "cesellare",
    "cesellin": "cesellare",
    "cesellino": "cesellare",
    "cesello": "cesellare",
    "cesellò": "cesellare",
    "cesenati": "cesenate",
    "cesi": "cesio",
    "cesoie": "cesoia",
    "cespi": "cespo",
    "cespiti": "cespite",
    "cespugli": "cespuglio",
    "cespugliosa": "cespuglioso",
    "cespugliose": "cespuglioso",
    "cespugliosi": "cespuglioso",
    "cessa": "cessare",
    "cessai": "cessare",
    "cessammo": "cessare",
    "cessan": "cessare",
    "cessando": "cessare",
    "cessano": "cessare",
    "cessante": "cessare",
    "cessanti": "cessare",
    "cessar": "cessare",
    "cessaron": "cessare",
    "cessarono": "cessare",
    "cessasse": "cessare",
    "cessasser": "cessare",
    "cessassero": "cessare",
    "cessassi": "cessare",
    "cessassimo": "cessare",
    "cessaste": "cessare",
    "cessasti": "cessare",
    "cessata": "cessare",
    "cessate": "cessare",
    "cessati": "cessare",
    "cessato": "cessare",
    "cessava": "cessare",
    "cessavamo": "cessare",
    "cessavan": "cessare",
    "cessavano": "cessare",
    "cessavate": "cessare",
    "cessavi": "cessare",
    "cessavo": "cessare",
    "cessazioni": "cessazione",
    "cesserai": "cessare",
    "cesseran": "cessare",
    "cesseranno": "cessare",
    "cesserebbe": "cessare",
    "cesserebber": "cessare",
    "cesserebbero": "cessare",
    "cesserei": "cessare",
    "cesseremmo": "cessare",
    "cesseremo": "cessare",
    "cessereste": "cessare",
    "cesseresti": "cessare",
    "cesserete": "cessare",
    "cesserà": "cessare",
    "cesserò": "cessare",
    "cessi": "cesso",
    "cessiamo": "cessare",
    "cessiate": "cessare",
    "cessin": "cessare",
    "cessino": "cessare",
    "cessioni": "cessione",
    "cesso": "cessare",
    "cessò": "cessare",
    "cesta": "cestire",
    "cestan": "cestire",
    "cestano": "cestire",
    "ceste": "cestire",
    "cestelli": "cestello",
    "cestendo": "cestire",
    "cestente": "cestire",
    "cestenti": "cestire",
    "cesti": "cesto",
    "cestiamo": "cestire",
    "cestiate": "cestire",
    "cestii": "cestire",
    "cestimmo": "cestire",
    "cestina": "cestinare",
    "cestinai": "cestinare",
    "cestinammo": "cestinare",
    "cestinan": "cestinare",
    "cestinando": "cestinare",
    "cestinano": "cestinare",
    "cestinante": "cestinare",
    "cestinanti": "cestinare",
    "cestinar": "cestinare",
    "cestinaron": "cestinare",
    "cestinarono": "cestinare",
    "cestinasse": "cestinare",
    "cestinasser": "cestinare",
    "cestinassero": "cestinare",
    "cestinassi": "cestinare",
    "cestinassimo": "cestinare",
    "cestinaste": "cestinare",
    "cestinasti": "cestinare",
    "cestinata": "cestinare",
    "cestinate": "cestinare",
    "cestinati": "cestinare",
    "cestinato": "cestinare",
    "cestinava": "cestinare",
    "cestinavamo": "cestinare",
    "cestinavan": "cestinare",
    "cestinavano": "cestinare",
    "cestinavate": "cestinare",
    "cestinavi": "cestinare",
    "cestinavo": "cestinare",
    "cestinerai": "cestinare",
    "cestineran": "cestinare",
    "cestineranno": "cestinare",
    "cestinerebbe": "cestinare",
    "cestinerebber": "cestinare",
    "cestinerebbero": "cestinare",
    "cestinerei": "cestinare",
    "cestineremmo": "cestinare",
    "cestineremo": "cestinare",
    "cestinereste": "cestinare",
    "cestineresti": "cestinare",
    "cestinerete": "cestinare",
    "cestinerà": "cestinare",
    "cestinerò": "cestinare",
    "cestini": "cestino",
    "cestiniamo": "cestinare",
    "cestiniate": "cestinare",
    "cestinin": "cestinare",
    "cestinino": "cestinare",
    "cestino": "cestinare",
    "cestinò": "cestinare",
    "cestir": "cestire",
    "cestirai": "cestire",
    "cestiran": "cestire",
    "cestiranno": "cestire",
    "cestirebbe": "cestire",
    "cestirebber": "cestire",
    "cestirebbero": "cestire",
    "cestirei": "cestire",
    "cestiremmo": "cestire",
    "cestiremo": "cestire",
    "cestireste": "cestire",
    "cestiresti": "cestire",
    "cestirete": "cestire",
    "cestiron": "cestire",
    "cestirono": "cestire",
    "cestirà": "cestire",
    "cestirò": "cestire",
    "cestisse": "cestire",
    "cestisser": "cestire",
    "cestissero": "cestire",
    "cestissi": "cestire",
    "cestissimo": "cestire",
    "cestiste": "cestire",
    "cestisti": "cestista",
    "cestistica": "cestistico",
    "cestistiche": "cestistico",
    "cestistici": "cestistico",
    "cestita": "cestire",
    "cestite": "cestire",
    "cestiti": "cestire",
    "cestito": "cestire",
    "cestiva": "cestire",
    "cestivamo": "cestire",
    "cestivan": "cestire",
    "cestivano": "cestire",
    "cestivate": "cestire",
    "cestivi": "cestire",
    "cestivo": "cestire",
    "cesto": "cestire",
    "ceston": "cestire",
    "cestono": "cestire",
    "cestì": "cestire",
    "cesure": "cesura",
    "cetacei": "cetaceo",
    "ceti": "ceto",
    "cetnici": "cetnico",
    "cetre": "cetra",
    "cetrioli": "cetriolo",
    "cgil-funzioni": "cgil-funzione",
    "chagalliana": "chagalliano",
    "chagalliane": "chagalliano",
    "chagalliani": "chagalliano",
    "chances": "chance",
    "chandleriana": "chandleriano",
    "chandleriane": "chandleriano",
    "chandleriani": "chandleriano",
    "charmes": "charme",
    "chassidica": "chassidico",
    "chassidiche": "chassidico",
    "chassidici": "chassidico",
    "chatta": "chattare",
    "chattai": "chattare",
    "chattammo": "chattare",
    "chattan": "chattare",
    "chattando": "chattare",
    "chattano": "chattare",
    "chattante": "chattare",
    "chattanti": "chattare",
    "chattar": "chattare",
    "chattaron": "chattare",
    "chattarono": "chattare",
    "chattasse": "chattare",
    "chattasser": "chattare",
    "chattassero": "chattare",
    "chattassi": "chattare",
    "chattassimo": "chattare",
    "chattaste": "chattare",
    "chattasti": "chattare",
    "chattata": "chattare",
    "chattate": "chattare",
    "chattati": "chattare",
    "chattato": "chattare",
    "chattava": "chattare",
    "chattavamo": "chattare",
    "chattavan": "chattare",
    "chattavano": "chattare",
    "chattavate": "chattare",
    "chattavi": "chattare",
    "chattavo": "chattare",
    "chatterai": "chattare",
    "chatteran": "chattare",
    "chatteranno": "chattare",
    "chatterebbe": "chattare",
    "chatterebber": "chattare",
    "chatterebbero": "chattare",
    "chatterei": "chattare",
    "chatteremmo": "chattare",
    "chatteremo": "chattare",
    "chattereste": "chattare",
    "chatteresti": "chattare",
    "chatterete": "chattare",
    "chatterà": "chattare",
    "chatterò": "chattare",
    "chatti": "chattare",
    "chattiamo": "chattare",
    "chattiate": "chattare",
    "chattin": "chattare",
    "chattino": "chattare",
    "chatto": "chattare",
    "chattò": "chattare",
    "chatwiniana": "chatwiniano",
    "chatwiniane": "chatwiniano",
    "chatwiniani": "chatwiniano",
    "checche": "checca",
    "chele": "chela",
    "chemioterapici": "chemioterapico",
    "chemioterapie": "chemioterapia",
    "cheratinizza": "cheratinizzare",
    "cheratinizzai": "cheratinizzare",
    "cheratinizzammo": "cheratinizzare",
    "cheratinizzan": "cheratinizzare",
    "cheratinizzando": "cheratinizzare",
    "cheratinizzano": "cheratinizzare",
    "cheratinizzante": "cheratinizzare",
    "cheratinizzanti": "cheratinizzare",
    "cheratinizzar": "cheratinizzare",
    "cheratinizzaron": "cheratinizzare",
    "cheratinizzarono": "cheratinizzare",
    "cheratinizzasse": "cheratinizzare",
    "cheratinizzasser": "cheratinizzare",
    "cheratinizzassero": "cheratinizzare",
    "cheratinizzassi": "cheratinizzare",
    "cheratinizzassimo": "cheratinizzare",
    "cheratinizzaste": "cheratinizzare",
    "cheratinizzasti": "cheratinizzare",
    "cheratinizzata": "cheratinizzare",
    "cheratinizzate": "cheratinizzare",
    "cheratinizzati": "cheratinizzare",
    "cheratinizzato": "cheratinizzare",
    "cheratinizzava": "cheratinizzare",
    "cheratinizzavamo": "cheratinizzare",
    "cheratinizzavan": "cheratinizzare",
    "cheratinizzavano": "cheratinizzare",
    "cheratinizzavate": "cheratinizzare",
    "cheratinizzavi": "cheratinizzare",
    "cheratinizzavo": "cheratinizzare",
    "cheratinizzerai": "cheratinizzare",
    "cheratinizzeran": "cheratinizzare",
    "cheratinizzeranno": "cheratinizzare",
    "cheratinizzerebbe": "cheratinizzare",
    "cheratinizzerebber": "cheratinizzare",
    "cheratinizzerebbero": "cheratinizzare",
    "cheratinizzerei": "cheratinizzare",
    "cheratinizzeremmo": "cheratinizzare",
    "cheratinizzeremo": "cheratinizzare",
    "cheratinizzereste": "cheratinizzare",
    "cheratinizzeresti": "cheratinizzare",
    "cheratinizzerete": "cheratinizzare",
    "cheratinizzerà": "cheratinizzare",
    "cheratinizzerò": "cheratinizzare",
    "cheratinizzi": "cheratinizzare",
    "cheratinizziamo": "cheratinizzare",
    "cheratinizziate": "cheratinizzare",
    "cheratinizzin": "cheratinizzare",
    "cheratinizzino": "cheratinizzare",
    "cheratinizzo": "cheratinizzare",
    "cheratinizzò": "cheratinizzare",
    "cherubini": "cherubino",
    "cheta": "cheto",
    "chetai": "chetare",
    "chetammo": "chetare",
    "chetan": "chetare",
    "chetando": "chetare",
    "chetano": "chetare",
    "chetante": "chetare",
    "chetanti": "chetare",
    "chetar": "chetare",
    "chetaron": "chetare",
    "chetarono": "chetare",
    "chetasse": "chetare",
    "chetasser": "chetare",
    "chetassero": "chetare",
    "chetassi": "chetare",
    "chetassimo": "chetare",
    "chetaste": "chetare",
    "chetasti": "chetare",
    "chetata": "chetare",
    "chetate": "chetare",
    "chetati": "chetare",
    "chetato": "chetare",
    "chetava": "chetare",
    "chetavamo": "chetare",
    "chetavan": "chetare",
    "chetavano": "chetare",
    "chetavate": "chetare",
    "chetavi": "chetare",
    "chetavo": "chetare",
    "chete": "cheto",
    "cheterai": "chetare",
    "cheteran": "chetare",
    "cheteranno": "chetare",
    "cheterebbe": "chetare",
    "cheterebber": "chetare",
    "cheterebbero": "chetare",
    "cheterei": "chetare",
    "cheteremmo": "chetare",
    "cheteremo": "chetare",
    "chetereste": "chetare",
    "cheteresti": "chetare",
    "cheterete": "chetare",
    "cheterà": "chetare",
    "cheterò": "chetare",
    "cheti": "cheto",
    "chetiamo": "chetare",
    "chetiate": "chetare",
    "chetin": "chetare",
    "chetino": "chetare",
    "cheto": "chetare",
    "chetò": "chetare",
    "chiacchere": "chiacchera",
    "chiacchiera": "chiacchierare",
    "chiacchierai": "chiacchierare",
    "chiacchierammo": "chiacchierare",
    "chiacchieran": "chiacchierare",
    "chiacchierando": "chiacchierare",
    "chiacchierano": "chiacchierare",
    "chiacchierante": "chiacchierare",
    "chiacchieranti": "chiacchierare",
    "chiacchierar": "chiacchierare",
    "chiacchieraron": "chiacchierare",
    "chiacchierarono": "chiacchierare",
    "chiacchierasse": "chiacchierare",
    "chiacchierasser": "chiacchierare",
    "chiacchierassero": "chiacchierare",
    "chiacchierassi": "chiacchierare",
    "chiacchierassimo": "chiacchierare",
    "chiacchieraste": "chiacchierare",
    "chiacchierasti": "chiacchierare",
    "chiacchierata": "chiacchierato",
    "chiacchierate": "chiacchierato",
    "chiacchierati": "chiacchierato",
    "chiacchierato": "chiacchierare",
    "chiacchierava": "chiacchierare",
    "chiacchieravamo": "chiacchierare",
    "chiacchieravan": "chiacchierare",
    "chiacchieravano": "chiacchierare",
    "chiacchieravate": "chiacchierare",
    "chiacchieravi": "chiacchierare",
    "chiacchieravo": "chiacchierare",
    "chiacchiere": "chiacchiera",
    "chiacchiererai": "chiacchierare",
    "chiacchiereran": "chiacchierare",
    "chiacchiereranno": "chiacchierare",
    "chiacchiererebbe": "chiacchierare",
    "chiacchiererebber": "chiacchierare",
    "chiacchiererebbero": "chiacchierare",
    "chiacchiererei": "chiacchierare",
    "chiacchiereremmo": "chiacchierare",
    "chiacchiereremo": "chiacchierare",
    "chiacchierereste": "chiacchierare",
    "chiacchiereresti": "chiacchierare",
    "chiacchiererete": "chiacchierare",
    "chiacchiererà": "chiacchierare",
    "chiacchiererò": "chiacchierare",
    "chiacchieri": "chiacchierare",
    "chiacchieriamo": "chiacchierare",
    "chiacchieriate": "chiacchierare",
    "chiacchiericci": "chiacchiericcio",
    "chiacchierin": "chiacchierare",
    "chiacchierino": "chiacchierare",
    "chiacchiero": "chiacchierare",
    "chiacchieroni": "chiacchierone",
    "chiacchierò": "chiacchierare",
    "chiama": "chiamare",
    "chiamai": "chiamare",
    "chiamammo": "chiamare",
    "chiaman": "chiamare",
    "chiamando": "chiamare",
    "chiamano": "chiamare",
    "chiamante": "chiamare",
    "chiamanti": "chiamare",
    "chiamar": "chiamare",
    "chiamaron": "chiamare",
    "chiamarono": "chiamare",
    "chiamasse": "chiamare",
    "chiamasser": "chiamare",
    "chiamassero": "chiamare",
    "chiamassi": "chiamare",
    "chiamassimo": "chiamare",
    "chiamaste": "chiamare",
    "chiamasti": "chiamare",
    "chiamata": "chiamare",
    "chiamate": "chiamata",
    "chiamati": "chiamare",
    "chiamato": "chiamare",
    "chiamava": "chiamare",
    "chiamavamo": "chiamare",
    "chiamavan": "chiamare",
    "chiamavano": "chiamare",
    "chiamavate": "chiamare",
    "chiamavi": "chiamare",
    "chiamavo": "chiamare",
    "chiamerai": "chiamare",
    "chiameran": "chiamare",
    "chiameranno": "chiamare",
    "chiamerebbe": "chiamare",
    "chiamerebber": "chiamare",
    "chiamerebbero": "chiamare",
    "chiamerei": "chiamare",
    "chiameremmo": "chiamare",
    "chiameremo": "chiamare",
    "chiamereste": "chiamare",
    "chiameresti": "chiamare",
    "chiamerete": "chiamare",
    "chiamerà": "chiamare",
    "chiamerò": "chiamare",
    "chiami": "chiamare",
    "chiamiamo": "chiamare",
    "chiamiate": "chiamare",
    "chiamin": "chiamare",
    "chiamino": "chiamare",
    "chiamo": "chiamare",
    "chiamò": "chiamare",
    "chiappa": "chiappare",
    "chiappai": "chiappare",
    "chiappammo": "chiappare",
    "chiappan": "chiappare",
    "chiappando": "chiappare",
    "chiappano": "chiappare",
    "chiappante": "chiappare",
    "chiappanti": "chiappare",
    "chiappar": "chiappare",
    "chiapparon": "chiappare",
    "chiapparono": "chiappare",
    "chiappasse": "chiappare",
    "chiappasser": "chiappare",
    "chiappassero": "chiappare",
    "chiappassi": "chiappare",
    "chiappassimo": "chiappare",
    "chiappaste": "chiappare",
    "chiappasti": "chiappare",
    "chiappata": "chiappare",
    "chiappate": "chiappare",
    "chiappati": "chiappare",
    "chiappato": "chiappare",
    "chiappava": "chiappare",
    "chiappavamo": "chiappare",
    "chiappavan": "chiappare",
    "chiappavano": "chiappare",
    "chiappavate": "chiappare",
    "chiappavi": "chiappare",
    "chiappavo": "chiappare",
    "chiappe": "chiappa",
    "chiapperai": "chiappare",
    "chiapperan": "chiappare",
    "chiapperanno": "chiappare",
    "chiapperebbe": "chiappare",
    "chiapperebber": "chiappare",
    "chiapperebbero": "chiappare",
    "chiapperei": "chiappare",
    "chiapperemmo": "chiappare",
    "chiapperemo": "chiappare",
    "chiappereste": "chiappare",
    "chiapperesti": "chiappare",
    "chiapperete": "chiappare",
    "chiapperà": "chiappare",
    "chiapperò": "chiappare",
    "chiappi": "chiappare",
    "chiappiamo": "chiappare",
    "chiappiate": "chiappare",
    "chiappin": "chiappare",
    "chiappino": "chiappare",
    "chiappo": "chiappare",
    "chiappò": "chiappare",
    "chiara": "chiaro",
    "chiare": "chiaro",
    "chiarendo": "chiarire",
    "chiarente": "chiarire",
    "chiarenti": "chiarire",
    "chiaretta": "chiaretto",
    "chiarette": "chiaretto",
    "chiaretti": "chiaretto",
    "chiari": "chiaro",
    "chiariamo": "chiarire",
    "chiariate": "chiarire",
    "chiarifica": "chiarificare",
    "chiarificai": "chiarificare",
    "chiarificammo": "chiarificare",
    "chiarifican": "chiarificare",
    "chiarificando": "chiarificare",
    "chiarificano": "chiarificare",
    "chiarificante": "chiarificare",
    "chiarificanti": "chiarificare",
    "chiarificar": "chiarificare",
    "chiarificaron": "chiarificare",
    "chiarificarono": "chiarificare",
    "chiarificasse": "chiarificare",
    "chiarificasser": "chiarificare",
    "chiarificassero": "chiarificare",
    "chiarificassi": "chiarificare",
    "chiarificassimo": "chiarificare",
    "chiarificaste": "chiarificare",
    "chiarificasti": "chiarificare",
    "chiarificata": "chiarificare",
    "chiarificate": "chiarificare",
    "chiarificati": "chiarificare",
    "chiarificato": "chiarificare",
    "chiarificatori": "chiarificatore",
    "chiarificatrice": "chiarificatore",
    "chiarificatrici": "chiarificatore",
    "chiarificava": "chiarificare",
    "chiarificavamo": "chiarificare",
    "chiarificavan": "chiarificare",
    "chiarificavano": "chiarificare",
    "chiarificavate": "chiarificare",
    "chiarificavi": "chiarificare",
    "chiarificavo": "chiarificare",
    "chiarificazioni": "chiarificazione",
    "chiarificherai": "chiarificare",
    "chiarificheran": "chiarificare",
    "chiarificheranno": "chiarificare",
    "chiarificherebbe": "chiarificare",
    "chiarificherebber": "chiarificare",
    "chiarificherebbero": "chiarificare",
    "chiarificherei": "chiarificare",
    "chiarificheremmo": "chiarificare",
    "chiarificheremo": "chiarificare",
    "chiarifichereste": "chiarificare",
    "chiarificheresti": "chiarificare",
    "chiarificherete": "chiarificare",
    "chiarificherà": "chiarificare",
    "chiarificherò": "chiarificare",
    "chiarifichi": "chiarificare",
    "chiarifichiamo": "chiarificare",
    "chiarifichiate": "chiarificare",
    "chiarifichin": "chiarificare",
    "chiarifichino": "chiarificare",
    "chiarifico": "chiarificare",
    "chiarificò": "chiarificare",
    "chiarii": "chiarire",
    "chiarimenti": "chiarimento",
    "chiarimmo": "chiarire",
    "chiarir": "chiarire",
    "chiarirai": "chiarire",
    "chiariran": "chiarire",
    "chiariranno": "chiarire",
    "chiarirebbe": "chiarire",
    "chiarirebber": "chiarire",
    "chiarirebbero": "chiarire",
    "chiarirei": "chiarire",
    "chiariremmo": "chiarire",
    "chiariremo": "chiarire",
    "chiarireste": "chiarire",
    "chiariresti": "chiarire",
    "chiarirete": "chiarire",
    "chiariron": "chiarire",
    "chiarirono": "chiarire",
    "chiarirà": "chiarire",
    "chiarirò": "chiarire",
    "chiarisca": "chiarire",
    "chiariscan": "chiarire",
    "chiariscano": "chiarire",
    "chiarisce": "chiarire",
    "chiarisci": "chiarire",
    "chiarisco": "chiarire",
    "chiariscon": "chiarire",
    "chiariscono": "chiarire",
    "chiarisse": "chiarire",
    "chiarisser": "chiarire",
    "chiarissero": "chiarire",
    "chiarissi": "chiarire",
    "chiarissimo": "chiarire",
    "chiariste": "chiarire",
    "chiaristi": "chiarire",
    "chiarita": "chiarire",
    "chiarite": "chiarire",
    "chiariti": "chiarire",
    "chiarito": "chiarire",
    "chiariva": "chiarire",
    "chiarivamo": "chiarire",
    "chiarivan": "chiarire",
    "chiarivano": "chiarire",
    "chiarivate": "chiarire",
    "chiarivi": "chiarire",
    "chiarivo": "chiarire",
    "chiarori": "chiarore",
    "chiaroscura": "chiaroscurare",
    "chiaroscurai": "chiaroscurare",
    "chiaroscurammo": "chiaroscurare",
    "chiaroscuran": "chiaroscurare",
    "chiaroscurando": "chiaroscurare",
    "chiaroscurano": "chiaroscurare",
    "chiaroscurante": "chiaroscurare",
    "chiaroscuranti": "chiaroscurare",
    "chiaroscurar": "chiaroscurare",
    "chiaroscuraron": "chiaroscurare",
    "chiaroscurarono": "chiaroscurare",
    "chiaroscurasse": "chiaroscurare",
    "chiaroscurasser": "chiaroscurare",
    "chiaroscurassero": "chiaroscurare",
    "chiaroscurassi": "chiaroscurare",
    "chiaroscurassimo": "chiaroscurare",
    "chiaroscuraste": "chiaroscurare",
    "chiaroscurasti": "chiaroscurare",
    "chiaroscurata": "chiaroscurare",
    "chiaroscurate": "chiaroscurare",
    "chiaroscurati": "chiaroscurare",
    "chiaroscurato": "chiaroscurare",
    "chiaroscurava": "chiaroscurare",
    "chiaroscuravamo": "chiaroscurare",
    "chiaroscuravan": "chiaroscurare",
    "chiaroscuravano": "chiaroscurare",
    "chiaroscuravate": "chiaroscurare",
    "chiaroscuravi": "chiaroscurare",
    "chiaroscuravo": "chiaroscurare",
    "chiaroscurerai": "chiaroscurare",
    "chiaroscureran": "chiaroscurare",
    "chiaroscureranno": "chiaroscurare",
    "chiaroscurerebbe": "chiaroscurare",
    "chiaroscurerebber": "chiaroscurare",
    "chiaroscurerebbero": "chiaroscurare",
    "chiaroscurerei": "chiaroscurare",
    "chiaroscureremmo": "chiaroscurare",
    "chiaroscureremo": "chiaroscurare",
    "chiaroscurereste": "chiaroscurare",
    "chiaroscureresti": "chiaroscurare",
    "chiaroscurerete": "chiaroscurare",
    "chiaroscurerà": "chiaroscurare",
    "chiaroscurerò": "chiaroscurare",
    "chiaroscuri": "chiaroscurare",
    "chiaroscuriamo": "chiaroscurare",
    "chiaroscuriate": "chiaroscurare",
    "chiaroscurin": "chiaroscurare",
    "chiaroscurino": "chiaroscurare",
    "chiaroscuro": "chiaroscurare",
    "chiaroscurò": "chiaroscurare",
    "chiaroveggenze": "chiaroveggenza",
    "chiarì": "chiarire",
    "chiassi": "chiasso",
    "chiassoni": "chiassone",
    "chiassosa": "chiassoso",
    "chiassose": "chiassoso",
    "chiassosi": "chiassoso",
    "chiatte": "chiatta",
    "chiava": "chiavare",
    "chiavai": "chiavare",
    "chiavammo": "chiavare",
    "chiavan": "chiavare",
    "chiavando": "chiavare",
    "chiavano": "chiavare",
    "chiavante": "chiavare",
    "chiavanti": "chiavare",
    "chiavar": "chiavare",
    "chiavaron": "chiavare",
    "chiavarono": "chiavare",
    "chiavasse": "chiavare",
    "chiavasser": "chiavare",
    "chiavassero": "chiavare",
    "chiavassi": "chiavare",
    "chiavassimo": "chiavare",
    "chiavaste": "chiavare",
    "chiavasti": "chiavare",
    "chiavata": "chiavare",
    "chiavate": "chiavare",
    "chiavati": "chiavare",
    "chiavato": "chiavare",
    "chiavava": "chiavare",
    "chiavavamo": "chiavare",
    "chiavavan": "chiavare",
    "chiavavano": "chiavare",
    "chiavavate": "chiavare",
    "chiavavi": "chiavare",
    "chiavavo": "chiavare",
    "chiaverai": "chiavare",
    "chiaveran": "chiavare",
    "chiaveranno": "chiavare",
    "chiaverebbe": "chiavare",
    "chiaverebber": "chiavare",
    "chiaverebbero": "chiavare",
    "chiaverei": "chiavare",
    "chiaveremmo": "chiavare",
    "chiaveremo": "chiavare",
    "chiavereste": "chiavare",
    "chiaveresti": "chiavare",
    "chiaverete": "chiavare",
    "chiaverà": "chiavare",
    "chiaverò": "chiavare",
    "chiavi": "chiave",
    "chiaviamo": "chiavare",
    "chiaviate": "chiavare",
    "chiavin": "chiavare",
    "chiavino": "chiavare",
    "chiavistelli": "chiavistello",
    "chiavo": "chiavare",
    "chiavò": "chiavare",
    "chiazza": "chiazzare",
    "chiazzai": "chiazzare",
    "chiazzammo": "chiazzare",
    "chiazzan": "chiazzare",
    "chiazzando": "chiazzare",
    "chiazzano": "chiazzare",
    "chiazzante": "chiazzare",
    "chiazzanti": "chiazzare",
    "chiazzar": "chiazzare",
    "chiazzaron": "chiazzare",
    "chiazzarono": "chiazzare",
    "chiazzasse": "chiazzare",
    "chiazzasser": "chiazzare",
    "chiazzassero": "chiazzare",
    "chiazzassi": "chiazzare",
    "chiazzassimo": "chiazzare",
    "chiazzaste": "chiazzare",
    "chiazzasti": "chiazzare",
    "chiazzata": "chiazzare",
    "chiazzate": "chiazzare",
    "chiazzati": "chiazzare",
    "chiazzato": "chiazzare",
    "chiazzava": "chiazzare",
    "chiazzavamo": "chiazzare",
    "chiazzavan": "chiazzare",
    "chiazzavano": "chiazzare",
    "chiazzavate": "chiazzare",
    "chiazzavi": "chiazzare",
    "chiazzavo": "chiazzare",
    "chiazze": "chiazza",
    "chiazzerai": "chiazzare",
    "chiazzeran": "chiazzare",
    "chiazzeranno": "chiazzare",
    "chiazzerebbe": "chiazzare",
    "chiazzerebber": "chiazzare",
    "chiazzerebbero": "chiazzare",
    "chiazzerei": "chiazzare",
    "chiazzeremmo": "chiazzare",
    "chiazzeremo": "chiazzare",
    "chiazzereste": "chiazzare",
    "chiazzeresti": "chiazzare",
    "chiazzerete": "chiazzare",
    "chiazzerà": "chiazzare",
    "chiazzerò": "chiazzare",
    "chiazzi": "chiazzare",
    "chiazziamo": "chiazzare",
    "chiazziate": "chiazzare",
    "chiazzin": "chiazzare",
    "chiazzino": "chiazzare",
    "chiazzo": "chiazzare",
    "chiazzò": "chiazzare",
    "chicche": "chicca",
    "chicchi": "chicco",
    "chieda": "chiedere",
    "chiedan": "chiedere",
    "chiedano": "chiedere",
    "chiede": "chiedere",
    "chiedemmo": "chiedere",
    "chiedendo": "chiedere",
    "chiedente": "chiedere",
    "chiedenti": "chiedere",
    "chieder": "chiedere",
    "chiederai": "chiedere",
    "chiederan": "chiedere",
    "chiederanno": "chiedere",
    "chiederebbe": "chiedere",
    "chiederebber": "chiedere",
    "chiederebbero": "chiedere",
    "chiederei": "chiedere",
    "chiederemmo": "chiedere",
    "chiederemo": "chiedere",
    "chiedereste": "chiedere",
    "chiederesti": "chiedere",
    "chiederete": "chiedere",
    "chiederà": "chiedere",
    "chiederò": "chiedere",
    "chiedesse": "chiedere",
    "chiedesser": "chiedere",
    "chiedessero": "chiedere",
    "chiedessi": "chiedere",
    "chiedessimo": "chiedere",
    "chiedeste": "chiedere",
    "chiedesti": "chiedere",
    "chiedete": "chiedere",
    "chiedeva": "chiedere",
    "chiedevamo": "chiedere",
    "chiedevan": "chiedere",
    "chiedevano": "chiedere",
    "chiedevate": "chiedere",
    "chiedevi": "chiedere",
    "chiedevo": "chiedere",
    "chiedi": "chiedere",
    "chiediamo": "chiedere",
    "chiediate": "chiedere",
    "chiedo": "chiedere",
    "chiedon": "chiedere",
    "chiedono": "chiedere",
    "chierichetti": "chierichetto",
    "chierici": "chierico",
    "chiesastica": "chiesastico",
    "chiesastiche": "chiesastico",
    "chiesastici": "chiesastico",
    "chiese": "chiesa",
    "chieser": "chiedere",
    "chiesero": "chiedere",
    "chiesette": "chiesetta",
    "chiesi": "chiedere",
    "chiesta": "chiesto",
    "chieste": "chiesto",
    "chiesti": "chiesto",
    "chiesto": "chiedere",
    "chiglie": "chiglia",
    "chili": "chilo",
    "chilometraggi": "chilometraggio",
    "chilometri": "chilometro",
    "chilometrica": "chilometrico",
    "chilometriche": "chilometrico",
    "chilometrici": "chilometrico",
    "chimere": "chimera",
    "chimerica": "chimerico",
    "chimeriche": "chimerico",
    "chimerici": "chimerico",
    "chimica": "chimico",
    "chimiche": "chimico",
    "chimici": "chimico",
    "chimico-batteriologica": "chimico-batteriologico",
    "chimico-batteriologiche": "chimico-batteriologico",
    "chimico-batteriologici": "chimico-batteriologico",
    "chimico-farmaceutica": "chimico-farmaceutico",
    "chimico-farmaceutiche": "chimico-farmaceutico",
    "chimico-farmaceutici": "chimico-farmaceutico",
    "chimico-fisica": "chimico-fisico",
    "chimico-fisiche": "chimico-fisico",
    "chimico-fisici": "chimico-fisico",
    "china": "chino",
    "chinai": "chinare",
    "chinammo": "chinare",
    "chinan": "chinare",
    "chinando": "chinare",
    "chinano": "chinare",
    "chinante": "chinare",
    "chinanti": "chinare",
    "chinar": "chinare",
    "chinaron": "chinare",
    "chinarono": "chinare",
    "chinasse": "chinare",
    "chinasser": "chinare",
    "chinassero": "chinare",
    "chinassi": "chinare",
    "chinassimo": "chinare",
    "chinaste": "chinare",
    "chinasti": "chinare",
    "chinata": "chinare",
    "chinate": "chinare",
    "chinati": "chinare",
    "chinato": "chinare",
    "chinava": "chinare",
    "chinavamo": "chinare",
    "chinavan": "chinare",
    "chinavano": "chinare",
    "chinavate": "chinare",
    "chinavi": "chinare",
    "chinavo": "chinare",
    "chincaglierie": "chincaglieria",
    "chine": "chino",
    "chinerai": "chinare",
    "chineran": "chinare",
    "chineranno": "chinare",
    "chinerebbe": "chinare",
    "chinerebber": "chinare",
    "chinerebbero": "chinare",
    "chinerei": "chinare",
    "chineremmo": "chinare",
    "chineremo": "chinare",
    "chinereste": "chinare",
    "chineresti": "chinare",
    "chinerete": "chinare",
    "chinerà": "chinare",
    "chinerò": "chinare",
    "chini": "chino",
    "chiniamo": "chinare",
    "chiniate": "chinare",
    "chinin": "chinare",
    "chinino": "chinare",
    "chino": "chinare",
    "chinò": "chinare",
    "chiocce": "chioccio",
    "chioccerai": "chiocciare",
    "chiocceran": "chiocciare",
    "chiocceranno": "chiocciare",
    "chioccerebbe": "chiocciare",
    "chioccerebber": "chiocciare",
    "chioccerebbero": "chiocciare",
    "chioccerei": "chiocciare",
    "chiocceremmo": "chiocciare",
    "chiocceremo": "chiocciare",
    "chioccereste": "chiocciare",
    "chiocceresti": "chiocciare",
    "chioccerete": "chiocciare",
    "chioccerà": "chiocciare",
    "chioccerò": "chiocciare",
    "chiocci": "chioccio",
    "chioccia": "chioccio",
    "chiocciai": "chiocciare",
    "chiocciammo": "chiocciare",
    "chiocciamo": "chiocciare",
    "chioccian": "chiocciare",
    "chiocciando": "chiocciare",
    "chiocciano": "chiocciare",
    "chiocciante": "chiocciare",
    "chioccianti": "chiocciare",
    "chiocciar": "chiocciare",
    "chiocciaron": "chiocciare",
    "chiocciarono": "chiocciare",
    "chiocciasse": "chiocciare",
    "chiocciasser": "chiocciare",
    "chiocciassero": "chiocciare",
    "chiocciassi": "chiocciare",
    "chiocciassimo": "chiocciare",
    "chiocciaste": "chiocciare",
    "chiocciasti": "chiocciare",
    "chiocciata": "chiocciare",
    "chiocciate": "chiocciare",
    "chiocciati": "chiocciare",
    "chiocciato": "chiocciare",
    "chiocciava": "chiocciare",
    "chiocciavamo": "chiocciare",
    "chiocciavan": "chiocciare",
    "chiocciavano": "chiocciare",
    "chiocciavate": "chiocciare",
    "chiocciavi": "chiocciare",
    "chiocciavo": "chiocciare",
    "chioccin": "chiocciare",
    "chioccino": "chiocciare",
    "chioccio": "chiocciare",
    "chiocciole": "chiocciola",
    "chiocciò": "chiocciare",
    "chioccola": "chioccolare",
    "chioccolai": "chioccolare",
    "chioccolammo": "chioccolare",
    "chioccolan": "chioccolare",
    "chioccolando": "chioccolare",
    "chioccolano": "chioccolare",
    "chioccolante": "chioccolare",
    "chioccolanti": "chioccolare",
    "chioccolar": "chioccolare",
    "chioccolaron": "chioccolare",
    "chioccolarono": "chioccolare",
    "chioccolasse": "chioccolare",
    "chioccolasser": "chioccolare",
    "chioccolassero": "chioccolare",
    "chioccolassi": "chioccolare",
    "chioccolassimo": "chioccolare",
    "chioccolaste": "chioccolare",
    "chioccolasti": "chioccolare",
    "chioccolata": "chioccolare",
    "chioccolate": "chioccolare",
    "chioccolati": "chioccolare",
    "chioccolato": "chioccolare",
    "chioccolava": "chioccolare",
    "chioccolavamo": "chioccolare",
    "chioccolavan": "chioccolare",
    "chioccolavano": "chioccolare",
    "chioccolavate": "chioccolare",
    "chioccolavi": "chioccolare",
    "chioccolavo": "chioccolare",
    "chioccolerai": "chioccolare",
    "chioccoleran": "chioccolare",
    "chioccoleranno": "chioccolare",
    "chioccolerebbe": "chioccolare",
    "chioccolerebber": "chioccolare",
    "chioccolerebbero": "chioccolare",
    "chioccolerei": "chioccolare",
    "chioccoleremmo": "chioccolare",
    "chioccoleremo": "chioccolare",
    "chioccolereste": "chioccolare",
    "chioccoleresti": "chioccolare",
    "chioccolerete": "chioccolare",
    "chioccolerà": "chioccolare",
    "chioccolerò": "chioccolare",
    "chioccoli": "chioccolare",
    "chioccoliamo": "chioccolare",
    "chioccoliate": "chioccolare",
    "chioccolin": "chioccolare",
    "chioccolino": "chioccolare",
    "chioccolo": "chioccolare",
    "chioccolò": "chioccolare",
    "chioda": "chiodare",
    "chiodai": "chiodare",
    "chiodammo": "chiodare",
    "chiodan": "chiodare",
    "chiodando": "chiodare",
    "chiodano": "chiodare",
    "chiodante": "chiodare",
    "chiodanti": "chiodare",
    "chiodar": "chiodare",
    "chiodaron": "chiodare",
    "chiodarono": "chiodare",
    "chiodasse": "chiodare",
    "chiodasser": "chiodare",
    "chiodassero": "chiodare",
    "chiodassi": "chiodare",
    "chiodassimo": "chiodare",
    "chiodaste": "chiodare",
    "chiodasti": "chiodare",
    "chiodata": "chiodato",
    "chiodate": "chiodato",
    "chiodati": "chiodato",
    "chiodato": "chiodare",
    "chiodava": "chiodare",
    "chiodavamo": "chiodare",
    "chiodavan": "chiodare",
    "chiodavano": "chiodare",
    "chiodavate": "chiodare",
    "chiodavi": "chiodare",
    "chiodavo": "chiodare",
    "chioderai": "chiodare",
    "chioderan": "chiodare",
    "chioderanno": "chiodare",
    "chioderebbe": "chiodare",
    "chioderebber": "chiodare",
    "chioderebbero": "chiodare",
    "chioderei": "chiodare",
    "chioderemmo": "chiodare",
    "chioderemo": "chiodare",
    "chiodereste": "chiodare",
    "chioderesti": "chiodare",
    "chioderete": "chiodare",
    "chioderà": "chiodare",
    "chioderò": "chiodare",
    "chiodi": "chiodo",
    "chiodiamo": "chiodare",
    "chiodiate": "chiodare",
    "chiodin": "chiodare",
    "chiodino": "chiodare",
    "chiodo": "chiodare",
    "chiodò": "chiodare",
    "chiome": "chioma",
    "chiosa": "chiosare",
    "chiosai": "chiosare",
    "chiosammo": "chiosare",
    "chiosan": "chiosare",
    "chiosando": "chiosare",
    "chiosano": "chiosare",
    "chiosante": "chiosare",
    "chiosanti": "chiosare",
    "chiosar": "chiosare",
    "chiosaron": "chiosare",
    "chiosarono": "chiosare",
    "chiosasse": "chiosare",
    "chiosasser": "chiosare",
    "chiosassero": "chiosare",
    "chiosassi": "chiosare",
    "chiosassimo": "chiosare",
    "chiosaste": "chiosare",
    "chiosasti": "chiosare",
    "chiosata": "chiosare",
    "chiosate": "chiosare",
    "chiosati": "chiosare",
    "chiosato": "chiosare",
    "chiosava": "chiosare",
    "chiosavamo": "chiosare",
    "chiosavan": "chiosare",
    "chiosavano": "chiosare",
    "chiosavate": "chiosare",
    "chiosavi": "chiosare",
    "chiosavo": "chiosare",
    "chioschetti": "chioschetto",
    "chioschi": "chiosco",
    "chioserai": "chiosare",
    "chioseran": "chiosare",
    "chioseranno": "chiosare",
    "chioserebbe": "chiosare",
    "chioserebber": "chiosare",
    "chioserebbero": "chiosare",
    "chioserei": "chiosare",
    "chioseremmo": "chiosare",
    "chioseremo": "chiosare",
    "chiosereste": "chiosare",
    "chioseresti": "chiosare",
    "chioserete": "chiosare",
    "chioserà": "chiosare",
    "chioserò": "chiosare",
    "chiosi": "chiosare",
    "chiosiamo": "chiosare",
    "chiosiate": "chiosare",
    "chiosin": "chiosare",
    "chiosino": "chiosare",
    "chioso": "chiosare",
    "chiostri": "chiostro",
    "chiosò": "chiosare",
    "chiotta": "chiotto",
    "chiotte": "chiotto",
    "chiotti": "chiotto",
    "chirografari": "chirografario",
    "chirografaria": "chirografario",
    "chirografarie": "chirografario",
    "chiromanti": "chiromante",
    "chirurghi": "chirurgo",
    "chirurgi": "chirurgo",
    "chirurgica": "chirurgico",
    "chirurgiche": "chirurgico",
    "chirurgici": "chirurgico",
    "chirurgie": "chirurgia",
    "chitarre": "chitarra",
    "chitarristi": "chitarrista",
    "chitarristica": "chitarristico",
    "chitarristiche": "chitarristico",
    "chitarristici": "chitarristico",
    "chiuda": "chiudere",
    "chiudan": "chiudere",
    "chiudano": "chiudere",
    "chiude": "chiudere",
    "chiudemmo": "chiudere",
    "chiudendo": "chiudere",
    "chiudente": "chiudere",
    "chiudenti": "chiudere",
    "chiuder": "chiudere",
    "chiuderai": "chiudere",
    "chiuderan": "chiudere",
    "chiuderanno": "chiudere",
    "chiuderebbe": "chiudere",
    "chiuderebber": "chiudere",
    "chiuderebbero": "chiudere",
    "chiuderei": "chiudere",
    "chiuderemmo": "chiudere",
    "chiuderemo": "chiudere",
    "chiudereste": "chiudere",
    "chiuderesti": "chiudere",
    "chiuderete": "chiudere",
    "chiuderà": "chiudere",
    "chiuderò": "chiudere",
    "chiudesse": "chiudere",
    "chiudesser": "chiudere",
    "chiudessero": "chiudere",
    "chiudessi": "chiudere",
    "chiudessimo": "chiudere",
    "chiudeste": "chiudere",
    "chiudesti": "chiudere",
    "chiudete": "chiudere",
    "chiudeva": "chiudere",
    "chiudevamo": "chiudere",
    "chiudevan": "chiudere",
    "chiudevano": "chiudere",
    "chiudevate": "chiudere",
    "chiudevi": "chiudere",
    "chiudevo": "chiudere",
    "chiudi": "chiudere",
    "chiudiamo": "chiudere",
    "chiudiate": "chiudere",
    "chiudo": "chiudere",
    "chiudon": "chiudere",
    "chiudono": "chiudere",
    "chiusa": "chiuso",
    "chiuse": "chiuso",
    "chiuser": "chiudere",
    "chiusero": "chiudere",
    "chiusi": "chiuso",
    "chiuso": "chiudere",
    "chiusure": "chiusura",
    "chocca": "choccare",
    "choccai": "choccare",
    "choccammo": "choccare",
    "choccan": "choccare",
    "choccando": "choccare",
    "choccano": "choccare",
    "choccante": "choccare",
    "choccanti": "choccare",
    "choccar": "choccare",
    "choccaron": "choccare",
    "choccarono": "choccare",
    "choccasse": "choccare",
    "choccasser": "choccare",
    "choccassero": "choccare",
    "choccassi": "choccare",
    "choccassimo": "choccare",
    "choccaste": "choccare",
    "choccasti": "choccare",
    "choccata": "choccare",
    "choccate": "choccare",
    "choccati": "choccare",
    "choccato": "choccare",
    "choccava": "choccare",
    "choccavamo": "choccare",
    "choccavan": "choccare",
    "choccavano": "choccare",
    "choccavate": "choccare",
    "choccavi": "choccare",
    "choccavo": "choccare",
    "choccherai": "choccare",
    "choccheran": "choccare",
    "choccheranno": "choccare",
    "choccherebbe": "choccare",
    "choccherebber": "choccare",
    "choccherebbero": "choccare",
    "choccherei": "choccare",
    "choccheremmo": "choccare",
    "choccheremo": "choccare",
    "chocchereste": "choccare",
    "choccheresti": "choccare",
    "choccherete": "choccare",
    "choccherà": "choccare",
    "choccherò": "choccare",
    "chocchi": "choccare",
    "chocchiamo": "choccare",
    "chocchiate": "choccare",
    "chocchin": "choccare",
    "chocchino": "choccare",
    "chocco": "choccare",
    "choccò": "choccare",
    "chopiniana": "chopiniano",
    "chopiniane": "chopiniano",
    "chopiniani": "chopiniano",
    "ciabatta": "ciabattare",
    "ciabattai": "ciabattare",
    "ciabattammo": "ciabattare",
    "ciabattan": "ciabattare",
    "ciabattando": "ciabattare",
    "ciabattano": "ciabattare",
    "ciabattante": "ciabattare",
    "ciabattanti": "ciabattare",
    "ciabattar": "ciabattare",
    "ciabattaron": "ciabattare",
    "ciabattarono": "ciabattare",
    "ciabattasse": "ciabattare",
    "ciabattasser": "ciabattare",
    "ciabattassero": "ciabattare",
    "ciabattassi": "ciabattare",
    "ciabattassimo": "ciabattare",
    "ciabattaste": "ciabattare",
    "ciabattasti": "ciabattare",
    "ciabattata": "ciabattare",
    "ciabattate": "ciabattare",
    "ciabattati": "ciabattare",
    "ciabattato": "ciabattare",
    "ciabattava": "ciabattare",
    "ciabattavamo": "ciabattare",
    "ciabattavan": "ciabattare",
    "ciabattavano": "ciabattare",
    "ciabattavate": "ciabattare",
    "ciabattavi": "ciabattare",
    "ciabattavo": "ciabattare",
    "ciabatte": "ciabatta",
    "ciabatterai": "ciabattare",
    "ciabatteran": "ciabattare",
    "ciabatteranno": "ciabattare",
    "ciabatterebbe": "ciabattare",
    "ciabatterebber": "ciabattare",
    "ciabatterebbero": "ciabattare",
    "ciabatterei": "ciabattare",
    "ciabatteremmo": "ciabattare",
    "ciabatteremo": "ciabattare",
    "ciabattereste": "ciabattare",
    "ciabatteresti": "ciabattare",
    "ciabatterete": "ciabattare",
    "ciabatterà": "ciabattare",
    "ciabatterò": "ciabattare",
    "ciabatti": "ciabattare",
    "ciabattiamo": "ciabattare",
    "ciabattiate": "ciabattare",
    "ciabattin": "ciabattare",
    "ciabattini": "ciabattino",
    "ciabattino": "ciabattare",
    "ciabatto": "ciabattare",
    "ciabattò": "ciabattare",
    "ciadiana": "ciadiano",
    "ciadiane": "ciadiano",
    "ciadiani": "ciadiano",
    "ciaikovskiana": "ciaikovskiano",
    "ciaikovskiane": "ciaikovskiano",
    "ciaikovskiani": "ciaikovskiano",
    "ciaikowskijana": "ciaikowskijano",
    "ciaikowskijane": "ciaikowskijano",
    "ciaikowskijani": "ciaikowskijano",
    "ciajkowskiana": "ciajkowskiano",
    "ciajkowskiane": "ciajkowskiano",
    "ciajkowskiani": "ciajkowskiano",
    "cialtronerie": "cialtroneria",
    "cialtronesca": "cialtronesco",
    "cialtronesche": "cialtronesco",
    "cialtroneschi": "cialtronesco",
    "cialtroni": "cialtrone",
    "ciambellani": "ciambellano",
    "ciambelle": "ciambella",
    "ciampica": "ciampicare",
    "ciampicai": "ciampicare",
    "ciampicammo": "ciampicare",
    "ciampican": "ciampicare",
    "ciampicando": "ciampicare",
    "ciampicano": "ciampicare",
    "ciampicante": "ciampicare",
    "ciampicanti": "ciampicare",
    "ciampicar": "ciampicare",
    "ciampicaron": "ciampicare",
    "ciampicarono": "ciampicare",
    "ciampicasse": "ciampicare",
    "ciampicasser": "ciampicare",
    "ciampicassero": "ciampicare",
    "ciampicassi": "ciampicare",
    "ciampicassimo": "ciampicare",
    "ciampicaste": "ciampicare",
    "ciampicasti": "ciampicare",
    "ciampicata": "ciampicare",
    "ciampicate": "ciampicare",
    "ciampicati": "ciampicare",
    "ciampicato": "ciampicare",
    "ciampicava": "ciampicare",
    "ciampicavamo": "ciampicare",
    "ciampicavan": "ciampicare",
    "ciampicavano": "ciampicare",
    "ciampicavate": "ciampicare",
    "ciampicavi": "ciampicare",
    "ciampicavo": "ciampicare",
    "ciampicherai": "ciampicare",
    "ciampicheran": "ciampicare",
    "ciampicheranno": "ciampicare",
    "ciampicherebbe": "ciampicare",
    "ciampicherebber": "ciampicare",
    "ciampicherebbero": "ciampicare",
    "ciampicherei": "ciampicare",
    "ciampicheremmo": "ciampicare",
    "ciampicheremo": "ciampicare",
    "ciampichereste": "ciampicare",
    "ciampicheresti": "ciampicare",
    "ciampicherete": "ciampicare",
    "ciampicherà": "ciampicare",
    "ciampicherò": "ciampicare",
    "ciampichi": "ciampicare",
    "ciampichiamo": "ciampicare",
    "ciampichiate": "ciampicare",
    "ciampichin": "ciampicare",
    "ciampichino": "ciampicare",
    "ciampico": "ciampicare",
    "ciampicò": "ciampicare",
    "ciancerai": "cianciare",
    "cianceran": "cianciare",
    "cianceranno": "cianciare",
    "ciancerebbe": "cianciare",
    "ciancerebber": "cianciare",
    "ciancerebbero": "cianciare",
    "ciancerei": "cianciare",
    "cianceremmo": "cianciare",
    "cianceremo": "cianciare",
    "ciancereste": "cianciare",
    "cianceresti": "cianciare",
    "ciancerete": "cianciare",
    "ciancerà": "cianciare",
    "ciancerò": "cianciare",
    "cianci": "cianciare",
    "ciancia": "cianciare",
    "cianciai": "cianciare",
    "cianciammo": "cianciare",
    "cianciamo": "cianciare",
    "ciancian": "cianciare",
    "cianciando": "cianciare",
    "cianciano": "cianciare",
    "cianciante": "cianciare",
    "ciancianti": "cianciare",
    "cianciar": "cianciare",
    "cianciaron": "cianciare",
    "cianciarono": "cianciare",
    "cianciasse": "cianciare",
    "cianciasser": "cianciare",
    "cianciassero": "cianciare",
    "cianciassi": "cianciare",
    "cianciassimo": "cianciare",
    "cianciaste": "cianciare",
    "cianciasti": "cianciare",
    "cianciata": "cianciare",
    "cianciate": "cianciare",
    "cianciati": "cianciare",
    "cianciato": "cianciare",
    "cianciava": "cianciare",
    "cianciavamo": "cianciare",
    "cianciavan": "cianciare",
    "cianciavano": "cianciare",
    "cianciavate": "cianciare",
    "cianciavi": "cianciare",
    "cianciavo": "cianciare",
    "ciancica": "ciancicare",
    "ciancicai": "ciancicare",
    "ciancicammo": "ciancicare",
    "ciancican": "ciancicare",
    "ciancicando": "ciancicare",
    "ciancicano": "ciancicare",
    "ciancicante": "ciancicare",
    "ciancicanti": "ciancicare",
    "ciancicar": "ciancicare",
    "ciancicaron": "ciancicare",
    "ciancicarono": "ciancicare",
    "ciancicasse": "ciancicare",
    "ciancicasser": "ciancicare",
    "ciancicassero": "ciancicare",
    "ciancicassi": "ciancicare",
    "ciancicassimo": "ciancicare",
    "ciancicaste": "ciancicare",
    "ciancicasti": "ciancicare",
    "ciancicata": "ciancicare",
    "ciancicate": "ciancicare",
    "ciancicati": "ciancicare",
    "ciancicato": "ciancicare",
    "ciancicava": "ciancicare",
    "ciancicavamo": "ciancicare",
    "ciancicavan": "ciancicare",
    "ciancicavano": "ciancicare",
    "ciancicavate": "ciancicare",
    "ciancicavi": "ciancicare",
    "ciancicavo": "ciancicare",
    "ciancicherai": "ciancicare",
    "ciancicheran": "ciancicare",
    "ciancicheranno": "ciancicare",
    "ciancicherebbe": "ciancicare",
    "ciancicherebber": "ciancicare",
    "ciancicherebbero": "ciancicare",
    "ciancicherei": "ciancicare",
    "ciancicheremmo": "ciancicare",
    "ciancicheremo": "ciancicare",
    "ciancichereste": "ciancicare",
    "ciancicheresti": "ciancicare",
    "ciancicherete": "ciancicare",
    "ciancicherà": "ciancicare",
    "ciancicherò": "ciancicare",
    "ciancichi": "ciancicare",
    "ciancichiamo": "ciancicare",
    "ciancichiate": "ciancicare",
    "ciancichin": "ciancicare",
    "ciancichino": "ciancicare",
    "ciancico": "ciancicare",
    "ciancicò": "ciancicare",
    "ciancin": "cianciare",
    "ciancino": "cianciare",
    "ciancio": "cianciare",
    "cianciò": "cianciare",
    "cianfrugli": "cianfrugliare",
    "cianfruglia": "cianfrugliare",
    "cianfrugliai": "cianfrugliare",
    "cianfrugliammo": "cianfrugliare",
    "cianfrugliamo": "cianfrugliare",
    "cianfruglian": "cianfrugliare",
    "cianfrugliando": "cianfrugliare",
    "cianfrugliano": "cianfrugliare",
    "cianfrugliante": "cianfrugliare",
    "cianfruglianti": "cianfrugliare",
    "cianfrugliar": "cianfrugliare",
    "cianfrugliaron": "cianfrugliare",
    "cianfrugliarono": "cianfrugliare",
    "cianfrugliasse": "cianfrugliare",
    "cianfrugliasser": "cianfrugliare",
    "cianfrugliassero": "cianfrugliare",
    "cianfrugliassi": "cianfrugliare",
    "cianfrugliassimo": "cianfrugliare",
    "cianfrugliaste": "cianfrugliare",
    "cianfrugliasti": "cianfrugliare",
    "cianfrugliata": "cianfrugliare",
    "cianfrugliate": "cianfrugliare",
    "cianfrugliati": "cianfrugliare",
    "cianfrugliato": "cianfrugliare",
    "cianfrugliava": "cianfrugliare",
    "cianfrugliavamo": "cianfrugliare",
    "cianfrugliavan": "cianfrugliare",
    "cianfrugliavano": "cianfrugliare",
    "cianfrugliavate": "cianfrugliare",
    "cianfrugliavi": "cianfrugliare",
    "cianfrugliavo": "cianfrugliare",
    "cianfruglierai": "cianfrugliare",
    "cianfruglieran": "cianfrugliare",
    "cianfruglieranno": "cianfrugliare",
    "cianfruglierebbe": "cianfrugliare",
    "cianfruglierebber": "cianfrugliare",
    "cianfruglierebbero": "cianfrugliare",
    "cianfruglierei": "cianfrugliare",
    "cianfruglieremmo": "cianfrugliare",
    "cianfruglieremo": "cianfrugliare",
    "cianfrugliereste": "cianfrugliare",
    "cianfruglieresti": "cianfrugliare",
    "cianfruglierete": "cianfrugliare",
    "cianfruglierà": "cianfrugliare",
    "cianfruglierò": "cianfrugliare",
    "cianfruglin": "cianfrugliare",
    "cianfruglino": "cianfrugliare",
    "cianfruglio": "cianfrugliare",
    "cianfrugliò": "cianfrugliare",
    "cianfrusaglie": "cianfrusaglia",
    "ciangotta": "ciangottare",
    "ciangottai": "ciangottare",
    "ciangottammo": "ciangottare",
    "ciangottan": "ciangottare",
    "ciangottando": "ciangottare",
    "ciangottano": "ciangottare",
    "ciangottante": "ciangottare",
    "ciangottanti": "ciangottare",
    "ciangottar": "ciangottare",
    "ciangottaron": "ciangottare",
    "ciangottarono": "ciangottare",
    "ciangottasse": "ciangottare",
    "ciangottasser": "ciangottare",
    "ciangottassero": "ciangottare",
    "ciangottassi": "ciangottare",
    "ciangottassimo": "ciangottare",
    "ciangottaste": "ciangottare",
    "ciangottasti": "ciangottare",
    "ciangottata": "ciangottare",
    "ciangottate": "ciangottare",
    "ciangottati": "ciangottare",
    "ciangottato": "ciangottare",
    "ciangottava": "ciangottare",
    "ciangottavamo": "ciangottare",
    "ciangottavan": "ciangottare",
    "ciangottavano": "ciangottare",
    "ciangottavate": "ciangottare",
    "ciangottavi": "ciangottare",
    "ciangottavo": "ciangottare",
    "ciangotterai": "ciangottare",
    "ciangotteran": "ciangottare",
    "ciangotteranno": "ciangottare",
    "ciangotterebbe": "ciangottare",
    "ciangotterebber": "ciangottare",
    "ciangotterebbero": "ciangottare",
    "ciangotterei": "ciangottare",
    "ciangotteremmo": "ciangottare",
    "ciangotteremo": "ciangottare",
    "ciangottereste": "ciangottare",
    "ciangotteresti": "ciangottare",
    "ciangotterete": "ciangottare",
    "ciangotterà": "ciangottare",
    "ciangotterò": "ciangottare",
    "ciangotti": "ciangottare",
    "ciangottiamo": "ciangottare",
    "ciangottiate": "ciangottare",
    "ciangottin": "ciangottare",
    "ciangottino": "ciangottare",
    "ciangotto": "ciangottare",
    "ciangottò": "ciangottare",
    "cianotica": "cianotico",
    "cianotiche": "cianotico",
    "cianotici": "cianotico",
    "ciarla": "ciarlare",
    "ciarlai": "ciarlare",
    "ciarlammo": "ciarlare",
    "ciarlan": "ciarlare",
    "ciarlando": "ciarlare",
    "ciarlano": "ciarlare",
    "ciarlante": "ciarlare",
    "ciarlanti": "ciarlare",
    "ciarlar": "ciarlare",
    "ciarlaron": "ciarlare",
    "ciarlarono": "ciarlare",
    "ciarlasse": "ciarlare",
    "ciarlasser": "ciarlare",
    "ciarlassero": "ciarlare",
    "ciarlassi": "ciarlare",
    "ciarlassimo": "ciarlare",
    "ciarlaste": "ciarlare",
    "ciarlasti": "ciarlare",
    "ciarlata": "ciarlare",
    "ciarlatani": "ciarlatano",
    "ciarlate": "ciarlare",
    "ciarlati": "ciarlare",
    "ciarlato": "ciarlare",
    "ciarlava": "ciarlare",
    "ciarlavamo": "ciarlare",
    "ciarlavan": "ciarlare",
    "ciarlavano": "ciarlare",
    "ciarlavate": "ciarlare",
    "ciarlavi": "ciarlare",
    "ciarlavo": "ciarlare",
    "ciarlerai": "ciarlare",
    "ciarleran": "ciarlare",
    "ciarleranno": "ciarlare",
    "ciarlerebbe": "ciarlare",
    "ciarlerebber": "ciarlare",
    "ciarlerebbero": "ciarlare",
    "ciarlerei": "ciarlare",
    "ciarleremmo": "ciarlare",
    "ciarleremo": "ciarlare",
    "ciarlereste": "ciarlare",
    "ciarleresti": "ciarlare",
    "ciarlerete": "ciarlare",
    "ciarlerà": "ciarlare",
    "ciarlerò": "ciarlare",
    "ciarli": "ciarlare",
    "ciarliamo": "ciarlare",
    "ciarliate": "ciarlare",
    "ciarliera": "ciarliero",
    "ciarliere": "ciarliero",
    "ciarlieri": "ciarliero",
    "ciarlin": "ciarlare",
    "ciarlino": "ciarlare",
    "ciarlo": "ciarlare",
    "ciarlò": "ciarlare",
    "ciarpami": "ciarpame",
    "ciascuna": "ciascun",
    "ciba": "cibare",
    "cibai": "cibare",
    "cibammo": "cibare",
    "ciban": "cibare",
    "cibando": "cibare",
    "cibano": "cibare",
    "cibante": "cibare",
    "cibanti": "cibare",
    "cibar": "cibare",
    "cibaron": "cibare",
    "cibarono": "cibare",
    "cibasse": "cibare",
    "cibasser": "cibare",
    "cibassero": "cibare",
    "cibassi": "cibare",
    "cibassimo": "cibare",
    "cibaste": "cibare",
    "cibasti": "cibare",
    "cibata": "cibare",
    "cibate": "cibare",
    "cibati": "cibare",
    "cibato": "cibare",
    "cibava": "cibare",
    "cibavamo": "cibare",
    "cibavan": "cibare",
    "cibavano": "cibare",
    "cibavate": "cibare",
    "cibavi": "cibare",
    "cibavo": "cibare",
    "ciberai": "cibare",
    "ciberan": "cibare",
    "ciberanno": "cibare",
    "ciberebbe": "cibare",
    "ciberebber": "cibare",
    "ciberebbero": "cibare",
    "ciberei": "cibare",
    "ciberemmo": "cibare",
    "ciberemo": "cibare",
    "cibereste": "cibare",
    "ciberesti": "cibare",
    "ciberete": "cibare",
    "cibernetica": "cibernetico",
    "cibernetiche": "cibernetico",
    "cibernetici": "cibernetico",
    "ciberspazi": "ciberspazio",
    "ciberà": "cibare",
    "ciberò": "cibare",
    "cibi": "cibo",
    "cibiamo": "cibare",
    "cibiate": "cibare",
    "cibin": "cibare",
    "cibino": "cibare",
    "cibo": "cibare",
    "cibò": "cibare",
    "cicala": "cicalare",
    "cicalai": "cicalare",
    "cicalammo": "cicalare",
    "cicalan": "cicalare",
    "cicalando": "cicalare",
    "cicalano": "cicalare",
    "cicalante": "cicalare",
    "cicalanti": "cicalare",
    "cicalar": "cicalare",
    "cicalaron": "cicalare",
    "cicalarono": "cicalare",
    "cicalasse": "cicalare",
    "cicalasser": "cicalare",
    "cicalassero": "cicalare",
    "cicalassi": "cicalare",
    "cicalassimo": "cicalare",
    "cicalaste": "cicalare",
    "cicalasti": "cicalare",
    "cicalata": "cicalare",
    "cicalate": "cicalare",
    "cicalati": "cicalare",
    "cicalato": "cicalare",
    "cicalava": "cicalare",
    "cicalavamo": "cicalare",
    "cicalavan": "cicalare",
    "cicalavano": "cicalare",
    "cicalavate": "cicalare",
    "cicalavi": "cicalare",
    "cicalavo": "cicalare",
    "cicale": "cicala",
    "cicalecci": "cicaleccio",
    "cicalerai": "cicalare",
    "cicaleran": "cicalare",
    "cicaleranno": "cicalare",
    "cicalerebbe": "cicalare",
    "cicalerebber": "cicalare",
    "cicalerebbero": "cicalare",
    "cicalerei": "cicalare",
    "cicaleremmo": "cicalare",
    "cicaleremo": "cicalare",
    "cicalereste": "cicalare",
    "cicaleresti": "cicalare",
    "cicalerete": "cicalare",
    "cicalerà": "cicalare",
    "cicalerò": "cicalare",
    "cicali": "cicalare",
    "cicaliamo": "cicalare",
    "cicaliate": "cicalare",
    "cicalin": "cicalare",
    "cicalino": "cicalare",
    "cicalo": "cicalare",
    "cicalò": "cicalare",
    "cicatrici": "cicatrice",
    "cicatrizza": "cicatrizzare",
    "cicatrizzai": "cicatrizzare",
    "cicatrizzammo": "cicatrizzare",
    "cicatrizzan": "cicatrizzare",
    "cicatrizzando": "cicatrizzare",
    "cicatrizzano": "cicatrizzare",
    "cicatrizzante": "cicatrizzare",
    "cicatrizzanti": "cicatrizzare",
    "cicatrizzar": "cicatrizzare",
    "cicatrizzaron": "cicatrizzare",
    "cicatrizzarono": "cicatrizzare",
    "cicatrizzasse": "cicatrizzare",
    "cicatrizzasser": "cicatrizzare",
    "cicatrizzassero": "cicatrizzare",
    "cicatrizzassi": "cicatrizzare",
    "cicatrizzassimo": "cicatrizzare",
    "cicatrizzaste": "cicatrizzare",
    "cicatrizzasti": "cicatrizzare",
    "cicatrizzata": "cicatrizzare",
    "cicatrizzate": "cicatrizzare",
    "cicatrizzati": "cicatrizzare",
    "cicatrizzato": "cicatrizzare",
    "cicatrizzava": "cicatrizzare",
    "cicatrizzavamo": "cicatrizzare",
    "cicatrizzavan": "cicatrizzare",
    "cicatrizzavano": "cicatrizzare",
    "cicatrizzavate": "cicatrizzare",
    "cicatrizzavi": "cicatrizzare",
    "cicatrizzavo": "cicatrizzare",
    "cicatrizzazioni": "cicatrizzazione",
    "cicatrizzerai": "cicatrizzare",
    "cicatrizzeran": "cicatrizzare",
    "cicatrizzeranno": "cicatrizzare",
    "cicatrizzerebbe": "cicatrizzare",
    "cicatrizzerebber": "cicatrizzare",
    "cicatrizzerebbero": "cicatrizzare",
    "cicatrizzerei": "cicatrizzare",
    "cicatrizzeremmo": "cicatrizzare",
    "cicatrizzeremo": "cicatrizzare",
    "cicatrizzereste": "cicatrizzare",
    "cicatrizzeresti": "cicatrizzare",
    "cicatrizzerete": "cicatrizzare",
    "cicatrizzerà": "cicatrizzare",
    "cicatrizzerò": "cicatrizzare",
    "cicatrizzi": "cicatrizzare",
    "cicatrizziamo": "cicatrizzare",
    "cicatrizziate": "cicatrizzare",
    "cicatrizzin": "cicatrizzare",
    "cicatrizzino": "cicatrizzare",
    "cicatrizzo": "cicatrizzare",
    "cicatrizzò": "cicatrizzare",
    "cicca": "ciccare",
    "ciccai": "ciccare",
    "ciccammo": "ciccare",
    "ciccan": "ciccare",
    "ciccando": "ciccare",
    "ciccano": "ciccare",
    "ciccante": "ciccare",
    "ciccanti": "ciccare",
    "ciccar": "ciccare",
    "ciccaron": "ciccare",
    "ciccarono": "ciccare",
    "ciccasse": "ciccare",
    "ciccasser": "ciccare",
    "ciccassero": "ciccare",
    "ciccassi": "ciccare",
    "ciccassimo": "ciccare",
    "ciccaste": "ciccare",
    "ciccasti": "ciccare",
    "ciccata": "ciccare",
    "ciccate": "ciccare",
    "ciccati": "ciccare",
    "ciccato": "ciccare",
    "ciccava": "ciccare",
    "ciccavamo": "ciccare",
    "ciccavan": "ciccare",
    "ciccavano": "ciccare",
    "ciccavate": "ciccare",
    "ciccavi": "ciccare",
    "ciccavo": "ciccare",
    "cicce": "ciccia",
    "cicche": "cicca",
    "ciccherai": "ciccare",
    "ciccheran": "ciccare",
    "ciccheranno": "ciccare",
    "ciccherebbe": "ciccare",
    "ciccherebber": "ciccare",
    "ciccherebbero": "ciccare",
    "ciccherei": "ciccare",
    "ciccheremmo": "ciccare",
    "ciccheremo": "ciccare",
    "cicchereste": "ciccare",
    "ciccheresti": "ciccare",
    "ciccherete": "ciccare",
    "ciccherà": "ciccare",
    "ciccherò": "ciccare",
    "cicchi": "ciccare",
    "cicchiamo": "ciccare",
    "cicchiate": "ciccare",
    "cicchin": "ciccare",
    "cicchino": "ciccare",
    "ciccioni": "ciccione",
    "cicco": "ciccare",
    "ciccò": "ciccare",
    "ciceroni": "cicerone",
    "cicisbei": "cicisbeo",
    "ciclabili": "ciclabile",
    "ciclamina": "ciclamino",
    "ciclamine": "ciclamino",
    "ciclamini": "ciclamino",
    "cicli": "ciclo",
    "ciclica": "ciclico",
    "cicliche": "ciclico",
    "ciclici": "ciclico",
    "ciclismi": "ciclismo",
    "ciclisti": "ciclista",
    "ciclistica": "ciclistico",
    "ciclistiche": "ciclistico",
    "ciclistici": "ciclistico",
    "cicloamatori": "cicloamatore",
    "ciclomotori": "ciclomotore",
    "cicloni": "ciclone",
    "ciclonica": "ciclonico",
    "cicloniche": "ciclonico",
    "ciclonici": "ciclonico",
    "ciclopica": "ciclopico",
    "ciclopiche": "ciclopico",
    "ciclopici": "ciclopico",
    "ciclostila": "ciclostilare",
    "ciclostilai": "ciclostilare",
    "ciclostilammo": "ciclostilare",
    "ciclostilan": "ciclostilare",
    "ciclostilando": "ciclostilare",
    "ciclostilano": "ciclostilare",
    "ciclostilante": "ciclostilare",
    "ciclostilanti": "ciclostilare",
    "ciclostilar": "ciclostilare",
    "ciclostilaron": "ciclostilare",
    "ciclostilarono": "ciclostilare",
    "ciclostilasse": "ciclostilare",
    "ciclostilasser": "ciclostilare",
    "ciclostilassero": "ciclostilare",
    "ciclostilassi": "ciclostilare",
    "ciclostilassimo": "ciclostilare",
    "ciclostilaste": "ciclostilare",
    "ciclostilasti": "ciclostilare",
    "ciclostilata": "ciclostilare",
    "ciclostilate": "ciclostilare",
    "ciclostilati": "ciclostilato",
    "ciclostilato": "ciclostilare",
    "ciclostilava": "ciclostilare",
    "ciclostilavamo": "ciclostilare",
    "ciclostilavan": "ciclostilare",
    "ciclostilavano": "ciclostilare",
    "ciclostilavate": "ciclostilare",
    "ciclostilavi": "ciclostilare",
    "ciclostilavo": "ciclostilare",
    "ciclostilerai": "ciclostilare",
    "ciclostileran": "ciclostilare",
    "ciclostileranno": "ciclostilare",
    "ciclostilerebbe": "ciclostilare",
    "ciclostilerebber": "ciclostilare",
    "ciclostilerebbero": "ciclostilare",
    "ciclostilerei": "ciclostilare",
    "ciclostileremmo": "ciclostilare",
    "ciclostileremo": "ciclostilare",
    "ciclostilereste": "ciclostilare",
    "ciclostileresti": "ciclostilare",
    "ciclostilerete": "ciclostilare",
    "ciclostilerà": "ciclostilare",
    "ciclostilerò": "ciclostilare",
    "ciclostili": "ciclostilare",
    "ciclostiliamo": "ciclostilare",
    "ciclostiliate": "ciclostilare",
    "ciclostilin": "ciclostilare",
    "ciclostilino": "ciclostilare",
    "ciclostilo": "ciclostilare",
    "ciclostilò": "ciclostilare",
    "cicloturisti": "cicloturista",
    "cicogne": "cicogna",
    "cieca": "cieco",
    "cieche": "cieco",
    "ciechi": "cieco",
    "cieci": "cieco",
    "ciel": "cielo",
    "cieli": "cielo",
    "ciellina": "ciellino",
    "cielline": "ciellino",
    "ciellini": "ciellino",
    "cifra": "cifrare",
    "cifrai": "cifrare",
    "ciframmo": "cifrare",
    "cifran": "cifrare",
    "cifrando": "cifrare",
    "cifrano": "cifrare",
    "cifrante": "cifrare",
    "cifranti": "cifrare",
    "cifrar": "cifrare",
    "cifrari": "cifrario",
    "cifraron": "cifrare",
    "cifrarono": "cifrare",
    "cifrasse": "cifrare",
    "cifrasser": "cifrare",
    "cifrassero": "cifrare",
    "cifrassi": "cifrare",
    "cifrassimo": "cifrare",
    "cifraste": "cifrare",
    "cifrasti": "cifrare",
    "cifrata": "cifrato",
    "cifrate": "cifrato",
    "cifrati": "cifrato",
    "cifrato": "cifrare",
    "cifrava": "cifrare",
    "cifravamo": "cifrare",
    "cifravan": "cifrare",
    "cifravano": "cifrare",
    "cifravate": "cifrare",
    "cifravi": "cifrare",
    "cifravo": "cifrare",
    "cifre": "cifra",
    "cifrerai": "cifrare",
    "cifreran": "cifrare",
    "cifreranno": "cifrare",
    "cifrerebbe": "cifrare",
    "cifrerebber": "cifrare",
    "cifrerebbero": "cifrare",
    "cifrerei": "cifrare",
    "cifreremmo": "cifrare",
    "cifreremo": "cifrare",
    "cifrereste": "cifrare",
    "cifreresti": "cifrare",
    "cifrerete": "cifrare",
    "cifrerà": "cifrare",
    "cifrerò": "cifrare",
    "cifri": "cifrare",
    "cifriamo": "cifrare",
    "cifriate": "cifrare",
    "cifrin": "cifrare",
    "cifrino": "cifrare",
    "cifro": "cifrare",
    "cifrò": "cifrare",
    "cigli": "ciglio",
    "ciglia": "ciglio",
    "cigni": "cigno",
    "cigola": "cigolare",
    "cigolai": "cigolare",
    "cigolammo": "cigolare",
    "cigolan": "cigolare",
    "cigolando": "cigolare",
    "cigolano": "cigolare",
    "cigolante": "cigolare",
    "cigolanti": "cigolare",
    "cigolar": "cigolare",
    "cigolaron": "cigolare",
    "cigolarono": "cigolare",
    "cigolasse": "cigolare",
    "cigolasser": "cigolare",
    "cigolassero": "cigolare",
    "cigolassi": "cigolare",
    "cigolassimo": "cigolare",
    "cigolaste": "cigolare",
    "cigolasti": "cigolare",
    "cigolata": "cigolare",
    "cigolate": "cigolare",
    "cigolati": "cigolare",
    "cigolato": "cigolare",
    "cigolava": "cigolare",
    "cigolavamo": "cigolare",
    "cigolavan": "cigolare",
    "cigolavano": "cigolare",
    "cigolavate": "cigolare",
    "cigolavi": "cigolare",
    "cigolavo": "cigolare",
    "cigolerai": "cigolare",
    "cigoleran": "cigolare",
    "cigoleranno": "cigolare",
    "cigolerebbe": "cigolare",
    "cigolerebber": "cigolare",
    "cigolerebbero": "cigolare",
    "cigolerei": "cigolare",
    "cigoleremmo": "cigolare",
    "cigoleremo": "cigolare",
    "cigolereste": "cigolare",
    "cigoleresti": "cigolare",
    "cigolerete": "cigolare",
    "cigolerà": "cigolare",
    "cigolerò": "cigolare",
    "cigoli": "cigolare",
    "cigoliamo": "cigolare",
    "cigoliate": "cigolare",
    "cigolii": "cigolio",
    "cigolin": "cigolare",
    "cigolino": "cigolare",
    "cigolo": "cigolare",
    "cigolò": "cigolare",
    "cilena": "cileno",
    "cilene": "cileno",
    "cileni": "cileno",
    "cilestrina": "cilestrino",
    "cilestrine": "cilestrino",
    "cilestrini": "cilestrino",
    "cilici": "cilicio",
    "ciliege": "ciliegia",
    "ciliegi": "ciliegio",
    "ciliegie": "ciliegia",
    "ciliegine": "ciliegina",
    "cilindra": "cilindrare",
    "cilindrai": "cilindrare",
    "cilindrammo": "cilindrare",
    "cilindran": "cilindrare",
    "cilindrando": "cilindrare",
    "cilindrano": "cilindrare",
    "cilindrante": "cilindrare",
    "cilindranti": "cilindrare",
    "cilindrar": "cilindrare",
    "cilindraron": "cilindrare",
    "cilindrarono": "cilindrare",
    "cilindrasse": "cilindrare",
    "cilindrasser": "cilindrare",
    "cilindrassero": "cilindrare",
    "cilindrassi": "cilindrare",
    "cilindrassimo": "cilindrare",
    "cilindraste": "cilindrare",
    "cilindrasti": "cilindrare",
    "cilindrata": "cilindrare",
    "cilindrate": "cilindrata",
    "cilindrati": "cilindrare",
    "cilindrato": "cilindrare",
    "cilindrava": "cilindrare",
    "cilindravamo": "cilindrare",
    "cilindravan": "cilindrare",
    "cilindravano": "cilindrare",
    "cilindravate": "cilindrare",
    "cilindravi": "cilindrare",
    "cilindravo": "cilindrare",
    "cilindrerai": "cilindrare",
    "cilindreran": "cilindrare",
    "cilindreranno": "cilindrare",
    "cilindrerebbe": "cilindrare",
    "cilindrerebber": "cilindrare",
    "cilindrerebbero": "cilindrare",
    "cilindrerei": "cilindrare",
    "cilindreremmo": "cilindrare",
    "cilindreremo": "cilindrare",
    "cilindrereste": "cilindrare",
    "cilindreresti": "cilindrare",
    "cilindrerete": "cilindrare",
    "cilindrerà": "cilindrare",
    "cilindrerò": "cilindrare",
    "cilindri": "cilindro",
    "cilindriamo": "cilindrare",
    "cilindriate": "cilindrare",
    "cilindrica": "cilindrico",
    "cilindriche": "cilindrico",
    "cilindrici": "cilindrico",
    "cilindrin": "cilindrare",
    "cilindrino": "cilindrare",
    "cilindro": "cilindrare",
    "cilindrò": "cilindrare",
    "cima": "cimare",
    "cimai": "cimare",
    "cimammo": "cimare",
    "ciman": "cimare",
    "cimando": "cimare",
    "cimano": "cimare",
    "cimante": "cimare",
    "cimanti": "cimare",
    "cimar": "cimare",
    "cimaron": "cimare",
    "cimarono": "cimare",
    "cimasse": "cimare",
    "cimasser": "cimare",
    "cimassero": "cimare",
    "cimassi": "cimare",
    "cimassimo": "cimare",
    "cimaste": "cimare",
    "cimasti": "cimare",
    "cimata": "cimare",
    "cimate": "cimare",
    "cimati": "cimare",
    "cimato": "cimare",
    "cimava": "cimare",
    "cimavamo": "cimare",
    "cimavan": "cimare",
    "cimavano": "cimare",
    "cimavate": "cimare",
    "cimavi": "cimare",
    "cimavo": "cimare",
    "cime": "cima",
    "cimeli": "cimelio",
    "cimenta": "cimentare",
    "cimentai": "cimentare",
    "cimentammo": "cimentare",
    "cimentan": "cimentare",
    "cimentando": "cimentare",
    "cimentano": "cimentare",
    "cimentante": "cimentare",
    "cimentanti": "cimentare",
    "cimentar": "cimentare",
    "cimentaron": "cimentare",
    "cimentarono": "cimentare",
    "cimentasse": "cimentare",
    "cimentasser": "cimentare",
    "cimentassero": "cimentare",
    "cimentassi": "cimentare",
    "cimentassimo": "cimentare",
    "cimentaste": "cimentare",
    "cimentasti": "cimentare",
    "cimentata": "cimentare",
    "cimentate": "cimentare",
    "cimentati": "cimentare",
    "cimentato": "cimentare",
    "cimentava": "cimentare",
    "cimentavamo": "cimentare",
    "cimentavan": "cimentare",
    "cimentavano": "cimentare",
    "cimentavate": "cimentare",
    "cimentavi": "cimentare",
    "cimentavo": "cimentare",
    "cimenterai": "cimentare",
    "cimenteran": "cimentare",
    "cimenteranno": "cimentare",
    "cimenterebbe": "cimentare",
    "cimenterebber": "cimentare",
    "cimenterebbero": "cimentare",
    "cimenterei": "cimentare",
    "cimenteremmo": "cimentare",
    "cimenteremo": "cimentare",
    "cimentereste": "cimentare",
    "cimenteresti": "cimentare",
    "cimenterete": "cimentare",
    "cimenterà": "cimentare",
    "cimenterò": "cimentare",
    "cimenti": "cimento",
    "cimentiamo": "cimentare",
    "cimentiate": "cimentare",
    "cimentin": "cimentare",
    "cimentino": "cimentare",
    "cimento": "cimentare",
    "cimentò": "cimentare",
    "cimerai": "cimare",
    "cimeran": "cimare",
    "cimeranno": "cimare",
    "cimerebbe": "cimare",
    "cimerebber": "cimare",
    "cimerebbero": "cimare",
    "cimerei": "cimare",
    "cimeremmo": "cimare",
    "cimeremo": "cimare",
    "cimereste": "cimare",
    "cimeresti": "cimare",
    "cimerete": "cimare",
    "cimerà": "cimare",
    "cimerò": "cimare",
    "cimi": "cimare",
    "cimiamo": "cimare",
    "cimiate": "cimare",
    "cimici": "cimice",
    "cimin": "cimare",
    "ciminiere": "ciminiera",
    "cimino": "cimare",
    "cimiteri": "cimitero",
    "cimiteriali": "cimiteriale",
    "cimo": "cimare",
    "cimò": "cimare",
    "cincischi": "cincischiare",
    "cincischia": "cincischiare",
    "cincischiai": "cincischiare",
    "cincischiammo": "cincischiare",
    "cincischiamo": "cincischiare",
    "cincischian": "cincischiare",
    "cincischiando": "cincischiare",
    "cincischiano": "cincischiare",
    "cincischiante": "cincischiare",
    "cincischianti": "cincischiare",
    "cincischiar": "cincischiare",
    "cincischiaron": "cincischiare",
    "cincischiarono": "cincischiare",
    "cincischiasse": "cincischiare",
    "cincischiasser": "cincischiare",
    "cincischiassero": "cincischiare",
    "cincischiassi": "cincischiare",
    "cincischiassimo": "cincischiare",
    "cincischiaste": "cincischiare",
    "cincischiasti": "cincischiare",
    "cincischiata": "cincischiare",
    "cincischiate": "cincischiare",
    "cincischiati": "cincischiare",
    "cincischiato": "cincischiare",
    "cincischiava": "cincischiare",
    "cincischiavamo": "cincischiare",
    "cincischiavan": "cincischiare",
    "cincischiavano": "cincischiare",
    "cincischiavate": "cincischiare",
    "cincischiavi": "cincischiare",
    "cincischiavo": "cincischiare",
    "cincischierai": "cincischiare",
    "cincischieran": "cincischiare",
    "cincischieranno": "cincischiare",
    "cincischierebbe": "cincischiare",
    "cincischierebber": "cincischiare",
    "cincischierebbero": "cincischiare",
    "cincischierei": "cincischiare",
    "cincischieremmo": "cincischiare",
    "cincischieremo": "cincischiare",
    "cincischiereste": "cincischiare",
    "cincischieresti": "cincischiare",
    "cincischierete": "cincischiare",
    "cincischierà": "cincischiare",
    "cincischierò": "cincischiare",
    "cincischin": "cincischiare",
    "cincischino": "cincischiare",
    "cincischio": "cincischiare",
    "cincischiò": "cincischiare",
    "cineaste": "cineasta",
    "cineasti": "cineasta",
    "cinebiografica": "cinebiografico",
    "cinebiografiche": "cinebiografico",
    "cinebiografici": "cinebiografico",
    "cinefili": "cinefilo",
    "cinegiornali": "cinegiornale",
    "cinematografa": "cinematografare",
    "cinematografai": "cinematografare",
    "cinematografammo": "cinematografare",
    "cinematografan": "cinematografare",
    "cinematografando": "cinematografare",
    "cinematografano": "cinematografare",
    "cinematografante": "cinematografare",
    "cinematografanti": "cinematografare",
    "cinematografar": "cinematografare",
    "cinematografaron": "cinematografare",
    "cinematografarono": "cinematografare",
    "cinematografasse": "cinematografare",
    "cinematografasser": "cinematografare",
    "cinematografassero": "cinematografare",
    "cinematografassi": "cinematografare",
    "cinematografassimo": "cinematografare",
    "cinematografaste": "cinematografare",
    "cinematografasti": "cinematografare",
    "cinematografata": "cinematografare",
    "cinematografate": "cinematografare",
    "cinematografati": "cinematografare",
    "cinematografato": "cinematografare",
    "cinematografava": "cinematografare",
    "cinematografavamo": "cinematografare",
    "cinematografavan": "cinematografare",
    "cinematografavano": "cinematografare",
    "cinematografavate": "cinematografare",
    "cinematografavi": "cinematografare",
    "cinematografavo": "cinematografare",
    "cinematograferai": "cinematografare",
    "cinematograferan": "cinematografare",
    "cinematograferanno": "cinematografare",
    "cinematograferebbe": "cinematografare",
    "cinematograferebber": "cinematografare",
    "cinematograferebbero": "cinematografare",
    "cinematograferei": "cinematografare",
    "cinematograferemmo": "cinematografare",
    "cinematograferemo": "cinematografare",
    "cinematografereste": "cinematografare",
    "cinematograferesti": "cinematografare",
    "cinematograferete": "cinematografare",
    "cinematograferà": "cinematografare",
    "cinematograferò": "cinematografare",
    "cinematografi": "cinematografo",
    "cinematografiamo": "cinematografare",
    "cinematografiate": "cinematografare",
    "cinematografica": "cinematografico",
    "cinematografiche": "cinematografico",
    "cinematografici": "cinematografico",
    "cinematografie": "cinematografia",
    "cinematografin": "cinematografare",
    "cinematografino": "cinematografare",
    "cinematografo": "cinematografare",
    "cinematografò": "cinematografare",
    "cinematrografica": "cinematrografico",
    "cinematrografiche": "cinematrografico",
    "cinematrografici": "cinematrografico",
    "cinemini": "cinemino",
    "cineoperatori": "cineoperatore",
    "cineprese": "cinepresa",
    "cinerea": "cinereo",
    "cineree": "cinereo",
    "cinerei": "cinereo",
    "cineserie": "cineseria",
    "cinesi": "cinese",
    "cineteche": "cineteca",
    "cinetica": "cinetico",
    "cinetiche": "cinetico",
    "cinetici": "cinetico",
    "cinga": "cingere",
    "cingalesi": "cingalese",
    "cingan": "cingere",
    "cingano": "cingere",
    "cinge": "cingere",
    "cingemmo": "cingere",
    "cingendo": "cingere",
    "cingente": "cingere",
    "cingenti": "cingere",
    "cinger": "cingere",
    "cingerai": "cingere",
    "cingeran": "cingere",
    "cingeranno": "cingere",
    "cingerebbe": "cingere",
    "cingerebber": "cingere",
    "cingerebbero": "cingere",
    "cingerei": "cingere",
    "cingeremmo": "cingere",
    "cingeremo": "cingere",
    "cingereste": "cingere",
    "cingeresti": "cingere",
    "cingerete": "cingere",
    "cingerà": "cingere",
    "cingerò": "cingere",
    "cingesse": "cingere",
    "cingesser": "cingere",
    "cingessero": "cingere",
    "cingessi": "cingere",
    "cingessimo": "cingere",
    "cingeste": "cingere",
    "cingesti": "cingere",
    "cingete": "cingere",
    "cingeva": "cingere",
    "cingevamo": "cingere",
    "cingevan": "cingere",
    "cingevano": "cingere",
    "cingevate": "cingere",
    "cingevi": "cingere",
    "cingevo": "cingere",
    "cinghi": "cinghiare",
    "cinghia": "cinghiare",
    "cinghiai": "cinghiare",
    "cinghialesca": "cinghialesco",
    "cinghialesche": "cinghialesco",
    "cinghialeschi": "cinghialesco",
    "cinghiali": "cinghiale",
    "cinghiammo": "cinghiare",
    "cinghiamo": "cinghiare",
    "cinghian": "cinghiare",
    "cinghiando": "cinghiare",
    "cinghiano": "cinghiare",
    "cinghiante": "cinghiare",
    "cinghianti": "cinghiare",
    "cinghiar": "cinghiare",
    "cinghiaron": "cinghiare",
    "cinghiarono": "cinghiare",
    "cinghiasse": "cinghiare",
    "cinghiasser": "cinghiare",
    "cinghiassero": "cinghiare",
    "cinghiassi": "cinghiare",
    "cinghiassimo": "cinghiare",
    "cinghiaste": "cinghiare",
    "cinghiasti": "cinghiare",
    "cinghiata": "cinghiare",
    "cinghiate": "cinghiare",
    "cinghiati": "cinghiare",
    "cinghiato": "cinghiare",
    "cinghiava": "cinghiare",
    "cinghiavamo": "cinghiare",
    "cinghiavan": "cinghiare",
    "cinghiavano": "cinghiare",
    "cinghiavate": "cinghiare",
    "cinghiavi": "cinghiare",
    "cinghiavo": "cinghiare",
    "cinghie": "cinghia",
    "cinghierai": "cinghiare",
    "cinghieran": "cinghiare",
    "cinghieranno": "cinghiare",
    "cinghierebbe": "cinghiare",
    "cinghierebber": "cinghiare",
    "cinghierebbero": "cinghiare",
    "cinghierei": "cinghiare",
    "cinghieremmo": "cinghiare",
    "cinghieremo": "cinghiare",
    "cinghiereste": "cinghiare",
    "cinghieresti": "cinghiare",
    "cinghierete": "cinghiare",
    "cinghierà": "cinghiare",
    "cinghierò": "cinghiare",
    "cinghin": "cinghiare",
    "cinghino": "cinghiare",
    "cinghio": "cinghiare",
    "cinghiò": "cinghiare",
    "cingi": "cingere",
    "cingiamo": "cingere",
    "cingiate": "cingere",
    "cingo": "cingere",
    "cingolata": "cingolato",
    "cingolate": "cingolato",
    "cingolati": "cingolato",
    "cingoli": "cingolo",
    "cingon": "cingere",
    "cingono": "cingere",
    "cinguetta": "cinguettare",
    "cinguettai": "cinguettare",
    "cinguettammo": "cinguettare",
    "cinguettan": "cinguettare",
    "cinguettando": "cinguettare",
    "cinguettano": "cinguettare",
    "cinguettante": "cinguettare",
    "cinguettanti": "cinguettare",
    "cinguettar": "cinguettare",
    "cinguettaron": "cinguettare",
    "cinguettarono": "cinguettare",
    "cinguettasse": "cinguettare",
    "cinguettasser": "cinguettare",
    "cinguettassero": "cinguettare",
    "cinguettassi": "cinguettare",
    "cinguettassimo": "cinguettare",
    "cinguettaste": "cinguettare",
    "cinguettasti": "cinguettare",
    "cinguettata": "cinguettare",
    "cinguettate": "cinguettare",
    "cinguettati": "cinguettare",
    "cinguettato": "cinguettare",
    "cinguettava": "cinguettare",
    "cinguettavamo": "cinguettare",
    "cinguettavan": "cinguettare",
    "cinguettavano": "cinguettare",
    "cinguettavate": "cinguettare",
    "cinguettavi": "cinguettare",
    "cinguettavo": "cinguettare",
    "cinguetterai": "cinguettare",
    "cinguetteran": "cinguettare",
    "cinguetteranno": "cinguettare",
    "cinguetterebbe": "cinguettare",
    "cinguetterebber": "cinguettare",
    "cinguetterebbero": "cinguettare",
    "cinguetterei": "cinguettare",
    "cinguetteremmo": "cinguettare",
    "cinguetteremo": "cinguettare",
    "cinguettereste": "cinguettare",
    "cinguetteresti": "cinguettare",
    "cinguetterete": "cinguettare",
    "cinguetterà": "cinguettare",
    "cinguetterò": "cinguettare",
    "cinguetti": "cinguettare",
    "cinguettiamo": "cinguettare",
    "cinguettiate": "cinguettare",
    "cinguettii": "cinguettio",
    "cinguettin": "cinguettare",
    "cinguettino": "cinguettare",
    "cinguetto": "cinguettare",
    "cinguettò": "cinguettare",
    "cinica": "cinico",
    "ciniche": "cinico",
    "cinici": "cinico",
    "cinismi": "cinismo",
    "cino-americana": "cino-americano",
    "cino-americane": "cino-americano",
    "cino-americani": "cino-americano",
    "cino-giapponesi": "cino-giapponese",
    "cino-sovietica": "cino-sovietico",
    "cino-sovietiche": "cino-sovietico",
    "cino-sovietici": "cino-sovietico",
    "cinoamericana": "cinoamericano",
    "cinoamericane": "cinoamericano",
    "cinoamericani": "cinoamericano",
    "cinoaustraliana": "cinoaustraliano",
    "cinoaustraliane": "cinoaustraliano",
    "cinoaustraliani": "cinoaustraliano",
    "cinocefala": "cinocefalo",
    "cinocefale": "cinocefalo",
    "cinocefali": "cinocefalo",
    "cinofila": "cinofilo",
    "cinofile": "cinofilo",
    "cinofili": "cinofilo",
    "cinquantacinquesima": "cinquantacinquesimo",
    "cinquantacinquesime": "cinquantacinquesimo",
    "cinquantacinquesimi": "cinquantacinquesimo",
    "cinquantaduesima": "cinquantaduesimo",
    "cinquantaduesime": "cinquantaduesimo",
    "cinquantaduesimi": "cinquantaduesimo",
    "cinquantanovesima": "cinquantanovesimo",
    "cinquantanovesime": "cinquantanovesimo",
    "cinquantanovesimi": "cinquantanovesimo",
    "cinquantaquattresima": "cinquantaquattresimo",
    "cinquantaquattresime": "cinquantaquattresimo",
    "cinquantaquattresimi": "cinquantaquattresimo",
    "cinquantaseiesima": "cinquantaseiesimo",
    "cinquantaseiesime": "cinquantaseiesimo",
    "cinquantaseiesimi": "cinquantaseiesimo",
    "cinquantasettesima": "cinquantasettesimo",
    "cinquantasettesime": "cinquantasettesimo",
    "cinquantasettesimi": "cinquantasettesimo",
    "cinquantatreesima": "cinquantatreesimo",
    "cinquantatreesime": "cinquantatreesimo",
    "cinquantatreesimi": "cinquantatreesimo",
    "cinquantenari": "cinquantenario",
    "cinquantenni": "cinquantenne",
    "cinquantennii": "cinquantennio",
    "cinquantesima": "cinquantesimo",
    "cinquantesime": "cinquantesimo",
    "cinquantesimi": "cinquantesimo",
    "cinquantine": "cinquantina",
    "cinquantini": "cinquantino",
    "cinquantottesima": "cinquantottesimo",
    "cinquantottesime": "cinquantottesimo",
    "cinquantottesimi": "cinquantottesimo",
    "cinquantunesima": "cinquantunesimo",
    "cinquantunesime": "cinquantunesimo",
    "cinquantunesimi": "cinquantunesimo",
    "cinquecentenari": "cinquecentenario",
    "cinquecentesca": "cinquecentesco",
    "cinquecentesche": "cinquecentesco",
    "cinquecenteschi": "cinquecentesco",
    "cinquecentesima": "cinquecentesimo",
    "cinquecentesime": "cinquecentesimo",
    "cinquecentesimi": "cinquecentesimo",
    "cinquemillesima": "cinquemillesimo",
    "cinquemillesime": "cinquemillesimo",
    "cinquemillesimi": "cinquemillesimo",
    "cinquine": "cinquina",
    "cinse": "cingere",
    "cinser": "cingere",
    "cinsero": "cingere",
    "cinsi": "cingere",
    "cinta": "cinto",
    "cintai": "cintare",
    "cintammo": "cintare",
    "cintan": "cintare",
    "cintando": "cintare",
    "cintano": "cintare",
    "cintante": "cintare",
    "cintanti": "cintare",
    "cintar": "cintare",
    "cintaron": "cintare",
    "cintarono": "cintare",
    "cintasse": "cintare",
    "cintasser": "cintare",
    "cintassero": "cintare",
    "cintassi": "cintare",
    "cintassimo": "cintare",
    "cintaste": "cintare",
    "cintasti": "cintare",
    "cintata": "cintare",
    "cintate": "cintare",
    "cintati": "cintare",
    "cintato": "cintare",
    "cintava": "cintare",
    "cintavamo": "cintare",
    "cintavan": "cintare",
    "cintavano": "cintare",
    "cintavate": "cintare",
    "cintavi": "cintare",
    "cintavo": "cintare",
    "cinte": "cinto",
    "cinterai": "cintare",
    "cinteran": "cintare",
    "cinteranno": "cintare",
    "cinterebbe": "cintare",
    "cinterebber": "cintare",
    "cinterebbero": "cintare",
    "cinterei": "cintare",
    "cinteremmo": "cintare",
    "cinteremo": "cintare",
    "cintereste": "cintare",
    "cinteresti": "cintare",
    "cinterete": "cintare",
    "cinterà": "cintare",
    "cinterò": "cintare",
    "cinti": "cinto",
    "cintiamo": "cintare",
    "cintiate": "cintare",
    "cintin": "cintare",
    "cintino": "cintare",
    "cinto": "cintare",
    "cintole": "cintola",
    "cinture": "cintura",
    "cinturini": "cinturino",
    "cinturoni": "cinturone",
    "cintò": "cintare",
    "ciocche": "ciocca",
    "cioccolate": "cioccolata",
    "cioccolati": "cioccolato",
    "cioccolatini": "cioccolatino",
    "ciociara": "ciociaro",
    "ciociare": "ciociaro",
    "ciociari": "ciociaro",
    "cionca": "cioncare",
    "cioncai": "cioncare",
    "cioncammo": "cioncare",
    "cioncan": "cioncare",
    "cioncando": "cioncare",
    "cioncano": "cioncare",
    "cioncante": "cioncare",
    "cioncanti": "cioncare",
    "cioncar": "cioncare",
    "cioncaron": "cioncare",
    "cioncarono": "cioncare",
    "cioncasse": "cioncare",
    "cioncasser": "cioncare",
    "cioncassero": "cioncare",
    "cioncassi": "cioncare",
    "cioncassimo": "cioncare",
    "cioncaste": "cioncare",
    "cioncasti": "cioncare",
    "cioncata": "cioncare",
    "cioncate": "cioncare",
    "cioncati": "cioncare",
    "cioncato": "cioncare",
    "cioncava": "cioncare",
    "cioncavamo": "cioncare",
    "cioncavan": "cioncare",
    "cioncavano": "cioncare",
    "cioncavate": "cioncare",
    "cioncavi": "cioncare",
    "cioncavo": "cioncare",
    "cioncherai": "cioncare",
    "cioncheran": "cioncare",
    "cioncheranno": "cioncare",
    "cioncherebbe": "cioncare",
    "cioncherebber": "cioncare",
    "cioncherebbero": "cioncare",
    "cioncherei": "cioncare",
    "cioncheremmo": "cioncare",
    "cioncheremo": "cioncare",
    "cionchereste": "cioncare",
    "cioncheresti": "cioncare",
    "cioncherete": "cioncare",
    "cioncherà": "cioncare",
    "cioncherò": "cioncare",
    "cionchi": "cioncare",
    "cionchiamo": "cioncare",
    "cionchiate": "cioncare",
    "cionchin": "cioncare",
    "cionchino": "cioncare",
    "cionco": "cioncare",
    "cioncò": "cioncare",
    "ciondola": "ciondolare",
    "ciondolai": "ciondolare",
    "ciondolammo": "ciondolare",
    "ciondolan": "ciondolare",
    "ciondolando": "ciondolare",
    "ciondolano": "ciondolare",
    "ciondolante": "ciondolare",
    "ciondolanti": "ciondolare",
    "ciondolar": "ciondolare",
    "ciondolaron": "ciondolare",
    "ciondolarono": "ciondolare",
    "ciondolasse": "ciondolare",
    "ciondolasser": "ciondolare",
    "ciondolassero": "ciondolare",
    "ciondolassi": "ciondolare",
    "ciondolassimo": "ciondolare",
    "ciondolaste": "ciondolare",
    "ciondolasti": "ciondolare",
    "ciondolata": "ciondolare",
    "ciondolate": "ciondolare",
    "ciondolati": "ciondolare",
    "ciondolato": "ciondolare",
    "ciondolava": "ciondolare",
    "ciondolavamo": "ciondolare",
    "ciondolavan": "ciondolare",
    "ciondolavano": "ciondolare",
    "ciondolavate": "ciondolare",
    "ciondolavi": "ciondolare",
    "ciondolavo": "ciondolare",
    "ciondolerai": "ciondolare",
    "ciondoleran": "ciondolare",
    "ciondoleranno": "ciondolare",
    "ciondolerebbe": "ciondolare",
    "ciondolerebber": "ciondolare",
    "ciondolerebbero": "ciondolare",
    "ciondolerei": "ciondolare",
    "ciondoleremmo": "ciondolare",
    "ciondoleremo": "ciondolare",
    "ciondolereste": "ciondolare",
    "ciondoleresti": "ciondolare",
    "ciondolerete": "ciondolare",
    "ciondolerà": "ciondolare",
    "ciondolerò": "ciondolare",
    "ciondoli": "ciondolo",
    "ciondoliamo": "ciondolare",
    "ciondoliate": "ciondolare",
    "ciondolin": "ciondolare",
    "ciondolino": "ciondolare",
    "ciondolo": "ciondolare",
    "ciondolò": "ciondolare",
    "ciotole": "ciotola",
    "ciottoli": "ciottolo",
    "cipigli": "cipiglio",
    "cipolle": "cipolla",
    "cippi": "cippo",
    "cipputiana": "cipputiano",
    "cipputiane": "cipputiano",
    "cipputiani": "cipputiano",
    "cipressi": "cipresso",
    "ciprie": "cipria",
    "cipriote": "cipriota",
    "ciprioti": "cipriota",
    "ciranesca": "ciranesco",
    "ciranesche": "ciranesco",
    "ciraneschi": "ciranesco",
    "circadiana": "circadiano",
    "circadiane": "circadiano",
    "circadiani": "circadiano",
    "circassa": "circasso",
    "circasse": "circasso",
    "circassi": "circasso",
    "circensi": "circense",
    "circhi": "circo",
    "circola": "circolare",
    "circolai": "circolare",
    "circolammo": "circolare",
    "circolan": "circolare",
    "circolando": "circolare",
    "circolano": "circolare",
    "circolante": "circolare",
    "circolanti": "circolare",
    "circolar": "circolare",
    "circolari": "circolare",
    "circolaron": "circolare",
    "circolarono": "circolare",
    "circolasse": "circolare",
    "circolasser": "circolare",
    "circolassero": "circolare",
    "circolassi": "circolare",
    "circolassimo": "circolare",
    "circolaste": "circolare",
    "circolasti": "circolare",
    "circolata": "circolare",
    "circolate": "circolare",
    "circolati": "circolare",
    "circolato": "circolare",
    "circolatori": "circolatorio",
    "circolatoria": "circolatorio",
    "circolatorie": "circolatorio",
    "circolava": "circolare",
    "circolavamo": "circolare",
    "circolavan": "circolare",
    "circolavano": "circolare",
    "circolavate": "circolare",
    "circolavi": "circolare",
    "circolavo": "circolare",
    "circolerai": "circolare",
    "circoleran": "circolare",
    "circoleranno": "circolare",
    "circolerebbe": "circolare",
    "circolerebber": "circolare",
    "circolerebbero": "circolare",
    "circolerei": "circolare",
    "circoleremmo": "circolare",
    "circoleremo": "circolare",
    "circolereste": "circolare",
    "circoleresti": "circolare",
    "circolerete": "circolare",
    "circolerà": "circolare",
    "circolerò": "circolare",
    "circoli": "circolo",
    "circoliamo": "circolare",
    "circoliate": "circolare",
    "circolin": "circolare",
    "circolino": "circolare",
    "circolo": "circolare",
    "circolò": "circolare",
    "circoncida": "circoncidere",
    "circoncidan": "circoncidere",
    "circoncidano": "circoncidere",
    "circoncide": "circoncidere",
    "circoncidemmo": "circoncidere",
    "circoncidendo": "circoncidere",
    "circoncidente": "circoncidere",
    "circoncidenti": "circoncidere",
    "circoncider": "circoncidere",
    "circonciderai": "circoncidere",
    "circoncideran": "circoncidere",
    "circoncideranno": "circoncidere",
    "circonciderebbe": "circoncidere",
    "circonciderebber": "circoncidere",
    "circonciderebbero": "circoncidere",
    "circonciderei": "circoncidere",
    "circoncideremmo": "circoncidere",
    "circoncideremo": "circoncidere",
    "circoncidereste": "circoncidere",
    "circoncideresti": "circoncidere",
    "circonciderete": "circoncidere",
    "circonciderà": "circoncidere",
    "circonciderò": "circoncidere",
    "circoncidesse": "circoncidere",
    "circoncidesser": "circoncidere",
    "circoncidessero": "circoncidere",
    "circoncidessi": "circoncidere",
    "circoncidessimo": "circoncidere",
    "circoncideste": "circoncidere",
    "circoncidesti": "circoncidere",
    "circoncidete": "circoncidere",
    "circoncideva": "circoncidere",
    "circoncidevamo": "circoncidere",
    "circoncidevan": "circoncidere",
    "circoncidevano": "circoncidere",
    "circoncidevate": "circoncidere",
    "circoncidevi": "circoncidere",
    "circoncidevo": "circoncidere",
    "circoncidi": "circoncidere",
    "circoncidiamo": "circoncidere",
    "circoncidiate": "circoncidere",
    "circoncido": "circoncidere",
    "circoncidon": "circoncidere",
    "circoncidono": "circoncidere",
    "circoncisa": "circoncidere",
    "circoncise": "circoncidere",
    "circonciser": "circoncidere",
    "circoncisero": "circoncidere",
    "circoncisi": "circoncidere",
    "circoncisioni": "circoncisione",
    "circonciso": "circoncidere",
    "circonda": "circondare",
    "circondai": "circondare",
    "circondammo": "circondare",
    "circondan": "circondare",
    "circondando": "circondare",
    "circondano": "circondare",
    "circondante": "circondare",
    "circondanti": "circondare",
    "circondar": "circondare",
    "circondari": "circondario",
    "circondariali": "circondariale",
    "circondaron": "circondare",
    "circondarono": "circondare",
    "circondasse": "circondare",
    "circondasser": "circondare",
    "circondassero": "circondare",
    "circondassi": "circondare",
    "circondassimo": "circondare",
    "circondaste": "circondare",
    "circondasti": "circondare",
    "circondata": "circondare",
    "circondate": "circondare",
    "circondati": "circondare",
    "circondato": "circondare",
    "circondava": "circondare",
    "circondavamo": "circondare",
    "circondavan": "circondare",
    "circondavano": "circondare",
    "circondavate": "circondare",
    "circondavi": "circondare",
    "circondavo": "circondare",
    "circonderai": "circondare",
    "circonderan": "circondare",
    "circonderanno": "circondare",
    "circonderebbe": "circondare",
    "circonderebber": "circondare",
    "circonderebbero": "circondare",
    "circonderei": "circondare",
    "circonderemmo": "circondare",
    "circonderemo": "circondare",
    "circondereste": "circondare",
    "circonderesti": "circondare",
    "circonderete": "circondare",
    "circonderà": "circondare",
    "circonderò": "circondare",
    "circondi": "circondare",
    "circondiamo": "circondare",
    "circondiate": "circondare",
    "circondin": "circondare",
    "circondino": "circondare",
    "circondo": "circondare",
    "circondò": "circondare",
    "circonferenze": "circonferenza",
    "circonfonda": "circonfondere",
    "circonfondan": "circonfondere",
    "circonfondano": "circonfondere",
    "circonfonde": "circonfondere",
    "circonfondemmo": "circonfondere",
    "circonfondendo": "circonfondere",
    "circonfondente": "circonfondere",
    "circonfondenti": "circonfondere",
    "circonfonder": "circonfondere",
    "circonfonderai": "circonfondere",
    "circonfonderan": "circonfondere",
    "circonfonderanno": "circonfondere",
    "circonfonderebbe": "circonfondere",
    "circonfonderebber": "circonfondere",
    "circonfonderebbero": "circonfondere",
    "circonfonderei": "circonfondere",
    "circonfonderemmo": "circonfondere",
    "circonfonderemo": "circonfondere",
    "circonfondereste": "circonfondere",
    "circonfonderesti": "circonfondere",
    "circonfonderete": "circonfondere",
    "circonfonderà": "circonfondere",
    "circonfonderò": "circonfondere",
    "circonfondesse": "circonfondere",
    "circonfondesser": "circonfondere",
    "circonfondessero": "circonfondere",
    "circonfondessi": "circonfondere",
    "circonfondessimo": "circonfondere",
    "circonfondeste": "circonfondere",
    "circonfondesti": "circonfondere",
    "circonfondete": "circonfondere",
    "circonfondeva": "circonfondere",
    "circonfondevamo": "circonfondere",
    "circonfondevan": "circonfondere",
    "circonfondevano": "circonfondere",
    "circonfondevate": "circonfondere",
    "circonfondevi": "circonfondere",
    "circonfondevo": "circonfondere",
    "circonfondi": "circonfondere",
    "circonfondiamo": "circonfondere",
    "circonfondiate": "circonfondere",
    "circonfondo": "circonfondere",
    "circonfondon": "circonfondere",
    "circonfondono": "circonfondere",
    "circonfoser": "circonfondere",
    "circonfosero": "circonfondere",
    "circonfosi": "circonfondere",
    "circonfosta": "circonfondere",
    "circonfoste": "circonfondere",
    "circonfosti": "circonfondere",
    "circonfosto": "circonfondere",
    "circonfosè": "circonfondere",
    "circonvallazioni": "circonvallazione",
    "circonvena": "circonvenire",
    "circonvenan": "circonvenire",
    "circonvenano": "circonvenire",
    "circonvene": "circonvenire",
    "circonvenendo": "circonvenire",
    "circonvenente": "circonvenire",
    "circonvenenti": "circonvenire",
    "circonveni": "circonvenire",
    "circonveniamo": "circonvenire",
    "circonveniate": "circonvenire",
    "circonvenii": "circonvenire",
    "circonvenimmo": "circonvenire",
    "circonvenir": "circonvenire",
    "circonvenirai": "circonvenire",
    "circonveniran": "circonvenire",
    "circonveniranno": "circonvenire",
    "circonvenirebbe": "circonvenire",
    "circonvenirebber": "circonvenire",
    "circonvenirebbero": "circonvenire",
    "circonvenirei": "circonvenire",
    "circonveniremmo": "circonvenire",
    "circonveniremo": "circonvenire",
    "circonvenireste": "circonvenire",
    "circonveniresti": "circonvenire",
    "circonvenirete": "circonvenire",
    "circonveniron": "circonvenire",
    "circonvenirono": "circonvenire",
    "circonvenirà": "circonvenire",
    "circonvenirò": "circonvenire",
    "circonvenisse": "circonvenire",
    "circonvenisser": "circonvenire",
    "circonvenissero": "circonvenire",
    "circonvenissi": "circonvenire",
    "circonvenissimo": "circonvenire",
    "circonveniste": "circonvenire",
    "circonvenisti": "circonvenire",
    "circonvenita": "circonvenire",
    "circonvenite": "circonvenire",
    "circonveniti": "circonvenire",
    "circonvenito": "circonvenire",
    "circonveniva": "circonvenire",
    "circonvenivamo": "circonvenire",
    "circonvenivan": "circonvenire",
    "circonvenivano": "circonvenire",
    "circonvenivate": "circonvenire",
    "circonvenivi": "circonvenire",
    "circonvenivo": "circonvenire",
    "circonveno": "circonvenire",
    "circonvenon": "circonvenire",
    "circonvenono": "circonvenire",
    "circonvenì": "circonvenire",
    "circonvicina": "circonvicino",
    "circonvicine": "circonvicino",
    "circonvicini": "circonvicino",
    "circoscrisse": "circoscrivere",
    "circoscrisser": "circoscrivere",
    "circoscrissero": "circoscrivere",
    "circoscrissi": "circoscrivere",
    "circoscritta": "circoscrivere",
    "circoscritte": "circoscrivere",
    "circoscritti": "circoscrivere",
    "circoscritto": "circoscrivere",
    "circoscriva": "circoscrivere",
    "circoscrivan": "circoscrivere",
    "circoscrivano": "circoscrivere",
    "circoscrive": "circoscrivere",
    "circoscrivemmo": "circoscrivere",
    "circoscrivendo": "circoscrivere",
    "circoscrivente": "circoscrivere",
    "circoscriventi": "circoscrivere",
    "circoscriver": "circoscrivere",
    "circoscriverai": "circoscrivere",
    "circoscriveran": "circoscrivere",
    "circoscriveranno": "circoscrivere",
    "circoscriverebbe": "circoscrivere",
    "circoscriverebber": "circoscrivere",
    "circoscriverebbero": "circoscrivere",
    "circoscriverei": "circoscrivere",
    "circoscriveremmo": "circoscrivere",
    "circoscriveremo": "circoscrivere",
    "circoscrivereste": "circoscrivere",
    "circoscriveresti": "circoscrivere",
    "circoscriverete": "circoscrivere",
    "circoscriverà": "circoscrivere",
    "circoscriverò": "circoscrivere",
    "circoscrivesse": "circoscrivere",
    "circoscrivesser": "circoscrivere",
    "circoscrivessero": "circoscrivere",
    "circoscrivessi": "circoscrivere",
    "circoscrivessimo": "circoscrivere",
    "circoscriveste": "circoscrivere",
    "circoscrivesti": "circoscrivere",
    "circoscrivete": "circoscrivere",
    "circoscriveva": "circoscrivere",
    "circoscrivevamo": "circoscrivere",
    "circoscrivevan": "circoscrivere",
    "circoscrivevano": "circoscrivere",
    "circoscrivevate": "circoscrivere",
    "circoscrivevi": "circoscrivere",
    "circoscrivevo": "circoscrivere",
    "circoscrivi": "circoscrivere",
    "circoscriviamo": "circoscrivere",
    "circoscriviate": "circoscrivere",
    "circoscrivibili": "circoscrivibile",
    "circoscrivo": "circoscrivere",
    "circoscrivon": "circoscrivere",
    "circoscrivono": "circoscrivere",
    "circoscrizionali": "circoscrizionale",
    "circoscrizioni": "circoscrizione",
    "circospetta": "circospetto",
    "circospette": "circospetto",
    "circospetti": "circospetto",
    "circospezioni": "circospezione",
    "circostanti": "circostante",
    "circostanze": "circostanza",
    "circostanzi": "circostanziare",
    "circostanzia": "circostanziare",
    "circostanziai": "circostanziare",
    "circostanziammo": "circostanziare",
    "circostanziamo": "circostanziare",
    "circostanzian": "circostanziare",
    "circostanziando": "circostanziare",
    "circostanziano": "circostanziare",
    "circostanziante": "circostanziare",
    "circostanzianti": "circostanziare",
    "circostanziar": "circostanziare",
    "circostanziaron": "circostanziare",
    "circostanziarono": "circostanziare",
    "circostanziasse": "circostanziare",
    "circostanziasser": "circostanziare",
    "circostanziassero": "circostanziare",
    "circostanziassi": "circostanziare",
    "circostanziassimo": "circostanziare",
    "circostanziaste": "circostanziare",
    "circostanziasti": "circostanziare",
    "circostanziata": "circostanziare",
    "circostanziate": "circostanziare",
    "circostanziati": "circostanziare",
    "circostanziato": "circostanziare",
    "circostanziava": "circostanziare",
    "circostanziavamo": "circostanziare",
    "circostanziavan": "circostanziare",
    "circostanziavano": "circostanziare",
    "circostanziavate": "circostanziare",
    "circostanziavi": "circostanziare",
    "circostanziavo": "circostanziare",
    "circostanzierai": "circostanziare",
    "circostanzieran": "circostanziare",
    "circostanzieranno": "circostanziare",
    "circostanzierebbe": "circostanziare",
    "circostanzierebber": "circostanziare",
    "circostanzierebbero": "circostanziare",
    "circostanzierei": "circostanziare",
    "circostanzieremmo": "circostanziare",
    "circostanzieremo": "circostanziare",
    "circostanziereste": "circostanziare",
    "circostanzieresti": "circostanziare",
    "circostanzierete": "circostanziare",
    "circostanzierà": "circostanziare",
    "circostanzierò": "circostanziare",
    "circostanzin": "circostanziare",
    "circostanzino": "circostanziare",
    "circostanzio": "circostanziare",
    "circostanziò": "circostanziare",
    "circuendo": "circuire",
    "circuente": "circuire",
    "circuenti": "circuire",
    "circuiamo": "circuire",
    "circuiate": "circuire",
    "circuii": "circuire",
    "circuimmo": "circuire",
    "circuir": "circuire",
    "circuirai": "circuire",
    "circuiran": "circuire",
    "circuiranno": "circuire",
    "circuirebbe": "circuire",
    "circuirebber": "circuire",
    "circuirebbero": "circuire",
    "circuirei": "circuire",
    "circuiremmo": "circuire",
    "circuiremo": "circuire",
    "circuireste": "circuire",
    "circuiresti": "circuire",
    "circuirete": "circuire",
    "circuiron": "circuire",
    "circuirono": "circuire",
    "circuirà": "circuire",
    "circuirò": "circuire",
    "circuisca": "circuire",
    "circuiscan": "circuire",
    "circuiscano": "circuire",
    "circuisce": "circuire",
    "circuisci": "circuire",
    "circuisco": "circuire",
    "circuiscon": "circuire",
    "circuiscono": "circuire",
    "circuisse": "circuire",
    "circuisser": "circuire",
    "circuissero": "circuire",
    "circuissi": "circuire",
    "circuissimo": "circuire",
    "circuiste": "circuire",
    "circuisti": "circuire",
    "circuita": "circuire",
    "circuitali": "circuitale",
    "circuite": "circuire",
    "circuiti": "circuito",
    "circuito": "circuire",
    "circuiva": "circuire",
    "circuivamo": "circuire",
    "circuivan": "circuire",
    "circuivano": "circuire",
    "circuivate": "circuire",
    "circuivi": "circuire",
    "circuivo": "circuire",
    "circumnaviga": "circumnavigare",
    "circumnavigai": "circumnavigare",
    "circumnavigammo": "circumnavigare",
    "circumnavigan": "circumnavigare",
    "circumnavigando": "circumnavigare",
    "circumnavigano": "circumnavigare",
    "circumnavigante": "circumnavigare",
    "circumnaviganti": "circumnavigare",
    "circumnavigar": "circumnavigare",
    "circumnavigaron": "circumnavigare",
    "circumnavigarono": "circumnavigare",
    "circumnavigasse": "circumnavigare",
    "circumnavigasser": "circumnavigare",
    "circumnavigassero": "circumnavigare",
    "circumnavigassi": "circumnavigare",
    "circumnavigassimo": "circumnavigare",
    "circumnavigaste": "circumnavigare",
    "circumnavigasti": "circumnavigare",
    "circumnavigata": "circumnavigare",
    "circumnavigate": "circumnavigare",
    "circumnavigati": "circumnavigare",
    "circumnavigato": "circumnavigare",
    "circumnavigava": "circumnavigare",
    "circumnavigavamo": "circumnavigare",
    "circumnavigavan": "circumnavigare",
    "circumnavigavano": "circumnavigare",
    "circumnavigavate": "circumnavigare",
    "circumnavigavi": "circumnavigare",
    "circumnavigavo": "circumnavigare",
    "circumnavigherai": "circumnavigare",
    "circumnavigheran": "circumnavigare",
    "circumnavigheranno": "circumnavigare",
    "circumnavigherebbe": "circumnavigare",
    "circumnavigherebber": "circumnavigare",
    "circumnavigherebbero": "circumnavigare",
    "circumnavigherei": "circumnavigare",
    "circumnavigheremmo": "circumnavigare",
    "circumnavigheremo": "circumnavigare",
    "circumnavighereste": "circumnavigare",
    "circumnavigheresti": "circumnavigare",
    "circumnavigherete": "circumnavigare",
    "circumnavigherà": "circumnavigare",
    "circumnavigherò": "circumnavigare",
    "circumnavighi": "circumnavigare",
    "circumnavighiamo": "circumnavigare",
    "circumnavighiate": "circumnavigare",
    "circumnavighin": "circumnavigare",
    "circumnavighino": "circumnavigare",
    "circumnavigo": "circumnavigare",
    "circumnavigò": "circumnavigare",
    "circumvesuviana": "circumvesuviano",
    "circumvesuviane": "circumvesuviano",
    "circumvesuviani": "circumvesuviano",
    "circuì": "circuire",
    "cirenea": "cireneo",
    "cirenee": "cireneo",
    "cirenei": "cireneo",
    "cirillica": "cirillico",
    "cirilliche": "cirillico",
    "cirillici": "cirillico",
    "cirinea": "cirineo",
    "cirinee": "cirineo",
    "cirinei": "cirineo",
    "cisgiordana": "cisgiordano",
    "cisgiordane": "cisgiordano",
    "cisgiordani": "cisgiordano",
    "cislina": "cislino",
    "cisline": "cislino",
    "cislini": "cislino",
    "cispadana": "cispadano",
    "cispadane": "cispadano",
    "cispadani": "cispadano",
    "cisposa": "cisposo",
    "cispose": "cisposo",
    "cisposi": "cisposo",
    "cistercensi": "cistercense",
    "cisti": "ciste",
    "cistica": "cistico",
    "cistiche": "cistico",
    "cistici": "cistico",
    "cistifellee": "cistifellea",
    "cistiti": "cistite",
    "cita": "citare",
    "citabili": "citabile",
    "citai": "citare",
    "citammo": "citare",
    "citan": "citare",
    "citando": "citare",
    "citano": "citare",
    "citante": "citare",
    "citanti": "citare",
    "citar": "citare",
    "citaron": "citare",
    "citarono": "citare",
    "citasse": "citare",
    "citasser": "citare",
    "citassero": "citare",
    "citassi": "citare",
    "citassimo": "citare",
    "citaste": "citare",
    "citasti": "citare",
    "citata": "citato",
    "citate": "citato",
    "citati": "citato",
    "citato": "citare",
    "citava": "citare",
    "citavamo": "citare",
    "citavan": "citare",
    "citavano": "citare",
    "citavate": "citare",
    "citavi": "citare",
    "citavo": "citare",
    "citazionali": "citazionale",
    "citazioni": "citazione",
    "citazionistica": "citazionistico",
    "citazionistiche": "citazionistico",
    "citazionistici": "citazionistico",
    "citerai": "citare",
    "citeran": "citare",
    "citeranno": "citare",
    "citerebbe": "citare",
    "citerebber": "citare",
    "citerebbero": "citare",
    "citerei": "citare",
    "citeremmo": "citare",
    "citeremo": "citare",
    "citereste": "citare",
    "citeresti": "citare",
    "citerete": "citare",
    "citerà": "citare",
    "citerò": "citare",
    "citi": "citare",
    "citiamo": "citare",
    "citiate": "citare",
    "citin": "citare",
    "citino": "citare",
    "cito": "citare",
    "citofona": "citofonare",
    "citofonai": "citofonare",
    "citofonammo": "citofonare",
    "citofonan": "citofonare",
    "citofonando": "citofonare",
    "citofonano": "citofonare",
    "citofonante": "citofonare",
    "citofonanti": "citofonare",
    "citofonar": "citofonare",
    "citofonaron": "citofonare",
    "citofonarono": "citofonare",
    "citofonasse": "citofonare",
    "citofonasser": "citofonare",
    "citofonassero": "citofonare",
    "citofonassi": "citofonare",
    "citofonassimo": "citofonare",
    "citofonaste": "citofonare",
    "citofonasti": "citofonare",
    "citofonata": "citofonare",
    "citofonate": "citofonare",
    "citofonati": "citofonare",
    "citofonato": "citofonare",
    "citofonava": "citofonare",
    "citofonavamo": "citofonare",
    "citofonavan": "citofonare",
    "citofonavano": "citofonare",
    "citofonavate": "citofonare",
    "citofonavi": "citofonare",
    "citofonavo": "citofonare",
    "citofonerai": "citofonare",
    "citofoneran": "citofonare",
    "citofoneranno": "citofonare",
    "citofonerebbe": "citofonare",
    "citofonerebber": "citofonare",
    "citofonerebbero": "citofonare",
    "citofonerei": "citofonare",
    "citofoneremmo": "citofonare",
    "citofoneremo": "citofonare",
    "citofonereste": "citofonare",
    "citofoneresti": "citofonare",
    "citofonerete": "citofonare",
    "citofonerà": "citofonare",
    "citofonerò": "citofonare",
    "citofoni": "citofono",
    "citofoniamo": "citofonare",
    "citofoniate": "citofonare",
    "citofonin": "citofonare",
    "citofonino": "citofonare",
    "citofono": "citofonare",
    "citofonò": "citofonare",
    "citotossica": "citotossico",
    "citotossiche": "citotossico",
    "citotossici": "citotossico",
    "citrica": "citrico",
    "citriche": "citrico",
    "citrici": "citrico",
    "cittadelle": "cittadella",
    "cittadina": "cittadino",
    "cittadinanze": "cittadinanza",
    "cittadine": "cittadino",
    "cittadini": "cittadino",
    "cittadini-elettori": "cittadino-elettore",
    "citò": "citare",
    "ciuccerai": "ciucciare",
    "ciucceran": "ciucciare",
    "ciucceranno": "ciucciare",
    "ciuccerebbe": "ciucciare",
    "ciuccerebber": "ciucciare",
    "ciuccerebbero": "ciucciare",
    "ciuccerei": "ciucciare",
    "ciucceremmo": "ciucciare",
    "ciucceremo": "ciucciare",
    "ciuccereste": "ciucciare",
    "ciucceresti": "ciucciare",
    "ciuccerete": "ciucciare",
    "ciuccerà": "ciucciare",
    "ciuccerò": "ciucciare",
    "ciucci": "ciuccio",
    "ciuccia": "ciucciare",
    "ciucciai": "ciucciare",
    "ciucciammo": "ciucciare",
    "ciucciamo": "ciucciare",
    "ciuccian": "ciucciare",
    "ciucciando": "ciucciare",
    "ciucciano": "ciucciare",
    "ciucciante": "ciucciare",
    "ciuccianti": "ciucciare",
    "ciucciar": "ciucciare",
    "ciucciaron": "ciucciare",
    "ciucciarono": "ciucciare",
    "ciucciasse": "ciucciare",
    "ciucciasser": "ciucciare",
    "ciucciassero": "ciucciare",
    "ciucciassi": "ciucciare",
    "ciucciassimo": "ciucciare",
    "ciucciaste": "ciucciare",
    "ciucciasti": "ciucciare",
    "ciucciata": "ciucciare",
    "ciucciate": "ciucciare",
    "ciucciati": "ciucciare",
    "ciucciato": "ciucciare",
    "ciucciava": "ciucciare",
    "ciucciavamo": "ciucciare",
    "ciucciavan": "ciucciare",
    "ciucciavano": "ciucciare",
    "ciucciavate": "ciucciare",
    "ciucciavi": "ciucciare",
    "ciucciavo": "ciucciare",
    "ciuccin": "ciucciare",
    "ciuccino": "ciucciare",
    "ciuccio": "ciucciare",
    "ciucciò": "ciucciare",
    "ciuffi": "ciuffo",
    "ciurla": "ciurlare",
    "ciurlai": "ciurlare",
    "ciurlammo": "ciurlare",
    "ciurlan": "ciurlare",
    "ciurlando": "ciurlare",
    "ciurlano": "ciurlare",
    "ciurlante": "ciurlare",
    "ciurlanti": "ciurlare",
    "ciurlar": "ciurlare",
    "ciurlaron": "ciurlare",
    "ciurlarono": "ciurlare",
    "ciurlasse": "ciurlare",
    "ciurlasser": "ciurlare",
    "ciurlassero": "ciurlare",
    "ciurlassi": "ciurlare",
    "ciurlassimo": "ciurlare",
    "ciurlaste": "ciurlare",
    "ciurlasti": "ciurlare",
    "ciurlata": "ciurlare",
    "ciurlate": "ciurlare",
    "ciurlati": "ciurlare",
    "ciurlato": "ciurlare",
    "ciurlava": "ciurlare",
    "ciurlavamo": "ciurlare",
    "ciurlavan": "ciurlare",
    "ciurlavano": "ciurlare",
    "ciurlavate": "ciurlare",
    "ciurlavi": "ciurlare",
    "ciurlavo": "ciurlare",
    "ciurlerai": "ciurlare",
    "ciurleran": "ciurlare",
    "ciurleranno": "ciurlare",
    "ciurlerebbe": "ciurlare",
    "ciurlerebber": "ciurlare",
    "ciurlerebbero": "ciurlare",
    "ciurlerei": "ciurlare",
    "ciurleremmo": "ciurlare",
    "ciurleremo": "ciurlare",
    "ciurlereste": "ciurlare",
    "ciurleresti": "ciurlare",
    "ciurlerete": "ciurlare",
    "ciurlerà": "ciurlare",
    "ciurlerò": "ciurlare",
    "ciurli": "ciurlare",
    "ciurliamo": "ciurlare",
    "ciurliate": "ciurlare",
    "ciurlin": "ciurlare",
    "ciurlino": "ciurlare",
    "ciurlo": "ciurlare",
    "ciurlò": "ciurlare",
    "ciurma": "ciurmare",
    "ciurmai": "ciurmare",
    "ciurmammo": "ciurmare",
    "ciurman": "ciurmare",
    "ciurmando": "ciurmare",
    "ciurmano": "ciurmare",
    "ciurmante": "ciurmare",
    "ciurmanti": "ciurmare",
    "ciurmar": "ciurmare",
    "ciurmaron": "ciurmare",
    "ciurmarono": "ciurmare",
    "ciurmasse": "ciurmare",
    "ciurmasser": "ciurmare",
    "ciurmassero": "ciurmare",
    "ciurmassi": "ciurmare",
    "ciurmassimo": "ciurmare",
    "ciurmaste": "ciurmare",
    "ciurmasti": "ciurmare",
    "ciurmata": "ciurmare",
    "ciurmate": "ciurmare",
    "ciurmati": "ciurmare",
    "ciurmato": "ciurmare",
    "ciurmava": "ciurmare",
    "ciurmavamo": "ciurmare",
    "ciurmavan": "ciurmare",
    "ciurmavano": "ciurmare",
    "ciurmavate": "ciurmare",
    "ciurmavi": "ciurmare",
    "ciurmavo": "ciurmare",
    "ciurme": "ciurma",
    "ciurmerai": "ciurmare",
    "ciurmeran": "ciurmare",
    "ciurmeranno": "ciurmare",
    "ciurmerebbe": "ciurmare",
    "ciurmerebber": "ciurmare",
    "ciurmerebbero": "ciurmare",
    "ciurmerei": "ciurmare",
    "ciurmeremmo": "ciurmare",
    "ciurmeremo": "ciurmare",
    "ciurmereste": "ciurmare",
    "ciurmeresti": "ciurmare",
    "ciurmerete": "ciurmare",
    "ciurmerà": "ciurmare",
    "ciurmerò": "ciurmare",
    "ciurmi": "ciurmare",
    "ciurmiamo": "ciurmare",
    "ciurmiate": "ciurmare",
    "ciurmin": "ciurmare",
    "ciurmino": "ciurmare",
    "ciurmo": "ciurmare",
    "ciurmò": "ciurmare",
    "civetta": "civettare",
    "civettai": "civettare",
    "civettammo": "civettare",
    "civettan": "civettare",
    "civettando": "civettare",
    "civettano": "civettare",
    "civettante": "civettare",
    "civettanti": "civettare",
    "civettar": "civettare",
    "civettaron": "civettare",
    "civettarono": "civettare",
    "civettasse": "civettare",
    "civettasser": "civettare",
    "civettassero": "civettare",
    "civettassi": "civettare",
    "civettassimo": "civettare",
    "civettaste": "civettare",
    "civettasti": "civettare",
    "civettata": "civettare",
    "civettate": "civettare",
    "civettati": "civettare",
    "civettato": "civettare",
    "civettava": "civettare",
    "civettavamo": "civettare",
    "civettavan": "civettare",
    "civettavano": "civettare",
    "civettavate": "civettare",
    "civettavi": "civettare",
    "civettavo": "civettare",
    "civette": "civetta",
    "civetterai": "civettare",
    "civetteran": "civettare",
    "civetteranno": "civettare",
    "civetterebbe": "civettare",
    "civetterebber": "civettare",
    "civetterebbero": "civettare",
    "civetterei": "civettare",
    "civetteremmo": "civettare",
    "civetteremo": "civettare",
    "civettereste": "civettare",
    "civetteresti": "civettare",
    "civetterete": "civettare",
    "civetterie": "civetteria",
    "civetterà": "civettare",
    "civetterò": "civettare",
    "civetti": "civettare",
    "civettiamo": "civettare",
    "civettiate": "civettare",
    "civettin": "civettare",
    "civettino": "civettare",
    "civetto": "civettare",
    "civettuola": "civettuolo",
    "civettuole": "civettuolo",
    "civettuoli": "civettuolo",
    "civettò": "civettare",
    "civica": "civico",
    "civiche": "civico",
    "civici": "civico",
    "civili": "civile",
    "civilisti": "civilista",
    "civilistica": "civilistico",
    "civilistiche": "civilistico",
    "civilistici": "civilistico",
    "civilizza": "civilizzare",
    "civilizzai": "civilizzare",
    "civilizzammo": "civilizzare",
    "civilizzan": "civilizzare",
    "civilizzando": "civilizzare",
    "civilizzano": "civilizzare",
    "civilizzante": "civilizzare",
    "civilizzanti": "civilizzare",
    "civilizzar": "civilizzare",
    "civilizzaron": "civilizzare",
    "civilizzarono": "civilizzare",
    "civilizzasse": "civilizzare",
    "civilizzasser": "civilizzare",
    "civilizzassero": "civilizzare",
    "civilizzassi": "civilizzare",
    "civilizzassimo": "civilizzare",
    "civilizzaste": "civilizzare",
    "civilizzasti": "civilizzare",
    "civilizzata": "civilizzare",
    "civilizzate": "civilizzare",
    "civilizzati": "civilizzare",
    "civilizzato": "civilizzare",
    "civilizzava": "civilizzare",
    "civilizzavamo": "civilizzare",
    "civilizzavan": "civilizzare",
    "civilizzavano": "civilizzare",
    "civilizzavate": "civilizzare",
    "civilizzavi": "civilizzare",
    "civilizzavo": "civilizzare",
    "civilizzazioni": "civilizzazione",
    "civilizzerai": "civilizzare",
    "civilizzeran": "civilizzare",
    "civilizzeranno": "civilizzare",
    "civilizzerebbe": "civilizzare",
    "civilizzerebber": "civilizzare",
    "civilizzerebbero": "civilizzare",
    "civilizzerei": "civilizzare",
    "civilizzeremmo": "civilizzare",
    "civilizzeremo": "civilizzare",
    "civilizzereste": "civilizzare",
    "civilizzeresti": "civilizzare",
    "civilizzerete": "civilizzare",
    "civilizzerà": "civilizzare",
    "civilizzerò": "civilizzare",
    "civilizzi": "civilizzare",
    "civilizziamo": "civilizzare",
    "civilizziate": "civilizzare",
    "civilizzin": "civilizzare",
    "civilizzino": "civilizzare",
    "civilizzo": "civilizzare",
    "civilizzò": "civilizzare",
    "clamori": "clamore",
    "clamorosa": "clamoroso",
    "clamorose": "clamoroso",
    "clamorosi": "clamoroso",
    "clandestina": "clandestino",
    "clandestine": "clandestino",
    "clandestini": "clandestino",
    "clangori": "clangore",
    "clarinetti": "clarinetto",
    "clarinettisti": "clarinettista",
    "classamenti": "classamento",
    "classi": "classe",
    "classica": "classico",
    "classiche": "classico",
    "classicheggerai": "classicheggiare",
    "classicheggeran": "classicheggiare",
    "classicheggeranno": "classicheggiare",
    "classicheggerebbe": "classicheggiare",
    "classicheggerebber": "classicheggiare",
    "classicheggerebbero": "classicheggiare",
    "classicheggerei": "classicheggiare",
    "classicheggeremmo": "classicheggiare",
    "classicheggeremo": "classicheggiare",
    "classicheggereste": "classicheggiare",
    "classicheggeresti": "classicheggiare",
    "classicheggerete": "classicheggiare",
    "classicheggerà": "classicheggiare",
    "classicheggerò": "classicheggiare",
    "classicheggi": "classicheggiare",
    "classicheggia": "classicheggiare",
    "classicheggiai": "classicheggiare",
    "classicheggiammo": "classicheggiare",
    "classicheggiamo": "classicheggiare",
    "classicheggian": "classicheggiare",
    "classicheggiando": "classicheggiare",
    "classicheggiano": "classicheggiare",
    "classicheggiante": "classicheggiare",
    "classicheggianti": "classicheggiare",
    "classicheggiar": "classicheggiare",
    "classicheggiaron": "classicheggiare",
    "classicheggiarono": "classicheggiare",
    "classicheggiasse": "classicheggiare",
    "classicheggiasser": "classicheggiare",
    "classicheggiassero": "classicheggiare",
    "classicheggiassi": "classicheggiare",
    "classicheggiassimo": "classicheggiare",
    "classicheggiaste": "classicheggiare",
    "classicheggiasti": "classicheggiare",
    "classicheggiata": "classicheggiare",
    "classicheggiate": "classicheggiare",
    "classicheggiati": "classicheggiare",
    "classicheggiato": "classicheggiare",
    "classicheggiava": "classicheggiare",
    "classicheggiavamo": "classicheggiare",
    "classicheggiavan": "classicheggiare",
    "classicheggiavano": "classicheggiare",
    "classicheggiavate": "classicheggiare",
    "classicheggiavi": "classicheggiare",
    "classicheggiavo": "classicheggiare",
    "classicheggin": "classicheggiare",
    "classicheggino": "classicheggiare",
    "classicheggio": "classicheggiare",
    "classicheggiò": "classicheggiare",
    "classici": "classico",
    "classicismi": "classicismo",
    "classicisti": "classicista",
    "classicistica": "classicistico",
    "classicistiche": "classicistico",
    "classicistici": "classicistico",
    "classico-accademica": "classico-accademico",
    "classico-accademiche": "classico-accademico",
    "classico-accademici": "classico-accademico",
    "classico-romantica": "classico-romantico",
    "classico-romantiche": "classico-romantico",
    "classico-romantici": "classico-romantico",
    "classico-umanistica": "classico-umanistico",
    "classico-umanistiche": "classico-umanistico",
    "classico-umanistici": "classico-umanistico",
    "classifica": "classificare",
    "classificabili": "classificabile",
    "classificai": "classificare",
    "classificammo": "classificare",
    "classifican": "classificare",
    "classificando": "classificare",
    "classificano": "classificare",
    "classificante": "classificare",
    "classificanti": "classificare",
    "classificar": "classificare",
    "classificaron": "classificare",
    "classificarono": "classificare",
    "classificasse": "classificare",
    "classificasser": "classificare",
    "classificassero": "classificare",
    "classificassi": "classificare",
    "classificassimo": "classificare",
    "classificaste": "classificare",
    "classificasti": "classificare",
    "classificata": "classificare",
    "classificate": "classificata",
    "classificati": "classificare",
    "classificato": "classificare",
    "classificatori": "classificatore",
    "classificava": "classificare",
    "classificavamo": "classificare",
    "classificavan": "classificare",
    "classificavano": "classificare",
    "classificavate": "classificare",
    "classificavi": "classificare",
    "classificavo": "classificare",
    "classificazioni": "classificazione",
    "classifiche": "classifica",
    "classificherai": "classificare",
    "classificheran": "classificare",
    "classificheranno": "classificare",
    "classificherebbe": "classificare",
    "classificherebber": "classificare",
    "classificherebbero": "classificare",
    "classificherei": "classificare",
    "classificheremmo": "classificare",
    "classificheremo": "classificare",
    "classifichereste": "classificare",
    "classificheresti": "classificare",
    "classificherete": "classificare",
    "classificherà": "classificare",
    "classificherò": "classificare",
    "classifichi": "classificare",
    "classifichiamo": "classificare",
    "classifichiate": "classificare",
    "classifichin": "classificare",
    "classifichino": "classificare",
    "classifico": "classificare",
    "classificò": "classificare",
    "classista": "classisto",
    "classiste": "classisto",
    "classisti": "classisto",
    "claudica": "claudicare",
    "claudicai": "claudicare",
    "claudicammo": "claudicare",
    "claudican": "claudicare",
    "claudicando": "claudicare",
    "claudicano": "claudicare",
    "claudicante": "claudicare",
    "claudicanti": "claudicare",
    "claudicar": "claudicare",
    "claudicaron": "claudicare",
    "claudicarono": "claudicare",
    "claudicasse": "claudicare",
    "claudicasser": "claudicare",
    "claudicassero": "claudicare",
    "claudicassi": "claudicare",
    "claudicassimo": "claudicare",
    "claudicaste": "claudicare",
    "claudicasti": "claudicare",
    "claudicata": "claudicare",
    "claudicate": "claudicare",
    "claudicati": "claudicare",
    "claudicato": "claudicare",
    "claudicava": "claudicare",
    "claudicavamo": "claudicare",
    "claudicavan": "claudicare",
    "claudicavano": "claudicare",
    "claudicavate": "claudicare",
    "claudicavi": "claudicare",
    "claudicavo": "claudicare",
    "claudicherai": "claudicare",
    "claudicheran": "claudicare",
    "claudicheranno": "claudicare",
    "claudicherebbe": "claudicare",
    "claudicherebber": "claudicare",
    "claudicherebbero": "claudicare",
    "claudicherei": "claudicare",
    "claudicheremmo": "claudicare",
    "claudicheremo": "claudicare",
    "claudichereste": "claudicare",
    "claudicheresti": "claudicare",
    "claudicherete": "claudicare",
    "claudicherà": "claudicare",
    "claudicherò": "claudicare",
    "claudichi": "claudicare",
    "claudichiamo": "claudicare",
    "claudichiate": "claudicare",
    "claudichin": "claudicare",
    "claudichino": "claudicare",
    "claudico": "claudicare",
    "claudicò": "claudicare",
    "clausole": "clausola",
    "claustrali": "claustrale",
    "claustrofobica": "claustrofobico",
    "claustrofobiche": "claustrofobico",
    "claustrofobici": "claustrofobico",
    "claustrofobie": "claustrofobia",
    "clausure": "clausura",
    "clave": "clava",
    "clavicembali": "clavicembalo",
    "clavicole": "clavicola",
    "clementi": "clemente",
    "clemenze": "clemenza",
    "clerical-calcistica": "clerical-calcistico",
    "clerical-calcistiche": "clerical-calcistico",
    "clerical-calcistici": "clerical-calcistico",
    "clericali": "clericale",
    "clericalismi": "clericalismo",
    "clerico-autoritari": "clerico-autoritario",
    "clerico-autoritaria": "clerico-autoritario",
    "clerico-autoritarie": "clerico-autoritario",
    "clerico-fasciste": "clerico-fascista",
    "clerico-fascisti": "clerico-fascista",
    "clerico-liberali": "clerico-liberale",
    "clerico-reazionari": "clerico-reazionario",
    "clerico-reazionaria": "clerico-reazionario",
    "clerico-reazionarie": "clerico-reazionario",
    "clericofasciste": "clericofascista",
    "clericofascisti": "clericofascista",
    "clericomoderata": "clericomoderato",
    "clericomoderate": "clericomoderato",
    "clericomoderati": "clericomoderato",
    "clessidre": "clessidra",
    "clicca": "cliccare",
    "cliccai": "cliccare",
    "cliccammo": "cliccare",
    "cliccan": "cliccare",
    "cliccando": "cliccare",
    "cliccano": "cliccare",
    "cliccante": "cliccare",
    "cliccanti": "cliccare",
    "cliccar": "cliccare",
    "cliccaron": "cliccare",
    "cliccarono": "cliccare",
    "cliccasse": "cliccare",
    "cliccasser": "cliccare",
    "cliccassero": "cliccare",
    "cliccassi": "cliccare",
    "cliccassimo": "cliccare",
    "cliccaste": "cliccare",
    "cliccasti": "cliccare",
    "cliccata": "cliccato",
    "cliccate": "cliccato",
    "cliccati": "cliccato",
    "cliccato": "cliccare",
    "cliccava": "cliccare",
    "cliccavamo": "cliccare",
    "cliccavan": "cliccare",
    "cliccavano": "cliccare",
    "cliccavate": "cliccare",
    "cliccavi": "cliccare",
    "cliccavo": "cliccare",
    "cliccherai": "cliccare",
    "cliccheran": "cliccare",
    "cliccheranno": "cliccare",
    "cliccherebbe": "cliccare",
    "cliccherebber": "cliccare",
    "cliccherebbero": "cliccare",
    "cliccherei": "cliccare",
    "cliccheremmo": "cliccare",
    "cliccheremo": "cliccare",
    "clicchereste": "cliccare",
    "cliccheresti": "cliccare",
    "cliccherete": "cliccare",
    "cliccherà": "cliccare",
    "cliccherò": "cliccare",
    "clicchi": "cliccare",
    "clicchiamo": "cliccare",
    "clicchiate": "cliccare",
    "clicchin": "cliccare",
    "clicchino": "cliccare",
    "clicco": "cliccare",
    "cliccò": "cliccare",
    "clientelari": "clientelare",
    "clientele": "clientela",
    "clientelismi": "clientelismo",
    "clienti": "cliente",
    "climatica": "climatico",
    "climatiche": "climatico",
    "climatici": "climatico",
    "climatizza": "climatizzare",
    "climatizzai": "climatizzare",
    "climatizzammo": "climatizzare",
    "climatizzan": "climatizzare",
    "climatizzando": "climatizzare",
    "climatizzano": "climatizzare",
    "climatizzante": "climatizzare",
    "climatizzanti": "climatizzare",
    "climatizzar": "climatizzare",
    "climatizzaron": "climatizzare",
    "climatizzarono": "climatizzare",
    "climatizzasse": "climatizzare",
    "climatizzasser": "climatizzare",
    "climatizzassero": "climatizzare",
    "climatizzassi": "climatizzare",
    "climatizzassimo": "climatizzare",
    "climatizzaste": "climatizzare",
    "climatizzasti": "climatizzare",
    "climatizzata": "climatizzare",
    "climatizzate": "climatizzare",
    "climatizzati": "climatizzare",
    "climatizzato": "climatizzare",
    "climatizzatori": "climatizzatore",
    "climatizzava": "climatizzare",
    "climatizzavamo": "climatizzare",
    "climatizzavan": "climatizzare",
    "climatizzavano": "climatizzare",
    "climatizzavate": "climatizzare",
    "climatizzavi": "climatizzare",
    "climatizzavo": "climatizzare",
    "climatizzazioni": "climatizzazione",
    "climatizzerai": "climatizzare",
    "climatizzeran": "climatizzare",
    "climatizzeranno": "climatizzare",
    "climatizzerebbe": "climatizzare",
    "climatizzerebber": "climatizzare",
    "climatizzerebbero": "climatizzare",
    "climatizzerei": "climatizzare",
    "climatizzeremmo": "climatizzare",
    "climatizzeremo": "climatizzare",
    "climatizzereste": "climatizzare",
    "climatizzeresti": "climatizzare",
    "climatizzerete": "climatizzare",
    "climatizzerà": "climatizzare",
    "climatizzerò": "climatizzare",
    "climatizzi": "climatizzare",
    "climatizziamo": "climatizzare",
    "climatizziate": "climatizzare",
    "climatizzin": "climatizzare",
    "climatizzino": "climatizzare",
    "climatizzo": "climatizzare",
    "climatizzò": "climatizzare",
    "climatologi": "climatologo",
    "climatologica": "climatologico",
    "climatologiche": "climatologico",
    "climatologici": "climatologico",
    "climi": "clima",
    "clinica": "clinico",
    "cliniche": "clinico",
    "clinici": "clinico",
    "clinico-epidemiologica": "clinico-epidemiologico",
    "clinico-epidemiologiche": "clinico-epidemiologico",
    "clinico-epidemiologici": "clinico-epidemiologico",
    "clinico-sanitari": "clinico-sanitario",
    "clinico-sanitaria": "clinico-sanitario",
    "clinico-sanitarie": "clinico-sanitario",
    "clinico-universitari": "clinico-universitario",
    "clinico-universitaria": "clinico-universitario",
    "clinico-universitarie": "clinico-universitario",
    "clintonesca": "clintonesco",
    "clintonesche": "clintonesco",
    "clintoneschi": "clintonesco",
    "clintoniana": "clintoniano",
    "clintoniane": "clintoniano",
    "clintoniani": "clintoniano",
    "clisteri": "clistere",
    "clitoridea": "clitorideo",
    "clitoridee": "clitorideo",
    "clitoridei": "clitorideo",
    "cloache": "cloaca",
    "cloches": "cloche",
    "clona": "clonare",
    "clonai": "clonare",
    "clonammo": "clonare",
    "clonan": "clonare",
    "clonando": "clonare",
    "clonano": "clonare",
    "clonante": "clonare",
    "clonanti": "clonare",
    "clonar": "clonare",
    "clonaron": "clonare",
    "clonarono": "clonare",
    "clonasse": "clonare",
    "clonasser": "clonare",
    "clonassero": "clonare",
    "clonassi": "clonare",
    "clonassimo": "clonare",
    "clonaste": "clonare",
    "clonasti": "clonare",
    "clonata": "clonare",
    "clonate": "clonare",
    "clonati": "clonare",
    "clonato": "clonare",
    "clonava": "clonare",
    "clonavamo": "clonare",
    "clonavan": "clonare",
    "clonavano": "clonare",
    "clonavate": "clonare",
    "clonavi": "clonare",
    "clonavo": "clonare",
    "clonazioni": "clonazione",
    "clonerai": "clonare",
    "cloneran": "clonare",
    "cloneranno": "clonare",
    "clonerebbe": "clonare",
    "clonerebber": "clonare",
    "clonerebbero": "clonare",
    "clonerei": "clonare",
    "cloneremmo": "clonare",
    "cloneremo": "clonare",
    "clonereste": "clonare",
    "cloneresti": "clonare",
    "clonerete": "clonare",
    "clonerà": "clonare",
    "clonerò": "clonare",
    "cloni": "clone",
    "cloniamo": "clonare",
    "cloniate": "clonare",
    "clonin": "clonare",
    "clonino": "clonare",
    "clono": "clonare",
    "clonò": "clonare",
    "clori": "cloro",
    "cloroformizza": "cloroformizzare",
    "cloroformizzai": "cloroformizzare",
    "cloroformizzammo": "cloroformizzare",
    "cloroformizzan": "cloroformizzare",
    "cloroformizzando": "cloroformizzare",
    "cloroformizzano": "cloroformizzare",
    "cloroformizzante": "cloroformizzare",
    "cloroformizzanti": "cloroformizzare",
    "cloroformizzar": "cloroformizzare",
    "cloroformizzaron": "cloroformizzare",
    "cloroformizzarono": "cloroformizzare",
    "cloroformizzasse": "cloroformizzare",
    "cloroformizzasser": "cloroformizzare",
    "cloroformizzassero": "cloroformizzare",
    "cloroformizzassi": "cloroformizzare",
    "cloroformizzassimo": "cloroformizzare",
    "cloroformizzaste": "cloroformizzare",
    "cloroformizzasti": "cloroformizzare",
    "cloroformizzata": "cloroformizzare",
    "cloroformizzate": "cloroformizzare",
    "cloroformizzati": "cloroformizzare",
    "cloroformizzato": "cloroformizzare",
    "cloroformizzava": "cloroformizzare",
    "cloroformizzavamo": "cloroformizzare",
    "cloroformizzavan": "cloroformizzare",
    "cloroformizzavano": "cloroformizzare",
    "cloroformizzavate": "cloroformizzare",
    "cloroformizzavi": "cloroformizzare",
    "cloroformizzavo": "cloroformizzare",
    "cloroformizzerai": "cloroformizzare",
    "cloroformizzeran": "cloroformizzare",
    "cloroformizzeranno": "cloroformizzare",
    "cloroformizzerebbe": "cloroformizzare",
    "cloroformizzerebber": "cloroformizzare",
    "cloroformizzerebbero": "cloroformizzare",
    "cloroformizzerei": "cloroformizzare",
    "cloroformizzeremmo": "cloroformizzare",
    "cloroformizzeremo": "cloroformizzare",
    "cloroformizzereste": "cloroformizzare",
    "cloroformizzeresti": "cloroformizzare",
    "cloroformizzerete": "cloroformizzare",
    "cloroformizzerà": "cloroformizzare",
    "cloroformizzerò": "cloroformizzare",
    "cloroformizzi": "cloroformizzare",
    "cloroformizziamo": "cloroformizzare",
    "cloroformizziate": "cloroformizzare",
    "cloroformizzin": "cloroformizzare",
    "cloroformizzino": "cloroformizzare",
    "cloroformizzo": "cloroformizzare",
    "cloroformizzò": "cloroformizzare",
    "clorotica": "clorotico",
    "clorotiche": "clorotico",
    "clorotici": "clorotico",
    "clorura": "clorurare",
    "clorurai": "clorurare",
    "clorurammo": "clorurare",
    "cloruran": "clorurare",
    "clorurando": "clorurare",
    "clorurano": "clorurare",
    "clorurante": "clorurare",
    "cloruranti": "clorurare",
    "clorurar": "clorurare",
    "cloruraron": "clorurare",
    "clorurarono": "clorurare",
    "clorurasse": "clorurare",
    "clorurasser": "clorurare",
    "clorurassero": "clorurare",
    "clorurassi": "clorurare",
    "clorurassimo": "clorurare",
    "cloruraste": "clorurare",
    "clorurasti": "clorurare",
    "clorurata": "clorurare",
    "clorurate": "clorurare",
    "clorurati": "clorurare",
    "clorurato": "clorurare",
    "clorurava": "clorurare",
    "cloruravamo": "clorurare",
    "cloruravan": "clorurare",
    "cloruravano": "clorurare",
    "cloruravate": "clorurare",
    "cloruravi": "clorurare",
    "cloruravo": "clorurare",
    "clorurerai": "clorurare",
    "clorureran": "clorurare",
    "clorureranno": "clorurare",
    "clorurerebbe": "clorurare",
    "clorurerebber": "clorurare",
    "clorurerebbero": "clorurare",
    "clorurerei": "clorurare",
    "clorureremmo": "clorurare",
    "clorureremo": "clorurare",
    "clorurereste": "clorurare",
    "clorureresti": "clorurare",
    "clorurerete": "clorurare",
    "clorurerà": "clorurare",
    "clorurerò": "clorurare",
    "cloruri": "clorurare",
    "cloruriamo": "clorurare",
    "cloruriate": "clorurare",
    "clorurin": "clorurare",
    "clorurino": "clorurare",
    "cloruro": "clorurare",
    "clorurò": "clorurare",
    "clownesca": "clownesco",
    "clownesche": "clownesco",
    "clowneschi": "clownesco",
    "clubs": "club",
    "co-finanzi": "co-finanziare",
    "co-finanzia": "co-finanziare",
    "co-finanziai": "co-finanziare",
    "co-finanziammo": "co-finanziare",
    "co-finanziamo": "co-finanziare",
    "co-finanzian": "co-finanziare",
    "co-finanziando": "co-finanziare",
    "co-finanziano": "co-finanziare",
    "co-finanziante": "co-finanziare",
    "co-finanzianti": "co-finanziare",
    "co-finanziar": "co-finanziare",
    "co-finanziaron": "co-finanziare",
    "co-finanziarono": "co-finanziare",
    "co-finanziasse": "co-finanziare",
    "co-finanziasser": "co-finanziare",
    "co-finanziassero": "co-finanziare",
    "co-finanziassi": "co-finanziare",
    "co-finanziassimo": "co-finanziare",
    "co-finanziaste": "co-finanziare",
    "co-finanziasti": "co-finanziare",
    "co-finanziata": "co-finanziare",
    "co-finanziate": "co-finanziare",
    "co-finanziati": "co-finanziare",
    "co-finanziato": "co-finanziare",
    "co-finanziava": "co-finanziare",
    "co-finanziavamo": "co-finanziare",
    "co-finanziavan": "co-finanziare",
    "co-finanziavano": "co-finanziare",
    "co-finanziavate": "co-finanziare",
    "co-finanziavi": "co-finanziare",
    "co-finanziavo": "co-finanziare",
    "co-finanzierai": "co-finanziare",
    "co-finanzieran": "co-finanziare",
    "co-finanzieranno": "co-finanziare",
    "co-finanzierebbe": "co-finanziare",
    "co-finanzierebber": "co-finanziare",
    "co-finanzierebbero": "co-finanziare",
    "co-finanzierei": "co-finanziare",
    "co-finanzieremmo": "co-finanziare",
    "co-finanzieremo": "co-finanziare",
    "co-finanziereste": "co-finanziare",
    "co-finanzieresti": "co-finanziare",
    "co-finanzierete": "co-finanziare",
    "co-finanzierà": "co-finanziare",
    "co-finanzierò": "co-finanziare",
    "co-finanzin": "co-finanziare",
    "co-finanzino": "co-finanziare",
    "co-finanzio": "co-finanziare",
    "co-finanziò": "co-finanziare",
    "co-fonda": "co-fondare",
    "co-fondai": "co-fondare",
    "co-fondammo": "co-fondare",
    "co-fondan": "co-fondare",
    "co-fondando": "co-fondare",
    "co-fondano": "co-fondare",
    "co-fondante": "co-fondare",
    "co-fondanti": "co-fondare",
    "co-fondar": "co-fondare",
    "co-fondaron": "co-fondare",
    "co-fondarono": "co-fondare",
    "co-fondasse": "co-fondare",
    "co-fondasser": "co-fondare",
    "co-fondassero": "co-fondare",
    "co-fondassi": "co-fondare",
    "co-fondassimo": "co-fondare",
    "co-fondaste": "co-fondare",
    "co-fondasti": "co-fondare",
    "co-fondata": "co-fondare",
    "co-fondate": "co-fondare",
    "co-fondati": "co-fondare",
    "co-fondato": "co-fondare",
    "co-fondava": "co-fondare",
    "co-fondavamo": "co-fondare",
    "co-fondavan": "co-fondare",
    "co-fondavano": "co-fondare",
    "co-fondavate": "co-fondare",
    "co-fondavi": "co-fondare",
    "co-fondavo": "co-fondare",
    "co-fonderai": "co-fondare",
    "co-fonderan": "co-fondare",
    "co-fonderanno": "co-fondare",
    "co-fonderebbe": "co-fondare",
    "co-fonderebber": "co-fondare",
    "co-fonderebbero": "co-fondare",
    "co-fonderei": "co-fondare",
    "co-fonderemmo": "co-fondare",
    "co-fonderemo": "co-fondare",
    "co-fondereste": "co-fondare",
    "co-fonderesti": "co-fondare",
    "co-fonderete": "co-fondare",
    "co-fonderà": "co-fondare",
    "co-fonderò": "co-fondare",
    "co-fondi": "co-fondare",
    "co-fondiamo": "co-fondare",
    "co-fondiate": "co-fondare",
    "co-fondin": "co-fondare",
    "co-fondino": "co-fondare",
    "co-fondo": "co-fondare",
    "co-fondò": "co-fondare",
    "co-piloti": "co-pilota",
    "co-presidenti": "co-presidente",
    "co-presieda": "co-presiedere",
    "co-presiedan": "co-presiedere",
    "co-presiedano": "co-presiedere",
    "co-presiede": "co-presiedere",
    "co-presiedei": "co-presiedere",
    "co-presiedemmo": "co-presiedere",
    "co-presiedendo": "co-presiedere",
    "co-presiedente": "co-presiedere",
    "co-presiedenti": "co-presiedere",
    "co-presieder": "co-presiedere",
    "co-presiederai": "co-presiedere",
    "co-presiederan": "co-presiedere",
    "co-presiederanno": "co-presiedere",
    "co-presiederebbe": "co-presiedere",
    "co-presiederebber": "co-presiedere",
    "co-presiederebbero": "co-presiedere",
    "co-presiederei": "co-presiedere",
    "co-presiederemmo": "co-presiedere",
    "co-presiederemo": "co-presiedere",
    "co-presiedereste": "co-presiedere",
    "co-presiederesti": "co-presiedere",
    "co-presiederete": "co-presiedere",
    "co-presiederon": "co-presiedere",
    "co-presiederono": "co-presiedere",
    "co-presiederà": "co-presiedere",
    "co-presiederò": "co-presiedere",
    "co-presiedesse": "co-presiedere",
    "co-presiedesser": "co-presiedere",
    "co-presiedessero": "co-presiedere",
    "co-presiedessi": "co-presiedere",
    "co-presiedessimo": "co-presiedere",
    "co-presiedeste": "co-presiedere",
    "co-presiedesti": "co-presiedere",
    "co-presiedete": "co-presiedere",
    "co-presiedeva": "co-presiedere",
    "co-presiedevamo": "co-presiedere",
    "co-presiedevan": "co-presiedere",
    "co-presiedevano": "co-presiedere",
    "co-presiedevate": "co-presiedere",
    "co-presiedevi": "co-presiedere",
    "co-presiedevo": "co-presiedere",
    "co-presiedi": "co-presiedere",
    "co-presiediamo": "co-presiedere",
    "co-presiediate": "co-presiedere",
    "co-presiedo": "co-presiedere",
    "co-presiedon": "co-presiedere",
    "co-presiedono": "co-presiedere",
    "co-presieduta": "co-presiedere",
    "co-presiedute": "co-presiedere",
    "co-presieduti": "co-presiedere",
    "co-presieduto": "co-presiedere",
    "co-presiedè": "co-presiedere",
    "co-produca": "co-produrre",
    "co-producan": "co-produrre",
    "co-producano": "co-produrre",
    "co-produce": "co-produrre",
    "co-producei": "co-produrre",
    "co-producemmo": "co-produrre",
    "co-producendo": "co-produrre",
    "co-producente": "co-produrre",
    "co-producenti": "co-produrre",
    "co-producerai": "co-produrre",
    "co-produceran": "co-produrre",
    "co-produceranno": "co-produrre",
    "co-producerebbe": "co-produrre",
    "co-producerebber": "co-produrre",
    "co-producerebbero": "co-produrre",
    "co-producerei": "co-produrre",
    "co-produceremmo": "co-produrre",
    "co-produceremo": "co-produrre",
    "co-producereste": "co-produrre",
    "co-produceresti": "co-produrre",
    "co-producerete": "co-produrre",
    "co-produceron": "co-produrre",
    "co-producerono": "co-produrre",
    "co-producerà": "co-produrre",
    "co-producerò": "co-produrre",
    "co-producesse": "co-produrre",
    "co-producesser": "co-produrre",
    "co-producessero": "co-produrre",
    "co-producessi": "co-produrre",
    "co-producessimo": "co-produrre",
    "co-produceste": "co-produrre",
    "co-producesti": "co-produrre",
    "co-producete": "co-produrre",
    "co-produceva": "co-produrre",
    "co-producevamo": "co-produrre",
    "co-producevan": "co-produrre",
    "co-producevano": "co-produrre",
    "co-producevate": "co-produrre",
    "co-producevi": "co-produrre",
    "co-producevo": "co-produrre",
    "co-produci": "co-produrre",
    "co-produciamo": "co-produrre",
    "co-produciate": "co-produrre",
    "co-produciuta": "co-produrre",
    "co-produciute": "co-produrre",
    "co-produciuti": "co-produrre",
    "co-produciuto": "co-produrre",
    "co-produco": "co-produrre",
    "co-producon": "co-produrre",
    "co-producono": "co-produrre",
    "co-producè": "co-produrre",
    "co-produrr": "co-produrre",
    "co-produzioni": "co-produzione",
    "co-protagonisti": "co-protagonista",
    "coabita": "coabitare",
    "coabitai": "coabitare",
    "coabitammo": "coabitare",
    "coabitan": "coabitare",
    "coabitando": "coabitare",
    "coabitano": "coabitare",
    "coabitante": "coabitare",
    "coabitanti": "coabitare",
    "coabitar": "coabitare",
    "coabitaron": "coabitare",
    "coabitarono": "coabitare",
    "coabitasse": "coabitare",
    "coabitasser": "coabitare",
    "coabitassero": "coabitare",
    "coabitassi": "coabitare",
    "coabitassimo": "coabitare",
    "coabitaste": "coabitare",
    "coabitasti": "coabitare",
    "coabitata": "coabitare",
    "coabitate": "coabitare",
    "coabitati": "coabitare",
    "coabitato": "coabitare",
    "coabitava": "coabitare",
    "coabitavamo": "coabitare",
    "coabitavan": "coabitare",
    "coabitavano": "coabitare",
    "coabitavate": "coabitare",
    "coabitavi": "coabitare",
    "coabitavo": "coabitare",
    "coabitazioni": "coabitazione",
    "coabiterai": "coabitare",
    "coabiteran": "coabitare",
    "coabiteranno": "coabitare",
    "coabiterebbe": "coabitare",
    "coabiterebber": "coabitare",
    "coabiterebbero": "coabitare",
    "coabiterei": "coabitare",
    "coabiteremmo": "coabitare",
    "coabiteremo": "coabitare",
    "coabitereste": "coabitare",
    "coabiteresti": "coabitare",
    "coabiterete": "coabitare",
    "coabiterà": "coabitare",
    "coabiterò": "coabitare",
    "coabiti": "coabitare",
    "coabitiamo": "coabitare",
    "coabitiate": "coabitare",
    "coabitin": "coabitare",
    "coabitino": "coabitare",
    "coabito": "coabitare",
    "coabitò": "coabitare",
    "coacervi": "coacervo",
    "coadiutori": "coadiutore",
    "coadiuva": "coadiuvare",
    "coadiuvai": "coadiuvare",
    "coadiuvammo": "coadiuvare",
    "coadiuvan": "coadiuvare",
    "coadiuvando": "coadiuvare",
    "coadiuvano": "coadiuvare",
    "coadiuvante": "coadiuvare",
    "coadiuvanti": "coadiuvare",
    "coadiuvar": "coadiuvare",
    "coadiuvaron": "coadiuvare",
    "coadiuvarono": "coadiuvare",
    "coadiuvasse": "coadiuvare",
    "coadiuvasser": "coadiuvare",
    "coadiuvassero": "coadiuvare",
    "coadiuvassi": "coadiuvare",
    "coadiuvassimo": "coadiuvare",
    "coadiuvaste": "coadiuvare",
    "coadiuvasti": "coadiuvare",
    "coadiuvata": "coadiuvare",
    "coadiuvate": "coadiuvare",
    "coadiuvati": "coadiuvare",
    "coadiuvato": "coadiuvare",
    "coadiuvava": "coadiuvare",
    "coadiuvavamo": "coadiuvare",
    "coadiuvavan": "coadiuvare",
    "coadiuvavano": "coadiuvare",
    "coadiuvavate": "coadiuvare",
    "coadiuvavi": "coadiuvare",
    "coadiuvavo": "coadiuvare",
    "coadiuverai": "coadiuvare",
    "coadiuveran": "coadiuvare",
    "coadiuveranno": "coadiuvare",
    "coadiuverebbe": "coadiuvare",
    "coadiuverebber": "coadiuvare",
    "coadiuverebbero": "coadiuvare",
    "coadiuverei": "coadiuvare",
    "coadiuveremmo": "coadiuvare",
    "coadiuveremo": "coadiuvare",
    "coadiuvereste": "coadiuvare",
    "coadiuveresti": "coadiuvare",
    "coadiuverete": "coadiuvare",
    "coadiuverà": "coadiuvare",
    "coadiuverò": "coadiuvare",
    "coadiuvi": "coadiuvare",
    "coadiuviamo": "coadiuvare",
    "coadiuviate": "coadiuvare",
    "coadiuvin": "coadiuvare",
    "coadiuvino": "coadiuvare",
    "coadiuvo": "coadiuvare",
    "coadiuvò": "coadiuvare",
    "coagula": "coagulare",
    "coagulai": "coagulare",
    "coagulammo": "coagulare",
    "coagulan": "coagulare",
    "coagulando": "coagulare",
    "coagulano": "coagulare",
    "coagulante": "coagulare",
    "coagulanti": "coagulare",
    "coagular": "coagulare",
    "coagularon": "coagulare",
    "coagularono": "coagulare",
    "coagulasse": "coagulare",
    "coagulasser": "coagulare",
    "coagulassero": "coagulare",
    "coagulassi": "coagulare",
    "coagulassimo": "coagulare",
    "coagulaste": "coagulare",
    "coagulasti": "coagulare",
    "coagulata": "coagulare",
    "coagulate": "coagulare",
    "coagulati": "coagulare",
    "coagulato": "coagulare",
    "coagulava": "coagulare",
    "coagulavamo": "coagulare",
    "coagulavan": "coagulare",
    "coagulavano": "coagulare",
    "coagulavate": "coagulare",
    "coagulavi": "coagulare",
    "coagulavo": "coagulare",
    "coagulazioni": "coagulazione",
    "coagulerai": "coagulare",
    "coaguleran": "coagulare",
    "coaguleranno": "coagulare",
    "coagulerebbe": "coagulare",
    "coagulerebber": "coagulare",
    "coagulerebbero": "coagulare",
    "coagulerei": "coagulare",
    "coaguleremmo": "coagulare",
    "coaguleremo": "coagulare",
    "coagulereste": "coagulare",
    "coaguleresti": "coagulare",
    "coagulerete": "coagulare",
    "coagulerà": "coagulare",
    "coagulerò": "coagulare",
    "coaguli": "coagulare",
    "coaguliamo": "coagulare",
    "coaguliate": "coagulare",
    "coagulin": "coagulare",
    "coagulino": "coagulare",
    "coagulo": "coagulare",
    "coagulò": "coagulare",
    "coalizionali": "coalizionale",
    "coalizioni": "coalizione",
    "coalizza": "coalizzare",
    "coalizzai": "coalizzare",
    "coalizzammo": "coalizzare",
    "coalizzan": "coalizzare",
    "coalizzando": "coalizzare",
    "coalizzano": "coalizzare",
    "coalizzante": "coalizzare",
    "coalizzanti": "coalizzare",
    "coalizzar": "coalizzare",
    "coalizzaron": "coalizzare",
    "coalizzarono": "coalizzare",
    "coalizzasse": "coalizzare",
    "coalizzasser": "coalizzare",
    "coalizzassero": "coalizzare",
    "coalizzassi": "coalizzare",
    "coalizzassimo": "coalizzare",
    "coalizzaste": "coalizzare",
    "coalizzasti": "coalizzare",
    "coalizzata": "coalizzare",
    "coalizzate": "coalizzare",
    "coalizzati": "coalizzare",
    "coalizzato": "coalizzare",
    "coalizzava": "coalizzare",
    "coalizzavamo": "coalizzare",
    "coalizzavan": "coalizzare",
    "coalizzavano": "coalizzare",
    "coalizzavate": "coalizzare",
    "coalizzavi": "coalizzare",
    "coalizzavo": "coalizzare",
    "coalizzerai": "coalizzare",
    "coalizzeran": "coalizzare",
    "coalizzeranno": "coalizzare",
    "coalizzerebbe": "coalizzare",
    "coalizzerebber": "coalizzare",
    "coalizzerebbero": "coalizzare",
    "coalizzerei": "coalizzare",
    "coalizzeremmo": "coalizzare",
    "coalizzeremo": "coalizzare",
    "coalizzereste": "coalizzare",
    "coalizzeresti": "coalizzare",
    "coalizzerete": "coalizzare",
    "coalizzerà": "coalizzare",
    "coalizzerò": "coalizzare",
    "coalizzi": "coalizzare",
    "coalizziamo": "coalizzare",
    "coalizziate": "coalizzare",
    "coalizzin": "coalizzare",
    "coalizzino": "coalizzare",
    "coalizzo": "coalizzare",
    "coalizzò": "coalizzare",
    "coarta": "coartare",
    "coartai": "coartare",
    "coartammo": "coartare",
    "coartan": "coartare",
    "coartando": "coartare",
    "coartano": "coartare",
    "coartante": "coartare",
    "coartanti": "coartare",
    "coartar": "coartare",
    "coartaron": "coartare",
    "coartarono": "coartare",
    "coartasse": "coartare",
    "coartasser": "coartare",
    "coartassero": "coartare",
    "coartassi": "coartare",
    "coartassimo": "coartare",
    "coartaste": "coartare",
    "coartasti": "coartare",
    "coartata": "coartare",
    "coartate": "coartare",
    "coartati": "coartare",
    "coartato": "coartare",
    "coartava": "coartare",
    "coartavamo": "coartare",
    "coartavan": "coartare",
    "coartavano": "coartare",
    "coartavate": "coartare",
    "coartavi": "coartare",
    "coartavo": "coartare",
    "coarterai": "coartare",
    "coarteran": "coartare",
    "coarteranno": "coartare",
    "coarterebbe": "coartare",
    "coarterebber": "coartare",
    "coarterebbero": "coartare",
    "coarterei": "coartare",
    "coarteremmo": "coartare",
    "coarteremo": "coartare",
    "coartereste": "coartare",
    "coarteresti": "coartare",
    "coarterete": "coartare",
    "coarterà": "coartare",
    "coarterò": "coartare",
    "coarti": "coartare",
    "coartiamo": "coartare",
    "coartiate": "coartare",
    "coartin": "coartare",
    "coartino": "coartare",
    "coarto": "coartare",
    "coartò": "coartare",
    "coassiali": "coassiale",
    "coatta": "coatto",
    "coatte": "coatto",
    "coatti": "coatto",
    "coattiva": "coattivo",
    "coattive": "coattivo",
    "coattivi": "coattivo",
    "coautori": "coautore",
    "coazioni": "coazione",
    "cocaine": "cocaina",
    "cocainomani": "cocainomane",
    "coccarde": "coccarda",
    "cocchi": "cocco",
    "cocchieri": "cocchiere",
    "cocci": "coccio",
    "coccinelle": "coccinella",
    "cocciuta": "cocciuto",
    "cocciutaggini": "cocciutaggine",
    "cocciute": "cocciuto",
    "cocciuti": "cocciuto",
    "coccodrilli": "coccodrillo",
    "coccola": "coccolare",
    "coccolai": "coccolare",
    "coccolammo": "coccolare",
    "coccolan": "coccolare",
    "coccolando": "coccolare",
    "coccolano": "coccolare",
    "coccolante": "coccolare",
    "coccolanti": "coccolare",
    "coccolar": "coccolare",
    "coccolaron": "coccolare",
    "coccolarono": "coccolare",
    "coccolasse": "coccolare",
    "coccolasser": "coccolare",
    "coccolassero": "coccolare",
    "coccolassi": "coccolare",
    "coccolassimo": "coccolare",
    "coccolaste": "coccolare",
    "coccolasti": "coccolare",
    "coccolata": "coccolato",
    "coccolate": "coccolato",
    "coccolati": "coccolato",
    "coccolato": "coccolare",
    "coccolava": "coccolare",
    "coccolavamo": "coccolare",
    "coccolavan": "coccolare",
    "coccolavano": "coccolare",
    "coccolavate": "coccolare",
    "coccolavi": "coccolare",
    "coccolavo": "coccolare",
    "coccole": "coccola",
    "coccolerai": "coccolare",
    "coccoleran": "coccolare",
    "coccoleranno": "coccolare",
    "coccolerebbe": "coccolare",
    "coccolerebber": "coccolare",
    "coccolerebbero": "coccolare",
    "coccolerei": "coccolare",
    "coccoleremmo": "coccolare",
    "coccoleremo": "coccolare",
    "coccolereste": "coccolare",
    "coccoleresti": "coccolare",
    "coccolerete": "coccolare",
    "coccolerà": "coccolare",
    "coccolerò": "coccolare",
    "coccoli": "coccolare",
    "coccoliamo": "coccolare",
    "coccoliate": "coccolare",
    "coccolin": "coccolare",
    "coccolino": "coccolare",
    "coccolo": "coccolare",
    "coccolosa": "coccoloso",
    "coccolose": "coccoloso",
    "coccolosi": "coccoloso",
    "coccolò": "coccolare",
    "cocemmo": "cuocere",
    "cocendo": "cuocere",
    "cocente": "cuocere",
    "cocenti": "cuocere",
    "cocerai": "cuocere",
    "coceran": "cuocere",
    "coceranno": "cuocere",
    "cocerebbe": "cuocere",
    "cocerebber": "cuocere",
    "cocerebbero": "cuocere",
    "cocerei": "cuocere",
    "coceremmo": "cuocere",
    "coceremo": "cuocere",
    "cocereste": "cuocere",
    "coceresti": "cuocere",
    "cocerete": "cuocere",
    "cocerà": "cuocere",
    "cocerò": "cuocere",
    "cocesse": "cuocere",
    "cocesser": "cuocere",
    "cocessero": "cuocere",
    "cocessi": "cuocere",
    "cocessimo": "cuocere",
    "coceste": "cuocere",
    "cocesti": "cuocere",
    "cocete": "cuocere",
    "coceva": "cuocere",
    "cocevamo": "cuocere",
    "cocevan": "cuocere",
    "cocevano": "cuocere",
    "cocevate": "cuocere",
    "cocevi": "cuocere",
    "cocevo": "cuocere",
    "cociamo": "cuocere",
    "cociate": "cuocere",
    "cocleari": "cocleare",
    "cocomeri": "cocomero",
    "cocuzzoli": "cocuzzolo",
    "codarda": "codardo",
    "codarde": "codardo",
    "codardi": "codardo",
    "codazzi": "codazzo",
    "code": "coda",
    "codesta": "codesto",
    "codeste": "codesto",
    "codesti": "codesto",
    "codici": "codice",
    "codicilli": "codicillo",
    "codifica": "codificare",
    "codificabili": "codificabile",
    "codificai": "codificare",
    "codificammo": "codificare",
    "codifican": "codificare",
    "codificando": "codificare",
    "codificano": "codificare",
    "codificante": "codificare",
    "codificanti": "codificare",
    "codificar": "codificare",
    "codificaron": "codificare",
    "codificarono": "codificare",
    "codificasse": "codificare",
    "codificasser": "codificare",
    "codificassero": "codificare",
    "codificassi": "codificare",
    "codificassimo": "codificare",
    "codificaste": "codificare",
    "codificasti": "codificare",
    "codificata": "codificare",
    "codificate": "codificare",
    "codificati": "codificare",
    "codificato": "codificare",
    "codificava": "codificare",
    "codificavamo": "codificare",
    "codificavan": "codificare",
    "codificavano": "codificare",
    "codificavate": "codificare",
    "codificavi": "codificare",
    "codificavo": "codificare",
    "codificazioni": "codificazione",
    "codificherai": "codificare",
    "codificheran": "codificare",
    "codificheranno": "codificare",
    "codificherebbe": "codificare",
    "codificherebber": "codificare",
    "codificherebbero": "codificare",
    "codificherei": "codificare",
    "codificheremmo": "codificare",
    "codificheremo": "codificare",
    "codifichereste": "codificare",
    "codificheresti": "codificare",
    "codificherete": "codificare",
    "codificherà": "codificare",
    "codificherò": "codificare",
    "codifichi": "codificare",
    "codifichiamo": "codificare",
    "codifichiate": "codificare",
    "codifichin": "codificare",
    "codifichino": "codificare",
    "codifico": "codificare",
    "codificò": "codificare",
    "codina": "codino",
    "codine": "codino",
    "codini": "codino",
    "coedizioni": "coedizione",
    "coefficenti": "coefficente",
    "coefficienti": "coefficiente",
    "coercibili": "coercibile",
    "coercitiva": "coercitivo",
    "coercitive": "coercitivo",
    "coercitivi": "coercitivo",
    "coercizioni": "coercizione",
    "coerenti": "coerente",
    "coerenze": "coerenza",
    "coesa": "coeso",
    "coese": "coeso",
    "coesi": "coeso",
    "coesioni": "coesione",
    "coesista": "coesistere",
    "coesistan": "coesistere",
    "coesistano": "coesistere",
    "coesiste": "coesistere",
    "coesistei": "coesistere",
    "coesistemmo": "coesistere",
    "coesistendo": "coesistere",
    "coesistente": "coesistere",
    "coesistenti": "coesistere",
    "coesistenze": "coesistenza",
    "coesister": "coesistere",
    "coesisterai": "coesistere",
    "coesisteran": "coesistere",
    "coesisteranno": "coesistere",
    "coesisterebbe": "coesistere",
    "coesisterebber": "coesistere",
    "coesisterebbero": "coesistere",
    "coesisterei": "coesistere",
    "coesisteremmo": "coesistere",
    "coesisteremo": "coesistere",
    "coesistereste": "coesistere",
    "coesisteresti": "coesistere",
    "coesisterete": "coesistere",
    "coesisteron": "coesistere",
    "coesisterono": "coesistere",
    "coesisterà": "coesistere",
    "coesisterò": "coesistere",
    "coesistesse": "coesistere",
    "coesistesser": "coesistere",
    "coesistessero": "coesistere",
    "coesistessi": "coesistere",
    "coesistessimo": "coesistere",
    "coesisteste": "coesistere",
    "coesistesti": "coesistere",
    "coesistete": "coesistere",
    "coesisteva": "coesistere",
    "coesistevamo": "coesistere",
    "coesistevan": "coesistere",
    "coesistevano": "coesistere",
    "coesistevate": "coesistere",
    "coesistevi": "coesistere",
    "coesistevo": "coesistere",
    "coesisti": "coesistere",
    "coesistiamo": "coesistere",
    "coesistiate": "coesistere",
    "coesisto": "coesistere",
    "coesiston": "coesistere",
    "coesistono": "coesistere",
    "coesistuta": "coesistere",
    "coesistute": "coesistere",
    "coesistuti": "coesistere",
    "coesistuto": "coesistere",
    "coesistè": "coesistere",
    "coesiva": "coesivo",
    "coesive": "coesivo",
    "coesivi": "coesivo",
    "coetanea": "coetaneo",
    "coetanee": "coetaneo",
    "coetanei": "coetaneo",
    "coeva": "coevo",
    "coeve": "coevo",
    "coevi": "coevo",
    "cofanetti": "cofanetto",
    "cofani": "cofano",
    "cofferatiana": "cofferatiano",
    "cofferatiane": "cofferatiano",
    "cofferatiani": "cofferatiano",
    "cofinanzi": "cofinanziare",
    "cofinanzia": "cofinanziare",
    "cofinanziai": "cofinanziare",
    "cofinanziammo": "cofinanziare",
    "cofinanziamo": "cofinanziare",
    "cofinanzian": "cofinanziare",
    "cofinanziando": "cofinanziare",
    "cofinanziano": "cofinanziare",
    "cofinanziante": "cofinanziare",
    "cofinanzianti": "cofinanziare",
    "cofinanziar": "cofinanziare",
    "cofinanziaron": "cofinanziare",
    "cofinanziarono": "cofinanziare",
    "cofinanziasse": "cofinanziare",
    "cofinanziasser": "cofinanziare",
    "cofinanziassero": "cofinanziare",
    "cofinanziassi": "cofinanziare",
    "cofinanziassimo": "cofinanziare",
    "cofinanziaste": "cofinanziare",
    "cofinanziasti": "cofinanziare",
    "cofinanziata": "cofinanziare",
    "cofinanziate": "cofinanziare",
    "cofinanziati": "cofinanziare",
    "cofinanziato": "cofinanziare",
    "cofinanziava": "cofinanziare",
    "cofinanziavamo": "cofinanziare",
    "cofinanziavan": "cofinanziare",
    "cofinanziavano": "cofinanziare",
    "cofinanziavate": "cofinanziare",
    "cofinanziavi": "cofinanziare",
    "cofinanziavo": "cofinanziare",
    "cofinanzierai": "cofinanziare",
    "cofinanzieran": "cofinanziare",
    "cofinanzieranno": "cofinanziare",
    "cofinanzierebbe": "cofinanziare",
    "cofinanzierebber": "cofinanziare",
    "cofinanzierebbero": "cofinanziare",
    "cofinanzierei": "cofinanziare",
    "cofinanzieremmo": "cofinanziare",
    "cofinanzieremo": "cofinanziare",
    "cofinanziereste": "cofinanziare",
    "cofinanzieresti": "cofinanziare",
    "cofinanzierete": "cofinanziare",
    "cofinanzierà": "cofinanziare",
    "cofinanzierò": "cofinanziare",
    "cofinanzin": "cofinanziare",
    "cofinanzino": "cofinanziare",
    "cofinanzio": "cofinanziare",
    "cofinanziò": "cofinanziare",
    "cofirma": "cofirmare",
    "cofirmai": "cofirmare",
    "cofirmammo": "cofirmare",
    "cofirman": "cofirmare",
    "cofirmando": "cofirmare",
    "cofirmano": "cofirmare",
    "cofirmante": "cofirmare",
    "cofirmanti": "cofirmare",
    "cofirmar": "cofirmare",
    "cofirmaron": "cofirmare",
    "cofirmarono": "cofirmare",
    "cofirmasse": "cofirmare",
    "cofirmasser": "cofirmare",
    "cofirmassero": "cofirmare",
    "cofirmassi": "cofirmare",
    "cofirmassimo": "cofirmare",
    "cofirmaste": "cofirmare",
    "cofirmasti": "cofirmare",
    "cofirmata": "cofirmare",
    "cofirmate": "cofirmare",
    "cofirmati": "cofirmare",
    "cofirmato": "cofirmare",
    "cofirmava": "cofirmare",
    "cofirmavamo": "cofirmare",
    "cofirmavan": "cofirmare",
    "cofirmavano": "cofirmare",
    "cofirmavate": "cofirmare",
    "cofirmavi": "cofirmare",
    "cofirmavo": "cofirmare",
    "cofirmerai": "cofirmare",
    "cofirmeran": "cofirmare",
    "cofirmeranno": "cofirmare",
    "cofirmerebbe": "cofirmare",
    "cofirmerebber": "cofirmare",
    "cofirmerebbero": "cofirmare",
    "cofirmerei": "cofirmare",
    "cofirmeremmo": "cofirmare",
    "cofirmeremo": "cofirmare",
    "cofirmereste": "cofirmare",
    "cofirmeresti": "cofirmare",
    "cofirmerete": "cofirmare",
    "cofirmerà": "cofirmare",
    "cofirmerò": "cofirmare",
    "cofirmi": "cofirmare",
    "cofirmiamo": "cofirmare",
    "cofirmiate": "cofirmare",
    "cofirmin": "cofirmare",
    "cofirmino": "cofirmare",
    "cofirmo": "cofirmare",
    "cofirmò": "cofirmare",
    "cofonda": "cofondare",
    "cofondai": "cofondare",
    "cofondammo": "cofondare",
    "cofondan": "cofondare",
    "cofondando": "cofondare",
    "cofondano": "cofondare",
    "cofondante": "cofondare",
    "cofondanti": "cofondare",
    "cofondar": "cofondare",
    "cofondaron": "cofondare",
    "cofondarono": "cofondare",
    "cofondasse": "cofondare",
    "cofondasser": "cofondare",
    "cofondassero": "cofondare",
    "cofondassi": "cofondare",
    "cofondassimo": "cofondare",
    "cofondaste": "cofondare",
    "cofondasti": "cofondare",
    "cofondata": "cofondare",
    "cofondate": "cofondare",
    "cofondati": "cofondare",
    "cofondato": "cofondare",
    "cofondatori": "cofondatore",
    "cofondava": "cofondare",
    "cofondavamo": "cofondare",
    "cofondavan": "cofondare",
    "cofondavano": "cofondare",
    "cofondavate": "cofondare",
    "cofondavi": "cofondare",
    "cofondavo": "cofondare",
    "cofonderai": "cofondare",
    "cofonderan": "cofondare",
    "cofonderanno": "cofondare",
    "cofonderebbe": "cofondare",
    "cofonderebber": "cofondare",
    "cofonderebbero": "cofondare",
    "cofonderei": "cofondare",
    "cofonderemmo": "cofondare",
    "cofonderemo": "cofondare",
    "cofondereste": "cofondare",
    "cofonderesti": "cofondare",
    "cofonderete": "cofondare",
    "cofonderà": "cofondare",
    "cofonderò": "cofondare",
    "cofondi": "cofondare",
    "cofondiamo": "cofondare",
    "cofondiate": "cofondare",
    "cofondin": "cofondare",
    "cofondino": "cofondare",
    "cofondo": "cofondare",
    "cofondò": "cofondare",
    "cogesta": "cogestire",
    "cogestan": "cogestire",
    "cogestano": "cogestire",
    "cogeste": "cogestire",
    "cogestendo": "cogestire",
    "cogestente": "cogestire",
    "cogestenti": "cogestire",
    "cogesti": "cogestire",
    "cogestiamo": "cogestire",
    "cogestiate": "cogestire",
    "cogestii": "cogestire",
    "cogestimmo": "cogestire",
    "cogestioni": "cogestione",
    "cogestir": "cogestire",
    "cogestirai": "cogestire",
    "cogestiran": "cogestire",
    "cogestiranno": "cogestire",
    "cogestirebbe": "cogestire",
    "cogestirebber": "cogestire",
    "cogestirebbero": "cogestire",
    "cogestirei": "cogestire",
    "cogestiremmo": "cogestire",
    "cogestiremo": "cogestire",
    "cogestireste": "cogestire",
    "cogestiresti": "cogestire",
    "cogestirete": "cogestire",
    "cogestiron": "cogestire",
    "cogestirono": "cogestire",
    "cogestirà": "cogestire",
    "cogestirò": "cogestire",
    "cogestisse": "cogestire",
    "cogestisser": "cogestire",
    "cogestissero": "cogestire",
    "cogestissi": "cogestire",
    "cogestissimo": "cogestire",
    "cogestiste": "cogestire",
    "cogestisti": "cogestire",
    "cogestita": "cogestire",
    "cogestite": "cogestire",
    "cogestiti": "cogestire",
    "cogestito": "cogestire",
    "cogestiva": "cogestire",
    "cogestivamo": "cogestire",
    "cogestivan": "cogestire",
    "cogestivano": "cogestire",
    "cogestivate": "cogestire",
    "cogestivi": "cogestire",
    "cogestivo": "cogestire",
    "cogesto": "cogestire",
    "cogeston": "cogestire",
    "cogestono": "cogestire",
    "cogestì": "cogestire",
    "cogitabonda": "cogitabondo",
    "cogitabonde": "cogitabondo",
    "cogitabondi": "cogitabondo",
    "cogli": "col",
    "cogliamo": "cogliere",
    "cogliate": "cogliere",
    "coglie": "cogliere",
    "cogliemmo": "cogliere",
    "cogliendo": "cogliere",
    "cogliente": "cogliere",
    "coglienti": "cogliere",
    "coglier": "cogliere",
    "coglierai": "cogliere",
    "coglieran": "cogliere",
    "coglieranno": "cogliere",
    "coglierebbe": "cogliere",
    "coglierebber": "cogliere",
    "coglierebbero": "cogliere",
    "coglierei": "cogliere",
    "coglieremmo": "cogliere",
    "coglieremo": "cogliere",
    "cogliereste": "cogliere",
    "coglieresti": "cogliere",
    "coglierete": "cogliere",
    "coglierà": "cogliere",
    "coglierò": "cogliere",
    "cogliesse": "cogliere",
    "cogliesser": "cogliere",
    "cogliessero": "cogliere",
    "cogliessi": "cogliere",
    "cogliessimo": "cogliere",
    "coglieste": "cogliere",
    "cogliesti": "cogliere",
    "cogliete": "cogliere",
    "coglieva": "cogliere",
    "coglievamo": "cogliere",
    "coglievan": "cogliere",
    "coglievano": "cogliere",
    "coglievate": "cogliere",
    "coglievi": "cogliere",
    "coglievo": "cogliere",
    "coglioneggerai": "coglioneggiare",
    "coglioneggeran": "coglioneggiare",
    "coglioneggeranno": "coglioneggiare",
    "coglioneggerebbe": "coglioneggiare",
    "coglioneggerebber": "coglioneggiare",
    "coglioneggerebbero": "coglioneggiare",
    "coglioneggerei": "coglioneggiare",
    "coglioneggeremmo": "coglioneggiare",
    "coglioneggeremo": "coglioneggiare",
    "coglioneggereste": "coglioneggiare",
    "coglioneggeresti": "coglioneggiare",
    "coglioneggerete": "coglioneggiare",
    "coglioneggerà": "coglioneggiare",
    "coglioneggerò": "coglioneggiare",
    "coglioneggi": "coglioneggiare",
    "coglioneggia": "coglioneggiare",
    "coglioneggiai": "coglioneggiare",
    "coglioneggiammo": "coglioneggiare",
    "coglioneggiamo": "coglioneggiare",
    "coglioneggian": "coglioneggiare",
    "coglioneggiando": "coglioneggiare",
    "coglioneggiano": "coglioneggiare",
    "coglioneggiante": "coglioneggiare",
    "coglioneggianti": "coglioneggiare",
    "coglioneggiar": "coglioneggiare",
    "coglioneggiaron": "coglioneggiare",
    "coglioneggiarono": "coglioneggiare",
    "coglioneggiasse": "coglioneggiare",
    "coglioneggiasser": "coglioneggiare",
    "coglioneggiassero": "coglioneggiare",
    "coglioneggiassi": "coglioneggiare",
    "coglioneggiassimo": "coglioneggiare",
    "coglioneggiaste": "coglioneggiare",
    "coglioneggiasti": "coglioneggiare",
    "coglioneggiata": "coglioneggiare",
    "coglioneggiate": "coglioneggiare",
    "coglioneggiati": "coglioneggiare",
    "coglioneggiato": "coglioneggiare",
    "coglioneggiava": "coglioneggiare",
    "coglioneggiavamo": "coglioneggiare",
    "coglioneggiavan": "coglioneggiare",
    "coglioneggiavano": "coglioneggiare",
    "coglioneggiavate": "coglioneggiare",
    "coglioneggiavi": "coglioneggiare",
    "coglioneggiavo": "coglioneggiare",
    "coglioneggin": "coglioneggiare",
    "coglioneggino": "coglioneggiare",
    "coglioneggio": "coglioneggiare",
    "coglioneggiò": "coglioneggiare",
    "coglionerie": "coglioneria",
    "coglioni": "coglione",
    "cognate": "cognata",
    "cognati": "cognato",
    "cognitiva": "cognitivo",
    "cognitive": "cognitivo",
    "cognitivi": "cognitivo",
    "cognizioni": "cognizione",
    "cognomi": "cognome",
    "coi": "col",
    "coibenta": "coibentare",
    "coibentai": "coibentare",
    "coibentammo": "coibentare",
    "coibentan": "coibentare",
    "coibentando": "coibentare",
    "coibentano": "coibentare",
    "coibentante": "coibentare",
    "coibentanti": "coibentare",
    "coibentar": "coibentare",
    "coibentaron": "coibentare",
    "coibentarono": "coibentare",
    "coibentasse": "coibentare",
    "coibentasser": "coibentare",
    "coibentassero": "coibentare",
    "coibentassi": "coibentare",
    "coibentassimo": "coibentare",
    "coibentaste": "coibentare",
    "coibentasti": "coibentare",
    "coibentata": "coibentare",
    "coibentate": "coibentare",
    "coibentati": "coibentare",
    "coibentato": "coibentare",
    "coibentava": "coibentare",
    "coibentavamo": "coibentare",
    "coibentavan": "coibentare",
    "coibentavano": "coibentare",
    "coibentavate": "coibentare",
    "coibentavi": "coibentare",
    "coibentavo": "coibentare",
    "coibenterai": "coibentare",
    "coibenteran": "coibentare",
    "coibenteranno": "coibentare",
    "coibenterebbe": "coibentare",
    "coibenterebber": "coibentare",
    "coibenterebbero": "coibentare",
    "coibenterei": "coibentare",
    "coibenteremmo": "coibentare",
    "coibenteremo": "coibentare",
    "coibentereste": "coibentare",
    "coibenteresti": "coibentare",
    "coibenterete": "coibentare",
    "coibenterà": "coibentare",
    "coibenterò": "coibentare",
    "coibenti": "coibentare",
    "coibentiamo": "coibentare",
    "coibentiate": "coibentare",
    "coibentin": "coibentare",
    "coibentino": "coibentare",
    "coibento": "coibentare",
    "coibentò": "coibentare",
    "coimputati": "coimputato",
    "coincida": "coincidere",
    "coincidan": "coincidere",
    "coincidano": "coincidere",
    "coincide": "coincidere",
    "coincidemmo": "coincidere",
    "coincidendo": "coincidere",
    "coincidente": "coincidere",
    "coincidenti": "coincidere",
    "coincidenze": "coincidenza",
    "coincider": "coincidere",
    "coinciderai": "coincidere",
    "coincideran": "coincidere",
    "coincideranno": "coincidere",
    "coinciderebbe": "coincidere",
    "coinciderebber": "coincidere",
    "coinciderebbero": "coincidere",
    "coinciderei": "coincidere",
    "coincideremmo": "coincidere",
    "coincideremo": "coincidere",
    "coincidereste": "coincidere",
    "coincideresti": "coincidere",
    "coinciderete": "coincidere",
    "coinciderà": "coincidere",
    "coinciderò": "coincidere",
    "coincidesse": "coincidere",
    "coincidesser": "coincidere",
    "coincidessero": "coincidere",
    "coincidessi": "coincidere",
    "coincidessimo": "coincidere",
    "coincideste": "coincidere",
    "coincidesti": "coincidere",
    "coincidete": "coincidere",
    "coincideva": "coincidere",
    "coincidevamo": "coincidere",
    "coincidevan": "coincidere",
    "coincidevano": "coincidere",
    "coincidevate": "coincidere",
    "coincidevi": "coincidere",
    "coincidevo": "coincidere",
    "coincidi": "coincidere",
    "coincidiamo": "coincidere",
    "coincidiate": "coincidere",
    "coincido": "coincidere",
    "coincidon": "coincidere",
    "coincidono": "coincidere",
    "coincisa": "coincidere",
    "coincise": "coincidere",
    "coinciser": "coincidere",
    "coincisero": "coincidere",
    "coincisi": "coincidere",
    "coinciso": "coincidere",
    "coindagati": "coindagato",
    "coinquilini": "coinquilino",
    "cointeressa": "cointeressare",
    "cointeressai": "cointeressare",
    "cointeressammo": "cointeressare",
    "cointeressan": "cointeressare",
    "cointeressando": "cointeressare",
    "cointeressano": "cointeressare",
    "cointeressante": "cointeressare",
    "cointeressanti": "cointeressare",
    "cointeressar": "cointeressare",
    "cointeressaron": "cointeressare",
    "cointeressarono": "cointeressare",
    "cointeressasse": "cointeressare",
    "cointeressasser": "cointeressare",
    "cointeressassero": "cointeressare",
    "cointeressassi": "cointeressare",
    "cointeressassimo": "cointeressare",
    "cointeressaste": "cointeressare",
    "cointeressasti": "cointeressare",
    "cointeressata": "cointeressare",
    "cointeressate": "cointeressare",
    "cointeressati": "cointeressare",
    "cointeressato": "cointeressare",
    "cointeressava": "cointeressare",
    "cointeressavamo": "cointeressare",
    "cointeressavan": "cointeressare",
    "cointeressavano": "cointeressare",
    "cointeressavate": "cointeressare",
    "cointeressavi": "cointeressare",
    "cointeressavo": "cointeressare",
    "cointeressenze": "cointeressenza",
    "cointeresserai": "cointeressare",
    "cointeresseran": "cointeressare",
    "cointeresseranno": "cointeressare",
    "cointeresserebbe": "cointeressare",
    "cointeresserebber": "cointeressare",
    "cointeresserebbero": "cointeressare",
    "cointeresserei": "cointeressare",
    "cointeresseremmo": "cointeressare",
    "cointeresseremo": "cointeressare",
    "cointeressereste": "cointeressare",
    "cointeresseresti": "cointeressare",
    "cointeresserete": "cointeressare",
    "cointeresserà": "cointeressare",
    "cointeresserò": "cointeressare",
    "cointeressi": "cointeressare",
    "cointeressiamo": "cointeressare",
    "cointeressiate": "cointeressare",
    "cointeressin": "cointeressare",
    "cointeressino": "cointeressare",
    "cointeresso": "cointeressare",
    "cointeressò": "cointeressare",
    "cointesta": "cointestare",
    "cointestai": "cointestare",
    "cointestammo": "cointestare",
    "cointestan": "cointestare",
    "cointestando": "cointestare",
    "cointestano": "cointestare",
    "cointestante": "cointestare",
    "cointestanti": "cointestare",
    "cointestar": "cointestare",
    "cointestaron": "cointestare",
    "cointestarono": "cointestare",
    "cointestasse": "cointestare",
    "cointestasser": "cointestare",
    "cointestassero": "cointestare",
    "cointestassi": "cointestare",
    "cointestassimo": "cointestare",
    "cointestaste": "cointestare",
    "cointestasti": "cointestare",
    "cointestata": "cointestare",
    "cointestatari": "cointestatario",
    "cointestate": "cointestare",
    "cointestati": "cointestare",
    "cointestato": "cointestare",
    "cointestava": "cointestare",
    "cointestavamo": "cointestare",
    "cointestavan": "cointestare",
    "cointestavano": "cointestare",
    "cointestavate": "cointestare",
    "cointestavi": "cointestare",
    "cointestavo": "cointestare",
    "cointesterai": "cointestare",
    "cointesteran": "cointestare",
    "cointesteranno": "cointestare",
    "cointesterebbe": "cointestare",
    "cointesterebber": "cointestare",
    "cointesterebbero": "cointestare",
    "cointesterei": "cointestare",
    "cointesteremmo": "cointestare",
    "cointesteremo": "cointestare",
    "cointestereste": "cointestare",
    "cointesteresti": "cointestare",
    "cointesterete": "cointestare",
    "cointesterà": "cointestare",
    "cointesterò": "cointestare",
    "cointesti": "cointestare",
    "cointestiamo": "cointestare",
    "cointestiate": "cointestare",
    "cointestin": "cointestare",
    "cointestino": "cointestare",
    "cointesto": "cointestare",
    "cointestò": "cointestare",
    "coinvolga": "coinvolgere",
    "coinvolgan": "coinvolgere",
    "coinvolgano": "coinvolgere",
    "coinvolge": "coinvolgere",
    "coinvolgemmo": "coinvolgere",
    "coinvolgendo": "coinvolgere",
    "coinvolgente": "coinvolgere",
    "coinvolgenti": "coinvolgere",
    "coinvolger": "coinvolgere",
    "coinvolgerai": "coinvolgere",
    "coinvolgeran": "coinvolgere",
    "coinvolgeranno": "coinvolgere",
    "coinvolgerebbe": "coinvolgere",
    "coinvolgerebber": "coinvolgere",
    "coinvolgerebbero": "coinvolgere",
    "coinvolgerei": "coinvolgere",
    "coinvolgeremmo": "coinvolgere",
    "coinvolgeremo": "coinvolgere",
    "coinvolgereste": "coinvolgere",
    "coinvolgeresti": "coinvolgere",
    "coinvolgerete": "coinvolgere",
    "coinvolgerà": "coinvolgere",
    "coinvolgerò": "coinvolgere",
    "coinvolgesse": "coinvolgere",
    "coinvolgesser": "coinvolgere",
    "coinvolgessero": "coinvolgere",
    "coinvolgessi": "coinvolgere",
    "coinvolgessimo": "coinvolgere",
    "coinvolgeste": "coinvolgere",
    "coinvolgesti": "coinvolgere",
    "coinvolgete": "coinvolgere",
    "coinvolgeva": "coinvolgere",
    "coinvolgevamo": "coinvolgere",
    "coinvolgevan": "coinvolgere",
    "coinvolgevano": "coinvolgere",
    "coinvolgevate": "coinvolgere",
    "coinvolgevi": "coinvolgere",
    "coinvolgevo": "coinvolgere",
    "coinvolgi": "coinvolgere",
    "coinvolgiamo": "coinvolgere",
    "coinvolgiate": "coinvolgere",
    "coinvolgimenti": "coinvolgimento",
    "coinvolgo": "coinvolgere",
    "coinvolgon": "coinvolgere",
    "coinvolgono": "coinvolgere",
    "coinvolse": "coinvolgere",
    "coinvolser": "coinvolgere",
    "coinvolsero": "coinvolgere",
    "coinvolsi": "coinvolgere",
    "coinvolta": "coinvolgere",
    "coinvolte": "coinvolgere",
    "coinvolti": "coinvolgere",
    "coinvolto": "coinvolgere",
    "coitali": "coitale",
    "coiti": "coito",
    "cola": "colare",
    "colai": "colare",
    "colammo": "colare",
    "colan": "colare",
    "colando": "colare",
    "colano": "colare",
    "colante": "colare",
    "colanti": "colare",
    "colar": "colare",
    "colaron": "colare",
    "colarono": "colare",
    "colasse": "colare",
    "colasser": "colare",
    "colassero": "colare",
    "colassi": "colare",
    "colassimo": "colare",
    "colaste": "colare",
    "colasti": "colare",
    "colata": "colato",
    "colate": "colato",
    "colati": "colato",
    "colato": "colare",
    "colava": "colare",
    "colavamo": "colare",
    "colavan": "colare",
    "colavano": "colare",
    "colavate": "colare",
    "colavi": "colare",
    "colavo": "colare",
    "colazioni": "colazione",
    "colbacchi": "colbacco",
    "colbertiana": "colbertiano",
    "colbertiane": "colbertiano",
    "colbertiani": "colbertiano",
    "colcosiana": "colcosiano",
    "colcosiane": "colcosiano",
    "colcosiani": "colcosiano",
    "coleotteri": "coleottero",
    "colerai": "colare",
    "coleran": "colare",
    "coleranno": "colare",
    "colerebbe": "colare",
    "colerebber": "colare",
    "colerebbero": "colare",
    "colerei": "colare",
    "coleremmo": "colare",
    "coleremo": "colare",
    "colereste": "colare",
    "coleresti": "colare",
    "colerete": "colare",
    "colerica": "colerico",
    "coleriche": "colerico",
    "colerici": "colerico",
    "colerà": "colare",
    "colerò": "colare",
    "colesteroli": "colesterolo",
    "colga": "cogliere",
    "colgan": "cogliere",
    "colgano": "cogliere",
    "colgo": "cogliere",
    "colgon": "cogliere",
    "colgono": "cogliere",
    "coli": "colare",
    "coliamo": "colare",
    "coliate": "colare",
    "colica": "colico",
    "coliche": "colico",
    "colici": "colico",
    "colin": "colare",
    "colino": "colare",
    "coliti": "colite",
    "colla": "collare",
    "collabora": "collaborare",
    "collaborai": "collaborare",
    "collaborammo": "collaborare",
    "collaboran": "collaborare",
    "collaborando": "collaborare",
    "collaborano": "collaborare",
    "collaborante": "collaborare",
    "collaboranti": "collaborare",
    "collaborar": "collaborare",
    "collaboraron": "collaborare",
    "collaborarono": "collaborare",
    "collaborasse": "collaborare",
    "collaborasser": "collaborare",
    "collaborassero": "collaborare",
    "collaborassi": "collaborare",
    "collaborassimo": "collaborare",
    "collaboraste": "collaborare",
    "collaborasti": "collaborare",
    "collaborata": "collaborare",
    "collaborate": "collaborare",
    "collaborati": "collaborare",
    "collaborativa": "collaborativo",
    "collaborative": "collaborativo",
    "collaborativi": "collaborativo",
    "collaborato": "collaborare",
    "collaboratori": "collaboratore",
    "collaboratrici": "collaboratrice",
    "collaborava": "collaborare",
    "collaboravamo": "collaborare",
    "collaboravan": "collaborare",
    "collaboravano": "collaborare",
    "collaboravate": "collaborare",
    "collaboravi": "collaborare",
    "collaboravo": "collaborare",
    "collaborazioni": "collaborazione",
    "collaborazionismi": "collaborazionismo",
    "collaborazioniste": "collaborazionista",
    "collaborazionisti": "collaborazionista",
    "collaborerai": "collaborare",
    "collaboreran": "collaborare",
    "collaboreranno": "collaborare",
    "collaborerebbe": "collaborare",
    "collaborerebber": "collaborare",
    "collaborerebbero": "collaborare",
    "collaborerei": "collaborare",
    "collaboreremmo": "collaborare",
    "collaboreremo": "collaborare",
    "collaborereste": "collaborare",
    "collaboreresti": "collaborare",
    "collaborerete": "collaborare",
    "collaborerà": "collaborare",
    "collaborerò": "collaborare",
    "collabori": "collaborare",
    "collaboriamo": "collaborare",
    "collaboriate": "collaborare",
    "collaborin": "collaborare",
    "collaborino": "collaborare",
    "collaboro": "collaborare",
    "collaborò": "collaborare",
    "collageni": "collagene",
    "collages": "collage",
    "collai": "collare",
    "collammo": "collare",
    "collan": "collare",
    "collando": "collare",
    "collane": "collana",
    "collanine": "collanina",
    "collano": "collare",
    "collante": "collare",
    "collanti": "collare",
    "collar": "collare",
    "collaron": "collare",
    "collarono": "collare",
    "collassa": "collassare",
    "collassai": "collassare",
    "collassammo": "collassare",
    "collassan": "collassare",
    "collassando": "collassare",
    "collassano": "collassare",
    "collassante": "collassare",
    "collassanti": "collassare",
    "collassar": "collassare",
    "collassaron": "collassare",
    "collassarono": "collassare",
    "collassasse": "collassare",
    "collassasser": "collassare",
    "collassassero": "collassare",
    "collassassi": "collassare",
    "collassassimo": "collassare",
    "collassaste": "collassare",
    "collassasti": "collassare",
    "collassata": "collassare",
    "collassate": "collassare",
    "collassati": "collassare",
    "collassato": "collassare",
    "collassava": "collassare",
    "collassavamo": "collassare",
    "collassavan": "collassare",
    "collassavano": "collassare",
    "collassavate": "collassare",
    "collassavi": "collassare",
    "collassavo": "collassare",
    "collasse": "collare",
    "collasser": "collare",
    "collasserai": "collassare",
    "collasseran": "collassare",
    "collasseranno": "collassare",
    "collasserebbe": "collassare",
    "collasserebber": "collassare",
    "collasserebbero": "collassare",
    "collasserei": "collassare",
    "collasseremmo": "collassare",
    "collasseremo": "collassare",
    "collassereste": "collassare",
    "collasseresti": "collassare",
    "collasserete": "collassare",
    "collassero": "collare",
    "collasserà": "collassare",
    "collasserò": "collassare",
    "collassi": "collasso",
    "collassiamo": "collassare",
    "collassiate": "collassare",
    "collassimo": "collare",
    "collassin": "collassare",
    "collassino": "collassare",
    "collasso": "collassare",
    "collassò": "collassare",
    "collaste": "collare",
    "collasti": "collare",
    "collata": "collare",
    "collate": "collare",
    "collaterali": "collaterale",
    "collateralismi": "collateralismo",
    "collati": "collare",
    "collato": "collare",
    "collauda": "collaudare",
    "collaudai": "collaudare",
    "collaudammo": "collaudare",
    "collaudan": "collaudare",
    "collaudando": "collaudare",
    "collaudano": "collaudare",
    "collaudante": "collaudare",
    "collaudanti": "collaudare",
    "collaudar": "collaudare",
    "collaudaron": "collaudare",
    "collaudarono": "collaudare",
    "collaudasse": "collaudare",
    "collaudasser": "collaudare",
    "collaudassero": "collaudare",
    "collaudassi": "collaudare",
    "collaudassimo": "collaudare",
    "collaudaste": "collaudare",
    "collaudasti": "collaudare",
    "collaudata": "collaudato",
    "collaudate": "collaudato",
    "collaudati": "collaudato",
    "collaudato": "collaudare",
    "collaudatori": "collaudatore",
    "collaudava": "collaudare",
    "collaudavamo": "collaudare",
    "collaudavan": "collaudare",
    "collaudavano": "collaudare",
    "collaudavate": "collaudare",
    "collaudavi": "collaudare",
    "collaudavo": "collaudare",
    "collauderai": "collaudare",
    "collauderan": "collaudare",
    "collauderanno": "collaudare",
    "collauderebbe": "collaudare",
    "collauderebber": "collaudare",
    "collauderebbero": "collaudare",
    "collauderei": "collaudare",
    "collauderemmo": "collaudare",
    "collauderemo": "collaudare",
    "collaudereste": "collaudare",
    "collauderesti": "collaudare",
    "collauderete": "collaudare",
    "collauderà": "collaudare",
    "collauderò": "collaudare",
    "collaudi": "collaudo",
    "collaudiamo": "collaudare",
    "collaudiate": "collaudare",
    "collaudin": "collaudare",
    "collaudino": "collaudare",
    "collaudo": "collaudare",
    "collaudò": "collaudare",
    "collava": "collare",
    "collavamo": "collare",
    "collavan": "collare",
    "collavano": "collare",
    "collavate": "collare",
    "collavi": "collare",
    "collavo": "collare",
    "collaziona": "collazionare",
    "collazionai": "collazionare",
    "collazionammo": "collazionare",
    "collazionan": "collazionare",
    "collazionando": "collazionare",
    "collazionano": "collazionare",
    "collazionante": "collazionare",
    "collazionanti": "collazionare",
    "collazionar": "collazionare",
    "collazionaron": "collazionare",
    "collazionarono": "collazionare",
    "collazionasse": "collazionare",
    "collazionasser": "collazionare",
    "collazionassero": "collazionare",
    "collazionassi": "collazionare",
    "collazionassimo": "collazionare",
    "collazionaste": "collazionare",
    "collazionasti": "collazionare",
    "collazionata": "collazionare",
    "collazionate": "collazionare",
    "collazionati": "collazionare",
    "collazionato": "collazionare",
    "collazionava": "collazionare",
    "collazionavamo": "collazionare",
    "collazionavan": "collazionare",
    "collazionavano": "collazionare",
    "collazionavate": "collazionare",
    "collazionavi": "collazionare",
    "collazionavo": "collazionare",
    "collazionerai": "collazionare",
    "collazioneran": "collazionare",
    "collazioneranno": "collazionare",
    "collazionerebbe": "collazionare",
    "collazionerebber": "collazionare",
    "collazionerebbero": "collazionare",
    "collazionerei": "collazionare",
    "collazioneremmo": "collazionare",
    "collazioneremo": "collazionare",
    "collazionereste": "collazionare",
    "collazioneresti": "collazionare",
    "collazionerete": "collazionare",
    "collazionerà": "collazionare",
    "collazionerò": "collazionare",
    "collazioni": "collazionare",
    "collazioniamo": "collazionare",
    "collazioniate": "collazionare",
    "collazionin": "collazionare",
    "collazionino": "collazionare",
    "collaziono": "collazionare",
    "collazionò": "collazionare",
    "colle": "colla",
    "collega": "collegare",
    "collegabili": "collegabile",
    "collegai": "collegare",
    "collegamenti": "collegamento",
    "collegammo": "collegare",
    "collegan": "collegare",
    "collegando": "collegare",
    "collegano": "collegare",
    "collegante": "collegare",
    "colleganti": "collegare",
    "collegar": "collegare",
    "collegaron": "collegare",
    "collegarono": "collegare",
    "collegasse": "collegare",
    "collegasser": "collegare",
    "collegassero": "collegare",
    "collegassi": "collegare",
    "collegassimo": "collegare",
    "collegaste": "collegare",
    "collegasti": "collegare",
    "collegata": "collegare",
    "collegate": "collegare",
    "collegati": "collegato",
    "collegato": "collegare",
    "collegava": "collegare",
    "collegavamo": "collegare",
    "collegavan": "collegare",
    "collegavano": "collegare",
    "collegavate": "collegare",
    "collegavi": "collegare",
    "collegavo": "collegare",
    "colleges": "college",
    "colleghe": "collega",
    "collegherai": "collegare",
    "collegheran": "collegare",
    "collegheranno": "collegare",
    "collegherebbe": "collegare",
    "collegherebber": "collegare",
    "collegherebbero": "collegare",
    "collegherei": "collegare",
    "collegheremmo": "collegare",
    "collegheremo": "collegare",
    "colleghereste": "collegare",
    "collegheresti": "collegare",
    "collegherete": "collegare",
    "collegherà": "collegare",
    "collegherò": "collegare",
    "colleghi": "collego",
    "colleghiamo": "collegare",
    "colleghiate": "collegare",
    "colleghin": "collegare",
    "colleghino": "collegare",
    "collegi": "collegio",
    "collegiali": "collegiale",
    "collegiata": "collegiato",
    "collegiate": "collegiato",
    "collegiati": "collegiato",
    "collego": "collegare",
    "collegò": "collegare",
    "collerai": "collare",
    "colleran": "collare",
    "colleranno": "collare",
    "collere": "collera",
    "collerebbe": "collare",
    "collerebber": "collare",
    "collerebbero": "collare",
    "collerei": "collare",
    "colleremmo": "collare",
    "colleremo": "collare",
    "collereste": "collare",
    "colleresti": "collare",
    "collerete": "collare",
    "collerica": "collerico",
    "colleriche": "collerico",
    "collerici": "collerico",
    "collerà": "collare",
    "collerò": "collare",
    "collette": "colletta",
    "colletti": "colletto",
    "collettini": "collettino",
    "collettiva": "collettivo",
    "collettive": "collettivo",
    "collettivi": "collettivo",
    "collettivismi": "collettivismo",
    "collettiviste": "collettivista",
    "collettivisti": "collettivista",
    "collettivistica": "collettivistico",
    "collettivistiche": "collettivistico",
    "collettivistici": "collettivistico",
    "collettivizza": "collettivizzare",
    "collettivizzai": "collettivizzare",
    "collettivizzammo": "collettivizzare",
    "collettivizzan": "collettivizzare",
    "collettivizzando": "collettivizzare",
    "collettivizzano": "collettivizzare",
    "collettivizzante": "collettivizzare",
    "collettivizzanti": "collettivizzare",
    "collettivizzar": "collettivizzare",
    "collettivizzaron": "collettivizzare",
    "collettivizzarono": "collettivizzare",
    "collettivizzasse": "collettivizzare",
    "collettivizzasser": "collettivizzare",
    "collettivizzassero": "collettivizzare",
    "collettivizzassi": "collettivizzare",
    "collettivizzassimo": "collettivizzare",
    "collettivizzaste": "collettivizzare",
    "collettivizzasti": "collettivizzare",
    "collettivizzata": "collettivizzare",
    "collettivizzate": "collettivizzare",
    "collettivizzati": "collettivizzare",
    "collettivizzato": "collettivizzare",
    "collettivizzava": "collettivizzare",
    "collettivizzavamo": "collettivizzare",
    "collettivizzavan": "collettivizzare",
    "collettivizzavano": "collettivizzare",
    "collettivizzavate": "collettivizzare",
    "collettivizzavi": "collettivizzare",
    "collettivizzavo": "collettivizzare",
    "collettivizzazioni": "collettivizzazione",
    "collettivizzerai": "collettivizzare",
    "collettivizzeran": "collettivizzare",
    "collettivizzeranno": "collettivizzare",
    "collettivizzerebbe": "collettivizzare",
    "collettivizzerebber": "collettivizzare",
    "collettivizzerebbero": "collettivizzare",
    "collettivizzerei": "collettivizzare",
    "collettivizzeremmo": "collettivizzare",
    "collettivizzeremo": "collettivizzare",
    "collettivizzereste": "collettivizzare",
    "collettivizzeresti": "collettivizzare",
    "collettivizzerete": "collettivizzare",
    "collettivizzerà": "collettivizzare",
    "collettivizzerò": "collettivizzare",
    "collettivizzi": "collettivizzare",
    "collettivizziamo": "collettivizzare",
    "collettivizziate": "collettivizzare",
    "collettivizzin": "collettivizzare",
    "collettivizzino": "collettivizzare",
    "collettivizzo": "collettivizzare",
    "collettivizzò": "collettivizzare",
    "collettori": "collettore",
    "collettrice": "collettore",
    "collettrici": "collettore",
    "colleziona": "collezionare",
    "collezionabili": "collezionabile",
    "collezionai": "collezionare",
    "collezionammo": "collezionare",
    "collezionan": "collezionare",
    "collezionando": "collezionare",
    "collezionano": "collezionare",
    "collezionante": "collezionare",
    "collezionanti": "collezionare",
    "collezionar": "collezionare",
    "collezionaron": "collezionare",
    "collezionarono": "collezionare",
    "collezionasse": "collezionare",
    "collezionasser": "collezionare",
    "collezionassero": "collezionare",
    "collezionassi": "collezionare",
    "collezionassimo": "collezionare",
    "collezionaste": "collezionare",
    "collezionasti": "collezionare",
    "collezionata": "collezionare",
    "collezionate": "collezionare",
    "collezionati": "collezionare",
    "collezionato": "collezionare",
    "collezionava": "collezionare",
    "collezionavamo": "collezionare",
    "collezionavan": "collezionare",
    "collezionavano": "collezionare",
    "collezionavate": "collezionare",
    "collezionavi": "collezionare",
    "collezionavo": "collezionare",
    "collezionerai": "collezionare",
    "collezioneran": "collezionare",
    "collezioneranno": "collezionare",
    "collezionerebbe": "collezionare",
    "collezionerebber": "collezionare",
    "collezionerebbero": "collezionare",
    "collezionerei": "collezionare",
    "collezioneremmo": "collezionare",
    "collezioneremo": "collezionare",
    "collezionereste": "collezionare",
    "collezioneresti": "collezionare",
    "collezionerete": "collezionare",
    "collezionerà": "collezionare",
    "collezionerò": "collezionare",
    "collezioni": "collezione",
    "collezioniamo": "collezionare",
    "collezioniate": "collezionare",
    "collezionin": "collezionare",
    "collezionino": "collezionare",
    "collezionismi": "collezionismo",
    "collezionisti": "collezionista",
    "collezionistica": "collezionistico",
    "collezionistiche": "collezionistico",
    "collezionistici": "collezionistico",
    "colleziono": "collezionare",
    "collezionò": "collezionare",
    "colli": "collo",
    "colliamo": "collare",
    "colliate": "collare",
    "collida": "collidere",
    "collidan": "collidere",
    "collidano": "collidere",
    "collide": "collidere",
    "collidei": "collidere",
    "collidemmo": "collidere",
    "collidendo": "collidere",
    "collidente": "collidere",
    "collidenti": "collidere",
    "collider": "collidere",
    "colliderai": "collidere",
    "collideran": "collidere",
    "collideranno": "collidere",
    "colliderebbe": "collidere",
    "colliderebber": "collidere",
    "colliderebbero": "collidere",
    "colliderei": "collidere",
    "collideremmo": "collidere",
    "collideremo": "collidere",
    "collidereste": "collidere",
    "collideresti": "collidere",
    "colliderete": "collidere",
    "collideron": "collidere",
    "colliderono": "collidere",
    "colliderà": "collidere",
    "colliderò": "collidere",
    "collidesse": "collidere",
    "collidesser": "collidere",
    "collidessero": "collidere",
    "collidessi": "collidere",
    "collidessimo": "collidere",
    "collideste": "collidere",
    "collidesti": "collidere",
    "collidete": "collidere",
    "collideva": "collidere",
    "collidevamo": "collidere",
    "collidevan": "collidere",
    "collidevano": "collidere",
    "collidevate": "collidere",
    "collidevi": "collidere",
    "collidevo": "collidere",
    "collidi": "collidere",
    "collidiamo": "collidere",
    "collidiate": "collidere",
    "collido": "collidere",
    "collidon": "collidere",
    "collidono": "collidere",
    "colliduta": "collidere",
    "collidute": "collidere",
    "colliduti": "collidere",
    "colliduto": "collidere",
    "collidè": "collidere",
    "collima": "collimare",
    "collimai": "collimare",
    "collimammo": "collimare",
    "colliman": "collimare",
    "collimando": "collimare",
    "collimano": "collimare",
    "collimante": "collimare",
    "collimanti": "collimare",
    "collimar": "collimare",
    "collimaron": "collimare",
    "collimarono": "collimare",
    "collimasse": "collimare",
    "collimasser": "collimare",
    "collimassero": "collimare",
    "collimassi": "collimare",
    "collimassimo": "collimare",
    "collimaste": "collimare",
    "collimasti": "collimare",
    "collimata": "collimare",
    "collimate": "collimare",
    "collimati": "collimare",
    "collimato": "collimare",
    "collimava": "collimare",
    "collimavamo": "collimare",
    "collimavan": "collimare",
    "collimavano": "collimare",
    "collimavate": "collimare",
    "collimavi": "collimare",
    "collimavo": "collimare",
    "collimerai": "collimare",
    "collimeran": "collimare",
    "collimeranno": "collimare",
    "collimerebbe": "collimare",
    "collimerebber": "collimare",
    "collimerebbero": "collimare",
    "collimerei": "collimare",
    "collimeremmo": "collimare",
    "collimeremo": "collimare",
    "collimereste": "collimare",
    "collimeresti": "collimare",
    "collimerete": "collimare",
    "collimerà": "collimare",
    "collimerò": "collimare",
    "collimi": "collimare",
    "collimiamo": "collimare",
    "collimiate": "collimare",
    "collimin": "collimare",
    "collimino": "collimare",
    "collimo": "collimare",
    "collimò": "collimare",
    "collin": "collare",
    "collinari": "collinare",
    "colline": "collina",
    "collinette": "collinetta",
    "collino": "collare",
    "collinosa": "collinoso",
    "collinose": "collinoso",
    "collinosi": "collinoso",
    "collisioni": "collisione",
    "collo": "collare",
    "colloca": "collocare",
    "collocabili": "collocabile",
    "collocai": "collocare",
    "collocamenti": "collocamento",
    "collocammo": "collocare",
    "collocan": "collocare",
    "collocando": "collocare",
    "collocano": "collocare",
    "collocante": "collocare",
    "collocanti": "collocare",
    "collocar": "collocare",
    "collocaron": "collocare",
    "collocarono": "collocare",
    "collocasse": "collocare",
    "collocasser": "collocare",
    "collocassero": "collocare",
    "collocassi": "collocare",
    "collocassimo": "collocare",
    "collocaste": "collocare",
    "collocasti": "collocare",
    "collocata": "collocare",
    "collocate": "collocare",
    "collocati": "collocare",
    "collocato": "collocare",
    "collocatori": "collocatore",
    "collocava": "collocare",
    "collocavamo": "collocare",
    "collocavan": "collocare",
    "collocavano": "collocare",
    "collocavate": "collocare",
    "collocavi": "collocare",
    "collocavo": "collocare",
    "collocazioni": "collocazione",
    "collocherai": "collocare",
    "collocheran": "collocare",
    "collocheranno": "collocare",
    "collocherebbe": "collocare",
    "collocherebber": "collocare",
    "collocherebbero": "collocare",
    "collocherei": "collocare",
    "collocheremmo": "collocare",
    "collocheremo": "collocare",
    "collochereste": "collocare",
    "collocheresti": "collocare",
    "collocherete": "collocare",
    "collocherà": "collocare",
    "collocherò": "collocare",
    "collochi": "collocare",
    "collochiamo": "collocare",
    "collochiate": "collocare",
    "collochin": "collocare",
    "collochino": "collocare",
    "colloco": "collocare",
    "collocò": "collocare",
    "colloqui": "colloquio",
    "colloquia": "colloquiare",
    "colloquiai": "colloquiare",
    "colloquiali": "colloquiale",
    "colloquiammo": "colloquiare",
    "colloquiamo": "colloquiare",
    "colloquian": "colloquiare",
    "colloquiando": "colloquiare",
    "colloquiano": "colloquiare",
    "colloquiante": "colloquiare",
    "colloquianti": "colloquiare",
    "colloquiar": "colloquiare",
    "colloquiaron": "colloquiare",
    "colloquiarono": "colloquiare",
    "colloquiasse": "colloquiare",
    "colloquiasser": "colloquiare",
    "colloquiassero": "colloquiare",
    "colloquiassi": "colloquiare",
    "colloquiassimo": "colloquiare",
    "colloquiaste": "colloquiare",
    "colloquiasti": "colloquiare",
    "colloquiata": "colloquiare",
    "colloquiate": "colloquiare",
    "colloquiati": "colloquiare",
    "colloquiato": "colloquiare",
    "colloquiava": "colloquiare",
    "colloquiavamo": "colloquiare",
    "colloquiavan": "colloquiare",
    "colloquiavano": "colloquiare",
    "colloquiavate": "colloquiare",
    "colloquiavi": "colloquiare",
    "colloquiavo": "colloquiare",
    "colloquierai": "colloquiare",
    "colloquieran": "colloquiare",
    "colloquieranno": "colloquiare",
    "colloquierebbe": "colloquiare",
    "colloquierebber": "colloquiare",
    "colloquierebbero": "colloquiare",
    "colloquierei": "colloquiare",
    "colloquieremmo": "colloquiare",
    "colloquieremo": "colloquiare",
    "colloquiereste": "colloquiare",
    "colloquieresti": "colloquiare",
    "colloquierete": "colloquiare",
    "colloquierà": "colloquiare",
    "colloquierò": "colloquiare",
    "colloquii": "colloquio",
    "colloquin": "colloquiare",
    "colloquino": "colloquiare",
    "colloquio": "colloquiare",
    "colloquiò": "colloquiare",
    "collosa": "colloso",
    "collose": "colloso",
    "collosi": "colloso",
    "colluda": "colludere",
    "colludan": "colludere",
    "colludano": "colludere",
    "collude": "colludere",
    "colludemmo": "colludere",
    "colludendo": "colludere",
    "colludente": "colludere",
    "colludenti": "colludere",
    "colluder": "colludere",
    "colluderai": "colludere",
    "colluderan": "colludere",
    "colluderanno": "colludere",
    "colluderebbe": "colludere",
    "colluderebber": "colludere",
    "colluderebbero": "colludere",
    "colluderei": "colludere",
    "colluderemmo": "colludere",
    "colluderemo": "colludere",
    "colludereste": "colludere",
    "colluderesti": "colludere",
    "colluderete": "colludere",
    "colluderà": "colludere",
    "colluderò": "colludere",
    "colludesse": "colludere",
    "colludesser": "colludere",
    "colludessero": "colludere",
    "colludessi": "colludere",
    "colludessimo": "colludere",
    "colludeste": "colludere",
    "colludesti": "colludere",
    "colludete": "colludere",
    "colludeva": "colludere",
    "colludevamo": "colludere",
    "colludevan": "colludere",
    "colludevano": "colludere",
    "colludevate": "colludere",
    "colludevi": "colludere",
    "colludevo": "colludere",
    "colludi": "colludere",
    "colludiamo": "colludere",
    "colludiate": "colludere",
    "colludo": "colludere",
    "colludon": "colludere",
    "colludono": "colludere",
    "collusa": "colludere",
    "colluse": "colludere",
    "colluser": "colludere",
    "collusero": "colludere",
    "collusi": "colluso",
    "collusioni": "collusione",
    "collusiva": "collusivo",
    "collusive": "collusivo",
    "collusivi": "collusivo",
    "colluso": "colludere",
    "collutta": "colluttare",
    "colluttai": "colluttare",
    "colluttammo": "colluttare",
    "colluttan": "colluttare",
    "colluttando": "colluttare",
    "colluttano": "colluttare",
    "colluttante": "colluttare",
    "colluttanti": "colluttare",
    "colluttar": "colluttare",
    "colluttaron": "colluttare",
    "colluttarono": "colluttare",
    "colluttasse": "colluttare",
    "colluttasser": "colluttare",
    "colluttassero": "colluttare",
    "colluttassi": "colluttare",
    "colluttassimo": "colluttare",
    "colluttaste": "colluttare",
    "colluttasti": "colluttare",
    "colluttata": "colluttare",
    "colluttate": "colluttare",
    "colluttati": "colluttare",
    "colluttato": "colluttare",
    "colluttava": "colluttare",
    "colluttavamo": "colluttare",
    "colluttavan": "colluttare",
    "colluttavano": "colluttare",
    "colluttavate": "colluttare",
    "colluttavi": "colluttare",
    "colluttavo": "colluttare",
    "colluttazioni": "colluttazione",
    "collutterai": "colluttare",
    "collutteran": "colluttare",
    "collutteranno": "colluttare",
    "collutterebbe": "colluttare",
    "collutterebber": "colluttare",
    "collutterebbero": "colluttare",
    "collutterei": "colluttare",
    "collutteremmo": "colluttare",
    "collutteremo": "colluttare",
    "colluttereste": "colluttare",
    "collutteresti": "colluttare",
    "collutterete": "colluttare",
    "collutterà": "colluttare",
    "collutterò": "colluttare",
    "collutti": "colluttare",
    "colluttiamo": "colluttare",
    "colluttiate": "colluttare",
    "colluttin": "colluttare",
    "colluttino": "colluttare",
    "collutto": "colluttare",
    "colluttori": "colluttorio",
    "colluttò": "colluttare",
    "collò": "collare",
    "colma": "colmo",
    "colmabili": "colmabile",
    "colmai": "colmare",
    "colmammo": "colmare",
    "colman": "colmare",
    "colmando": "colmare",
    "colmano": "colmare",
    "colmante": "colmare",
    "colmanti": "colmare",
    "colmar": "colmare",
    "colmaron": "colmare",
    "colmarono": "colmare",
    "colmasse": "colmare",
    "colmasser": "colmare",
    "colmassero": "colmare",
    "colmassi": "colmare",
    "colmassimo": "colmare",
    "colmaste": "colmare",
    "colmasti": "colmare",
    "colmata": "colmare",
    "colmate": "colmare",
    "colmati": "colmare",
    "colmato": "colmare",
    "colmava": "colmare",
    "colmavamo": "colmare",
    "colmavan": "colmare",
    "colmavano": "colmare",
    "colmavate": "colmare",
    "colmavi": "colmare",
    "colmavo": "colmare",
    "colme": "colmo",
    "colmerai": "colmare",
    "colmeran": "colmare",
    "colmeranno": "colmare",
    "colmerebbe": "colmare",
    "colmerebber": "colmare",
    "colmerebbero": "colmare",
    "colmerei": "colmare",
    "colmeremmo": "colmare",
    "colmeremo": "colmare",
    "colmereste": "colmare",
    "colmeresti": "colmare",
    "colmerete": "colmare",
    "colmerà": "colmare",
    "colmerò": "colmare",
    "colmi": "colmo",
    "colmiamo": "colmare",
    "colmiate": "colmare",
    "colmin": "colmare",
    "colmino": "colmare",
    "colmo": "colmare",
    "colmò": "colmare",
    "colo": "colare",
    "colombe": "colomba",
    "colombi": "colombo",
    "colombiana": "colombiano",
    "colombiane": "colombiano",
    "colombiani": "colombiano",
    "colonelli": "colonello",
    "coloni": "colono",
    "coloniali": "coloniale",
    "colonialismi": "colonialismo",
    "colonialiste": "colonialista",
    "colonialisti": "colonialista",
    "colonialistica": "colonialistico",
    "colonialistiche": "colonialistico",
    "colonialistici": "colonialistico",
    "colonica": "colonico",
    "coloniche": "colonico",
    "colonici": "colonico",
    "colonie": "colonia",
    "colonizza": "colonizzare",
    "colonizzai": "colonizzare",
    "colonizzammo": "colonizzare",
    "colonizzan": "colonizzare",
    "colonizzando": "colonizzare",
    "colonizzano": "colonizzare",
    "colonizzante": "colonizzare",
    "colonizzanti": "colonizzare",
    "colonizzar": "colonizzare",
    "colonizzaron": "colonizzare",
    "colonizzarono": "colonizzare",
    "colonizzasse": "colonizzare",
    "colonizzasser": "colonizzare",
    "colonizzassero": "colonizzare",
    "colonizzassi": "colonizzare",
    "colonizzassimo": "colonizzare",
    "colonizzaste": "colonizzare",
    "colonizzasti": "colonizzare",
    "colonizzata": "colonizzare",
    "colonizzate": "colonizzare",
    "colonizzati": "colonizzato",
    "colonizzato": "colonizzare",
    "colonizzatori": "colonizzatore",
    "colonizzava": "colonizzare",
    "colonizzavamo": "colonizzare",
    "colonizzavan": "colonizzare",
    "colonizzavano": "colonizzare",
    "colonizzavate": "colonizzare",
    "colonizzavi": "colonizzare",
    "colonizzavo": "colonizzare",
    "colonizzazioni": "colonizzazione",
    "colonizzerai": "colonizzare",
    "colonizzeran": "colonizzare",
    "colonizzeranno": "colonizzare",
    "colonizzerebbe": "colonizzare",
    "colonizzerebber": "colonizzare",
    "colonizzerebbero": "colonizzare",
    "colonizzerei": "colonizzare",
    "colonizzeremmo": "colonizzare",
    "colonizzeremo": "colonizzare",
    "colonizzereste": "colonizzare",
    "colonizzeresti": "colonizzare",
    "colonizzerete": "colonizzare",
    "colonizzerà": "colonizzare",
    "colonizzerò": "colonizzare",
    "colonizzi": "colonizzare",
    "colonizziamo": "colonizzare",
    "colonizziate": "colonizzare",
    "colonizzin": "colonizzare",
    "colonizzino": "colonizzare",
    "colonizzo": "colonizzare",
    "colonizzò": "colonizzare",
    "colonna": "colonnare",
    "colonnai": "colonnare",
    "colonnammo": "colonnare",
    "colonnan": "colonnare",
    "colonnando": "colonnare",
    "colonnano": "colonnare",
    "colonnante": "colonnare",
    "colonnanti": "colonnare",
    "colonnar": "colonnare",
    "colonnaron": "colonnare",
    "colonnarono": "colonnare",
    "colonnasse": "colonnare",
    "colonnasser": "colonnare",
    "colonnassero": "colonnare",
    "colonnassi": "colonnare",
    "colonnassimo": "colonnare",
    "colonnaste": "colonnare",
    "colonnasti": "colonnare",
    "colonnata": "colonnare",
    "colonnate": "colonnare",
    "colonnati": "colonnato",
    "colonnato": "colonnare",
    "colonnava": "colonnare",
    "colonnavamo": "colonnare",
    "colonnavan": "colonnare",
    "colonnavano": "colonnare",
    "colonnavate": "colonnare",
    "colonnavi": "colonnare",
    "colonnavo": "colonnare",
    "colonne": "colonna",
    "colonnelli": "colonnello",
    "colonnerai": "colonnare",
    "colonneran": "colonnare",
    "colonneranno": "colonnare",
    "colonnerebbe": "colonnare",
    "colonnerebber": "colonnare",
    "colonnerebbero": "colonnare",
    "colonnerei": "colonnare",
    "colonneremmo": "colonnare",
    "colonneremo": "colonnare",
    "colonnereste": "colonnare",
    "colonneresti": "colonnare",
    "colonnerete": "colonnare",
    "colonnerà": "colonnare",
    "colonnerò": "colonnare",
    "colonni": "colonnare",
    "colonniamo": "colonnare",
    "colonniate": "colonnare",
    "colonnin": "colonnare",
    "colonnine": "colonnina",
    "colonnino": "colonnare",
    "colonno": "colonnare",
    "colonnò": "colonnare",
    "colonscopica": "colonscopico",
    "colonscopiche": "colonscopico",
    "colonscopici": "colonscopico",
    "color": "colore",
    "colora": "colorire",
    "colorai": "colorare",
    "colorammo": "colorare",
    "coloran": "colorire",
    "colorando": "colorare",
    "colorano": "colorire",
    "colorante": "colorare",
    "coloranti": "colorare",
    "colorar": "colorare",
    "coloraron": "colorare",
    "colorarono": "colorare",
    "colorasse": "colorare",
    "colorasser": "colorare",
    "colorassero": "colorare",
    "colorassi": "colorare",
    "colorassimo": "colorare",
    "coloraste": "colorare",
    "colorasti": "colorare",
    "colorata": "colorato",
    "colorate": "colorato",
    "colorati": "colorato",
    "colorato": "colorare",
    "colorature": "coloratura",
    "colorava": "colorare",
    "coloravamo": "colorare",
    "coloravan": "colorare",
    "coloravano": "colorare",
    "coloravate": "colorare",
    "coloravi": "colorare",
    "coloravo": "colorare",
    "colorazioni": "colorazione",
    "colore": "colorire",
    "colorendo": "colorire",
    "colorente": "colorire",
    "colorenti": "colorire",
    "colorerai": "colorare",
    "coloreran": "colorare",
    "coloreranno": "colorare",
    "colorerebbe": "colorare",
    "colorerebber": "colorare",
    "colorerebbero": "colorare",
    "colorerei": "colorare",
    "coloreremmo": "colorare",
    "coloreremo": "colorare",
    "colorereste": "colorare",
    "coloreresti": "colorare",
    "colorerete": "colorare",
    "colorerà": "colorare",
    "colorerò": "colorare",
    "colori": "colorire",
    "coloriamo": "colorire",
    "coloriate": "colorire",
    "colorii": "colorire",
    "colorimmo": "colorire",
    "colorin": "colorare",
    "colorini": "colorino",
    "colorino": "colorare",
    "colorir": "colorire",
    "colorirai": "colorire",
    "coloriran": "colorire",
    "coloriranno": "colorire",
    "colorirebbe": "colorire",
    "colorirebber": "colorire",
    "colorirebbero": "colorire",
    "colorirei": "colorire",
    "coloriremmo": "colorire",
    "coloriremo": "colorire",
    "colorireste": "colorire",
    "coloriresti": "colorire",
    "colorirete": "colorire",
    "coloriron": "colorire",
    "colorirono": "colorire",
    "colorirà": "colorire",
    "colorirò": "colorire",
    "colorisse": "colorire",
    "colorisser": "colorire",
    "colorissero": "colorire",
    "colorissi": "colorire",
    "colorissimo": "colorire",
    "coloriste": "colorire",
    "coloristi": "colorista",
    "coloristica": "coloristico",
    "coloristiche": "coloristico",
    "coloristici": "coloristico",
    "colorita": "colorito",
    "colorite": "colorito",
    "coloriti": "colorito",
    "colorito": "colorire",
    "coloriture": "coloritura",
    "coloriva": "colorire",
    "colorivamo": "colorire",
    "colorivan": "colorire",
    "colorivano": "colorire",
    "colorivate": "colorire",
    "colorivi": "colorire",
    "colorivo": "colorire",
    "coloro": "colorire",
    "coloron": "colorire",
    "colorono": "colorire",
    "colorì": "colorire",
    "colorò": "colorare",
    "colossali": "colossale",
    "colossi": "colosso",
    "colpacci": "colpaccio",
    "colpe": "colpa",
    "colpendo": "colpire",
    "colpente": "colpire",
    "colpenti": "colpire",
    "colpetti": "colpetto",
    "colpevolezze": "colpevolezza",
    "colpevoli": "colpevole",
    "colpevolizza": "colpevolizzare",
    "colpevolizzai": "colpevolizzare",
    "colpevolizzammo": "colpevolizzare",
    "colpevolizzan": "colpevolizzare",
    "colpevolizzando": "colpevolizzare",
    "colpevolizzano": "colpevolizzare",
    "colpevolizzante": "colpevolizzare",
    "colpevolizzanti": "colpevolizzare",
    "colpevolizzar": "colpevolizzare",
    "colpevolizzaron": "colpevolizzare",
    "colpevolizzarono": "colpevolizzare",
    "colpevolizzasse": "colpevolizzare",
    "colpevolizzasser": "colpevolizzare",
    "colpevolizzassero": "colpevolizzare",
    "colpevolizzassi": "colpevolizzare",
    "colpevolizzassimo": "colpevolizzare",
    "colpevolizzaste": "colpevolizzare",
    "colpevolizzasti": "colpevolizzare",
    "colpevolizzata": "colpevolizzare",
    "colpevolizzate": "colpevolizzare",
    "colpevolizzati": "colpevolizzare",
    "colpevolizzato": "colpevolizzare",
    "colpevolizzava": "colpevolizzare",
    "colpevolizzavamo": "colpevolizzare",
    "colpevolizzavan": "colpevolizzare",
    "colpevolizzavano": "colpevolizzare",
    "colpevolizzavate": "colpevolizzare",
    "colpevolizzavi": "colpevolizzare",
    "colpevolizzavo": "colpevolizzare",
    "colpevolizzerai": "colpevolizzare",
    "colpevolizzeran": "colpevolizzare",
    "colpevolizzeranno": "colpevolizzare",
    "colpevolizzerebbe": "colpevolizzare",
    "colpevolizzerebber": "colpevolizzare",
    "colpevolizzerebbero": "colpevolizzare",
    "colpevolizzerei": "colpevolizzare",
    "colpevolizzeremmo": "colpevolizzare",
    "colpevolizzeremo": "colpevolizzare",
    "colpevolizzereste": "colpevolizzare",
    "colpevolizzeresti": "colpevolizzare",
    "colpevolizzerete": "colpevolizzare",
    "colpevolizzerà": "colpevolizzare",
    "colpevolizzerò": "colpevolizzare",
    "colpevolizzi": "colpevolizzare",
    "colpevolizziamo": "colpevolizzare",
    "colpevolizziate": "colpevolizzare",
    "colpevolizzin": "colpevolizzare",
    "colpevolizzino": "colpevolizzare",
    "colpevolizzo": "colpevolizzare",
    "colpevolizzò": "colpevolizzare",
    "colpi": "colpo",
    "colpiamo": "colpire",
    "colpiate": "colpire",
    "colpii": "colpire",
    "colpimmo": "colpire",
    "colpir": "colpire",
    "colpirai": "colpire",
    "colpiran": "colpire",
    "colpiranno": "colpire",
    "colpirebbe": "colpire",
    "colpirebber": "colpire",
    "colpirebbero": "colpire",
    "colpirei": "colpire",
    "colpiremmo": "colpire",
    "colpiremo": "colpire",
    "colpireste": "colpire",
    "colpiresti": "colpire",
    "colpirete": "colpire",
    "colpiron": "colpire",
    "colpirono": "colpire",
    "colpirà": "colpire",
    "colpirò": "colpire",
    "colpisca": "colpire",
    "colpiscan": "colpire",
    "colpiscano": "colpire",
    "colpisce": "colpire",
    "colpisci": "colpire",
    "colpisco": "colpire",
    "colpiscon": "colpire",
    "colpiscono": "colpire",
    "colpisse": "colpire",
    "colpisser": "colpire",
    "colpissero": "colpire",
    "colpissi": "colpire",
    "colpissimo": "colpire",
    "colpiste": "colpire",
    "colpisti": "colpire",
    "colpita": "colpire",
    "colpite": "colpire",
    "colpiti": "colpire",
    "colpito": "colpire",
    "colpiva": "colpire",
    "colpivamo": "colpire",
    "colpivan": "colpire",
    "colpivano": "colpire",
    "colpivate": "colpire",
    "colpivi": "colpire",
    "colpivo": "colpire",
    "colposa": "colposo",
    "colpose": "colposo",
    "colposi": "colposo",
    "colpì": "colpire",
    "colse": "cogliere",
    "colser": "cogliere",
    "colsero": "cogliere",
    "colsi": "cogliere",
    "colta": "colto",
    "colte": "colto",
    "coltellacci": "coltellaccio",
    "coltellate": "coltellata",
    "coltelli": "coltello",
    "coltellini": "coltellino",
    "colti": "colto",
    "coltiva": "coltivo",
    "coltivabili": "coltivabile",
    "coltivai": "coltivare",
    "coltivammo": "coltivare",
    "coltivan": "coltivare",
    "coltivando": "coltivare",
    "coltivano": "coltivare",
    "coltivante": "coltivare",
    "coltivanti": "coltivare",
    "coltivar": "coltivare",
    "coltivaron": "coltivare",
    "coltivarono": "coltivare",
    "coltivasse": "coltivare",
    "coltivasser": "coltivare",
    "coltivassero": "coltivare",
    "coltivassi": "coltivare",
    "coltivassimo": "coltivare",
    "coltivaste": "coltivare",
    "coltivasti": "coltivare",
    "coltivata": "coltivato",
    "coltivate": "coltivato",
    "coltivati": "coltivato",
    "coltivato": "coltivare",
    "coltivatori": "coltivatore",
    "coltivava": "coltivare",
    "coltivavamo": "coltivare",
    "coltivavan": "coltivare",
    "coltivavano": "coltivare",
    "coltivavate": "coltivare",
    "coltivavi": "coltivare",
    "coltivavo": "coltivare",
    "coltivazioni": "coltivazione",
    "coltive": "coltivo",
    "coltiverai": "coltivare",
    "coltiveran": "coltivare",
    "coltiveranno": "coltivare",
    "coltiverebbe": "coltivare",
    "coltiverebber": "coltivare",
    "coltiverebbero": "coltivare",
    "coltiverei": "coltivare",
    "coltiveremmo": "coltivare",
    "coltiveremo": "coltivare",
    "coltivereste": "coltivare",
    "coltiveresti": "coltivare",
    "coltiverete": "coltivare",
    "coltiverà": "coltivare",
    "coltiverò": "coltivare",
    "coltivi": "coltivo",
    "coltiviamo": "coltivare",
    "coltiviate": "coltivare",
    "coltivin": "coltivare",
    "coltivino": "coltivare",
    "coltivo": "coltivare",
    "coltivò": "coltivare",
    "colto": "cogliere",
    "coltri": "coltre",
    "colture": "coltura",
    "colubrine": "colubrina",
    "colò": "colare",
    "com'": "come",
    "comanda": "comandare",
    "comandabili": "comandabile",
    "comandai": "comandare",
    "comandamenti": "comandamento",
    "comandammo": "comandare",
    "comandan": "comandare",
    "comandando": "comandare",
    "comandano": "comandare",
    "comandante": "comandare",
    "comandanti": "comandare",
    "comandar": "comandare",
    "comandaron": "comandare",
    "comandarono": "comandare",
    "comandasse": "comandare",
    "comandasser": "comandare",
    "comandassero": "comandare",
    "comandassi": "comandare",
    "comandassimo": "comandare",
    "comandaste": "comandare",
    "comandasti": "comandare",
    "comandata": "comandato",
    "comandate": "comandato",
    "comandati": "comandato",
    "comandato": "comandare",
    "comandava": "comandare",
    "comandavamo": "comandare",
    "comandavan": "comandare",
    "comandavano": "comandare",
    "comandavate": "comandare",
    "comandavi": "comandare",
    "comandavo": "comandare",
    "comanderai": "comandare",
    "comanderan": "comandare",
    "comanderanno": "comandare",
    "comanderebbe": "comandare",
    "comanderebber": "comandare",
    "comanderebbero": "comandare",
    "comanderei": "comandare",
    "comanderemmo": "comandare",
    "comanderemo": "comandare",
    "comandereste": "comandare",
    "comanderesti": "comandare",
    "comanderete": "comandare",
    "comanderà": "comandare",
    "comanderò": "comandare",
    "comandi": "comando",
    "comandiamo": "comandare",
    "comandiate": "comandare",
    "comandin": "comandare",
    "comandino": "comandare",
    "comando": "comandare",
    "comandò": "comandare",
    "comari": "comare",
    "comaschi": "comasco",
    "comatosa": "comatoso",
    "comatose": "comatoso",
    "comatosi": "comatoso",
    "combacerai": "combaciare",
    "combaceran": "combaciare",
    "combaceranno": "combaciare",
    "combacerebbe": "combaciare",
    "combacerebber": "combaciare",
    "combacerebbero": "combaciare",
    "combacerei": "combaciare",
    "combaceremmo": "combaciare",
    "combaceremo": "combaciare",
    "combacereste": "combaciare",
    "combaceresti": "combaciare",
    "combacerete": "combaciare",
    "combacerà": "combaciare",
    "combacerò": "combaciare",
    "combaci": "combaciare",
    "combacia": "combaciare",
    "combaciai": "combaciare",
    "combaciammo": "combaciare",
    "combaciamo": "combaciare",
    "combacian": "combaciare",
    "combaciando": "combaciare",
    "combaciano": "combaciare",
    "combaciante": "combaciare",
    "combacianti": "combaciare",
    "combaciar": "combaciare",
    "combaciaron": "combaciare",
    "combaciarono": "combaciare",
    "combaciasse": "combaciare",
    "combaciasser": "combaciare",
    "combaciassero": "combaciare",
    "combaciassi": "combaciare",
    "combaciassimo": "combaciare",
    "combaciaste": "combaciare",
    "combaciasti": "combaciare",
    "combaciata": "combaciare",
    "combaciate": "combaciare",
    "combaciati": "combaciare",
    "combaciato": "combaciare",
    "combaciava": "combaciare",
    "combaciavamo": "combaciare",
    "combaciavan": "combaciare",
    "combaciavano": "combaciare",
    "combaciavate": "combaciare",
    "combaciavi": "combaciare",
    "combaciavo": "combaciare",
    "combacin": "combaciare",
    "combacino": "combaciare",
    "combacio": "combaciare",
    "combaciò": "combaciare",
    "combatta": "combattere",
    "combattan": "combattere",
    "combattano": "combattere",
    "combatte": "combattere",
    "combattei": "combattere",
    "combattemmo": "combattere",
    "combattendo": "combattere",
    "combattente": "combattere",
    "combattenti": "combattere",
    "combatter": "combattere",
    "combatterai": "combattere",
    "combatteran": "combattere",
    "combatteranno": "combattere",
    "combatterebbe": "combattere",
    "combatterebber": "combattere",
    "combatterebbero": "combattere",
    "combatterei": "combattere",
    "combatteremmo": "combattere",
    "combatteremo": "combattere",
    "combattereste": "combattere",
    "combatteresti": "combattere",
    "combatterete": "combattere",
    "combatteron": "combattere",
    "combatterono": "combattere",
    "combatterà": "combattere",
    "combatterò": "combattere",
    "combattesse": "combattere",
    "combattesser": "combattere",
    "combattessero": "combattere",
    "combattessi": "combattere",
    "combattessimo": "combattere",
    "combatteste": "combattere",
    "combattesti": "combattere",
    "combattete": "combattere",
    "combatteva": "combattere",
    "combattevamo": "combattere",
    "combattevan": "combattere",
    "combattevano": "combattere",
    "combattevate": "combattere",
    "combattevi": "combattere",
    "combattevo": "combattere",
    "combatti": "combattere",
    "combattiamo": "combattere",
    "combattiate": "combattere",
    "combattimenti": "combattimento",
    "combattiva": "combattivo",
    "combattive": "combattivo",
    "combattivi": "combattivo",
    "combatto": "combattere",
    "combatton": "combattere",
    "combattono": "combattere",
    "combattuta": "combattuto",
    "combattute": "combattuto",
    "combattuti": "combattuto",
    "combattuto": "combattere",
    "combattè": "combattere",
    "combina": "combinare",
    "combinai": "combinare",
    "combinammo": "combinare",
    "combinan": "combinare",
    "combinando": "combinare",
    "combinano": "combinare",
    "combinante": "combinare",
    "combinanti": "combinare",
    "combinar": "combinare",
    "combinaron": "combinare",
    "combinarono": "combinare",
    "combinasse": "combinare",
    "combinasser": "combinare",
    "combinassero": "combinare",
    "combinassi": "combinare",
    "combinassimo": "combinare",
    "combinaste": "combinare",
    "combinasti": "combinare",
    "combinata": "combinato",
    "combinate": "combinato",
    "combinati": "combinato",
    "combinato": "combinare",
    "combinatori": "combinatorio",
    "combinatoria": "combinatorio",
    "combinatorie": "combinatorio",
    "combinava": "combinare",
    "combinavamo": "combinare",
    "combinavan": "combinare",
    "combinavano": "combinare",
    "combinavate": "combinare",
    "combinavi": "combinare",
    "combinavo": "combinare",
    "combinazioni": "combinazione",
    "combinerai": "combinare",
    "combineran": "combinare",
    "combineranno": "combinare",
    "combinerebbe": "combinare",
    "combinerebber": "combinare",
    "combinerebbero": "combinare",
    "combinerei": "combinare",
    "combineremmo": "combinare",
    "combineremo": "combinare",
    "combinereste": "combinare",
    "combineresti": "combinare",
    "combinerete": "combinare",
    "combinerà": "combinare",
    "combinerò": "combinare",
    "combini": "combinare",
    "combiniamo": "combinare",
    "combiniate": "combinare",
    "combinin": "combinare",
    "combinino": "combinare",
    "combino": "combinare",
    "combinò": "combinare",
    "combriccole": "combriccola",
    "combusta": "combusto",
    "combuste": "combusto",
    "combusti": "combusto",
    "combustibili": "combustibile",
    "combustioni": "combustione",
    "comete": "cometa",
    "comi": "coma",
    "comica": "comico",
    "comiche": "comico",
    "comici": "comico",
    "comicizza": "comicizzare",
    "comicizzai": "comicizzare",
    "comicizzammo": "comicizzare",
    "comicizzan": "comicizzare",
    "comicizzando": "comicizzare",
    "comicizzano": "comicizzare",
    "comicizzante": "comicizzare",
    "comicizzanti": "comicizzare",
    "comicizzar": "comicizzare",
    "comicizzaron": "comicizzare",
    "comicizzarono": "comicizzare",
    "comicizzasse": "comicizzare",
    "comicizzasser": "comicizzare",
    "comicizzassero": "comicizzare",
    "comicizzassi": "comicizzare",
    "comicizzassimo": "comicizzare",
    "comicizzaste": "comicizzare",
    "comicizzasti": "comicizzare",
    "comicizzata": "comicizzare",
    "comicizzate": "comicizzare",
    "comicizzati": "comicizzare",
    "comicizzato": "comicizzare",
    "comicizzava": "comicizzare",
    "comicizzavamo": "comicizzare",
    "comicizzavan": "comicizzare",
    "comicizzavano": "comicizzare",
    "comicizzavate": "comicizzare",
    "comicizzavi": "comicizzare",
    "comicizzavo": "comicizzare",
    "comicizzerai": "comicizzare",
    "comicizzeran": "comicizzare",
    "comicizzeranno": "comicizzare",
    "comicizzerebbe": "comicizzare",
    "comicizzerebber": "comicizzare",
    "comicizzerebbero": "comicizzare",
    "comicizzerei": "comicizzare",
    "comicizzeremmo": "comicizzare",
    "comicizzeremo": "comicizzare",
    "comicizzereste": "comicizzare",
    "comicizzeresti": "comicizzare",
    "comicizzerete": "comicizzare",
    "comicizzerà": "comicizzare",
    "comicizzerò": "comicizzare",
    "comicizzi": "comicizzare",
    "comicizziamo": "comicizzare",
    "comicizziate": "comicizzare",
    "comicizzin": "comicizzare",
    "comicizzino": "comicizzare",
    "comicizzo": "comicizzare",
    "comicizzò": "comicizzare",
    "comignoli": "comignolo",
    "comincerai": "cominciare",
    "cominceran": "cominciare",
    "cominceranno": "cominciare",
    "comincerebbe": "cominciare",
    "comincerebber": "cominciare",
    "comincerebbero": "cominciare",
    "comincerei": "cominciare",
    "cominceremmo": "cominciare",
    "cominceremo": "cominciare",
    "comincereste": "cominciare",
    "cominceresti": "cominciare",
    "comincerete": "cominciare",
    "comincerà": "cominciare",
    "comincerò": "cominciare",
    "cominci": "cominciare",
    "comincia": "cominciare",
    "cominciai": "cominciare",
    "cominciammo": "cominciare",
    "cominciamo": "cominciare",
    "comincian": "cominciare",
    "cominciando": "cominciare",
    "cominciano": "cominciare",
    "cominciante": "cominciare",
    "comincianti": "cominciare",
    "cominciar": "cominciare",
    "cominciaron": "cominciare",
    "cominciarono": "cominciare",
    "cominciasse": "cominciare",
    "cominciasser": "cominciare",
    "cominciassero": "cominciare",
    "cominciassi": "cominciare",
    "cominciassimo": "cominciare",
    "cominciaste": "cominciare",
    "cominciasti": "cominciare",
    "cominciata": "cominciare",
    "cominciate": "cominciare",
    "cominciati": "cominciare",
    "cominciato": "cominciare",
    "cominciava": "cominciare",
    "cominciavamo": "cominciare",
    "cominciavan": "cominciare",
    "cominciavano": "cominciare",
    "cominciavate": "cominciare",
    "cominciavi": "cominciare",
    "cominciavo": "cominciare",
    "comincin": "cominciare",
    "comincino": "cominciare",
    "comincio": "cominciare",
    "cominciò": "cominciare",
    "comissioni": "comissione",
    "comitali": "comitale",
    "comitati": "comitato",
    "comitive": "comitiva",
    "comizi": "comizio",
    "comiziali": "comiziale",
    "commandos": "commando",
    "commedianti": "commediante",
    "commedie": "commedia",
    "commediografi": "commediografo",
    "commediole": "commediola",
    "commemora": "commemorare",
    "commemorai": "commemorare",
    "commemorammo": "commemorare",
    "commemoran": "commemorare",
    "commemorando": "commemorare",
    "commemorano": "commemorare",
    "commemorante": "commemorare",
    "commemoranti": "commemorare",
    "commemorar": "commemorare",
    "commemoraron": "commemorare",
    "commemorarono": "commemorare",
    "commemorasse": "commemorare",
    "commemorasser": "commemorare",
    "commemorassero": "commemorare",
    "commemorassi": "commemorare",
    "commemorassimo": "commemorare",
    "commemoraste": "commemorare",
    "commemorasti": "commemorare",
    "commemorata": "commemorare",
    "commemorate": "commemorare",
    "commemorati": "commemorare",
    "commemorativa": "commemorativo",
    "commemorative": "commemorativo",
    "commemorativi": "commemorativo",
    "commemorato": "commemorare",
    "commemorava": "commemorare",
    "commemoravamo": "commemorare",
    "commemoravan": "commemorare",
    "commemoravano": "commemorare",
    "commemoravate": "commemorare",
    "commemoravi": "commemorare",
    "commemoravo": "commemorare",
    "commemorazioni": "commemorazione",
    "commemorerai": "commemorare",
    "commemoreran": "commemorare",
    "commemoreranno": "commemorare",
    "commemorerebbe": "commemorare",
    "commemorerebber": "commemorare",
    "commemorerebbero": "commemorare",
    "commemorerei": "commemorare",
    "commemoreremmo": "commemorare",
    "commemoreremo": "commemorare",
    "commemorereste": "commemorare",
    "commemoreresti": "commemorare",
    "commemorerete": "commemorare",
    "commemorerà": "commemorare",
    "commemorerò": "commemorare",
    "commemori": "commemorare",
    "commemoriamo": "commemorare",
    "commemoriate": "commemorare",
    "commemorin": "commemorare",
    "commemorino": "commemorare",
    "commemoro": "commemorare",
    "commemorò": "commemorare",
    "commenda": "commendare",
    "commendai": "commendare",
    "commendammo": "commendare",
    "commendan": "commendare",
    "commendando": "commendare",
    "commendano": "commendare",
    "commendante": "commendare",
    "commendanti": "commendare",
    "commendar": "commendare",
    "commendaron": "commendare",
    "commendarono": "commendare",
    "commendasse": "commendare",
    "commendasser": "commendare",
    "commendassero": "commendare",
    "commendassi": "commendare",
    "commendassimo": "commendare",
    "commendaste": "commendare",
    "commendasti": "commendare",
    "commendata": "commendare",
    "commendate": "commendare",
    "commendati": "commendare",
    "commendato": "commendare",
    "commendator": "commendatore",
    "commendatori": "commendatore",
    "commendava": "commendare",
    "commendavamo": "commendare",
    "commendavan": "commendare",
    "commendavano": "commendare",
    "commendavate": "commendare",
    "commendavi": "commendare",
    "commendavo": "commendare",
    "commenderai": "commendare",
    "commenderan": "commendare",
    "commenderanno": "commendare",
    "commenderebbe": "commendare",
    "commenderebber": "commendare",
    "commenderebbero": "commendare",
    "commenderei": "commendare",
    "commenderemmo": "commendare",
    "commenderemo": "commendare",
    "commendereste": "commendare",
    "commenderesti": "commendare",
    "commenderete": "commendare",
    "commenderà": "commendare",
    "commenderò": "commendare",
    "commendevoli": "commendevole",
    "commendi": "commendare",
    "commendiamo": "commendare",
    "commendiate": "commendare",
    "commendin": "commendare",
    "commendino": "commendare",
    "commendo": "commendare",
    "commendò": "commendare",
    "commensali": "commensale",
    "commensura": "commensurare",
    "commensurabili": "commensurabile",
    "commensurai": "commensurare",
    "commensurammo": "commensurare",
    "commensuran": "commensurare",
    "commensurando": "commensurare",
    "commensurano": "commensurare",
    "commensurante": "commensurare",
    "commensuranti": "commensurare",
    "commensurar": "commensurare",
    "commensuraron": "commensurare",
    "commensurarono": "commensurare",
    "commensurasse": "commensurare",
    "commensurasser": "commensurare",
    "commensurassero": "commensurare",
    "commensurassi": "commensurare",
    "commensurassimo": "commensurare",
    "commensuraste": "commensurare",
    "commensurasti": "commensurare",
    "commensurata": "commensurare",
    "commensurate": "commensurare",
    "commensurati": "commensurare",
    "commensurato": "commensurare",
    "commensurava": "commensurare",
    "commensuravamo": "commensurare",
    "commensuravan": "commensurare",
    "commensuravano": "commensurare",
    "commensuravate": "commensurare",
    "commensuravi": "commensurare",
    "commensuravo": "commensurare",
    "commensurerai": "commensurare",
    "commensureran": "commensurare",
    "commensureranno": "commensurare",
    "commensurerebbe": "commensurare",
    "commensurerebber": "commensurare",
    "commensurerebbero": "commensurare",
    "commensurerei": "commensurare",
    "commensureremmo": "commensurare",
    "commensureremo": "commensurare",
    "commensurereste": "commensurare",
    "commensureresti": "commensurare",
    "commensurerete": "commensurare",
    "commensurerà": "commensurare",
    "commensurerò": "commensurare",
    "commensuri": "commensurare",
    "commensuriamo": "commensurare",
    "commensuriate": "commensurare",
    "commensurin": "commensurare",
    "commensurino": "commensurare",
    "commensuro": "commensurare",
    "commensurò": "commensurare",
    "commenta": "commentare",
    "commentai": "commentare",
    "commentammo": "commentare",
    "commentan": "commentare",
    "commentando": "commentare",
    "commentano": "commentare",
    "commentante": "commentare",
    "commentanti": "commentare",
    "commentar": "commentare",
    "commentari": "commentario",
    "commentaron": "commentare",
    "commentarono": "commentare",
    "commentasse": "commentare",
    "commentasser": "commentare",
    "commentassero": "commentare",
    "commentassi": "commentare",
    "commentassimo": "commentare",
    "commentaste": "commentare",
    "commentasti": "commentare",
    "commentata": "commentare",
    "commentate": "commentare",
    "commentati": "commentare",
    "commentato": "commentare",
    "commentatori": "commentatore",
    "commentava": "commentare",
    "commentavamo": "commentare",
    "commentavan": "commentare",
    "commentavano": "commentare",
    "commentavate": "commentare",
    "commentavi": "commentare",
    "commentavo": "commentare",
    "commenterai": "commentare",
    "commenteran": "commentare",
    "commenteranno": "commentare",
    "commenterebbe": "commentare",
    "commenterebber": "commentare",
    "commenterebbero": "commentare",
    "commenterei": "commentare",
    "commenteremmo": "commentare",
    "commenteremo": "commentare",
    "commentereste": "commentare",
    "commenteresti": "commentare",
    "commenterete": "commentare",
    "commenterà": "commentare",
    "commenterò": "commentare",
    "commenti": "commento",
    "commentiamo": "commentare",
    "commentiate": "commentare",
    "commentin": "commentare",
    "commentino": "commentare",
    "commento": "commentare",
    "commentò": "commentare",
    "commercerai": "commerciare",
    "commerceran": "commerciare",
    "commerceranno": "commerciare",
    "commercerebbe": "commerciare",
    "commercerebber": "commerciare",
    "commercerebbero": "commerciare",
    "commercerei": "commerciare",
    "commerceremmo": "commerciare",
    "commerceremo": "commerciare",
    "commercereste": "commerciare",
    "commerceresti": "commerciare",
    "commercerete": "commerciare",
    "commercerà": "commerciare",
    "commercerò": "commerciare",
    "commerci": "commercio",
    "commercia": "commerciare",
    "commerciabili": "commerciabile",
    "commerciai": "commerciare",
    "commerciali": "commerciale",
    "commercialisti": "commercialista",
    "commercializza": "commercializzare",
    "commercializzai": "commercializzare",
    "commercializzammo": "commercializzare",
    "commercializzan": "commercializzare",
    "commercializzando": "commercializzare",
    "commercializzano": "commercializzare",
    "commercializzante": "commercializzare",
    "commercializzanti": "commercializzare",
    "commercializzar": "commercializzare",
    "commercializzaron": "commercializzare",
    "commercializzarono": "commercializzare",
    "commercializzasse": "commercializzare",
    "commercializzasser": "commercializzare",
    "commercializzassero": "commercializzare",
    "commercializzassi": "commercializzare",
    "commercializzassimo": "commercializzare",
    "commercializzaste": "commercializzare",
    "commercializzasti": "commercializzare",
    "commercializzata": "commercializzare",
    "commercializzate": "commercializzare",
    "commercializzati": "commercializzare",
    "commercializzato": "commercializzare",
    "commercializzava": "commercializzare",
    "commercializzavamo": "commercializzare",
    "commercializzavan": "commercializzare",
    "commercializzavano": "commercializzare",
    "commercializzavate": "commercializzare",
    "commercializzavi": "commercializzare",
    "commercializzavo": "commercializzare",
    "commercializzazioni": "commercializzazione",
    "commercializzerai": "commercializzare",
    "commercializzeran": "commercializzare",
    "commercializzeranno": "commercializzare",
    "commercializzerebbe": "commercializzare",
    "commercializzerebber": "commercializzare",
    "commercializzerebbero": "commercializzare",
    "commercializzerei": "commercializzare",
    "commercializzeremmo": "commercializzare",
    "commercializzeremo": "commercializzare",
    "commercializzereste": "commercializzare",
    "commercializzeresti": "commercializzare",
    "commercializzerete": "commercializzare",
    "commercializzerà": "commercializzare",
    "commercializzerò": "commercializzare",
    "commercializzi": "commercializzare",
    "commercializziamo": "commercializzare",
    "commercializziate": "commercializzare",
    "commercializzin": "commercializzare",
    "commercializzino": "commercializzare",
    "commercializzo": "commercializzare",
    "commercializzò": "commercializzare",
    "commerciammo": "commerciare",
    "commerciamo": "commerciare",
    "commercian": "commerciare",
    "commerciando": "commerciare",
    "commerciano": "commerciare",
    "commerciante": "commerciare",
    "commercianti": "commerciare",
    "commerciar": "commerciare",
    "commerciaron": "commerciare",
    "commerciarono": "commerciare",
    "commerciasse": "commerciare",
    "commerciasser": "commerciare",
    "commerciassero": "commerciare",
    "commerciassi": "commerciare",
    "commerciassimo": "commerciare",
    "commerciaste": "commerciare",
    "commerciasti": "commerciare",
    "commerciata": "commerciare",
    "commerciate": "commerciare",
    "commerciati": "commerciare",
    "commerciato": "commerciare",
    "commerciava": "commerciare",
    "commerciavamo": "commerciare",
    "commerciavan": "commerciare",
    "commerciavano": "commerciare",
    "commerciavate": "commerciare",
    "commerciavi": "commerciare",
    "commerciavo": "commerciare",
    "commercin": "commerciare",
    "commercino": "commerciare",
    "commercio": "commerciare",
    "commerciò": "commerciare",
    "commessa": "commettere",
    "commesse": "commettere",
    "commessi": "commettere",
    "commesso": "commettere",
    "commestibili": "commestibile",
    "commetta": "commettere",
    "commettan": "commettere",
    "commettano": "commettere",
    "commette": "commettere",
    "commettemmo": "commettere",
    "commettendo": "commettere",
    "commettente": "commettere",
    "commettenti": "commettere",
    "commetter": "commettere",
    "commetterai": "commettere",
    "commetteran": "commettere",
    "commetteranno": "commettere",
    "commetterebbe": "commettere",
    "commetterebber": "commettere",
    "commetterebbero": "commettere",
    "commetterei": "commettere",
    "commetteremmo": "commettere",
    "commetteremo": "commettere",
    "commettereste": "commettere",
    "commetteresti": "commettere",
    "commetterete": "commettere",
    "commetterà": "commettere",
    "commetterò": "commettere",
    "commettesse": "commettere",
    "commettesser": "commettere",
    "commettessero": "commettere",
    "commettessi": "commettere",
    "commettessimo": "commettere",
    "commetteste": "commettere",
    "commettesti": "commettere",
    "commettete": "commettere",
    "commetteva": "commettere",
    "commettevamo": "commettere",
    "commettevan": "commettere",
    "commettevano": "commettere",
    "commettevate": "commettere",
    "commettevi": "commettere",
    "commettevo": "commettere",
    "commetti": "commettere",
    "commettiamo": "commettere",
    "commettiate": "commettere",
    "commetto": "commettere",
    "commetton": "commettere",
    "commettono": "commettere",
    "commi": "comma",
    "commiati": "commiato",
    "commilitoni": "commilitone",
    "commina": "comminare",
    "comminai": "comminare",
    "comminammo": "comminare",
    "comminan": "comminare",
    "comminando": "comminare",
    "comminano": "comminare",
    "comminante": "comminare",
    "comminanti": "comminare",
    "comminar": "comminare",
    "comminaron": "comminare",
    "comminarono": "comminare",
    "comminasse": "comminare",
    "comminasser": "comminare",
    "comminassero": "comminare",
    "comminassi": "comminare",
    "comminassimo": "comminare",
    "comminaste": "comminare",
    "comminasti": "comminare",
    "comminata": "comminare",
    "comminate": "comminare",
    "comminati": "comminare",
    "comminato": "comminare",
    "comminava": "comminare",
    "comminavamo": "comminare",
    "comminavan": "comminare",
    "comminavano": "comminare",
    "comminavate": "comminare",
    "comminavi": "comminare",
    "comminavo": "comminare",
    "comminerai": "comminare",
    "commineran": "comminare",
    "commineranno": "comminare",
    "comminerebbe": "comminare",
    "comminerebber": "comminare",
    "comminerebbero": "comminare",
    "comminerei": "comminare",
    "commineremmo": "comminare",
    "commineremo": "comminare",
    "comminereste": "comminare",
    "commineresti": "comminare",
    "comminerete": "comminare",
    "comminerà": "comminare",
    "comminerò": "comminare",
    "commini": "comminare",
    "comminiamo": "comminare",
    "comminiate": "comminare",
    "comminin": "comminare",
    "comminino": "comminare",
    "commino": "comminare",
    "comminò": "comminare",
    "commise": "commettere",
    "commiser": "commettere",
    "commisera": "commiserare",
    "commiserai": "commiserare",
    "commiserammo": "commiserare",
    "commiseran": "commiserare",
    "commiserando": "commiserare",
    "commiserano": "commiserare",
    "commiserante": "commiserare",
    "commiseranti": "commiserare",
    "commiserar": "commiserare",
    "commiseraron": "commiserare",
    "commiserarono": "commiserare",
    "commiserasse": "commiserare",
    "commiserasser": "commiserare",
    "commiserassero": "commiserare",
    "commiserassi": "commiserare",
    "commiserassimo": "commiserare",
    "commiseraste": "commiserare",
    "commiserasti": "commiserare",
    "commiserata": "commiserare",
    "commiserate": "commiserare",
    "commiserati": "commiserare",
    "commiserato": "commiserare",
    "commiserava": "commiserare",
    "commiseravamo": "commiserare",
    "commiseravan": "commiserare",
    "commiseravano": "commiserare",
    "commiseravate": "commiserare",
    "commiseravi": "commiserare",
    "commiseravo": "commiserare",
    "commisererai": "commiserare",
    "commisereran": "commiserare",
    "commisereranno": "commiserare",
    "commisererebbe": "commiserare",
    "commisererebber": "commiserare",
    "commisererebbero": "commiserare",
    "commisererei": "commiserare",
    "commisereremmo": "commiserare",
    "commisereremo": "commiserare",
    "commiserereste": "commiserare",
    "commisereresti": "commiserare",
    "commisererete": "commiserare",
    "commisererà": "commiserare",
    "commisererò": "commiserare",
    "commiseri": "commiserare",
    "commiseriamo": "commiserare",
    "commiseriate": "commiserare",
    "commiserin": "commiserare",
    "commiserino": "commiserare",
    "commisero": "commiserare",
    "commiserò": "commiserare",
    "commisi": "commettere",
    "commisioni": "commisione",
    "commissari": "commissario",
    "commissaria": "commissariare",
    "commissariai": "commissariare",
    "commissariali": "commissariale",
    "commissariamenti": "commissariamento",
    "commissariammo": "commissariare",
    "commissariamo": "commissariare",
    "commissarian": "commissariare",
    "commissariando": "commissariare",
    "commissariano": "commissariare",
    "commissariante": "commissariare",
    "commissarianti": "commissariare",
    "commissariar": "commissariare",
    "commissariaron": "commissariare",
    "commissariarono": "commissariare",
    "commissariasse": "commissariare",
    "commissariasser": "commissariare",
    "commissariassero": "commissariare",
    "commissariassi": "commissariare",
    "commissariassimo": "commissariare",
    "commissariaste": "commissariare",
    "commissariasti": "commissariare",
    "commissariata": "commissariare",
    "commissariate": "commissariare",
    "commissariati": "commissariato",
    "commissariato": "commissariare",
    "commissariava": "commissariare",
    "commissariavamo": "commissariare",
    "commissariavan": "commissariare",
    "commissariavano": "commissariare",
    "commissariavate": "commissariare",
    "commissariavi": "commissariare",
    "commissariavo": "commissariare",
    "commissarie": "commissaria",
    "commissarierai": "commissariare",
    "commissarieran": "commissariare",
    "commissarieranno": "commissariare",
    "commissarierebbe": "commissariare",
    "commissarierebber": "commissariare",
    "commissarierebbero": "commissariare",
    "commissarierei": "commissariare",
    "commissarieremmo": "commissariare",
    "commissarieremo": "commissariare",
    "commissariereste": "commissariare",
    "commissarieresti": "commissariare",
    "commissarierete": "commissariare",
    "commissarierà": "commissariare",
    "commissarierò": "commissariare",
    "commissarin": "commissariare",
    "commissarino": "commissariare",
    "commissario": "commissariare",
    "commissariò": "commissariare",
    "commissiona": "commissionare",
    "commissionai": "commissionare",
    "commissionammo": "commissionare",
    "commissionan": "commissionare",
    "commissionando": "commissionare",
    "commissionano": "commissionare",
    "commissionante": "commissionare",
    "commissionanti": "commissionare",
    "commissionar": "commissionare",
    "commissionari": "commissionario",
    "commissionarie": "commissionaria",
    "commissionaron": "commissionare",
    "commissionarono": "commissionare",
    "commissionasse": "commissionare",
    "commissionasser": "commissionare",
    "commissionassero": "commissionare",
    "commissionassi": "commissionare",
    "commissionassimo": "commissionare",
    "commissionaste": "commissionare",
    "commissionasti": "commissionare",
    "commissionata": "commissionare",
    "commissionate": "commissionare",
    "commissionati": "commissionare",
    "commissionato": "commissionare",
    "commissionava": "commissionare",
    "commissionavamo": "commissionare",
    "commissionavan": "commissionare",
    "commissionavano": "commissionare",
    "commissionavate": "commissionare",
    "commissionavi": "commissionare",
    "commissionavo": "commissionare",
    "commissionerai": "commissionare",
    "commissioneran": "commissionare",
    "commissioneranno": "commissionare",
    "commissionerebbe": "commissionare",
    "commissionerebber": "commissionare",
    "commissionerebbero": "commissionare",
    "commissionerei": "commissionare",
    "commissioneremmo": "commissionare",
    "commissioneremo": "commissionare",
    "commissionereste": "commissionare",
    "commissioneresti": "commissionare",
    "commissionerete": "commissionare",
    "commissionerà": "commissionare",
    "commissionerò": "commissionare",
    "commissioni": "commissione",
    "commissioniamo": "commissionare",
    "commissioniate": "commissionare",
    "commissionin": "commissionare",
    "commissionino": "commissionare",
    "commissiono": "commissionare",
    "commissionò": "commissionare",
    "commistioni": "commistione",
    "commisura": "commisurare",
    "commisurai": "commisurare",
    "commisurammo": "commisurare",
    "commisuran": "commisurare",
    "commisurando": "commisurare",
    "commisurano": "commisurare",
    "commisurante": "commisurare",
    "commisuranti": "commisurare",
    "commisurar": "commisurare",
    "commisuraron": "commisurare",
    "commisurarono": "commisurare",
    "commisurasse": "commisurare",
    "commisurasser": "commisurare",
    "commisurassero": "commisurare",
    "commisurassi": "commisurare",
    "commisurassimo": "commisurare",
    "commisuraste": "commisurare",
    "commisurasti": "commisurare",
    "commisurata": "commisurare",
    "commisurate": "commisurare",
    "commisurati": "commisurare",
    "commisurato": "commisurare",
    "commisurava": "commisurare",
    "commisuravamo": "commisurare",
    "commisuravan": "commisurare",
    "commisuravano": "commisurare",
    "commisuravate": "commisurare",
    "commisuravi": "commisurare",
    "commisuravo": "commisurare",
    "commisurerai": "commisurare",
    "commisureran": "commisurare",
    "commisureranno": "commisurare",
    "commisurerebbe": "commisurare",
    "commisurerebber": "commisurare",
    "commisurerebbero": "commisurare",
    "commisurerei": "commisurare",
    "commisureremmo": "commisurare",
    "commisureremo": "commisurare",
    "commisurereste": "commisurare",
    "commisureresti": "commisurare",
    "commisurerete": "commisurare",
    "commisurerà": "commisurare",
    "commisurerò": "commisurare",
    "commisuri": "commisurare",
    "commisuriamo": "commisurare",
    "commisuriate": "commisurare",
    "commisurin": "commisurare",
    "commisurino": "commisurare",
    "commisuro": "commisurare",
    "commisurò": "commisurare",
    "committenti": "committente",
    "committenze": "committenza",
    "commodities": "commodity",
    "commossa": "commuovere",
    "commosse": "commuovere",
    "commosser": "commuovere",
    "commossero": "commuovere",
    "commossi": "commuovere",
    "commosso": "commuovere",
    "commoventi": "commovente",
    "commozioni": "commozione",
    "commuova": "commuovere",
    "commuovan": "commuovere",
    "commuovano": "commuovere",
    "commuove": "commuovere",
    "commuovemmo": "commuovere",
    "commuovendo": "commuovere",
    "commuovente": "commuovere",
    "commuoventi": "commuovere",
    "commuover": "commuovere",
    "commuoverai": "commuovere",
    "commuoveran": "commuovere",
    "commuoveranno": "commuovere",
    "commuoverebbe": "commuovere",
    "commuoverebber": "commuovere",
    "commuoverebbero": "commuovere",
    "commuoverei": "commuovere",
    "commuoveremmo": "commuovere",
    "commuoveremo": "commuovere",
    "commuovereste": "commuovere",
    "commuoveresti": "commuovere",
    "commuoverete": "commuovere",
    "commuoverà": "commuovere",
    "commuoverò": "commuovere",
    "commuovesse": "commuovere",
    "commuovesser": "commuovere",
    "commuovessero": "commuovere",
    "commuovessi": "commuovere",
    "commuovessimo": "commuovere",
    "commuoveste": "commuovere",
    "commuovesti": "commuovere",
    "commuovete": "commuovere",
    "commuoveva": "commuovere",
    "commuovevamo": "commuovere",
    "commuovevan": "commuovere",
    "commuovevano": "commuovere",
    "commuovevate": "commuovere",
    "commuovevi": "commuovere",
    "commuovevo": "commuovere",
    "commuovi": "commuovere",
    "commuoviamo": "commuovere",
    "commuoviate": "commuovere",
    "commuovo": "commuovere",
    "commuovon": "commuovere",
    "commuovono": "commuovere",
    "commuta": "commutare",
    "commutabili": "commutabile",
    "commutai": "commutare",
    "commutammo": "commutare",
    "commutan": "commutare",
    "commutando": "commutare",
    "commutano": "commutare",
    "commutante": "commutare",
    "commutanti": "commutare",
    "commutar": "commutare",
    "commutaron": "commutare",
    "commutarono": "commutare",
    "commutasse": "commutare",
    "commutasser": "commutare",
    "commutassero": "commutare",
    "commutassi": "commutare",
    "commutassimo": "commutare",
    "commutaste": "commutare",
    "commutasti": "commutare",
    "commutata": "commutare",
    "commutate": "commutare",
    "commutati": "commutare",
    "commutato": "commutare",
    "commutatori": "commutatore",
    "commutatrice": "commutatore",
    "commutatrici": "commutatore",
    "commutava": "commutare",
    "commutavamo": "commutare",
    "commutavan": "commutare",
    "commutavano": "commutare",
    "commutavate": "commutare",
    "commutavi": "commutare",
    "commutavo": "commutare",
    "commutazioni": "commutazione",
    "commuterai": "commutare",
    "commuteran": "commutare",
    "commuteranno": "commutare",
    "commuterebbe": "commutare",
    "commuterebber": "commutare",
    "commuterebbero": "commutare",
    "commuterei": "commutare",
    "commuteremmo": "commutare",
    "commuteremo": "commutare",
    "commutereste": "commutare",
    "commuteresti": "commutare",
    "commuterete": "commutare",
    "commuterà": "commutare",
    "commuterò": "commutare",
    "commuti": "commutare",
    "commutiamo": "commutare",
    "commutiate": "commutare",
    "commutin": "commutare",
    "commutino": "commutare",
    "commuto": "commutare",
    "commutò": "commutare",
    "comoda": "comodo",
    "comodai": "comodare",
    "comodammo": "comodare",
    "comodan": "comodare",
    "comodando": "comodare",
    "comodano": "comodare",
    "comodante": "comodare",
    "comodanti": "comodare",
    "comodar": "comodare",
    "comodaron": "comodare",
    "comodarono": "comodare",
    "comodasse": "comodare",
    "comodasser": "comodare",
    "comodassero": "comodare",
    "comodassi": "comodare",
    "comodassimo": "comodare",
    "comodaste": "comodare",
    "comodasti": "comodare",
    "comodata": "comodare",
    "comodate": "comodare",
    "comodati": "comodare",
    "comodato": "comodare",
    "comodava": "comodare",
    "comodavamo": "comodare",
    "comodavan": "comodare",
    "comodavano": "comodare",
    "comodavate": "comodare",
    "comodavi": "comodare",
    "comodavo": "comodare",
    "comode": "comodo",
    "comoderai": "comodare",
    "comoderan": "comodare",
    "comoderanno": "comodare",
    "comoderebbe": "comodare",
    "comoderebber": "comodare",
    "comoderebbero": "comodare",
    "comoderei": "comodare",
    "comoderemmo": "comodare",
    "comoderemo": "comodare",
    "comodereste": "comodare",
    "comoderesti": "comodare",
    "comoderete": "comodare",
    "comoderà": "comodare",
    "comoderò": "comodare",
    "comodi": "comodo",
    "comodiamo": "comodare",
    "comodiate": "comodare",
    "comodin": "comodare",
    "comodini": "comodino",
    "comodino": "comodare",
    "comodo": "comodare",
    "comodò": "comodare",
    "compaesani": "compaesano",
    "compagina": "compaginare",
    "compaginai": "compaginare",
    "compaginammo": "compaginare",
    "compaginan": "compaginare",
    "compaginando": "compaginare",
    "compaginano": "compaginare",
    "compaginante": "compaginare",
    "compaginanti": "compaginare",
    "compaginar": "compaginare",
    "compaginaron": "compaginare",
    "compaginarono": "compaginare",
    "compaginasse": "compaginare",
    "compaginasser": "compaginare",
    "compaginassero": "compaginare",
    "compaginassi": "compaginare",
    "compaginassimo": "compaginare",
    "compaginaste": "compaginare",
    "compaginasti": "compaginare",
    "compaginata": "compaginare",
    "compaginate": "compaginare",
    "compaginati": "compaginare",
    "compaginato": "compaginare",
    "compaginava": "compaginare",
    "compaginavamo": "compaginare",
    "compaginavan": "compaginare",
    "compaginavano": "compaginare",
    "compaginavate": "compaginare",
    "compaginavi": "compaginare",
    "compaginavo": "compaginare",
    "compaginerai": "compaginare",
    "compagineran": "compaginare",
    "compagineranno": "compaginare",
    "compaginerebbe": "compaginare",
    "compaginerebber": "compaginare",
    "compaginerebbero": "compaginare",
    "compaginerei": "compaginare",
    "compagineremmo": "compaginare",
    "compagineremo": "compaginare",
    "compaginereste": "compaginare",
    "compagineresti": "compaginare",
    "compaginerete": "compaginare",
    "compaginerà": "compaginare",
    "compaginerò": "compaginare",
    "compagini": "compagine",
    "compaginiamo": "compaginare",
    "compaginiate": "compaginare",
    "compaginin": "compaginare",
    "compaginino": "compaginare",
    "compagino": "compaginare",
    "compaginò": "compaginare",
    "compagne": "compagna",
    "compagni": "compagno",
    "compagnie": "compagnia",
    "compagnoni": "compagnone",
    "compagnucci": "compagnuccio",
    "compagnìe": "compagnìa",
    "compaia": "comparire",
    "compaian": "comparire",
    "compaiano": "comparire",
    "compaio": "comparire",
    "compaion": "comparire",
    "compaiono": "comparire",
    "compara": "comparare",
    "comparabili": "comparabile",
    "comparai": "comparare",
    "comparammo": "comparare",
    "comparan": "comparare",
    "comparando": "comparare",
    "comparano": "comparare",
    "comparante": "comparare",
    "comparanti": "comparare",
    "comparar": "comparare",
    "compararon": "comparare",
    "compararono": "comparare",
    "comparasse": "comparare",
    "comparasser": "comparare",
    "comparassero": "comparare",
    "comparassi": "comparare",
    "comparassimo": "comparare",
    "comparaste": "comparare",
    "comparasti": "comparare",
    "comparata": "comparato",
    "comparate": "comparato",
    "comparati": "comparato",
    "comparativa": "comparativo",
    "comparative": "comparativo",
    "comparativi": "comparativo",
    "comparato": "comparare",
    "comparava": "comparare",
    "comparavamo": "comparare",
    "comparavan": "comparare",
    "comparavano": "comparare",
    "comparavate": "comparare",
    "comparavi": "comparare",
    "comparavo": "comparare",
    "comparazioni": "comparazione",
    "compare": "comparire",
    "comparendo": "comparire",
    "comparente": "comparire",
    "comparenti": "comparire",
    "comparerai": "comparare",
    "compareran": "comparare",
    "compareranno": "comparare",
    "comparerebbe": "comparare",
    "comparerebber": "comparare",
    "comparerebbero": "comparare",
    "comparerei": "comparare",
    "compareremmo": "comparare",
    "compareremo": "comparare",
    "comparereste": "comparare",
    "compareresti": "comparare",
    "comparerete": "comparare",
    "comparerà": "comparare",
    "comparerò": "comparare",
    "compari": "comparire",
    "compariamo": "comparire",
    "compariate": "comparire",
    "comparimmo": "comparire",
    "comparin": "comparare",
    "comparino": "comparare",
    "comparir": "comparire",
    "comparirai": "comparire",
    "compariran": "comparire",
    "compariranno": "comparire",
    "comparirebbe": "comparire",
    "comparirebber": "comparire",
    "comparirebbero": "comparire",
    "comparirei": "comparire",
    "compariremmo": "comparire",
    "compariremo": "comparire",
    "comparireste": "comparire",
    "compariresti": "comparire",
    "comparirete": "comparire",
    "comparirà": "comparire",
    "comparirò": "comparire",
    "comparisse": "comparire",
    "comparisser": "comparire",
    "comparissero": "comparire",
    "comparissi": "comparire",
    "comparissimo": "comparire",
    "compariste": "comparire",
    "comparisti": "comparire",
    "comparite": "comparire",
    "compariva": "comparire",
    "comparivamo": "comparire",
    "comparivan": "comparire",
    "comparivano": "comparire",
    "comparivate": "comparire",
    "comparivi": "comparire",
    "comparivo": "comparire",
    "comparo": "comparare",
    "comparsa": "comparso",
    "comparsate": "comparsata",
    "comparse": "comparso",
    "comparsi": "comparso",
    "comparso": "comparire",
    "compartecipa": "compartecipare",
    "compartecipai": "compartecipare",
    "compartecipammo": "compartecipare",
    "compartecipan": "compartecipare",
    "compartecipando": "compartecipare",
    "compartecipano": "compartecipare",
    "compartecipante": "compartecipare",
    "compartecipanti": "compartecipare",
    "compartecipar": "compartecipare",
    "comparteciparon": "compartecipare",
    "comparteciparono": "compartecipare",
    "compartecipasse": "compartecipare",
    "compartecipasser": "compartecipare",
    "compartecipassero": "compartecipare",
    "compartecipassi": "compartecipare",
    "compartecipassimo": "compartecipare",
    "compartecipaste": "compartecipare",
    "compartecipasti": "compartecipare",
    "compartecipata": "compartecipare",
    "compartecipate": "compartecipare",
    "compartecipati": "compartecipare",
    "compartecipato": "compartecipare",
    "compartecipava": "compartecipare",
    "compartecipavamo": "compartecipare",
    "compartecipavan": "compartecipare",
    "compartecipavano": "compartecipare",
    "compartecipavate": "compartecipare",
    "compartecipavi": "compartecipare",
    "compartecipavo": "compartecipare",
    "compartecipazioni": "compartecipazione",
    "comparteciperai": "compartecipare",
    "comparteciperan": "compartecipare",
    "comparteciperanno": "compartecipare",
    "comparteciperebbe": "compartecipare",
    "comparteciperebber": "compartecipare",
    "comparteciperebbero": "compartecipare",
    "comparteciperei": "compartecipare",
    "comparteciperemmo": "compartecipare",
    "comparteciperemo": "compartecipare",
    "compartecipereste": "compartecipare",
    "comparteciperesti": "compartecipare",
    "comparteciperete": "compartecipare",
    "comparteciperà": "compartecipare",
    "comparteciperò": "compartecipare",
    "compartecipi": "compartecipare",
    "compartecipiamo": "compartecipare",
    "compartecipiate": "compartecipare",
    "compartecipin": "compartecipare",
    "compartecipino": "compartecipare",
    "compartecipo": "compartecipare",
    "compartecipò": "compartecipare",
    "comparti": "comparto",
    "compartimenta": "compartimentare",
    "compartimentai": "compartimentare",
    "compartimentali": "compartimentale",
    "compartimentammo": "compartimentare",
    "compartimentan": "compartimentare",
    "compartimentando": "compartimentare",
    "compartimentano": "compartimentare",
    "compartimentante": "compartimentare",
    "compartimentanti": "compartimentare",
    "compartimentar": "compartimentare",
    "compartimentaron": "compartimentare",
    "compartimentarono": "compartimentare",
    "compartimentasse": "compartimentare",
    "compartimentasser": "compartimentare",
    "compartimentassero": "compartimentare",
    "compartimentassi": "compartimentare",
    "compartimentassimo": "compartimentare",
    "compartimentaste": "compartimentare",
    "compartimentasti": "compartimentare",
    "compartimentata": "compartimentare",
    "compartimentate": "compartimentare",
    "compartimentati": "compartimentare",
    "compartimentato": "compartimentare",
    "compartimentava": "compartimentare",
    "compartimentavamo": "compartimentare",
    "compartimentavan": "compartimentare",
    "compartimentavano": "compartimentare",
    "compartimentavate": "compartimentare",
    "compartimentavi": "compartimentare",
    "compartimentavo": "compartimentare",
    "compartimenterai": "compartimentare",
    "compartimenteran": "compartimentare",
    "compartimenteranno": "compartimentare",
    "compartimenterebbe": "compartimentare",
    "compartimenterebber": "compartimentare",
    "compartimenterebbero": "compartimentare",
    "compartimenterei": "compartimentare",
    "compartimenteremmo": "compartimentare",
    "compartimenteremo": "compartimentare",
    "compartimentereste": "compartimentare",
    "compartimenteresti": "compartimentare",
    "compartimenterete": "compartimentare",
    "compartimenterà": "compartimentare",
    "compartimenterò": "compartimentare",
    "compartimenti": "compartimento",
    "compartimentiamo": "compartimentare",
    "compartimentiate": "compartimentare",
    "compartimentin": "compartimentare",
    "compartimentino": "compartimentare",
    "compartimento": "compartimentare",
    "compartimentò": "compartimentare",
    "comparve": "comparire",
    "comparver": "comparire",
    "comparvero": "comparire",
    "comparvi": "comparire",
    "comparò": "comparare",
    "compassa": "compassare",
    "compassai": "compassare",
    "compassammo": "compassare",
    "compassan": "compassare",
    "compassando": "compassare",
    "compassano": "compassare",
    "compassante": "compassare",
    "compassanti": "compassare",
    "compassar": "compassare",
    "compassaron": "compassare",
    "compassarono": "compassare",
    "compassasse": "compassare",
    "compassasser": "compassare",
    "compassassero": "compassare",
    "compassassi": "compassare",
    "compassassimo": "compassare",
    "compassaste": "compassare",
    "compassasti": "compassare",
    "compassata": "compassato",
    "compassate": "compassato",
    "compassati": "compassato",
    "compassato": "compassare",
    "compassava": "compassare",
    "compassavamo": "compassare",
    "compassavan": "compassare",
    "compassavano": "compassare",
    "compassavate": "compassare",
    "compassavi": "compassare",
    "compassavo": "compassare",
    "compasserai": "compassare",
    "compasseran": "compassare",
    "compasseranno": "compassare",
    "compasserebbe": "compassare",
    "compasserebber": "compassare",
    "compasserebbero": "compassare",
    "compasserei": "compassare",
    "compasseremmo": "compassare",
    "compasseremo": "compassare",
    "compassereste": "compassare",
    "compasseresti": "compassare",
    "compasserete": "compassare",
    "compasserà": "compassare",
    "compasserò": "compassare",
    "compassi": "compasso",
    "compassiamo": "compassare",
    "compassiate": "compassare",
    "compassin": "compassare",
    "compassino": "compassare",
    "compassiona": "compassionare",
    "compassionai": "compassionare",
    "compassionammo": "compassionare",
    "compassionan": "compassionare",
    "compassionando": "compassionare",
    "compassionano": "compassionare",
    "compassionante": "compassionare",
    "compassionanti": "compassionare",
    "compassionar": "compassionare",
    "compassionaron": "compassionare",
    "compassionarono": "compassionare",
    "compassionasse": "compassionare",
    "compassionasser": "compassionare",
    "compassionassero": "compassionare",
    "compassionassi": "compassionare",
    "compassionassimo": "compassionare",
    "compassionaste": "compassionare",
    "compassionasti": "compassionare",
    "compassionata": "compassionare",
    "compassionate": "compassionare",
    "compassionati": "compassionare",
    "compassionato": "compassionare",
    "compassionava": "compassionare",
    "compassionavamo": "compassionare",
    "compassionavan": "compassionare",
    "compassionavano": "compassionare",
    "compassionavate": "compassionare",
    "compassionavi": "compassionare",
    "compassionavo": "compassionare",
    "compassionerai": "compassionare",
    "compassioneran": "compassionare",
    "compassioneranno": "compassionare",
    "compassionerebbe": "compassionare",
    "compassionerebber": "compassionare",
    "compassionerebbero": "compassionare",
    "compassionerei": "compassionare",
    "compassioneremmo": "compassionare",
    "compassioneremo": "compassionare",
    "compassionereste": "compassionare",
    "compassioneresti": "compassionare",
    "compassionerete": "compassionare",
    "compassionerà": "compassionare",
    "compassionerò": "compassionare",
    "compassionevoli": "compassionevole",
    "compassioni": "compassione",
    "compassioniamo": "compassionare",
    "compassioniate": "compassionare",
    "compassionin": "compassionare",
    "compassionino": "compassionare",
    "compassiono": "compassionare",
    "compassionò": "compassionare",
    "compasso": "compassare",
    "compassò": "compassare",
    "compatendo": "compatire",
    "compatente": "compatire",
    "compatenti": "compatire",
    "compatiamo": "compatire",
    "compatiate": "compatire",
    "compatibili": "compatibile",
    "compatii": "compatire",
    "compatimmo": "compatire",
    "compatir": "compatire",
    "compatirai": "compatire",
    "compatiran": "compatire",
    "compatiranno": "compatire",
    "compatirebbe": "compatire",
    "compatirebber": "compatire",
    "compatirebbero": "compatire",
    "compatirei": "compatire",
    "compatiremmo": "compatire",
    "compatiremo": "compatire",
    "compatireste": "compatire",
    "compatiresti": "compatire",
    "compatirete": "compatire",
    "compatiron": "compatire",
    "compatirono": "compatire",
    "compatirà": "compatire",
    "compatirò": "compatire",
    "compatisca": "compatire",
    "compatiscan": "compatire",
    "compatiscano": "compatire",
    "compatisce": "compatire",
    "compatisci": "compatire",
    "compatisco": "compatire",
    "compatiscon": "compatire",
    "compatiscono": "compatire",
    "compatisse": "compatire",
    "compatisser": "compatire",
    "compatissero": "compatire",
    "compatissi": "compatire",
    "compatissimo": "compatire",
    "compatiste": "compatire",
    "compatisti": "compatire",
    "compatita": "compatire",
    "compatite": "compatire",
    "compatiti": "compatire",
    "compatito": "compatire",
    "compativa": "compatire",
    "compativamo": "compatire",
    "compativan": "compatire",
    "compativano": "compatire",
    "compativate": "compatire",
    "compativi": "compatire",
    "compativo": "compatire",
    "compatrioti": "compatriota",
    "compatta": "compatto",
    "compattai": "compattare",
    "compattammo": "compattare",
    "compattan": "compattare",
    "compattando": "compattare",
    "compattano": "compattare",
    "compattante": "compattare",
    "compattanti": "compattare",
    "compattar": "compattare",
    "compattaron": "compattare",
    "compattarono": "compattare",
    "compattasse": "compattare",
    "compattasser": "compattare",
    "compattassero": "compattare",
    "compattassi": "compattare",
    "compattassimo": "compattare",
    "compattaste": "compattare",
    "compattasti": "compattare",
    "compattata": "compattare",
    "compattate": "compattare",
    "compattati": "compattare",
    "compattato": "compattare",
    "compattava": "compattare",
    "compattavamo": "compattare",
    "compattavan": "compattare",
    "compattavano": "compattare",
    "compattavate": "compattare",
    "compattavi": "compattare",
    "compattavo": "compattare",
    "compatte": "compatto",
    "compatterai": "compattare",
    "compatteran": "compattare",
    "compatteranno": "compattare",
    "compatterebbe": "compattare",
    "compatterebber": "compattare",
    "compatterebbero": "compattare",
    "compatterei": "compattare",
    "compatteremmo": "compattare",
    "compatteremo": "compattare",
    "compattereste": "compattare",
    "compatteresti": "compattare",
    "compatterete": "compattare",
    "compatterà": "compattare",
    "compatterò": "compattare",
    "compattezze": "compattezza",
    "compatti": "compatto",
    "compattiamo": "compattare",
    "compattiate": "compattare",
    "compattin": "compattare",
    "compattino": "compattare",
    "compatto": "compattare",
    "compattò": "compattare",
    "compatì": "compatire",
    "compendi": "compendio",
    "compendia": "compendiare",
    "compendiai": "compendiare",
    "compendiammo": "compendiare",
    "compendiamo": "compendiare",
    "compendian": "compendiare",
    "compendiando": "compendiare",
    "compendiano": "compendiare",
    "compendiante": "compendiare",
    "compendianti": "compendiare",
    "compendiar": "compendiare",
    "compendiaron": "compendiare",
    "compendiarono": "compendiare",
    "compendiasse": "compendiare",
    "compendiasser": "compendiare",
    "compendiassero": "compendiare",
    "compendiassi": "compendiare",
    "compendiassimo": "compendiare",
    "compendiaste": "compendiare",
    "compendiasti": "compendiare",
    "compendiata": "compendiare",
    "compendiate": "compendiare",
    "compendiati": "compendiare",
    "compendiato": "compendiare",
    "compendiava": "compendiare",
    "compendiavamo": "compendiare",
    "compendiavan": "compendiare",
    "compendiavano": "compendiare",
    "compendiavate": "compendiare",
    "compendiavi": "compendiare",
    "compendiavo": "compendiare",
    "compendierai": "compendiare",
    "compendieran": "compendiare",
    "compendieranno": "compendiare",
    "compendierebbe": "compendiare",
    "compendierebber": "compendiare",
    "compendierebbero": "compendiare",
    "compendierei": "compendiare",
    "compendieremmo": "compendiare",
    "compendieremo": "compendiare",
    "compendiereste": "compendiare",
    "compendieresti": "compendiare",
    "compendierete": "compendiare",
    "compendierà": "compendiare",
    "compendierò": "compendiare",
    "compendin": "compendiare",
    "compendino": "compendiare",
    "compendio": "compendiare",
    "compendiò": "compendiare",
    "compendo": "compire",
    "compenetra": "compenetrare",
    "compenetrai": "compenetrare",
    "compenetrammo": "compenetrare",
    "compenetran": "compenetrare",
    "compenetrando": "compenetrare",
    "compenetrano": "compenetrare",
    "compenetrante": "compenetrare",
    "compenetranti": "compenetrare",
    "compenetrar": "compenetrare",
    "compenetraron": "compenetrare",
    "compenetrarono": "compenetrare",
    "compenetrasse": "compenetrare",
    "compenetrasser": "compenetrare",
    "compenetrassero": "compenetrare",
    "compenetrassi": "compenetrare",
    "compenetrassimo": "compenetrare",
    "compenetraste": "compenetrare",
    "compenetrasti": "compenetrare",
    "compenetrata": "compenetrare",
    "compenetrate": "compenetrare",
    "compenetrati": "compenetrare",
    "compenetrato": "compenetrare",
    "compenetrava": "compenetrare",
    "compenetravamo": "compenetrare",
    "compenetravan": "compenetrare",
    "compenetravano": "compenetrare",
    "compenetravate": "compenetrare",
    "compenetravi": "compenetrare",
    "compenetravo": "compenetrare",
    "compenetrazioni": "compenetrazione",
    "compenetrerai": "compenetrare",
    "compenetreran": "compenetrare",
    "compenetreranno": "compenetrare",
    "compenetrerebbe": "compenetrare",
    "compenetrerebber": "compenetrare",
    "compenetrerebbero": "compenetrare",
    "compenetrerei": "compenetrare",
    "compenetreremmo": "compenetrare",
    "compenetreremo": "compenetrare",
    "compenetrereste": "compenetrare",
    "compenetreresti": "compenetrare",
    "compenetrerete": "compenetrare",
    "compenetrerà": "compenetrare",
    "compenetrerò": "compenetrare",
    "compenetri": "compenetrare",
    "compenetriamo": "compenetrare",
    "compenetriate": "compenetrare",
    "compenetrin": "compenetrare",
    "compenetrino": "compenetrare",
    "compenetro": "compenetrare",
    "compenetrò": "compenetrare",
    "compensa": "compensare",
    "compensabili": "compensabile",
    "compensai": "compensare",
    "compensammo": "compensare",
    "compensan": "compensare",
    "compensando": "compensare",
    "compensano": "compensare",
    "compensante": "compensare",
    "compensanti": "compensare",
    "compensar": "compensare",
    "compensaron": "compensare",
    "compensarono": "compensare",
    "compensasse": "compensare",
    "compensasser": "compensare",
    "compensassero": "compensare",
    "compensassi": "compensare",
    "compensassimo": "compensare",
    "compensaste": "compensare",
    "compensasti": "compensare",
    "compensata": "compensato",
    "compensate": "compensato",
    "compensati": "compensato",
    "compensativa": "compensativo",
    "compensative": "compensativo",
    "compensativi": "compensativo",
    "compensato": "compensare",
    "compensatori": "compensatore",
    "compensatrice": "compensatore",
    "compensatrici": "compensatore",
    "compensava": "compensare",
    "compensavamo": "compensare",
    "compensavan": "compensare",
    "compensavano": "compensare",
    "compensavate": "compensare",
    "compensavi": "compensare",
    "compensavo": "compensare",
    "compensazioni": "compensazione",
    "compenserai": "compensare",
    "compenseran": "compensare",
    "compenseranno": "compensare",
    "compenserebbe": "compensare",
    "compenserebber": "compensare",
    "compenserebbero": "compensare",
    "compenserei": "compensare",
    "compenseremmo": "compensare",
    "compenseremo": "compensare",
    "compensereste": "compensare",
    "compenseresti": "compensare",
    "compenserete": "compensare",
    "compenserà": "compensare",
    "compenserò": "compensare",
    "compensi": "compenso",
    "compensiamo": "compensare",
    "compensiate": "compensare",
    "compensin": "compensare",
    "compensino": "compensare",
    "compenso": "compensare",
    "compensò": "compensare",
    "compente": "compire",
    "compenti": "compire",
    "compera": "comperare",
    "comperai": "comperare",
    "comperammo": "comperare",
    "comperan": "comperare",
    "comperando": "comperare",
    "comperano": "comperare",
    "comperante": "comperare",
    "comperanti": "comperare",
    "comperar": "comperare",
    "comperaron": "comperare",
    "comperarono": "comperare",
    "comperasse": "comperare",
    "comperasser": "comperare",
    "comperassero": "comperare",
    "comperassi": "comperare",
    "comperassimo": "comperare",
    "comperaste": "comperare",
    "comperasti": "comperare",
    "comperata": "comperare",
    "comperate": "comperare",
    "comperati": "comperare",
    "comperato": "comperare",
    "comperava": "comperare",
    "comperavamo": "comperare",
    "comperavan": "comperare",
    "comperavano": "comperare",
    "comperavate": "comperare",
    "comperavi": "comperare",
    "comperavo": "comperare",
    "compererai": "comperare",
    "compereran": "comperare",
    "compereranno": "comperare",
    "compererebbe": "comperare",
    "compererebber": "comperare",
    "compererebbero": "comperare",
    "compererei": "comperare",
    "compereremmo": "comperare",
    "compereremo": "comperare",
    "comperereste": "comperare",
    "compereresti": "comperare",
    "compererete": "comperare",
    "compererà": "comperare",
    "compererò": "comperare",
    "comperi": "comperare",
    "comperiamo": "comperare",
    "comperiate": "comperare",
    "comperin": "comperare",
    "comperino": "comperare",
    "compero": "comperare",
    "comperò": "comperare",
    "competa": "competere",
    "competan": "competere",
    "competano": "competere",
    "compete": "competere",
    "competei": "competere",
    "competemmo": "competere",
    "competendo": "competere",
    "competente": "competere",
    "competenti": "competere",
    "competenze": "competenza",
    "competer": "competere",
    "competerai": "competere",
    "competeran": "competere",
    "competeranno": "competere",
    "competerebbe": "competere",
    "competerebber": "competere",
    "competerebbero": "competere",
    "competerei": "competere",
    "competeremmo": "competere",
    "competeremo": "competere",
    "competereste": "competere",
    "competeresti": "competere",
    "competerete": "competere",
    "competeron": "competere",
    "competerono": "competere",
    "competerà": "competere",
    "competerò": "competere",
    "competesse": "competere",
    "competesser": "competere",
    "competessero": "competere",
    "competessi": "competere",
    "competessimo": "competere",
    "competeste": "competere",
    "competesti": "competere",
    "competete": "competere",
    "competeva": "competere",
    "competevamo": "competere",
    "competevan": "competere",
    "competevano": "competere",
    "competevate": "competere",
    "competevi": "competere",
    "competevo": "competere",
    "competi": "competere",
    "competiamo": "competere",
    "competiate": "competere",
    "competitiva": "competitivo",
    "competitive": "competitivo",
    "competitivi": "competitivo",
    "competitori": "competitore",
    "competizioni": "competizione",
    "competo": "competere",
    "competon": "competere",
    "competono": "competere",
    "competuta": "competere",
    "competute": "competere",
    "competuti": "competere",
    "competuto": "competere",
    "competè": "competere",
    "compi": "compiere",
    "compia": "compiere",
    "compiaccia": "compiacere",
    "compiacciamo": "compiacere",
    "compiaccian": "compiacere",
    "compiacciano": "compiacere",
    "compiacciate": "compiacere",
    "compiaccio": "compiacere",
    "compiaccion": "compiacere",
    "compiacciono": "compiacere",
    "compiace": "compiacere",
    "compiacemmo": "compiacere",
    "compiacendo": "compiacere",
    "compiacente": "compiacere",
    "compiacenti": "compiacere",
    "compiacenze": "compiacenza",
    "compiacer": "compiacere",
    "compiacerai": "compiacere",
    "compiaceran": "compiacere",
    "compiaceranno": "compiacere",
    "compiacerebbe": "compiacere",
    "compiacerebber": "compiacere",
    "compiacerebbero": "compiacere",
    "compiacerei": "compiacere",
    "compiaceremmo": "compiacere",
    "compiaceremo": "compiacere",
    "compiacereste": "compiacere",
    "compiaceresti": "compiacere",
    "compiacerete": "compiacere",
    "compiacerà": "compiacere",
    "compiacerò": "compiacere",
    "compiacesse": "compiacere",
    "compiacesser": "compiacere",
    "compiacessero": "compiacere",
    "compiacessi": "compiacere",
    "compiacessimo": "compiacere",
    "compiaceste": "compiacere",
    "compiacesti": "compiacere",
    "compiacete": "compiacere",
    "compiaceva": "compiacere",
    "compiacevamo": "compiacere",
    "compiacevan": "compiacere",
    "compiacevano": "compiacere",
    "compiacevate": "compiacere",
    "compiacevi": "compiacere",
    "compiacevo": "compiacere",
    "compiaci": "compiacere",
    "compiacimenti": "compiacimento",
    "compiaciuta": "compiacere",
    "compiaciute": "compiacere",
    "compiaciuti": "compiacere",
    "compiaciuto": "compiacere",
    "compiacque": "compiacere",
    "compiacquer": "compiacere",
    "compiacquero": "compiacere",
    "compiacqui": "compiacere",
    "compiamo": "compire",
    "compian": "compiere",
    "compianga": "compiangere",
    "compiangan": "compiangere",
    "compiangano": "compiangere",
    "compiange": "compiangere",
    "compiangemmo": "compiangere",
    "compiangendo": "compiangere",
    "compiangente": "compiangere",
    "compiangenti": "compiangere",
    "compianger": "compiangere",
    "compiangerai": "compiangere",
    "compiangeran": "compiangere",
    "compiangeranno": "compiangere",
    "compiangerebbe": "compiangere",
    "compiangerebber": "compiangere",
    "compiangerebbero": "compiangere",
    "compiangerei": "compiangere",
    "compiangeremmo": "compiangere",
    "compiangeremo": "compiangere",
    "compiangereste": "compiangere",
    "compiangeresti": "compiangere",
    "compiangerete": "compiangere",
    "compiangerà": "compiangere",
    "compiangerò": "compiangere",
    "compiangesse": "compiangere",
    "compiangesser": "compiangere",
    "compiangessero": "compiangere",
    "compiangessi": "compiangere",
    "compiangessimo": "compiangere",
    "compiangeste": "compiangere",
    "compiangesti": "compiangere",
    "compiangete": "compiangere",
    "compiangeva": "compiangere",
    "compiangevamo": "compiangere",
    "compiangevan": "compiangere",
    "compiangevano": "compiangere",
    "compiangevate": "compiangere",
    "compiangevi": "compiangere",
    "compiangevo": "compiangere",
    "compiangi": "compiangere",
    "compiangiamo": "compiangere",
    "compiangiate": "compiangere",
    "compiango": "compiangere",
    "compiangon": "compiangere",
    "compiangono": "compiangere",
    "compiano": "compiere",
    "compianser": "compiangere",
    "compiansero": "compiangere",
    "compiansi": "compiangere",
    "compiansè": "compiangere",
    "compianta": "compianto",
    "compiante": "compianto",
    "compianti": "compianto",
    "compianto": "compiangere",
    "compiate": "compire",
    "compie": "compiere",
    "compiei": "compiere",
    "compiemmo": "compiere",
    "compiendo": "compiere",
    "compiente": "compiere",
    "compienti": "compiere",
    "compier": "compiere",
    "compierai": "compiere",
    "compieran": "compiere",
    "compieranno": "compiere",
    "compierebbe": "compiere",
    "compierebber": "compiere",
    "compierebbero": "compiere",
    "compierei": "compiere",
    "compieremmo": "compiere",
    "compieremo": "compiere",
    "compiereste": "compiere",
    "compieresti": "compiere",
    "compierete": "compiere",
    "compieron": "compiere",
    "compierono": "compiere",
    "compierà": "compiere",
    "compierò": "compiere",
    "compiesse": "compiere",
    "compiesser": "compiere",
    "compiessero": "compiere",
    "compiessi": "compiere",
    "compiessimo": "compiere",
    "compieste": "compiere",
    "compiesti": "compiere",
    "compieva": "compiere",
    "compievamo": "compiere",
    "compievan": "compiere",
    "compievano": "compiere",
    "compievate": "compiere",
    "compievi": "compiere",
    "compievo": "compiere",
    "compii": "compire",
    "compila": "compilare",
    "compilai": "compilare",
    "compilammo": "compilare",
    "compilan": "compilare",
    "compilando": "compilare",
    "compilano": "compilare",
    "compilante": "compilare",
    "compilanti": "compilare",
    "compilar": "compilare",
    "compilaron": "compilare",
    "compilarono": "compilare",
    "compilasse": "compilare",
    "compilasser": "compilare",
    "compilassero": "compilare",
    "compilassi": "compilare",
    "compilassimo": "compilare",
    "compilaste": "compilare",
    "compilasti": "compilare",
    "compilata": "compilare",
    "compilate": "compilare",
    "compilati": "compilare",
    "compilato": "compilare",
    "compilatori": "compilatore",
    "compilava": "compilare",
    "compilavamo": "compilare",
    "compilavan": "compilare",
    "compilavano": "compilare",
    "compilavate": "compilare",
    "compilavi": "compilare",
    "compilavo": "compilare",
    "compilazioni": "compilazione",
    "compilerai": "compilare",
    "compileran": "compilare",
    "compileranno": "compilare",
    "compilerebbe": "compilare",
    "compilerebber": "compilare",
    "compilerebbero": "compilare",
    "compilerei": "compilare",
    "compileremmo": "compilare",
    "compileremo": "compilare",
    "compilereste": "compilare",
    "compileresti": "compilare",
    "compilerete": "compilare",
    "compilerà": "compilare",
    "compilerò": "compilare",
    "compili": "compilare",
    "compiliamo": "compilare",
    "compiliate": "compilare",
    "compilin": "compilare",
    "compilino": "compilare",
    "compilo": "compilare",
    "compilò": "compilare",
    "compimenti": "compimento",
    "compimmo": "compire",
    "compio": "compiere",
    "compion": "compiere",
    "compiono": "compiere",
    "compir": "compire",
    "compirai": "compire",
    "compiran": "compire",
    "compiranno": "compire",
    "compirebbe": "compire",
    "compirebber": "compire",
    "compirebbero": "compire",
    "compirei": "compire",
    "compiremmo": "compire",
    "compiremo": "compire",
    "compireste": "compire",
    "compiresti": "compire",
    "compirete": "compire",
    "compiron": "compire",
    "compirono": "compire",
    "compirà": "compire",
    "compirò": "compire",
    "compisca": "compire",
    "compiscan": "compire",
    "compiscano": "compire",
    "compisce": "compire",
    "compisci": "compire",
    "compisco": "compire",
    "compiscon": "compire",
    "compiscono": "compire",
    "compisse": "compire",
    "compisser": "compire",
    "compissero": "compire",
    "compissi": "compire",
    "compissimo": "compire",
    "compiste": "compire",
    "compisti": "compire",
    "compita": "compitare",
    "compitai": "compitare",
    "compitammo": "compitare",
    "compitan": "compitare",
    "compitando": "compitare",
    "compitano": "compitare",
    "compitante": "compitare",
    "compitanti": "compitare",
    "compitar": "compitare",
    "compitaron": "compitare",
    "compitarono": "compitare",
    "compitasse": "compitare",
    "compitasser": "compitare",
    "compitassero": "compitare",
    "compitassi": "compitare",
    "compitassimo": "compitare",
    "compitaste": "compitare",
    "compitasti": "compitare",
    "compitata": "compitare",
    "compitate": "compitare",
    "compitati": "compitare",
    "compitato": "compitare",
    "compitava": "compitare",
    "compitavamo": "compitare",
    "compitavan": "compitare",
    "compitavano": "compitare",
    "compitavate": "compitare",
    "compitavi": "compitare",
    "compitavo": "compitare",
    "compite": "compire",
    "compiterai": "compitare",
    "compiteran": "compitare",
    "compiteranno": "compitare",
    "compiterebbe": "compitare",
    "compiterebber": "compitare",
    "compiterebbero": "compitare",
    "compiterei": "compitare",
    "compiteremmo": "compitare",
    "compiteremo": "compitare",
    "compitereste": "compitare",
    "compiteresti": "compitare",
    "compiterete": "compitare",
    "compiterà": "compitare",
    "compiterò": "compitare",
    "compiti": "compito",
    "compitiamo": "compitare",
    "compitiate": "compitare",
    "compitin": "compitare",
    "compitini": "compitino",
    "compitino": "compitare",
    "compito": "compitare",
    "compitò": "compitare",
    "compiuta": "compiuto",
    "compiute": "compiuto",
    "compiutezze": "compiutezza",
    "compiuti": "compiuto",
    "compiuto": "compiere",
    "compiva": "compire",
    "compivamo": "compire",
    "compivan": "compire",
    "compivano": "compire",
    "compivate": "compire",
    "compivi": "compire",
    "compivo": "compire",
    "compiè": "compiere",
    "complana": "complanare",
    "complanai": "complanare",
    "complanammo": "complanare",
    "complanan": "complanare",
    "complanando": "complanare",
    "complanano": "complanare",
    "complanante": "complanare",
    "complananti": "complanare",
    "complanar": "complanare",
    "complanaron": "complanare",
    "complanarono": "complanare",
    "complanasse": "complanare",
    "complanasser": "complanare",
    "complanassero": "complanare",
    "complanassi": "complanare",
    "complanassimo": "complanare",
    "complanaste": "complanare",
    "complanasti": "complanare",
    "complanata": "complanare",
    "complanate": "complanare",
    "complanati": "complanare",
    "complanato": "complanare",
    "complanava": "complanare",
    "complanavamo": "complanare",
    "complanavan": "complanare",
    "complanavano": "complanare",
    "complanavate": "complanare",
    "complanavi": "complanare",
    "complanavo": "complanare",
    "complanerai": "complanare",
    "complaneran": "complanare",
    "complaneranno": "complanare",
    "complanerebbe": "complanare",
    "complanerebber": "complanare",
    "complanerebbero": "complanare",
    "complanerei": "complanare",
    "complaneremmo": "complanare",
    "complaneremo": "complanare",
    "complanereste": "complanare",
    "complaneresti": "complanare",
    "complanerete": "complanare",
    "complanerà": "complanare",
    "complanerò": "complanare",
    "complani": "complanare",
    "complaniamo": "complanare",
    "complaniate": "complanare",
    "complanin": "complanare",
    "complanino": "complanare",
    "complano": "complanare",
    "complanò": "complanare",
    "compleanni": "compleanno",
    "complementa": "complementare",
    "complementai": "complementare",
    "complementammo": "complementare",
    "complementan": "complementare",
    "complementando": "complementare",
    "complementano": "complementare",
    "complementante": "complementare",
    "complementanti": "complementare",
    "complementar": "complementare",
    "complementari": "complementare",
    "complementaron": "complementare",
    "complementarono": "complementare",
    "complementasse": "complementare",
    "complementasser": "complementare",
    "complementassero": "complementare",
    "complementassi": "complementare",
    "complementassimo": "complementare",
    "complementaste": "complementare",
    "complementasti": "complementare",
    "complementata": "complementare",
    "complementate": "complementare",
    "complementati": "complementare",
    "complementato": "complementare",
    "complementava": "complementare",
    "complementavamo": "complementare",
    "complementavan": "complementare",
    "complementavano": "complementare",
    "complementavate": "complementare",
    "complementavi": "complementare",
    "complementavo": "complementare",
    "complementerai": "complementare",
    "complementeran": "complementare",
    "complementeranno": "complementare",
    "complementerebbe": "complementare",
    "complementerebber": "complementare",
    "complementerebbero": "complementare",
    "complementerei": "complementare",
    "complementeremmo": "complementare",
    "complementeremo": "complementare",
    "complementereste": "complementare",
    "complementeresti": "complementare",
    "complementerete": "complementare",
    "complementerà": "complementare",
    "complementerò": "complementare",
    "complementi": "complemento",
    "complementiamo": "complementare",
    "complementiate": "complementare",
    "complementin": "complementare",
    "complementino": "complementare",
    "complemento": "complementare",
    "complementò": "complementare",
    "complessa": "complesso",
    "complessata": "complessato",
    "complessate": "complessato",
    "complessati": "complessato",
    "complesse": "complesso",
    "complessi": "complesso",
    "complessini": "complessino",
    "complessiva": "complessivo",
    "complessive": "complessivo",
    "complessivi": "complessivo",
    "completa": "completo",
    "completai": "completare",
    "completamenti": "completamento",
    "completammo": "completare",
    "completan": "completare",
    "completando": "completare",
    "completano": "completare",
    "completante": "completare",
    "completanti": "completare",
    "completar": "completare",
    "completaron": "completare",
    "completarono": "completare",
    "completasse": "completare",
    "completasser": "completare",
    "completassero": "completare",
    "completassi": "completare",
    "completassimo": "completare",
    "completaste": "completare",
    "completasti": "completare",
    "completata": "completare",
    "completate": "completare",
    "completati": "completare",
    "completato": "completare",
    "completava": "completare",
    "completavamo": "completare",
    "completavan": "completare",
    "completavano": "completare",
    "completavate": "completare",
    "completavi": "completare",
    "completavo": "completare",
    "complete": "completo",
    "completerai": "completare",
    "completeran": "completare",
    "completeranno": "completare",
    "completerebbe": "completare",
    "completerebber": "completare",
    "completerebbero": "completare",
    "completerei": "completare",
    "completeremmo": "completare",
    "completeremo": "completare",
    "completereste": "completare",
    "completeresti": "completare",
    "completerete": "completare",
    "completerà": "completare",
    "completerò": "completare",
    "completezze": "completezza",
    "completi": "completo",
    "completiamo": "completare",
    "completiate": "completare",
    "completin": "completare",
    "completini": "completino",
    "completino": "completare",
    "completo": "completare",
    "completò": "completare",
    "complica": "complicare",
    "complicai": "complicare",
    "complicammo": "complicare",
    "complican": "complicare",
    "complicando": "complicare",
    "complicano": "complicare",
    "complicante": "complicare",
    "complicanti": "complicare",
    "complicanze": "complicanza",
    "complicar": "complicare",
    "complicaron": "complicare",
    "complicarono": "complicare",
    "complicasse": "complicare",
    "complicasser": "complicare",
    "complicassero": "complicare",
    "complicassi": "complicare",
    "complicassimo": "complicare",
    "complicaste": "complicare",
    "complicasti": "complicare",
    "complicata": "complicato",
    "complicate": "complicato",
    "complicati": "complicato",
    "complicato": "complicare",
    "complicava": "complicare",
    "complicavamo": "complicare",
    "complicavan": "complicare",
    "complicavano": "complicare",
    "complicavate": "complicare",
    "complicavi": "complicare",
    "complicavo": "complicare",
    "complicazioni": "complicazione",
    "complicherai": "complicare",
    "complicheran": "complicare",
    "complicheranno": "complicare",
    "complicherebbe": "complicare",
    "complicherebber": "complicare",
    "complicherebbero": "complicare",
    "complicherei": "complicare",
    "complicheremmo": "complicare",
    "complicheremo": "complicare",
    "complichereste": "complicare",
    "complicheresti": "complicare",
    "complicherete": "complicare",
    "complicherà": "complicare",
    "complicherò": "complicare",
    "complichi": "complicare",
    "complichiamo": "complicare",
    "complichiate": "complicare",
    "complichin": "complicare",
    "complichino": "complicare",
    "complici": "complice",
    "complico": "complicare",
    "complicò": "complicare",
    "complimenta": "complimentare",
    "complimentai": "complimentare",
    "complimentammo": "complimentare",
    "complimentan": "complimentare",
    "complimentando": "complimentare",
    "complimentano": "complimentare",
    "complimentante": "complimentare",
    "complimentanti": "complimentare",
    "complimentar": "complimentare",
    "complimentaron": "complimentare",
    "complimentarono": "complimentare",
    "complimentasse": "complimentare",
    "complimentasser": "complimentare",
    "complimentassero": "complimentare",
    "complimentassi": "complimentare",
    "complimentassimo": "complimentare",
    "complimentaste": "complimentare",
    "complimentasti": "complimentare",
    "complimentata": "complimentare",
    "complimentate": "complimentare",
    "complimentati": "complimentare",
    "complimentato": "complimentare",
    "complimentava": "complimentare",
    "complimentavamo": "complimentare",
    "complimentavan": "complimentare",
    "complimentavano": "complimentare",
    "complimentavate": "complimentare",
    "complimentavi": "complimentare",
    "complimentavo": "complimentare",
    "complimenterai": "complimentare",
    "complimenteran": "complimentare",
    "complimenteranno": "complimentare",
    "complimenterebbe": "complimentare",
    "complimenterebber": "complimentare",
    "complimenterebbero": "complimentare",
    "complimenterei": "complimentare",
    "complimenteremmo": "complimentare",
    "complimenteremo": "complimentare",
    "complimentereste": "complimentare",
    "complimenteresti": "complimentare",
    "complimenterete": "complimentare",
    "complimenterà": "complimentare",
    "complimenterò": "complimentare",
    "complimenti": "complimento",
    "complimentiamo": "complimentare",
    "complimentiate": "complimentare",
    "complimentin": "complimentare",
    "complimentino": "complimentare",
    "complimento": "complimentare",
    "complimentosa": "complimentoso",
    "complimentose": "complimentoso",
    "complimentosi": "complimentoso",
    "complimentò": "complimentare",
    "complotta": "complottare",
    "complottai": "complottare",
    "complottammo": "complottare",
    "complottan": "complottare",
    "complottando": "complottare",
    "complottano": "complottare",
    "complottante": "complottare",
    "complottanti": "complottare",
    "complottar": "complottare",
    "complottaron": "complottare",
    "complottarono": "complottare",
    "complottasse": "complottare",
    "complottasser": "complottare",
    "complottassero": "complottare",
    "complottassi": "complottare",
    "complottassimo": "complottare",
    "complottaste": "complottare",
    "complottasti": "complottare",
    "complottata": "complottare",
    "complottate": "complottare",
    "complottati": "complottare",
    "complottato": "complottare",
    "complottatori": "complottatore",
    "complottava": "complottare",
    "complottavamo": "complottare",
    "complottavan": "complottare",
    "complottavano": "complottare",
    "complottavate": "complottare",
    "complottavi": "complottare",
    "complottavo": "complottare",
    "complotterai": "complottare",
    "complotteran": "complottare",
    "complotteranno": "complottare",
    "complotterebbe": "complottare",
    "complotterebber": "complottare",
    "complotterebbero": "complottare",
    "complotterei": "complottare",
    "complotteremmo": "complottare",
    "complotteremo": "complottare",
    "complottereste": "complottare",
    "complotteresti": "complottare",
    "complotterete": "complottare",
    "complotterà": "complottare",
    "complotterò": "complottare",
    "complotti": "complotto",
    "complottiamo": "complottare",
    "complottiate": "complottare",
    "complottin": "complottare",
    "complottino": "complottare",
    "complotto": "complottare",
    "complottò": "complottare",
    "compone": "comporre",
    "componemmo": "comporre",
    "componendo": "comporre",
    "componente": "comporre",
    "componenti": "comporre",
    "componentistiche": "componentistica",
    "componesse": "comporre",
    "componesser": "comporre",
    "componessero": "comporre",
    "componessi": "comporre",
    "componessimo": "comporre",
    "componeste": "comporre",
    "componesti": "comporre",
    "componete": "comporre",
    "componeva": "comporre",
    "componevamo": "comporre",
    "componevan": "comporre",
    "componevano": "comporre",
    "componevate": "comporre",
    "componevi": "comporre",
    "componevo": "comporre",
    "componga": "comporre",
    "compongan": "comporre",
    "compongano": "comporre",
    "compongo": "comporre",
    "compongon": "comporre",
    "compongono": "comporre",
    "componi": "comporre",
    "componiamo": "comporre",
    "componiate": "comporre",
    "componibili": "componibile",
    "componimenti": "componimento",
    "comporr": "comporre",
    "comporrai": "comporre",
    "comporran": "comporre",
    "comporranno": "comporre",
    "comporrebbe": "comporre",
    "comporrebber": "comporre",
    "comporrebbero": "comporre",
    "comporrei": "comporre",
    "comporremmo": "comporre",
    "comporremo": "comporre",
    "comporreste": "comporre",
    "comporresti": "comporre",
    "comporrete": "comporre",
    "comporrà": "comporre",
    "comporrò": "comporre",
    "comporta": "comportare",
    "comportai": "comportare",
    "comportamentali": "comportamentale",
    "comportamenti": "comportamento",
    "comportammo": "comportare",
    "comportan": "comportare",
    "comportando": "comportare",
    "comportano": "comportare",
    "comportante": "comportare",
    "comportanti": "comportare",
    "comportar": "comportare",
    "comportaron": "comportare",
    "comportarono": "comportare",
    "comportasse": "comportare",
    "comportasser": "comportare",
    "comportassero": "comportare",
    "comportassi": "comportare",
    "comportassimo": "comportare",
    "comportaste": "comportare",
    "comportasti": "comportare",
    "comportata": "comportare",
    "comportate": "comportare",
    "comportati": "comportare",
    "comportato": "comportare",
    "comportava": "comportare",
    "comportavamo": "comportare",
    "comportavan": "comportare",
    "comportavano": "comportare",
    "comportavate": "comportare",
    "comportavi": "comportare",
    "comportavo": "comportare",
    "comporterai": "comportare",
    "comporteran": "comportare",
    "comporteranno": "comportare",
    "comporterebbe": "comportare",
    "comporterebber": "comportare",
    "comporterebbero": "comportare",
    "comporterei": "comportare",
    "comporteremmo": "comportare",
    "comporteremo": "comportare",
    "comportereste": "comportare",
    "comporteresti": "comportare",
    "comporterete": "comportare",
    "comporterà": "comportare",
    "comporterò": "comportare",
    "comporti": "comportare",
    "comportiamo": "comportare",
    "comportiate": "comportare",
    "comportin": "comportare",
    "comportino": "comportare",
    "comporto": "comportare",
    "comportò": "comportare",
    "compose": "comporre",
    "composer": "comporre",
    "composero": "comporre",
    "composi": "comporre",
    "composita": "composito",
    "composite": "composito",
    "compositi": "composito",
    "compositiva": "compositivo",
    "compositive": "compositivo",
    "compositivi": "compositivo",
    "compositori": "compositore",
    "composizioni": "composizione",
    "composta": "composto",
    "composte": "composto",
    "composti": "composto",
    "composto": "comporre",
    "compra": "comprare",
    "comprai": "comprare",
    "comprammo": "comprare",
    "compran": "comprare",
    "comprando": "comprare",
    "comprano": "comprare",
    "comprante": "comprare",
    "compranti": "comprare",
    "comprar": "comprare",
    "compraron": "comprare",
    "comprarono": "comprare",
    "comprasse": "comprare",
    "comprasser": "comprare",
    "comprassero": "comprare",
    "comprassi": "comprare",
    "comprassimo": "comprare",
    "compraste": "comprare",
    "comprasti": "comprare",
    "comprata": "comprare",
    "comprate": "comprare",
    "comprati": "comprare",
    "comprato": "comprare",
    "compratori": "compratore",
    "comprava": "comprare",
    "compravamo": "comprare",
    "compravan": "comprare",
    "compravano": "comprare",
    "compravate": "comprare",
    "compravenda": "compravendere",
    "compravendan": "compravendere",
    "compravendano": "compravendere",
    "compravende": "compravendere",
    "compravendemmo": "compravendere",
    "compravendendo": "compravendere",
    "compravendente": "compravendere",
    "compravendenti": "compravendere",
    "compravender": "compravendere",
    "compravenderai": "compravendere",
    "compravenderan": "compravendere",
    "compravenderanno": "compravendere",
    "compravenderebbe": "compravendere",
    "compravenderebber": "compravendere",
    "compravenderebbero": "compravendere",
    "compravenderei": "compravendere",
    "compravenderemmo": "compravendere",
    "compravenderemo": "compravendere",
    "compravendereste": "compravendere",
    "compravenderesti": "compravendere",
    "compravenderete": "compravendere",
    "compravenderà": "compravendere",
    "compravenderò": "compravendere",
    "compravendesse": "compravendere",
    "compravendesser": "compravendere",
    "compravendessero": "compravendere",
    "compravendessi": "compravendere",
    "compravendessimo": "compravendere",
    "compravendeste": "compravendere",
    "compravendesti": "compravendere",
    "compravendete": "compravendere",
    "compravendeva": "compravendere",
    "compravendevamo": "compravendere",
    "compravendevan": "compravendere",
    "compravendevano": "compravendere",
    "compravendevate": "compravendere",
    "compravendevi": "compravendere",
    "compravendevo": "compravendere",
    "compravendi": "compravendere",
    "compravendiamo": "compravendere",
    "compravendiate": "compravendere",
    "compravendite": "compravendita",
    "compravendo": "compravendere",
    "compravendon": "compravendere",
    "compravendono": "compravendere",
    "compravesa": "compravendere",
    "compravese": "compravendere",
    "compraveser": "compravendere",
    "compravesero": "compravendere",
    "compravesi": "compravendere",
    "compraveso": "compravendere",
    "compravesè": "compravendere",
    "compravi": "comprare",
    "compravo": "comprare",
    "comprenda": "comprendere",
    "comprendan": "comprendere",
    "comprendano": "comprendere",
    "comprende": "comprendere",
    "comprendemmo": "comprendere",
    "comprendendo": "comprendere",
    "comprendente": "comprendere",
    "comprendenti": "comprendere",
    "comprender": "comprendere",
    "comprenderai": "comprendere",
    "comprenderan": "comprendere",
    "comprenderanno": "comprendere",
    "comprenderebbe": "comprendere",
    "comprenderebber": "comprendere",
    "comprenderebbero": "comprendere",
    "comprenderei": "comprendere",
    "comprenderemmo": "comprendere",
    "comprenderemo": "comprendere",
    "comprendereste": "comprendere",
    "comprenderesti": "comprendere",
    "comprenderete": "comprendere",
    "comprenderà": "comprendere",
    "comprenderò": "comprendere",
    "comprendesse": "comprendere",
    "comprendesser": "comprendere",
    "comprendessero": "comprendere",
    "comprendessi": "comprendere",
    "comprendessimo": "comprendere",
    "comprendeste": "comprendere",
    "comprendesti": "comprendere",
    "comprendete": "comprendere",
    "comprendeva": "comprendere",
    "comprendevamo": "comprendere",
    "comprendevan": "comprendere",
    "comprendevano": "comprendere",
    "comprendevate": "comprendere",
    "comprendevi": "comprendere",
    "comprendevo": "comprendere",
    "comprendi": "comprendere",
    "comprendiamo": "comprendere",
    "comprendiate": "comprendere",
    "comprendo": "comprendere",
    "comprendon": "comprendere",
    "comprendono": "comprendere",
    "comprensibili": "comprensibile",
    "comprensioni": "comprensione",
    "comprensiva": "comprensivo",
    "comprensive": "comprensivo",
    "comprensivi": "comprensivo",
    "comprensori": "comprensorio",
    "comprerai": "comprare",
    "compreran": "comprare",
    "compreranno": "comprare",
    "comprerebbe": "comprare",
    "comprerebber": "comprare",
    "comprerebbero": "comprare",
    "comprerei": "comprare",
    "compreremmo": "comprare",
    "compreremo": "comprare",
    "comprereste": "comprare",
    "compreresti": "comprare",
    "comprerete": "comprare",
    "comprerà": "comprare",
    "comprerò": "comprare",
    "compresa": "compreso",
    "comprese": "compreso",
    "compresenze": "compresenza",
    "compreser": "comprendere",
    "compresero": "comprendere",
    "compresi": "compreso",
    "compreso": "comprendere",
    "compressa": "comprimere",
    "compresse": "comprimere",
    "compresser": "comprimere",
    "compressero": "comprimere",
    "compressi": "comprimere",
    "compressioni": "compressione",
    "compresso": "comprimere",
    "compressori": "compressore",
    "compresè": "comprendere",
    "compri": "comprare",
    "compriamo": "comprare",
    "compriate": "comprare",
    "comprima": "comprimere",
    "compriman": "comprimere",
    "comprimano": "comprimere",
    "comprimari": "comprimario",
    "comprime": "comprimere",
    "comprimemmo": "comprimere",
    "comprimendo": "comprimere",
    "comprimente": "comprimere",
    "comprimenti": "comprimere",
    "comprimer": "comprimere",
    "comprimerai": "comprimere",
    "comprimeran": "comprimere",
    "comprimeranno": "comprimere",
    "comprimerebbe": "comprimere",
    "comprimerebber": "comprimere",
    "comprimerebbero": "comprimere",
    "comprimerei": "comprimere",
    "comprimeremmo": "comprimere",
    "comprimeremo": "comprimere",
    "comprimereste": "comprimere",
    "comprimeresti": "comprimere",
    "comprimerete": "comprimere",
    "comprimerà": "comprimere",
    "comprimerò": "comprimere",
    "comprimesse": "comprimere",
    "comprimesser": "comprimere",
    "comprimessero": "comprimere",
    "comprimessi": "comprimere",
    "comprimessimo": "comprimere",
    "comprimeste": "comprimere",
    "comprimesti": "comprimere",
    "comprimete": "comprimere",
    "comprimeva": "comprimere",
    "comprimevamo": "comprimere",
    "comprimevan": "comprimere",
    "comprimevano": "comprimere",
    "comprimevate": "comprimere",
    "comprimevi": "comprimere",
    "comprimevo": "comprimere",
    "comprimi": "comprimere",
    "comprimiamo": "comprimere",
    "comprimiate": "comprimere",
    "comprimibili": "comprimibile",
    "comprimo": "comprimere",
    "comprimon": "comprimere",
    "comprimono": "comprimere",
    "comprin": "comprare",
    "comprino": "comprare",
    "compro": "comprare",
    "compromessa": "compromettere",
    "compromesse": "compromettere",
    "compromessi": "compromettere",
    "compromesso": "compromettere",
    "comprometta": "compromettere",
    "compromettan": "compromettere",
    "compromettano": "compromettere",
    "compromette": "compromettere",
    "compromettemmo": "compromettere",
    "compromettendo": "compromettere",
    "compromettente": "compromettere",
    "compromettenti": "compromettere",
    "comprometter": "compromettere",
    "comprometterai": "compromettere",
    "comprometteran": "compromettere",
    "comprometteranno": "compromettere",
    "comprometterebbe": "compromettere",
    "comprometterebber": "compromettere",
    "comprometterebbero": "compromettere",
    "comprometterei": "compromettere",
    "comprometteremmo": "compromettere",
    "comprometteremo": "compromettere",
    "compromettereste": "compromettere",
    "comprometteresti": "compromettere",
    "comprometterete": "compromettere",
    "comprometterà": "compromettere",
    "comprometterò": "compromettere",
    "compromettesse": "compromettere",
    "compromettesser": "compromettere",
    "compromettessero": "compromettere",
    "compromettessi": "compromettere",
    "compromettessimo": "compromettere",
    "comprometteste": "compromettere",
    "compromettesti": "compromettere",
    "compromettete": "compromettere",
    "comprometteva": "compromettere",
    "compromettevamo": "compromettere",
    "compromettevan": "compromettere",
    "compromettevano": "compromettere",
    "compromettevate": "compromettere",
    "compromettevi": "compromettere",
    "compromettevo": "compromettere",
    "comprometti": "compromettere",
    "compromettiamo": "compromettere",
    "compromettiate": "compromettere",
    "comprometto": "compromettere",
    "comprometton": "compromettere",
    "compromettono": "compromettere",
    "compromise": "compromettere",
    "compromiser": "compromettere",
    "compromisero": "compromettere",
    "compromisi": "compromettere",
    "compromissioni": "compromissione",
    "compromissiva": "compromissivo",
    "compromissive": "compromissivo",
    "compromissivi": "compromissivo",
    "compromissori": "compromissorio",
    "compromissoria": "compromissorio",
    "compromissorie": "compromissorio",
    "comprova": "comprovare",
    "comprovai": "comprovare",
    "comprovammo": "comprovare",
    "comprovan": "comprovare",
    "comprovando": "comprovare",
    "comprovano": "comprovare",
    "comprovante": "comprovare",
    "comprovanti": "comprovare",
    "comprovar": "comprovare",
    "comprovaron": "comprovare",
    "comprovarono": "comprovare",
    "comprovasse": "comprovare",
    "comprovasser": "comprovare",
    "comprovassero": "comprovare",
    "comprovassi": "comprovare",
    "comprovassimo": "comprovare",
    "comprovaste": "comprovare",
    "comprovasti": "comprovare",
    "comprovata": "comprovare",
    "comprovate": "comprovare",
    "comprovati": "comprovare",
    "comprovato": "comprovare",
    "comprovava": "comprovare",
    "comprovavamo": "comprovare",
    "comprovavan": "comprovare",
    "comprovavano": "comprovare",
    "comprovavate": "comprovare",
    "comprovavi": "comprovare",
    "comprovavo": "comprovare",
    "comproverai": "comprovare",
    "comproveran": "comprovare",
    "comproveranno": "comprovare",
    "comproverebbe": "comprovare",
    "comproverebber": "comprovare",
    "comproverebbero": "comprovare",
    "comproverei": "comprovare",
    "comproveremmo": "comprovare",
    "comproveremo": "comprovare",
    "comprovereste": "comprovare",
    "comproveresti": "comprovare",
    "comproverete": "comprovare",
    "comproverà": "comprovare",
    "comproverò": "comprovare",
    "comprovi": "comprovare",
    "comproviamo": "comprovare",
    "comproviate": "comprovare",
    "comprovin": "comprovare",
    "comprovino": "comprovare",
    "comprovo": "comprovare",
    "comprovò": "comprovare",
    "comprò": "comprare",
    "compulsa": "compulsare",
    "compulsai": "compulsare",
    "compulsammo": "compulsare",
    "compulsan": "compulsare",
    "compulsando": "compulsare",
    "compulsano": "compulsare",
    "compulsante": "compulsare",
    "compulsanti": "compulsare",
    "compulsar": "compulsare",
    "compulsaron": "compulsare",
    "compulsarono": "compulsare",
    "compulsasse": "compulsare",
    "compulsasser": "compulsare",
    "compulsassero": "compulsare",
    "compulsassi": "compulsare",
    "compulsassimo": "compulsare",
    "compulsaste": "compulsare",
    "compulsasti": "compulsare",
    "compulsata": "compulsare",
    "compulsate": "compulsare",
    "compulsati": "compulsare",
    "compulsato": "compulsare",
    "compulsava": "compulsare",
    "compulsavamo": "compulsare",
    "compulsavan": "compulsare",
    "compulsavano": "compulsare",
    "compulsavate": "compulsare",
    "compulsavi": "compulsare",
    "compulsavo": "compulsare",
    "compulserai": "compulsare",
    "compulseran": "compulsare",
    "compulseranno": "compulsare",
    "compulserebbe": "compulsare",
    "compulserebber": "compulsare",
    "compulserebbero": "compulsare",
    "compulserei": "compulsare",
    "compulseremmo": "compulsare",
    "compulseremo": "compulsare",
    "compulsereste": "compulsare",
    "compulseresti": "compulsare",
    "compulserete": "compulsare",
    "compulserà": "compulsare",
    "compulserò": "compulsare",
    "compulsi": "compulsare",
    "compulsiamo": "compulsare",
    "compulsiate": "compulsare",
    "compulsin": "compulsare",
    "compulsino": "compulsare",
    "compulsiva": "compulsivo",
    "compulsive": "compulsivo",
    "compulsivi": "compulsivo",
    "compulso": "compulsare",
    "compulsò": "compulsare",
    "compunga": "compungere",
    "compungan": "compungere",
    "compungano": "compungere",
    "compunge": "compungere",
    "compungemmo": "compungere",
    "compungendo": "compungere",
    "compungente": "compungere",
    "compungenti": "compungere",
    "compunger": "compungere",
    "compungerai": "compungere",
    "compungeran": "compungere",
    "compungeranno": "compungere",
    "compungerebbe": "compungere",
    "compungerebber": "compungere",
    "compungerebbero": "compungere",
    "compungerei": "compungere",
    "compungeremmo": "compungere",
    "compungeremo": "compungere",
    "compungereste": "compungere",
    "compungeresti": "compungere",
    "compungerete": "compungere",
    "compungerà": "compungere",
    "compungerò": "compungere",
    "compungesse": "compungere",
    "compungesser": "compungere",
    "compungessero": "compungere",
    "compungessi": "compungere",
    "compungessimo": "compungere",
    "compungeste": "compungere",
    "compungesti": "compungere",
    "compungete": "compungere",
    "compungeva": "compungere",
    "compungevamo": "compungere",
    "compungevan": "compungere",
    "compungevano": "compungere",
    "compungevate": "compungere",
    "compungevi": "compungere",
    "compungevo": "compungere",
    "compungi": "compungere",
    "compungiamo": "compungere",
    "compungiate": "compungere",
    "compungo": "compungere",
    "compungon": "compungere",
    "compungono": "compungere",
    "compunser": "compungere",
    "compunsero": "compungere",
    "compunsi": "compungere",
    "compunsè": "compungere",
    "compunta": "compunto",
    "compunte": "compunto",
    "compunti": "compunto",
    "compunto": "compungere",
    "computa": "computare",
    "computai": "computare",
    "computammo": "computare",
    "computan": "computare",
    "computando": "computare",
    "computano": "computare",
    "computante": "computare",
    "computanti": "computare",
    "computar": "computare",
    "computaron": "computare",
    "computarono": "computare",
    "computasse": "computare",
    "computasser": "computare",
    "computassero": "computare",
    "computassi": "computare",
    "computassimo": "computare",
    "computaste": "computare",
    "computasti": "computare",
    "computata": "computare",
    "computate": "computare",
    "computati": "computare",
    "computato": "computare",
    "computava": "computare",
    "computavamo": "computare",
    "computavan": "computare",
    "computavano": "computare",
    "computavate": "computare",
    "computavi": "computare",
    "computavo": "computare",
    "computerai": "computare",
    "computeran": "computare",
    "computeranno": "computare",
    "computerebbe": "computare",
    "computerebber": "computare",
    "computerebbero": "computare",
    "computerei": "computare",
    "computeremmo": "computare",
    "computeremo": "computare",
    "computereste": "computare",
    "computeresti": "computare",
    "computerete": "computare",
    "computerizza": "computerizzare",
    "computerizzai": "computerizzare",
    "computerizzammo": "computerizzare",
    "computerizzan": "computerizzare",
    "computerizzando": "computerizzare",
    "computerizzano": "computerizzare",
    "computerizzante": "computerizzare",
    "computerizzanti": "computerizzare",
    "computerizzar": "computerizzare",
    "computerizzaron": "computerizzare",
    "computerizzarono": "computerizzare",
    "computerizzasse": "computerizzare",
    "computerizzasser": "computerizzare",
    "computerizzassero": "computerizzare",
    "computerizzassi": "computerizzare",
    "computerizzassimo": "computerizzare",
    "computerizzaste": "computerizzare",
    "computerizzasti": "computerizzare",
    "computerizzata": "computerizzare",
    "computerizzate": "computerizzare",
    "computerizzati": "computerizzare",
    "computerizzato": "computerizzare",
    "computerizzava": "computerizzare",
    "computerizzavamo": "computerizzare",
    "computerizzavan": "computerizzare",
    "computerizzavano": "computerizzare",
    "computerizzavate": "computerizzare",
    "computerizzavi": "computerizzare",
    "computerizzavo": "computerizzare",
    "computerizzazioni": "computerizzazione",
    "computerizzerai": "computerizzare",
    "computerizzeran": "computerizzare",
    "computerizzeranno": "computerizzare",
    "computerizzerebbe": "computerizzare",
    "computerizzerebber": "computerizzare",
    "computerizzerebbero": "computerizzare",
    "computerizzerei": "computerizzare",
    "computerizzeremmo": "computerizzare",
    "computerizzeremo": "computerizzare",
    "computerizzereste": "computerizzare",
    "computerizzeresti": "computerizzare",
    "computerizzerete": "computerizzare",
    "computerizzerà": "computerizzare",
    "computerizzerò": "computerizzare",
    "computerizzi": "computerizzare",
    "computerizziamo": "computerizzare",
    "computerizziate": "computerizzare",
    "computerizzin": "computerizzare",
    "computerizzino": "computerizzare",
    "computerizzo": "computerizzare",
    "computerizzò": "computerizzare",
    "computers": "computer",
    "computerà": "computare",
    "computerò": "computare",
    "computi": "computo",
    "computiamo": "computare",
    "computiate": "computare",
    "computin": "computare",
    "computino": "computare",
    "computo": "computare",
    "computò": "computare",
    "compì": "compire",
    "comunali": "comunale",
    "comunanze": "comunanza",
    "comunarda": "comunardo",
    "comunarde": "comunardo",
    "comunardi": "comunardo",
    "comuni": "comune",
    "comunica": "comunicare",
    "comunicabili": "comunicabile",
    "comunicai": "comunicare",
    "comunicammo": "comunicare",
    "comunican": "comunicare",
    "comunicando": "comunicare",
    "comunicano": "comunicare",
    "comunicante": "comunicare",
    "comunicanti": "comunicare",
    "comunicar": "comunicare",
    "comunicaron": "comunicare",
    "comunicarono": "comunicare",
    "comunicasse": "comunicare",
    "comunicasser": "comunicare",
    "comunicassero": "comunicare",
    "comunicassi": "comunicare",
    "comunicassimo": "comunicare",
    "comunicaste": "comunicare",
    "comunicasti": "comunicare",
    "comunicata": "comunicato",
    "comunicate": "comunicato",
    "comunicati": "comunicato",
    "comunicativa": "comunicativo",
    "comunicative": "comunicativo",
    "comunicativi": "comunicativo",
    "comunicato": "comunicare",
    "comunicatori": "comunicatore",
    "comunicava": "comunicare",
    "comunicavamo": "comunicare",
    "comunicavan": "comunicare",
    "comunicavano": "comunicare",
    "comunicavate": "comunicare",
    "comunicavi": "comunicare",
    "comunicavo": "comunicare",
    "comunicazioni": "comunicazione",
    "comunicherai": "comunicare",
    "comunicheran": "comunicare",
    "comunicheranno": "comunicare",
    "comunicherebbe": "comunicare",
    "comunicherebber": "comunicare",
    "comunicherebbero": "comunicare",
    "comunicherei": "comunicare",
    "comunicheremmo": "comunicare",
    "comunicheremo": "comunicare",
    "comunichereste": "comunicare",
    "comunicheresti": "comunicare",
    "comunicherete": "comunicare",
    "comunicherà": "comunicare",
    "comunicherò": "comunicare",
    "comunichi": "comunicare",
    "comunichiamo": "comunicare",
    "comunichiate": "comunicare",
    "comunichin": "comunicare",
    "comunichino": "comunicare",
    "comunico": "comunicare",
    "comunicò": "comunicare",
    "comunioni": "comunione",
    "comunismi": "comunismo",
    "comuniste": "comunista",
    "comunisti": "comunista",
    "comunistizza": "comunistizzare",
    "comunistizzai": "comunistizzare",
    "comunistizzammo": "comunistizzare",
    "comunistizzan": "comunistizzare",
    "comunistizzando": "comunistizzare",
    "comunistizzano": "comunistizzare",
    "comunistizzante": "comunistizzare",
    "comunistizzanti": "comunistizzare",
    "comunistizzar": "comunistizzare",
    "comunistizzaron": "comunistizzare",
    "comunistizzarono": "comunistizzare",
    "comunistizzasse": "comunistizzare",
    "comunistizzasser": "comunistizzare",
    "comunistizzassero": "comunistizzare",
    "comunistizzassi": "comunistizzare",
    "comunistizzassimo": "comunistizzare",
    "comunistizzaste": "comunistizzare",
    "comunistizzasti": "comunistizzare",
    "comunistizzata": "comunistizzare",
    "comunistizzate": "comunistizzare",
    "comunistizzati": "comunistizzare",
    "comunistizzato": "comunistizzare",
    "comunistizzava": "comunistizzare",
    "comunistizzavamo": "comunistizzare",
    "comunistizzavan": "comunistizzare",
    "comunistizzavano": "comunistizzare",
    "comunistizzavate": "comunistizzare",
    "comunistizzavi": "comunistizzare",
    "comunistizzavo": "comunistizzare",
    "comunistizzerai": "comunistizzare",
    "comunistizzeran": "comunistizzare",
    "comunistizzeranno": "comunistizzare",
    "comunistizzerebbe": "comunistizzare",
    "comunistizzerebber": "comunistizzare",
    "comunistizzerebbero": "comunistizzare",
    "comunistizzerei": "comunistizzare",
    "comunistizzeremmo": "comunistizzare",
    "comunistizzeremo": "comunistizzare",
    "comunistizzereste": "comunistizzare",
    "comunistizzeresti": "comunistizzare",
    "comunistizzerete": "comunistizzare",
    "comunistizzerà": "comunistizzare",
    "comunistizzerò": "comunistizzare",
    "comunistizzi": "comunistizzare",
    "comunistizziamo": "comunistizzare",
    "comunistizziate": "comunistizzare",
    "comunistizzin": "comunistizzare",
    "comunistizzino": "comunistizzare",
    "comunistizzo": "comunistizzare",
    "comunistizzò": "comunistizzare",
    "comunitari": "comunitario",
    "comunitaria": "comunitario",
    "comunitarie": "comunitario",
    "comunitarizza": "comunitarizzare",
    "comunitarizzai": "comunitarizzare",
    "comunitarizzammo": "comunitarizzare",
    "comunitarizzan": "comunitarizzare",
    "comunitarizzando": "comunitarizzare",
    "comunitarizzano": "comunitarizzare",
    "comunitarizzante": "comunitarizzare",
    "comunitarizzanti": "comunitarizzare",
    "comunitarizzar": "comunitarizzare",
    "comunitarizzaron": "comunitarizzare",
    "comunitarizzarono": "comunitarizzare",
    "comunitarizzasse": "comunitarizzare",
    "comunitarizzasser": "comunitarizzare",
    "comunitarizzassero": "comunitarizzare",
    "comunitarizzassi": "comunitarizzare",
    "comunitarizzassimo": "comunitarizzare",
    "comunitarizzaste": "comunitarizzare",
    "comunitarizzasti": "comunitarizzare",
    "comunitarizzata": "comunitarizzare",
    "comunitarizzate": "comunitarizzare",
    "comunitarizzati": "comunitarizzare",
    "comunitarizzato": "comunitarizzare",
    "comunitarizzava": "comunitarizzare",
    "comunitarizzavamo": "comunitarizzare",
    "comunitarizzavan": "comunitarizzare",
    "comunitarizzavano": "comunitarizzare",
    "comunitarizzavate": "comunitarizzare",
    "comunitarizzavi": "comunitarizzare",
    "comunitarizzavo": "comunitarizzare",
    "comunitarizzerai": "comunitarizzare",
    "comunitarizzeran": "comunitarizzare",
    "comunitarizzeranno": "comunitarizzare",
    "comunitarizzerebbe": "comunitarizzare",
    "comunitarizzerebber": "comunitarizzare",
    "comunitarizzerebbero": "comunitarizzare",
    "comunitarizzerei": "comunitarizzare",
    "comunitarizzeremmo": "comunitarizzare",
    "comunitarizzeremo": "comunitarizzare",
    "comunitarizzereste": "comunitarizzare",
    "comunitarizzeresti": "comunitarizzare",
    "comunitarizzerete": "comunitarizzare",
    "comunitarizzerà": "comunitarizzare",
    "comunitarizzerò": "comunitarizzare",
    "comunitarizzi": "comunitarizzare",
    "comunitarizziamo": "comunitarizzare",
    "comunitarizziate": "comunitarizzare",
    "comunitarizzin": "comunitarizzare",
    "comunitarizzino": "comunitarizzare",
    "comunitarizzo": "comunitarizzare",
    "comunitarizzò": "comunitarizzare",
    "conati": "conato",
    "concambi": "concambio",
    "concatena": "concatenare",
    "concatenai": "concatenare",
    "concatenamenti": "concatenamento",
    "concatenammo": "concatenare",
    "concatenan": "concatenare",
    "concatenando": "concatenare",
    "concatenano": "concatenare",
    "concatenante": "concatenare",
    "concatenanti": "concatenare",
    "concatenar": "concatenare",
    "concatenaron": "concatenare",
    "concatenarono": "concatenare",
    "concatenasse": "concatenare",
    "concatenasser": "concatenare",
    "concatenassero": "concatenare",
    "concatenassi": "concatenare",
    "concatenassimo": "concatenare",
    "concatenaste": "concatenare",
    "concatenasti": "concatenare",
    "concatenata": "concatenare",
    "concatenate": "concatenare",
    "concatenati": "concatenare",
    "concatenato": "concatenare",
    "concatenava": "concatenare",
    "concatenavamo": "concatenare",
    "concatenavan": "concatenare",
    "concatenavano": "concatenare",
    "concatenavate": "concatenare",
    "concatenavi": "concatenare",
    "concatenavo": "concatenare",
    "concatenazioni": "concatenazione",
    "concatenerai": "concatenare",
    "concateneran": "concatenare",
    "concateneranno": "concatenare",
    "concatenerebbe": "concatenare",
    "concatenerebber": "concatenare",
    "concatenerebbero": "concatenare",
    "concatenerei": "concatenare",
    "concateneremmo": "concatenare",
    "concateneremo": "concatenare",
    "concatenereste": "concatenare",
    "concateneresti": "concatenare",
    "concatenerete": "concatenare",
    "concatenerà": "concatenare",
    "concatenerò": "concatenare",
    "concateni": "concatenare",
    "concateniamo": "concatenare",
    "concateniate": "concatenare",
    "concatenin": "concatenare",
    "concatenino": "concatenare",
    "concateno": "concatenare",
    "concatenò": "concatenare",
    "concause": "concausa",
    "concava": "concavo",
    "concave": "concavo",
    "concavi": "concavo",
    "conceda": "concedere",
    "concedan": "concedere",
    "concedano": "concedere",
    "concede": "concedere",
    "concedemmo": "concedere",
    "concedendo": "concedere",
    "concedente": "concedere",
    "concedenti": "concedere",
    "conceder": "concedere",
    "concederai": "concedere",
    "concederan": "concedere",
    "concederanno": "concedere",
    "concederebbe": "concedere",
    "concederebber": "concedere",
    "concederebbero": "concedere",
    "concederei": "concedere",
    "concederemmo": "concedere",
    "concederemo": "concedere",
    "concedereste": "concedere",
    "concederesti": "concedere",
    "concederete": "concedere",
    "concederà": "concedere",
    "concederò": "concedere",
    "concedesse": "concedere",
    "concedesser": "concedere",
    "concedessero": "concedere",
    "concedessi": "concedere",
    "concedessimo": "concedere",
    "concedeste": "concedere",
    "concedesti": "concedere",
    "concedete": "concedere",
    "concedette": "concedere",
    "concedettero": "concedere",
    "concedetti": "concedere",
    "concedeva": "concedere",
    "concedevamo": "concedere",
    "concedevan": "concedere",
    "concedevano": "concedere",
    "concedevate": "concedere",
    "concedevi": "concedere",
    "concedevo": "concedere",
    "concedi": "concedere",
    "concediamo": "concedere",
    "concediate": "concedere",
    "concedo": "concedere",
    "concedon": "concedere",
    "concedono": "concedere",
    "conceduta": "concedere",
    "concedute": "concedere",
    "conceduti": "concedere",
    "conceduto": "concedere",
    "concentra": "concentrare",
    "concentrai": "concentrare",
    "concentramenti": "concentramento",
    "concentrammo": "concentrare",
    "concentran": "concentrare",
    "concentrando": "concentrare",
    "concentrano": "concentrare",
    "concentrante": "concentrare",
    "concentranti": "concentrare",
    "concentrar": "concentrare",
    "concentraron": "concentrare",
    "concentrarono": "concentrare",
    "concentrasse": "concentrare",
    "concentrasser": "concentrare",
    "concentrassero": "concentrare",
    "concentrassi": "concentrare",
    "concentrassimo": "concentrare",
    "concentraste": "concentrare",
    "concentrasti": "concentrare",
    "concentrata": "concentrato",
    "concentrate": "concentrato",
    "concentrati": "concentrato",
    "concentrato": "concentrare",
    "concentrava": "concentrare",
    "concentravamo": "concentrare",
    "concentravan": "concentrare",
    "concentravano": "concentrare",
    "concentravate": "concentrare",
    "concentravi": "concentrare",
    "concentravo": "concentrare",
    "concentrazioni": "concentrazione",
    "concentrerai": "concentrare",
    "concentreran": "concentrare",
    "concentreranno": "concentrare",
    "concentrerebbe": "concentrare",
    "concentrerebber": "concentrare",
    "concentrerebbero": "concentrare",
    "concentrerei": "concentrare",
    "concentreremmo": "concentrare",
    "concentreremo": "concentrare",
    "concentrereste": "concentrare",
    "concentreresti": "concentrare",
    "concentrerete": "concentrare",
    "concentrerà": "concentrare",
    "concentrerò": "concentrare",
    "concentri": "concentrare",
    "concentriamo": "concentrare",
    "concentriate": "concentrare",
    "concentrica": "concentrico",
    "concentriche": "concentrico",
    "concentrici": "concentrico",
    "concentrin": "concentrare",
    "concentrino": "concentrare",
    "concentro": "concentrare",
    "concentrò": "concentrare",
    "concependo": "concepire",
    "concepente": "concepire",
    "concepenti": "concepire",
    "concepiamo": "concepire",
    "concepiate": "concepire",
    "concepibili": "concepibile",
    "concepii": "concepire",
    "concepimenti": "concepimento",
    "concepimmo": "concepire",
    "concepir": "concepire",
    "concepirai": "concepire",
    "concepiran": "concepire",
    "concepiranno": "concepire",
    "concepirebbe": "concepire",
    "concepirebber": "concepire",
    "concepirebbero": "concepire",
    "concepirei": "concepire",
    "concepiremmo": "concepire",
    "concepiremo": "concepire",
    "concepireste": "concepire",
    "concepiresti": "concepire",
    "concepirete": "concepire",
    "concepiron": "concepire",
    "concepirono": "concepire",
    "concepirà": "concepire",
    "concepirò": "concepire",
    "concepisca": "concepire",
    "concepiscan": "concepire",
    "concepiscano": "concepire",
    "concepisce": "concepire",
    "concepisci": "concepire",
    "concepisco": "concepire",
    "concepiscon": "concepire",
    "concepiscono": "concepire",
    "concepisse": "concepire",
    "concepisser": "concepire",
    "concepissero": "concepire",
    "concepissi": "concepire",
    "concepissimo": "concepire",
    "concepiste": "concepire",
    "concepisti": "concepire",
    "concepita": "concepire",
    "concepite": "concepire",
    "concepiti": "concepire",
    "concepito": "concepire",
    "concepiva": "concepire",
    "concepivamo": "concepire",
    "concepivan": "concepire",
    "concepivano": "concepire",
    "concepivate": "concepire",
    "concepivi": "concepire",
    "concepivo": "concepire",
    "concepì": "concepire",
    "concerai": "conciare",
    "conceran": "conciare",
    "conceranno": "conciare",
    "concerebbe": "conciare",
    "concerebber": "conciare",
    "concerebbero": "conciare",
    "concerei": "conciare",
    "conceremmo": "conciare",
    "conceremo": "conciare",
    "concereste": "conciare",
    "conceresti": "conciare",
    "concerete": "conciare",
    "concerie": "conceria",
    "concerna": "concernere",
    "concernan": "concernere",
    "concernano": "concernere",
    "concerne": "concernere",
    "concernei": "concernere",
    "concernemmo": "concernere",
    "concernendo": "concernere",
    "concernente": "concernere",
    "concernenti": "concernere",
    "concerner": "concernere",
    "concernerai": "concernere",
    "concerneran": "concernere",
    "concerneranno": "concernere",
    "concernerebbe": "concernere",
    "concernerebber": "concernere",
    "concernerebbero": "concernere",
    "concernerei": "concernere",
    "concerneremmo": "concernere",
    "concerneremo": "concernere",
    "concernereste": "concernere",
    "concerneresti": "concernere",
    "concernerete": "concernere",
    "concerneron": "concernere",
    "concernerono": "concernere",
    "concernerà": "concernere",
    "concernerò": "concernere",
    "concernesse": "concernere",
    "concernesser": "concernere",
    "concernessero": "concernere",
    "concernessi": "concernere",
    "concernessimo": "concernere",
    "concerneste": "concernere",
    "concernesti": "concernere",
    "concernete": "concernere",
    "concerneva": "concernere",
    "concernevamo": "concernere",
    "concernevan": "concernere",
    "concernevano": "concernere",
    "concernevate": "concernere",
    "concernevi": "concernere",
    "concernevo": "concernere",
    "concerni": "concernere",
    "concerniamo": "concernere",
    "concerniate": "concernere",
    "concerno": "concernere",
    "concernon": "concernere",
    "concernono": "concernere",
    "concernè": "concernere",
    "concerta": "concertare",
    "concertai": "concertare",
    "concertammo": "concertare",
    "concertan": "concertare",
    "concertando": "concertare",
    "concertano": "concertare",
    "concertante": "concertare",
    "concertanti": "concertare",
    "concertar": "concertare",
    "concertaron": "concertare",
    "concertarono": "concertare",
    "concertasse": "concertare",
    "concertasser": "concertare",
    "concertassero": "concertare",
    "concertassi": "concertare",
    "concertassimo": "concertare",
    "concertaste": "concertare",
    "concertasti": "concertare",
    "concertata": "concertato",
    "concertate": "concertato",
    "concertati": "concertato",
    "concertato": "concertare",
    "concertatori": "concertatore",
    "concertatrice": "concertatore",
    "concertatrici": "concertatore",
    "concertava": "concertare",
    "concertavamo": "concertare",
    "concertavan": "concertare",
    "concertavano": "concertare",
    "concertavate": "concertare",
    "concertavi": "concertare",
    "concertavo": "concertare",
    "concertazioni": "concertazione",
    "concerterai": "concertare",
    "concerteran": "concertare",
    "concerteranno": "concertare",
    "concerterebbe": "concertare",
    "concerterebber": "concertare",
    "concerterebbero": "concertare",
    "concerterei": "concertare",
    "concerteremmo": "concertare",
    "concerteremo": "concertare",
    "concertereste": "concertare",
    "concerteresti": "concertare",
    "concerterete": "concertare",
    "concerterà": "concertare",
    "concerterò": "concertare",
    "concerti": "concerto",
    "concertiamo": "concertare",
    "concertiate": "concertare",
    "concertin": "concertare",
    "concertini": "concertino",
    "concertino": "concertare",
    "concertisti": "concertista",
    "concertistica": "concertistico",
    "concertistiche": "concertistico",
    "concertistici": "concertistico",
    "concerto": "concertare",
    "concertoni": "concertone",
    "concertò": "concertare",
    "concerà": "conciare",
    "concerò": "conciare",
    "concessa": "concesso",
    "concesse": "concesso",
    "concessero": "concedere",
    "concessi": "concesso",
    "concessionari": "concessionario",
    "concessionaria": "concessionario",
    "concessionarie": "concessionario",
    "concessioni": "concessione",
    "concetti": "concetto",
    "concettosa": "concettoso",
    "concettose": "concettoso",
    "concettosi": "concettoso",
    "concettuali": "concettuale",
    "concezioni": "concezione",
    "conche": "conca",
    "conchiglie": "conchiglia",
    "conchiuda": "conchiudere",
    "conchiudan": "conchiudere",
    "conchiudano": "conchiudere",
    "conchiude": "conchiudere",
    "conchiudemmo": "conchiudere",
    "conchiudendo": "conchiudere",
    "conchiudente": "conchiudere",
    "conchiudenti": "conchiudere",
    "conchiuder": "conchiudere",
    "conchiuderai": "conchiudere",
    "conchiuderan": "conchiudere",
    "conchiuderanno": "conchiudere",
    "conchiuderebbe": "conchiudere",
    "conchiuderebber": "conchiudere",
    "conchiuderebbero": "conchiudere",
    "conchiuderei": "conchiudere",
    "conchiuderemmo": "conchiudere",
    "conchiuderemo": "conchiudere",
    "conchiudereste": "conchiudere",
    "conchiuderesti": "conchiudere",
    "conchiuderete": "conchiudere",
    "conchiuderà": "conchiudere",
    "conchiuderò": "conchiudere",
    "conchiudesse": "conchiudere",
    "conchiudesser": "conchiudere",
    "conchiudessero": "conchiudere",
    "conchiudessi": "conchiudere",
    "conchiudessimo": "conchiudere",
    "conchiudeste": "conchiudere",
    "conchiudesti": "conchiudere",
    "conchiudete": "conchiudere",
    "conchiudeva": "conchiudere",
    "conchiudevamo": "conchiudere",
    "conchiudevan": "conchiudere",
    "conchiudevano": "conchiudere",
    "conchiudevate": "conchiudere",
    "conchiudevi": "conchiudere",
    "conchiudevo": "conchiudere",
    "conchiudi": "conchiudere",
    "conchiudiamo": "conchiudere",
    "conchiudiate": "conchiudere",
    "conchiudo": "conchiudere",
    "conchiudon": "conchiudere",
    "conchiudono": "conchiudere",
    "conchiusa": "conchiudere",
    "conchiuse": "conchiudere",
    "conchiuser": "conchiudere",
    "conchiusero": "conchiudere",
    "conchiusi": "conchiudere",
    "conchiuso": "conchiudere",
    "conci": "conciare",
    "concia": "conciare",
    "conciai": "conciare",
    "conciammo": "conciare",
    "conciamo": "conciare",
    "concian": "conciare",
    "conciando": "conciare",
    "conciano": "conciare",
    "conciante": "conciare",
    "concianti": "conciare",
    "conciar": "conciare",
    "conciaron": "conciare",
    "conciarono": "conciare",
    "conciasse": "conciare",
    "conciasser": "conciare",
    "conciassero": "conciare",
    "conciassi": "conciare",
    "conciassimo": "conciare",
    "conciaste": "conciare",
    "conciasti": "conciare",
    "conciata": "conciare",
    "conciate": "conciare",
    "conciati": "conciare",
    "conciato": "conciare",
    "conciava": "conciare",
    "conciavamo": "conciare",
    "conciavan": "conciare",
    "conciavano": "conciare",
    "conciavate": "conciare",
    "conciavi": "conciare",
    "conciavo": "conciare",
    "concili": "concilio",
    "concilia": "conciliare",
    "conciliabili": "conciliabile",
    "conciliaboli": "conciliabolo",
    "conciliai": "conciliare",
    "conciliammo": "conciliare",
    "conciliamo": "conciliare",
    "concilian": "conciliare",
    "conciliando": "conciliare",
    "conciliano": "conciliare",
    "conciliante": "conciliare",
    "concilianti": "conciliare",
    "conciliar": "conciliare",
    "conciliaron": "conciliare",
    "conciliarono": "conciliare",
    "conciliasse": "conciliare",
    "conciliasser": "conciliare",
    "conciliassero": "conciliare",
    "conciliassi": "conciliare",
    "conciliassimo": "conciliare",
    "conciliaste": "conciliare",
    "conciliasti": "conciliare",
    "conciliata": "conciliare",
    "conciliate": "conciliare",
    "conciliati": "conciliare",
    "conciliativa": "conciliativo",
    "conciliative": "conciliativo",
    "conciliativi": "conciliativo",
    "conciliato": "conciliare",
    "conciliatori": "conciliatorio",
    "conciliatoria": "conciliatorio",
    "conciliatorie": "conciliatorio",
    "conciliatrice": "conciliatore",
    "conciliatrici": "conciliatore",
    "conciliava": "conciliare",
    "conciliavamo": "conciliare",
    "conciliavan": "conciliare",
    "conciliavano": "conciliare",
    "conciliavate": "conciliare",
    "conciliavi": "conciliare",
    "conciliavo": "conciliare",
    "conciliazioni": "conciliazione",
    "concilierai": "conciliare",
    "concilieran": "conciliare",
    "concilieranno": "conciliare",
    "concilierebbe": "conciliare",
    "concilierebber": "conciliare",
    "concilierebbero": "conciliare",
    "concilierei": "conciliare",
    "concilieremmo": "conciliare",
    "concilieremo": "conciliare",
    "conciliereste": "conciliare",
    "concilieresti": "conciliare",
    "concilierete": "conciliare",
    "concilierà": "conciliare",
    "concilierò": "conciliare",
    "concilin": "conciliare",
    "concilino": "conciliare",
    "concilio": "conciliare",
    "conciliò": "conciliare",
    "concima": "concimare",
    "concimai": "concimare",
    "concimammo": "concimare",
    "conciman": "concimare",
    "concimando": "concimare",
    "concimano": "concimare",
    "concimante": "concimare",
    "concimanti": "concimare",
    "concimar": "concimare",
    "concimaron": "concimare",
    "concimarono": "concimare",
    "concimasse": "concimare",
    "concimasser": "concimare",
    "concimassero": "concimare",
    "concimassi": "concimare",
    "concimassimo": "concimare",
    "concimaste": "concimare",
    "concimasti": "concimare",
    "concimata": "concimare",
    "concimate": "concimare",
    "concimati": "concimare",
    "concimato": "concimare",
    "concimava": "concimare",
    "concimavamo": "concimare",
    "concimavan": "concimare",
    "concimavano": "concimare",
    "concimavate": "concimare",
    "concimavi": "concimare",
    "concimavo": "concimare",
    "concimerai": "concimare",
    "concimeran": "concimare",
    "concimeranno": "concimare",
    "concimerebbe": "concimare",
    "concimerebber": "concimare",
    "concimerebbero": "concimare",
    "concimerei": "concimare",
    "concimeremmo": "concimare",
    "concimeremo": "concimare",
    "concimereste": "concimare",
    "concimeresti": "concimare",
    "concimerete": "concimare",
    "concimerà": "concimare",
    "concimerò": "concimare",
    "concimi": "concime",
    "concimiamo": "concimare",
    "concimiate": "concimare",
    "concimin": "concimare",
    "concimino": "concimare",
    "concimo": "concimare",
    "concimò": "concimare",
    "concin": "conciare",
    "concino": "conciare",
    "concio": "conciare",
    "conciona": "concionare",
    "concionai": "concionare",
    "concionammo": "concionare",
    "concionan": "concionare",
    "concionando": "concionare",
    "concionano": "concionare",
    "concionante": "concionare",
    "concionanti": "concionare",
    "concionar": "concionare",
    "concionaron": "concionare",
    "concionarono": "concionare",
    "concionasse": "concionare",
    "concionasser": "concionare",
    "concionassero": "concionare",
    "concionassi": "concionare",
    "concionassimo": "concionare",
    "concionaste": "concionare",
    "concionasti": "concionare",
    "concionata": "concionare",
    "concionate": "concionare",
    "concionati": "concionare",
    "concionato": "concionare",
    "concionava": "concionare",
    "concionavamo": "concionare",
    "concionavan": "concionare",
    "concionavano": "concionare",
    "concionavate": "concionare",
    "concionavi": "concionare",
    "concionavo": "concionare",
    "concionerai": "concionare",
    "concioneran": "concionare",
    "concioneranno": "concionare",
    "concionerebbe": "concionare",
    "concionerebber": "concionare",
    "concionerebbero": "concionare",
    "concionerei": "concionare",
    "concioneremmo": "concionare",
    "concioneremo": "concionare",
    "concionereste": "concionare",
    "concioneresti": "concionare",
    "concionerete": "concionare",
    "concionerà": "concionare",
    "concionerò": "concionare",
    "concioni": "concione",
    "concioniamo": "concionare",
    "concioniate": "concionare",
    "concionin": "concionare",
    "concionino": "concionare",
    "conciono": "concionare",
    "concionò": "concionare",
    "concisa": "conciso",
    "concise": "conciso",
    "concisi": "conciso",
    "concisioni": "concisione",
    "concistori": "concistoro",
    "concistoriali": "concistoriale",
    "concita": "concitare",
    "concitai": "concitare",
    "concitammo": "concitare",
    "concitan": "concitare",
    "concitando": "concitare",
    "concitano": "concitare",
    "concitante": "concitare",
    "concitanti": "concitare",
    "concitar": "concitare",
    "concitaron": "concitare",
    "concitarono": "concitare",
    "concitasse": "concitare",
    "concitasser": "concitare",
    "concitassero": "concitare",
    "concitassi": "concitare",
    "concitassimo": "concitare",
    "concitaste": "concitare",
    "concitasti": "concitare",
    "concitata": "concitato",
    "concitate": "concitato",
    "concitati": "concitato",
    "concitato": "concitare",
    "concitava": "concitare",
    "concitavamo": "concitare",
    "concitavan": "concitare",
    "concitavano": "concitare",
    "concitavate": "concitare",
    "concitavi": "concitare",
    "concitavo": "concitare",
    "concitazioni": "concitazione",
    "conciterai": "concitare",
    "conciteran": "concitare",
    "conciteranno": "concitare",
    "conciterebbe": "concitare",
    "conciterebber": "concitare",
    "conciterebbero": "concitare",
    "conciterei": "concitare",
    "conciteremmo": "concitare",
    "conciteremo": "concitare",
    "concitereste": "concitare",
    "conciteresti": "concitare",
    "conciterete": "concitare",
    "conciterà": "concitare",
    "conciterò": "concitare",
    "conciti": "concitare",
    "concitiamo": "concitare",
    "concitiate": "concitare",
    "concitin": "concitare",
    "concitino": "concitare",
    "concito": "concitare",
    "concittadini": "concittadino",
    "concitò": "concitare",
    "conciò": "conciare",
    "conclama": "conclamare",
    "conclamai": "conclamare",
    "conclamammo": "conclamare",
    "conclaman": "conclamare",
    "conclamando": "conclamare",
    "conclamano": "conclamare",
    "conclamante": "conclamare",
    "conclamanti": "conclamare",
    "conclamar": "conclamare",
    "conclamaron": "conclamare",
    "conclamarono": "conclamare",
    "conclamasse": "conclamare",
    "conclamasser": "conclamare",
    "conclamassero": "conclamare",
    "conclamassi": "conclamare",
    "conclamassimo": "conclamare",
    "conclamaste": "conclamare",
    "conclamasti": "conclamare",
    "conclamata": "conclamare",
    "conclamate": "conclamare",
    "conclamati": "conclamare",
    "conclamato": "conclamare",
    "conclamava": "conclamare",
    "conclamavamo": "conclamare",
    "conclamavan": "conclamare",
    "conclamavano": "conclamare",
    "conclamavate": "conclamare",
    "conclamavi": "conclamare",
    "conclamavo": "conclamare",
    "conclamerai": "conclamare",
    "conclameran": "conclamare",
    "conclameranno": "conclamare",
    "conclamerebbe": "conclamare",
    "conclamerebber": "conclamare",
    "conclamerebbero": "conclamare",
    "conclamerei": "conclamare",
    "conclameremmo": "conclamare",
    "conclameremo": "conclamare",
    "conclamereste": "conclamare",
    "conclameresti": "conclamare",
    "conclamerete": "conclamare",
    "conclamerà": "conclamare",
    "conclamerò": "conclamare",
    "conclami": "conclamare",
    "conclamiamo": "conclamare",
    "conclamiate": "conclamare",
    "conclamin": "conclamare",
    "conclamino": "conclamare",
    "conclamo": "conclamare",
    "conclamò": "conclamare",
    "conclavi": "conclave",
    "concluda": "concludere",
    "concludan": "concludere",
    "concludano": "concludere",
    "conclude": "concludere",
    "concludemmo": "concludere",
    "concludendo": "concludere",
    "concludente": "concludere",
    "concludenti": "concludere",
    "concluder": "concludere",
    "concluderai": "concludere",
    "concluderan": "concludere",
    "concluderanno": "concludere",
    "concluderebbe": "concludere",
    "concluderebber": "concludere",
    "concluderebbero": "concludere",
    "concluderei": "concludere",
    "concluderemmo": "concludere",
    "concluderemo": "concludere",
    "concludereste": "concludere",
    "concluderesti": "concludere",
    "concluderete": "concludere",
    "concluderà": "concludere",
    "concluderò": "concludere",
    "concludesse": "concludere",
    "concludesser": "concludere",
    "concludessero": "concludere",
    "concludessi": "concludere",
    "concludessimo": "concludere",
    "concludeste": "concludere",
    "concludesti": "concludere",
    "concludete": "concludere",
    "concludeva": "concludere",
    "concludevamo": "concludere",
    "concludevan": "concludere",
    "concludevano": "concludere",
    "concludevate": "concludere",
    "concludevi": "concludere",
    "concludevo": "concludere",
    "concludi": "concludere",
    "concludiamo": "concludere",
    "concludiate": "concludere",
    "concludo": "concludere",
    "concludon": "concludere",
    "concludono": "concludere",
    "conclusa": "concluso",
    "concluse": "concluso",
    "concluser": "concludere",
    "conclusero": "concludere",
    "conclusi": "concluso",
    "conclusioni": "conclusione",
    "conclusiva": "conclusivo",
    "conclusive": "conclusivo",
    "conclusivi": "conclusivo",
    "concluso": "concludere",
    "concomitanti": "concomitante",
    "concomitanze": "concomitanza",
    "concorda": "concordare",
    "concordai": "concordare",
    "concordammo": "concordare",
    "concordan": "concordare",
    "concordando": "concordare",
    "concordano": "concordare",
    "concordante": "concordare",
    "concordanti": "concordare",
    "concordanze": "concordanza",
    "concordar": "concordare",
    "concordaron": "concordare",
    "concordarono": "concordare",
    "concordasse": "concordare",
    "concordasser": "concordare",
    "concordassero": "concordare",
    "concordassi": "concordare",
    "concordassimo": "concordare",
    "concordaste": "concordare",
    "concordasti": "concordare",
    "concordata": "concordato",
    "concordatari": "concordatario",
    "concordataria": "concordatario",
    "concordatarie": "concordatario",
    "concordate": "concordato",
    "concordati": "concordato",
    "concordato": "concordare",
    "concordava": "concordare",
    "concordavamo": "concordare",
    "concordavan": "concordare",
    "concordavano": "concordare",
    "concordavate": "concordare",
    "concordavi": "concordare",
    "concordavo": "concordare",
    "concorderai": "concordare",
    "concorderan": "concordare",
    "concorderanno": "concordare",
    "concorderebbe": "concordare",
    "concorderebber": "concordare",
    "concorderebbero": "concordare",
    "concorderei": "concordare",
    "concorderemmo": "concordare",
    "concorderemo": "concordare",
    "concordereste": "concordare",
    "concorderesti": "concordare",
    "concorderete": "concordare",
    "concorderà": "concordare",
    "concorderò": "concordare",
    "concordi": "concorde",
    "concordiamo": "concordare",
    "concordiate": "concordare",
    "concordie": "concordia",
    "concordin": "concordare",
    "concordino": "concordare",
    "concordo": "concordare",
    "concordò": "concordare",
    "concorra": "concorrere",
    "concorran": "concorrere",
    "concorrano": "concorrere",
    "concorre": "concorrere",
    "concorremmo": "concorrere",
    "concorrendo": "concorrere",
    "concorrente": "concorrere",
    "concorrenti": "concorrere",
    "concorrenze": "concorrenza",
    "concorrenziali": "concorrenziale",
    "concorrer": "concorrere",
    "concorrerai": "concorrere",
    "concorreran": "concorrere",
    "concorreranno": "concorrere",
    "concorrerebbe": "concorrere",
    "concorrerebber": "concorrere",
    "concorrerebbero": "concorrere",
    "concorrerei": "concorrere",
    "concorreremmo": "concorrere",
    "concorreremo": "concorrere",
    "concorrereste": "concorrere",
    "concorreresti": "concorrere",
    "concorrerete": "concorrere",
    "concorrerà": "concorrere",
    "concorrerò": "concorrere",
    "concorresse": "concorrere",
    "concorresser": "concorrere",
    "concorressero": "concorrere",
    "concorressi": "concorrere",
    "concorressimo": "concorrere",
    "concorreste": "concorrere",
    "concorresti": "concorrere",
    "concorrete": "concorrere",
    "concorreva": "concorrere",
    "concorrevamo": "concorrere",
    "concorrevan": "concorrere",
    "concorrevano": "concorrere",
    "concorrevate": "concorrere",
    "concorrevi": "concorrere",
    "concorrevo": "concorrere",
    "concorri": "concorrere",
    "concorriamo": "concorrere",
    "concorriate": "concorrere",
    "concorro": "concorrere",
    "concorron": "concorrere",
    "concorrono": "concorrere",
    "concorsa": "concorrere",
    "concorse": "concorrere",
    "concorser": "concorrere",
    "concorsero": "concorrere",
    "concorsi": "concorso",
    "concorso": "concorrere",
    "concreta": "concreto",
    "concretai": "concretare",
    "concretammo": "concretare",
    "concretan": "concretare",
    "concretando": "concretare",
    "concretano": "concretare",
    "concretante": "concretare",
    "concretanti": "concretare",
    "concretar": "concretare",
    "concretaron": "concretare",
    "concretarono": "concretare",
    "concretasse": "concretare",
    "concretasser": "concretare",
    "concretassero": "concretare",
    "concretassi": "concretare",
    "concretassimo": "concretare",
    "concretaste": "concretare",
    "concretasti": "concretare",
    "concretata": "concretare",
    "concretate": "concretare",
    "concretati": "concretare",
    "concretato": "concretare",
    "concretava": "concretare",
    "concretavamo": "concretare",
    "concretavan": "concretare",
    "concretavano": "concretare",
    "concretavate": "concretare",
    "concretavi": "concretare",
    "concretavo": "concretare",
    "concrete": "concreto",
    "concreterai": "concretare",
    "concreteran": "concretare",
    "concreteranno": "concretare",
    "concreterebbe": "concretare",
    "concreterebber": "concretare",
    "concreterebbero": "concretare",
    "concreterei": "concretare",
    "concreteremmo": "concretare",
    "concreteremo": "concretare",
    "concretereste": "concretare",
    "concreteresti": "concretare",
    "concreterete": "concretare",
    "concreterà": "concretare",
    "concreterò": "concretare",
    "concretezze": "concretezza",
    "concreti": "concreto",
    "concretiamo": "concretare",
    "concretiate": "concretare",
    "concretin": "concretare",
    "concretino": "concretare",
    "concretizza": "concretizzare",
    "concretizzai": "concretizzare",
    "concretizzammo": "concretizzare",
    "concretizzan": "concretizzare",
    "concretizzando": "concretizzare",
    "concretizzano": "concretizzare",
    "concretizzante": "concretizzare",
    "concretizzanti": "concretizzare",
    "concretizzar": "concretizzare",
    "concretizzaron": "concretizzare",
    "concretizzarono": "concretizzare",
    "concretizzasse": "concretizzare",
    "concretizzasser": "concretizzare",
    "concretizzassero": "concretizzare",
    "concretizzassi": "concretizzare",
    "concretizzassimo": "concretizzare",
    "concretizzaste": "concretizzare",
    "concretizzasti": "concretizzare",
    "concretizzata": "concretizzare",
    "concretizzate": "concretizzare",
    "concretizzati": "concretizzare",
    "concretizzato": "concretizzare",
    "concretizzava": "concretizzare",
    "concretizzavamo": "concretizzare",
    "concretizzavan": "concretizzare",
    "concretizzavano": "concretizzare",
    "concretizzavate": "concretizzare",
    "concretizzavi": "concretizzare",
    "concretizzavo": "concretizzare",
    "concretizzazioni": "concretizzazione",
    "concretizzerai": "concretizzare",
    "concretizzeran": "concretizzare",
    "concretizzeranno": "concretizzare",
    "concretizzerebbe": "concretizzare",
    "concretizzerebber": "concretizzare",
    "concretizzerebbero": "concretizzare",
    "concretizzerei": "concretizzare",
    "concretizzeremmo": "concretizzare",
    "concretizzeremo": "concretizzare",
    "concretizzereste": "concretizzare",
    "concretizzeresti": "concretizzare",
    "concretizzerete": "concretizzare",
    "concretizzerà": "concretizzare",
    "concretizzerò": "concretizzare",
    "concretizzi": "concretizzare",
    "concretizziamo": "concretizzare",
    "concretizziate": "concretizzare",
    "concretizzin": "concretizzare",
    "concretizzino": "concretizzare",
    "concretizzo": "concretizzare",
    "concretizzò": "concretizzare",
    "concreto": "concretare",
    "concretò": "concretare",
    "concrezioni": "concrezione",
    "concubine": "concubina",
    "conculca": "conculcare",
    "conculcai": "conculcare",
    "conculcammo": "conculcare",
    "conculcan": "conculcare",
    "conculcando": "conculcare",
    "conculcano": "conculcare",
    "conculcante": "conculcare",
    "conculcanti": "conculcare",
    "conculcar": "conculcare",
    "conculcaron": "conculcare",
    "conculcarono": "conculcare",
    "conculcasse": "conculcare",
    "conculcasser": "conculcare",
    "conculcassero": "conculcare",
    "conculcassi": "conculcare",
    "conculcassimo": "conculcare",
    "conculcaste": "conculcare",
    "conculcasti": "conculcare",
    "conculcata": "conculcare",
    "conculcate": "conculcare",
    "conculcati": "conculcare",
    "conculcato": "conculcare",
    "conculcava": "conculcare",
    "conculcavamo": "conculcare",
    "conculcavan": "conculcare",
    "conculcavano": "conculcare",
    "conculcavate": "conculcare",
    "conculcavi": "conculcare",
    "conculcavo": "conculcare",
    "conculcherai": "conculcare",
    "conculcheran": "conculcare",
    "conculcheranno": "conculcare",
    "conculcherebbe": "conculcare",
    "conculcherebber": "conculcare",
    "conculcherebbero": "conculcare",
    "conculcherei": "conculcare",
    "conculcheremmo": "conculcare",
    "conculcheremo": "conculcare",
    "conculchereste": "conculcare",
    "conculcheresti": "conculcare",
    "conculcherete": "conculcare",
    "conculcherà": "conculcare",
    "conculcherò": "conculcare",
    "conculchi": "conculcare",
    "conculchiamo": "conculcare",
    "conculchiate": "conculcare",
    "conculchin": "conculcare",
    "conculchino": "conculcare",
    "conculco": "conculcare",
    "conculcò": "conculcare",
    "concupa": "concupire",
    "concupan": "concupire",
    "concupano": "concupire",
    "concupe": "concupire",
    "concupendo": "concupire",
    "concupente": "concupire",
    "concupenti": "concupire",
    "concupi": "concupire",
    "concupiamo": "concupire",
    "concupiate": "concupire",
    "concupii": "concupire",
    "concupimmo": "concupire",
    "concupir": "concupire",
    "concupirai": "concupire",
    "concupiran": "concupire",
    "concupiranno": "concupire",
    "concupirebbe": "concupire",
    "concupirebber": "concupire",
    "concupirebbero": "concupire",
    "concupirei": "concupire",
    "concupiremmo": "concupire",
    "concupiremo": "concupire",
    "concupireste": "concupire",
    "concupiresti": "concupire",
    "concupirete": "concupire",
    "concupiron": "concupire",
    "concupirono": "concupire",
    "concupirà": "concupire",
    "concupirò": "concupire",
    "concupiscibili": "concupiscibile",
    "concupisse": "concupire",
    "concupisser": "concupire",
    "concupissero": "concupire",
    "concupissi": "concupire",
    "concupissimo": "concupire",
    "concupiste": "concupire",
    "concupisti": "concupire",
    "concupita": "concupire",
    "concupite": "concupire",
    "concupiti": "concupire",
    "concupito": "concupire",
    "concupiva": "concupire",
    "concupivamo": "concupire",
    "concupivan": "concupire",
    "concupivano": "concupire",
    "concupivate": "concupire",
    "concupivi": "concupire",
    "concupivo": "concupire",
    "concupo": "concupire",
    "concupon": "concupire",
    "concupono": "concupire",
    "concupì": "concupire",
    "concussi": "concusso",
    "concussioni": "concussione",
    "concussori": "concussore",
    "condanna": "condannare",
    "condannabili": "condannabile",
    "condannai": "condannare",
    "condannammo": "condannare",
    "condannan": "condannare",
    "condannando": "condannare",
    "condannano": "condannare",
    "condannante": "condannare",
    "condannanti": "condannare",
    "condannar": "condannare",
    "condannaron": "condannare",
    "condannarono": "condannare",
    "condannasse": "condannare",
    "condannasser": "condannare",
    "condannassero": "condannare",
    "condannassi": "condannare",
    "condannassimo": "condannare",
    "condannaste": "condannare",
    "condannasti": "condannare",
    "condannata": "condannato",
    "condannate": "condannato",
    "condannati": "condannato",
    "condannato": "condannare",
    "condannava": "condannare",
    "condannavamo": "condannare",
    "condannavan": "condannare",
    "condannavano": "condannare",
    "condannavate": "condannare",
    "condannavi": "condannare",
    "condannavo": "condannare",
    "condanne": "condanna",
    "condannerai": "condannare",
    "condanneran": "condannare",
    "condanneranno": "condannare",
    "condannerebbe": "condannare",
    "condannerebber": "condannare",
    "condannerebbero": "condannare",
    "condannerei": "condannare",
    "condanneremmo": "condannare",
    "condanneremo": "condannare",
    "condannereste": "condannare",
    "condanneresti": "condannare",
    "condannerete": "condannare",
    "condannerà": "condannare",
    "condannerò": "condannare",
    "condanni": "condannare",
    "condanniamo": "condannare",
    "condanniate": "condannare",
    "condannin": "condannare",
    "condannino": "condannare",
    "condanno": "condannare",
    "condannò": "condannare",
    "condendo": "condire",
    "condensa": "condensare",
    "condensai": "condensare",
    "condensammo": "condensare",
    "condensan": "condensare",
    "condensando": "condensare",
    "condensano": "condensare",
    "condensante": "condensare",
    "condensanti": "condensare",
    "condensar": "condensare",
    "condensaron": "condensare",
    "condensarono": "condensare",
    "condensasse": "condensare",
    "condensasser": "condensare",
    "condensassero": "condensare",
    "condensassi": "condensare",
    "condensassimo": "condensare",
    "condensaste": "condensare",
    "condensasti": "condensare",
    "condensata": "condensato",
    "condensate": "condensato",
    "condensati": "condensato",
    "condensato": "condensare",
    "condensatori": "condensatore",
    "condensava": "condensare",
    "condensavamo": "condensare",
    "condensavan": "condensare",
    "condensavano": "condensare",
    "condensavate": "condensare",
    "condensavi": "condensare",
    "condensavo": "condensare",
    "condensazioni": "condensazione",
    "condenserai": "condensare",
    "condenseran": "condensare",
    "condenseranno": "condensare",
    "condenserebbe": "condensare",
    "condenserebber": "condensare",
    "condenserebbero": "condensare",
    "condenserei": "condensare",
    "condenseremmo": "condensare",
    "condenseremo": "condensare",
    "condensereste": "condensare",
    "condenseresti": "condensare",
    "condenserete": "condensare",
    "condenserà": "condensare",
    "condenserò": "condensare",
    "condensi": "condensare",
    "condensiamo": "condensare",
    "condensiate": "condensare",
    "condensin": "condensare",
    "condensino": "condensare",
    "condenso": "condensare",
    "condensò": "condensare",
    "condente": "condire",
    "condenti": "condire",
    "condiamo": "condire",
    "condiate": "condire",
    "condiciones": "condicio",
    "condii": "condire",
    "condimenti": "condimento",
    "condimmo": "condire",
    "condir": "condire",
    "condirai": "condire",
    "condiran": "condire",
    "condiranno": "condire",
    "condirebbe": "condire",
    "condirebber": "condire",
    "condirebbero": "condire",
    "condirei": "condire",
    "condiremmo": "condire",
    "condiremo": "condire",
    "condireste": "condire",
    "condiresti": "condire",
    "condirete": "condire",
    "condirettori": "condirettore",
    "condiron": "condire",
    "condirono": "condire",
    "condirà": "condire",
    "condirò": "condire",
    "condisca": "condire",
    "condiscan": "condire",
    "condiscano": "condire",
    "condisce": "condire",
    "condiscenda": "condiscendere",
    "condiscendan": "condiscendere",
    "condiscendano": "condiscendere",
    "condiscende": "condiscendere",
    "condiscendemmo": "condiscendere",
    "condiscendendo": "condiscendere",
    "condiscendente": "condiscendere",
    "condiscendenti": "condiscendere",
    "condiscendenze": "condiscendenza",
    "condiscender": "condiscendere",
    "condiscenderai": "condiscendere",
    "condiscenderan": "condiscendere",
    "condiscenderanno": "condiscendere",
    "condiscenderebbe": "condiscendere",
    "condiscenderebber": "condiscendere",
    "condiscenderebbero": "condiscendere",
    "condiscenderei": "condiscendere",
    "condiscenderemmo": "condiscendere",
    "condiscenderemo": "condiscendere",
    "condiscendereste": "condiscendere",
    "condiscenderesti": "condiscendere",
    "condiscenderete": "condiscendere",
    "condiscenderà": "condiscendere",
    "condiscenderò": "condiscendere",
    "condiscendesse": "condiscendere",
    "condiscendesser": "condiscendere",
    "condiscendessero": "condiscendere",
    "condiscendessi": "condiscendere",
    "condiscendessimo": "condiscendere",
    "condiscendeste": "condiscendere",
    "condiscendesti": "condiscendere",
    "condiscendete": "condiscendere",
    "condiscendeva": "condiscendere",
    "condiscendevamo": "condiscendere",
    "condiscendevan": "condiscendere",
    "condiscendevano": "condiscendere",
    "condiscendevate": "condiscendere",
    "condiscendevi": "condiscendere",
    "condiscendevo": "condiscendere",
    "condiscendi": "condiscendere",
    "condiscendiamo": "condiscendere",
    "condiscendiate": "condiscendere",
    "condiscendo": "condiscendere",
    "condiscendon": "condiscendere",
    "condiscendono": "condiscendere",
    "condiscesa": "condiscendere",
    "condiscese": "condiscendere",
    "condisceser": "condiscendere",
    "condiscesero": "condiscendere",
    "condiscesi": "condiscendere",
    "condisceso": "condiscendere",
    "condiscesè": "condiscendere",
    "condisci": "condire",
    "condisco": "condire",
    "condiscon": "condire",
    "condiscono": "condire",
    "condisse": "condire",
    "condisser": "condire",
    "condissero": "condire",
    "condissi": "condire",
    "condissimo": "condire",
    "condiste": "condire",
    "condisti": "condire",
    "condita": "condire",
    "condite": "condire",
    "conditi": "condire",
    "condito": "condire",
    "condiva": "condire",
    "condivamo": "condire",
    "condivan": "condire",
    "condivano": "condire",
    "condivate": "condire",
    "condivi": "condire",
    "condivida": "condividere",
    "condividan": "condividere",
    "condividano": "condividere",
    "condivide": "condividere",
    "condividemmo": "condividere",
    "condividendo": "condividere",
    "condividente": "condividere",
    "condividenti": "condividere",
    "condivider": "condividere",
    "condividerai": "condividere",
    "condivideran": "condividere",
    "condivideranno": "condividere",
    "condividerebbe": "condividere",
    "condividerebber": "condividere",
    "condividerebbero": "condividere",
    "condividerei": "condividere",
    "condivideremmo": "condividere",
    "condivideremo": "condividere",
    "condividereste": "condividere",
    "condivideresti": "condividere",
    "condividerete": "condividere",
    "condividerà": "condividere",
    "condividerò": "condividere",
    "condividesse": "condividere",
    "condividesser": "condividere",
    "condividessero": "condividere",
    "condividessi": "condividere",
    "condividessimo": "condividere",
    "condivideste": "condividere",
    "condividesti": "condividere",
    "condividete": "condividere",
    "condivideva": "condividere",
    "condividevamo": "condividere",
    "condividevan": "condividere",
    "condividevano": "condividere",
    "condividevate": "condividere",
    "condividevi": "condividere",
    "condividevo": "condividere",
    "condividi": "condividere",
    "condividiamo": "condividere",
    "condividiate": "condividere",
    "condivido": "condividere",
    "condividon": "condividere",
    "condividono": "condividere",
    "condivisa": "condividere",
    "condivise": "condividere",
    "condiviser": "condividere",
    "condivisero": "condividere",
    "condivisi": "condividere",
    "condivisibili": "condivisibile",
    "condivisioni": "condivisione",
    "condiviso": "condividere",
    "condivo": "condire",
    "condiziona": "condizionare",
    "condizionabili": "condizionabile",
    "condizionai": "condizionare",
    "condizionali": "condizionale",
    "condizionamenti": "condizionamento",
    "condizionammo": "condizionare",
    "condizionan": "condizionare",
    "condizionando": "condizionare",
    "condizionano": "condizionare",
    "condizionante": "condizionare",
    "condizionanti": "condizionare",
    "condizionar": "condizionare",
    "condizionaron": "condizionare",
    "condizionarono": "condizionare",
    "condizionasse": "condizionare",
    "condizionasser": "condizionare",
    "condizionassero": "condizionare",
    "condizionassi": "condizionare",
    "condizionassimo": "condizionare",
    "condizionaste": "condizionare",
    "condizionasti": "condizionare",
    "condizionata": "condizionato",
    "condizionate": "condizionato",
    "condizionati": "condizionato",
    "condizionato": "condizionare",
    "condizionatori": "condizionatore",
    "condizionava": "condizionare",
    "condizionavamo": "condizionare",
    "condizionavan": "condizionare",
    "condizionavano": "condizionare",
    "condizionavate": "condizionare",
    "condizionavi": "condizionare",
    "condizionavo": "condizionare",
    "condizionerai": "condizionare",
    "condizioneran": "condizionare",
    "condizioneranno": "condizionare",
    "condizionerebbe": "condizionare",
    "condizionerebber": "condizionare",
    "condizionerebbero": "condizionare",
    "condizionerei": "condizionare",
    "condizioneremmo": "condizionare",
    "condizioneremo": "condizionare",
    "condizionereste": "condizionare",
    "condizioneresti": "condizionare",
    "condizionerete": "condizionare",
    "condizionerà": "condizionare",
    "condizionerò": "condizionare",
    "condizioni": "condizione",
    "condizioniamo": "condizionare",
    "condizioniate": "condizionare",
    "condizionin": "condizionare",
    "condizionino": "condizionare",
    "condiziono": "condizionare",
    "condizionò": "condizionare",
    "condoglianze": "condoglianza",
    "condola": "condolere",
    "condolan": "condolere",
    "condolano": "condolere",
    "condole": "condolere",
    "condolei": "condolere",
    "condolemmo": "condolere",
    "condolendo": "condolere",
    "condoler": "condolere",
    "condolerai": "condolere",
    "condoleran": "condolere",
    "condoleranno": "condolere",
    "condolerebbe": "condolere",
    "condolerebber": "condolere",
    "condolerebbero": "condolere",
    "condolerei": "condolere",
    "condoleremmo": "condolere",
    "condoleremo": "condolere",
    "condolereste": "condolere",
    "condoleresti": "condolere",
    "condolerete": "condolere",
    "condoleron": "condolere",
    "condolerono": "condolere",
    "condolerà": "condolere",
    "condolerò": "condolere",
    "condolesse": "condolere",
    "condolesser": "condolere",
    "condolessero": "condolere",
    "condolessi": "condolere",
    "condolessimo": "condolere",
    "condoleste": "condolere",
    "condolesti": "condolere",
    "condolete": "condolere",
    "condoleva": "condolere",
    "condolevamo": "condolere",
    "condolevan": "condolere",
    "condolevano": "condolere",
    "condolevate": "condolere",
    "condolevi": "condolere",
    "condolevo": "condolere",
    "condoli": "condolere",
    "condoliamo": "condolere",
    "condoliate": "condolere",
    "condolo": "condolere",
    "condolon": "condolere",
    "condolono": "condolere",
    "condoluta": "condolere",
    "condolute": "condolere",
    "condoluti": "condolere",
    "condoluto": "condolere",
    "condolè": "condolere",
    "condomini": "condomino",
    "condominiali": "condominiale",
    "condominii": "condominio",
    "condona": "condonare",
    "condonabili": "condonabile",
    "condonai": "condonare",
    "condonammo": "condonare",
    "condonan": "condonare",
    "condonando": "condonare",
    "condonano": "condonare",
    "condonante": "condonare",
    "condonanti": "condonare",
    "condonar": "condonare",
    "condonaron": "condonare",
    "condonarono": "condonare",
    "condonasse": "condonare",
    "condonasser": "condonare",
    "condonassero": "condonare",
    "condonassi": "condonare",
    "condonassimo": "condonare",
    "condonaste": "condonare",
    "condonasti": "condonare",
    "condonata": "condonare",
    "condonate": "condonare",
    "condonati": "condonare",
    "condonato": "condonare",
    "condonava": "condonare",
    "condonavamo": "condonare",
    "condonavan": "condonare",
    "condonavano": "condonare",
    "condonavate": "condonare",
    "condonavi": "condonare",
    "condonavo": "condonare",
    "condonerai": "condonare",
    "condoneran": "condonare",
    "condoneranno": "condonare",
    "condonerebbe": "condonare",
    "condonerebber": "condonare",
    "condonerebbero": "condonare",
    "condonerei": "condonare",
    "condoneremmo": "condonare",
    "condoneremo": "condonare",
    "condonereste": "condonare",
    "condoneresti": "condonare",
    "condonerete": "condonare",
    "condonerà": "condonare",
    "condonerò": "condonare",
    "condoni": "condono",
    "condoniamo": "condonare",
    "condoniate": "condonare",
    "condonin": "condonare",
    "condonino": "condonare",
    "condono": "condonare",
    "condonò": "condonare",
    "condotta": "condurre",
    "condotte": "condurre",
    "condotti": "condurre",
    "condottieri": "condottiero",
    "condotto": "condurre",
    "conduca": "condurre",
    "conducan": "condurre",
    "conducano": "condurre",
    "conduce": "condurre",
    "conducemmo": "condurre",
    "conducendo": "condurre",
    "conducente": "condurre",
    "conducenti": "condurre",
    "conducesse": "condurre",
    "conducesser": "condurre",
    "conducessero": "condurre",
    "conducessi": "condurre",
    "conducessimo": "condurre",
    "conduceste": "condurre",
    "conducesti": "condurre",
    "conducete": "condurre",
    "conduceva": "condurre",
    "conducevamo": "condurre",
    "conducevan": "condurre",
    "conducevano": "condurre",
    "conducevate": "condurre",
    "conducevi": "condurre",
    "conducevo": "condurre",
    "conduci": "condurre",
    "conduciamo": "condurre",
    "conduciate": "condurre",
    "conduco": "condurre",
    "conducon": "condurre",
    "conducono": "condurre",
    "condurr": "condurre",
    "condurrai": "condurre",
    "condurran": "condurre",
    "condurranno": "condurre",
    "condurrebbe": "condurre",
    "condurrebber": "condurre",
    "condurrebbero": "condurre",
    "condurrei": "condurre",
    "condurremmo": "condurre",
    "condurremo": "condurre",
    "condurreste": "condurre",
    "condurresti": "condurre",
    "condurrete": "condurre",
    "condurrà": "condurre",
    "condurrò": "condurre",
    "condusse": "condurre",
    "condusser": "condurre",
    "condussero": "condurre",
    "condussi": "condurre",
    "conduttori": "conduttore",
    "conduttrice": "conduttore",
    "conduttrici": "conduttrice",
    "condutture": "conduttura",
    "conduzioni": "conduzione",
    "condì": "condire",
    "cone": "corre",
    "conei": "corre",
    "conemmo": "corre",
    "conendo": "corre",
    "conente": "corre",
    "conenti": "corre",
    "conerai": "corre",
    "coneran": "corre",
    "coneranno": "corre",
    "conerebbe": "corre",
    "conerebber": "corre",
    "conerebbero": "corre",
    "conerei": "corre",
    "coneremmo": "corre",
    "coneremo": "corre",
    "conereste": "corre",
    "coneresti": "corre",
    "conerete": "corre",
    "coneron": "corre",
    "conerono": "corre",
    "conerà": "corre",
    "conerò": "corre",
    "conesse": "corre",
    "conesser": "corre",
    "conessero": "corre",
    "conessi": "corre",
    "conessimo": "corre",
    "coneste": "corre",
    "conesti": "corre",
    "conete": "corre",
    "coneva": "corre",
    "conevamo": "corre",
    "conevan": "corre",
    "conevano": "corre",
    "conevate": "corre",
    "conevi": "corre",
    "conevo": "corre",
    "confa": "confare",
    "confa'": "confare",
    "confabula": "confabulare",
    "confabulai": "confabulare",
    "confabulammo": "confabulare",
    "confabulan": "confabulare",
    "confabulando": "confabulare",
    "confabulano": "confabulare",
    "confabulante": "confabulare",
    "confabulanti": "confabulare",
    "confabular": "confabulare",
    "confabularon": "confabulare",
    "confabularono": "confabulare",
    "confabulasse": "confabulare",
    "confabulasser": "confabulare",
    "confabulassero": "confabulare",
    "confabulassi": "confabulare",
    "confabulassimo": "confabulare",
    "confabulaste": "confabulare",
    "confabulasti": "confabulare",
    "confabulata": "confabulare",
    "confabulate": "confabulare",
    "confabulati": "confabulare",
    "confabulato": "confabulare",
    "confabulava": "confabulare",
    "confabulavamo": "confabulare",
    "confabulavan": "confabulare",
    "confabulavano": "confabulare",
    "confabulavate": "confabulare",
    "confabulavi": "confabulare",
    "confabulavo": "confabulare",
    "confabulerai": "confabulare",
    "confabuleran": "confabulare",
    "confabuleranno": "confabulare",
    "confabulerebbe": "confabulare",
    "confabulerebber": "confabulare",
    "confabulerebbero": "confabulare",
    "confabulerei": "confabulare",
    "confabuleremmo": "confabulare",
    "confabuleremo": "confabulare",
    "confabulereste": "confabulare",
    "confabuleresti": "confabulare",
    "confabulerete": "confabulare",
    "confabulerà": "confabulare",
    "confabulerò": "confabulare",
    "confabuli": "confabulare",
    "confabuliamo": "confabulare",
    "confabuliate": "confabulare",
    "confabulin": "confabulare",
    "confabulino": "confabulare",
    "confabulo": "confabulare",
    "confabulò": "confabulare",
    "confaccia": "confare",
    "confacciamo": "confare",
    "confaccian": "confare",
    "confacciano": "confare",
    "confacciate": "confare",
    "confaccio": "confare",
    "confacemmo": "confare",
    "confacendo": "confare",
    "confacente": "confare",
    "confacenti": "confare",
    "confacesse": "confare",
    "confacesser": "confare",
    "confacessero": "confare",
    "confacessi": "confare",
    "confacessimo": "confare",
    "confaceste": "confare",
    "confacesti": "confare",
    "confaceva": "confare",
    "confacevamo": "confare",
    "confacevan": "confare",
    "confacevano": "confare",
    "confacevate": "confare",
    "confacevi": "confare",
    "confacevo": "confare",
    "confai": "confare",
    "confan": "confare",
    "confanno": "confare",
    "confar": "confare",
    "confarai": "confare",
    "confaran": "confare",
    "confaranno": "confare",
    "confarebbe": "confare",
    "confarebber": "confare",
    "confarebbero": "confare",
    "confarei": "confare",
    "confaremmo": "confare",
    "confaremo": "confare",
    "confareste": "confare",
    "confaresti": "confare",
    "confarete": "confare",
    "confarà": "confare",
    "confarò": "confare",
    "confate": "confare",
    "confatta": "confare",
    "confatte": "confare",
    "confatti": "confare",
    "confatto": "confare",
    "confece": "confare",
    "confecer": "confare",
    "confecero": "confare",
    "confeci": "confare",
    "confedera": "confederare",
    "confederai": "confederare",
    "confederali": "confederale",
    "confederammo": "confederare",
    "confederan": "confederare",
    "confederando": "confederare",
    "confederano": "confederare",
    "confederante": "confederare",
    "confederanti": "confederare",
    "confederar": "confederare",
    "confederaron": "confederare",
    "confederarono": "confederare",
    "confederasse": "confederare",
    "confederasser": "confederare",
    "confederassero": "confederare",
    "confederassi": "confederare",
    "confederassimo": "confederare",
    "confederaste": "confederare",
    "confederasti": "confederare",
    "confederata": "confederato",
    "confederate": "confederato",
    "confederati": "confederato",
    "confederato": "confederare",
    "confederava": "confederare",
    "confederavamo": "confederare",
    "confederavan": "confederare",
    "confederavano": "confederare",
    "confederavate": "confederare",
    "confederavi": "confederare",
    "confederavo": "confederare",
    "confederazioni": "confederazione",
    "confedererai": "confederare",
    "confedereran": "confederare",
    "confedereranno": "confederare",
    "confedererebbe": "confederare",
    "confedererebber": "confederare",
    "confedererebbero": "confederare",
    "confedererei": "confederare",
    "confedereremmo": "confederare",
    "confedereremo": "confederare",
    "confederereste": "confederare",
    "confedereresti": "confederare",
    "confedererete": "confederare",
    "confedererà": "confederare",
    "confedererò": "confederare",
    "confederi": "confederare",
    "confederiamo": "confederare",
    "confederiate": "confederare",
    "confederin": "confederare",
    "confederino": "confederare",
    "confedero": "confederare",
    "confederò": "confederare",
    "conferendo": "conferire",
    "conferente": "conferire",
    "conferenti": "conferire",
    "conferenze": "conferenza",
    "conferenze-stampa": "conferenza-stampa",
    "conferenzieri": "conferenziere",
    "conferiamo": "conferire",
    "conferiate": "conferire",
    "conferii": "conferire",
    "conferimenti": "conferimento",
    "conferimmo": "conferire",
    "conferir": "conferire",
    "conferirai": "conferire",
    "conferiran": "conferire",
    "conferiranno": "conferire",
    "conferirebbe": "conferire",
    "conferirebber": "conferire",
    "conferirebbero": "conferire",
    "conferirei": "conferire",
    "conferiremmo": "conferire",
    "conferiremo": "conferire",
    "conferireste": "conferire",
    "conferiresti": "conferire",
    "conferirete": "conferire",
    "conferiron": "conferire",
    "conferirono": "conferire",
    "conferirà": "conferire",
    "conferirò": "conferire",
    "conferisca": "conferire",
    "conferiscan": "conferire",
    "conferiscano": "conferire",
    "conferisce": "conferire",
    "conferisci": "conferire",
    "conferisco": "conferire",
    "conferiscon": "conferire",
    "conferiscono": "conferire",
    "conferisse": "conferire",
    "conferisser": "conferire",
    "conferissero": "conferire",
    "conferissi": "conferire",
    "conferissimo": "conferire",
    "conferiste": "conferire",
    "conferisti": "conferire",
    "conferita": "conferire",
    "conferite": "conferire",
    "conferiti": "conferire",
    "conferito": "conferire",
    "conferiva": "conferire",
    "conferivamo": "conferire",
    "conferivan": "conferire",
    "conferivano": "conferire",
    "conferivate": "conferire",
    "conferivi": "conferire",
    "conferivo": "conferire",
    "conferma": "confermare",
    "confermai": "confermare",
    "confermammo": "confermare",
    "conferman": "confermare",
    "confermando": "confermare",
    "confermano": "confermare",
    "confermante": "confermare",
    "confermanti": "confermare",
    "confermar": "confermare",
    "confermaron": "confermare",
    "confermarono": "confermare",
    "confermasse": "confermare",
    "confermasser": "confermare",
    "confermassero": "confermare",
    "confermassi": "confermare",
    "confermassimo": "confermare",
    "confermaste": "confermare",
    "confermasti": "confermare",
    "confermata": "confermato",
    "confermate": "confermato",
    "confermati": "confermato",
    "confermato": "confermare",
    "confermava": "confermare",
    "confermavamo": "confermare",
    "confermavan": "confermare",
    "confermavano": "confermare",
    "confermavate": "confermare",
    "confermavi": "confermare",
    "confermavo": "confermare",
    "conferme": "conferma",
    "confermerai": "confermare",
    "confermeran": "confermare",
    "confermeranno": "confermare",
    "confermerebbe": "confermare",
    "confermerebber": "confermare",
    "confermerebbero": "confermare",
    "confermerei": "confermare",
    "confermeremmo": "confermare",
    "confermeremo": "confermare",
    "confermereste": "confermare",
    "confermeresti": "confermare",
    "confermerete": "confermare",
    "confermerà": "confermare",
    "confermerò": "confermare",
    "confermi": "confermare",
    "confermiamo": "confermare",
    "confermiate": "confermare",
    "confermin": "confermare",
    "confermino": "confermare",
    "confermo": "confermare",
    "confermò": "confermare",
    "conferì": "conferire",
    "confessa": "confesso",
    "confessabili": "confessabile",
    "confessai": "confessare",
    "confessammo": "confessare",
    "confessan": "confessare",
    "confessando": "confessare",
    "confessano": "confessare",
    "confessante": "confessare",
    "confessanti": "confessare",
    "confessar": "confessare",
    "confessaron": "confessare",
    "confessarono": "confessare",
    "confessasse": "confessare",
    "confessasser": "confessare",
    "confessassero": "confessare",
    "confessassi": "confessare",
    "confessassimo": "confessare",
    "confessaste": "confessare",
    "confessasti": "confessare",
    "confessata": "confessare",
    "confessate": "confessare",
    "confessati": "confessare",
    "confessato": "confessare",
    "confessava": "confessare",
    "confessavamo": "confessare",
    "confessavan": "confessare",
    "confessavano": "confessare",
    "confessavate": "confessare",
    "confessavi": "confessare",
    "confessavo": "confessare",
    "confesse": "confesso",
    "confesserai": "confessare",
    "confesseran": "confessare",
    "confesseranno": "confessare",
    "confesserebbe": "confessare",
    "confesserebber": "confessare",
    "confesserebbero": "confessare",
    "confesserei": "confessare",
    "confesseremmo": "confessare",
    "confesseremo": "confessare",
    "confessereste": "confessare",
    "confesseresti": "confessare",
    "confesserete": "confessare",
    "confesserà": "confessare",
    "confesserò": "confessare",
    "confessi": "confesso",
    "confessiamo": "confessare",
    "confessiate": "confessare",
    "confessin": "confessare",
    "confessino": "confessare",
    "confessionali": "confessionale",
    "confessioni": "confessione",
    "confesso": "confessare",
    "confessori": "confessore",
    "confessò": "confessare",
    "confetta": "confettare",
    "confettai": "confettare",
    "confettammo": "confettare",
    "confettan": "confettare",
    "confettando": "confettare",
    "confettano": "confettare",
    "confettante": "confettare",
    "confettanti": "confettare",
    "confettar": "confettare",
    "confettaron": "confettare",
    "confettarono": "confettare",
    "confettasse": "confettare",
    "confettasser": "confettare",
    "confettassero": "confettare",
    "confettassi": "confettare",
    "confettassimo": "confettare",
    "confettaste": "confettare",
    "confettasti": "confettare",
    "confettata": "confettare",
    "confettate": "confettare",
    "confettati": "confettare",
    "confettato": "confettare",
    "confettava": "confettare",
    "confettavamo": "confettare",
    "confettavan": "confettare",
    "confettavano": "confettare",
    "confettavate": "confettare",
    "confettavi": "confettare",
    "confettavo": "confettare",
    "confetterai": "confettare",
    "confetteran": "confettare",
    "confetteranno": "confettare",
    "confetterebbe": "confettare",
    "confetterebber": "confettare",
    "confetterebbero": "confettare",
    "confetterei": "confettare",
    "confetteremmo": "confettare",
    "confetteremo": "confettare",
    "confettereste": "confettare",
    "confetteresti": "confettare",
    "confetterete": "confettare",
    "confetterà": "confettare",
    "confetterò": "confettare",
    "confetti": "confetto",
    "confettiamo": "confettare",
    "confettiate": "confettare",
    "confettin": "confettare",
    "confettino": "confettare",
    "confetto": "confettare",
    "confettò": "confettare",
    "confeziona": "confezionare",
    "confezionai": "confezionare",
    "confezionamenti": "confezionamento",
    "confezionammo": "confezionare",
    "confezionan": "confezionare",
    "confezionando": "confezionare",
    "confezionano": "confezionare",
    "confezionante": "confezionare",
    "confezionanti": "confezionare",
    "confezionar": "confezionare",
    "confezionaron": "confezionare",
    "confezionarono": "confezionare",
    "confezionasse": "confezionare",
    "confezionasser": "confezionare",
    "confezionassero": "confezionare",
    "confezionassi": "confezionare",
    "confezionassimo": "confezionare",
    "confezionaste": "confezionare",
    "confezionasti": "confezionare",
    "confezionata": "confezionare",
    "confezionate": "confezionare",
    "confezionati": "confezionare",
    "confezionato": "confezionare",
    "confezionatori": "confezionatore",
    "confezionava": "confezionare",
    "confezionavamo": "confezionare",
    "confezionavan": "confezionare",
    "confezionavano": "confezionare",
    "confezionavate": "confezionare",
    "confezionavi": "confezionare",
    "confezionavo": "confezionare",
    "confezionerai": "confezionare",
    "confezioneran": "confezionare",
    "confezioneranno": "confezionare",
    "confezionerebbe": "confezionare",
    "confezionerebber": "confezionare",
    "confezionerebbero": "confezionare",
    "confezionerei": "confezionare",
    "confezioneremmo": "confezionare",
    "confezioneremo": "confezionare",
    "confezionereste": "confezionare",
    "confezioneresti": "confezionare",
    "confezionerete": "confezionare",
    "confezionerà": "confezionare",
    "confezionerò": "confezionare",
    "confezioni": "confezione",
    "confezioniamo": "confezionare",
    "confezioniate": "confezionare",
    "confezionin": "confezionare",
    "confezionino": "confezionare",
    "confeziono": "confezionare",
    "confezionò": "confezionare",
    "conficca": "conficcare",
    "conficcai": "conficcare",
    "conficcammo": "conficcare",
    "conficcan": "conficcare",
    "conficcando": "conficcare",
    "conficcano": "conficcare",
    "conficcante": "conficcare",
    "conficcanti": "conficcare",
    "conficcar": "conficcare",
    "conficcaron": "conficcare",
    "conficcarono": "conficcare",
    "conficcasse": "conficcare",
    "conficcasser": "conficcare",
    "conficcassero": "conficcare",
    "conficcassi": "conficcare",
    "conficcassimo": "conficcare",
    "conficcaste": "conficcare",
    "conficcasti": "conficcare",
    "conficcata": "conficcare",
    "conficcate": "conficcare",
    "conficcati": "conficcare",
    "conficcato": "conficcare",
    "conficcava": "conficcare",
    "conficcavamo": "conficcare",
    "conficcavan": "conficcare",
    "conficcavano": "conficcare",
    "conficcavate": "conficcare",
    "conficcavi": "conficcare",
    "conficcavo": "conficcare",
    "conficcherai": "conficcare",
    "conficcheran": "conficcare",
    "conficcheranno": "conficcare",
    "conficcherebbe": "conficcare",
    "conficcherebber": "conficcare",
    "conficcherebbero": "conficcare",
    "conficcherei": "conficcare",
    "conficcheremmo": "conficcare",
    "conficcheremo": "conficcare",
    "conficchereste": "conficcare",
    "conficcheresti": "conficcare",
    "conficcherete": "conficcare",
    "conficcherà": "conficcare",
    "conficcherò": "conficcare",
    "conficchi": "conficcare",
    "conficchiamo": "conficcare",
    "conficchiate": "conficcare",
    "conficchin": "conficcare",
    "conficchino": "conficcare",
    "conficco": "conficcare",
    "conficcò": "conficcare",
    "confida": "confidare",
    "confidai": "confidare",
    "confidammo": "confidare",
    "confidan": "confidare",
    "confidando": "confidare",
    "confidano": "confidare",
    "confidante": "confidare",
    "confidanti": "confidare",
    "confidar": "confidare",
    "confidaron": "confidare",
    "confidarono": "confidare",
    "confidasse": "confidare",
    "confidasser": "confidare",
    "confidassero": "confidare",
    "confidassi": "confidare",
    "confidassimo": "confidare",
    "confidaste": "confidare",
    "confidasti": "confidare",
    "confidata": "confidare",
    "confidate": "confidare",
    "confidati": "confidare",
    "confidato": "confidare",
    "confidava": "confidare",
    "confidavamo": "confidare",
    "confidavan": "confidare",
    "confidavano": "confidare",
    "confidavate": "confidare",
    "confidavi": "confidare",
    "confidavo": "confidare",
    "confidenti": "confidente",
    "confidenze": "confidenza",
    "confidenziali": "confidenziale",
    "confiderai": "confidare",
    "confideran": "confidare",
    "confideranno": "confidare",
    "confiderebbe": "confidare",
    "confiderebber": "confidare",
    "confiderebbero": "confidare",
    "confiderei": "confidare",
    "confideremmo": "confidare",
    "confideremo": "confidare",
    "confidereste": "confidare",
    "confideresti": "confidare",
    "confiderete": "confidare",
    "confiderà": "confidare",
    "confiderò": "confidare",
    "confidi": "confidare",
    "confidiamo": "confidare",
    "confidiate": "confidare",
    "confidin": "confidare",
    "confidino": "confidare",
    "confido": "confidare",
    "confidò": "confidare",
    "configga": "configgere",
    "configgan": "configgere",
    "configgano": "configgere",
    "configge": "configgere",
    "configgemmo": "configgere",
    "configgendo": "configgere",
    "configgente": "configgere",
    "configgenti": "configgere",
    "configger": "configgere",
    "configgerai": "configgere",
    "configgeran": "configgere",
    "configgeranno": "configgere",
    "configgerebbe": "configgere",
    "configgerebber": "configgere",
    "configgerebbero": "configgere",
    "configgerei": "configgere",
    "configgeremmo": "configgere",
    "configgeremo": "configgere",
    "configgereste": "configgere",
    "configgeresti": "configgere",
    "configgerete": "configgere",
    "configgerà": "configgere",
    "configgerò": "configgere",
    "configgesse": "configgere",
    "configgesser": "configgere",
    "configgessero": "configgere",
    "configgessi": "configgere",
    "configgessimo": "configgere",
    "configgeste": "configgere",
    "configgesti": "configgere",
    "configgete": "configgere",
    "configgeva": "configgere",
    "configgevamo": "configgere",
    "configgevan": "configgere",
    "configgevano": "configgere",
    "configgevate": "configgere",
    "configgevi": "configgere",
    "configgevo": "configgere",
    "configgi": "configgere",
    "configgiamo": "configgere",
    "configgiate": "configgere",
    "configgo": "configgere",
    "configgon": "configgere",
    "configgono": "configgere",
    "configura": "configurare",
    "configurabili": "configurabile",
    "configurai": "configurare",
    "configurammo": "configurare",
    "configuran": "configurare",
    "configurando": "configurare",
    "configurano": "configurare",
    "configurante": "configurare",
    "configuranti": "configurare",
    "configurar": "configurare",
    "configuraron": "configurare",
    "configurarono": "configurare",
    "configurasse": "configurare",
    "configurasser": "configurare",
    "configurassero": "configurare",
    "configurassi": "configurare",
    "configurassimo": "configurare",
    "configuraste": "configurare",
    "configurasti": "configurare",
    "configurata": "configurare",
    "configurate": "configurare",
    "configurati": "configurare",
    "configurato": "configurare",
    "configurava": "configurare",
    "configuravamo": "configurare",
    "configuravan": "configurare",
    "configuravano": "configurare",
    "configuravate": "configurare",
    "configuravi": "configurare",
    "configuravo": "configurare",
    "configurazioni": "configurazione",
    "configurerai": "configurare",
    "configureran": "configurare",
    "configureranno": "configurare",
    "configurerebbe": "configurare",
    "configurerebber": "configurare",
    "configurerebbero": "configurare",
    "configurerei": "configurare",
    "configureremmo": "configurare",
    "configureremo": "configurare",
    "configurereste": "configurare",
    "configureresti": "configurare",
    "configurerete": "configurare",
    "configurerà": "configurare",
    "configurerò": "configurare",
    "configuri": "configurare",
    "configuriamo": "configurare",
    "configuriate": "configurare",
    "configurin": "configurare",
    "configurino": "configurare",
    "configuro": "configurare",
    "configurò": "configurare",
    "confina": "confinare",
    "confinai": "confinare",
    "confinamenti": "confinamento",
    "confinammo": "confinare",
    "confinan": "confinare",
    "confinando": "confinare",
    "confinano": "confinare",
    "confinante": "confinare",
    "confinanti": "confinare",
    "confinar": "confinare",
    "confinari": "confinario",
    "confinaria": "confinario",
    "confinarie": "confinario",
    "confinaron": "confinare",
    "confinarono": "confinare",
    "confinasse": "confinare",
    "confinasser": "confinare",
    "confinassero": "confinare",
    "confinassi": "confinare",
    "confinassimo": "confinare",
    "confinaste": "confinare",
    "confinasti": "confinare",
    "confinata": "confinato",
    "confinate": "confinato",
    "confinati": "confinato",
    "confinato": "confinare",
    "confinava": "confinare",
    "confinavamo": "confinare",
    "confinavan": "confinare",
    "confinavano": "confinare",
    "confinavate": "confinare",
    "confinavi": "confinare",
    "confinavo": "confinare",
    "confindustrial-governativa": "confindustrial-governativo",
    "confindustrial-governative": "confindustrial-governativo",
    "confindustrial-governativi": "confindustrial-governativo",
    "confindustriali": "confindustriale",
    "confindustrie": "confindustria",
    "confinerai": "confinare",
    "confineran": "confinare",
    "confineranno": "confinare",
    "confinerebbe": "confinare",
    "confinerebber": "confinare",
    "confinerebbero": "confinare",
    "confinerei": "confinare",
    "confineremmo": "confinare",
    "confineremo": "confinare",
    "confinereste": "confinare",
    "confineresti": "confinare",
    "confinerete": "confinare",
    "confinerà": "confinare",
    "confinerò": "confinare",
    "confini": "confino",
    "confiniamo": "confinare",
    "confiniate": "confinare",
    "confinin": "confinare",
    "confinino": "confinare",
    "confino": "confinare",
    "confinò": "confinare",
    "confisca": "confiscare",
    "confiscai": "confiscare",
    "confiscammo": "confiscare",
    "confiscan": "confiscare",
    "confiscando": "confiscare",
    "confiscano": "confiscare",
    "confiscante": "confiscare",
    "confiscanti": "confiscare",
    "confiscar": "confiscare",
    "confiscaron": "confiscare",
    "confiscarono": "confiscare",
    "confiscasse": "confiscare",
    "confiscasser": "confiscare",
    "confiscassero": "confiscare",
    "confiscassi": "confiscare",
    "confiscassimo": "confiscare",
    "confiscaste": "confiscare",
    "confiscasti": "confiscare",
    "confiscata": "confiscare",
    "confiscate": "confiscare",
    "confiscati": "confiscare",
    "confiscato": "confiscare",
    "confiscava": "confiscare",
    "confiscavamo": "confiscare",
    "confiscavan": "confiscare",
    "confiscavano": "confiscare",
    "confiscavate": "confiscare",
    "confiscavi": "confiscare",
    "confiscavo": "confiscare",
    "confische": "confisca",
    "confischerai": "confiscare",
    "confischeran": "confiscare",
    "confischeranno": "confiscare",
    "confischerebbe": "confiscare",
    "confischerebber": "confiscare",
    "confischerebbero": "confiscare",
    "confischerei": "confiscare",
    "confischeremmo": "confiscare",
    "confischeremo": "confiscare",
    "confischereste": "confiscare",
    "confischeresti": "confiscare",
    "confischerete": "confiscare",
    "confischerà": "confiscare",
    "confischerò": "confiscare",
    "confischi": "confiscare",
    "confischiamo": "confiscare",
    "confischiate": "confiscare",
    "confischin": "confiscare",
    "confischino": "confiscare",
    "confisco": "confiscare",
    "confiscò": "confiscare",
    "confisser": "configgere",
    "confissero": "configgere",
    "confissi": "configgere",
    "confissè": "configgere",
    "confitta": "configgere",
    "confitte": "configgere",
    "confitti": "configgere",
    "confitto": "configgere",
    "conflagra": "conflagrare",
    "conflagrai": "conflagrare",
    "conflagrammo": "conflagrare",
    "conflagran": "conflagrare",
    "conflagrando": "conflagrare",
    "conflagrano": "conflagrare",
    "conflagrante": "conflagrare",
    "conflagranti": "conflagrare",
    "conflagrar": "conflagrare",
    "conflagraron": "conflagrare",
    "conflagrarono": "conflagrare",
    "conflagrasse": "conflagrare",
    "conflagrasser": "conflagrare",
    "conflagrassero": "conflagrare",
    "conflagrassi": "conflagrare",
    "conflagrassimo": "conflagrare",
    "conflagraste": "conflagrare",
    "conflagrasti": "conflagrare",
    "conflagrata": "conflagrare",
    "conflagrate": "conflagrare",
    "conflagrati": "conflagrare",
    "conflagrato": "conflagrare",
    "conflagrava": "conflagrare",
    "conflagravamo": "conflagrare",
    "conflagravan": "conflagrare",
    "conflagravano": "conflagrare",
    "conflagravate": "conflagrare",
    "conflagravi": "conflagrare",
    "conflagravo": "conflagrare",
    "conflagrerai": "conflagrare",
    "conflagreran": "conflagrare",
    "conflagreranno": "conflagrare",
    "conflagrerebbe": "conflagrare",
    "conflagrerebber": "conflagrare",
    "conflagrerebbero": "conflagrare",
    "conflagrerei": "conflagrare",
    "conflagreremmo": "conflagrare",
    "conflagreremo": "conflagrare",
    "conflagrereste": "conflagrare",
    "conflagreresti": "conflagrare",
    "conflagrerete": "conflagrare",
    "conflagrerà": "conflagrare",
    "conflagrerò": "conflagrare",
    "conflagri": "conflagrare",
    "conflagriamo": "conflagrare",
    "conflagriate": "conflagrare",
    "conflagrin": "conflagrare",
    "conflagrino": "conflagrare",
    "conflagro": "conflagrare",
    "conflagrò": "conflagrare",
    "confligga": "confliggere",
    "confliggan": "confliggere",
    "confliggano": "confliggere",
    "confligge": "confliggere",
    "confliggemmo": "confliggere",
    "confliggendo": "confliggere",
    "confliggente": "confliggere",
    "confliggenti": "confliggere",
    "confligger": "confliggere",
    "confliggerai": "confliggere",
    "confliggeran": "confliggere",
    "confliggeranno": "confliggere",
    "confliggerebbe": "confliggere",
    "confliggerebber": "confliggere",
    "confliggerebbero": "confliggere",
    "confliggerei": "confliggere",
    "confliggeremmo": "confliggere",
    "confliggeremo": "confliggere",
    "confliggereste": "confliggere",
    "confliggeresti": "confliggere",
    "confliggerete": "confliggere",
    "confliggerà": "confliggere",
    "confliggerò": "confliggere",
    "confliggesse": "confliggere",
    "confliggesser": "confliggere",
    "confliggessero": "confliggere",
    "confliggessi": "confliggere",
    "confliggessimo": "confliggere",
    "confliggeste": "confliggere",
    "confliggesti": "confliggere",
    "confliggete": "confliggere",
    "confliggeva": "confliggere",
    "confliggevamo": "confliggere",
    "confliggevan": "confliggere",
    "confliggevano": "confliggere",
    "confliggevate": "confliggere",
    "confliggevi": "confliggere",
    "confliggevo": "confliggere",
    "confliggi": "confliggere",
    "confliggiamo": "confliggere",
    "confliggiate": "confliggere",
    "confliggo": "confliggere",
    "confliggon": "confliggere",
    "confliggono": "confliggere",
    "conflisser": "confliggere",
    "conflissero": "confliggere",
    "conflissi": "confliggere",
    "conflissè": "confliggere",
    "conflitta": "confliggere",
    "conflitte": "confliggere",
    "conflitti": "conflitto",
    "conflitto": "confliggere",
    "conflittuali": "conflittuale",
    "confluendo": "confluire",
    "confluente": "confluire",
    "confluenti": "confluire",
    "confluenze": "confluenza",
    "confluiamo": "confluire",
    "confluiate": "confluire",
    "confluii": "confluire",
    "confluimmo": "confluire",
    "confluir": "confluire",
    "confluirai": "confluire",
    "confluiran": "confluire",
    "confluiranno": "confluire",
    "confluirebbe": "confluire",
    "confluirebber": "confluire",
    "confluirebbero": "confluire",
    "confluirei": "confluire",
    "confluiremmo": "confluire",
    "confluiremo": "confluire",
    "confluireste": "confluire",
    "confluiresti": "confluire",
    "confluirete": "confluire",
    "confluiron": "confluire",
    "confluirono": "confluire",
    "confluirà": "confluire",
    "confluirò": "confluire",
    "confluisca": "confluire",
    "confluiscan": "confluire",
    "confluiscano": "confluire",
    "confluisce": "confluire",
    "confluisci": "confluire",
    "confluisco": "confluire",
    "confluiscon": "confluire",
    "confluiscono": "confluire",
    "confluisse": "confluire",
    "confluisser": "confluire",
    "confluissero": "confluire",
    "confluissi": "confluire",
    "confluissimo": "confluire",
    "confluiste": "confluire",
    "confluisti": "confluire",
    "confluita": "confluire",
    "confluite": "confluire",
    "confluiti": "confluire",
    "confluito": "confluire",
    "confluiva": "confluire",
    "confluivamo": "confluire",
    "confluivan": "confluire",
    "confluivano": "confluire",
    "confluivate": "confluire",
    "confluivi": "confluire",
    "confluivo": "confluire",
    "confluì": "confluire",
    "confonda": "confondere",
    "confondan": "confondere",
    "confondano": "confondere",
    "confonde": "confondere",
    "confondemmo": "confondere",
    "confondendo": "confondere",
    "confondente": "confondere",
    "confondenti": "confondere",
    "confonder": "confondere",
    "confonderai": "confondere",
    "confonderan": "confondere",
    "confonderanno": "confondere",
    "confonderebbe": "confondere",
    "confonderebber": "confondere",
    "confonderebbero": "confondere",
    "confonderei": "confondere",
    "confonderemmo": "confondere",
    "confonderemo": "confondere",
    "confondereste": "confondere",
    "confonderesti": "confondere",
    "confonderete": "confondere",
    "confonderà": "confondere",
    "confonderò": "confondere",
    "confondesse": "confondere",
    "confondesser": "confondere",
    "confondessero": "confondere",
    "confondessi": "confondere",
    "confondessimo": "confondere",
    "confondeste": "confondere",
    "confondesti": "confondere",
    "confondete": "confondere",
    "confondeva": "confondere",
    "confondevamo": "confondere",
    "confondevan": "confondere",
    "confondevano": "confondere",
    "confondevate": "confondere",
    "confondevi": "confondere",
    "confondevo": "confondere",
    "confondi": "confondere",
    "confondiamo": "confondere",
    "confondiate": "confondere",
    "confondo": "confondere",
    "confondon": "confondere",
    "confondono": "confondere",
    "confonti": "confonto",
    "conforma": "conformare",
    "conformai": "conformare",
    "conformammo": "conformare",
    "conforman": "conformare",
    "conformando": "conformare",
    "conformano": "conformare",
    "conformante": "conformare",
    "conformanti": "conformare",
    "conformar": "conformare",
    "conformaron": "conformare",
    "conformarono": "conformare",
    "conformasse": "conformare",
    "conformasser": "conformare",
    "conformassero": "conformare",
    "conformassi": "conformare",
    "conformassimo": "conformare",
    "conformaste": "conformare",
    "conformasti": "conformare",
    "conformata": "conformare",
    "conformate": "conformare",
    "conformati": "conformare",
    "conformato": "conformare",
    "conformava": "conformare",
    "conformavamo": "conformare",
    "conformavan": "conformare",
    "conformavano": "conformare",
    "conformavate": "conformare",
    "conformavi": "conformare",
    "conformavo": "conformare",
    "conformazioni": "conformazione",
    "conformerai": "conformare",
    "conformeran": "conformare",
    "conformeranno": "conformare",
    "conformerebbe": "conformare",
    "conformerebber": "conformare",
    "conformerebbero": "conformare",
    "conformerei": "conformare",
    "conformeremmo": "conformare",
    "conformeremo": "conformare",
    "conformereste": "conformare",
    "conformeresti": "conformare",
    "conformerete": "conformare",
    "conformerà": "conformare",
    "conformerò": "conformare",
    "conformi": "conforme",
    "conformiamo": "conformare",
    "conformiate": "conformare",
    "conformin": "conformare",
    "conformino": "conformare",
    "conformismi": "conformismo",
    "conformiste": "conformista",
    "conformisti": "conformista",
    "conformo": "conformare",
    "conformò": "conformare",
    "conforta": "confortare",
    "confortai": "confortare",
    "confortammo": "confortare",
    "confortan": "confortare",
    "confortando": "confortare",
    "confortano": "confortare",
    "confortante": "confortare",
    "confortanti": "confortare",
    "confortar": "confortare",
    "confortaron": "confortare",
    "confortarono": "confortare",
    "confortasse": "confortare",
    "confortasser": "confortare",
    "confortassero": "confortare",
    "confortassi": "confortare",
    "confortassimo": "confortare",
    "confortaste": "confortare",
    "confortasti": "confortare",
    "confortata": "confortare",
    "confortate": "confortare",
    "confortati": "confortare",
    "confortato": "confortare",
    "confortatori": "confortatore",
    "confortatrice": "confortatore",
    "confortatrici": "confortatore",
    "confortava": "confortare",
    "confortavamo": "confortare",
    "confortavan": "confortare",
    "confortavano": "confortare",
    "confortavate": "confortare",
    "confortavi": "confortare",
    "confortavo": "confortare",
    "conforterai": "confortare",
    "conforteran": "confortare",
    "conforteranno": "confortare",
    "conforterebbe": "confortare",
    "conforterebber": "confortare",
    "conforterebbero": "confortare",
    "conforterei": "confortare",
    "conforteremmo": "confortare",
    "conforteremo": "confortare",
    "confortereste": "confortare",
    "conforteresti": "confortare",
    "conforterete": "confortare",
    "conforterà": "confortare",
    "conforterò": "confortare",
    "confortevoli": "confortevole",
    "conforti": "conforto",
    "confortiamo": "confortare",
    "confortiate": "confortare",
    "confortin": "confortare",
    "confortino": "confortare",
    "conforto": "confortare",
    "confortò": "confortare",
    "confratelli": "confratello",
    "confraternite": "confraternita",
    "confrica": "confricare",
    "confricai": "confricare",
    "confricammo": "confricare",
    "confrican": "confricare",
    "confricando": "confricare",
    "confricano": "confricare",
    "confricante": "confricare",
    "confricanti": "confricare",
    "confricar": "confricare",
    "confricaron": "confricare",
    "confricarono": "confricare",
    "confricasse": "confricare",
    "confricasser": "confricare",
    "confricassero": "confricare",
    "confricassi": "confricare",
    "confricassimo": "confricare",
    "confricaste": "confricare",
    "confricasti": "confricare",
    "confricata": "confricare",
    "confricate": "confricare",
    "confricati": "confricare",
    "confricato": "confricare",
    "confricava": "confricare",
    "confricavamo": "confricare",
    "confricavan": "confricare",
    "confricavano": "confricare",
    "confricavate": "confricare",
    "confricavi": "confricare",
    "confricavo": "confricare",
    "confricherai": "confricare",
    "confricheran": "confricare",
    "confricheranno": "confricare",
    "confricherebbe": "confricare",
    "confricherebber": "confricare",
    "confricherebbero": "confricare",
    "confricherei": "confricare",
    "confricheremmo": "confricare",
    "confricheremo": "confricare",
    "confrichereste": "confricare",
    "confricheresti": "confricare",
    "confricherete": "confricare",
    "confricherà": "confricare",
    "confricherò": "confricare",
    "confrichi": "confricare",
    "confrichiamo": "confricare",
    "confrichiate": "confricare",
    "confrichin": "confricare",
    "confrichino": "confricare",
    "confrico": "confricare",
    "confricò": "confricare",
    "confronta": "confrontare",
    "confrontabili": "confrontabile",
    "confrontai": "confrontare",
    "confrontammo": "confrontare",
    "confrontan": "confrontare",
    "confrontando": "confrontare",
    "confrontano": "confrontare",
    "confrontante": "confrontare",
    "confrontanti": "confrontare",
    "confrontar": "confrontare",
    "confrontaron": "confrontare",
    "confrontarono": "confrontare",
    "confrontasse": "confrontare",
    "confrontasser": "confrontare",
    "confrontassero": "confrontare",
    "confrontassi": "confrontare",
    "confrontassimo": "confrontare",
    "confrontaste": "confrontare",
    "confrontasti": "confrontare",
    "confrontata": "confrontare",
    "confrontate": "confrontare",
    "confrontati": "confrontare",
    "confrontato": "confrontare",
    "confrontava": "confrontare",
    "confrontavamo": "confrontare",
    "confrontavan": "confrontare",
    "confrontavano": "confrontare",
    "confrontavate": "confrontare",
    "confrontavi": "confrontare",
    "confrontavo": "confrontare",
    "confronterai": "confrontare",
    "confronteran": "confrontare",
    "confronteranno": "confrontare",
    "confronterebbe": "confrontare",
    "confronterebber": "confrontare",
    "confronterebbero": "confrontare",
    "confronterei": "confrontare",
    "confronteremmo": "confrontare",
    "confronteremo": "confrontare",
    "confrontereste": "confrontare",
    "confronteresti": "confrontare",
    "confronterete": "confrontare",
    "confronterà": "confrontare",
    "confronterò": "confrontare",
    "confronti": "confronto",
    "confronti-scontri": "confronto-scontro",
    "confrontiamo": "confrontare",
    "confrontiate": "confrontare",
    "confrontin": "confrontare",
    "confrontino": "confrontare",
    "confronto": "confrontare",
    "confrontò": "confrontare",
    "confuciana": "confuciano",
    "confuciane": "confuciano",
    "confuciani": "confuciano",
    "confusa": "confuso",
    "confuse": "confuso",
    "confuser": "confondere",
    "confusero": "confondere",
    "confusi": "confuso",
    "confusionali": "confusionale",
    "confusionari": "confusionario",
    "confusionaria": "confusionario",
    "confusionarie": "confusionario",
    "confusioni": "confusione",
    "confuso": "confondere",
    "confuta": "confutare",
    "confutabili": "confutabile",
    "confutai": "confutare",
    "confutammo": "confutare",
    "confutan": "confutare",
    "confutando": "confutare",
    "confutano": "confutare",
    "confutante": "confutare",
    "confutanti": "confutare",
    "confutar": "confutare",
    "confutaron": "confutare",
    "confutarono": "confutare",
    "confutasse": "confutare",
    "confutasser": "confutare",
    "confutassero": "confutare",
    "confutassi": "confutare",
    "confutassimo": "confutare",
    "confutaste": "confutare",
    "confutasti": "confutare",
    "confutata": "confutare",
    "confutate": "confutare",
    "confutati": "confutare",
    "confutato": "confutare",
    "confutava": "confutare",
    "confutavamo": "confutare",
    "confutavan": "confutare",
    "confutavano": "confutare",
    "confutavate": "confutare",
    "confutavi": "confutare",
    "confutavo": "confutare",
    "confutazioni": "confutazione",
    "confuterai": "confutare",
    "confuteran": "confutare",
    "confuteranno": "confutare",
    "confuterebbe": "confutare",
    "confuterebber": "confutare",
    "confuterebbero": "confutare",
    "confuterei": "confutare",
    "confuteremmo": "confutare",
    "confuteremo": "confutare",
    "confutereste": "confutare",
    "confuteresti": "confutare",
    "confuterete": "confutare",
    "confuterà": "confutare",
    "confuterò": "confutare",
    "confuti": "confutare",
    "confutiamo": "confutare",
    "confutiate": "confutare",
    "confutin": "confutare",
    "confutino": "confutare",
    "confuto": "confutare",
    "confutò": "confutare",
    "conga": "corre",
    "congan": "corre",
    "congano": "corre",
    "congeda": "congedare",
    "congedai": "congedare",
    "congedammo": "congedare",
    "congedan": "congedare",
    "congedando": "congedare",
    "congedano": "congedare",
    "congedante": "congedare",
    "congedanti": "congedare",
    "congedar": "congedare",
    "congedaron": "congedare",
    "congedarono": "congedare",
    "congedasse": "congedare",
    "congedasser": "congedare",
    "congedassero": "congedare",
    "congedassi": "congedare",
    "congedassimo": "congedare",
    "congedaste": "congedare",
    "congedasti": "congedare",
    "congedata": "congedare",
    "congedate": "congedare",
    "congedati": "congedare",
    "congedato": "congedare",
    "congedava": "congedare",
    "congedavamo": "congedare",
    "congedavan": "congedare",
    "congedavano": "congedare",
    "congedavate": "congedare",
    "congedavi": "congedare",
    "congedavo": "congedare",
    "congederai": "congedare",
    "congederan": "congedare",
    "congederanno": "congedare",
    "congederebbe": "congedare",
    "congederebber": "congedare",
    "congederebbero": "congedare",
    "congederei": "congedare",
    "congederemmo": "congedare",
    "congederemo": "congedare",
    "congedereste": "congedare",
    "congederesti": "congedare",
    "congederete": "congedare",
    "congederà": "congedare",
    "congederò": "congedare",
    "congedi": "congedo",
    "congediamo": "congedare",
    "congediate": "congedare",
    "congedin": "congedare",
    "congedino": "congedare",
    "congedo": "congedare",
    "congedò": "congedare",
    "congegna": "congegnare",
    "congegnai": "congegnare",
    "congegnammo": "congegnare",
    "congegnan": "congegnare",
    "congegnando": "congegnare",
    "congegnano": "congegnare",
    "congegnante": "congegnare",
    "congegnanti": "congegnare",
    "congegnar": "congegnare",
    "congegnaron": "congegnare",
    "congegnarono": "congegnare",
    "congegnasse": "congegnare",
    "congegnasser": "congegnare",
    "congegnassero": "congegnare",
    "congegnassi": "congegnare",
    "congegnassimo": "congegnare",
    "congegnaste": "congegnare",
    "congegnasti": "congegnare",
    "congegnata": "congegnare",
    "congegnate": "congegnare",
    "congegnati": "congegnare",
    "congegnato": "congegnare",
    "congegnava": "congegnare",
    "congegnavamo": "congegnare",
    "congegnavan": "congegnare",
    "congegnavano": "congegnare",
    "congegnavate": "congegnare",
    "congegnavi": "congegnare",
    "congegnavo": "congegnare",
    "congegnerai": "congegnare",
    "congegneran": "congegnare",
    "congegneranno": "congegnare",
    "congegnerebbe": "congegnare",
    "congegnerebber": "congegnare",
    "congegnerebbero": "congegnare",
    "congegnerei": "congegnare",
    "congegneremmo": "congegnare",
    "congegneremo": "congegnare",
    "congegnereste": "congegnare",
    "congegneresti": "congegnare",
    "congegnerete": "congegnare",
    "congegnerà": "congegnare",
    "congegnerò": "congegnare",
    "congegni": "congegno",
    "congegniamo": "congegnare",
    "congegniate": "congegnare",
    "congegnin": "congegnare",
    "congegnino": "congegnare",
    "congegno": "congegnare",
    "congegnò": "congegnare",
    "congela": "congelare",
    "congelai": "congelare",
    "congelamenti": "congelamento",
    "congelammo": "congelare",
    "congelan": "congelare",
    "congelando": "congelare",
    "congelano": "congelare",
    "congelante": "congelare",
    "congelanti": "congelare",
    "congelar": "congelare",
    "congelaron": "congelare",
    "congelarono": "congelare",
    "congelasse": "congelare",
    "congelasser": "congelare",
    "congelassero": "congelare",
    "congelassi": "congelare",
    "congelassimo": "congelare",
    "congelaste": "congelare",
    "congelasti": "congelare",
    "congelata": "congelare",
    "congelate": "congelare",
    "congelati": "congelare",
    "congelato": "congelare",
    "congelatori": "congelatore",
    "congelava": "congelare",
    "congelavamo": "congelare",
    "congelavan": "congelare",
    "congelavano": "congelare",
    "congelavate": "congelare",
    "congelavi": "congelare",
    "congelavo": "congelare",
    "congelerai": "congelare",
    "congeleran": "congelare",
    "congeleranno": "congelare",
    "congelerebbe": "congelare",
    "congelerebber": "congelare",
    "congelerebbero": "congelare",
    "congelerei": "congelare",
    "congeleremmo": "congelare",
    "congeleremo": "congelare",
    "congelereste": "congelare",
    "congeleresti": "congelare",
    "congelerete": "congelare",
    "congelerà": "congelare",
    "congelerò": "congelare",
    "congeli": "congelare",
    "congeliamo": "congelare",
    "congeliate": "congelare",
    "congelin": "congelare",
    "congelino": "congelare",
    "congelo": "congelare",
    "congelò": "congelare",
    "congene": "congenere",
    "congenei": "congenere",
    "congenemmo": "congenere",
    "congenendo": "congenere",
    "congenente": "congenere",
    "congenenti": "congenere",
    "congener": "congenere",
    "congenerai": "congenere",
    "congeneran": "congenere",
    "congeneranno": "congenere",
    "congenerebbe": "congenere",
    "congenerebber": "congenere",
    "congenerebbero": "congenere",
    "congenerei": "congenere",
    "congeneremmo": "congenere",
    "congeneremo": "congenere",
    "congenereste": "congenere",
    "congeneresti": "congenere",
    "congenerete": "congenere",
    "congeneron": "congenere",
    "congenerono": "congenere",
    "congenerà": "congenere",
    "congenerò": "congenere",
    "congenesse": "congenere",
    "congenesser": "congenere",
    "congenessero": "congenere",
    "congenessi": "congenere",
    "congenessimo": "congenere",
    "congeneste": "congenere",
    "congenesti": "congenere",
    "congenete": "congenere",
    "congeneva": "congenere",
    "congenevamo": "congenere",
    "congenevan": "congenere",
    "congenevano": "congenere",
    "congenevate": "congenere",
    "congenevi": "congenere",
    "congenevo": "congenere",
    "congenga": "congenere",
    "congengan": "congenere",
    "congengano": "congenere",
    "congengo": "congenere",
    "congengon": "congenere",
    "congengono": "congenere",
    "congeni": "congenere",
    "congeniali": "congeniale",
    "congeniamo": "congenere",
    "congeniate": "congenere",
    "congenita": "congenito",
    "congenite": "congenito",
    "congeniti": "congenito",
    "congenuta": "congenere",
    "congenute": "congenere",
    "congenuti": "congenere",
    "congenuto": "congenere",
    "congenè": "congenere",
    "congestiona": "congestionare",
    "congestionai": "congestionare",
    "congestionammo": "congestionare",
    "congestionan": "congestionare",
    "congestionando": "congestionare",
    "congestionano": "congestionare",
    "congestionante": "congestionare",
    "congestionanti": "congestionare",
    "congestionar": "congestionare",
    "congestionaron": "congestionare",
    "congestionarono": "congestionare",
    "congestionasse": "congestionare",
    "congestionasser": "congestionare",
    "congestionassero": "congestionare",
    "congestionassi": "congestionare",
    "congestionassimo": "congestionare",
    "congestionaste": "congestionare",
    "congestionasti": "congestionare",
    "congestionata": "congestionato",
    "congestionate": "congestionato",
    "congestionati": "congestionato",
    "congestionato": "congestionare",
    "congestionava": "congestionare",
    "congestionavamo": "congestionare",
    "congestionavan": "congestionare",
    "congestionavano": "congestionare",
    "congestionavate": "congestionare",
    "congestionavi": "congestionare",
    "congestionavo": "congestionare",
    "congestionerai": "congestionare",
    "congestioneran": "congestionare",
    "congestioneranno": "congestionare",
    "congestionerebbe": "congestionare",
    "congestionerebber": "congestionare",
    "congestionerebbero": "congestionare",
    "congestionerei": "congestionare",
    "congestioneremmo": "congestionare",
    "congestioneremo": "congestionare",
    "congestionereste": "congestionare",
    "congestioneresti": "congestionare",
    "congestionerete": "congestionare",
    "congestionerà": "congestionare",
    "congestionerò": "congestionare",
    "congestioni": "congestione",
    "congestioniamo": "congestionare",
    "congestioniate": "congestionare",
    "congestionin": "congestionare",
    "congestionino": "congestionare",
    "congestiono": "congestionare",
    "congestionò": "congestionare",
    "congettura": "congetturare",
    "congetturai": "congetturare",
    "congetturammo": "congetturare",
    "congetturan": "congetturare",
    "congetturando": "congetturare",
    "congetturano": "congetturare",
    "congetturante": "congetturare",
    "congetturanti": "congetturare",
    "congetturar": "congetturare",
    "congetturaron": "congetturare",
    "congetturarono": "congetturare",
    "congetturasse": "congetturare",
    "congetturasser": "congetturare",
    "congetturassero": "congetturare",
    "congetturassi": "congetturare",
    "congetturassimo": "congetturare",
    "congetturaste": "congetturare",
    "congetturasti": "congetturare",
    "congetturata": "congetturare",
    "congetturate": "congetturare",
    "congetturati": "congetturare",
    "congetturato": "congetturare",
    "congetturava": "congetturare",
    "congetturavamo": "congetturare",
    "congetturavan": "congetturare",
    "congetturavano": "congetturare",
    "congetturavate": "congetturare",
    "congetturavi": "congetturare",
    "congetturavo": "congetturare",
    "congetture": "congettura",
    "congetturerai": "congetturare",
    "congettureran": "congetturare",
    "congettureranno": "congetturare",
    "congetturerebbe": "congetturare",
    "congetturerebber": "congetturare",
    "congetturerebbero": "congetturare",
    "congetturerei": "congetturare",
    "congettureremmo": "congetturare",
    "congettureremo": "congetturare",
    "congetturereste": "congetturare",
    "congettureresti": "congetturare",
    "congetturerete": "congetturare",
    "congetturerà": "congetturare",
    "congetturerò": "congetturare",
    "congetturi": "congetturare",
    "congetturiamo": "congetturare",
    "congetturiate": "congetturare",
    "congetturin": "congetturare",
    "congetturino": "congetturare",
    "congetturo": "congetturare",
    "congetturò": "congetturare",
    "congiunga": "congiungere",
    "congiungan": "congiungere",
    "congiungano": "congiungere",
    "congiunge": "congiungere",
    "congiungemmo": "congiungere",
    "congiungendo": "congiungere",
    "congiungente": "congiungere",
    "congiungenti": "congiungere",
    "congiunger": "congiungere",
    "congiungerai": "congiungere",
    "congiungeran": "congiungere",
    "congiungeranno": "congiungere",
    "congiungerebbe": "congiungere",
    "congiungerebber": "congiungere",
    "congiungerebbero": "congiungere",
    "congiungerei": "congiungere",
    "congiungeremmo": "congiungere",
    "congiungeremo": "congiungere",
    "congiungereste": "congiungere",
    "congiungeresti": "congiungere",
    "congiungerete": "congiungere",
    "congiungerà": "congiungere",
    "congiungerò": "congiungere",
    "congiungesse": "congiungere",
    "congiungesser": "congiungere",
    "congiungessero": "congiungere",
    "congiungessi": "congiungere",
    "congiungessimo": "congiungere",
    "congiungeste": "congiungere",
    "congiungesti": "congiungere",
    "congiungete": "congiungere",
    "congiungeva": "congiungere",
    "congiungevamo": "congiungere",
    "congiungevan": "congiungere",
    "congiungevano": "congiungere",
    "congiungevate": "congiungere",
    "congiungevi": "congiungere",
    "congiungevo": "congiungere",
    "congiungi": "congiungere",
    "congiungiamo": "congiungere",
    "congiungiate": "congiungere",
    "congiungimenti": "congiungimento",
    "congiungo": "congiungere",
    "congiungon": "congiungere",
    "congiungono": "congiungere",
    "congiunse": "congiungere",
    "congiunser": "congiungere",
    "congiunsero": "congiungere",
    "congiunsi": "congiungere",
    "congiunta": "congiunto",
    "congiunte": "congiunto",
    "congiunti": "congiunto",
    "congiuntivi": "congiuntivo",
    "congiuntiviti": "congiuntivite",
    "congiunto": "congiungere",
    "congiunturali": "congiunturale",
    "congiunture": "congiuntura",
    "congiunzioni": "congiunzione",
    "congiura": "congiurare",
    "congiurai": "congiurare",
    "congiurammo": "congiurare",
    "congiuran": "congiurare",
    "congiurando": "congiurare",
    "congiurano": "congiurare",
    "congiurante": "congiurare",
    "congiuranti": "congiurare",
    "congiurar": "congiurare",
    "congiuraron": "congiurare",
    "congiurarono": "congiurare",
    "congiurasse": "congiurare",
    "congiurasser": "congiurare",
    "congiurassero": "congiurare",
    "congiurassi": "congiurare",
    "congiurassimo": "congiurare",
    "congiuraste": "congiurare",
    "congiurasti": "congiurare",
    "congiurata": "congiurare",
    "congiurate": "congiurare",
    "congiurati": "congiurato",
    "congiurato": "congiurare",
    "congiurava": "congiurare",
    "congiuravamo": "congiurare",
    "congiuravan": "congiurare",
    "congiuravano": "congiurare",
    "congiuravate": "congiurare",
    "congiuravi": "congiurare",
    "congiuravo": "congiurare",
    "congiure": "congiura",
    "congiurerai": "congiurare",
    "congiureran": "congiurare",
    "congiureranno": "congiurare",
    "congiurerebbe": "congiurare",
    "congiurerebber": "congiurare",
    "congiurerebbero": "congiurare",
    "congiurerei": "congiurare",
    "congiureremmo": "congiurare",
    "congiureremo": "congiurare",
    "congiurereste": "congiurare",
    "congiureresti": "congiurare",
    "congiurerete": "congiurare",
    "congiurerà": "congiurare",
    "congiurerò": "congiurare",
    "congiuri": "congiurare",
    "congiuriamo": "congiurare",
    "congiuriate": "congiurare",
    "congiurin": "congiurare",
    "congiurino": "congiurare",
    "congiuro": "congiurare",
    "congiurò": "congiurare",
    "congiuturali": "congiuturale",
    "congloba": "conglobare",
    "conglobai": "conglobare",
    "conglobammo": "conglobare",
    "congloban": "conglobare",
    "conglobando": "conglobare",
    "conglobano": "conglobare",
    "conglobante": "conglobare",
    "conglobanti": "conglobare",
    "conglobar": "conglobare",
    "conglobaron": "conglobare",
    "conglobarono": "conglobare",
    "conglobasse": "conglobare",
    "conglobasser": "conglobare",
    "conglobassero": "conglobare",
    "conglobassi": "conglobare",
    "conglobassimo": "conglobare",
    "conglobaste": "conglobare",
    "conglobasti": "conglobare",
    "conglobata": "conglobare",
    "conglobate": "conglobare",
    "conglobati": "conglobare",
    "conglobato": "conglobare",
    "conglobava": "conglobare",
    "conglobavamo": "conglobare",
    "conglobavan": "conglobare",
    "conglobavano": "conglobare",
    "conglobavate": "conglobare",
    "conglobavi": "conglobare",
    "conglobavo": "conglobare",
    "congloberai": "conglobare",
    "congloberan": "conglobare",
    "congloberanno": "conglobare",
    "congloberebbe": "conglobare",
    "congloberebber": "conglobare",
    "congloberebbero": "conglobare",
    "congloberei": "conglobare",
    "congloberemmo": "conglobare",
    "congloberemo": "conglobare",
    "conglobereste": "conglobare",
    "congloberesti": "conglobare",
    "congloberete": "conglobare",
    "congloberà": "conglobare",
    "congloberò": "conglobare",
    "conglobi": "conglobare",
    "conglobiamo": "conglobare",
    "conglobiate": "conglobare",
    "conglobin": "conglobare",
    "conglobino": "conglobare",
    "conglobo": "conglobare",
    "conglobò": "conglobare",
    "conglomera": "conglomerare",
    "conglomerai": "conglomerare",
    "conglomerammo": "conglomerare",
    "conglomeran": "conglomerare",
    "conglomerando": "conglomerare",
    "conglomerano": "conglomerare",
    "conglomerante": "conglomerare",
    "conglomeranti": "conglomerare",
    "conglomerar": "conglomerare",
    "conglomeraron": "conglomerare",
    "conglomerarono": "conglomerare",
    "conglomerasse": "conglomerare",
    "conglomerasser": "conglomerare",
    "conglomerassero": "conglomerare",
    "conglomerassi": "conglomerare",
    "conglomerassimo": "conglomerare",
    "conglomeraste": "conglomerare",
    "conglomerasti": "conglomerare",
    "conglomerata": "conglomerato",
    "conglomerate": "conglomerato",
    "conglomerati": "conglomerato",
    "conglomerato": "conglomerare",
    "conglomerava": "conglomerare",
    "conglomeravamo": "conglomerare",
    "conglomeravan": "conglomerare",
    "conglomeravano": "conglomerare",
    "conglomeravate": "conglomerare",
    "conglomeravi": "conglomerare",
    "conglomeravo": "conglomerare",
    "conglomererai": "conglomerare",
    "conglomereran": "conglomerare",
    "conglomereranno": "conglomerare",
    "conglomererebbe": "conglomerare",
    "conglomererebber": "conglomerare",
    "conglomererebbero": "conglomerare",
    "conglomererei": "conglomerare",
    "conglomereremmo": "conglomerare",
    "conglomereremo": "conglomerare",
    "conglomerereste": "conglomerare",
    "conglomereresti": "conglomerare",
    "conglomererete": "conglomerare",
    "conglomererà": "conglomerare",
    "conglomererò": "conglomerare",
    "conglomeri": "conglomerare",
    "conglomeriamo": "conglomerare",
    "conglomeriate": "conglomerare",
    "conglomerin": "conglomerare",
    "conglomerino": "conglomerare",
    "conglomero": "conglomerare",
    "conglomerò": "conglomerare",
    "congo": "corre",
    "congolesi": "congolese",
    "congon": "corre",
    "congono": "corre",
    "congratula": "congratulare",
    "congratulai": "congratulare",
    "congratulammo": "congratulare",
    "congratulan": "congratulare",
    "congratulando": "congratulare",
    "congratulano": "congratulare",
    "congratular": "congratulare",
    "congratularon": "congratulare",
    "congratularono": "congratulare",
    "congratulasse": "congratulare",
    "congratulasser": "congratulare",
    "congratulassero": "congratulare",
    "congratulassi": "congratulare",
    "congratulassimo": "congratulare",
    "congratulaste": "congratulare",
    "congratulasti": "congratulare",
    "congratulata": "congratulare",
    "congratulate": "congratulare",
    "congratulati": "congratulare",
    "congratulato": "congratulare",
    "congratulava": "congratulare",
    "congratulavamo": "congratulare",
    "congratulavan": "congratulare",
    "congratulavano": "congratulare",
    "congratulavate": "congratulare",
    "congratulavi": "congratulare",
    "congratulavo": "congratulare",
    "congratulazioni": "congratulazione",
    "congratulerai": "congratulare",
    "congratuleran": "congratulare",
    "congratuleranno": "congratulare",
    "congratulerebbe": "congratulare",
    "congratulerebber": "congratulare",
    "congratulerebbero": "congratulare",
    "congratulerei": "congratulare",
    "congratuleremmo": "congratulare",
    "congratuleremo": "congratulare",
    "congratulereste": "congratulare",
    "congratuleresti": "congratulare",
    "congratulerete": "congratulare",
    "congratulerà": "congratulare",
    "congratulerò": "congratulare",
    "congratuli": "congratulare",
    "congratuliamo": "congratulare",
    "congratuliate": "congratulare",
    "congratulin": "congratulare",
    "congratulino": "congratulare",
    "congratulo": "congratulare",
    "congratulò": "congratulare",
    "congrega": "congregare",
    "congregai": "congregare",
    "congregammo": "congregare",
    "congregan": "congregare",
    "congregando": "congregare",
    "congregano": "congregare",
    "congregante": "congregare",
    "congreganti": "congregare",
    "congregar": "congregare",
    "congregaron": "congregare",
    "congregarono": "congregare",
    "congregasse": "congregare",
    "congregasser": "congregare",
    "congregassero": "congregare",
    "congregassi": "congregare",
    "congregassimo": "congregare",
    "congregaste": "congregare",
    "congregasti": "congregare",
    "congregata": "congregare",
    "congregate": "congregare",
    "congregati": "congregare",
    "congregato": "congregare",
    "congregava": "congregare",
    "congregavamo": "congregare",
    "congregavan": "congregare",
    "congregavano": "congregare",
    "congregavate": "congregare",
    "congregavi": "congregare",
    "congregavo": "congregare",
    "congregazioni": "congregazione",
    "congreghe": "congrega",
    "congregherai": "congregare",
    "congregheran": "congregare",
    "congregheranno": "congregare",
    "congregherebbe": "congregare",
    "congregherebber": "congregare",
    "congregherebbero": "congregare",
    "congregherei": "congregare",
    "congregheremmo": "congregare",
    "congregheremo": "congregare",
    "congreghereste": "congregare",
    "congregheresti": "congregare",
    "congregherete": "congregare",
    "congregherà": "congregare",
    "congregherò": "congregare",
    "congreghi": "congregare",
    "congreghiamo": "congregare",
    "congreghiate": "congregare",
    "congreghin": "congregare",
    "congreghino": "congregare",
    "congrego": "congregare",
    "congregò": "congregare",
    "congressi": "congresso",
    "congressisti": "congressista",
    "congressuali": "congressuale",
    "congrua": "congruo",
    "congrue": "congruo",
    "congrui": "congruo",
    "conguagli": "conguaglio",
    "conguaglia": "conguagliare",
    "conguagliai": "conguagliare",
    "conguagliammo": "conguagliare",
    "conguagliamo": "conguagliare",
    "conguaglian": "conguagliare",
    "conguagliando": "conguagliare",
    "conguagliano": "conguagliare",
    "conguagliante": "conguagliare",
    "conguaglianti": "conguagliare",
    "conguagliar": "conguagliare",
    "conguagliaron": "conguagliare",
    "conguagliarono": "conguagliare",
    "conguagliasse": "conguagliare",
    "conguagliasser": "conguagliare",
    "conguagliassero": "conguagliare",
    "conguagliassi": "conguagliare",
    "conguagliassimo": "conguagliare",
    "conguagliaste": "conguagliare",
    "conguagliasti": "conguagliare",
    "conguagliata": "conguagliare",
    "conguagliate": "conguagliare",
    "conguagliati": "conguagliare",
    "conguagliato": "conguagliare",
    "conguagliava": "conguagliare",
    "conguagliavamo": "conguagliare",
    "conguagliavan": "conguagliare",
    "conguagliavano": "conguagliare",
    "conguagliavate": "conguagliare",
    "conguagliavi": "conguagliare",
    "conguagliavo": "conguagliare",
    "conguaglierai": "conguagliare",
    "conguaglieran": "conguagliare",
    "conguaglieranno": "conguagliare",
    "conguaglierebbe": "conguagliare",
    "conguaglierebber": "conguagliare",
    "conguaglierebbero": "conguagliare",
    "conguaglierei": "conguagliare",
    "conguaglieremmo": "conguagliare",
    "conguaglieremo": "conguagliare",
    "conguagliereste": "conguagliare",
    "conguaglieresti": "conguagliare",
    "conguaglierete": "conguagliare",
    "conguaglierà": "conguagliare",
    "conguaglierò": "conguagliare",
    "conguaglin": "conguagliare",
    "conguaglino": "conguagliare",
    "conguaglio": "conguagliare",
    "conguagliò": "conguagliare",
    "coni": "corre",
    "conia": "coniare",
    "coniai": "coniare",
    "coniammo": "coniare",
    "coniamo": "corre",
    "conian": "coniare",
    "coniando": "coniare",
    "coniano": "coniare",
    "coniante": "coniare",
    "conianti": "coniare",
    "coniar": "coniare",
    "coniaron": "coniare",
    "coniarono": "coniare",
    "coniasse": "coniare",
    "coniasser": "coniare",
    "coniassero": "coniare",
    "coniassi": "coniare",
    "coniassimo": "coniare",
    "coniaste": "coniare",
    "coniasti": "coniare",
    "coniata": "coniare",
    "coniate": "corre",
    "coniati": "coniare",
    "coniato": "coniare",
    "coniava": "coniare",
    "coniavamo": "coniare",
    "coniavan": "coniare",
    "coniavano": "coniare",
    "coniavate": "coniare",
    "coniavi": "coniare",
    "coniavo": "coniare",
    "conica": "conico",
    "coniche": "conico",
    "conici": "conico",
    "conierai": "coniare",
    "conieran": "coniare",
    "conieranno": "coniare",
    "conierebbe": "coniare",
    "conierebber": "coniare",
    "conierebbero": "coniare",
    "conierei": "coniare",
    "conieremmo": "coniare",
    "conieremo": "coniare",
    "coniereste": "coniare",
    "conieresti": "coniare",
    "conierete": "coniare",
    "conierà": "coniare",
    "conierò": "coniare",
    "conigli": "coniglio",
    "conigliette": "coniglietta",
    "coniglietti": "coniglietto",
    "conin": "coniare",
    "conino": "coniare",
    "conio": "coniare",
    "coniuga": "coniugare",
    "coniugai": "coniugare",
    "coniugali": "coniugale",
    "coniugammo": "coniugare",
    "coniugan": "coniugare",
    "coniugando": "coniugare",
    "coniugano": "coniugare",
    "coniugante": "coniugare",
    "coniuganti": "coniugare",
    "coniugar": "coniugare",
    "coniugaron": "coniugare",
    "coniugarono": "coniugare",
    "coniugasse": "coniugare",
    "coniugasser": "coniugare",
    "coniugassero": "coniugare",
    "coniugassi": "coniugare",
    "coniugassimo": "coniugare",
    "coniugaste": "coniugare",
    "coniugasti": "coniugare",
    "coniugata": "coniugato",
    "coniugate": "coniugato",
    "coniugati": "coniugato",
    "coniugato": "coniugare",
    "coniugava": "coniugare",
    "coniugavamo": "coniugare",
    "coniugavan": "coniugare",
    "coniugavano": "coniugare",
    "coniugavate": "coniugare",
    "coniugavi": "coniugare",
    "coniugavo": "coniugare",
    "coniugherai": "coniugare",
    "coniugheran": "coniugare",
    "coniugheranno": "coniugare",
    "coniugherebbe": "coniugare",
    "coniugherebber": "coniugare",
    "coniugherebbero": "coniugare",
    "coniugherei": "coniugare",
    "coniugheremmo": "coniugare",
    "coniugheremo": "coniugare",
    "coniughereste": "coniugare",
    "coniugheresti": "coniugare",
    "coniugherete": "coniugare",
    "coniugherà": "coniugare",
    "coniugherò": "coniugare",
    "coniughi": "coniugare",
    "coniughiamo": "coniugare",
    "coniughiate": "coniugare",
    "coniughin": "coniugare",
    "coniughino": "coniugare",
    "coniugi": "coniuge",
    "coniugo": "coniugare",
    "coniugò": "coniugare",
    "coniò": "coniare",
    "connatura": "connaturare",
    "connaturai": "connaturare",
    "connaturali": "connaturale",
    "connaturammo": "connaturare",
    "connaturan": "connaturare",
    "connaturando": "connaturare",
    "connaturano": "connaturare",
    "connaturante": "connaturare",
    "connaturanti": "connaturare",
    "connaturar": "connaturare",
    "connaturaron": "connaturare",
    "connaturarono": "connaturare",
    "connaturasse": "connaturare",
    "connaturasser": "connaturare",
    "connaturassero": "connaturare",
    "connaturassi": "connaturare",
    "connaturassimo": "connaturare",
    "connaturaste": "connaturare",
    "connaturasti": "connaturare",
    "connaturata": "connaturato",
    "connaturate": "connaturato",
    "connaturati": "connaturato",
    "connaturato": "connaturare",
    "connaturava": "connaturare",
    "connaturavamo": "connaturare",
    "connaturavan": "connaturare",
    "connaturavano": "connaturare",
    "connaturavate": "connaturare",
    "connaturavi": "connaturare",
    "connaturavo": "connaturare",
    "connaturerai": "connaturare",
    "connatureran": "connaturare",
    "connatureranno": "connaturare",
    "connaturerebbe": "connaturare",
    "connaturerebber": "connaturare",
    "connaturerebbero": "connaturare",
    "connaturerei": "connaturare",
    "connatureremmo": "connaturare",
    "connatureremo": "connaturare",
    "connaturereste": "connaturare",
    "connatureresti": "connaturare",
    "connaturerete": "connaturare",
    "connaturerà": "connaturare",
    "connaturerò": "connaturare",
    "connaturi": "connaturare",
    "connaturiamo": "connaturare",
    "connaturiate": "connaturare",
    "connaturin": "connaturare",
    "connaturino": "connaturare",
    "connaturo": "connaturare",
    "connaturò": "connaturare",
    "connazionali": "connazionale",
    "connessa": "connettere",
    "connesse": "connettere",
    "connessi": "connettere",
    "connessioni": "connessione",
    "connesso": "connettere",
    "connetta": "connettere",
    "connettan": "connettere",
    "connettano": "connettere",
    "connette": "connettere",
    "connettei": "connettere",
    "connettemmo": "connettere",
    "connettendo": "connettere",
    "connettente": "connettere",
    "connettenti": "connettere",
    "connetter": "connettere",
    "connetterai": "connettere",
    "connetteran": "connettere",
    "connetteranno": "connettere",
    "connetterebbe": "connettere",
    "connetterebber": "connettere",
    "connetterebbero": "connettere",
    "connetterei": "connettere",
    "connetteremmo": "connettere",
    "connetteremo": "connettere",
    "connettereste": "connettere",
    "connetteresti": "connettere",
    "connetterete": "connettere",
    "connetteron": "connettere",
    "connetterono": "connettere",
    "connetterà": "connettere",
    "connetterò": "connettere",
    "connettesse": "connettere",
    "connettesser": "connettere",
    "connettessero": "connettere",
    "connettessi": "connettere",
    "connettessimo": "connettere",
    "connetteste": "connettere",
    "connettesti": "connettere",
    "connettete": "connettere",
    "connetteva": "connettere",
    "connettevamo": "connettere",
    "connettevan": "connettere",
    "connettevano": "connettere",
    "connettevate": "connettere",
    "connettevi": "connettere",
    "connettevo": "connettere",
    "connetti": "connettere",
    "connettiamo": "connettere",
    "connettiate": "connettere",
    "connettiva": "connettivo",
    "connettive": "connettivo",
    "connettivi": "connettivo",
    "connetto": "connettere",
    "connetton": "connettere",
    "connettono": "connettere",
    "connettè": "connettere",
    "conniventi": "connivente",
    "connivenze": "connivenza",
    "connota": "connotare",
    "connotai": "connotare",
    "connotammo": "connotare",
    "connotan": "connotare",
    "connotando": "connotare",
    "connotano": "connotare",
    "connotante": "connotare",
    "connotanti": "connotare",
    "connotar": "connotare",
    "connotaron": "connotare",
    "connotarono": "connotare",
    "connotasse": "connotare",
    "connotasser": "connotare",
    "connotassero": "connotare",
    "connotassi": "connotare",
    "connotassimo": "connotare",
    "connotaste": "connotare",
    "connotasti": "connotare",
    "connotata": "connotare",
    "connotate": "connotare",
    "connotati": "connotato",
    "connotato": "connotare",
    "connotava": "connotare",
    "connotavamo": "connotare",
    "connotavan": "connotare",
    "connotavano": "connotare",
    "connotavate": "connotare",
    "connotavi": "connotare",
    "connotavo": "connotare",
    "connotazioni": "connotazione",
    "connoterai": "connotare",
    "connoteran": "connotare",
    "connoteranno": "connotare",
    "connoterebbe": "connotare",
    "connoterebber": "connotare",
    "connoterebbero": "connotare",
    "connoterei": "connotare",
    "connoteremmo": "connotare",
    "connoteremo": "connotare",
    "connotereste": "connotare",
    "connoteresti": "connotare",
    "connoterete": "connotare",
    "connoterà": "connotare",
    "connoterò": "connotare",
    "connoti": "connotare",
    "connotiamo": "connotare",
    "connotiate": "connotare",
    "connotin": "connotare",
    "connotino": "connotare",
    "connoto": "connotare",
    "connotò": "connotare",
    "connubi": "connubio",
    "conobbe": "conoscere",
    "conobber": "conoscere",
    "conobbero": "conoscere",
    "conobbi": "conoscere",
    "conosca": "conoscere",
    "conoscan": "conoscere",
    "conoscano": "conoscere",
    "conosce": "conoscere",
    "conoscemmo": "conoscere",
    "conoscendo": "conoscere",
    "conoscente": "conoscere",
    "conoscenti": "conoscere",
    "conoscenze": "conoscenza",
    "conoscer": "conoscere",
    "conoscerai": "conoscere",
    "conosceran": "conoscere",
    "conosceranno": "conoscere",
    "conoscerebbe": "conoscere",
    "conoscerebber": "conoscere",
    "conoscerebbero": "conoscere",
    "conoscerei": "conoscere",
    "conosceremmo": "conoscere",
    "conosceremo": "conoscere",
    "conoscereste": "conoscere",
    "conosceresti": "conoscere",
    "conoscerete": "conoscere",
    "conoscerà": "conoscere",
    "conoscerò": "conoscere",
    "conoscesse": "conoscere",
    "conoscesser": "conoscere",
    "conoscessero": "conoscere",
    "conoscessi": "conoscere",
    "conoscessimo": "conoscere",
    "conosceste": "conoscere",
    "conoscesti": "conoscere",
    "conoscete": "conoscere",
    "conosceva": "conoscere",
    "conoscevamo": "conoscere",
    "conoscevan": "conoscere",
    "conoscevano": "conoscere",
    "conoscevate": "conoscere",
    "conoscevi": "conoscere",
    "conoscevo": "conoscere",
    "conosci": "conoscere",
    "conosciamo": "conoscere",
    "conosciate": "conoscere",
    "conoscibili": "conoscibile",
    "conoscitiva": "conoscitivo",
    "conoscitive": "conoscitivo",
    "conoscitivi": "conoscitivo",
    "conoscitori": "conoscitore",
    "conosciuta": "conosciuto",
    "conosciute": "conosciuto",
    "conosciuti": "conosciuto",
    "conosciuto": "conoscere",
    "conosco": "conoscere",
    "conoscon": "conoscere",
    "conoscono": "conoscere",
    "conquida": "conquidere",
    "conquidan": "conquidere",
    "conquidano": "conquidere",
    "conquide": "conquidere",
    "conquidei": "conquidere",
    "conquidemmo": "conquidere",
    "conquidendo": "conquidere",
    "conquidente": "conquidere",
    "conquidenti": "conquidere",
    "conquider": "conquidere",
    "conquiderai": "conquidere",
    "conquideran": "conquidere",
    "conquideranno": "conquidere",
    "conquiderebbe": "conquidere",
    "conquiderebber": "conquidere",
    "conquiderebbero": "conquidere",
    "conquiderei": "conquidere",
    "conquideremmo": "conquidere",
    "conquideremo": "conquidere",
    "conquidereste": "conquidere",
    "conquideresti": "conquidere",
    "conquiderete": "conquidere",
    "conquideron": "conquidere",
    "conquiderono": "conquidere",
    "conquiderà": "conquidere",
    "conquiderò": "conquidere",
    "conquidesse": "conquidere",
    "conquidesser": "conquidere",
    "conquidessero": "conquidere",
    "conquidessi": "conquidere",
    "conquidessimo": "conquidere",
    "conquideste": "conquidere",
    "conquidesti": "conquidere",
    "conquidete": "conquidere",
    "conquideva": "conquidere",
    "conquidevamo": "conquidere",
    "conquidevan": "conquidere",
    "conquidevano": "conquidere",
    "conquidevate": "conquidere",
    "conquidevi": "conquidere",
    "conquidevo": "conquidere",
    "conquidi": "conquidere",
    "conquidiamo": "conquidere",
    "conquidiate": "conquidere",
    "conquido": "conquidere",
    "conquidon": "conquidere",
    "conquidono": "conquidere",
    "conquiduta": "conquidere",
    "conquidute": "conquidere",
    "conquiduti": "conquidere",
    "conquiduto": "conquidere",
    "conquidè": "conquidere",
    "conquista": "conquistare",
    "conquistai": "conquistare",
    "conquistammo": "conquistare",
    "conquistan": "conquistare",
    "conquistando": "conquistare",
    "conquistano": "conquistare",
    "conquistante": "conquistare",
    "conquistanti": "conquistare",
    "conquistar": "conquistare",
    "conquistaron": "conquistare",
    "conquistarono": "conquistare",
    "conquistasse": "conquistare",
    "conquistasser": "conquistare",
    "conquistassero": "conquistare",
    "conquistassi": "conquistare",
    "conquistassimo": "conquistare",
    "conquistaste": "conquistare",
    "conquistasti": "conquistare",
    "conquistata": "conquistare",
    "conquistate": "conquistare",
    "conquistati": "conquistare",
    "conquistato": "conquistare",
    "conquistatori": "conquistatore",
    "conquistava": "conquistare",
    "conquistavamo": "conquistare",
    "conquistavan": "conquistare",
    "conquistavano": "conquistare",
    "conquistavate": "conquistare",
    "conquistavi": "conquistare",
    "conquistavo": "conquistare",
    "conquiste": "conquista",
    "conquisterai": "conquistare",
    "conquisteran": "conquistare",
    "conquisteranno": "conquistare",
    "conquisterebbe": "conquistare",
    "conquisterebber": "conquistare",
    "conquisterebbero": "conquistare",
    "conquisterei": "conquistare",
    "conquisteremmo": "conquistare",
    "conquisteremo": "conquistare",
    "conquistereste": "conquistare",
    "conquisteresti": "conquistare",
    "conquisterete": "conquistare",
    "conquisterà": "conquistare",
    "conquisterò": "conquistare",
    "conquisti": "conquistare",
    "conquistiamo": "conquistare",
    "conquistiate": "conquistare",
    "conquistin": "conquistare",
    "conquistino": "conquistare",
    "conquisto": "conquistare",
    "conquistò": "conquistare",
    "conradiana": "conradiano",
    "conradiane": "conradiano",
    "conradiani": "conradiano",
    "consacra": "consacrare",
    "consacrai": "consacrare",
    "consacrammo": "consacrare",
    "consacran": "consacrare",
    "consacrando": "consacrare",
    "consacrano": "consacrare",
    "consacrante": "consacrare",
    "consacranti": "consacrare",
    "consacrar": "consacrare",
    "consacraron": "consacrare",
    "consacrarono": "consacrare",
    "consacrasse": "consacrare",
    "consacrasser": "consacrare",
    "consacrassero": "consacrare",
    "consacrassi": "consacrare",
    "consacrassimo": "consacrare",
    "consacraste": "consacrare",
    "consacrasti": "consacrare",
    "consacrata": "consacrare",
    "consacrate": "consacrare",
    "consacrati": "consacrare",
    "consacrato": "consacrare",
    "consacratori": "consacratorio",
    "consacratoria": "consacratorio",
    "consacratorie": "consacratorio",
    "consacrava": "consacrare",
    "consacravamo": "consacrare",
    "consacravan": "consacrare",
    "consacravano": "consacrare",
    "consacravate": "consacrare",
    "consacravi": "consacrare",
    "consacravo": "consacrare",
    "consacrazioni": "consacrazione",
    "consacrerai": "consacrare",
    "consacreran": "consacrare",
    "consacreranno": "consacrare",
    "consacrerebbe": "consacrare",
    "consacrerebber": "consacrare",
    "consacrerebbero": "consacrare",
    "consacrerei": "consacrare",
    "consacreremmo": "consacrare",
    "consacreremo": "consacrare",
    "consacrereste": "consacrare",
    "consacreresti": "consacrare",
    "consacrerete": "consacrare",
    "consacrerà": "consacrare",
    "consacrerò": "consacrare",
    "consacri": "consacrare",
    "consacriamo": "consacrare",
    "consacriate": "consacrare",
    "consacrin": "consacrare",
    "consacrino": "consacrare",
    "consacro": "consacrare",
    "consacrò": "consacrare",
    "consanguinea": "consanguineo",
    "consanguinee": "consanguineo",
    "consanguinei": "consanguineo",
    "consapevolezze": "consapevolezza",
    "consapevoli": "consapevole",
    "consce": "conscio",
    "consci": "conscio",
    "conscia": "conscio",
    "consecutiva": "consecutivo",
    "consecutive": "consecutivo",
    "consecutivi": "consecutivo",
    "consegna": "consegnare",
    "consegnai": "consegnare",
    "consegnammo": "consegnare",
    "consegnan": "consegnare",
    "consegnando": "consegnare",
    "consegnano": "consegnare",
    "consegnante": "consegnare",
    "consegnanti": "consegnare",
    "consegnar": "consegnare",
    "consegnaron": "consegnare",
    "consegnarono": "consegnare",
    "consegnasse": "consegnare",
    "consegnasser": "consegnare",
    "consegnassero": "consegnare",
    "consegnassi": "consegnare",
    "consegnassimo": "consegnare",
    "consegnaste": "consegnare",
    "consegnasti": "consegnare",
    "consegnata": "consegnare",
    "consegnate": "consegnare",
    "consegnati": "consegnare",
    "consegnato": "consegnare",
    "consegnava": "consegnare",
    "consegnavamo": "consegnare",
    "consegnavan": "consegnare",
    "consegnavano": "consegnare",
    "consegnavate": "consegnare",
    "consegnavi": "consegnare",
    "consegnavo": "consegnare",
    "consegne": "consegna",
    "consegnerai": "consegnare",
    "consegneran": "consegnare",
    "consegneranno": "consegnare",
    "consegnerebbe": "consegnare",
    "consegnerebber": "consegnare",
    "consegnerebbero": "consegnare",
    "consegnerei": "consegnare",
    "consegneremmo": "consegnare",
    "consegneremo": "consegnare",
    "consegnereste": "consegnare",
    "consegneresti": "consegnare",
    "consegnerete": "consegnare",
    "consegnerà": "consegnare",
    "consegnerò": "consegnare",
    "consegni": "consegnare",
    "consegniamo": "consegnare",
    "consegniate": "consegnare",
    "consegnin": "consegnare",
    "consegnino": "consegnare",
    "consegno": "consegnare",
    "consegnò": "consegnare",
    "consegua": "conseguire",
    "conseguan": "conseguire",
    "conseguano": "conseguire",
    "consegue": "conseguire",
    "conseguendo": "conseguire",
    "conseguente": "conseguire",
    "conseguenti": "conseguire",
    "conseguenze": "conseguenza",
    "consegui": "conseguire",
    "conseguiamo": "conseguire",
    "conseguiate": "conseguire",
    "conseguibili": "conseguibile",
    "conseguii": "conseguire",
    "conseguimenti": "conseguimento",
    "conseguimmo": "conseguire",
    "conseguir": "conseguire",
    "conseguirai": "conseguire",
    "conseguiran": "conseguire",
    "conseguiranno": "conseguire",
    "conseguirebbe": "conseguire",
    "conseguirebber": "conseguire",
    "conseguirebbero": "conseguire",
    "conseguirei": "conseguire",
    "conseguiremmo": "conseguire",
    "conseguiremo": "conseguire",
    "conseguireste": "conseguire",
    "conseguiresti": "conseguire",
    "conseguirete": "conseguire",
    "conseguiron": "conseguire",
    "conseguirono": "conseguire",
    "conseguirà": "conseguire",
    "conseguirò": "conseguire",
    "conseguisse": "conseguire",
    "conseguisser": "conseguire",
    "conseguissero": "conseguire",
    "conseguissi": "conseguire",
    "conseguissimo": "conseguire",
    "conseguiste": "conseguire",
    "conseguisti": "conseguire",
    "conseguita": "conseguire",
    "conseguite": "conseguire",
    "conseguiti": "conseguire",
    "conseguito": "conseguire",
    "conseguiva": "conseguire",
    "conseguivamo": "conseguire",
    "conseguivan": "conseguire",
    "conseguivano": "conseguire",
    "conseguivate": "conseguire",
    "conseguivi": "conseguire",
    "conseguivo": "conseguire",
    "conseguo": "conseguire",
    "conseguon": "conseguire",
    "conseguono": "conseguire",
    "conseguì": "conseguire",
    "consensi": "consenso",
    "consensuali": "consensuale",
    "consenta": "consentire",
    "consentan": "consentire",
    "consentano": "consentire",
    "consente": "consentire",
    "consentendo": "consentire",
    "consentente": "consentire",
    "consententi": "consentire",
    "consenti": "consentire",
    "consentiamo": "consentire",
    "consentiate": "consentire",
    "consentii": "consentire",
    "consentimmo": "consentire",
    "consentir": "consentire",
    "consentirai": "consentire",
    "consentiran": "consentire",
    "consentiranno": "consentire",
    "consentirebbe": "consentire",
    "consentirebber": "consentire",
    "consentirebbero": "consentire",
    "consentirei": "consentire",
    "consentiremmo": "consentire",
    "consentiremo": "consentire",
    "consentireste": "consentire",
    "consentiresti": "consentire",
    "consentirete": "consentire",
    "consentiron": "consentire",
    "consentirono": "consentire",
    "consentirà": "consentire",
    "consentirò": "consentire",
    "consentisse": "consentire",
    "consentisser": "consentire",
    "consentissero": "consentire",
    "consentissi": "consentire",
    "consentissimo": "consentire",
    "consentiste": "consentire",
    "consentisti": "consentire",
    "consentita": "consentire",
    "consentite": "consentire",
    "consentiti": "consentire",
    "consentito": "consentire",
    "consentiva": "consentire",
    "consentivamo": "consentire",
    "consentivan": "consentire",
    "consentivano": "consentire",
    "consentivate": "consentire",
    "consentivi": "consentire",
    "consentivo": "consentire",
    "consento": "consentire",
    "consenton": "consentire",
    "consentono": "consentire",
    "consentì": "consentire",
    "consenziente": "consentire",
    "consenzienti": "consenziente",
    "conserta": "conserto",
    "conserte": "conserto",
    "conserti": "conserto",
    "conserva": "conservare",
    "conservai": "conservare",
    "conservammo": "conservare",
    "conservan": "conservare",
    "conservando": "conservare",
    "conservano": "conservare",
    "conservante": "conservare",
    "conservanti": "conservare",
    "conservar": "conservare",
    "conservaron": "conservare",
    "conservarono": "conservare",
    "conservasse": "conservare",
    "conservasser": "conservare",
    "conservassero": "conservare",
    "conservassi": "conservare",
    "conservassimo": "conservare",
    "conservaste": "conservare",
    "conservasti": "conservare",
    "conservata": "conservare",
    "conservate": "conservare",
    "conservati": "conservare",
    "conservativa": "conservativo",
    "conservative": "conservativo",
    "conservativi": "conservativo",
    "conservato": "conservare",
    "conservatori": "conservatorio",
    "conservatorie": "conservatoria",
    "conservatorismi": "conservatorismo",
    "conservava": "conservare",
    "conservavamo": "conservare",
    "conservavan": "conservare",
    "conservavano": "conservare",
    "conservavate": "conservare",
    "conservavi": "conservare",
    "conservavo": "conservare",
    "conservazioni": "conservazione",
    "conserve": "conserva",
    "conserverai": "conservare",
    "conserveran": "conservare",
    "conserveranno": "conservare",
    "conserverebbe": "conservare",
    "conserverebber": "conservare",
    "conserverebbero": "conservare",
    "conserverei": "conservare",
    "conserveremmo": "conservare",
    "conserveremo": "conservare",
    "conservereste": "conservare",
    "conserveresti": "conservare",
    "conserverete": "conservare",
    "conserverà": "conservare",
    "conserverò": "conservare",
    "conservi": "conservare",
    "conserviamo": "conservare",
    "conserviate": "conservare",
    "conserviera": "conserviero",
    "conserviere": "conserviero",
    "conservieri": "conserviero",
    "conservin": "conservare",
    "conservino": "conservare",
    "conservo": "conservare",
    "conservò": "conservare",
    "consessi": "consesso",
    "considera": "considerare",
    "considerai": "considerare",
    "considerammo": "considerare",
    "consideran": "considerare",
    "considerando": "considerare",
    "considerano": "considerare",
    "considerante": "considerare",
    "consideranti": "considerare",
    "considerar": "considerare",
    "consideraron": "considerare",
    "considerarono": "considerare",
    "considerasse": "considerare",
    "considerasser": "considerare",
    "considerassero": "considerare",
    "considerassi": "considerare",
    "considerassimo": "considerare",
    "consideraste": "considerare",
    "considerasti": "considerare",
    "considerata": "considerato",
    "considerate": "considerato",
    "considerati": "considerato",
    "considerato": "considerare",
    "considerava": "considerare",
    "consideravamo": "considerare",
    "consideravan": "considerare",
    "consideravano": "considerare",
    "consideravate": "considerare",
    "consideravi": "considerare",
    "consideravo": "considerare",
    "considerazioni": "considerazione",
    "considererai": "considerare",
    "considereran": "considerare",
    "considereranno": "considerare",
    "considererebbe": "considerare",
    "considererebber": "considerare",
    "considererebbero": "considerare",
    "considererei": "considerare",
    "considereremmo": "considerare",
    "considereremo": "considerare",
    "considerereste": "considerare",
    "considereresti": "considerare",
    "considererete": "considerare",
    "considererà": "considerare",
    "considererò": "considerare",
    "considerevoli": "considerevole",
    "consideri": "considerare",
    "consideriamo": "considerare",
    "consideriate": "considerare",
    "considerin": "considerare",
    "considerino": "considerare",
    "considero": "considerare",
    "considerò": "considerare",
    "consigli": "consiglio",
    "consiglia": "consigliare",
    "consigliabili": "consigliabile",
    "consigliai": "consigliare",
    "consigliammo": "consigliare",
    "consigliamo": "consigliare",
    "consiglian": "consigliare",
    "consigliando": "consigliare",
    "consigliano": "consigliare",
    "consigliante": "consigliare",
    "consiglianti": "consigliare",
    "consigliar": "consigliare",
    "consigliaron": "consigliare",
    "consigliarono": "consigliare",
    "consigliasse": "consigliare",
    "consigliasser": "consigliare",
    "consigliassero": "consigliare",
    "consigliassi": "consigliare",
    "consigliassimo": "consigliare",
    "consigliaste": "consigliare",
    "consigliasti": "consigliare",
    "consigliata": "consigliare",
    "consigliate": "consigliare",
    "consigliati": "consigliare",
    "consigliato": "consigliare",
    "consigliava": "consigliare",
    "consigliavamo": "consigliare",
    "consigliavan": "consigliare",
    "consigliavano": "consigliare",
    "consigliavate": "consigliare",
    "consigliavi": "consigliare",
    "consigliavo": "consigliare",
    "consiglierai": "consigliare",
    "consiglieran": "consigliare",
    "consiglieranno": "consigliare",
    "consigliere": "consigliera",
    "consiglierebbe": "consigliare",
    "consiglierebber": "consigliare",
    "consiglierebbero": "consigliare",
    "consiglierei": "consigliare",
    "consiglieremmo": "consigliare",
    "consiglieremo": "consigliare",
    "consigliereste": "consigliare",
    "consiglieresti": "consigliare",
    "consiglierete": "consigliare",
    "consiglieri": "consigliere",
    "consiglierà": "consigliare",
    "consiglierò": "consigliare",
    "consiglin": "consigliare",
    "consiglino": "consigliare",
    "consiglio": "consigliare",
    "consigliò": "consigliare",
    "consili": "consiliare",
    "consilia": "consiliare",
    "consiliai": "consiliare",
    "consiliammo": "consiliare",
    "consiliamo": "consiliare",
    "consilian": "consiliare",
    "consiliando": "consiliare",
    "consiliano": "consiliare",
    "consiliante": "consiliare",
    "consilianti": "consiliare",
    "consiliar": "consiliare",
    "consiliari": "consiliare",
    "consiliaron": "consiliare",
    "consiliarono": "consiliare",
    "consiliasse": "consiliare",
    "consiliasser": "consiliare",
    "consiliassero": "consiliare",
    "consiliassi": "consiliare",
    "consiliassimo": "consiliare",
    "consiliaste": "consiliare",
    "consiliasti": "consiliare",
    "consiliata": "consiliare",
    "consiliate": "consiliare",
    "consiliati": "consiliare",
    "consiliato": "consiliare",
    "consiliava": "consiliare",
    "consiliavamo": "consiliare",
    "consiliavan": "consiliare",
    "consiliavano": "consiliare",
    "consiliavate": "consiliare",
    "consiliavi": "consiliare",
    "consiliavo": "consiliare",
    "consilierai": "consiliare",
    "consilieran": "consiliare",
    "consilieranno": "consiliare",
    "consilierebbe": "consiliare",
    "consilierebber": "consiliare",
    "consilierebbero": "consiliare",
    "consilierei": "consiliare",
    "consilieremmo": "consiliare",
    "consilieremo": "consiliare",
    "consiliereste": "consiliare",
    "consilieresti": "consiliare",
    "consilierete": "consiliare",
    "consilierà": "consiliare",
    "consilierò": "consiliare",
    "consilin": "consiliare",
    "consilino": "consiliare",
    "consilio": "consiliare",
    "consiliò": "consiliare",
    "consimili": "consimile",
    "consista": "consistere",
    "consistan": "consistere",
    "consistano": "consistere",
    "consiste": "consistere",
    "consistei": "consistere",
    "consistemmo": "consistere",
    "consistendo": "consistere",
    "consistente": "consistere",
    "consistenti": "consistere",
    "consistenze": "consistenza",
    "consister": "consistere",
    "consisterai": "consistere",
    "consisteran": "consistere",
    "consisteranno": "consistere",
    "consisterebbe": "consistere",
    "consisterebber": "consistere",
    "consisterebbero": "consistere",
    "consisterei": "consistere",
    "consisteremmo": "consistere",
    "consisteremo": "consistere",
    "consistereste": "consistere",
    "consisteresti": "consistere",
    "consisterete": "consistere",
    "consisterono": "consistere",
    "consisterà": "consistere",
    "consisterò": "consistere",
    "consistesse": "consistere",
    "consistesser": "consistere",
    "consistessero": "consistere",
    "consistessi": "consistere",
    "consistessimo": "consistere",
    "consisteste": "consistere",
    "consistesti": "consistere",
    "consistete": "consistere",
    "consisteva": "consistere",
    "consistevamo": "consistere",
    "consistevan": "consistere",
    "consistevano": "consistere",
    "consistevate": "consistere",
    "consistevi": "consistere",
    "consistevo": "consistere",
    "consisti": "consistere",
    "consistiamo": "consistere",
    "consistiate": "consistere",
    "consistita": "consistere",
    "consistite": "consistere",
    "consistiti": "consistere",
    "consistito": "consistere",
    "consisto": "consistere",
    "consiston": "consistere",
    "consistono": "consistere",
    "consistè": "consistere",
    "consocerai": "consociare",
    "consoceran": "consociare",
    "consoceranno": "consociare",
    "consocerebbe": "consociare",
    "consocerebber": "consociare",
    "consocerebbero": "consociare",
    "consocerei": "consociare",
    "consoceremmo": "consociare",
    "consoceremo": "consociare",
    "consocereste": "consociare",
    "consoceresti": "consociare",
    "consocerete": "consociare",
    "consocerà": "consociare",
    "consocerò": "consociare",
    "consoci": "consociare",
    "consocia": "consociare",
    "consociai": "consociare",
    "consociammo": "consociare",
    "consociamo": "consociare",
    "consocian": "consociare",
    "consociando": "consociare",
    "consociano": "consociare",
    "consociante": "consociare",
    "consocianti": "consociare",
    "consociar": "consociare",
    "consociaron": "consociare",
    "consociarono": "consociare",
    "consociasse": "consociare",
    "consociasser": "consociare",
    "consociassero": "consociare",
    "consociassi": "consociare",
    "consociassimo": "consociare",
    "consociaste": "consociare",
    "consociasti": "consociare",
    "consociata": "consociato",
    "consociate": "consociato",
    "consociati": "consociato",
    "consociativismi": "consociativismo",
    "consociato": "consociare",
    "consociava": "consociare",
    "consociavamo": "consociare",
    "consociavan": "consociare",
    "consociavano": "consociare",
    "consociavate": "consociare",
    "consociavi": "consociare",
    "consociavo": "consociare",
    "consociazioni": "consociazione",
    "consocin": "consociare",
    "consocino": "consociare",
    "consocio": "consociare",
    "consociò": "consociare",
    "consola": "consolare",
    "consolai": "consolare",
    "consolammo": "consolare",
    "consolan": "consolare",
    "consolando": "consolare",
    "consolano": "consolare",
    "consolante": "consolare",
    "consolanti": "consolare",
    "consolar": "consolare",
    "consolari": "consolare",
    "consolaron": "consolare",
    "consolarono": "consolare",
    "consolasse": "consolare",
    "consolasser": "consolare",
    "consolassero": "consolare",
    "consolassi": "consolare",
    "consolassimo": "consolare",
    "consolaste": "consolare",
    "consolasti": "consolare",
    "consolata": "consolare",
    "consolate": "consolare",
    "consolati": "consolato",
    "consolato": "consolare",
    "consolatori": "consolatorio",
    "consolatoria": "consolatorio",
    "consolatorie": "consolatorio",
    "consolatrice": "consolatore",
    "consolatrici": "consolatore",
    "consolava": "consolare",
    "consolavamo": "consolare",
    "consolavan": "consolare",
    "consolavano": "consolare",
    "consolavate": "consolare",
    "consolavi": "consolare",
    "consolavo": "consolare",
    "consolazioni": "consolazione",
    "consolerai": "consolare",
    "consoleran": "consolare",
    "consoleranno": "consolare",
    "consolerebbe": "consolare",
    "consolerebber": "consolare",
    "consolerebbero": "consolare",
    "consolerei": "consolare",
    "consoleremmo": "consolare",
    "consoleremo": "consolare",
    "consolereste": "consolare",
    "consoleresti": "consolare",
    "consolerete": "consolare",
    "consolerà": "consolare",
    "consolerò": "consolare",
    "consoli": "console",
    "consoliamo": "consolare",
    "consoliate": "consolare",
    "consolida": "consolidare",
    "consolidai": "consolidare",
    "consolidamenti": "consolidamento",
    "consolidammo": "consolidare",
    "consolidan": "consolidare",
    "consolidando": "consolidare",
    "consolidano": "consolidare",
    "consolidante": "consolidare",
    "consolidanti": "consolidare",
    "consolidar": "consolidare",
    "consolidaron": "consolidare",
    "consolidarono": "consolidare",
    "consolidasse": "consolidare",
    "consolidasser": "consolidare",
    "consolidassero": "consolidare",
    "consolidassi": "consolidare",
    "consolidassimo": "consolidare",
    "consolidaste": "consolidare",
    "consolidasti": "consolidare",
    "consolidata": "consolidato",
    "consolidate": "consolidato",
    "consolidati": "consolidato",
    "consolidato": "consolidare",
    "consolidava": "consolidare",
    "consolidavamo": "consolidare",
    "consolidavan": "consolidare",
    "consolidavano": "consolidare",
    "consolidavate": "consolidare",
    "consolidavi": "consolidare",
    "consolidavo": "consolidare",
    "consoliderai": "consolidare",
    "consolideran": "consolidare",
    "consolideranno": "consolidare",
    "consoliderebbe": "consolidare",
    "consoliderebber": "consolidare",
    "consoliderebbero": "consolidare",
    "consoliderei": "consolidare",
    "consolideremmo": "consolidare",
    "consolideremo": "consolidare",
    "consolidereste": "consolidare",
    "consolideresti": "consolidare",
    "consoliderete": "consolidare",
    "consoliderà": "consolidare",
    "consoliderò": "consolidare",
    "consolidi": "consolidare",
    "consolidiamo": "consolidare",
    "consolidiate": "consolidare",
    "consolidin": "consolidare",
    "consolidino": "consolidare",
    "consolido": "consolidare",
    "consolidò": "consolidare",
    "consolin": "consolare",
    "consolino": "consolare",
    "consolo": "consolare",
    "consolò": "consolare",
    "consona": "consono",
    "consonai": "consonare",
    "consonammo": "consonare",
    "consonan": "consonare",
    "consonando": "consonare",
    "consonano": "consonare",
    "consonante": "consonare",
    "consonanti": "consonare",
    "consonanze": "consonanza",
    "consonar": "consonare",
    "consonaron": "consonare",
    "consonarono": "consonare",
    "consonasse": "consonare",
    "consonasser": "consonare",
    "consonassero": "consonare",
    "consonassi": "consonare",
    "consonassimo": "consonare",
    "consonaste": "consonare",
    "consonasti": "consonare",
    "consonata": "consonare",
    "consonate": "consonare",
    "consonati": "consonare",
    "consonato": "consonare",
    "consonava": "consonare",
    "consonavamo": "consonare",
    "consonavan": "consonare",
    "consonavano": "consonare",
    "consonavate": "consonare",
    "consonavi": "consonare",
    "consonavo": "consonare",
    "consone": "consono",
    "consonerai": "consonare",
    "consoneran": "consonare",
    "consoneranno": "consonare",
    "consonerebbe": "consonare",
    "consonerebber": "consonare",
    "consonerebbero": "consonare",
    "consonerei": "consonare",
    "consoneremmo": "consonare",
    "consoneremo": "consonare",
    "consonereste": "consonare",
    "consoneresti": "consonare",
    "consonerete": "consonare",
    "consonerà": "consonare",
    "consonerò": "consonare",
    "consoni": "consono",
    "consoniamo": "consonare",
    "consoniate": "consonare",
    "consonin": "consonare",
    "consonino": "consonare",
    "consono": "consonare",
    "consonò": "consonare",
    "consorelle": "consorella",
    "consorterie": "consorteria",
    "consorti": "consorte",
    "consortili": "consortile",
    "consorzi": "consorzio",
    "consorzia": "consorziare",
    "consorziai": "consorziare",
    "consorziammo": "consorziare",
    "consorziamo": "consorziare",
    "consorzian": "consorziare",
    "consorziando": "consorziare",
    "consorziano": "consorziare",
    "consorziante": "consorziare",
    "consorzianti": "consorziare",
    "consorziar": "consorziare",
    "consorziaron": "consorziare",
    "consorziarono": "consorziare",
    "consorziasse": "consorziare",
    "consorziasser": "consorziare",
    "consorziassero": "consorziare",
    "consorziassi": "consorziare",
    "consorziassimo": "consorziare",
    "consorziaste": "consorziare",
    "consorziasti": "consorziare",
    "consorziata": "consorziare",
    "consorziate": "consorziare",
    "consorziati": "consorziare",
    "consorziato": "consorziare",
    "consorziava": "consorziare",
    "consorziavamo": "consorziare",
    "consorziavan": "consorziare",
    "consorziavano": "consorziare",
    "consorziavate": "consorziare",
    "consorziavi": "consorziare",
    "consorziavo": "consorziare",
    "consorzierai": "consorziare",
    "consorzieran": "consorziare",
    "consorzieranno": "consorziare",
    "consorzierebbe": "consorziare",
    "consorzierebber": "consorziare",
    "consorzierebbero": "consorziare",
    "consorzierei": "consorziare",
    "consorzieremmo": "consorziare",
    "consorzieremo": "consorziare",
    "consorziereste": "consorziare",
    "consorzieresti": "consorziare",
    "consorzierete": "consorziare",
    "consorzierà": "consorziare",
    "consorzierò": "consorziare",
    "consorzin": "consorziare",
    "consorzino": "consorziare",
    "consorzio": "consorziare",
    "consorziò": "consorziare",
    "consta": "constare",
    "constai": "constare",
    "constammo": "constare",
    "constan": "constare",
    "constando": "constare",
    "constano": "constare",
    "constante": "constare",
    "constanti": "constare",
    "constar": "constare",
    "constaron": "constare",
    "constarono": "constare",
    "constasse": "constare",
    "constasser": "constare",
    "constassero": "constare",
    "constassi": "constare",
    "constassimo": "constare",
    "constaste": "constare",
    "constasti": "constare",
    "constata": "constatare",
    "constatai": "constatare",
    "constatammo": "constatare",
    "constatan": "constatare",
    "constatando": "constatare",
    "constatano": "constatare",
    "constatante": "constatare",
    "constatanti": "constatare",
    "constatar": "constatare",
    "constataron": "constatare",
    "constatarono": "constatare",
    "constatasse": "constatare",
    "constatasser": "constatare",
    "constatassero": "constatare",
    "constatassi": "constatare",
    "constatassimo": "constatare",
    "constataste": "constatare",
    "constatasti": "constatare",
    "constatata": "constatare",
    "constatate": "constatare",
    "constatati": "constatare",
    "constatato": "constatare",
    "constatava": "constatare",
    "constatavamo": "constatare",
    "constatavan": "constatare",
    "constatavano": "constatare",
    "constatavate": "constatare",
    "constatavi": "constatare",
    "constatavo": "constatare",
    "constatazioni": "constatazione",
    "constate": "constare",
    "constaterai": "constatare",
    "constateran": "constatare",
    "constateranno": "constatare",
    "constaterebbe": "constatare",
    "constaterebber": "constatare",
    "constaterebbero": "constatare",
    "constaterei": "constatare",
    "constateremmo": "constatare",
    "constateremo": "constatare",
    "constatereste": "constatare",
    "constateresti": "constatare",
    "constaterete": "constatare",
    "constaterà": "constatare",
    "constaterò": "constatare",
    "constati": "constatare",
    "constatiamo": "constatare",
    "constatiate": "constatare",
    "constatin": "constatare",
    "constatino": "constatare",
    "constato": "constatare",
    "constatò": "constatare",
    "constava": "constare",
    "constavamo": "constare",
    "constavan": "constare",
    "constavano": "constare",
    "constavate": "constare",
    "constavi": "constare",
    "constavo": "constare",
    "consterai": "constare",
    "consteran": "constare",
    "consteranno": "constare",
    "consterebbe": "constare",
    "consterebber": "constare",
    "consterebbero": "constare",
    "consterei": "constare",
    "consteremmo": "constare",
    "consteremo": "constare",
    "constereste": "constare",
    "consteresti": "constare",
    "consterete": "constare",
    "consterà": "constare",
    "consterò": "constare",
    "consti": "constare",
    "constiamo": "constare",
    "constiate": "constare",
    "constin": "constare",
    "constino": "constare",
    "consto": "constare",
    "constò": "constare",
    "consueta": "consueto",
    "consuete": "consueto",
    "consueti": "consueto",
    "consuetudini": "consuetudine",
    "consulenti": "consulente",
    "consulenze": "consulenza",
    "consulta": "consultare",
    "consultabili": "consultabile",
    "consultai": "consultare",
    "consultammo": "consultare",
    "consultan": "consultare",
    "consultando": "consultare",
    "consultano": "consultare",
    "consultante": "consultare",
    "consultanti": "consultare",
    "consultar": "consultare",
    "consultaron": "consultare",
    "consultarono": "consultare",
    "consultasse": "consultare",
    "consultasser": "consultare",
    "consultassero": "consultare",
    "consultassi": "consultare",
    "consultassimo": "consultare",
    "consultaste": "consultare",
    "consultasti": "consultare",
    "consultata": "consultare",
    "consultate": "consultare",
    "consultati": "consultare",
    "consultato": "consultare",
    "consultava": "consultare",
    "consultavamo": "consultare",
    "consultavan": "consultare",
    "consultavano": "consultare",
    "consultavate": "consultare",
    "consultavi": "consultare",
    "consultavo": "consultare",
    "consultazioni": "consultazione",
    "consulte": "consulta",
    "consulterai": "consultare",
    "consulteran": "consultare",
    "consulteranno": "consultare",
    "consulterebbe": "consultare",
    "consulterebber": "consultare",
    "consulterebbero": "consultare",
    "consulterei": "consultare",
    "consulteremmo": "consultare",
    "consulteremo": "consultare",
    "consultereste": "consultare",
    "consulteresti": "consultare",
    "consulterete": "consultare",
    "consulterà": "consultare",
    "consulterò": "consultare",
    "consulti": "consulto",
    "consultiamo": "consultare",
    "consultiate": "consultare",
    "consultin": "consultare",
    "consultino": "consultare",
    "consultiva": "consultivo",
    "consultive": "consultivo",
    "consultivi": "consultivo",
    "consulto": "consultare",
    "consultori": "consultorio",
    "consultoria": "consultorio",
    "consultorie": "consultorio",
    "consultò": "consultare",
    "consuma": "consumere",
    "consumabili": "consumabile",
    "consumai": "consumare",
    "consumammo": "consumare",
    "consuman": "consumere",
    "consumando": "consumare",
    "consumano": "consumere",
    "consumante": "consumare",
    "consumanti": "consumare",
    "consumar": "consumare",
    "consumaron": "consumare",
    "consumarono": "consumare",
    "consumasse": "consumare",
    "consumasser": "consumare",
    "consumassero": "consumare",
    "consumassi": "consumare",
    "consumassimo": "consumare",
    "consumaste": "consumare",
    "consumasti": "consumare",
    "consumata": "consumato",
    "consumate": "consumato",
    "consumati": "consumato",
    "consumato": "consumare",
    "consumatori": "consumatore",
    "consumatrice": "consumatore",
    "consumatrici": "consumatrice",
    "consumava": "consumare",
    "consumavamo": "consumare",
    "consumavan": "consumare",
    "consumavano": "consumare",
    "consumavate": "consumare",
    "consumavi": "consumare",
    "consumavo": "consumare",
    "consumazioni": "consumazione",
    "consume": "consumere",
    "consumei": "consumere",
    "consumemmo": "consumere",
    "consumendo": "consumere",
    "consumente": "consumere",
    "consumenti": "consumere",
    "consumer": "consumere",
    "consumerai": "consumere",
    "consumeran": "consumere",
    "consumeranno": "consumere",
    "consumerebbe": "consumere",
    "consumerebber": "consumere",
    "consumerebbero": "consumere",
    "consumerei": "consumere",
    "consumeremmo": "consumere",
    "consumeremo": "consumere",
    "consumereste": "consumere",
    "consumeresti": "consumere",
    "consumerete": "consumere",
    "consumeron": "consumere",
    "consumerono": "consumere",
    "consumerà": "consumere",
    "consumerò": "consumere",
    "consumesse": "consumere",
    "consumesser": "consumere",
    "consumessero": "consumere",
    "consumessi": "consumere",
    "consumessimo": "consumere",
    "consumeste": "consumere",
    "consumesti": "consumere",
    "consumete": "consumere",
    "consumeva": "consumere",
    "consumevamo": "consumere",
    "consumevan": "consumere",
    "consumevano": "consumere",
    "consumevate": "consumere",
    "consumevi": "consumere",
    "consumevo": "consumere",
    "consumi": "consumo",
    "consumiamo": "consumere",
    "consumiate": "consumere",
    "consumin": "consumare",
    "consumino": "consumare",
    "consumismi": "consumismo",
    "consumiste": "consumista",
    "consumisti": "consumista",
    "consumistica": "consumistico",
    "consumistiche": "consumistico",
    "consumistici": "consumistico",
    "consumo": "consumere",
    "consumon": "consumere",
    "consumono": "consumere",
    "consumuta": "consumere",
    "consumute": "consumere",
    "consumuti": "consumere",
    "consumuto": "consumere",
    "consumè": "consumere",
    "consumò": "consumare",
    "consunta": "consunto",
    "consunte": "consunto",
    "consunti": "consunto",
    "consuntiva": "consuntivo",
    "consuntive": "consuntivo",
    "consuntivi": "consuntivo",
    "consunzioni": "consunzione",
    "consustanziali": "consustanziale",
    "conta": "contare",
    "contabili": "contabile",
    "contabilizza": "contabilizzare",
    "contabilizzai": "contabilizzare",
    "contabilizzammo": "contabilizzare",
    "contabilizzan": "contabilizzare",
    "contabilizzando": "contabilizzare",
    "contabilizzano": "contabilizzare",
    "contabilizzante": "contabilizzare",
    "contabilizzanti": "contabilizzare",
    "contabilizzar": "contabilizzare",
    "contabilizzaron": "contabilizzare",
    "contabilizzarono": "contabilizzare",
    "contabilizzasse": "contabilizzare",
    "contabilizzasser": "contabilizzare",
    "contabilizzassero": "contabilizzare",
    "contabilizzassi": "contabilizzare",
    "contabilizzassimo": "contabilizzare",
    "contabilizzaste": "contabilizzare",
    "contabilizzasti": "contabilizzare",
    "contabilizzata": "contabilizzare",
    "contabilizzate": "contabilizzare",
    "contabilizzati": "contabilizzare",
    "contabilizzato": "contabilizzare",
    "contabilizzava": "contabilizzare",
    "contabilizzavamo": "contabilizzare",
    "contabilizzavan": "contabilizzare",
    "contabilizzavano": "contabilizzare",
    "contabilizzavate": "contabilizzare",
    "contabilizzavi": "contabilizzare",
    "contabilizzavo": "contabilizzare",
    "contabilizzazioni": "contabilizzazione",
    "contabilizzerai": "contabilizzare",
    "contabilizzeran": "contabilizzare",
    "contabilizzeranno": "contabilizzare",
    "contabilizzerebbe": "contabilizzare",
    "contabilizzerebber": "contabilizzare",
    "contabilizzerebbero": "contabilizzare",
    "contabilizzerei": "contabilizzare",
    "contabilizzeremmo": "contabilizzare",
    "contabilizzeremo": "contabilizzare",
    "contabilizzereste": "contabilizzare",
    "contabilizzeresti": "contabilizzare",
    "contabilizzerete": "contabilizzare",
    "contabilizzerà": "contabilizzare",
    "contabilizzerò": "contabilizzare",
    "contabilizzi": "contabilizzare",
    "contabilizziamo": "contabilizzare",
    "contabilizziate": "contabilizzare",
    "contabilizzin": "contabilizzare",
    "contabilizzino": "contabilizzare",
    "contabilizzo": "contabilizzare",
    "contabilizzò": "contabilizzare",
    "contadina": "contadino",
    "contadine": "contadino",
    "contadini": "contadino",
    "contagerai": "contagiare",
    "contageran": "contagiare",
    "contageranno": "contagiare",
    "contagerebbe": "contagiare",
    "contagerebber": "contagiare",
    "contagerebbero": "contagiare",
    "contagerei": "contagiare",
    "contageremmo": "contagiare",
    "contageremo": "contagiare",
    "contagereste": "contagiare",
    "contageresti": "contagiare",
    "contagerete": "contagiare",
    "contagerà": "contagiare",
    "contagerò": "contagiare",
    "contagi": "contagio",
    "contagia": "contagiare",
    "contagiai": "contagiare",
    "contagiammo": "contagiare",
    "contagiamo": "contagiare",
    "contagian": "contagiare",
    "contagiando": "contagiare",
    "contagiano": "contagiare",
    "contagiante": "contagiare",
    "contagianti": "contagiare",
    "contagiar": "contagiare",
    "contagiaron": "contagiare",
    "contagiarono": "contagiare",
    "contagiasse": "contagiare",
    "contagiasser": "contagiare",
    "contagiassero": "contagiare",
    "contagiassi": "contagiare",
    "contagiassimo": "contagiare",
    "contagiaste": "contagiare",
    "contagiasti": "contagiare",
    "contagiata": "contagiare",
    "contagiate": "contagiare",
    "contagiati": "contagiare",
    "contagiato": "contagiare",
    "contagiava": "contagiare",
    "contagiavamo": "contagiare",
    "contagiavan": "contagiare",
    "contagiavano": "contagiare",
    "contagiavate": "contagiare",
    "contagiavi": "contagiare",
    "contagiavo": "contagiare",
    "contagin": "contagiare",
    "contagino": "contagiare",
    "contagio": "contagiare",
    "contagiosa": "contagioso",
    "contagiose": "contagioso",
    "contagiosi": "contagioso",
    "contagiò": "contagiare",
    "contai": "contare",
    "containers": "container",
    "contamina": "contaminare",
    "contaminai": "contaminare",
    "contaminammo": "contaminare",
    "contaminan": "contaminare",
    "contaminando": "contaminare",
    "contaminano": "contaminare",
    "contaminante": "contaminare",
    "contaminanti": "contaminare",
    "contaminar": "contaminare",
    "contaminaron": "contaminare",
    "contaminarono": "contaminare",
    "contaminasse": "contaminare",
    "contaminasser": "contaminare",
    "contaminassero": "contaminare",
    "contaminassi": "contaminare",
    "contaminassimo": "contaminare",
    "contaminaste": "contaminare",
    "contaminasti": "contaminare",
    "contaminata": "contaminare",
    "contaminate": "contaminare",
    "contaminati": "contaminare",
    "contaminato": "contaminare",
    "contaminava": "contaminare",
    "contaminavamo": "contaminare",
    "contaminavan": "contaminare",
    "contaminavano": "contaminare",
    "contaminavate": "contaminare",
    "contaminavi": "contaminare",
    "contaminavo": "contaminare",
    "contaminazioni": "contaminazione",
    "contaminerai": "contaminare",
    "contamineran": "contaminare",
    "contamineranno": "contaminare",
    "contaminerebbe": "contaminare",
    "contaminerebber": "contaminare",
    "contaminerebbero": "contaminare",
    "contaminerei": "contaminare",
    "contamineremmo": "contaminare",
    "contamineremo": "contaminare",
    "contaminereste": "contaminare",
    "contamineresti": "contaminare",
    "contaminerete": "contaminare",
    "contaminerà": "contaminare",
    "contaminerò": "contaminare",
    "contamini": "contaminare",
    "contaminiamo": "contaminare",
    "contaminiate": "contaminare",
    "contaminin": "contaminare",
    "contaminino": "contaminare",
    "contamino": "contaminare",
    "contaminò": "contaminare",
    "contammo": "contare",
    "contan": "contare",
    "contando": "contare",
    "contano": "contare",
    "contante": "contare",
    "contanti": "contare",
    "contar": "contare",
    "contaron": "contare",
    "contarono": "contare",
    "contasse": "contare",
    "contasser": "contare",
    "contassero": "contare",
    "contassi": "contare",
    "contassimo": "contare",
    "contaste": "contare",
    "contasti": "contare",
    "contata": "contato",
    "contate": "contato",
    "contati": "contato",
    "contato": "contare",
    "contatori": "contatore",
    "contatta": "contattare",
    "contattai": "contattare",
    "contattammo": "contattare",
    "contattan": "contattare",
    "contattando": "contattare",
    "contattano": "contattare",
    "contattante": "contattare",
    "contattanti": "contattare",
    "contattar": "contattare",
    "contattaron": "contattare",
    "contattarono": "contattare",
    "contattasse": "contattare",
    "contattasser": "contattare",
    "contattassero": "contattare",
    "contattassi": "contattare",
    "contattassimo": "contattare",
    "contattaste": "contattare",
    "contattasti": "contattare",
    "contattata": "contattare",
    "contattate": "contattare",
    "contattati": "contattare",
    "contattato": "contattare",
    "contattava": "contattare",
    "contattavamo": "contattare",
    "contattavan": "contattare",
    "contattavano": "contattare",
    "contattavate": "contattare",
    "contattavi": "contattare",
    "contattavo": "contattare",
    "contatterai": "contattare",
    "contatteran": "contattare",
    "contatteranno": "contattare",
    "contatterebbe": "contattare",
    "contatterebber": "contattare",
    "contatterebbero": "contattare",
    "contatterei": "contattare",
    "contatteremmo": "contattare",
    "contatteremo": "contattare",
    "contattereste": "contattare",
    "contatteresti": "contattare",
    "contatterete": "contattare",
    "contatterà": "contattare",
    "contatterò": "contattare",
    "contatti": "contatto",
    "contattiamo": "contattare",
    "contattiate": "contattare",
    "contattin": "contattare",
    "contattino": "contattare",
    "contatto": "contattare",
    "contattò": "contattare",
    "contava": "contare",
    "contavamo": "contare",
    "contavan": "contare",
    "contavano": "contare",
    "contavate": "contare",
    "contavi": "contare",
    "contavo": "contare",
    "conte": "conta",
    "contee": "contea",
    "conteggerai": "conteggiare",
    "conteggeran": "conteggiare",
    "conteggeranno": "conteggiare",
    "conteggerebbe": "conteggiare",
    "conteggerebber": "conteggiare",
    "conteggerebbero": "conteggiare",
    "conteggerei": "conteggiare",
    "conteggeremmo": "conteggiare",
    "conteggeremo": "conteggiare",
    "conteggereste": "conteggiare",
    "conteggeresti": "conteggiare",
    "conteggerete": "conteggiare",
    "conteggerà": "conteggiare",
    "conteggerò": "conteggiare",
    "conteggi": "conteggio",
    "conteggia": "conteggiare",
    "conteggiai": "conteggiare",
    "conteggiammo": "conteggiare",
    "conteggiamo": "conteggiare",
    "conteggian": "conteggiare",
    "conteggiando": "conteggiare",
    "conteggiano": "conteggiare",
    "conteggiante": "conteggiare",
    "conteggianti": "conteggiare",
    "conteggiar": "conteggiare",
    "conteggiaron": "conteggiare",
    "conteggiarono": "conteggiare",
    "conteggiasse": "conteggiare",
    "conteggiasser": "conteggiare",
    "conteggiassero": "conteggiare",
    "conteggiassi": "conteggiare",
    "conteggiassimo": "conteggiare",
    "conteggiaste": "conteggiare",
    "conteggiasti": "conteggiare",
    "conteggiata": "conteggiare",
    "conteggiate": "conteggiare",
    "conteggiati": "conteggiare",
    "conteggiato": "conteggiare",
    "conteggiava": "conteggiare",
    "conteggiavamo": "conteggiare",
    "conteggiavan": "conteggiare",
    "conteggiavano": "conteggiare",
    "conteggiavate": "conteggiare",
    "conteggiavi": "conteggiare",
    "conteggiavo": "conteggiare",
    "conteggin": "conteggiare",
    "conteggino": "conteggiare",
    "conteggio": "conteggiare",
    "conteggiò": "conteggiare",
    "contegni": "contegno",
    "contempera": "contemperare",
    "contemperai": "contemperare",
    "contemperammo": "contemperare",
    "contemperan": "contemperare",
    "contemperando": "contemperare",
    "contemperano": "contemperare",
    "contemperante": "contemperare",
    "contemperanti": "contemperare",
    "contemperar": "contemperare",
    "contemperaron": "contemperare",
    "contemperarono": "contemperare",
    "contemperasse": "contemperare",
    "contemperasser": "contemperare",
    "contemperassero": "contemperare",
    "contemperassi": "contemperare",
    "contemperassimo": "contemperare",
    "contemperaste": "contemperare",
    "contemperasti": "contemperare",
    "contemperata": "contemperare",
    "contemperate": "contemperare",
    "contemperati": "contemperare",
    "contemperato": "contemperare",
    "contemperava": "contemperare",
    "contemperavamo": "contemperare",
    "contemperavan": "contemperare",
    "contemperavano": "contemperare",
    "contemperavate": "contemperare",
    "contemperavi": "contemperare",
    "contemperavo": "contemperare",
    "contempererai": "contemperare",
    "contempereran": "contemperare",
    "contempereranno": "contemperare",
    "contempererebbe": "contemperare",
    "contempererebber": "contemperare",
    "contempererebbero": "contemperare",
    "contempererei": "contemperare",
    "contempereremmo": "contemperare",
    "contempereremo": "contemperare",
    "contemperereste": "contemperare",
    "contempereresti": "contemperare",
    "contempererete": "contemperare",
    "contempererà": "contemperare",
    "contempererò": "contemperare",
    "contemperi": "contemperare",
    "contemperiamo": "contemperare",
    "contemperiate": "contemperare",
    "contemperin": "contemperare",
    "contemperino": "contemperare",
    "contempero": "contemperare",
    "contemperò": "contemperare",
    "contempla": "contemplare",
    "contemplai": "contemplare",
    "contemplammo": "contemplare",
    "contemplan": "contemplare",
    "contemplando": "contemplare",
    "contemplano": "contemplare",
    "contemplante": "contemplare",
    "contemplanti": "contemplare",
    "contemplar": "contemplare",
    "contemplaron": "contemplare",
    "contemplarono": "contemplare",
    "contemplasse": "contemplare",
    "contemplasser": "contemplare",
    "contemplassero": "contemplare",
    "contemplassi": "contemplare",
    "contemplassimo": "contemplare",
    "contemplaste": "contemplare",
    "contemplasti": "contemplare",
    "contemplata": "contemplare",
    "contemplate": "contemplare",
    "contemplati": "contemplare",
    "contemplativa": "contemplativo",
    "contemplative": "contemplativo",
    "contemplativi": "contemplativo",
    "contemplato": "contemplare",
    "contemplava": "contemplare",
    "contemplavamo": "contemplare",
    "contemplavan": "contemplare",
    "contemplavano": "contemplare",
    "contemplavate": "contemplare",
    "contemplavi": "contemplare",
    "contemplavo": "contemplare",
    "contemplazioni": "contemplazione",
    "contemplerai": "contemplare",
    "contempleran": "contemplare",
    "contempleranno": "contemplare",
    "contemplerebbe": "contemplare",
    "contemplerebber": "contemplare",
    "contemplerebbero": "contemplare",
    "contemplerei": "contemplare",
    "contempleremmo": "contemplare",
    "contempleremo": "contemplare",
    "contemplereste": "contemplare",
    "contempleresti": "contemplare",
    "contemplerete": "contemplare",
    "contemplerà": "contemplare",
    "contemplerò": "contemplare",
    "contempli": "contemplare",
    "contempliamo": "contemplare",
    "contempliate": "contemplare",
    "contemplin": "contemplare",
    "contemplino": "contemplare",
    "contemplo": "contemplare",
    "contemplò": "contemplare",
    "contemporanea": "contemporaneo",
    "contemporanee": "contemporaneo",
    "contemporanei": "contemporaneo",
    "contenda": "contendere",
    "contendan": "contendere",
    "contendano": "contendere",
    "contende": "contendere",
    "contendemmo": "contendere",
    "contendendo": "contendere",
    "contendente": "contendere",
    "contendenti": "contendere",
    "contender": "contendere",
    "contenderai": "contendere",
    "contenderan": "contendere",
    "contenderanno": "contendere",
    "contenderebbe": "contendere",
    "contenderebber": "contendere",
    "contenderebbero": "contendere",
    "contenderei": "contendere",
    "contenderemmo": "contendere",
    "contenderemo": "contendere",
    "contendereste": "contendere",
    "contenderesti": "contendere",
    "contenderete": "contendere",
    "contenderà": "contendere",
    "contenderò": "contendere",
    "contendesse": "contendere",
    "contendesser": "contendere",
    "contendessero": "contendere",
    "contendessi": "contendere",
    "contendessimo": "contendere",
    "contendeste": "contendere",
    "contendesti": "contendere",
    "contendete": "contendere",
    "contendeva": "contendere",
    "contendevamo": "contendere",
    "contendevan": "contendere",
    "contendevano": "contendere",
    "contendevate": "contendere",
    "contendevi": "contendere",
    "contendevo": "contendere",
    "contendi": "contendere",
    "contendiamo": "contendere",
    "contendiate": "contendere",
    "contendibili": "contendibile",
    "contendo": "contendere",
    "contendon": "contendere",
    "contendono": "contendere",
    "contenemmo": "contenere",
    "contenendo": "contenere",
    "contenente": "contenere",
    "contenenti": "contenere",
    "contener": "contenere",
    "contenesse": "contenere",
    "contenesser": "contenere",
    "contenessero": "contenere",
    "contenessi": "contenere",
    "contenessimo": "contenere",
    "conteneste": "contenere",
    "contenesti": "contenere",
    "contenete": "contenere",
    "conteneva": "contenere",
    "contenevamo": "contenere",
    "contenevan": "contenere",
    "contenevano": "contenere",
    "contenevate": "contenere",
    "contenevi": "contenere",
    "contenevo": "contenere",
    "contenga": "contenere",
    "contengan": "contenere",
    "contengano": "contenere",
    "contengo": "contenere",
    "contengon": "contenere",
    "contengono": "contenere",
    "conteniamo": "contenere",
    "conteniate": "contenere",
    "contenibili": "contenibile",
    "contenimenti": "contenimento",
    "contenitiva": "contenitivo",
    "contenitive": "contenitivo",
    "contenitivi": "contenitivo",
    "contenitori": "contenitore",
    "contenne": "contenere",
    "contenner": "contenere",
    "contennero": "contenere",
    "contenni": "contenere",
    "contenta": "contento",
    "contentai": "contentare",
    "contentammo": "contentare",
    "contentan": "contentare",
    "contentando": "contentare",
    "contentano": "contentare",
    "contentante": "contentare",
    "contentanti": "contentare",
    "contentar": "contentare",
    "contentaron": "contentare",
    "contentarono": "contentare",
    "contentasse": "contentare",
    "contentasser": "contentare",
    "contentassero": "contentare",
    "contentassi": "contentare",
    "contentassimo": "contentare",
    "contentaste": "contentare",
    "contentasti": "contentare",
    "contentata": "contentare",
    "contentate": "contentare",
    "contentati": "contentare",
    "contentato": "contentare",
    "contentava": "contentare",
    "contentavamo": "contentare",
    "contentavan": "contentare",
    "contentavano": "contentare",
    "contentavate": "contentare",
    "contentavi": "contentare",
    "contentavo": "contentare",
    "contente": "contento",
    "contenterai": "contentare",
    "contenteran": "contentare",
    "contenteranno": "contentare",
    "contenterebbe": "contentare",
    "contenterebber": "contentare",
    "contenterebbero": "contentare",
    "contenterei": "contentare",
    "contenteremmo": "contentare",
    "contenteremo": "contentare",
    "contentereste": "contentare",
    "contenteresti": "contentare",
    "contenterete": "contentare",
    "contenterà": "contentare",
    "contenterò": "contentare",
    "contentezze": "contentezza",
    "contenti": "contento",
    "contentiamo": "contentare",
    "contentiate": "contentare",
    "contentin": "contentare",
    "contentini": "contentino",
    "contentino": "contentare",
    "contento": "contentare",
    "contentò": "contentare",
    "contenuta": "contenuto",
    "contenute": "contenuto",
    "contenuti": "contenuto",
    "contenutistica": "contenutistico",
    "contenutistiche": "contenutistico",
    "contenutistici": "contenutistico",
    "contenuto": "contenere",
    "contenziosa": "contenzioso",
    "contenziose": "contenzioso",
    "contenziosi": "contenzioso",
    "conterai": "contare",
    "conteran": "contare",
    "conteranno": "contare",
    "conterebbe": "contare",
    "conterebber": "contare",
    "conterebbero": "contare",
    "conterei": "contare",
    "conteremmo": "contare",
    "conteremo": "contare",
    "contereste": "contare",
    "conteresti": "contare",
    "conterete": "contare",
    "conterrai": "contenere",
    "conterran": "contenere",
    "conterranea": "conterraneo",
    "conterranee": "conterraneo",
    "conterranei": "conterraneo",
    "conterranno": "contenere",
    "conterrebbe": "contenere",
    "conterrebber": "contenere",
    "conterrebbero": "contenere",
    "conterrei": "contenere",
    "conterremmo": "contenere",
    "conterremo": "contenere",
    "conterreste": "contenere",
    "conterresti": "contenere",
    "conterrete": "contenere",
    "conterrà": "contenere",
    "conterrò": "contenere",
    "conterà": "contare",
    "conterò": "contare",
    "contesa": "conteso",
    "contese": "conteso",
    "conteser": "contendere",
    "contesero": "contendere",
    "contesi": "conteso",
    "conteso": "contendere",
    "contessa": "contessere",
    "contessan": "contessere",
    "contessano": "contessere",
    "contesse": "contessere",
    "contessei": "contessere",
    "contessemmo": "contessere",
    "contessendo": "contessere",
    "contessente": "contessere",
    "contessenti": "contessere",
    "contesser": "contessere",
    "contesserai": "contessere",
    "contesseran": "contessere",
    "contesseranno": "contessere",
    "contesserebbe": "contessere",
    "contesserebber": "contessere",
    "contesserebbero": "contessere",
    "contesserei": "contessere",
    "contesseremmo": "contessere",
    "contesseremo": "contessere",
    "contessereste": "contessere",
    "contesseresti": "contessere",
    "contesserete": "contessere",
    "contesseron": "contessere",
    "contesserono": "contessere",
    "contesserà": "contessere",
    "contesserò": "contessere",
    "contessesse": "contessere",
    "contessesser": "contessere",
    "contessessero": "contessere",
    "contessessi": "contessere",
    "contessessimo": "contessere",
    "contesseste": "contessere",
    "contessesti": "contessere",
    "contessete": "contessere",
    "contesseva": "contessere",
    "contessevamo": "contessere",
    "contessevan": "contessere",
    "contessevano": "contessere",
    "contessevate": "contessere",
    "contessevi": "contessere",
    "contessevo": "contessere",
    "contessi": "contessere",
    "contessiamo": "contessere",
    "contessiate": "contessere",
    "contesso": "contessere",
    "contesson": "contessere",
    "contessono": "contessere",
    "contessuta": "contessere",
    "contessute": "contessere",
    "contessuti": "contessere",
    "contessuto": "contessere",
    "contessè": "contessere",
    "contesta": "contesto",
    "contestabili": "contestabile",
    "contestai": "contestare",
    "contestammo": "contestare",
    "contestan": "contestare",
    "contestando": "contestare",
    "contestano": "contestare",
    "contestante": "contestare",
    "contestanti": "contestare",
    "contestar": "contestare",
    "contestaron": "contestare",
    "contestarono": "contestare",
    "contestasse": "contestare",
    "contestasser": "contestare",
    "contestassero": "contestare",
    "contestassi": "contestare",
    "contestassimo": "contestare",
    "contestaste": "contestare",
    "contestasti": "contestare",
    "contestata": "contestato",
    "contestatari": "contestatario",
    "contestataria": "contestatario",
    "contestatarie": "contestatario",
    "contestate": "contestato",
    "contestati": "contestato",
    "contestato": "contestare",
    "contestatori": "contestatore",
    "contestava": "contestare",
    "contestavamo": "contestare",
    "contestavan": "contestare",
    "contestavano": "contestare",
    "contestavate": "contestare",
    "contestavi": "contestare",
    "contestavo": "contestare",
    "contestazioni": "contestazione",
    "conteste": "contesto",
    "contesterai": "contestare",
    "contesteran": "contestare",
    "contesteranno": "contestare",
    "contesterebbe": "contestare",
    "contesterebber": "contestare",
    "contesterebbero": "contestare",
    "contesterei": "contestare",
    "contesteremmo": "contestare",
    "contesteremo": "contestare",
    "contestereste": "contestare",
    "contesteresti": "contestare",
    "contesterete": "contestare",
    "contesterà": "contestare",
    "contesterò": "contestare",
    "contesti": "contesto",
    "contestiamo": "contestare",
    "contestiate": "contestare",
    "contestin": "contestare",
    "contestino": "contestare",
    "contesto": "contestare",
    "contestuali": "contestuale",
    "contestualizza": "contestualizzare",
    "contestualizzai": "contestualizzare",
    "contestualizzammo": "contestualizzare",
    "contestualizzan": "contestualizzare",
    "contestualizzando": "contestualizzare",
    "contestualizzano": "contestualizzare",
    "contestualizzante": "contestualizzare",
    "contestualizzanti": "contestualizzare",
    "contestualizzar": "contestualizzare",
    "contestualizzaron": "contestualizzare",
    "contestualizzarono": "contestualizzare",
    "contestualizzasse": "contestualizzare",
    "contestualizzasser": "contestualizzare",
    "contestualizzassero": "contestualizzare",
    "contestualizzassi": "contestualizzare",
    "contestualizzassimo": "contestualizzare",
    "contestualizzaste": "contestualizzare",
    "contestualizzasti": "contestualizzare",
    "contestualizzata": "contestualizzare",
    "contestualizzate": "contestualizzare",
    "contestualizzati": "contestualizzare",
    "contestualizzato": "contestualizzare",
    "contestualizzava": "contestualizzare",
    "contestualizzavamo": "contestualizzare",
    "contestualizzavan": "contestualizzare",
    "contestualizzavano": "contestualizzare",
    "contestualizzavate": "contestualizzare",
    "contestualizzavi": "contestualizzare",
    "contestualizzavo": "contestualizzare",
    "contestualizzerai": "contestualizzare",
    "contestualizzeran": "contestualizzare",
    "contestualizzeranno": "contestualizzare",
    "contestualizzerebbe": "contestualizzare",
    "contestualizzerebber": "contestualizzare",
    "contestualizzerebbero": "contestualizzare",
    "contestualizzerei": "contestualizzare",
    "contestualizzeremmo": "contestualizzare",
    "contestualizzeremo": "contestualizzare",
    "contestualizzereste": "contestualizzare",
    "contestualizzeresti": "contestualizzare",
    "contestualizzerete": "contestualizzare",
    "contestualizzerà": "contestualizzare",
    "contestualizzerò": "contestualizzare",
    "contestualizzi": "contestualizzare",
    "contestualizziamo": "contestualizzare",
    "contestualizziate": "contestualizzare",
    "contestualizzin": "contestualizzare",
    "contestualizzino": "contestualizzare",
    "contestualizzo": "contestualizzare",
    "contestualizzò": "contestualizzare",
    "contestò": "contestare",
    "contesè": "contendere",
    "conti": "conto",
    "contiamo": "contare",
    "contiate": "contare",
    "contiene": "contenere",
    "contieni": "contenere",
    "contigenti": "contigente",
    "contigua": "contiguo",
    "contigue": "contiguo",
    "contigui": "contiguo",
    "contin": "contare",
    "continentali": "continentale",
    "continenti": "continente",
    "continenze": "continenza",
    "contingenta": "contingentare",
    "contingentai": "contingentare",
    "contingentamenti": "contingentamento",
    "contingentammo": "contingentare",
    "contingentan": "contingentare",
    "contingentando": "contingentare",
    "contingentano": "contingentare",
    "contingentante": "contingentare",
    "contingentanti": "contingentare",
    "contingentar": "contingentare",
    "contingentaron": "contingentare",
    "contingentarono": "contingentare",
    "contingentasse": "contingentare",
    "contingentasser": "contingentare",
    "contingentassero": "contingentare",
    "contingentassi": "contingentare",
    "contingentassimo": "contingentare",
    "contingentaste": "contingentare",
    "contingentasti": "contingentare",
    "contingentata": "contingentare",
    "contingentate": "contingentare",
    "contingentati": "contingentare",
    "contingentato": "contingentare",
    "contingentava": "contingentare",
    "contingentavamo": "contingentare",
    "contingentavan": "contingentare",
    "contingentavano": "contingentare",
    "contingentavate": "contingentare",
    "contingentavi": "contingentare",
    "contingentavo": "contingentare",
    "contingenterai": "contingentare",
    "contingenteran": "contingentare",
    "contingenteranno": "contingentare",
    "contingenterebbe": "contingentare",
    "contingenterebber": "contingentare",
    "contingenterebbero": "contingentare",
    "contingenterei": "contingentare",
    "contingenteremmo": "contingentare",
    "contingenteremo": "contingentare",
    "contingentereste": "contingentare",
    "contingenteresti": "contingentare",
    "contingenterete": "contingentare",
    "contingenterà": "contingentare",
    "contingenterò": "contingentare",
    "contingenti": "contingente",
    "contingentiamo": "contingentare",
    "contingentiate": "contingentare",
    "contingentin": "contingentare",
    "contingentino": "contingentare",
    "contingento": "contingentare",
    "contingentò": "contingentare",
    "contingenze": "contingenza",
    "continiana": "continiano",
    "continiane": "continiano",
    "continiani": "continiano",
    "contino": "contare",
    "continua": "continuo",
    "continuai": "continuare",
    "continuammo": "continuare",
    "continuan": "continuare",
    "continuando": "continuare",
    "continuano": "continuare",
    "continuante": "continuare",
    "continuanti": "continuare",
    "continuar": "continuare",
    "continuaron": "continuare",
    "continuarono": "continuare",
    "continuasse": "continuare",
    "continuasser": "continuare",
    "continuassero": "continuare",
    "continuassi": "continuare",
    "continuassimo": "continuare",
    "continuaste": "continuare",
    "continuasti": "continuare",
    "continuata": "continuato",
    "continuate": "continuato",
    "continuati": "continuato",
    "continuativa": "continuativo",
    "continuative": "continuativo",
    "continuativi": "continuativo",
    "continuato": "continuare",
    "continuatori": "continuatore",
    "continuava": "continuare",
    "continuavamo": "continuare",
    "continuavan": "continuare",
    "continuavano": "continuare",
    "continuavate": "continuare",
    "continuavi": "continuare",
    "continuavo": "continuare",
    "continuazioni": "continuazione",
    "continue": "continuo",
    "continuerai": "continuare",
    "continueran": "continuare",
    "continueranno": "continuare",
    "continuerebbe": "continuare",
    "continuerebber": "continuare",
    "continuerebbero": "continuare",
    "continuerei": "continuare",
    "continueremmo": "continuare",
    "continueremo": "continuare",
    "continuereste": "continuare",
    "continueresti": "continuare",
    "continuerete": "continuare",
    "continuerà": "continuare",
    "continuerò": "continuare",
    "continui": "continuo",
    "continuiamo": "continuare",
    "continuiate": "continuare",
    "continuin": "continuare",
    "continuino": "continuare",
    "continuismi": "continuismo",
    "continuo": "continuare",
    "continuua": "continuum",
    "continuò": "continuare",
    "contitola": "contitolare",
    "contitolai": "contitolare",
    "contitolammo": "contitolare",
    "contitolan": "contitolare",
    "contitolando": "contitolare",
    "contitolano": "contitolare",
    "contitolante": "contitolare",
    "contitolanti": "contitolare",
    "contitolar": "contitolare",
    "contitolari": "contitolare",
    "contitolaron": "contitolare",
    "contitolarono": "contitolare",
    "contitolasse": "contitolare",
    "contitolasser": "contitolare",
    "contitolassero": "contitolare",
    "contitolassi": "contitolare",
    "contitolassimo": "contitolare",
    "contitolaste": "contitolare",
    "contitolasti": "contitolare",
    "contitolata": "contitolare",
    "contitolate": "contitolare",
    "contitolati": "contitolare",
    "contitolato": "contitolare",
    "contitolava": "contitolare",
    "contitolavamo": "contitolare",
    "contitolavan": "contitolare",
    "contitolavano": "contitolare",
    "contitolavate": "contitolare",
    "contitolavi": "contitolare",
    "contitolavo": "contitolare",
    "contitolerai": "contitolare",
    "contitoleran": "contitolare",
    "contitoleranno": "contitolare",
    "contitolerebbe": "contitolare",
    "contitolerebber": "contitolare",
    "contitolerebbero": "contitolare",
    "contitolerei": "contitolare",
    "contitoleremmo": "contitolare",
    "contitoleremo": "contitolare",
    "contitolereste": "contitolare",
    "contitoleresti": "contitolare",
    "contitolerete": "contitolare",
    "contitolerà": "contitolare",
    "contitolerò": "contitolare",
    "contitoli": "contitolare",
    "contitoliamo": "contitolare",
    "contitoliate": "contitolare",
    "contitolin": "contitolare",
    "contitolino": "contitolare",
    "contitolo": "contitolare",
    "contitolò": "contitolare",
    "conto": "contare",
    "contorca": "contorcere",
    "contorcan": "contorcere",
    "contorcano": "contorcere",
    "contorce": "contorcere",
    "contorcemmo": "contorcere",
    "contorcendo": "contorcere",
    "contorcente": "contorcere",
    "contorcenti": "contorcere",
    "contorcer": "contorcere",
    "contorcerai": "contorcere",
    "contorceran": "contorcere",
    "contorceranno": "contorcere",
    "contorcerebbe": "contorcere",
    "contorcerebber": "contorcere",
    "contorcerebbero": "contorcere",
    "contorcerei": "contorcere",
    "contorceremmo": "contorcere",
    "contorceremo": "contorcere",
    "contorcereste": "contorcere",
    "contorceresti": "contorcere",
    "contorcerete": "contorcere",
    "contorcerà": "contorcere",
    "contorcerò": "contorcere",
    "contorcesse": "contorcere",
    "contorcesser": "contorcere",
    "contorcessero": "contorcere",
    "contorcessi": "contorcere",
    "contorcessimo": "contorcere",
    "contorceste": "contorcere",
    "contorcesti": "contorcere",
    "contorcete": "contorcere",
    "contorceva": "contorcere",
    "contorcevamo": "contorcere",
    "contorcevan": "contorcere",
    "contorcevano": "contorcere",
    "contorcevate": "contorcere",
    "contorcevi": "contorcere",
    "contorcevo": "contorcere",
    "contorci": "contorcere",
    "contorciamo": "contorcere",
    "contorciate": "contorcere",
    "contorcimenti": "contorcimento",
    "contorco": "contorcere",
    "contorcon": "contorcere",
    "contorcono": "contorcere",
    "contorna": "contornare",
    "contornai": "contornare",
    "contornammo": "contornare",
    "contornan": "contornare",
    "contornando": "contornare",
    "contornano": "contornare",
    "contornante": "contornare",
    "contornanti": "contornare",
    "contornar": "contornare",
    "contornaron": "contornare",
    "contornarono": "contornare",
    "contornasse": "contornare",
    "contornasser": "contornare",
    "contornassero": "contornare",
    "contornassi": "contornare",
    "contornassimo": "contornare",
    "contornaste": "contornare",
    "contornasti": "contornare",
    "contornata": "contornare",
    "contornate": "contornare",
    "contornati": "contornare",
    "contornato": "contornare",
    "contornava": "contornare",
    "contornavamo": "contornare",
    "contornavan": "contornare",
    "contornavano": "contornare",
    "contornavate": "contornare",
    "contornavi": "contornare",
    "contornavo": "contornare",
    "contornerai": "contornare",
    "contorneran": "contornare",
    "contorneranno": "contornare",
    "contornerebbe": "contornare",
    "contornerebber": "contornare",
    "contornerebbero": "contornare",
    "contornerei": "contornare",
    "contorneremmo": "contornare",
    "contorneremo": "contornare",
    "contornereste": "contornare",
    "contorneresti": "contornare",
    "contornerete": "contornare",
    "contornerà": "contornare",
    "contornerò": "contornare",
    "contorni": "contorno",
    "contorniamo": "contornare",
    "contorniate": "contornare",
    "contornin": "contornare",
    "contornino": "contornare",
    "contorno": "contornare",
    "contornò": "contornare",
    "contorse": "contorcere",
    "contorser": "contorcere",
    "contorsero": "contorcere",
    "contorsi": "contorcere",
    "contorsioni": "contorsione",
    "contorsionismi": "contorsionismo",
    "contorta": "contorto",
    "contorte": "contorto",
    "contorti": "contorto",
    "contorto": "contorcere",
    "contrabbanda": "contrabbandare",
    "contrabbandai": "contrabbandare",
    "contrabbandammo": "contrabbandare",
    "contrabbandan": "contrabbandare",
    "contrabbandando": "contrabbandare",
    "contrabbandano": "contrabbandare",
    "contrabbandante": "contrabbandare",
    "contrabbandanti": "contrabbandare",
    "contrabbandar": "contrabbandare",
    "contrabbandaron": "contrabbandare",
    "contrabbandarono": "contrabbandare",
    "contrabbandasse": "contrabbandare",
    "contrabbandasser": "contrabbandare",
    "contrabbandassero": "contrabbandare",
    "contrabbandassi": "contrabbandare",
    "contrabbandassimo": "contrabbandare",
    "contrabbandaste": "contrabbandare",
    "contrabbandasti": "contrabbandare",
    "contrabbandata": "contrabbandare",
    "contrabbandate": "contrabbandare",
    "contrabbandati": "contrabbandare",
    "contrabbandato": "contrabbandare",
    "contrabbandava": "contrabbandare",
    "contrabbandavamo": "contrabbandare",
    "contrabbandavan": "contrabbandare",
    "contrabbandavano": "contrabbandare",
    "contrabbandavate": "contrabbandare",
    "contrabbandavi": "contrabbandare",
    "contrabbandavo": "contrabbandare",
    "contrabbanderai": "contrabbandare",
    "contrabbanderan": "contrabbandare",
    "contrabbanderanno": "contrabbandare",
    "contrabbanderebbe": "contrabbandare",
    "contrabbanderebber": "contrabbandare",
    "contrabbanderebbero": "contrabbandare",
    "contrabbanderei": "contrabbandare",
    "contrabbanderemmo": "contrabbandare",
    "contrabbanderemo": "contrabbandare",
    "contrabbandereste": "contrabbandare",
    "contrabbanderesti": "contrabbandare",
    "contrabbanderete": "contrabbandare",
    "contrabbanderà": "contrabbandare",
    "contrabbanderò": "contrabbandare",
    "contrabbandi": "contrabbando",
    "contrabbandiamo": "contrabbandare",
    "contrabbandiate": "contrabbandare",
    "contrabbandieri": "contrabbandiere",
    "contrabbandin": "contrabbandare",
    "contrabbandino": "contrabbandare",
    "contrabbando": "contrabbandare",
    "contrabbandò": "contrabbandare",
    "contrabbassi": "contrabbasso",
    "contrabbassisti": "contrabbassista",
    "contraccambi": "contraccambiare",
    "contraccambia": "contraccambiare",
    "contraccambiai": "contraccambiare",
    "contraccambiammo": "contraccambiare",
    "contraccambiamo": "contraccambiare",
    "contraccambian": "contraccambiare",
    "contraccambiando": "contraccambiare",
    "contraccambiano": "contraccambiare",
    "contraccambiante": "contraccambiare",
    "contraccambianti": "contraccambiare",
    "contraccambiar": "contraccambiare",
    "contraccambiaron": "contraccambiare",
    "contraccambiarono": "contraccambiare",
    "contraccambiasse": "contraccambiare",
    "contraccambiasser": "contraccambiare",
    "contraccambiassero": "contraccambiare",
    "contraccambiassi": "contraccambiare",
    "contraccambiassimo": "contraccambiare",
    "contraccambiaste": "contraccambiare",
    "contraccambiasti": "contraccambiare",
    "contraccambiata": "contraccambiare",
    "contraccambiate": "contraccambiare",
    "contraccambiati": "contraccambiare",
    "contraccambiato": "contraccambiare",
    "contraccambiava": "contraccambiare",
    "contraccambiavamo": "contraccambiare",
    "contraccambiavan": "contraccambiare",
    "contraccambiavano": "contraccambiare",
    "contraccambiavate": "contraccambiare",
    "contraccambiavi": "contraccambiare",
    "contraccambiavo": "contraccambiare",
    "contraccambierai": "contraccambiare",
    "contraccambieran": "contraccambiare",
    "contraccambieranno": "contraccambiare",
    "contraccambierebbe": "contraccambiare",
    "contraccambierebber": "contraccambiare",
    "contraccambierebbero": "contraccambiare",
    "contraccambierei": "contraccambiare",
    "contraccambieremmo": "contraccambiare",
    "contraccambieremo": "contraccambiare",
    "contraccambiereste": "contraccambiare",
    "contraccambieresti": "contraccambiare",
    "contraccambierete": "contraccambiare",
    "contraccambierà": "contraccambiare",
    "contraccambierò": "contraccambiare",
    "contraccambin": "contraccambiare",
    "contraccambino": "contraccambiare",
    "contraccambio": "contraccambiare",
    "contraccambiò": "contraccambiare",
    "contraccettiva": "contraccettivo",
    "contraccettive": "contraccettivo",
    "contraccettivi": "contraccettivo",
    "contraccezioni": "contraccezione",
    "contraccolpi": "contraccolpo",
    "contradaioli": "contradaiolo",
    "contraddetta": "contraddire",
    "contraddette": "contraddire",
    "contraddetti": "contraddire",
    "contraddetto": "contraddire",
    "contraddica": "contraddire",
    "contraddican": "contraddire",
    "contraddicano": "contraddire",
    "contraddice": "contraddire",
    "contraddicemmo": "contraddire",
    "contraddicendo": "contraddire",
    "contraddicente": "contraddire",
    "contraddicenti": "contraddire",
    "contraddicesse": "contraddire",
    "contraddicesser": "contraddire",
    "contraddicessero": "contraddire",
    "contraddicessi": "contraddire",
    "contraddicessimo": "contraddire",
    "contraddiceste": "contraddire",
    "contraddicesti": "contraddire",
    "contraddiceva": "contraddire",
    "contraddicevamo": "contraddire",
    "contraddicevan": "contraddire",
    "contraddicevano": "contraddire",
    "contraddicevate": "contraddire",
    "contraddicevi": "contraddire",
    "contraddicevo": "contraddire",
    "contraddici": "contraddire",
    "contraddiciamo": "contraddire",
    "contraddiciate": "contraddire",
    "contraddico": "contraddire",
    "contraddicon": "contraddire",
    "contraddicono": "contraddire",
    "contraddir": "contraddire",
    "contraddirai": "contraddire",
    "contraddiran": "contraddire",
    "contraddiranno": "contraddire",
    "contraddirebbe": "contraddire",
    "contraddirebber": "contraddire",
    "contraddirebbero": "contraddire",
    "contraddirei": "contraddire",
    "contraddiremmo": "contraddire",
    "contraddiremo": "contraddire",
    "contraddireste": "contraddire",
    "contraddiresti": "contraddire",
    "contraddirete": "contraddire",
    "contraddirà": "contraddire",
    "contraddirò": "contraddire",
    "contraddisse": "contraddire",
    "contraddisser": "contraddire",
    "contraddissero": "contraddire",
    "contraddissi": "contraddire",
    "contraddistingua": "contraddistinguere",
    "contraddistinguan": "contraddistinguere",
    "contraddistinguano": "contraddistinguere",
    "contraddistingue": "contraddistinguere",
    "contraddistinguei": "contraddistinguere",
    "contraddistinguemmo": "contraddistinguere",
    "contraddistinguendo": "contraddistinguere",
    "contraddistinguente": "contraddistinguere",
    "contraddistinguenti": "contraddistinguere",
    "contraddistinguer": "contraddistinguere",
    "contraddistinguerai": "contraddistinguere",
    "contraddistingueran": "contraddistinguere",
    "contraddistingueranno": "contraddistinguere",
    "contraddistinguerebbe": "contraddistinguere",
    "contraddistinguerebber": "contraddistinguere",
    "contraddistinguerebbero": "contraddistinguere",
    "contraddistinguerei": "contraddistinguere",
    "contraddistingueremmo": "contraddistinguere",
    "contraddistingueremo": "contraddistinguere",
    "contraddistinguereste": "contraddistinguere",
    "contraddistingueresti": "contraddistinguere",
    "contraddistinguerete": "contraddistinguere",
    "contraddistingueron": "contraddistinguere",
    "contraddistinguerono": "contraddistinguere",
    "contraddistinguerà": "contraddistinguere",
    "contraddistinguerò": "contraddistinguere",
    "contraddistinguesse": "contraddistinguere",
    "contraddistinguesser": "contraddistinguere",
    "contraddistinguessero": "contraddistinguere",
    "contraddistinguessi": "contraddistinguere",
    "contraddistinguessimo": "contraddistinguere",
    "contraddistingueste": "contraddistinguere",
    "contraddistinguesti": "contraddistinguere",
    "contraddistinguete": "contraddistinguere",
    "contraddistingueva": "contraddistinguere",
    "contraddistinguevamo": "contraddistinguere",
    "contraddistinguevan": "contraddistinguere",
    "contraddistinguevano": "contraddistinguere",
    "contraddistinguevate": "contraddistinguere",
    "contraddistinguevi": "contraddistinguere",
    "contraddistinguevo": "contraddistinguere",
    "contraddistingui": "contraddistinguere",
    "contraddistinguiamo": "contraddistinguere",
    "contraddistinguiate": "contraddistinguere",
    "contraddistinguo": "contraddistinguere",
    "contraddistinguon": "contraddistinguere",
    "contraddistinguono": "contraddistinguere",
    "contraddistinguuta": "contraddistinguere",
    "contraddistinguute": "contraddistinguere",
    "contraddistinguuti": "contraddistinguere",
    "contraddistinguuto": "contraddistinguere",
    "contraddistinguè": "contraddistinguere",
    "contraddite": "contraddire",
    "contraddittori": "contraddittorio",
    "contraddittoria": "contraddittorio",
    "contraddittorie": "contraddittorio",
    "contraddizioni": "contraddizione",
    "contrade": "contrada",
    "contrae": "contrarre",
    "contraemmo": "contrarre",
    "contraendo": "contrarre",
    "contraente": "contrarre",
    "contraenti": "contrarre",
    "contraerea": "contraereo",
    "contraeree": "contraereo",
    "contraerei": "contraereo",
    "contraesse": "contrarre",
    "contraesser": "contrarre",
    "contraessero": "contrarre",
    "contraessi": "contrarre",
    "contraessimo": "contrarre",
    "contraeste": "contrarre",
    "contraesti": "contrarre",
    "contraete": "contrarre",
    "contraeva": "contrarre",
    "contraevamo": "contrarre",
    "contraevan": "contrarre",
    "contraevano": "contrarre",
    "contraevate": "contrarre",
    "contraevi": "contrarre",
    "contraevo": "contrarre",
    "contraffa": "contraffare",
    "contraffai": "contraffare",
    "contraffammo": "contraffare",
    "contraffan": "contraffare",
    "contraffando": "contraffare",
    "contraffano": "contraffare",
    "contraffante": "contraffare",
    "contraffanti": "contraffare",
    "contraffar": "contraffare",
    "contraffaron": "contraffare",
    "contraffarono": "contraffare",
    "contraffasse": "contraffare",
    "contraffasser": "contraffare",
    "contraffassero": "contraffare",
    "contraffassi": "contraffare",
    "contraffassimo": "contraffare",
    "contraffaste": "contraffare",
    "contraffasti": "contraffare",
    "contraffata": "contraffare",
    "contraffate": "contraffare",
    "contraffati": "contraffare",
    "contraffato": "contraffare",
    "contraffava": "contraffare",
    "contraffavamo": "contraffare",
    "contraffavan": "contraffare",
    "contraffavano": "contraffare",
    "contraffavate": "contraffare",
    "contraffavi": "contraffare",
    "contraffavo": "contraffare",
    "contraffazioni": "contraffazione",
    "contrafferai": "contraffare",
    "contrafferan": "contraffare",
    "contrafferanno": "contraffare",
    "contrafferebbe": "contraffare",
    "contrafferebber": "contraffare",
    "contrafferebbero": "contraffare",
    "contrafferei": "contraffare",
    "contrafferemmo": "contraffare",
    "contrafferemo": "contraffare",
    "contraffereste": "contraffare",
    "contrafferesti": "contraffare",
    "contrafferete": "contraffare",
    "contrafferà": "contraffare",
    "contrafferò": "contraffare",
    "contraffi": "contraffare",
    "contraffiamo": "contraffare",
    "contraffiate": "contraffare",
    "contraffin": "contraffare",
    "contraffino": "contraffare",
    "contraffo": "contraffare",
    "contrafforti": "contrafforte",
    "contraffò": "contraffare",
    "contragga": "contrarre",
    "contraggan": "contrarre",
    "contraggano": "contrarre",
    "contraggo": "contrarre",
    "contraggon": "contrarre",
    "contraggono": "contrarre",
    "contrai": "contrarre",
    "contraiamo": "contrarre",
    "contraiate": "contrarre",
    "contraltari": "contraltare",
    "contralti": "contralto",
    "contrammiragli": "contrammiraglio",
    "contrappassi": "contrappasso",
    "contrappesa": "contrappesare",
    "contrappesai": "contrappesare",
    "contrappesammo": "contrappesare",
    "contrappesan": "contrappesare",
    "contrappesando": "contrappesare",
    "contrappesano": "contrappesare",
    "contrappesante": "contrappesare",
    "contrappesanti": "contrappesare",
    "contrappesar": "contrappesare",
    "contrappesaron": "contrappesare",
    "contrappesarono": "contrappesare",
    "contrappesasse": "contrappesare",
    "contrappesasser": "contrappesare",
    "contrappesassero": "contrappesare",
    "contrappesassi": "contrappesare",
    "contrappesassimo": "contrappesare",
    "contrappesaste": "contrappesare",
    "contrappesasti": "contrappesare",
    "contrappesata": "contrappesare",
    "contrappesate": "contrappesare",
    "contrappesati": "contrappesare",
    "contrappesato": "contrappesare",
    "contrappesava": "contrappesare",
    "contrappesavamo": "contrappesare",
    "contrappesavan": "contrappesare",
    "contrappesavano": "contrappesare",
    "contrappesavate": "contrappesare",
    "contrappesavi": "contrappesare",
    "contrappesavo": "contrappesare",
    "contrappeserai": "contrappesare",
    "contrappeseran": "contrappesare",
    "contrappeseranno": "contrappesare",
    "contrappeserebbe": "contrappesare",
    "contrappeserebber": "contrappesare",
    "contrappeserebbero": "contrappesare",
    "contrappeserei": "contrappesare",
    "contrappeseremmo": "contrappesare",
    "contrappeseremo": "contrappesare",
    "contrappesereste": "contrappesare",
    "contrappeseresti": "contrappesare",
    "contrappeserete": "contrappesare",
    "contrappeserà": "contrappesare",
    "contrappeserò": "contrappesare",
    "contrappesi": "contrappeso",
    "contrappesiamo": "contrappesare",
    "contrappesiate": "contrappesare",
    "contrappesin": "contrappesare",
    "contrappesino": "contrappesare",
    "contrappeso": "contrappesare",
    "contrappesò": "contrappesare",
    "contrappone": "contrapporre",
    "contrapponemmo": "contrapporre",
    "contrapponendo": "contrapporre",
    "contrapponente": "contrapporre",
    "contrapponenti": "contrapporre",
    "contrapponesse": "contrapporre",
    "contrapponesser": "contrapporre",
    "contrapponessero": "contrapporre",
    "contrapponessi": "contrapporre",
    "contrapponessimo": "contrapporre",
    "contrapponeste": "contrapporre",
    "contrapponesti": "contrapporre",
    "contrapponete": "contrapporre",
    "contrapponeva": "contrapporre",
    "contrapponevamo": "contrapporre",
    "contrapponevan": "contrapporre",
    "contrapponevano": "contrapporre",
    "contrapponevate": "contrapporre",
    "contrapponevi": "contrapporre",
    "contrapponevo": "contrapporre",
    "contrapponga": "contrapporre",
    "contrappongan": "contrapporre",
    "contrappongano": "contrapporre",
    "contrappongo": "contrapporre",
    "contrappongon": "contrapporre",
    "contrappongono": "contrapporre",
    "contrapponi": "contrapporre",
    "contrapponiamo": "contrapporre",
    "contrapponiate": "contrapporre",
    "contrapporr": "contrapporre",
    "contrapporrai": "contrapporre",
    "contrapporran": "contrapporre",
    "contrapporranno": "contrapporre",
    "contrapporrebbe": "contrapporre",
    "contrapporrebber": "contrapporre",
    "contrapporrebbero": "contrapporre",
    "contrapporrei": "contrapporre",
    "contrapporremmo": "contrapporre",
    "contrapporremo": "contrapporre",
    "contrapporreste": "contrapporre",
    "contrapporresti": "contrapporre",
    "contrapporrete": "contrapporre",
    "contrapporrà": "contrapporre",
    "contrapporrò": "contrapporre",
    "contrappose": "contrapporre",
    "contrapposer": "contrapporre",
    "contrapposero": "contrapporre",
    "contrapposi": "contrapporre",
    "contrapposizioni": "contrapposizione",
    "contrapposta": "contrapposto",
    "contrapposte": "contrapposto",
    "contrapposti": "contrapposto",
    "contrapposto": "contrapporre",
    "contrappunti": "contrappunto",
    "contrari": "contrario",
    "contraria": "contrario",
    "contrariai": "contrariare",
    "contrariammo": "contrariare",
    "contrariamo": "contrariare",
    "contrarian": "contrariare",
    "contrariando": "contrariare",
    "contrariano": "contrariare",
    "contrariante": "contrariare",
    "contrarianti": "contrariare",
    "contrariar": "contrariare",
    "contrariaron": "contrariare",
    "contrariarono": "contrariare",
    "contrariasse": "contrariare",
    "contrariasser": "contrariare",
    "contrariassero": "contrariare",
    "contrariassi": "contrariare",
    "contrariassimo": "contrariare",
    "contrariaste": "contrariare",
    "contrariasti": "contrariare",
    "contrariata": "contrariato",
    "contrariate": "contrariato",
    "contrariati": "contrariato",
    "contrariato": "contrariare",
    "contrariava": "contrariare",
    "contrariavamo": "contrariare",
    "contrariavan": "contrariare",
    "contrariavano": "contrariare",
    "contrariavate": "contrariare",
    "contrariavi": "contrariare",
    "contrariavo": "contrariare",
    "contrarie": "contrario",
    "contrarierai": "contrariare",
    "contrarieran": "contrariare",
    "contrarieranno": "contrariare",
    "contrarierebbe": "contrariare",
    "contrarierebber": "contrariare",
    "contrarierebbero": "contrariare",
    "contrarierei": "contrariare",
    "contrarieremmo": "contrariare",
    "contrarieremo": "contrariare",
    "contrariereste": "contrariare",
    "contrarieresti": "contrariare",
    "contrarierete": "contrariare",
    "contrarierà": "contrariare",
    "contrarierò": "contrariare",
    "contrarin": "contrariare",
    "contrarino": "contrariare",
    "contrario": "contrariare",
    "contrariò": "contrariare",
    "contrarr": "contrarre",
    "contrarrai": "contrarre",
    "contrarran": "contrarre",
    "contrarranno": "contrarre",
    "contrarrebbe": "contrarre",
    "contrarrebber": "contrarre",
    "contrarrebbero": "contrarre",
    "contrarrei": "contrarre",
    "contrarremmo": "contrarre",
    "contrarremo": "contrarre",
    "contrarreste": "contrarre",
    "contrarresti": "contrarre",
    "contrarrete": "contrarre",
    "contrarrà": "contrarre",
    "contrarrò": "contrarre",
    "contrasse": "contrarre",
    "contrassegna": "contrassegnare",
    "contrassegnai": "contrassegnare",
    "contrassegnammo": "contrassegnare",
    "contrassegnan": "contrassegnare",
    "contrassegnando": "contrassegnare",
    "contrassegnano": "contrassegnare",
    "contrassegnante": "contrassegnare",
    "contrassegnanti": "contrassegnare",
    "contrassegnar": "contrassegnare",
    "contrassegnaron": "contrassegnare",
    "contrassegnarono": "contrassegnare",
    "contrassegnasse": "contrassegnare",
    "contrassegnasser": "contrassegnare",
    "contrassegnassero": "contrassegnare",
    "contrassegnassi": "contrassegnare",
    "contrassegnassimo": "contrassegnare",
    "contrassegnaste": "contrassegnare",
    "contrassegnasti": "contrassegnare",
    "contrassegnata": "contrassegnare",
    "contrassegnate": "contrassegnare",
    "contrassegnati": "contrassegnare",
    "contrassegnato": "contrassegnare",
    "contrassegnava": "contrassegnare",
    "contrassegnavamo": "contrassegnare",
    "contrassegnavan": "contrassegnare",
    "contrassegnavano": "contrassegnare",
    "contrassegnavate": "contrassegnare",
    "contrassegnavi": "contrassegnare",
    "contrassegnavo": "contrassegnare",
    "contrassegnerai": "contrassegnare",
    "contrassegneran": "contrassegnare",
    "contrassegneranno": "contrassegnare",
    "contrassegnerebbe": "contrassegnare",
    "contrassegnerebber": "contrassegnare",
    "contrassegnerebbero": "contrassegnare",
    "contrassegnerei": "contrassegnare",
    "contrassegneremmo": "contrassegnare",
    "contrassegneremo": "contrassegnare",
    "contrassegnereste": "contrassegnare",
    "contrassegneresti": "contrassegnare",
    "contrassegnerete": "contrassegnare",
    "contrassegnerà": "contrassegnare",
    "contrassegnerò": "contrassegnare",
    "contrassegni": "contrassegno",
    "contrassegniamo": "contrassegnare",
    "contrassegniate": "contrassegnare",
    "contrassegnin": "contrassegnare",
    "contrassegnino": "contrassegnare",
    "contrassegno": "contrassegnare",
    "contrassegnò": "contrassegnare",
    "contrasser": "contrarre",
    "contrassero": "contrarre",
    "contrassi": "contrarre",
    "contrasta": "contrastare",
    "contrastai": "contrastare",
    "contrastammo": "contrastare",
    "contrastan": "contrastare",
    "contrastando": "contrastare",
    "contrastano": "contrastare",
    "contrastante": "contrastare",
    "contrastanti": "contrastare",
    "contrastar": "contrastare",
    "contrastaron": "contrastare",
    "contrastarono": "contrastare",
    "contrastasse": "contrastare",
    "contrastasser": "contrastare",
    "contrastassero": "contrastare",
    "contrastassi": "contrastare",
    "contrastassimo": "contrastare",
    "contrastaste": "contrastare",
    "contrastasti": "contrastare",
    "contrastata": "contrastato",
    "contrastate": "contrastato",
    "contrastati": "contrastato",
    "contrastato": "contrastare",
    "contrastava": "contrastare",
    "contrastavamo": "contrastare",
    "contrastavan": "contrastare",
    "contrastavano": "contrastare",
    "contrastavate": "contrastare",
    "contrastavi": "contrastare",
    "contrastavo": "contrastare",
    "contrasterai": "contrastare",
    "contrasteran": "contrastare",
    "contrasteranno": "contrastare",
    "contrasterebbe": "contrastare",
    "contrasterebber": "contrastare",
    "contrasterebbero": "contrastare",
    "contrasterei": "contrastare",
    "contrasteremmo": "contrastare",
    "contrasteremo": "contrastare",
    "contrastereste": "contrastare",
    "contrasteresti": "contrastare",
    "contrasterete": "contrastare",
    "contrasterà": "contrastare",
    "contrasterò": "contrastare",
    "contrasti": "contrasto",
    "contrastiamo": "contrastare",
    "contrastiate": "contrastare",
    "contrastin": "contrastare",
    "contrastino": "contrastare",
    "contrasto": "contrastare",
    "contrastò": "contrastare",
    "contratta": "contrattare",
    "contrattacca": "contrattaccare",
    "contrattaccai": "contrattaccare",
    "contrattaccammo": "contrattaccare",
    "contrattaccan": "contrattaccare",
    "contrattaccando": "contrattaccare",
    "contrattaccano": "contrattaccare",
    "contrattaccante": "contrattaccare",
    "contrattaccanti": "contrattaccare",
    "contrattaccar": "contrattaccare",
    "contrattaccaron": "contrattaccare",
    "contrattaccarono": "contrattaccare",
    "contrattaccasse": "contrattaccare",
    "contrattaccasser": "contrattaccare",
    "contrattaccassero": "contrattaccare",
    "contrattaccassi": "contrattaccare",
    "contrattaccassimo": "contrattaccare",
    "contrattaccaste": "contrattaccare",
    "contrattaccasti": "contrattaccare",
    "contrattaccata": "contrattaccare",
    "contrattaccate": "contrattaccare",
    "contrattaccati": "contrattaccare",
    "contrattaccato": "contrattaccare",
    "contrattaccava": "contrattaccare",
    "contrattaccavamo": "contrattaccare",
    "contrattaccavan": "contrattaccare",
    "contrattaccavano": "contrattaccare",
    "contrattaccavate": "contrattaccare",
    "contrattaccavi": "contrattaccare",
    "contrattaccavo": "contrattaccare",
    "contrattaccherai": "contrattaccare",
    "contrattaccheran": "contrattaccare",
    "contrattaccheranno": "contrattaccare",
    "contrattaccherebbe": "contrattaccare",
    "contrattaccherebber": "contrattaccare",
    "contrattaccherebbero": "contrattaccare",
    "contrattaccherei": "contrattaccare",
    "contrattaccheremmo": "contrattaccare",
    "contrattaccheremo": "contrattaccare",
    "contrattacchereste": "contrattaccare",
    "contrattaccheresti": "contrattaccare",
    "contrattaccherete": "contrattaccare",
    "contrattaccherà": "contrattaccare",
    "contrattaccherò": "contrattaccare",
    "contrattacchi": "contrattacco",
    "contrattacchiamo": "contrattaccare",
    "contrattacchiate": "contrattaccare",
    "contrattacchin": "contrattaccare",
    "contrattacchino": "contrattaccare",
    "contrattacco": "contrattaccare",
    "contrattaccò": "contrattaccare",
    "contrattai": "contrattare",
    "contrattammo": "contrattare",
    "contrattan": "contrattare",
    "contrattando": "contrattare",
    "contrattano": "contrattare",
    "contrattante": "contrattare",
    "contrattanti": "contrattare",
    "contrattar": "contrattare",
    "contrattaron": "contrattare",
    "contrattarono": "contrattare",
    "contrattasse": "contrattare",
    "contrattasser": "contrattare",
    "contrattassero": "contrattare",
    "contrattassi": "contrattare",
    "contrattassimo": "contrattare",
    "contrattaste": "contrattare",
    "contrattasti": "contrattare",
    "contrattata": "contrattare",
    "contrattate": "contrattare",
    "contrattati": "contrattare",
    "contrattato": "contrattare",
    "contrattava": "contrattare",
    "contrattavamo": "contrattare",
    "contrattavan": "contrattare",
    "contrattavano": "contrattare",
    "contrattavate": "contrattare",
    "contrattavi": "contrattare",
    "contrattavo": "contrattare",
    "contrattazioni": "contrattazione",
    "contratte": "contrarre",
    "contrattempi": "contrattempo",
    "contratterai": "contrattare",
    "contratteran": "contrattare",
    "contratteranno": "contrattare",
    "contratterebbe": "contrattare",
    "contratterebber": "contrattare",
    "contratterebbero": "contrattare",
    "contratterei": "contrattare",
    "contratteremmo": "contrattare",
    "contratteremo": "contrattare",
    "contrattereste": "contrattare",
    "contratteresti": "contrattare",
    "contratterete": "contrattare",
    "contratterà": "contrattare",
    "contratterò": "contrattare",
    "contratti": "contratto",
    "contrattiamo": "contrattare",
    "contrattiate": "contrattare",
    "contrattin": "contrattare",
    "contrattino": "contrattare",
    "contratto": "contrattare",
    "contrattuali": "contrattuale",
    "contrattualistica": "contrattualistico",
    "contrattualistiche": "contrattualistico",
    "contrattualistici": "contrattualistico",
    "contratture": "contrattura",
    "contrattò": "contrattare",
    "contravvenendo": "contravvenire",
    "contravvenente": "contravvenire",
    "contravvenenti": "contravvenire",
    "contravvenga": "contravvenire",
    "contravvengan": "contravvenire",
    "contravvengano": "contravvenire",
    "contravvengo": "contravvenire",
    "contravvengon": "contravvenire",
    "contravvengono": "contravvenire",
    "contravveniamo": "contravvenire",
    "contravveniate": "contravvenire",
    "contravvenimmo": "contravvenire",
    "contravvenir": "contravvenire",
    "contravvenisse": "contravvenire",
    "contravvenisser": "contravvenire",
    "contravvenissero": "contravvenire",
    "contravvenissi": "contravvenire",
    "contravvenissimo": "contravvenire",
    "contravveniste": "contravvenire",
    "contravvenisti": "contravvenire",
    "contravvenite": "contravvenire",
    "contravveniva": "contravvenire",
    "contravvenivamo": "contravvenire",
    "contravvenivan": "contravvenire",
    "contravvenivano": "contravvenire",
    "contravvenivate": "contravvenire",
    "contravvenivi": "contravvenire",
    "contravvenivo": "contravvenire",
    "contravvenne": "contravvenire",
    "contravvenner": "contravvenire",
    "contravvennero": "contravvenire",
    "contravvenni": "contravvenire",
    "contravventori": "contravventore",
    "contravvenuta": "contravvenire",
    "contravvenute": "contravvenire",
    "contravvenuti": "contravvenire",
    "contravvenuto": "contravvenire",
    "contravvenzioni": "contravvenzione",
    "contravverrai": "contravvenire",
    "contravverran": "contravvenire",
    "contravverranno": "contravvenire",
    "contravverrebbe": "contravvenire",
    "contravverrebber": "contravvenire",
    "contravverrebbero": "contravvenire",
    "contravverrei": "contravvenire",
    "contravverremmo": "contravvenire",
    "contravverremo": "contravvenire",
    "contravverreste": "contravvenire",
    "contravverresti": "contravvenire",
    "contravverrete": "contravvenire",
    "contravverrà": "contravvenire",
    "contravverrò": "contravvenire",
    "contravviene": "contravvenire",
    "contravvieni": "contravvenire",
    "contrazioni": "contrazione",
    "contribuendo": "contribuire",
    "contribuente": "contribuire",
    "contribuenti": "contribuire",
    "contribuiamo": "contribuire",
    "contribuiate": "contribuire",
    "contribuii": "contribuire",
    "contribuimmo": "contribuire",
    "contribuir": "contribuire",
    "contribuirai": "contribuire",
    "contribuiran": "contribuire",
    "contribuiranno": "contribuire",
    "contribuirebbe": "contribuire",
    "contribuirebber": "contribuire",
    "contribuirebbero": "contribuire",
    "contribuirei": "contribuire",
    "contribuiremmo": "contribuire",
    "contribuiremo": "contribuire",
    "contribuireste": "contribuire",
    "contribuiresti": "contribuire",
    "contribuirete": "contribuire",
    "contribuiron": "contribuire",
    "contribuirono": "contribuire",
    "contribuirà": "contribuire",
    "contribuirò": "contribuire",
    "contribuisca": "contribuire",
    "contribuiscan": "contribuire",
    "contribuiscano": "contribuire",
    "contribuisce": "contribuire",
    "contribuisci": "contribuire",
    "contribuisco": "contribuire",
    "contribuiscon": "contribuire",
    "contribuiscono": "contribuire",
    "contribuisse": "contribuire",
    "contribuisser": "contribuire",
    "contribuissero": "contribuire",
    "contribuissi": "contribuire",
    "contribuissimo": "contribuire",
    "contribuiste": "contribuire",
    "contribuisti": "contribuire",
    "contribuita": "contribuire",
    "contribuite": "contribuire",
    "contribuiti": "contribuito",
    "contribuito": "contribuire",
    "contribuiva": "contribuire",
    "contribuivamo": "contribuire",
    "contribuivan": "contribuire",
    "contribuivano": "contribuire",
    "contribuivate": "contribuire",
    "contribuivi": "contribuire",
    "contribuivo": "contribuire",
    "contributi": "contributo",
    "contributiva": "contributivo",
    "contributive": "contributivo",
    "contributivi": "contributivo",
    "contribuzioni": "contribuzione",
    "contribuì": "contribuire",
    "contrista": "contristare",
    "contristai": "contristare",
    "contristammo": "contristare",
    "contristan": "contristare",
    "contristando": "contristare",
    "contristano": "contristare",
    "contristante": "contristare",
    "contristanti": "contristare",
    "contristar": "contristare",
    "contristaron": "contristare",
    "contristarono": "contristare",
    "contristasse": "contristare",
    "contristasser": "contristare",
    "contristassero": "contristare",
    "contristassi": "contristare",
    "contristassimo": "contristare",
    "contristaste": "contristare",
    "contristasti": "contristare",
    "contristata": "contristare",
    "contristate": "contristare",
    "contristati": "contristare",
    "contristato": "contristare",
    "contristava": "contristare",
    "contristavamo": "contristare",
    "contristavan": "contristare",
    "contristavano": "contristare",
    "contristavate": "contristare",
    "contristavi": "contristare",
    "contristavo": "contristare",
    "contristerai": "contristare",
    "contristeran": "contristare",
    "contristeranno": "contristare",
    "contristerebbe": "contristare",
    "contristerebber": "contristare",
    "contristerebbero": "contristare",
    "contristerei": "contristare",
    "contristeremmo": "contristare",
    "contristeremo": "contristare",
    "contristereste": "contristare",
    "contristeresti": "contristare",
    "contristerete": "contristare",
    "contristerà": "contristare",
    "contristerò": "contristare",
    "contristi": "contristare",
    "contristiamo": "contristare",
    "contristiate": "contristare",
    "contristin": "contristare",
    "contristino": "contristare",
    "contristo": "contristare",
    "contristò": "contristare",
    "contrita": "contrito",
    "contrite": "contrito",
    "contriti": "contrito",
    "contrizioni": "contrizione",
    "contro-rivoluzionari": "contro-rivoluzionario",
    "contro-rivoluzionaria": "contro-rivoluzionario",
    "contro-rivoluzionarie": "contro-rivoluzionario",
    "controaccuse": "controaccusa",
    "controbatta": "controbattere",
    "controbattan": "controbattere",
    "controbattano": "controbattere",
    "controbatte": "controbattere",
    "controbattei": "controbattere",
    "controbattemmo": "controbattere",
    "controbattendo": "controbattere",
    "controbattente": "controbattere",
    "controbattenti": "controbattere",
    "controbatter": "controbattere",
    "controbatterai": "controbattere",
    "controbatteran": "controbattere",
    "controbatteranno": "controbattere",
    "controbatterebbe": "controbattere",
    "controbatterebber": "controbattere",
    "controbatterebbero": "controbattere",
    "controbatterei": "controbattere",
    "controbatteremmo": "controbattere",
    "controbatteremo": "controbattere",
    "controbattereste": "controbattere",
    "controbatteresti": "controbattere",
    "controbatterete": "controbattere",
    "controbatteron": "controbattere",
    "controbatterono": "controbattere",
    "controbatterà": "controbattere",
    "controbatterò": "controbattere",
    "controbattesse": "controbattere",
    "controbattesser": "controbattere",
    "controbattessero": "controbattere",
    "controbattessi": "controbattere",
    "controbattessimo": "controbattere",
    "controbatteste": "controbattere",
    "controbattesti": "controbattere",
    "controbattete": "controbattere",
    "controbatteva": "controbattere",
    "controbattevamo": "controbattere",
    "controbattevan": "controbattere",
    "controbattevano": "controbattere",
    "controbattevate": "controbattere",
    "controbattevi": "controbattere",
    "controbattevo": "controbattere",
    "controbatti": "controbattere",
    "controbattiamo": "controbattere",
    "controbattiate": "controbattere",
    "controbatto": "controbattere",
    "controbatton": "controbattere",
    "controbattono": "controbattere",
    "controbattuta": "controbattere",
    "controbattute": "controbattere",
    "controbattuti": "controbattere",
    "controbattuto": "controbattere",
    "controbattè": "controbattere",
    "controbilancerai": "controbilanciare",
    "controbilanceran": "controbilanciare",
    "controbilanceranno": "controbilanciare",
    "controbilancerebbe": "controbilanciare",
    "controbilancerebber": "controbilanciare",
    "controbilancerebbero": "controbilanciare",
    "controbilancerei": "controbilanciare",
    "controbilanceremmo": "controbilanciare",
    "controbilanceremo": "controbilanciare",
    "controbilancereste": "controbilanciare",
    "controbilanceresti": "controbilanciare",
    "controbilancerete": "controbilanciare",
    "controbilancerà": "controbilanciare",
    "controbilancerò": "controbilanciare",
    "controbilanci": "controbilanciare",
    "controbilancia": "controbilanciare",
    "controbilanciai": "controbilanciare",
    "controbilanciammo": "controbilanciare",
    "controbilanciamo": "controbilanciare",
    "controbilancian": "controbilanciare",
    "controbilanciando": "controbilanciare",
    "controbilanciano": "controbilanciare",
    "controbilanciante": "controbilanciare",
    "controbilancianti": "controbilanciare",
    "controbilanciar": "controbilanciare",
    "controbilanciaron": "controbilanciare",
    "controbilanciarono": "controbilanciare",
    "controbilanciasse": "controbilanciare",
    "controbilanciasser": "controbilanciare",
    "controbilanciassero": "controbilanciare",
    "controbilanciassi": "controbilanciare",
    "controbilanciassimo": "controbilanciare",
    "controbilanciaste": "controbilanciare",
    "controbilanciasti": "controbilanciare",
    "controbilanciata": "controbilanciare",
    "controbilanciate": "controbilanciare",
    "controbilanciati": "controbilanciare",
    "controbilanciato": "controbilanciare",
    "controbilanciava": "controbilanciare",
    "controbilanciavamo": "controbilanciare",
    "controbilanciavan": "controbilanciare",
    "controbilanciavano": "controbilanciare",
    "controbilanciavate": "controbilanciare",
    "controbilanciavi": "controbilanciare",
    "controbilanciavo": "controbilanciare",
    "controbilancin": "controbilanciare",
    "controbilancino": "controbilanciare",
    "controbilancio": "controbilanciare",
    "controbilanciò": "controbilanciare",
    "controcampi": "controcampo",
    "controcanti": "controcanto",
    "controcarra": "controcarro",
    "controcarre": "controcarro",
    "controcarri": "controcarro",
    "controculture": "controcultura",
    "controdeduzioni": "controdeduzione",
    "controesodi": "controesodo",
    "controffensiva": "controffensivo",
    "controffensive": "controffensivo",
    "controffensivi": "controffensivo",
    "controfferte": "controfferta",
    "controfigure": "controfigura",
    "controfirma": "controfirmare",
    "controfirmai": "controfirmare",
    "controfirmammo": "controfirmare",
    "controfirman": "controfirmare",
    "controfirmando": "controfirmare",
    "controfirmano": "controfirmare",
    "controfirmante": "controfirmare",
    "controfirmanti": "controfirmare",
    "controfirmar": "controfirmare",
    "controfirmaron": "controfirmare",
    "controfirmarono": "controfirmare",
    "controfirmasse": "controfirmare",
    "controfirmasser": "controfirmare",
    "controfirmassero": "controfirmare",
    "controfirmassi": "controfirmare",
    "controfirmassimo": "controfirmare",
    "controfirmaste": "controfirmare",
    "controfirmasti": "controfirmare",
    "controfirmata": "controfirmare",
    "controfirmate": "controfirmare",
    "controfirmati": "controfirmare",
    "controfirmato": "controfirmare",
    "controfirmava": "controfirmare",
    "controfirmavamo": "controfirmare",
    "controfirmavan": "controfirmare",
    "controfirmavano": "controfirmare",
    "controfirmavate": "controfirmare",
    "controfirmavi": "controfirmare",
    "controfirmavo": "controfirmare",
    "controfirme": "controfirma",
    "controfirmerai": "controfirmare",
    "controfirmeran": "controfirmare",
    "controfirmeranno": "controfirmare",
    "controfirmerebbe": "controfirmare",
    "controfirmerebber": "controfirmare",
    "controfirmerebbero": "controfirmare",
    "controfirmerei": "controfirmare",
    "controfirmeremmo": "controfirmare",
    "controfirmeremo": "controfirmare",
    "controfirmereste": "controfirmare",
    "controfirmeresti": "controfirmare",
    "controfirmerete": "controfirmare",
    "controfirmerà": "controfirmare",
    "controfirmerò": "controfirmare",
    "controfirmi": "controfirmare",
    "controfirmiamo": "controfirmare",
    "controfirmiate": "controfirmare",
    "controfirmin": "controfirmare",
    "controfirmino": "controfirmare",
    "controfirmo": "controfirmare",
    "controfirmò": "controfirmare",
    "controinchieste": "controinchiesta",
    "controindica": "controindicare",
    "controindicai": "controindicare",
    "controindicammo": "controindicare",
    "controindican": "controindicare",
    "controindicando": "controindicare",
    "controindicano": "controindicare",
    "controindicante": "controindicare",
    "controindicanti": "controindicare",
    "controindicar": "controindicare",
    "controindicaron": "controindicare",
    "controindicarono": "controindicare",
    "controindicasse": "controindicare",
    "controindicasser": "controindicare",
    "controindicassero": "controindicare",
    "controindicassi": "controindicare",
    "controindicassimo": "controindicare",
    "controindicaste": "controindicare",
    "controindicasti": "controindicare",
    "controindicata": "controindicare",
    "controindicate": "controindicare",
    "controindicati": "controindicare",
    "controindicato": "controindicare",
    "controindicava": "controindicare",
    "controindicavamo": "controindicare",
    "controindicavan": "controindicare",
    "controindicavano": "controindicare",
    "controindicavate": "controindicare",
    "controindicavi": "controindicare",
    "controindicavo": "controindicare",
    "controindicazioni": "controindicazione",
    "controindicherai": "controindicare",
    "controindicheran": "controindicare",
    "controindicheranno": "controindicare",
    "controindicherebbe": "controindicare",
    "controindicherebber": "controindicare",
    "controindicherebbero": "controindicare",
    "controindicherei": "controindicare",
    "controindicheremmo": "controindicare",
    "controindicheremo": "controindicare",
    "controindichereste": "controindicare",
    "controindicheresti": "controindicare",
    "controindicherete": "controindicare",
    "controindicherà": "controindicare",
    "controindicherò": "controindicare",
    "controindichi": "controindicare",
    "controindichiamo": "controindicare",
    "controindichiate": "controindicare",
    "controindichin": "controindicare",
    "controindichino": "controindicare",
    "controindico": "controindicare",
    "controindicò": "controindicare",
    "controinformazioni": "controinformazione",
    "controlla": "controllare",
    "controllabili": "controllabile",
    "controllai": "controllare",
    "controllammo": "controllare",
    "controllan": "controllare",
    "controllando": "controllare",
    "controllano": "controllare",
    "controllante": "controllare",
    "controllanti": "controllare",
    "controllar": "controllare",
    "controllaron": "controllare",
    "controllarono": "controllare",
    "controllasse": "controllare",
    "controllasser": "controllare",
    "controllassero": "controllare",
    "controllassi": "controllare",
    "controllassimo": "controllare",
    "controllaste": "controllare",
    "controllasti": "controllare",
    "controllata": "controllato",
    "controllate": "controllato",
    "controllati": "controllato",
    "controllato": "controllare",
    "controllava": "controllare",
    "controllavamo": "controllare",
    "controllavan": "controllare",
    "controllavano": "controllare",
    "controllavate": "controllare",
    "controllavi": "controllare",
    "controllavo": "controllare",
    "controllerai": "controllare",
    "controlleran": "controllare",
    "controlleranno": "controllare",
    "controllerebbe": "controllare",
    "controllerebber": "controllare",
    "controllerebbero": "controllare",
    "controllerei": "controllare",
    "controlleremmo": "controllare",
    "controlleremo": "controllare",
    "controllereste": "controllare",
    "controlleresti": "controllare",
    "controllerete": "controllare",
    "controllerà": "controllare",
    "controllerò": "controllare",
    "controlli": "controllo",
    "controlliamo": "controllare",
    "controlliate": "controllare",
    "controllin": "controllare",
    "controllino": "controllare",
    "controllo": "controllare",
    "controllori": "controllore",
    "controllò": "controllare",
    "contromanifestazioni": "contromanifestazione",
    "contromisure": "contromisura",
    "contromosse": "contromossa",
    "controparti": "controparte",
    "contropartite": "contropartita",
    "controperizie": "controperizia",
    "contropiani": "contropiano",
    "contropiedi": "contropiede",
    "contropiedisti": "contropiedista",
    "contropoteri": "contropotere",
    "controproducenti": "controproducente",
    "controproposte": "controproposta",
    "controrappresaglie": "controrappresaglia",
    "contrordini": "contrordine",
    "controreplica": "controreplicare",
    "controreplicai": "controreplicare",
    "controreplicammo": "controreplicare",
    "controreplican": "controreplicare",
    "controreplicando": "controreplicare",
    "controreplicano": "controreplicare",
    "controreplicante": "controreplicare",
    "controreplicanti": "controreplicare",
    "controreplicar": "controreplicare",
    "controreplicaron": "controreplicare",
    "controreplicarono": "controreplicare",
    "controreplicasse": "controreplicare",
    "controreplicasser": "controreplicare",
    "controreplicassero": "controreplicare",
    "controreplicassi": "controreplicare",
    "controreplicassimo": "controreplicare",
    "controreplicaste": "controreplicare",
    "controreplicasti": "controreplicare",
    "controreplicata": "controreplicare",
    "controreplicate": "controreplicare",
    "controreplicati": "controreplicare",
    "controreplicato": "controreplicare",
    "controreplicava": "controreplicare",
    "controreplicavamo": "controreplicare",
    "controreplicavan": "controreplicare",
    "controreplicavano": "controreplicare",
    "controreplicavate": "controreplicare",
    "controreplicavi": "controreplicare",
    "controreplicavo": "controreplicare",
    "controrepliche": "controreplica",
    "controreplicherai": "controreplicare",
    "controreplicheran": "controreplicare",
    "controreplicheranno": "controreplicare",
    "controreplicherebbe": "controreplicare",
    "controreplicherebber": "controreplicare",
    "controreplicherebbero": "controreplicare",
    "controreplicherei": "controreplicare",
    "controreplicheremmo": "controreplicare",
    "controreplicheremo": "controreplicare",
    "controreplichereste": "controreplicare",
    "controreplicheresti": "controreplicare",
    "controreplicherete": "controreplicare",
    "controreplicherà": "controreplicare",
    "controreplicherò": "controreplicare",
    "controreplichi": "controreplicare",
    "controreplichiamo": "controreplicare",
    "controreplichiate": "controreplicare",
    "controreplichin": "controreplicare",
    "controreplichino": "controreplicare",
    "controreplico": "controreplicare",
    "controreplicò": "controreplicare",
    "controriforme": "controriforma",
    "controrivoluzionari": "controrivoluzionario",
    "controrivoluzioni": "controrivoluzione",
    "controscene": "controscena",
    "controsensi": "controsenso",
    "controsoffitti": "controsoffitto",
    "controspionaggi": "controspionaggio",
    "controsterza": "controsterzare",
    "controsterzai": "controsterzare",
    "controsterzammo": "controsterzare",
    "controsterzan": "controsterzare",
    "controsterzando": "controsterzare",
    "controsterzano": "controsterzare",
    "controsterzante": "controsterzare",
    "controsterzanti": "controsterzare",
    "controsterzar": "controsterzare",
    "controsterzaron": "controsterzare",
    "controsterzarono": "controsterzare",
    "controsterzasse": "controsterzare",
    "controsterzasser": "controsterzare",
    "controsterzassero": "controsterzare",
    "controsterzassi": "controsterzare",
    "controsterzassimo": "controsterzare",
    "controsterzaste": "controsterzare",
    "controsterzasti": "controsterzare",
    "controsterzata": "controsterzare",
    "controsterzate": "controsterzare",
    "controsterzati": "controsterzare",
    "controsterzato": "controsterzare",
    "controsterzava": "controsterzare",
    "controsterzavamo": "controsterzare",
    "controsterzavan": "controsterzare",
    "controsterzavano": "controsterzare",
    "controsterzavate": "controsterzare",
    "controsterzavi": "controsterzare",
    "controsterzavo": "controsterzare",
    "controsterzerai": "controsterzare",
    "controsterzeran": "controsterzare",
    "controsterzeranno": "controsterzare",
    "controsterzerebbe": "controsterzare",
    "controsterzerebber": "controsterzare",
    "controsterzerebbero": "controsterzare",
    "controsterzerei": "controsterzare",
    "controsterzeremmo": "controsterzare",
    "controsterzeremo": "controsterzare",
    "controsterzereste": "controsterzare",
    "controsterzeresti": "controsterzare",
    "controsterzerete": "controsterzare",
    "controsterzerà": "controsterzare",
    "controsterzerò": "controsterzare",
    "controsterzi": "controsterzare",
    "controsterziamo": "controsterzare",
    "controsterziate": "controsterzare",
    "controsterzin": "controsterzare",
    "controsterzino": "controsterzare",
    "controsterzo": "controsterzare",
    "controsterzò": "controsterzare",
    "controtendenze": "controtendenza",
    "controvalori": "controvalore",
    "controversa": "controverso",
    "controverse": "controverso",
    "controversi": "controverso",
    "controversie": "controversia",
    "controverta": "controvertere",
    "controvertan": "controvertere",
    "controvertano": "controvertere",
    "controverte": "controvertere",
    "controvertei": "controvertere",
    "controvertemmo": "controvertere",
    "controvertendo": "controvertere",
    "controvertente": "controvertere",
    "controvertenti": "controvertere",
    "controverter": "controvertere",
    "controverterai": "controvertere",
    "controverteran": "controvertere",
    "controverteranno": "controvertere",
    "controverterebbe": "controvertere",
    "controverterebber": "controvertere",
    "controverterebbero": "controvertere",
    "controverterei": "controvertere",
    "controverteremmo": "controvertere",
    "controverteremo": "controvertere",
    "controvertereste": "controvertere",
    "controverteresti": "controvertere",
    "controverterete": "controvertere",
    "controverteron": "controvertere",
    "controverterono": "controvertere",
    "controverterà": "controvertere",
    "controverterò": "controvertere",
    "controvertesse": "controvertere",
    "controvertesser": "controvertere",
    "controvertessero": "controvertere",
    "controvertessi": "controvertere",
    "controvertessimo": "controvertere",
    "controverteste": "controvertere",
    "controvertesti": "controvertere",
    "controvertete": "controvertere",
    "controverteva": "controvertere",
    "controvertevamo": "controvertere",
    "controvertevan": "controvertere",
    "controvertevano": "controvertere",
    "controvertevate": "controvertere",
    "controvertevi": "controvertere",
    "controvertevo": "controvertere",
    "controverti": "controvertere",
    "controvertiamo": "controvertere",
    "controvertiate": "controvertere",
    "controvertibili": "controvertibile",
    "controverto": "controvertere",
    "controverton": "controvertere",
    "controvertono": "controvertere",
    "controvertuta": "controvertere",
    "controvertute": "controvertere",
    "controvertuti": "controvertere",
    "controvertuto": "controvertere",
    "controvertè": "controvertere",
    "controviali": "controviale",
    "contumaci": "contumace",
    "contumelie": "contumelia",
    "contunda": "contundere",
    "contundan": "contundere",
    "contundano": "contundere",
    "contunde": "contundere",
    "contundemmo": "contundere",
    "contundendo": "contundere",
    "contundente": "contundere",
    "contundenti": "contundere",
    "contunder": "contundere",
    "contunderai": "contundere",
    "contunderan": "contundere",
    "contunderanno": "contundere",
    "contunderebbe": "contundere",
    "contunderebber": "contundere",
    "contunderebbero": "contundere",
    "contunderei": "contundere",
    "contunderemmo": "contundere",
    "contunderemo": "contundere",
    "contundereste": "contundere",
    "contunderesti": "contundere",
    "contunderete": "contundere",
    "contunderà": "contundere",
    "contunderò": "contundere",
    "contundesse": "contundere",
    "contundesser": "contundere",
    "contundessero": "contundere",
    "contundessi": "contundere",
    "contundessimo": "contundere",
    "contundeste": "contundere",
    "contundesti": "contundere",
    "contundete": "contundere",
    "contundeva": "contundere",
    "contundevamo": "contundere",
    "contundevan": "contundere",
    "contundevano": "contundere",
    "contundevate": "contundere",
    "contundevi": "contundere",
    "contundevo": "contundere",
    "contundi": "contundere",
    "contundiamo": "contundere",
    "contundiate": "contundere",
    "contundo": "contundere",
    "contundon": "contundere",
    "contundono": "contundere",
    "conturba": "conturbare",
    "conturbai": "conturbare",
    "conturbammo": "conturbare",
    "conturban": "conturbare",
    "conturbando": "conturbare",
    "conturbano": "conturbare",
    "conturbante": "conturbare",
    "conturbanti": "conturbare",
    "conturbar": "conturbare",
    "conturbaron": "conturbare",
    "conturbarono": "conturbare",
    "conturbasse": "conturbare",
    "conturbasser": "conturbare",
    "conturbassero": "conturbare",
    "conturbassi": "conturbare",
    "conturbassimo": "conturbare",
    "conturbaste": "conturbare",
    "conturbasti": "conturbare",
    "conturbata": "conturbare",
    "conturbate": "conturbare",
    "conturbati": "conturbare",
    "conturbato": "conturbare",
    "conturbava": "conturbare",
    "conturbavamo": "conturbare",
    "conturbavan": "conturbare",
    "conturbavano": "conturbare",
    "conturbavate": "conturbare",
    "conturbavi": "conturbare",
    "conturbavo": "conturbare",
    "conturberai": "conturbare",
    "conturberan": "conturbare",
    "conturberanno": "conturbare",
    "conturberebbe": "conturbare",
    "conturberebber": "conturbare",
    "conturberebbero": "conturbare",
    "conturberei": "conturbare",
    "conturberemmo": "conturbare",
    "conturberemo": "conturbare",
    "conturbereste": "conturbare",
    "conturberesti": "conturbare",
    "conturberete": "conturbare",
    "conturberà": "conturbare",
    "conturberò": "conturbare",
    "conturbi": "conturbare",
    "conturbiamo": "conturbare",
    "conturbiate": "conturbare",
    "conturbin": "conturbare",
    "conturbino": "conturbare",
    "conturbo": "conturbare",
    "conturbò": "conturbare",
    "contusa": "contuso",
    "contuse": "contuso",
    "contuser": "contundere",
    "contusero": "contundere",
    "contusi": "contuso",
    "contusioni": "contusione",
    "contuso": "contundere",
    "contusè": "contundere",
    "contò": "contare",
    "conuta": "corre",
    "conute": "corre",
    "conuti": "corre",
    "conuto": "corre",
    "convalescenti": "convalescente",
    "convalescenze": "convalescenza",
    "convalida": "convalidare",
    "convalidai": "convalidare",
    "convalidammo": "convalidare",
    "convalidan": "convalidare",
    "convalidando": "convalidare",
    "convalidano": "convalidare",
    "convalidante": "convalidare",
    "convalidanti": "convalidare",
    "convalidar": "convalidare",
    "convalidaron": "convalidare",
    "convalidarono": "convalidare",
    "convalidasse": "convalidare",
    "convalidasser": "convalidare",
    "convalidassero": "convalidare",
    "convalidassi": "convalidare",
    "convalidassimo": "convalidare",
    "convalidaste": "convalidare",
    "convalidasti": "convalidare",
    "convalidata": "convalidare",
    "convalidate": "convalidare",
    "convalidati": "convalidare",
    "convalidato": "convalidare",
    "convalidava": "convalidare",
    "convalidavamo": "convalidare",
    "convalidavan": "convalidare",
    "convalidavano": "convalidare",
    "convalidavate": "convalidare",
    "convalidavi": "convalidare",
    "convalidavo": "convalidare",
    "convaliderai": "convalidare",
    "convalideran": "convalidare",
    "convalideranno": "convalidare",
    "convaliderebbe": "convalidare",
    "convaliderebber": "convalidare",
    "convaliderebbero": "convalidare",
    "convaliderei": "convalidare",
    "convalideremmo": "convalidare",
    "convalideremo": "convalidare",
    "convalidereste": "convalidare",
    "convalideresti": "convalidare",
    "convaliderete": "convalidare",
    "convaliderà": "convalidare",
    "convaliderò": "convalidare",
    "convalidi": "convalidare",
    "convalidiamo": "convalidare",
    "convalidiate": "convalidare",
    "convalidin": "convalidare",
    "convalidino": "convalidare",
    "convalido": "convalidare",
    "convalidò": "convalidare",
    "convegni": "convegno",
    "convegnisti": "convegnista",
    "convenendo": "convenire",
    "convenente": "convenire",
    "convenenti": "convenire",
    "convenevoli": "convenevole",
    "convenga": "convenire",
    "convengan": "convenire",
    "convengano": "convenire",
    "convengo": "convenire",
    "convengon": "convenire",
    "convengono": "convenire",
    "conveniamo": "convenire",
    "conveniate": "convenire",
    "convenienti": "conveniente",
    "convenienze": "convenienza",
    "convenimmo": "convenire",
    "convenir": "convenire",
    "convenisse": "convenire",
    "convenisser": "convenire",
    "convenissero": "convenire",
    "convenissi": "convenire",
    "convenissimo": "convenire",
    "conveniste": "convenire",
    "convenisti": "convenire",
    "convenite": "convenire",
    "conveniva": "convenire",
    "convenivamo": "convenire",
    "convenivan": "convenire",
    "convenivano": "convenire",
    "convenivate": "convenire",
    "convenivi": "convenire",
    "convenivo": "convenire",
    "convenne": "convenire",
    "convenner": "convenire",
    "convennero": "convenire",
    "convenni": "convenire",
    "conventi": "convento",
    "conventicole": "conventicola",
    "conventiones": "conventio",
    "conventuali": "conventuale",
    "convenuta": "convenuto",
    "convenute": "convenuto",
    "convenuti": "convenuto",
    "convenuto": "convenire",
    "convenziona": "convenzionare",
    "convenzionai": "convenzionare",
    "convenzionali": "convenzionale",
    "convenzionalismi": "convenzionalismo",
    "convenzionammo": "convenzionare",
    "convenzionan": "convenzionare",
    "convenzionando": "convenzionare",
    "convenzionano": "convenzionare",
    "convenzionante": "convenzionare",
    "convenzionanti": "convenzionare",
    "convenzionar": "convenzionare",
    "convenzionaron": "convenzionare",
    "convenzionarono": "convenzionare",
    "convenzionasse": "convenzionare",
    "convenzionasser": "convenzionare",
    "convenzionassero": "convenzionare",
    "convenzionassi": "convenzionare",
    "convenzionassimo": "convenzionare",
    "convenzionaste": "convenzionare",
    "convenzionasti": "convenzionare",
    "convenzionata": "convenzionato",
    "convenzionate": "convenzionato",
    "convenzionati": "convenzionato",
    "convenzionato": "convenzionare",
    "convenzionava": "convenzionare",
    "convenzionavamo": "convenzionare",
    "convenzionavan": "convenzionare",
    "convenzionavano": "convenzionare",
    "convenzionavate": "convenzionare",
    "convenzionavi": "convenzionare",
    "convenzionavo": "convenzionare",
    "convenzionerai": "convenzionare",
    "convenzioneran": "convenzionare",
    "convenzioneranno": "convenzionare",
    "convenzionerebbe": "convenzionare",
    "convenzionerebber": "convenzionare",
    "convenzionerebbero": "convenzionare",
    "convenzionerei": "convenzionare",
    "convenzioneremmo": "convenzionare",
    "convenzioneremo": "convenzionare",
    "convenzionereste": "convenzionare",
    "convenzioneresti": "convenzionare",
    "convenzionerete": "convenzionare",
    "convenzionerà": "convenzionare",
    "convenzionerò": "convenzionare",
    "convenzioni": "convenzione",
    "convenzioniamo": "convenzionare",
    "convenzioniate": "convenzionare",
    "convenzionin": "convenzionare",
    "convenzionino": "convenzionare",
    "convenziono": "convenzionare",
    "convenzionò": "convenzionare",
    "converga": "convergere",
    "convergan": "convergere",
    "convergano": "convergere",
    "converge": "convergere",
    "convergemmo": "convergere",
    "convergendo": "convergere",
    "convergente": "convergere",
    "convergenti": "convergere",
    "convergenze": "convergenza",
    "converger": "convergere",
    "convergerai": "convergere",
    "convergeran": "convergere",
    "convergeranno": "convergere",
    "convergerebbe": "convergere",
    "convergerebber": "convergere",
    "convergerebbero": "convergere",
    "convergerei": "convergere",
    "convergeremmo": "convergere",
    "convergeremo": "convergere",
    "convergereste": "convergere",
    "convergeresti": "convergere",
    "convergerete": "convergere",
    "convergerà": "convergere",
    "convergerò": "convergere",
    "convergesse": "convergere",
    "convergesser": "convergere",
    "convergessero": "convergere",
    "convergessi": "convergere",
    "convergessimo": "convergere",
    "convergeste": "convergere",
    "convergesti": "convergere",
    "convergete": "convergere",
    "convergeva": "convergere",
    "convergevamo": "convergere",
    "convergevan": "convergere",
    "convergevano": "convergere",
    "convergevate": "convergere",
    "convergevi": "convergere",
    "convergevo": "convergere",
    "convergi": "convergere",
    "convergiamo": "convergere",
    "convergiate": "convergere",
    "convergo": "convergere",
    "convergon": "convergere",
    "convergono": "convergere",
    "converrai": "convenire",
    "converran": "convenire",
    "converranno": "convenire",
    "converrebbe": "convenire",
    "converrebber": "convenire",
    "converrebbero": "convenire",
    "converrei": "convenire",
    "converremmo": "convenire",
    "converremo": "convenire",
    "converreste": "convenire",
    "converresti": "convenire",
    "converrete": "convenire",
    "converrà": "convenire",
    "converrò": "convenire",
    "conversa": "converso",
    "conversai": "conversare",
    "conversammo": "conversare",
    "conversan": "conversare",
    "conversando": "conversare",
    "conversano": "conversare",
    "conversante": "conversare",
    "conversanti": "conversare",
    "conversar": "conversare",
    "conversari": "conversare",
    "conversaron": "conversare",
    "conversarono": "conversare",
    "conversasse": "conversare",
    "conversasser": "conversare",
    "conversassero": "conversare",
    "conversassi": "conversare",
    "conversassimo": "conversare",
    "conversaste": "conversare",
    "conversasti": "conversare",
    "conversata": "conversare",
    "conversate": "conversare",
    "conversati": "conversare",
    "conversato": "conversare",
    "conversatori": "conversatore",
    "conversava": "conversare",
    "conversavamo": "conversare",
    "conversavan": "conversare",
    "conversavano": "conversare",
    "conversavate": "conversare",
    "conversavi": "conversare",
    "conversavo": "conversare",
    "conversazioni": "conversazione",
    "converse": "converso",
    "converser": "convergere",
    "converserai": "conversare",
    "converseran": "conversare",
    "converseranno": "conversare",
    "converserebbe": "conversare",
    "converserebber": "conversare",
    "converserebbero": "conversare",
    "converserei": "conversare",
    "converseremmo": "conversare",
    "converseremo": "conversare",
    "conversereste": "conversare",
    "converseresti": "conversare",
    "converserete": "conversare",
    "conversero": "convergere",
    "converserà": "conversare",
    "converserò": "conversare",
    "conversi": "converso",
    "conversiamo": "conversare",
    "conversiate": "conversare",
    "conversin": "conversare",
    "conversino": "conversare",
    "conversioni": "conversione",
    "converso": "conversare",
    "conversè": "convergere",
    "conversò": "conversare",
    "converta": "convertire",
    "convertan": "convertire",
    "convertano": "convertire",
    "converte": "convertire",
    "convertendo": "convertire",
    "convertente": "convertire",
    "convertenti": "convertire",
    "converti": "convertire",
    "convertiamo": "convertire",
    "convertiate": "convertire",
    "convertibili": "convertibile",
    "convertii": "convertire",
    "convertimmo": "convertire",
    "convertir": "convertire",
    "convertirai": "convertire",
    "convertiran": "convertire",
    "convertiranno": "convertire",
    "convertirebbe": "convertire",
    "convertirebber": "convertire",
    "convertirebbero": "convertire",
    "convertirei": "convertire",
    "convertiremmo": "convertire",
    "convertiremo": "convertire",
    "convertireste": "convertire",
    "convertiresti": "convertire",
    "convertirete": "convertire",
    "convertiron": "convertire",
    "convertirono": "convertire",
    "convertirà": "convertire",
    "convertirò": "convertire",
    "convertisse": "convertire",
    "convertisser": "convertire",
    "convertissero": "convertire",
    "convertissi": "convertire",
    "convertissimo": "convertire",
    "convertiste": "convertire",
    "convertisti": "convertire",
    "convertita": "convertito",
    "convertite": "convertito",
    "convertiti": "convertito",
    "convertito": "convertire",
    "convertitori": "convertitore",
    "convertiva": "convertire",
    "convertivamo": "convertire",
    "convertivan": "convertire",
    "convertivano": "convertire",
    "convertivate": "convertire",
    "convertivi": "convertire",
    "convertivo": "convertire",
    "converto": "convertire",
    "converton": "convertire",
    "convertono": "convertire",
    "convertì": "convertire",
    "convessa": "convesso",
    "convesse": "convesso",
    "convessi": "convesso",
    "convezioni": "convezione",
    "conviene": "convenire",
    "convieni": "convenire",
    "convinca": "convincere",
    "convincan": "convincere",
    "convincano": "convincere",
    "convince": "convincere",
    "convincemmo": "convincere",
    "convincendo": "convincere",
    "convincente": "convincere",
    "convincenti": "convincere",
    "convincer": "convincere",
    "convincerai": "convincere",
    "convinceran": "convincere",
    "convinceranno": "convincere",
    "convincerebbe": "convincere",
    "convincerebber": "convincere",
    "convincerebbero": "convincere",
    "convincerei": "convincere",
    "convinceremmo": "convincere",
    "convinceremo": "convincere",
    "convincereste": "convincere",
    "convinceresti": "convincere",
    "convincerete": "convincere",
    "convincerà": "convincere",
    "convincerò": "convincere",
    "convincesse": "convincere",
    "convincesser": "convincere",
    "convincessero": "convincere",
    "convincessi": "convincere",
    "convincessimo": "convincere",
    "convinceste": "convincere",
    "convincesti": "convincere",
    "convincete": "convincere",
    "convinceva": "convincere",
    "convincevamo": "convincere",
    "convincevan": "convincere",
    "convincevano": "convincere",
    "convincevate": "convincere",
    "convincevi": "convincere",
    "convincevo": "convincere",
    "convinci": "convincere",
    "convinciamo": "convincere",
    "convinciate": "convincere",
    "convincimenti": "convincimento",
    "convinco": "convincere",
    "convincon": "convincere",
    "convincono": "convincere",
    "convinse": "convincere",
    "convinser": "convincere",
    "convinsero": "convincere",
    "convinsi": "convincere",
    "convinta": "convinto",
    "convinte": "convinto",
    "convinti": "convinto",
    "convinto": "convincere",
    "convinzioni": "convinzione",
    "convita": "convitare",
    "convitai": "convitare",
    "convitammo": "convitare",
    "convitan": "convitare",
    "convitando": "convitare",
    "convitano": "convitare",
    "convitante": "convitare",
    "convitanti": "convitare",
    "convitar": "convitare",
    "convitaron": "convitare",
    "convitarono": "convitare",
    "convitasse": "convitare",
    "convitasser": "convitare",
    "convitassero": "convitare",
    "convitassi": "convitare",
    "convitassimo": "convitare",
    "convitaste": "convitare",
    "convitasti": "convitare",
    "convitata": "convitare",
    "convitate": "convitare",
    "convitati": "convitato",
    "convitato": "convitare",
    "convitava": "convitare",
    "convitavamo": "convitare",
    "convitavan": "convitare",
    "convitavano": "convitare",
    "convitavate": "convitare",
    "convitavi": "convitare",
    "convitavo": "convitare",
    "conviterai": "convitare",
    "conviteran": "convitare",
    "conviteranno": "convitare",
    "conviterebbe": "convitare",
    "conviterebber": "convitare",
    "conviterebbero": "convitare",
    "conviterei": "convitare",
    "conviteremmo": "convitare",
    "conviteremo": "convitare",
    "convitereste": "convitare",
    "conviteresti": "convitare",
    "conviterete": "convitare",
    "conviterà": "convitare",
    "conviterò": "convitare",
    "conviti": "convito",
    "convitiamo": "convitare",
    "convitiate": "convitare",
    "convitin": "convitare",
    "convitino": "convitare",
    "convito": "convitare",
    "convitti": "convitto",
    "convitò": "convitare",
    "conviva": "convivere",
    "convivan": "convivere",
    "convivano": "convivere",
    "convive": "convivere",
    "convivei": "convivere",
    "convivemmo": "convivere",
    "convivendo": "convivere",
    "convivente": "convivere",
    "conviventi": "convivere",
    "convivenze": "convivenza",
    "conviver": "convivere",
    "conviverai": "convivere",
    "conviveran": "convivere",
    "conviveranno": "convivere",
    "conviverebbe": "convivere",
    "conviverebber": "convivere",
    "conviverebbero": "convivere",
    "conviverei": "convivere",
    "conviveremmo": "convivere",
    "conviveremo": "convivere",
    "convivereste": "convivere",
    "conviveresti": "convivere",
    "conviverete": "convivere",
    "conviveron": "convivere",
    "conviverono": "convivere",
    "conviverà": "convivere",
    "conviverò": "convivere",
    "convivesse": "convivere",
    "convivesser": "convivere",
    "convivessero": "convivere",
    "convivessi": "convivere",
    "convivessimo": "convivere",
    "conviveste": "convivere",
    "convivesti": "convivere",
    "convivete": "convivere",
    "conviveva": "convivere",
    "convivevamo": "convivere",
    "convivevan": "convivere",
    "convivevano": "convivere",
    "convivevate": "convivere",
    "convivevi": "convivere",
    "convivevo": "convivere",
    "convivi": "convivere",
    "conviviali": "conviviale",
    "conviviamo": "convivere",
    "conviviate": "convivere",
    "convivo": "convivere",
    "convivon": "convivere",
    "convivono": "convivere",
    "convivuta": "convivere",
    "convivute": "convivere",
    "convivuti": "convivere",
    "convivuto": "convivere",
    "convivè": "convivere",
    "convizioni": "convizione",
    "convoca": "convocare",
    "convocabili": "convocabile",
    "convocai": "convocare",
    "convocammo": "convocare",
    "convocan": "convocare",
    "convocando": "convocare",
    "convocano": "convocare",
    "convocante": "convocare",
    "convocanti": "convocare",
    "convocar": "convocare",
    "convocaron": "convocare",
    "convocarono": "convocare",
    "convocasse": "convocare",
    "convocasser": "convocare",
    "convocassero": "convocare",
    "convocassi": "convocare",
    "convocassimo": "convocare",
    "convocaste": "convocare",
    "convocasti": "convocare",
    "convocata": "convocare",
    "convocate": "convocare",
    "convocati": "convocare",
    "convocato": "convocare",
    "convocava": "convocare",
    "convocavamo": "convocare",
    "convocavan": "convocare",
    "convocavano": "convocare",
    "convocavate": "convocare",
    "convocavi": "convocare",
    "convocavo": "convocare",
    "convocazioni": "convocazione",
    "convocherai": "convocare",
    "convocheran": "convocare",
    "convocheranno": "convocare",
    "convocherebbe": "convocare",
    "convocherebber": "convocare",
    "convocherebbero": "convocare",
    "convocherei": "convocare",
    "convocheremmo": "convocare",
    "convocheremo": "convocare",
    "convochereste": "convocare",
    "convocheresti": "convocare",
    "convocherete": "convocare",
    "convocherà": "convocare",
    "convocherò": "convocare",
    "convochi": "convocare",
    "convochiamo": "convocare",
    "convochiate": "convocare",
    "convochin": "convocare",
    "convochino": "convocare",
    "convoco": "convocare",
    "convocò": "convocare",
    "convogli": "convoglio",
    "convoglia": "convogliare",
    "convogliai": "convogliare",
    "convogliammo": "convogliare",
    "convogliamo": "convogliare",
    "convoglian": "convogliare",
    "convogliando": "convogliare",
    "convogliano": "convogliare",
    "convogliante": "convogliare",
    "convoglianti": "convogliare",
    "convogliar": "convogliare",
    "convogliaron": "convogliare",
    "convogliarono": "convogliare",
    "convogliasse": "convogliare",
    "convogliasser": "convogliare",
    "convogliassero": "convogliare",
    "convogliassi": "convogliare",
    "convogliassimo": "convogliare",
    "convogliaste": "convogliare",
    "convogliasti": "convogliare",
    "convogliata": "convogliare",
    "convogliate": "convogliare",
    "convogliati": "convogliare",
    "convogliato": "convogliare",
    "convogliava": "convogliare",
    "convogliavamo": "convogliare",
    "convogliavan": "convogliare",
    "convogliavano": "convogliare",
    "convogliavate": "convogliare",
    "convogliavi": "convogliare",
    "convogliavo": "convogliare",
    "convoglierai": "convogliare",
    "convoglieran": "convogliare",
    "convoglieranno": "convogliare",
    "convoglierebbe": "convogliare",
    "convoglierebber": "convogliare",
    "convoglierebbero": "convogliare",
    "convoglierei": "convogliare",
    "convoglieremmo": "convogliare",
    "convoglieremo": "convogliare",
    "convogliereste": "convogliare",
    "convoglieresti": "convogliare",
    "convoglierete": "convogliare",
    "convoglierà": "convogliare",
    "convoglierò": "convogliare",
    "convoglin": "convogliare",
    "convoglino": "convogliare",
    "convoglio": "convogliare",
    "convogliò": "convogliare",
    "convola": "convolare",
    "convolai": "convolare",
    "convolammo": "convolare",
    "convolan": "convolare",
    "convolando": "convolare",
    "convolano": "convolare",
    "convolante": "convolare",
    "convolanti": "convolare",
    "convolar": "convolare",
    "convolaron": "convolare",
    "convolarono": "convolare",
    "convolasse": "convolare",
    "convolasser": "convolare",
    "convolassero": "convolare",
    "convolassi": "convolare",
    "convolassimo": "convolare",
    "convolaste": "convolare",
    "convolasti": "convolare",
    "convolata": "convolare",
    "convolate": "convolare",
    "convolati": "convolare",
    "convolato": "convolare",
    "convolava": "convolare",
    "convolavamo": "convolare",
    "convolavan": "convolare",
    "convolavano": "convolare",
    "convolavate": "convolare",
    "convolavi": "convolare",
    "convolavo": "convolare",
    "convolerai": "convolare",
    "convoleran": "convolare",
    "convoleranno": "convolare",
    "convolerebbe": "convolare",
    "convolerebber": "convolare",
    "convolerebbero": "convolare",
    "convolerei": "convolare",
    "convoleremmo": "convolare",
    "convoleremo": "convolare",
    "convolereste": "convolare",
    "convoleresti": "convolare",
    "convolerete": "convolare",
    "convolerà": "convolare",
    "convolerò": "convolare",
    "convoli": "convolare",
    "convoliamo": "convolare",
    "convoliate": "convolare",
    "convolin": "convolare",
    "convolino": "convolare",
    "convolo": "convolare",
    "convolò": "convolare",
    "convulsa": "convulso",
    "convulse": "convulso",
    "convulsi": "convulso",
    "convulsioni": "convulsione",
    "conè": "corre",
    "coonesta": "coonestare",
    "coonestai": "coonestare",
    "coonestammo": "coonestare",
    "coonestan": "coonestare",
    "coonestando": "coonestare",
    "coonestano": "coonestare",
    "coonestante": "coonestare",
    "coonestanti": "coonestare",
    "coonestar": "coonestare",
    "coonestaron": "coonestare",
    "coonestarono": "coonestare",
    "coonestasse": "coonestare",
    "coonestasser": "coonestare",
    "coonestassero": "coonestare",
    "coonestassi": "coonestare",
    "coonestassimo": "coonestare",
    "coonestaste": "coonestare",
    "coonestasti": "coonestare",
    "coonestata": "coonestare",
    "coonestate": "coonestare",
    "coonestati": "coonestare",
    "coonestato": "coonestare",
    "coonestava": "coonestare",
    "coonestavamo": "coonestare",
    "coonestavan": "coonestare",
    "coonestavano": "coonestare",
    "coonestavate": "coonestare",
    "coonestavi": "coonestare",
    "coonestavo": "coonestare",
    "coonesterai": "coonestare",
    "coonesteran": "coonestare",
    "coonesteranno": "coonestare",
    "coonesterebbe": "coonestare",
    "coonesterebber": "coonestare",
    "coonesterebbero": "coonestare",
    "coonesterei": "coonestare",
    "coonesteremmo": "coonestare",
    "coonesteremo": "coonestare",
    "coonestereste": "coonestare",
    "coonesteresti": "coonestare",
    "coonesterete": "coonestare",
    "coonesterà": "coonestare",
    "coonesterò": "coonestare",
    "coonesti": "coonestare",
    "coonestiamo": "coonestare",
    "coonestiate": "coonestare",
    "coonestin": "coonestare",
    "coonestino": "coonestare",
    "coonesto": "coonestare",
    "coonestò": "coonestare",
    "coopera": "cooperare",
    "cooperai": "cooperare",
    "cooperammo": "cooperare",
    "cooperan": "cooperare",
    "cooperando": "cooperare",
    "cooperano": "cooperare",
    "cooperante": "cooperare",
    "cooperanti": "cooperare",
    "cooperar": "cooperare",
    "cooperaron": "cooperare",
    "cooperarono": "cooperare",
    "cooperasse": "cooperare",
    "cooperasser": "cooperare",
    "cooperassero": "cooperare",
    "cooperassi": "cooperare",
    "cooperassimo": "cooperare",
    "cooperaste": "cooperare",
    "cooperasti": "cooperare",
    "cooperata": "cooperare",
    "cooperate": "cooperare",
    "cooperati": "cooperare",
    "cooperativa": "cooperativo",
    "cooperative": "cooperativo",
    "cooperativi": "cooperativo",
    "cooperativistica": "cooperativistico",
    "cooperativistiche": "cooperativistico",
    "cooperativistici": "cooperativistico",
    "cooperato": "cooperare",
    "cooperatori": "cooperatore",
    "cooperatrice": "cooperatore",
    "cooperatrici": "cooperatore",
    "cooperava": "cooperare",
    "cooperavamo": "cooperare",
    "cooperavan": "cooperare",
    "cooperavano": "cooperare",
    "cooperavate": "cooperare",
    "cooperavi": "cooperare",
    "cooperavo": "cooperare",
    "cooperazioni": "cooperazione",
    "coopererai": "cooperare",
    "coopereran": "cooperare",
    "coopereranno": "cooperare",
    "coopererebbe": "cooperare",
    "coopererebber": "cooperare",
    "coopererebbero": "cooperare",
    "coopererei": "cooperare",
    "coopereremmo": "cooperare",
    "coopereremo": "cooperare",
    "cooperereste": "cooperare",
    "coopereresti": "cooperare",
    "coopererete": "cooperare",
    "coopererà": "cooperare",
    "coopererò": "cooperare",
    "cooperi": "cooperare",
    "cooperiamo": "cooperare",
    "cooperiate": "cooperare",
    "cooperin": "cooperare",
    "cooperino": "cooperare",
    "coopero": "cooperare",
    "cooperò": "cooperare",
    "coopta": "cooptare",
    "cooptai": "cooptare",
    "cooptammo": "cooptare",
    "cooptan": "cooptare",
    "cooptando": "cooptare",
    "cooptano": "cooptare",
    "cooptante": "cooptare",
    "cooptanti": "cooptare",
    "cooptar": "cooptare",
    "cooptaron": "cooptare",
    "cooptarono": "cooptare",
    "cooptasse": "cooptare",
    "cooptasser": "cooptare",
    "cooptassero": "cooptare",
    "cooptassi": "cooptare",
    "cooptassimo": "cooptare",
    "cooptaste": "cooptare",
    "cooptasti": "cooptare",
    "cooptata": "cooptare",
    "cooptate": "cooptare",
    "cooptati": "cooptare",
    "cooptato": "cooptare",
    "cooptava": "cooptare",
    "cooptavamo": "cooptare",
    "cooptavan": "cooptare",
    "cooptavano": "cooptare",
    "cooptavate": "cooptare",
    "cooptavi": "cooptare",
    "cooptavo": "cooptare",
    "cooptazioni": "cooptazione",
    "coopterai": "cooptare",
    "coopteran": "cooptare",
    "coopteranno": "cooptare",
    "coopterebbe": "cooptare",
    "coopterebber": "cooptare",
    "coopterebbero": "cooptare",
    "coopterei": "cooptare",
    "coopteremmo": "cooptare",
    "coopteremo": "cooptare",
    "cooptereste": "cooptare",
    "coopteresti": "cooptare",
    "coopterete": "cooptare",
    "coopterà": "cooptare",
    "coopterò": "cooptare",
    "coopti": "cooptare",
    "cooptiamo": "cooptare",
    "cooptiate": "cooptare",
    "cooptin": "cooptare",
    "cooptino": "cooptare",
    "coopto": "cooptare",
    "cooptò": "cooptare",
    "coordina": "coordinare",
    "coordinai": "coordinare",
    "coordinamenti": "coordinamento",
    "coordinammo": "coordinare",
    "coordinan": "coordinare",
    "coordinando": "coordinare",
    "coordinano": "coordinare",
    "coordinante": "coordinare",
    "coordinanti": "coordinare",
    "coordinar": "coordinare",
    "coordinaron": "coordinare",
    "coordinarono": "coordinare",
    "coordinasse": "coordinare",
    "coordinasser": "coordinare",
    "coordinassero": "coordinare",
    "coordinassi": "coordinare",
    "coordinassimo": "coordinare",
    "coordinaste": "coordinare",
    "coordinasti": "coordinare",
    "coordinata": "coordinato",
    "coordinate": "coordinato",
    "coordinati": "coordinato",
    "coordinato": "coordinare",
    "coordinatori": "coordinatore",
    "coordinatrici": "coordinatrice",
    "coordinava": "coordinare",
    "coordinavamo": "coordinare",
    "coordinavan": "coordinare",
    "coordinavano": "coordinare",
    "coordinavate": "coordinare",
    "coordinavi": "coordinare",
    "coordinavo": "coordinare",
    "coordinazioni": "coordinazione",
    "coordinerai": "coordinare",
    "coordineran": "coordinare",
    "coordineranno": "coordinare",
    "coordinerebbe": "coordinare",
    "coordinerebber": "coordinare",
    "coordinerebbero": "coordinare",
    "coordinerei": "coordinare",
    "coordineremmo": "coordinare",
    "coordineremo": "coordinare",
    "coordinereste": "coordinare",
    "coordineresti": "coordinare",
    "coordinerete": "coordinare",
    "coordinerà": "coordinare",
    "coordinerò": "coordinare",
    "coordini": "coordinare",
    "coordiniamo": "coordinare",
    "coordiniate": "coordinare",
    "coordinin": "coordinare",
    "coordinino": "coordinare",
    "coordino": "coordinare",
    "coordinò": "coordinare",
    "coorti": "coorte",
    "copechi": "copeco",
    "coperchi": "coperchio",
    "copernicana": "copernicano",
    "copernicane": "copernicano",
    "copernicani": "copernicano",
    "coperta": "coprire",
    "coperte": "coprire",
    "coperti": "coprire",
    "copertine": "copertina",
    "coperto": "coprire",
    "copertoni": "copertone",
    "coperture": "copertura",
    "copi": "copiare",
    "copia": "copiare",
    "copiai": "copiare",
    "copiammo": "copiare",
    "copiamo": "copiare",
    "copian": "copiare",
    "copiando": "copiare",
    "copiano": "copiare",
    "copiante": "copiare",
    "copianti": "copiare",
    "copiar": "copiare",
    "copiaron": "copiare",
    "copiarono": "copiare",
    "copiasse": "copiare",
    "copiasser": "copiare",
    "copiassero": "copiare",
    "copiassi": "copiare",
    "copiassimo": "copiare",
    "copiaste": "copiare",
    "copiasti": "copiare",
    "copiata": "copiare",
    "copiate": "copiare",
    "copiati": "copiare",
    "copiato": "copiare",
    "copiava": "copiare",
    "copiavamo": "copiare",
    "copiavan": "copiare",
    "copiavano": "copiare",
    "copiavate": "copiare",
    "copiavi": "copiare",
    "copiavo": "copiare",
    "copie": "copia",
    "copierai": "copiare",
    "copieran": "copiare",
    "copieranno": "copiare",
    "copierebbe": "copiare",
    "copierebber": "copiare",
    "copierebbero": "copiare",
    "copierei": "copiare",
    "copieremmo": "copiare",
    "copieremo": "copiare",
    "copiereste": "copiare",
    "copieresti": "copiare",
    "copierete": "copiare",
    "copierà": "copiare",
    "copierò": "copiare",
    "copiloti": "copilota",
    "copin": "copiare",
    "copino": "copiare",
    "copio": "copiare",
    "copioni": "copione",
    "copiosa": "copioso",
    "copiose": "copioso",
    "copiosi": "copioso",
    "copisterie": "copisteria",
    "copisti": "copista",
    "copiò": "copiare",
    "coppe": "coppa",
    "coppette": "coppetta",
    "coppie": "coppia",
    "coppiette": "coppietta",
    "coppole": "coppola",
    "coppoliana": "coppoliano",
    "coppoliane": "coppoliano",
    "coppoliani": "coppoliano",
    "copra": "coprire",
    "copran": "coprire",
    "coprano": "coprire",
    "copre": "coprire",
    "coprendo": "coprire",
    "coprente": "coprire",
    "coprenti": "coprire",
    "copresidenti": "copresidente",
    "copri": "coprire",
    "copriamo": "coprire",
    "copriate": "coprire",
    "copricapi": "copricapo",
    "coprii": "coprire",
    "coprimmo": "coprire",
    "coprir": "coprire",
    "coprirai": "coprire",
    "copriran": "coprire",
    "copriranno": "coprire",
    "coprirebbe": "coprire",
    "coprirebber": "coprire",
    "coprirebbero": "coprire",
    "coprirei": "coprire",
    "copriremmo": "coprire",
    "copriremo": "coprire",
    "coprireste": "coprire",
    "copriresti": "coprire",
    "coprirete": "coprire",
    "copriron": "coprire",
    "coprirono": "coprire",
    "coprirà": "coprire",
    "coprirò": "coprire",
    "coprisse": "coprire",
    "coprisser": "coprire",
    "coprissero": "coprire",
    "coprissi": "coprire",
    "coprissimo": "coprire",
    "copriste": "coprire",
    "copristi": "coprire",
    "coprite": "coprire",
    "copriva": "coprire",
    "coprivamo": "coprire",
    "coprivan": "coprire",
    "coprivano": "coprire",
    "coprivate": "coprire",
    "coprivi": "coprire",
    "coprivo": "coprire",
    "copro": "coprire",
    "coproduca": "coprodurre",
    "coproducan": "coprodurre",
    "coproducano": "coprodurre",
    "coproduce": "coprodurre",
    "coproducei": "coprodurre",
    "coproducemmo": "coprodurre",
    "coproducendo": "coprodurre",
    "coproducente": "coprodurre",
    "coproducenti": "coprodurre",
    "coproducerai": "coprodurre",
    "coproduceran": "coprodurre",
    "coproduceranno": "coprodurre",
    "coproducerebbe": "coprodurre",
    "coproducerebber": "coprodurre",
    "coproducerebbero": "coprodurre",
    "coproducerei": "coprodurre",
    "coproduceremmo": "coprodurre",
    "coproduceremo": "coprodurre",
    "coproducereste": "coprodurre",
    "coproduceresti": "coprodurre",
    "coproducerete": "coprodurre",
    "coproduceron": "coprodurre",
    "coproducerono": "coprodurre",
    "coproducerà": "coprodurre",
    "coproducerò": "coprodurre",
    "coproducesse": "coprodurre",
    "coproducesser": "coprodurre",
    "coproducessero": "coprodurre",
    "coproducessi": "coprodurre",
    "coproducessimo": "coprodurre",
    "coproduceste": "coprodurre",
    "coproducesti": "coprodurre",
    "coproducete": "coprodurre",
    "coproduceva": "coprodurre",
    "coproducevamo": "coprodurre",
    "coproducevan": "coprodurre",
    "coproducevano": "coprodurre",
    "coproducevate": "coprodurre",
    "coproducevi": "coprodurre",
    "coproducevo": "coprodurre",
    "coproduci": "coprodurre",
    "coproduciamo": "coprodurre",
    "coproduciate": "coprodurre",
    "coproduciuta": "coprodurre",
    "coproduciute": "coprodurre",
    "coproduciuti": "coprodurre",
    "coproduciuto": "coprodurre",
    "coproduco": "coprodurre",
    "coproducon": "coprodurre",
    "coproducono": "coprodurre",
    "coproducè": "coprodurre",
    "coprodurr": "coprodurre",
    "coproduttori": "coproduttore",
    "coproduzioni": "coproduzione",
    "copron": "coprire",
    "coprono": "coprire",
    "coprotagoniste": "coprotagonista",
    "coprotagonisti": "coprotagonista",
    "coprì": "coprire",
    "copta": "copto",
    "copte": "copto",
    "copti": "copto",
    "copto-ortodossa": "copto-ortodosso",
    "copto-ortodosse": "copto-ortodosso",
    "copto-ortodossi": "copto-ortodosso",
    "coraggi": "coraggio",
    "coraggiosa": "coraggioso",
    "coraggiose": "coraggioso",
    "coraggiosi": "coraggioso",
    "corali": "corale",
    "coralli": "corallo",
    "corallina": "corallino",
    "coralline": "corallino",
    "corallini": "corallino",
    "corazza": "corazzare",
    "corazzai": "corazzare",
    "corazzammo": "corazzare",
    "corazzan": "corazzare",
    "corazzando": "corazzare",
    "corazzano": "corazzare",
    "corazzante": "corazzare",
    "corazzanti": "corazzare",
    "corazzar": "corazzare",
    "corazzaron": "corazzare",
    "corazzarono": "corazzare",
    "corazzasse": "corazzare",
    "corazzasser": "corazzare",
    "corazzassero": "corazzare",
    "corazzassi": "corazzare",
    "corazzassimo": "corazzare",
    "corazzaste": "corazzare",
    "corazzasti": "corazzare",
    "corazzata": "corazzato",
    "corazzate": "corazzato",
    "corazzati": "corazzato",
    "corazzato": "corazzare",
    "corazzava": "corazzare",
    "corazzavamo": "corazzare",
    "corazzavan": "corazzare",
    "corazzavano": "corazzare",
    "corazzavate": "corazzare",
    "corazzavi": "corazzare",
    "corazzavo": "corazzare",
    "corazze": "corazza",
    "corazzerai": "corazzare",
    "corazzeran": "corazzare",
    "corazzeranno": "corazzare",
    "corazzerebbe": "corazzare",
    "corazzerebber": "corazzare",
    "corazzerebbero": "corazzare",
    "corazzerei": "corazzare",
    "corazzeremmo": "corazzare",
    "corazzeremo": "corazzare",
    "corazzereste": "corazzare",
    "corazzeresti": "corazzare",
    "corazzerete": "corazzare",
    "corazzerà": "corazzare",
    "corazzerò": "corazzare",
    "corazzi": "corazzare",
    "corazziamo": "corazzare",
    "corazziate": "corazzare",
    "corazzieri": "corazziere",
    "corazzin": "corazzare",
    "corazzino": "corazzare",
    "corazzo": "corazzare",
    "corazzò": "corazzare",
    "corbella": "corbellare",
    "corbellai": "corbellare",
    "corbellammo": "corbellare",
    "corbellan": "corbellare",
    "corbellando": "corbellare",
    "corbellano": "corbellare",
    "corbellante": "corbellare",
    "corbellanti": "corbellare",
    "corbellar": "corbellare",
    "corbellaron": "corbellare",
    "corbellarono": "corbellare",
    "corbellasse": "corbellare",
    "corbellasser": "corbellare",
    "corbellassero": "corbellare",
    "corbellassi": "corbellare",
    "corbellassimo": "corbellare",
    "corbellaste": "corbellare",
    "corbellasti": "corbellare",
    "corbellata": "corbellare",
    "corbellate": "corbellare",
    "corbellati": "corbellare",
    "corbellato": "corbellare",
    "corbellava": "corbellare",
    "corbellavamo": "corbellare",
    "corbellavan": "corbellare",
    "corbellavano": "corbellare",
    "corbellavate": "corbellare",
    "corbellavi": "corbellare",
    "corbellavo": "corbellare",
    "corbellerai": "corbellare",
    "corbelleran": "corbellare",
    "corbelleranno": "corbellare",
    "corbellerebbe": "corbellare",
    "corbellerebber": "corbellare",
    "corbellerebbero": "corbellare",
    "corbellerei": "corbellare",
    "corbelleremmo": "corbellare",
    "corbelleremo": "corbellare",
    "corbellereste": "corbellare",
    "corbelleresti": "corbellare",
    "corbellerete": "corbellare",
    "corbellerie": "corbelleria",
    "corbellerà": "corbellare",
    "corbellerò": "corbellare",
    "corbelli": "corbellare",
    "corbelliamo": "corbellare",
    "corbelliate": "corbellare",
    "corbellin": "corbellare",
    "corbellino": "corbellare",
    "corbello": "corbellare",
    "corbellò": "corbellare",
    "corbezzoli": "corbezzolo",
    "cordate": "cordata",
    "corde": "corda",
    "cordiali": "cordiale",
    "cordicelle": "cordicella",
    "cordogli": "cordoglio",
    "cordoli": "cordolo",
    "cordoni": "cordone",
    "coreana": "coreano",
    "coreane": "coreano",
    "coreani": "coreano",
    "coreografa": "coreografare",
    "coreografai": "coreografare",
    "coreografammo": "coreografare",
    "coreografan": "coreografare",
    "coreografando": "coreografare",
    "coreografano": "coreografare",
    "coreografante": "coreografare",
    "coreografanti": "coreografare",
    "coreografar": "coreografare",
    "coreografaron": "coreografare",
    "coreografarono": "coreografare",
    "coreografasse": "coreografare",
    "coreografasser": "coreografare",
    "coreografassero": "coreografare",
    "coreografassi": "coreografare",
    "coreografassimo": "coreografare",
    "coreografaste": "coreografare",
    "coreografasti": "coreografare",
    "coreografata": "coreografare",
    "coreografate": "coreografare",
    "coreografati": "coreografare",
    "coreografato": "coreografare",
    "coreografava": "coreografare",
    "coreografavamo": "coreografare",
    "coreografavan": "coreografare",
    "coreografavano": "coreografare",
    "coreografavate": "coreografare",
    "coreografavi": "coreografare",
    "coreografavo": "coreografare",
    "coreografe": "coreografa",
    "coreograferai": "coreografare",
    "coreograferan": "coreografare",
    "coreograferanno": "coreografare",
    "coreograferebbe": "coreografare",
    "coreograferebber": "coreografare",
    "coreograferebbero": "coreografare",
    "coreograferei": "coreografare",
    "coreograferemmo": "coreografare",
    "coreograferemo": "coreografare",
    "coreografereste": "coreografare",
    "coreograferesti": "coreografare",
    "coreograferete": "coreografare",
    "coreograferà": "coreografare",
    "coreograferò": "coreografare",
    "coreografi": "coreografo",
    "coreografiamo": "coreografare",
    "coreografiate": "coreografare",
    "coreografica": "coreografico",
    "coreografiche": "coreografico",
    "coreografici": "coreografico",
    "coreografie": "coreografia",
    "coreografin": "coreografare",
    "coreografino": "coreografare",
    "coreografo": "coreografare",
    "coreografò": "coreografare",
    "coretti": "coretto",
    "cori": "coro",
    "coriacea": "coriaceo",
    "coriacee": "coriaceo",
    "coriacei": "coriaceo",
    "coriandoli": "coriandolo",
    "corica": "coricare",
    "coricai": "coricare",
    "coricammo": "coricare",
    "corican": "coricare",
    "coricando": "coricare",
    "coricano": "coricare",
    "coricante": "coricare",
    "coricanti": "coricare",
    "coricar": "coricare",
    "coricaron": "coricare",
    "coricarono": "coricare",
    "coricasse": "coricare",
    "coricasser": "coricare",
    "coricassero": "coricare",
    "coricassi": "coricare",
    "coricassimo": "coricare",
    "coricaste": "coricare",
    "coricasti": "coricare",
    "coricata": "coricare",
    "coricate": "coricare",
    "coricati": "coricare",
    "coricato": "coricare",
    "coricava": "coricare",
    "coricavamo": "coricare",
    "coricavan": "coricare",
    "coricavano": "coricare",
    "coricavate": "coricare",
    "coricavi": "coricare",
    "coricavo": "coricare",
    "coricherai": "coricare",
    "coricheran": "coricare",
    "coricheranno": "coricare",
    "coricherebbe": "coricare",
    "coricherebber": "coricare",
    "coricherebbero": "coricare",
    "coricherei": "coricare",
    "coricheremmo": "coricare",
    "coricheremo": "coricare",
    "corichereste": "coricare",
    "coricheresti": "coricare",
    "coricherete": "coricare",
    "coricherà": "coricare",
    "coricherò": "coricare",
    "corichi": "coricare",
    "corichiamo": "coricare",
    "corichiate": "coricare",
    "corichin": "coricare",
    "corichino": "coricare",
    "corico": "coricare",
    "coricò": "coricare",
    "corifei": "corifeo",
    "corinzi": "corinzio",
    "corinzia": "corinzio",
    "corinzie": "corinzio",
    "coriste": "corista",
    "coristi": "corista",
    "corleonesi": "corleonese",
    "cormorani": "cormorano",
    "corna": "corno",
    "cornacchie": "cornacchia",
    "cornamuse": "cornamusa",
    "cornee": "cornea",
    "cornette": "cornetta",
    "cornetti": "cornetto",
    "corni": "corno",
    "cornici": "cornice",
    "cornicioni": "cornicione",
    "cornifica": "cornificare",
    "cornificai": "cornificare",
    "cornificammo": "cornificare",
    "cornifican": "cornificare",
    "cornificando": "cornificare",
    "cornificano": "cornificare",
    "cornificante": "cornificare",
    "cornificanti": "cornificare",
    "cornificar": "cornificare",
    "cornificaron": "cornificare",
    "cornificarono": "cornificare",
    "cornificasse": "cornificare",
    "cornificasser": "cornificare",
    "cornificassero": "cornificare",
    "cornificassi": "cornificare",
    "cornificassimo": "cornificare",
    "cornificaste": "cornificare",
    "cornificasti": "cornificare",
    "cornificata": "cornificare",
    "cornificate": "cornificare",
    "cornificati": "cornificare",
    "cornificato": "cornificare",
    "cornificava": "cornificare",
    "cornificavamo": "cornificare",
    "cornificavan": "cornificare",
    "cornificavano": "cornificare",
    "cornificavate": "cornificare",
    "cornificavi": "cornificare",
    "cornificavo": "cornificare",
    "cornificherai": "cornificare",
    "cornificheran": "cornificare",
    "cornificheranno": "cornificare",
    "cornificherebbe": "cornificare",
    "cornificherebber": "cornificare",
    "cornificherebbero": "cornificare",
    "cornificherei": "cornificare",
    "cornificheremmo": "cornificare",
    "cornificheremo": "cornificare",
    "cornifichereste": "cornificare",
    "cornificheresti": "cornificare",
    "cornificherete": "cornificare",
    "cornificherà": "cornificare",
    "cornificherò": "cornificare",
    "cornifichi": "cornificare",
    "cornifichiamo": "cornificare",
    "cornifichiate": "cornificare",
    "cornifichin": "cornificare",
    "cornifichino": "cornificare",
    "cornifico": "cornificare",
    "cornificò": "cornificare",
    "cornucopie": "cornucopia",
    "cornuta": "cornuto",
    "cornute": "cornuto",
    "cornuti": "cornuto",
    "corollari": "corollario",
    "corolle": "corolla",
    "corona": "coronare",
    "coronai": "coronare",
    "coronamenti": "coronamento",
    "coronammo": "coronare",
    "coronan": "coronare",
    "coronando": "coronare",
    "coronano": "coronare",
    "coronante": "coronare",
    "coronanti": "coronare",
    "coronar": "coronare",
    "coronarica": "coronarico",
    "coronariche": "coronarico",
    "coronarici": "coronarico",
    "coronarie": "coronaria",
    "coronaron": "coronare",
    "coronarono": "coronare",
    "coronasse": "coronare",
    "coronasser": "coronare",
    "coronassero": "coronare",
    "coronassi": "coronare",
    "coronassimo": "coronare",
    "coronaste": "coronare",
    "coronasti": "coronare",
    "coronata": "coronare",
    "coronate": "coronare",
    "coronati": "coronare",
    "coronato": "coronare",
    "coronava": "coronare",
    "coronavamo": "coronare",
    "coronavan": "coronare",
    "coronavano": "coronare",
    "coronavate": "coronare",
    "coronavi": "coronare",
    "coronavo": "coronare",
    "coroncine": "coroncina",
    "corone": "corona",
    "coronerai": "coronare",
    "coroneran": "coronare",
    "coroneranno": "coronare",
    "coronerebbe": "coronare",
    "coronerebber": "coronare",
    "coronerebbero": "coronare",
    "coronerei": "coronare",
    "coroneremmo": "coronare",
    "coroneremo": "coronare",
    "coronereste": "coronare",
    "coroneresti": "coronare",
    "coronerete": "coronare",
    "coronerà": "coronare",
    "coronerò": "coronare",
    "coroni": "coronare",
    "coroniamo": "coronare",
    "coroniate": "coronare",
    "coronin": "coronare",
    "coronino": "coronare",
    "corono": "coronare",
    "coronò": "coronare",
    "corpaccioni": "corpaccione",
    "corpetti": "corpetto",
    "corpi": "corpo",
    "corpicini": "corpicino",
    "corpini": "corpino",
    "corpora": "corpus",
    "corporali": "corporale",
    "corporativa": "corporativo",
    "corporative": "corporativo",
    "corporativi": "corporativo",
    "corporativismi": "corporativismo",
    "corporature": "corporatura",
    "corporazioni": "corporazione",
    "corporea": "corporeo",
    "corporee": "corporeo",
    "corporei": "corporeo",
    "corposa": "corposo",
    "corpose": "corposo",
    "corposi": "corposo",
    "corpulenta": "corpulento",
    "corpulente": "corpulento",
    "corpulenti": "corpulento",
    "corpuscolari": "corpuscolare",
    "corpuscoli": "corpuscolo",
    "corr": "corre",
    "corra": "correre",
    "corran": "correre",
    "corrano": "correre",
    "corre": "correre",
    "correda": "corredare",
    "corredai": "corredare",
    "corredammo": "corredare",
    "corredan": "corredare",
    "corredando": "corredare",
    "corredano": "corredare",
    "corredante": "corredare",
    "corredanti": "corredare",
    "corredar": "corredare",
    "corredaron": "corredare",
    "corredarono": "corredare",
    "corredasse": "corredare",
    "corredasser": "corredare",
    "corredassero": "corredare",
    "corredassi": "corredare",
    "corredassimo": "corredare",
    "corredaste": "corredare",
    "corredasti": "corredare",
    "corredata": "corredare",
    "corredate": "corredare",
    "corredati": "corredare",
    "corredato": "corredare",
    "corredava": "corredare",
    "corredavamo": "corredare",
    "corredavan": "corredare",
    "corredavano": "corredare",
    "corredavate": "corredare",
    "corredavi": "corredare",
    "corredavo": "corredare",
    "correderai": "corredare",
    "correderan": "corredare",
    "correderanno": "corredare",
    "correderebbe": "corredare",
    "correderebber": "corredare",
    "correderebbero": "corredare",
    "correderei": "corredare",
    "correderemmo": "corredare",
    "correderemo": "corredare",
    "corredereste": "corredare",
    "correderesti": "corredare",
    "correderete": "corredare",
    "correderà": "corredare",
    "correderò": "corredare",
    "corredi": "corredo",
    "corrediamo": "corredare",
    "corrediate": "corredare",
    "corredin": "corredare",
    "corredino": "corredare",
    "corredo": "corredare",
    "corredò": "corredare",
    "corregga": "correggere",
    "correggan": "correggere",
    "correggano": "correggere",
    "corregge": "correggere",
    "correggemmo": "correggere",
    "correggendo": "correggere",
    "correggente": "correggere",
    "correggenti": "correggere",
    "corregger": "correggere",
    "correggerai": "correggere",
    "correggeran": "correggere",
    "correggeranno": "correggere",
    "correggerebbe": "correggere",
    "correggerebber": "correggere",
    "correggerebbero": "correggere",
    "correggerei": "correggere",
    "correggeremmo": "correggere",
    "correggeremo": "correggere",
    "correggereste": "correggere",
    "correggeresti": "correggere",
    "correggerete": "correggere",
    "correggerà": "correggere",
    "correggerò": "correggere",
    "correggesse": "correggere",
    "correggesser": "correggere",
    "correggessero": "correggere",
    "correggessi": "correggere",
    "correggessimo": "correggere",
    "correggeste": "correggere",
    "correggesti": "correggere",
    "correggete": "correggere",
    "correggeva": "correggere",
    "correggevamo": "correggere",
    "correggevan": "correggere",
    "correggevano": "correggere",
    "correggevate": "correggere",
    "correggevi": "correggere",
    "correggevo": "correggere",
    "correggi": "correggere",
    "correggiamo": "correggere",
    "correggiate": "correggere",
    "correggibili": "correggibile",
    "correggo": "correggere",
    "correggon": "correggere",
    "correggono": "correggere",
    "corregionali": "corregionale",
    "correla": "correlare",
    "correlai": "correlare",
    "correlammo": "correlare",
    "correlan": "correlare",
    "correlando": "correlare",
    "correlano": "correlare",
    "correlante": "correlare",
    "correlanti": "correlare",
    "correlar": "correlare",
    "correlaron": "correlare",
    "correlarono": "correlare",
    "correlasse": "correlare",
    "correlasser": "correlare",
    "correlassero": "correlare",
    "correlassi": "correlare",
    "correlassimo": "correlare",
    "correlaste": "correlare",
    "correlasti": "correlare",
    "correlata": "correlare",
    "correlate": "correlare",
    "correlati": "correlare",
    "correlativa": "correlativo",
    "correlative": "correlativo",
    "correlativi": "correlativo",
    "correlato": "correlare",
    "correlava": "correlare",
    "correlavamo": "correlare",
    "correlavan": "correlare",
    "correlavano": "correlare",
    "correlavate": "correlare",
    "correlavi": "correlare",
    "correlavo": "correlare",
    "correlazioni": "correlazione",
    "correlerai": "correlare",
    "correleran": "correlare",
    "correleranno": "correlare",
    "correlerebbe": "correlare",
    "correlerebber": "correlare",
    "correlerebbero": "correlare",
    "correlerei": "correlare",
    "correleremmo": "correlare",
    "correleremo": "correlare",
    "correlereste": "correlare",
    "correleresti": "correlare",
    "correlerete": "correlare",
    "correlerà": "correlare",
    "correlerò": "correlare",
    "correli": "correlare",
    "correliamo": "correlare",
    "correliate": "correlare",
    "correligionari": "correligionario",
    "correligionaria": "correligionario",
    "correligionarie": "correligionario",
    "correlin": "correlare",
    "correlino": "correlare",
    "correlo": "correlare",
    "correlò": "correlare",
    "corremmo": "correre",
    "correndo": "correre",
    "corrente": "correre",
    "correnti": "correre",
    "correntisti": "correntista",
    "correntizi": "correntizio",
    "correntizia": "correntizio",
    "correntizie": "correntizio",
    "correntoni": "correntone",
    "correr": "correre",
    "correrai": "correre",
    "correran": "correre",
    "correranno": "correre",
    "correrebbe": "correre",
    "correrebber": "correre",
    "correrebbero": "correre",
    "correrei": "correre",
    "correremmo": "correre",
    "correremo": "correre",
    "correreste": "correre",
    "correresti": "correre",
    "correrete": "correre",
    "correrà": "correre",
    "correrò": "correre",
    "corresponsabili": "corresponsabile",
    "corresponsioni": "corresponsione",
    "corresse": "correre",
    "corresser": "correre",
    "corressero": "correre",
    "corressi": "correre",
    "corressimo": "correre",
    "correste": "correre",
    "corresti": "correre",
    "correte": "correre",
    "corretta": "corretto",
    "corrette": "corretto",
    "correttezze": "correttezza",
    "corretti": "corretto",
    "correttiva": "correttivo",
    "correttive": "correttivo",
    "correttivi": "correttivo",
    "corretto": "correggere",
    "correttori": "correttore",
    "correva": "correre",
    "correvamo": "correre",
    "correvan": "correre",
    "correvano": "correre",
    "correvate": "correre",
    "correvi": "correre",
    "correvo": "correre",
    "correzioni": "correzione",
    "corri": "correre",
    "corriamo": "correre",
    "corriate": "correre",
    "corride": "corrida",
    "corridoi": "corridoio",
    "corridori": "corridore",
    "corriere": "corriera",
    "corrieri": "corriere",
    "corrimani": "corrimano",
    "corrispettiva": "corrispettivo",
    "corrispettive": "corrispettivo",
    "corrispettivi": "corrispettivo",
    "corrisponda": "corrispondere",
    "corrispondan": "corrispondere",
    "corrispondano": "corrispondere",
    "corrisponde": "corrispondere",
    "corrispondemmo": "corrispondere",
    "corrispondendo": "corrispondere",
    "corrispondente": "corrispondere",
    "corrispondenti": "corrispondere",
    "corrispondenze": "corrispondenza",
    "corrisponder": "corrispondere",
    "corrisponderai": "corrispondere",
    "corrisponderan": "corrispondere",
    "corrisponderanno": "corrispondere",
    "corrisponderebbe": "corrispondere",
    "corrisponderebber": "corrispondere",
    "corrisponderebbero": "corrispondere",
    "corrisponderei": "corrispondere",
    "corrisponderemmo": "corrispondere",
    "corrisponderemo": "corrispondere",
    "corrispondereste": "corrispondere",
    "corrisponderesti": "corrispondere",
    "corrisponderete": "corrispondere",
    "corrisponderà": "corrispondere",
    "corrisponderò": "corrispondere",
    "corrispondesse": "corrispondere",
    "corrispondesser": "corrispondere",
    "corrispondessero": "corrispondere",
    "corrispondessi": "corrispondere",
    "corrispondessimo": "corrispondere",
    "corrispondeste": "corrispondere",
    "corrispondesti": "corrispondere",
    "corrispondete": "corrispondere",
    "corrispondeva": "corrispondere",
    "corrispondevamo": "corrispondere",
    "corrispondevan": "corrispondere",
    "corrispondevano": "corrispondere",
    "corrispondevate": "corrispondere",
    "corrispondevi": "corrispondere",
    "corrispondevo": "corrispondere",
    "corrispondi": "corrispondere",
    "corrispondiamo": "corrispondere",
    "corrispondiate": "corrispondere",
    "corrispondo": "corrispondere",
    "corrispondon": "corrispondere",
    "corrispondono": "corrispondere",
    "corrisposer": "corrispondere",
    "corrisposero": "corrispondere",
    "corrisposi": "corrispondere",
    "corrisposta": "corrispondere",
    "corrisposte": "corrispondere",
    "corrisposti": "corrispondere",
    "corrisposto": "corrispondere",
    "corrisposè": "corrispondere",
    "corriva": "corrivo",
    "corrivai": "corrivare",
    "corrivammo": "corrivare",
    "corrivan": "corrivare",
    "corrivando": "corrivare",
    "corrivano": "corrivare",
    "corrivante": "corrivare",
    "corrivanti": "corrivare",
    "corrivar": "corrivare",
    "corrivaron": "corrivare",
    "corrivarono": "corrivare",
    "corrivasse": "corrivare",
    "corrivasser": "corrivare",
    "corrivassero": "corrivare",
    "corrivassi": "corrivare",
    "corrivassimo": "corrivare",
    "corrivaste": "corrivare",
    "corrivasti": "corrivare",
    "corrivata": "corrivare",
    "corrivate": "corrivare",
    "corrivati": "corrivare",
    "corrivato": "corrivare",
    "corrivava": "corrivare",
    "corrivavamo": "corrivare",
    "corrivavan": "corrivare",
    "corrivavano": "corrivare",
    "corrivavate": "corrivare",
    "corrivavi": "corrivare",
    "corrivavo": "corrivare",
    "corrive": "corrivo",
    "corriverai": "corrivare",
    "corriveran": "corrivare",
    "corriveranno": "corrivare",
    "corriverebbe": "corrivare",
    "corriverebber": "corrivare",
    "corriverebbero": "corrivare",
    "corriverei": "corrivare",
    "corriveremmo": "corrivare",
    "corriveremo": "corrivare",
    "corrivereste": "corrivare",
    "corriveresti": "corrivare",
    "corriverete": "corrivare",
    "corriverà": "corrivare",
    "corriverò": "corrivare",
    "corrivi": "corrivo",
    "corriviamo": "corrivare",
    "corriviate": "corrivare",
    "corrivin": "corrivare",
    "corrivino": "corrivare",
    "corrivo": "corrivare",
    "corrivò": "corrivare",
    "corro": "correre",
    "corrobora": "corroborare",
    "corroborai": "corroborare",
    "corroborammo": "corroborare",
    "corroboran": "corroborare",
    "corroborando": "corroborare",
    "corroborano": "corroborare",
    "corroborante": "corroborare",
    "corroboranti": "corroborare",
    "corroborar": "corroborare",
    "corroboraron": "corroborare",
    "corroborarono": "corroborare",
    "corroborasse": "corroborare",
    "corroborasser": "corroborare",
    "corroborassero": "corroborare",
    "corroborassi": "corroborare",
    "corroborassimo": "corroborare",
    "corroboraste": "corroborare",
    "corroborasti": "corroborare",
    "corroborata": "corroborare",
    "corroborate": "corroborare",
    "corroborati": "corroborare",
    "corroborato": "corroborare",
    "corroborava": "corroborare",
    "corroboravamo": "corroborare",
    "corroboravan": "corroborare",
    "corroboravano": "corroborare",
    "corroboravate": "corroborare",
    "corroboravi": "corroborare",
    "corroboravo": "corroborare",
    "corroborerai": "corroborare",
    "corroboreran": "corroborare",
    "corroboreranno": "corroborare",
    "corroborerebbe": "corroborare",
    "corroborerebber": "corroborare",
    "corroborerebbero": "corroborare",
    "corroborerei": "corroborare",
    "corroboreremmo": "corroborare",
    "corroboreremo": "corroborare",
    "corroborereste": "corroborare",
    "corroboreresti": "corroborare",
    "corroborerete": "corroborare",
    "corroborerà": "corroborare",
    "corroborerò": "corroborare",
    "corrobori": "corroborare",
    "corroboriamo": "corroborare",
    "corroboriate": "corroborare",
    "corroborin": "corroborare",
    "corroborino": "corroborare",
    "corroboro": "corroborare",
    "corroborò": "corroborare",
    "corroda": "corrodere",
    "corrodan": "corrodere",
    "corrodano": "corrodere",
    "corrode": "corrodere",
    "corrodemmo": "corrodere",
    "corrodendo": "corrodere",
    "corrodente": "corrodere",
    "corrodenti": "corrodere",
    "corroder": "corrodere",
    "corroderai": "corrodere",
    "corroderan": "corrodere",
    "corroderanno": "corrodere",
    "corroderebbe": "corrodere",
    "corroderebber": "corrodere",
    "corroderebbero": "corrodere",
    "corroderei": "corrodere",
    "corroderemmo": "corrodere",
    "corroderemo": "corrodere",
    "corrodereste": "corrodere",
    "corroderesti": "corrodere",
    "corroderete": "corrodere",
    "corroderà": "corrodere",
    "corroderò": "corrodere",
    "corrodesse": "corrodere",
    "corrodesser": "corrodere",
    "corrodessero": "corrodere",
    "corrodessi": "corrodere",
    "corrodessimo": "corrodere",
    "corrodeste": "corrodere",
    "corrodesti": "corrodere",
    "corrodete": "corrodere",
    "corrodeva": "corrodere",
    "corrodevamo": "corrodere",
    "corrodevan": "corrodere",
    "corrodevano": "corrodere",
    "corrodevate": "corrodere",
    "corrodevi": "corrodere",
    "corrodevo": "corrodere",
    "corrodi": "corrodere",
    "corrodiamo": "corrodere",
    "corrodiate": "corrodere",
    "corrodo": "corrodere",
    "corrodon": "corrodere",
    "corrodono": "corrodere",
    "corrompa": "corrompere",
    "corrompan": "corrompere",
    "corrompano": "corrompere",
    "corrompe": "corrompere",
    "corrompemmo": "corrompere",
    "corrompendo": "corrompere",
    "corrompente": "corrompere",
    "corrompenti": "corrompere",
    "corromper": "corrompere",
    "corromperai": "corrompere",
    "corromperan": "corrompere",
    "corromperanno": "corrompere",
    "corromperebbe": "corrompere",
    "corromperebber": "corrompere",
    "corromperebbero": "corrompere",
    "corromperei": "corrompere",
    "corromperemmo": "corrompere",
    "corromperemo": "corrompere",
    "corrompereste": "corrompere",
    "corromperesti": "corrompere",
    "corromperete": "corrompere",
    "corromperà": "corrompere",
    "corromperò": "corrompere",
    "corrompesse": "corrompere",
    "corrompesser": "corrompere",
    "corrompessero": "corrompere",
    "corrompessi": "corrompere",
    "corrompessimo": "corrompere",
    "corrompeste": "corrompere",
    "corrompesti": "corrompere",
    "corrompete": "corrompere",
    "corrompeva": "corrompere",
    "corrompevamo": "corrompere",
    "corrompevan": "corrompere",
    "corrompevano": "corrompere",
    "corrompevate": "corrompere",
    "corrompevi": "corrompere",
    "corrompevo": "corrompere",
    "corrompi": "corrompere",
    "corrompiamo": "corrompere",
    "corrompiate": "corrompere",
    "corrompo": "corrompere",
    "corrompon": "corrompere",
    "corrompono": "corrompere",
    "corron": "correre",
    "corrono": "correre",
    "corrosa": "corrodere",
    "corrose": "corrodere",
    "corroser": "corrodere",
    "corrosero": "corrodere",
    "corrosi": "corrodere",
    "corrosioni": "corrosione",
    "corrosiva": "corrosivo",
    "corrosive": "corrosivo",
    "corrosivi": "corrosivo",
    "corroso": "corrodere",
    "corrotta": "corrotto",
    "corrotte": "corrotto",
    "corrotti": "corrotto",
    "corrotto": "corrompere",
    "corruccerai": "corrucciare",
    "corrucceran": "corrucciare",
    "corrucceranno": "corrucciare",
    "corruccerebbe": "corrucciare",
    "corruccerebber": "corrucciare",
    "corruccerebbero": "corrucciare",
    "corruccerei": "corrucciare",
    "corrucceremmo": "corrucciare",
    "corrucceremo": "corrucciare",
    "corruccereste": "corrucciare",
    "corrucceresti": "corrucciare",
    "corruccerete": "corrucciare",
    "corruccerà": "corrucciare",
    "corruccerò": "corrucciare",
    "corrucci": "corrucciare",
    "corruccia": "corrucciare",
    "corrucciai": "corrucciare",
    "corrucciammo": "corrucciare",
    "corrucciamo": "corrucciare",
    "corruccian": "corrucciare",
    "corrucciando": "corrucciare",
    "corrucciano": "corrucciare",
    "corrucciante": "corrucciare",
    "corruccianti": "corrucciare",
    "corrucciar": "corrucciare",
    "corrucciaron": "corrucciare",
    "corrucciarono": "corrucciare",
    "corrucciasse": "corrucciare",
    "corrucciasser": "corrucciare",
    "corrucciassero": "corrucciare",
    "corrucciassi": "corrucciare",
    "corrucciassimo": "corrucciare",
    "corrucciaste": "corrucciare",
    "corrucciasti": "corrucciare",
    "corrucciata": "corrucciare",
    "corrucciate": "corrucciare",
    "corrucciati": "corrucciare",
    "corrucciato": "corrucciare",
    "corrucciava": "corrucciare",
    "corrucciavamo": "corrucciare",
    "corrucciavan": "corrucciare",
    "corrucciavano": "corrucciare",
    "corrucciavate": "corrucciare",
    "corrucciavi": "corrucciare",
    "corrucciavo": "corrucciare",
    "corruccin": "corrucciare",
    "corruccino": "corrucciare",
    "corruccio": "corrucciare",
    "corrucciò": "corrucciare",
    "corruga": "corrugare",
    "corrugai": "corrugare",
    "corrugammo": "corrugare",
    "corrugan": "corrugare",
    "corrugando": "corrugare",
    "corrugano": "corrugare",
    "corrugante": "corrugare",
    "corruganti": "corrugare",
    "corrugar": "corrugare",
    "corrugaron": "corrugare",
    "corrugarono": "corrugare",
    "corrugasse": "corrugare",
    "corrugasser": "corrugare",
    "corrugassero": "corrugare",
    "corrugassi": "corrugare",
    "corrugassimo": "corrugare",
    "corrugaste": "corrugare",
    "corrugasti": "corrugare",
    "corrugata": "corrugare",
    "corrugate": "corrugare",
    "corrugati": "corrugare",
    "corrugato": "corrugare",
    "corrugava": "corrugare",
    "corrugavamo": "corrugare",
    "corrugavan": "corrugare",
    "corrugavano": "corrugare",
    "corrugavate": "corrugare",
    "corrugavi": "corrugare",
    "corrugavo": "corrugare",
    "corrugherai": "corrugare",
    "corrugheran": "corrugare",
    "corrugheranno": "corrugare",
    "corrugherebbe": "corrugare",
    "corrugherebber": "corrugare",
    "corrugherebbero": "corrugare",
    "corrugherei": "corrugare",
    "corrugheremmo": "corrugare",
    "corrugheremo": "corrugare",
    "corrughereste": "corrugare",
    "corrugheresti": "corrugare",
    "corrugherete": "corrugare",
    "corrugherà": "corrugare",
    "corrugherò": "corrugare",
    "corrughi": "corrugare",
    "corrughiamo": "corrugare",
    "corrughiate": "corrugare",
    "corrughin": "corrugare",
    "corrughino": "corrugare",
    "corrugo": "corrugare",
    "corrugò": "corrugare",
    "corruppe": "corrompere",
    "corrupper": "corrompere",
    "corruppero": "corrompere",
    "corruppi": "corrompere",
    "corrusca": "corrusco",
    "corruscai": "corruscare",
    "corruscammo": "corruscare",
    "corruscan": "corruscare",
    "corruscando": "corruscare",
    "corruscano": "corruscare",
    "corruscante": "corruscare",
    "corruscanti": "corruscare",
    "corruscar": "corruscare",
    "corruscaron": "corruscare",
    "corruscarono": "corruscare",
    "corruscasse": "corruscare",
    "corruscasser": "corruscare",
    "corruscassero": "corruscare",
    "corruscassi": "corruscare",
    "corruscassimo": "corruscare",
    "corruscaste": "corruscare",
    "corruscasti": "corruscare",
    "corruscata": "corruscare",
    "corruscate": "corruscare",
    "corruscati": "corruscare",
    "corruscato": "corruscare",
    "corruscava": "corruscare",
    "corruscavamo": "corruscare",
    "corruscavan": "corruscare",
    "corruscavano": "corruscare",
    "corruscavate": "corruscare",
    "corruscavi": "corruscare",
    "corruscavo": "corruscare",
    "corrusche": "corrusco",
    "corruscherai": "corruscare",
    "corruscheran": "corruscare",
    "corruscheranno": "corruscare",
    "corruscherebbe": "corruscare",
    "corruscherebber": "corruscare",
    "corruscherebbero": "corruscare",
    "corruscherei": "corruscare",
    "corruscheremmo": "corruscare",
    "corruscheremo": "corruscare",
    "corruschereste": "corruscare",
    "corruscheresti": "corruscare",
    "corruscherete": "corruscare",
    "corruscherà": "corruscare",
    "corruscherò": "corruscare",
    "corruschi": "corrusco",
    "corruschiamo": "corruscare",
    "corruschiate": "corruscare",
    "corruschin": "corruscare",
    "corruschino": "corruscare",
    "corrusco": "corruscare",
    "corruscò": "corruscare",
    "corruttele": "corruttela",
    "corruttibili": "corruttibile",
    "corruttori": "corruttore",
    "corruttrice": "corruttore",
    "corruttrici": "corruttore",
    "corruzioni": "corruzione",
    "corsa": "corso",
    "corsara": "corsaro",
    "corsare": "corsaro",
    "corsari": "corsaro",
    "corse": "corso",
    "corser": "correre",
    "corsero": "correre",
    "corsette": "corsetta",
    "corsetti": "corsetto",
    "corsi": "corso",
    "corsie": "corsia",
    "corsivi": "corsivo",
    "corsivisti": "corsivista",
    "corso": "correre",
    "corta": "corto",
    "corte": "corto",
    "cortecce": "corteccia",
    "corteggerai": "corteggiare",
    "corteggeran": "corteggiare",
    "corteggeranno": "corteggiare",
    "corteggerebbe": "corteggiare",
    "corteggerebber": "corteggiare",
    "corteggerebbero": "corteggiare",
    "corteggerei": "corteggiare",
    "corteggeremmo": "corteggiare",
    "corteggeremo": "corteggiare",
    "corteggereste": "corteggiare",
    "corteggeresti": "corteggiare",
    "corteggerete": "corteggiare",
    "corteggerà": "corteggiare",
    "corteggerò": "corteggiare",
    "corteggi": "corteggiare",
    "corteggia": "corteggiare",
    "corteggiai": "corteggiare",
    "corteggiamenti": "corteggiamento",
    "corteggiammo": "corteggiare",
    "corteggiamo": "corteggiare",
    "corteggian": "corteggiare",
    "corteggiando": "corteggiare",
    "corteggiano": "corteggiare",
    "corteggiante": "corteggiare",
    "corteggianti": "corteggiare",
    "corteggiar": "corteggiare",
    "corteggiaron": "corteggiare",
    "corteggiarono": "corteggiare",
    "corteggiasse": "corteggiare",
    "corteggiasser": "corteggiare",
    "corteggiassero": "corteggiare",
    "corteggiassi": "corteggiare",
    "corteggiassimo": "corteggiare",
    "corteggiaste": "corteggiare",
    "corteggiasti": "corteggiare",
    "corteggiata": "corteggiare",
    "corteggiate": "corteggiare",
    "corteggiati": "corteggiare",
    "corteggiato": "corteggiare",
    "corteggiatori": "corteggiatore",
    "corteggiava": "corteggiare",
    "corteggiavamo": "corteggiare",
    "corteggiavan": "corteggiare",
    "corteggiavano": "corteggiare",
    "corteggiavate": "corteggiare",
    "corteggiavi": "corteggiare",
    "corteggiavo": "corteggiare",
    "corteggin": "corteggiare",
    "corteggino": "corteggiare",
    "corteggio": "corteggiare",
    "corteggiò": "corteggiare",
    "cortei": "corteo",
    "cortesi": "cortese",
    "cortesie": "cortesia",
    "corti": "corto",
    "cortigiana": "cortigiano",
    "cortigiane": "cortigiano",
    "cortigiani": "cortigiano",
    "cortiletti": "cortiletto",
    "cortili": "cortile",
    "cortine": "cortina",
    "cortinesi": "cortinese",
    "cortisoni": "cortisone",
    "cortocircuiti": "cortocircuito",
    "cortometraggi": "cortometraggio",
    "corvette": "corvetta",
    "corvi": "corvo",
    "corvina": "corvino",
    "corvine": "corvino",
    "corvini": "corvino",
    "cos'": "cosa",
    "cosacchi": "cosacco",
    "cosce": "coscia",
    "cosceneggiatori": "cosceneggiatore",
    "cosche": "cosca",
    "coscienti": "cosciente",
    "coscienze": "coscienza",
    "coscienziosa": "coscienzioso",
    "coscienziose": "coscienzioso",
    "coscienziosi": "coscienzioso",
    "cosciotti": "cosciotto",
    "coscritti": "coscritto",
    "coscriva": "coscrivere",
    "coscrivan": "coscrivere",
    "coscrivano": "coscrivere",
    "coscrive": "coscrivere",
    "coscrivei": "coscrivere",
    "coscrivemmo": "coscrivere",
    "coscrivendo": "coscrivere",
    "coscrivente": "coscrivere",
    "coscriventi": "coscrivere",
    "coscriver": "coscrivere",
    "coscriverai": "coscrivere",
    "coscriveran": "coscrivere",
    "coscriveranno": "coscrivere",
    "coscriverebbe": "coscrivere",
    "coscriverebber": "coscrivere",
    "coscriverebbero": "coscrivere",
    "coscriverei": "coscrivere",
    "coscriveremmo": "coscrivere",
    "coscriveremo": "coscrivere",
    "coscrivereste": "coscrivere",
    "coscriveresti": "coscrivere",
    "coscriverete": "coscrivere",
    "coscriveron": "coscrivere",
    "coscriverono": "coscrivere",
    "coscriverà": "coscrivere",
    "coscriverò": "coscrivere",
    "coscrivesse": "coscrivere",
    "coscrivesser": "coscrivere",
    "coscrivessero": "coscrivere",
    "coscrivessi": "coscrivere",
    "coscrivessimo": "coscrivere",
    "coscriveste": "coscrivere",
    "coscrivesti": "coscrivere",
    "coscrivete": "coscrivere",
    "coscriveva": "coscrivere",
    "coscrivevamo": "coscrivere",
    "coscrivevan": "coscrivere",
    "coscrivevano": "coscrivere",
    "coscrivevate": "coscrivere",
    "coscrivevi": "coscrivere",
    "coscrivevo": "coscrivere",
    "coscrivi": "coscrivere",
    "coscriviamo": "coscrivere",
    "coscriviate": "coscrivere",
    "coscrivo": "coscrivere",
    "coscrivon": "coscrivere",
    "coscrivono": "coscrivere",
    "coscrivuta": "coscrivere",
    "coscrivute": "coscrivere",
    "coscrivuti": "coscrivere",
    "coscrivuto": "coscrivere",
    "coscrivè": "coscrivere",
    "cose": "cosa",
    "cosentini": "cosentino",
    "cosette": "cosetta",
    "cosiddetta": "cosiddetto",
    "cosiddette": "cosiddetto",
    "cosiddetti": "cosiddetto",
    "cosine": "cosina",
    "cosmetica": "cosmetico",
    "cosmetiche": "cosmetico",
    "cosmetici": "cosmetico",
    "cosmi": "cosmo",
    "cosmica": "cosmico",
    "cosmiche": "cosmico",
    "cosmici": "cosmico",
    "cosmogonie": "cosmogonia",
    "cosmologi": "cosmologo",
    "cosmologica": "cosmologico",
    "cosmologiche": "cosmologico",
    "cosmologici": "cosmologico",
    "cosmologie": "cosmologia",
    "cosmonauti": "cosmonauta",
    "cosmopolite": "cosmopolita",
    "cosmopoliti": "cosmopolita",
    "cosmopolitismi": "cosmopolitismo",
    "cosparga": "cospargere",
    "cospargan": "cospargere",
    "cospargano": "cospargere",
    "cosparge": "cospargere",
    "cospargemmo": "cospargere",
    "cospargendo": "cospargere",
    "cospargente": "cospargere",
    "cospargenti": "cospargere",
    "cosparger": "cospargere",
    "cospargerai": "cospargere",
    "cospargeran": "cospargere",
    "cospargeranno": "cospargere",
    "cospargerebbe": "cospargere",
    "cospargerebber": "cospargere",
    "cospargerebbero": "cospargere",
    "cospargerei": "cospargere",
    "cospargeremmo": "cospargere",
    "cospargeremo": "cospargere",
    "cospargereste": "cospargere",
    "cospargeresti": "cospargere",
    "cospargerete": "cospargere",
    "cospargerà": "cospargere",
    "cospargerò": "cospargere",
    "cospargesse": "cospargere",
    "cospargesser": "cospargere",
    "cospargessero": "cospargere",
    "cospargessi": "cospargere",
    "cospargessimo": "cospargere",
    "cospargeste": "cospargere",
    "cospargesti": "cospargere",
    "cospargete": "cospargere",
    "cospargeva": "cospargere",
    "cospargevamo": "cospargere",
    "cospargevan": "cospargere",
    "cospargevano": "cospargere",
    "cospargevate": "cospargere",
    "cospargevi": "cospargere",
    "cospargevo": "cospargere",
    "cospargi": "cospargere",
    "cospargiamo": "cospargere",
    "cospargiate": "cospargere",
    "cospargo": "cospargere",
    "cospargon": "cospargere",
    "cospargono": "cospargere",
    "cosparsa": "cospargere",
    "cosparse": "cospargere",
    "cosparser": "cospargere",
    "cosparsero": "cospargere",
    "cosparsi": "cospargere",
    "cosparso": "cospargere",
    "cospetti": "cospetto",
    "cospicua": "cospicuo",
    "cospicue": "cospicuo",
    "cospicui": "cospicuo",
    "cospira": "cospirare",
    "cospirai": "cospirare",
    "cospirammo": "cospirare",
    "cospiran": "cospirare",
    "cospirando": "cospirare",
    "cospirano": "cospirare",
    "cospirante": "cospirare",
    "cospiranti": "cospirare",
    "cospirar": "cospirare",
    "cospiraron": "cospirare",
    "cospirarono": "cospirare",
    "cospirasse": "cospirare",
    "cospirasser": "cospirare",
    "cospirassero": "cospirare",
    "cospirassi": "cospirare",
    "cospirassimo": "cospirare",
    "cospiraste": "cospirare",
    "cospirasti": "cospirare",
    "cospirata": "cospirare",
    "cospirate": "cospirare",
    "cospirati": "cospirare",
    "cospirato": "cospirare",
    "cospiratori": "cospiratorio",
    "cospiratoria": "cospiratorio",
    "cospiratorie": "cospiratorio",
    "cospirava": "cospirare",
    "cospiravamo": "cospirare",
    "cospiravan": "cospirare",
    "cospiravano": "cospirare",
    "cospiravate": "cospirare",
    "cospiravi": "cospirare",
    "cospiravo": "cospirare",
    "cospirazioni": "cospirazione",
    "cospirerai": "cospirare",
    "cospireran": "cospirare",
    "cospireranno": "cospirare",
    "cospirerebbe": "cospirare",
    "cospirerebber": "cospirare",
    "cospirerebbero": "cospirare",
    "cospirerei": "cospirare",
    "cospireremmo": "cospirare",
    "cospireremo": "cospirare",
    "cospirereste": "cospirare",
    "cospireresti": "cospirare",
    "cospirerete": "cospirare",
    "cospirerà": "cospirare",
    "cospirerò": "cospirare",
    "cospiri": "cospirare",
    "cospiriamo": "cospirare",
    "cospiriate": "cospirare",
    "cospirin": "cospirare",
    "cospirino": "cospirare",
    "cospiro": "cospirare",
    "cospirò": "cospirare",
    "cosse": "cuocere",
    "cosser": "cuocere",
    "cossero": "cuocere",
    "cossi": "cuocere",
    "cossighiani": "cossighiano",
    "cossuttiana": "cossuttiano",
    "cossuttiane": "cossuttiano",
    "cossuttiani": "cossuttiano",
    "costa": "costare",
    "costai": "costare",
    "costammo": "costare",
    "costan": "costare",
    "costando": "costare",
    "costano": "costare",
    "costante": "costare",
    "costanti": "costare",
    "costantiniana": "costantiniano",
    "costantiniane": "costantiniano",
    "costantiniani": "costantiniano",
    "costanze": "costanza",
    "costar": "costare",
    "costaricana": "costaricano",
    "costaricane": "costaricano",
    "costaricani": "costaricano",
    "costaron": "costare",
    "costarono": "costare",
    "costasse": "costare",
    "costasser": "costare",
    "costassero": "costare",
    "costassi": "costare",
    "costassimo": "costare",
    "costaste": "costare",
    "costasti": "costare",
    "costata": "costatare",
    "costatai": "costatare",
    "costatammo": "costatare",
    "costatan": "costatare",
    "costatando": "costatare",
    "costatano": "costatare",
    "costatante": "costatare",
    "costatanti": "costatare",
    "costatar": "costatare",
    "costataron": "costatare",
    "costatarono": "costatare",
    "costatasse": "costatare",
    "costatasser": "costatare",
    "costatassero": "costatare",
    "costatassi": "costatare",
    "costatassimo": "costatare",
    "costataste": "costatare",
    "costatasti": "costatare",
    "costatata": "costatare",
    "costatate": "costatare",
    "costatati": "costatare",
    "costatato": "costatare",
    "costatava": "costatare",
    "costatavamo": "costatare",
    "costatavan": "costatare",
    "costatavano": "costatare",
    "costatavate": "costatare",
    "costatavi": "costatare",
    "costatavo": "costatare",
    "costatazioni": "costatazione",
    "costate": "costare",
    "costaterai": "costatare",
    "costateran": "costatare",
    "costateranno": "costatare",
    "costaterebbe": "costatare",
    "costaterebber": "costatare",
    "costaterebbero": "costatare",
    "costaterei": "costatare",
    "costateremmo": "costatare",
    "costateremo": "costatare",
    "costatereste": "costatare",
    "costateresti": "costatare",
    "costaterete": "costatare",
    "costaterà": "costatare",
    "costaterò": "costatare",
    "costati": "costatare",
    "costatiamo": "costatare",
    "costatiate": "costatare",
    "costatin": "costatare",
    "costatino": "costatare",
    "costato": "costatare",
    "costatò": "costatare",
    "costava": "costare",
    "costavamo": "costare",
    "costavan": "costare",
    "costavano": "costare",
    "costavate": "costare",
    "costavi": "costare",
    "costavo": "costare",
    "coste": "costa",
    "costeggerai": "costeggiare",
    "costeggeran": "costeggiare",
    "costeggeranno": "costeggiare",
    "costeggerebbe": "costeggiare",
    "costeggerebber": "costeggiare",
    "costeggerebbero": "costeggiare",
    "costeggerei": "costeggiare",
    "costeggeremmo": "costeggiare",
    "costeggeremo": "costeggiare",
    "costeggereste": "costeggiare",
    "costeggeresti": "costeggiare",
    "costeggerete": "costeggiare",
    "costeggerà": "costeggiare",
    "costeggerò": "costeggiare",
    "costeggi": "costeggiare",
    "costeggia": "costeggiare",
    "costeggiai": "costeggiare",
    "costeggiammo": "costeggiare",
    "costeggiamo": "costeggiare",
    "costeggian": "costeggiare",
    "costeggiando": "costeggiare",
    "costeggiano": "costeggiare",
    "costeggiante": "costeggiare",
    "costeggianti": "costeggiare",
    "costeggiar": "costeggiare",
    "costeggiaron": "costeggiare",
    "costeggiarono": "costeggiare",
    "costeggiasse": "costeggiare",
    "costeggiasser": "costeggiare",
    "costeggiassero": "costeggiare",
    "costeggiassi": "costeggiare",
    "costeggiassimo": "costeggiare",
    "costeggiaste": "costeggiare",
    "costeggiasti": "costeggiare",
    "costeggiata": "costeggiare",
    "costeggiate": "costeggiare",
    "costeggiati": "costeggiare",
    "costeggiato": "costeggiare",
    "costeggiava": "costeggiare",
    "costeggiavamo": "costeggiare",
    "costeggiavan": "costeggiare",
    "costeggiavano": "costeggiare",
    "costeggiavate": "costeggiare",
    "costeggiavi": "costeggiare",
    "costeggiavo": "costeggiare",
    "costeggin": "costeggiare",
    "costeggino": "costeggiare",
    "costeggio": "costeggiare",
    "costeggiò": "costeggiare",
    "costella": "costellare",
    "costellai": "costellare",
    "costellammo": "costellare",
    "costellan": "costellare",
    "costellando": "costellare",
    "costellano": "costellare",
    "costellante": "costellare",
    "costellanti": "costellare",
    "costellar": "costellare",
    "costellaron": "costellare",
    "costellarono": "costellare",
    "costellasse": "costellare",
    "costellasser": "costellare",
    "costellassero": "costellare",
    "costellassi": "costellare",
    "costellassimo": "costellare",
    "costellaste": "costellare",
    "costellasti": "costellare",
    "costellata": "costellare",
    "costellate": "costellare",
    "costellati": "costellare",
    "costellato": "costellare",
    "costellava": "costellare",
    "costellavamo": "costellare",
    "costellavan": "costellare",
    "costellavano": "costellare",
    "costellavate": "costellare",
    "costellavi": "costellare",
    "costellavo": "costellare",
    "costellazioni": "costellazione",
    "costellerai": "costellare",
    "costelleran": "costellare",
    "costelleranno": "costellare",
    "costellerebbe": "costellare",
    "costellerebber": "costellare",
    "costellerebbero": "costellare",
    "costellerei": "costellare",
    "costelleremmo": "costellare",
    "costelleremo": "costellare",
    "costellereste": "costellare",
    "costelleresti": "costellare",
    "costellerete": "costellare",
    "costellerà": "costellare",
    "costellerò": "costellare",
    "costelli": "costellare",
    "costelliamo": "costellare",
    "costelliate": "costellare",
    "costellin": "costellare",
    "costellino": "costellare",
    "costello": "costellare",
    "costellò": "costellare",
    "costerai": "costare",
    "costeran": "costare",
    "costeranno": "costare",
    "costerebbe": "costare",
    "costerebber": "costare",
    "costerebbero": "costare",
    "costerei": "costare",
    "costeremmo": "costare",
    "costeremo": "costare",
    "costereste": "costare",
    "costeresti": "costare",
    "costerete": "costare",
    "costerna": "costernare",
    "costernai": "costernare",
    "costernammo": "costernare",
    "costernan": "costernare",
    "costernando": "costernare",
    "costernano": "costernare",
    "costernante": "costernare",
    "costernanti": "costernare",
    "costernar": "costernare",
    "costernaron": "costernare",
    "costernarono": "costernare",
    "costernasse": "costernare",
    "costernasser": "costernare",
    "costernassero": "costernare",
    "costernassi": "costernare",
    "costernassimo": "costernare",
    "costernaste": "costernare",
    "costernasti": "costernare",
    "costernata": "costernato",
    "costernate": "costernato",
    "costernati": "costernato",
    "costernato": "costernare",
    "costernava": "costernare",
    "costernavamo": "costernare",
    "costernavan": "costernare",
    "costernavano": "costernare",
    "costernavate": "costernare",
    "costernavi": "costernare",
    "costernavo": "costernare",
    "costernazioni": "costernazione",
    "costernerai": "costernare",
    "costerneran": "costernare",
    "costerneranno": "costernare",
    "costernerebbe": "costernare",
    "costernerebber": "costernare",
    "costernerebbero": "costernare",
    "costernerei": "costernare",
    "costerneremmo": "costernare",
    "costerneremo": "costernare",
    "costernereste": "costernare",
    "costerneresti": "costernare",
    "costernerete": "costernare",
    "costernerà": "costernare",
    "costernerò": "costernare",
    "costerni": "costernare",
    "costerniamo": "costernare",
    "costerniate": "costernare",
    "costernin": "costernare",
    "costernino": "costernare",
    "costerno": "costernare",
    "costernò": "costernare",
    "costerà": "costare",
    "costerò": "costare",
    "costi": "costo",
    "costiamo": "costare",
    "costiate": "costare",
    "costiera": "costiero",
    "costiere": "costiero",
    "costieri": "costiero",
    "costin": "costare",
    "costino": "costare",
    "costipa": "costipare",
    "costipai": "costipare",
    "costipammo": "costipare",
    "costipan": "costipare",
    "costipando": "costipare",
    "costipano": "costipare",
    "costipante": "costipare",
    "costipanti": "costipare",
    "costipar": "costipare",
    "costiparon": "costipare",
    "costiparono": "costipare",
    "costipasse": "costipare",
    "costipasser": "costipare",
    "costipassero": "costipare",
    "costipassi": "costipare",
    "costipassimo": "costipare",
    "costipaste": "costipare",
    "costipasti": "costipare",
    "costipata": "costipare",
    "costipate": "costipare",
    "costipati": "costipare",
    "costipato": "costipare",
    "costipava": "costipare",
    "costipavamo": "costipare",
    "costipavan": "costipare",
    "costipavano": "costipare",
    "costipavate": "costipare",
    "costipavi": "costipare",
    "costipavo": "costipare",
    "costiperai": "costipare",
    "costiperan": "costipare",
    "costiperanno": "costipare",
    "costiperebbe": "costipare",
    "costiperebber": "costipare",
    "costiperebbero": "costipare",
    "costiperei": "costipare",
    "costiperemmo": "costipare",
    "costiperemo": "costipare",
    "costipereste": "costipare",
    "costiperesti": "costipare",
    "costiperete": "costipare",
    "costiperà": "costipare",
    "costiperò": "costipare",
    "costipi": "costipare",
    "costipiamo": "costipare",
    "costipiate": "costipare",
    "costipin": "costipare",
    "costipino": "costipare",
    "costipo": "costipare",
    "costipò": "costipare",
    "costituenda": "costituendo",
    "costituende": "costituendo",
    "costituendi": "costituendo",
    "costituendo": "costituire",
    "costituente": "costituire",
    "costituenti": "costituire",
    "costituiamo": "costituire",
    "costituiate": "costituire",
    "costituii": "costituire",
    "costituimmo": "costituire",
    "costituir": "costituire",
    "costituirai": "costituire",
    "costituiran": "costituire",
    "costituiranno": "costituire",
    "costituirebbe": "costituire",
    "costituirebber": "costituire",
    "costituirebbero": "costituire",
    "costituirei": "costituire",
    "costituiremmo": "costituire",
    "costituiremo": "costituire",
    "costituireste": "costituire",
    "costituiresti": "costituire",
    "costituirete": "costituire",
    "costituiron": "costituire",
    "costituirono": "costituire",
    "costituirà": "costituire",
    "costituirò": "costituire",
    "costituisca": "costituire",
    "costituiscan": "costituire",
    "costituiscano": "costituire",
    "costituisce": "costituire",
    "costituisci": "costituire",
    "costituisco": "costituire",
    "costituiscon": "costituire",
    "costituiscono": "costituire",
    "costituisse": "costituire",
    "costituisser": "costituire",
    "costituissero": "costituire",
    "costituissi": "costituire",
    "costituissimo": "costituire",
    "costituiste": "costituire",
    "costituisti": "costituire",
    "costituita": "costituito",
    "costituite": "costituito",
    "costituiti": "costituito",
    "costituito": "costituire",
    "costituiva": "costituire",
    "costituivamo": "costituire",
    "costituivan": "costituire",
    "costituivano": "costituire",
    "costituivate": "costituire",
    "costituivi": "costituire",
    "costituivo": "costituire",
    "costituta": "costituto",
    "costitute": "costituto",
    "costituti": "costituto",
    "costitutiva": "costitutivo",
    "costitutive": "costitutivo",
    "costitutivi": "costitutivo",
    "costituzionali": "costituzionale",
    "costituzionalismi": "costituzionalismo",
    "costituzionaliste": "costituzionalista",
    "costituzionalisti": "costituzionalista",
    "costituzionalizzata": "costituzionalizzato",
    "costituzionalizzate": "costituzionalizzato",
    "costituzionalizzati": "costituzionalizzato",
    "costituzioni": "costituzione",
    "costituì": "costituire",
    "costo": "costare",
    "costole": "costola",
    "costoni": "costone",
    "costosa": "costoso",
    "costose": "costoso",
    "costosi": "costoso",
    "costretta": "costringere",
    "costrette": "costringere",
    "costretti": "costringere",
    "costretto": "costringere",
    "costringa": "costringere",
    "costringan": "costringere",
    "costringano": "costringere",
    "costringe": "costringere",
    "costringemmo": "costringere",
    "costringendo": "costringere",
    "costringente": "costringere",
    "costringenti": "costringere",
    "costringer": "costringere",
    "costringerai": "costringere",
    "costringeran": "costringere",
    "costringeranno": "costringere",
    "costringerebbe": "costringere",
    "costringerebber": "costringere",
    "costringerebbero": "costringere",
    "costringerei": "costringere",
    "costringeremmo": "costringere",
    "costringeremo": "costringere",
    "costringereste": "costringere",
    "costringeresti": "costringere",
    "costringerete": "costringere",
    "costringerà": "costringere",
    "costringerò": "costringere",
    "costringesse": "costringere",
    "costringesser": "costringere",
    "costringessero": "costringere",
    "costringessi": "costringere",
    "costringessimo": "costringere",
    "costringeste": "costringere",
    "costringesti": "costringere",
    "costringete": "costringere",
    "costringeva": "costringere",
    "costringevamo": "costringere",
    "costringevan": "costringere",
    "costringevano": "costringere",
    "costringevate": "costringere",
    "costringevi": "costringere",
    "costringevo": "costringere",
    "costringi": "costringere",
    "costringiamo": "costringere",
    "costringiate": "costringere",
    "costringo": "costringere",
    "costringon": "costringere",
    "costringono": "costringere",
    "costrinse": "costringere",
    "costrinser": "costringere",
    "costrinsero": "costringere",
    "costrinsi": "costringere",
    "costrittiva": "costrittivo",
    "costrittive": "costrittivo",
    "costrittivi": "costrittivo",
    "costrizioni": "costrizione",
    "costruendo": "costruire",
    "costruente": "costruire",
    "costruenti": "costruire",
    "costruiamo": "costruire",
    "costruiate": "costruire",
    "costruibili": "costruibile",
    "costruii": "costruire",
    "costruimmo": "costruire",
    "costruir": "costruire",
    "costruirai": "costruire",
    "costruiran": "costruire",
    "costruiranno": "costruire",
    "costruirebbe": "costruire",
    "costruirebber": "costruire",
    "costruirebbero": "costruire",
    "costruirei": "costruire",
    "costruiremmo": "costruire",
    "costruiremo": "costruire",
    "costruireste": "costruire",
    "costruiresti": "costruire",
    "costruirete": "costruire",
    "costruiron": "costruire",
    "costruirono": "costruire",
    "costruirà": "costruire",
    "costruirò": "costruire",
    "costruisca": "costruire",
    "costruiscan": "costruire",
    "costruiscano": "costruire",
    "costruisce": "costruire",
    "costruisci": "costruire",
    "costruisco": "costruire",
    "costruiscon": "costruire",
    "costruiscono": "costruire",
    "costruisse": "costruire",
    "costruisser": "costruire",
    "costruissero": "costruire",
    "costruissi": "costruire",
    "costruissimo": "costruire",
    "costruiste": "costruire",
    "costruisti": "costruire",
    "costruita": "costruire",
    "costruite": "costruire",
    "costruiti": "costruire",
    "costruito": "costruire",
    "costruiva": "costruire",
    "costruivamo": "costruire",
    "costruivan": "costruire",
    "costruivano": "costruire",
    "costruivate": "costruire",
    "costruivi": "costruire",
    "costruivo": "costruire",
    "costrutti": "costrutto",
    "costruttiva": "costruttivo",
    "costruttive": "costruttivo",
    "costruttivi": "costruttivo",
    "costruttivismi": "costruttivismo",
    "costruttori": "costruttore",
    "costruttrice": "costruttore",
    "costruttrici": "costruttore",
    "costruzioni": "costruzione",
    "costruì": "costruire",
    "costuma": "costumare",
    "costumai": "costumare",
    "costumammo": "costumare",
    "costuman": "costumare",
    "costumando": "costumare",
    "costumano": "costumare",
    "costumante": "costumare",
    "costumanti": "costumare",
    "costumanze": "costumanza",
    "costumar": "costumare",
    "costumaron": "costumare",
    "costumarono": "costumare",
    "costumasse": "costumare",
    "costumasser": "costumare",
    "costumassero": "costumare",
    "costumassi": "costumare",
    "costumassimo": "costumare",
    "costumaste": "costumare",
    "costumasti": "costumare",
    "costumata": "costumato",
    "costumate": "costumato",
    "costumati": "costumato",
    "costumato": "costumare",
    "costumava": "costumare",
    "costumavamo": "costumare",
    "costumavan": "costumare",
    "costumavano": "costumare",
    "costumavate": "costumare",
    "costumavi": "costumare",
    "costumavo": "costumare",
    "costumerai": "costumare",
    "costumeran": "costumare",
    "costumeranno": "costumare",
    "costumerebbe": "costumare",
    "costumerebber": "costumare",
    "costumerebbero": "costumare",
    "costumerei": "costumare",
    "costumeremmo": "costumare",
    "costumeremo": "costumare",
    "costumereste": "costumare",
    "costumeresti": "costumare",
    "costumerete": "costumare",
    "costumerà": "costumare",
    "costumerò": "costumare",
    "costumi": "costume",
    "costumiamo": "costumare",
    "costumiate": "costumare",
    "costumin": "costumare",
    "costumini": "costumino",
    "costumino": "costumare",
    "costumiste": "costumista",
    "costumisti": "costumista",
    "costumo": "costumare",
    "costumò": "costumare",
    "costò": "costare",
    "cosucce": "cosuccia",
    "cotanta": "cotanto",
    "cotante": "cotanto",
    "cotanti": "cotanto",
    "cotemmo": "scuotere",
    "cotesse": "scuotere",
    "cotessero": "scuotere",
    "cotessi": "scuotere",
    "cotessimo": "scuotere",
    "coteste": "scuotere",
    "cotesti": "scuotere",
    "cotete": "scuotere",
    "coteva": "scuotere",
    "cotevamo": "scuotere",
    "cotevano": "scuotere",
    "cotevate": "scuotere",
    "cotevi": "scuotere",
    "cotevo": "scuotere",
    "cotiamo": "scuotere",
    "cotiate": "scuotere",
    "cotolette": "cotoletta",
    "cotona": "cotonare",
    "cotonai": "cotonare",
    "cotonammo": "cotonare",
    "cotonan": "cotonare",
    "cotonando": "cotonare",
    "cotonano": "cotonare",
    "cotonante": "cotonare",
    "cotonanti": "cotonare",
    "cotonar": "cotonare",
    "cotonaron": "cotonare",
    "cotonarono": "cotonare",
    "cotonasse": "cotonare",
    "cotonasser": "cotonare",
    "cotonassero": "cotonare",
    "cotonassi": "cotonare",
    "cotonassimo": "cotonare",
    "cotonaste": "cotonare",
    "cotonasti": "cotonare",
    "cotonata": "cotonare",
    "cotonate": "cotonare",
    "cotonati": "cotonare",
    "cotonato": "cotonare",
    "cotonava": "cotonare",
    "cotonavamo": "cotonare",
    "cotonavan": "cotonare",
    "cotonavano": "cotonare",
    "cotonavate": "cotonare",
    "cotonavi": "cotonare",
    "cotonavo": "cotonare",
    "cotonerai": "cotonare",
    "cotoneran": "cotonare",
    "cotoneranno": "cotonare",
    "cotonerebbe": "cotonare",
    "cotonerebber": "cotonare",
    "cotonerebbero": "cotonare",
    "cotonerei": "cotonare",
    "cotoneremmo": "cotonare",
    "cotoneremo": "cotonare",
    "cotonereste": "cotonare",
    "cotoneresti": "cotonare",
    "cotonerete": "cotonare",
    "cotonerà": "cotonare",
    "cotonerò": "cotonare",
    "cotoni": "cotone",
    "cotoniamo": "cotonare",
    "cotoniate": "cotonare",
    "cotoniera": "cotoniero",
    "cotoniere": "cotoniero",
    "cotonieri": "cotoniero",
    "cotonifici": "cotonificio",
    "cotonin": "cotonare",
    "cotonino": "cotonare",
    "cotono": "cotonare",
    "cotonò": "cotonare",
    "cotta": "cuocere",
    "cotte": "cuocere",
    "cotti": "cuocere",
    "cotto": "cuocere",
    "cotture": "cottura",
    "coturni": "coturno",
    "coutures": "couture",
    "cova": "covare",
    "covai": "covare",
    "covammo": "covare",
    "covan": "covare",
    "covando": "covare",
    "covano": "covare",
    "covante": "covare",
    "covanti": "covare",
    "covar": "covare",
    "covaron": "covare",
    "covarono": "covare",
    "covasse": "covare",
    "covasser": "covare",
    "covassero": "covare",
    "covassi": "covare",
    "covassimo": "covare",
    "covaste": "covare",
    "covasti": "covare",
    "covata": "covare",
    "covate": "covata",
    "covati": "covare",
    "covato": "covare",
    "covava": "covare",
    "covavamo": "covare",
    "covavan": "covare",
    "covavano": "covare",
    "covavate": "covare",
    "covavi": "covare",
    "covavo": "covare",
    "coverai": "covare",
    "coveran": "covare",
    "coveranno": "covare",
    "coverebbe": "covare",
    "coverebber": "covare",
    "coverebbero": "covare",
    "coverei": "covare",
    "coveremmo": "covare",
    "coveremo": "covare",
    "covereste": "covare",
    "coveresti": "covare",
    "coverete": "covare",
    "coverà": "covare",
    "coverò": "covare",
    "covi": "covo",
    "coviamo": "covare",
    "coviate": "covare",
    "covin": "covare",
    "covino": "covare",
    "covo": "covare",
    "covoni": "covone",
    "covò": "covare",
    "cozza": "cozzare",
    "cozzai": "cozzare",
    "cozzammo": "cozzare",
    "cozzan": "cozzare",
    "cozzando": "cozzare",
    "cozzano": "cozzare",
    "cozzante": "cozzare",
    "cozzanti": "cozzare",
    "cozzar": "cozzare",
    "cozzaron": "cozzare",
    "cozzarono": "cozzare",
    "cozzasse": "cozzare",
    "cozzasser": "cozzare",
    "cozzassero": "cozzare",
    "cozzassi": "cozzare",
    "cozzassimo": "cozzare",
    "cozzaste": "cozzare",
    "cozzasti": "cozzare",
    "cozzata": "cozzare",
    "cozzate": "cozzare",
    "cozzati": "cozzare",
    "cozzato": "cozzare",
    "cozzava": "cozzare",
    "cozzavamo": "cozzare",
    "cozzavan": "cozzare",
    "cozzavano": "cozzare",
    "cozzavate": "cozzare",
    "cozzavi": "cozzare",
    "cozzavo": "cozzare",
    "cozze": "cozza",
    "cozzerai": "cozzare",
    "cozzeran": "cozzare",
    "cozzeranno": "cozzare",
    "cozzerebbe": "cozzare",
    "cozzerebber": "cozzare",
    "cozzerebbero": "cozzare",
    "cozzerei": "cozzare",
    "cozzeremmo": "cozzare",
    "cozzeremo": "cozzare",
    "cozzereste": "cozzare",
    "cozzeresti": "cozzare",
    "cozzerete": "cozzare",
    "cozzerà": "cozzare",
    "cozzerò": "cozzare",
    "cozzi": "cozzo",
    "cozziamo": "cozzare",
    "cozziate": "cozzare",
    "cozzin": "cozzare",
    "cozzino": "cozzare",
    "cozzo": "cozzare",
    "cozzò": "cozzare",
    "cragnottiana": "cragnottiano",
    "cragnottiane": "cragnottiano",
    "cragnottiani": "cragnottiano",
    "crampi": "crampo",
    "crani": "cranio",
    "cranica": "cranico",
    "craniche": "cranico",
    "cranici": "cranico",
    "crassa": "crasso",
    "crasse": "crasso",
    "crassi": "crasso",
    "crateri": "cratere",
    "cravattari": "cravattaro",
    "cravatte": "cravatta",
    "cravattini": "cravattino",
    "craxiana": "craxiano",
    "craxiane": "craxiano",
    "craxiani": "craxiano",
    "craxismi": "craxismo",
    "craxiste": "craxista",
    "craxisti": "craxista",
    "crea": "creare",
    "creai": "creare",
    "creammo": "creare",
    "crean": "creare",
    "creando": "creare",
    "creano": "creare",
    "creante": "creare",
    "creanti": "creare",
    "creanze": "creanza",
    "crear": "creare",
    "crearon": "creare",
    "crearono": "creare",
    "creasse": "creare",
    "creasser": "creare",
    "creassero": "creare",
    "creassi": "creare",
    "creassimo": "creare",
    "creaste": "creare",
    "creasti": "creare",
    "creata": "creare",
    "create": "creare",
    "creati": "creare",
    "creatine": "creatina",
    "creativa": "creativo",
    "creative": "creativo",
    "creativi": "creativo",
    "creato": "creare",
    "creatori": "creatore",
    "creatrice": "creatore",
    "creatrici": "creatrice",
    "creature": "creatura",
    "creaturine": "creaturina",
    "creava": "creare",
    "creavamo": "creare",
    "creavan": "creare",
    "creavano": "creare",
    "creavate": "creare",
    "creavi": "creare",
    "creavo": "creare",
    "creazioni": "creazione",
    "crebbe": "crescere",
    "crebber": "crescere",
    "crebbero": "crescere",
    "crebbi": "crescere",
    "creda": "credere",
    "credan": "credere",
    "credano": "credere",
    "crede": "credere",
    "credei": "credere",
    "credemmo": "credere",
    "credendo": "credere",
    "credente": "credere",
    "credenti": "credere",
    "credenze": "credenza",
    "credenziali": "credenziale",
    "creder": "credere",
    "crederai": "credere",
    "crederan": "credere",
    "crederanno": "credere",
    "crederebbe": "credere",
    "crederebber": "credere",
    "crederebbero": "credere",
    "crederei": "credere",
    "crederemmo": "credere",
    "crederemo": "credere",
    "credereste": "credere",
    "crederesti": "credere",
    "crederete": "credere",
    "crederono": "credere",
    "crederà": "credere",
    "crederò": "credere",
    "credesse": "credere",
    "credesser": "credere",
    "credessero": "credere",
    "credessi": "credere",
    "credessimo": "credere",
    "credeste": "credere",
    "credesti": "credere",
    "credete": "credere",
    "credette": "ricredere",
    "credettero": "ricredere",
    "credetti": "ricredere",
    "credeva": "credere",
    "credevamo": "credere",
    "credevan": "credere",
    "credevano": "credere",
    "credevate": "credere",
    "credevi": "credere",
    "credevo": "credere",
    "credi": "credere",
    "crediamo": "credere",
    "crediate": "credere",
    "credibili": "credibile",
    "crediti": "credito",
    "creditizi": "creditizio",
    "creditizia": "creditizio",
    "creditizie": "creditizio",
    "creditori": "creditore",
    "creditrice": "creditore",
    "creditrici": "creditore",
    "credo": "credere",
    "credon": "credere",
    "credono": "credere",
    "credula": "credulo",
    "credule": "credulo",
    "creduli": "credulo",
    "creduloni": "credulone",
    "creduta": "credere",
    "credute": "credere",
    "creduti": "credere",
    "creduto": "credere",
    "credè": "credere",
    "creerai": "creare",
    "creeran": "creare",
    "creeranno": "creare",
    "creerebbe": "creare",
    "creerebber": "creare",
    "creerebbero": "creare",
    "creerei": "creare",
    "creeremmo": "creare",
    "creeremo": "creare",
    "creereste": "creare",
    "creeresti": "creare",
    "creerete": "creare",
    "creerà": "creare",
    "creerò": "creare",
    "crei": "creare",
    "creiamo": "creare",
    "creiate": "creare",
    "crein": "creare",
    "creino": "creare",
    "crema": "cremare",
    "cremai": "cremare",
    "cremammo": "cremare",
    "creman": "cremare",
    "cremando": "cremare",
    "cremano": "cremare",
    "cremante": "cremare",
    "cremanti": "cremare",
    "cremar": "cremare",
    "cremaron": "cremare",
    "cremarono": "cremare",
    "cremasse": "cremare",
    "cremasser": "cremare",
    "cremassero": "cremare",
    "cremassi": "cremare",
    "cremassimo": "cremare",
    "cremaste": "cremare",
    "cremasti": "cremare",
    "cremata": "cremare",
    "cremate": "cremare",
    "cremati": "cremare",
    "cremato": "cremare",
    "crematori": "crematorio",
    "cremava": "cremare",
    "cremavamo": "cremare",
    "cremavan": "cremare",
    "cremavano": "cremare",
    "cremavate": "cremare",
    "cremavi": "cremare",
    "cremavo": "cremare",
    "cremazioni": "cremazione",
    "creme": "crema",
    "cremerai": "cremare",
    "cremeran": "cremare",
    "cremeranno": "cremare",
    "cremerebbe": "cremare",
    "cremerebber": "cremare",
    "cremerebbero": "cremare",
    "cremerei": "cremare",
    "cremeremmo": "cremare",
    "cremeremo": "cremare",
    "cremereste": "cremare",
    "cremeresti": "cremare",
    "cremerete": "cremare",
    "cremerà": "cremare",
    "cremerò": "cremare",
    "cremi": "cremare",
    "cremiamo": "cremare",
    "cremiate": "cremare",
    "cremin": "cremare",
    "cremino": "cremare",
    "cremo": "cremare",
    "cremonesi": "cremonese",
    "cremosa": "cremoso",
    "cremose": "cremoso",
    "cremosi": "cremoso",
    "cremò": "cremare",
    "creo": "creare",
    "creoli": "creolo",
    "crepa": "crepare",
    "crepacci": "crepaccio",
    "crepai": "crepare",
    "crepammo": "crepare",
    "crepan": "crepare",
    "crepando": "crepare",
    "crepano": "crepare",
    "crepante": "crepare",
    "crepanti": "crepare",
    "crepar": "crepare",
    "creparon": "crepare",
    "creparono": "crepare",
    "crepasse": "crepare",
    "crepasser": "crepare",
    "crepassero": "crepare",
    "crepassi": "crepare",
    "crepassimo": "crepare",
    "crepaste": "crepare",
    "crepasti": "crepare",
    "crepata": "crepare",
    "crepate": "crepare",
    "crepati": "crepare",
    "crepato": "crepare",
    "crepava": "crepare",
    "crepavamo": "crepare",
    "crepavan": "crepare",
    "crepavano": "crepare",
    "crepavate": "crepare",
    "crepavi": "crepare",
    "crepavo": "crepare",
    "crepe": "crepa",
    "creperai": "crepare",
    "creperan": "crepare",
    "creperanno": "crepare",
    "creperebbe": "crepare",
    "creperebber": "crepare",
    "creperebbero": "crepare",
    "creperei": "crepare",
    "creperemmo": "crepare",
    "creperemo": "crepare",
    "crepereste": "crepare",
    "creperesti": "crepare",
    "creperete": "crepare",
    "creperà": "crepare",
    "creperò": "crepare",
    "crepi": "crepare",
    "crepiamo": "crepare",
    "crepiate": "crepare",
    "crepin": "crepare",
    "crepino": "crepare",
    "crepita": "crepitare",
    "crepitai": "crepitare",
    "crepitammo": "crepitare",
    "crepitan": "crepitare",
    "crepitando": "crepitare",
    "crepitano": "crepitare",
    "crepitante": "crepitare",
    "crepitanti": "crepitare",
    "crepitar": "crepitare",
    "crepitaron": "crepitare",
    "crepitarono": "crepitare",
    "crepitasse": "crepitare",
    "crepitasser": "crepitare",
    "crepitassero": "crepitare",
    "crepitassi": "crepitare",
    "crepitassimo": "crepitare",
    "crepitaste": "crepitare",
    "crepitasti": "crepitare",
    "crepitata": "crepitare",
    "crepitate": "crepitare",
    "crepitati": "crepitare",
    "crepitato": "crepitare",
    "crepitava": "crepitare",
    "crepitavamo": "crepitare",
    "crepitavan": "crepitare",
    "crepitavano": "crepitare",
    "crepitavate": "crepitare",
    "crepitavi": "crepitare",
    "crepitavo": "crepitare",
    "crepiterai": "crepitare",
    "crepiteran": "crepitare",
    "crepiteranno": "crepitare",
    "crepiterebbe": "crepitare",
    "crepiterebber": "crepitare",
    "crepiterebbero": "crepitare",
    "crepiterei": "crepitare",
    "crepiteremmo": "crepitare",
    "crepiteremo": "crepitare",
    "crepitereste": "crepitare",
    "crepiteresti": "crepitare",
    "crepiterete": "crepitare",
    "crepiterà": "crepitare",
    "crepiterò": "crepitare",
    "crepiti": "crepitare",
    "crepitiamo": "crepitare",
    "crepitiate": "crepitare",
    "crepitii": "crepitio",
    "crepitin": "crepitare",
    "crepitino": "crepitare",
    "crepito": "crepitare",
    "crepitò": "crepitare",
    "crepo": "crepare",
    "crepuscola": "crepuscolare",
    "crepuscolai": "crepuscolare",
    "crepuscolammo": "crepuscolare",
    "crepuscolan": "crepuscolare",
    "crepuscolando": "crepuscolare",
    "crepuscolano": "crepuscolare",
    "crepuscolante": "crepuscolare",
    "crepuscolanti": "crepuscolare",
    "crepuscolar": "crepuscolare",
    "crepuscolari": "crepuscolare",
    "crepuscolaron": "crepuscolare",
    "crepuscolarono": "crepuscolare",
    "crepuscolasse": "crepuscolare",
    "crepuscolasser": "crepuscolare",
    "crepuscolassero": "crepuscolare",
    "crepuscolassi": "crepuscolare",
    "crepuscolassimo": "crepuscolare",
    "crepuscolaste": "crepuscolare",
    "crepuscolasti": "crepuscolare",
    "crepuscolata": "crepuscolare",
    "crepuscolate": "crepuscolare",
    "crepuscolati": "crepuscolare",
    "crepuscolato": "crepuscolare",
    "crepuscolava": "crepuscolare",
    "crepuscolavamo": "crepuscolare",
    "crepuscolavan": "crepuscolare",
    "crepuscolavano": "crepuscolare",
    "crepuscolavate": "crepuscolare",
    "crepuscolavi": "crepuscolare",
    "crepuscolavo": "crepuscolare",
    "crepuscolerai": "crepuscolare",
    "crepuscoleran": "crepuscolare",
    "crepuscoleranno": "crepuscolare",
    "crepuscolerebbe": "crepuscolare",
    "crepuscolerebber": "crepuscolare",
    "crepuscolerebbero": "crepuscolare",
    "crepuscolerei": "crepuscolare",
    "crepuscoleremmo": "crepuscolare",
    "crepuscoleremo": "crepuscolare",
    "crepuscolereste": "crepuscolare",
    "crepuscoleresti": "crepuscolare",
    "crepuscolerete": "crepuscolare",
    "crepuscolerà": "crepuscolare",
    "crepuscolerò": "crepuscolare",
    "crepuscoli": "crepuscolo",
    "crepuscoliamo": "crepuscolare",
    "crepuscoliate": "crepuscolare",
    "crepuscolin": "crepuscolare",
    "crepuscolino": "crepuscolare",
    "crepuscolo": "crepuscolare",
    "crepuscolò": "crepuscolare",
    "crepò": "crepare",
    "cresca": "crescere",
    "crescan": "crescere",
    "crescano": "crescere",
    "cresce": "crescere",
    "crescei": "crescere",
    "crescemmo": "crescere",
    "crescendo": "crescere",
    "crescente": "crescere",
    "crescenti": "crescere",
    "crescer": "crescere",
    "crescerai": "crescere",
    "cresceran": "crescere",
    "cresceranno": "crescere",
    "crescerebbe": "crescere",
    "crescerebber": "crescere",
    "crescerebbero": "crescere",
    "crescerei": "crescere",
    "cresceremmo": "crescere",
    "cresceremo": "crescere",
    "crescereste": "crescere",
    "cresceresti": "crescere",
    "crescerete": "crescere",
    "crescerà": "crescere",
    "crescerò": "crescere",
    "crescesse": "crescere",
    "crescesser": "crescere",
    "crescessero": "crescere",
    "crescessi": "crescere",
    "crescessimo": "crescere",
    "cresceste": "crescere",
    "crescesti": "crescere",
    "crescete": "crescere",
    "cresceva": "crescere",
    "crescevamo": "crescere",
    "crescevan": "crescere",
    "crescevano": "crescere",
    "crescevate": "crescere",
    "crescevi": "crescere",
    "crescevo": "crescere",
    "cresci": "crescere",
    "cresciamo": "crescere",
    "cresciate": "crescere",
    "crescite": "crescita",
    "cresciuta": "crescere",
    "cresciute": "crescere",
    "cresciuti": "crescere",
    "cresciuto": "crescere",
    "cresco": "crescere",
    "crescon": "crescere",
    "crescono": "crescere",
    "cresima": "cresimare",
    "cresimai": "cresimare",
    "cresimammo": "cresimare",
    "cresiman": "cresimare",
    "cresimando": "cresimare",
    "cresimano": "cresimare",
    "cresimante": "cresimare",
    "cresimanti": "cresimare",
    "cresimar": "cresimare",
    "cresimaron": "cresimare",
    "cresimarono": "cresimare",
    "cresimasse": "cresimare",
    "cresimasser": "cresimare",
    "cresimassero": "cresimare",
    "cresimassi": "cresimare",
    "cresimassimo": "cresimare",
    "cresimaste": "cresimare",
    "cresimasti": "cresimare",
    "cresimata": "cresimare",
    "cresimate": "cresimare",
    "cresimati": "cresimare",
    "cresimato": "cresimare",
    "cresimava": "cresimare",
    "cresimavamo": "cresimare",
    "cresimavan": "cresimare",
    "cresimavano": "cresimare",
    "cresimavate": "cresimare",
    "cresimavi": "cresimare",
    "cresimavo": "cresimare",
    "cresimerai": "cresimare",
    "cresimeran": "cresimare",
    "cresimeranno": "cresimare",
    "cresimerebbe": "cresimare",
    "cresimerebber": "cresimare",
    "cresimerebbero": "cresimare",
    "cresimerei": "cresimare",
    "cresimeremmo": "cresimare",
    "cresimeremo": "cresimare",
    "cresimereste": "cresimare",
    "cresimeresti": "cresimare",
    "cresimerete": "cresimare",
    "cresimerà": "cresimare",
    "cresimerò": "cresimare",
    "cresimi": "cresimare",
    "cresimiamo": "cresimare",
    "cresimiate": "cresimare",
    "cresimin": "cresimare",
    "cresimino": "cresimare",
    "cresimo": "cresimare",
    "cresimò": "cresimare",
    "crespa": "crespo",
    "crespata": "crespato",
    "crespate": "crespato",
    "crespati": "crespato",
    "crespe": "crespo",
    "crespi": "crespo",
    "creste": "cresta",
    "creta": "cernere",
    "crete": "creta",
    "cretesi": "cretese",
    "creti": "cernere",
    "cretina": "cretino",
    "cretinate": "cretinata",
    "cretine": "cretino",
    "cretini": "cretino",
    "creto": "cernere",
    "creò": "creare",
    "cricche": "cricca",
    "cricchi": "cricchiare",
    "cricchia": "cricchiare",
    "cricchiai": "cricchiare",
    "cricchiammo": "cricchiare",
    "cricchiamo": "cricchiare",
    "cricchian": "cricchiare",
    "cricchiando": "cricchiare",
    "cricchiano": "cricchiare",
    "cricchiante": "cricchiare",
    "cricchianti": "cricchiare",
    "cricchiar": "cricchiare",
    "cricchiaron": "cricchiare",
    "cricchiarono": "cricchiare",
    "cricchiasse": "cricchiare",
    "cricchiasser": "cricchiare",
    "cricchiassero": "cricchiare",
    "cricchiassi": "cricchiare",
    "cricchiassimo": "cricchiare",
    "cricchiaste": "cricchiare",
    "cricchiasti": "cricchiare",
    "cricchiata": "cricchiare",
    "cricchiate": "cricchiare",
    "cricchiati": "cricchiare",
    "cricchiato": "cricchiare",
    "cricchiava": "cricchiare",
    "cricchiavamo": "cricchiare",
    "cricchiavan": "cricchiare",
    "cricchiavano": "cricchiare",
    "cricchiavate": "cricchiare",
    "cricchiavi": "cricchiare",
    "cricchiavo": "cricchiare",
    "cricchierai": "cricchiare",
    "cricchieran": "cricchiare",
    "cricchieranno": "cricchiare",
    "cricchierebbe": "cricchiare",
    "cricchierebber": "cricchiare",
    "cricchierebbero": "cricchiare",
    "cricchierei": "cricchiare",
    "cricchieremmo": "cricchiare",
    "cricchieremo": "cricchiare",
    "cricchiereste": "cricchiare",
    "cricchieresti": "cricchiare",
    "cricchierete": "cricchiare",
    "cricchierà": "cricchiare",
    "cricchierò": "cricchiare",
    "cricchin": "cricchiare",
    "cricchino": "cricchiare",
    "cricchio": "cricchiare",
    "cricchiò": "cricchiare",
    "criminali": "criminale",
    "criminalizza": "criminalizzare",
    "criminalizzai": "criminalizzare",
    "criminalizzammo": "criminalizzare",
    "criminalizzan": "criminalizzare",
    "criminalizzando": "criminalizzare",
    "criminalizzano": "criminalizzare",
    "criminalizzante": "criminalizzare",
    "criminalizzanti": "criminalizzare",
    "criminalizzar": "criminalizzare",
    "criminalizzaron": "criminalizzare",
    "criminalizzarono": "criminalizzare",
    "criminalizzasse": "criminalizzare",
    "criminalizzasser": "criminalizzare",
    "criminalizzassero": "criminalizzare",
    "criminalizzassi": "criminalizzare",
    "criminalizzassimo": "criminalizzare",
    "criminalizzaste": "criminalizzare",
    "criminalizzasti": "criminalizzare",
    "criminalizzata": "criminalizzare",
    "criminalizzate": "criminalizzare",
    "criminalizzati": "criminalizzare",
    "criminalizzato": "criminalizzare",
    "criminalizzava": "criminalizzare",
    "criminalizzavamo": "criminalizzare",
    "criminalizzavan": "criminalizzare",
    "criminalizzavano": "criminalizzare",
    "criminalizzavate": "criminalizzare",
    "criminalizzavi": "criminalizzare",
    "criminalizzavo": "criminalizzare",
    "criminalizzazioni": "criminalizzazione",
    "criminalizzerai": "criminalizzare",
    "criminalizzeran": "criminalizzare",
    "criminalizzeranno": "criminalizzare",
    "criminalizzerebbe": "criminalizzare",
    "criminalizzerebber": "criminalizzare",
    "criminalizzerebbero": "criminalizzare",
    "criminalizzerei": "criminalizzare",
    "criminalizzeremmo": "criminalizzare",
    "criminalizzeremo": "criminalizzare",
    "criminalizzereste": "criminalizzare",
    "criminalizzeresti": "criminalizzare",
    "criminalizzerete": "criminalizzare",
    "criminalizzerà": "criminalizzare",
    "criminalizzerò": "criminalizzare",
    "criminalizzi": "criminalizzare",
    "criminalizziamo": "criminalizzare",
    "criminalizziate": "criminalizzare",
    "criminalizzin": "criminalizzare",
    "criminalizzino": "criminalizzare",
    "criminalizzo": "criminalizzare",
    "criminalizzò": "criminalizzare",
    "crimini": "crimine",
    "criminogena": "criminogeno",
    "criminogene": "criminogeno",
    "criminogeni": "criminogeno",
    "criminologi": "criminologo",
    "criminologica": "criminologico",
    "criminologiche": "criminologico",
    "criminologici": "criminologico",
    "criminosa": "criminoso",
    "criminose": "criminoso",
    "criminosi": "criminoso",
    "crinali": "crinale",
    "criniere": "criniera",
    "crinoline": "crinolina",
    "criocongela": "criocongelare",
    "criocongelai": "criocongelare",
    "criocongelammo": "criocongelare",
    "criocongelan": "criocongelare",
    "criocongelando": "criocongelare",
    "criocongelano": "criocongelare",
    "criocongelante": "criocongelare",
    "criocongelanti": "criocongelare",
    "criocongelar": "criocongelare",
    "criocongelaron": "criocongelare",
    "criocongelarono": "criocongelare",
    "criocongelasse": "criocongelare",
    "criocongelasser": "criocongelare",
    "criocongelassero": "criocongelare",
    "criocongelassi": "criocongelare",
    "criocongelassimo": "criocongelare",
    "criocongelaste": "criocongelare",
    "criocongelasti": "criocongelare",
    "criocongelata": "criocongelare",
    "criocongelate": "criocongelare",
    "criocongelati": "criocongelare",
    "criocongelato": "criocongelare",
    "criocongelava": "criocongelare",
    "criocongelavamo": "criocongelare",
    "criocongelavan": "criocongelare",
    "criocongelavano": "criocongelare",
    "criocongelavate": "criocongelare",
    "criocongelavi": "criocongelare",
    "criocongelavo": "criocongelare",
    "criocongelerai": "criocongelare",
    "criocongeleran": "criocongelare",
    "criocongeleranno": "criocongelare",
    "criocongelerebbe": "criocongelare",
    "criocongelerebber": "criocongelare",
    "criocongelerebbero": "criocongelare",
    "criocongelerei": "criocongelare",
    "criocongeleremmo": "criocongelare",
    "criocongeleremo": "criocongelare",
    "criocongelereste": "criocongelare",
    "criocongeleresti": "criocongelare",
    "criocongelerete": "criocongelare",
    "criocongelerà": "criocongelare",
    "criocongelerò": "criocongelare",
    "criocongeli": "criocongelare",
    "criocongeliamo": "criocongelare",
    "criocongeliate": "criocongelare",
    "criocongelin": "criocongelare",
    "criocongelino": "criocongelare",
    "criocongelo": "criocongelare",
    "criocongelò": "criocongelare",
    "crioconserva": "crioconservare",
    "crioconservai": "crioconservare",
    "crioconservammo": "crioconservare",
    "crioconservan": "crioconservare",
    "crioconservando": "crioconservare",
    "crioconservano": "crioconservare",
    "crioconservante": "crioconservare",
    "crioconservanti": "crioconservare",
    "crioconservar": "crioconservare",
    "crioconservaron": "crioconservare",
    "crioconservarono": "crioconservare",
    "crioconservasse": "crioconservare",
    "crioconservasser": "crioconservare",
    "crioconservassero": "crioconservare",
    "crioconservassi": "crioconservare",
    "crioconservassimo": "crioconservare",
    "crioconservaste": "crioconservare",
    "crioconservasti": "crioconservare",
    "crioconservata": "crioconservare",
    "crioconservate": "crioconservare",
    "crioconservati": "crioconservare",
    "crioconservato": "crioconservare",
    "crioconservava": "crioconservare",
    "crioconservavamo": "crioconservare",
    "crioconservavan": "crioconservare",
    "crioconservavano": "crioconservare",
    "crioconservavate": "crioconservare",
    "crioconservavi": "crioconservare",
    "crioconservavo": "crioconservare",
    "crioconserverai": "crioconservare",
    "crioconserveran": "crioconservare",
    "crioconserveranno": "crioconservare",
    "crioconserverebbe": "crioconservare",
    "crioconserverebber": "crioconservare",
    "crioconserverebbero": "crioconservare",
    "crioconserverei": "crioconservare",
    "crioconserveremmo": "crioconservare",
    "crioconserveremo": "crioconservare",
    "crioconservereste": "crioconservare",
    "crioconserveresti": "crioconservare",
    "crioconserverete": "crioconservare",
    "crioconserverà": "crioconservare",
    "crioconserverò": "crioconservare",
    "crioconservi": "crioconservare",
    "crioconserviamo": "crioconservare",
    "crioconserviate": "crioconservare",
    "crioconservin": "crioconservare",
    "crioconservino": "crioconservare",
    "crioconservo": "crioconservare",
    "crioconservò": "crioconservare",
    "cripta": "criptare",
    "criptai": "criptare",
    "criptammo": "criptare",
    "criptan": "criptare",
    "criptando": "criptare",
    "criptano": "criptare",
    "criptante": "criptare",
    "criptanti": "criptare",
    "criptar": "criptare",
    "criptaron": "criptare",
    "criptarono": "criptare",
    "criptasse": "criptare",
    "criptasser": "criptare",
    "criptassero": "criptare",
    "criptassi": "criptare",
    "criptassimo": "criptare",
    "criptaste": "criptare",
    "criptasti": "criptare",
    "criptata": "criptato",
    "criptate": "criptato",
    "criptati": "criptato",
    "criptato": "criptare",
    "criptava": "criptare",
    "criptavamo": "criptare",
    "criptavan": "criptare",
    "criptavano": "criptare",
    "criptavate": "criptare",
    "criptavi": "criptare",
    "criptavo": "criptare",
    "cripte": "cripta",
    "cripterai": "criptare",
    "cripteran": "criptare",
    "cripteranno": "criptare",
    "cripterebbe": "criptare",
    "cripterebber": "criptare",
    "cripterebbero": "criptare",
    "cripterei": "criptare",
    "cripteremmo": "criptare",
    "cripteremo": "criptare",
    "criptereste": "criptare",
    "cripteresti": "criptare",
    "cripterete": "criptare",
    "cripterà": "criptare",
    "cripterò": "criptare",
    "cripti": "criptare",
    "criptiamo": "criptare",
    "criptiate": "criptare",
    "criptica": "criptico",
    "criptiche": "criptico",
    "criptici": "criptico",
    "criptin": "criptare",
    "criptino": "criptare",
    "cripto": "criptare",
    "criptocomuniste": "criptocomunista",
    "criptocomunisti": "criptocomunista",
    "criptò": "criptare",
    "crismi": "crisma",
    "cristalizza": "cristalizzare",
    "cristalizzai": "cristalizzare",
    "cristalizzammo": "cristalizzare",
    "cristalizzan": "cristalizzare",
    "cristalizzando": "cristalizzare",
    "cristalizzano": "cristalizzare",
    "cristalizzante": "cristalizzare",
    "cristalizzanti": "cristalizzare",
    "cristalizzar": "cristalizzare",
    "cristalizzaron": "cristalizzare",
    "cristalizzarono": "cristalizzare",
    "cristalizzasse": "cristalizzare",
    "cristalizzasser": "cristalizzare",
    "cristalizzassero": "cristalizzare",
    "cristalizzassi": "cristalizzare",
    "cristalizzassimo": "cristalizzare",
    "cristalizzaste": "cristalizzare",
    "cristalizzasti": "cristalizzare",
    "cristalizzata": "cristalizzare",
    "cristalizzate": "cristalizzare",
    "cristalizzati": "cristalizzare",
    "cristalizzato": "cristalizzare",
    "cristalizzava": "cristalizzare",
    "cristalizzavamo": "cristalizzare",
    "cristalizzavan": "cristalizzare",
    "cristalizzavano": "cristalizzare",
    "cristalizzavate": "cristalizzare",
    "cristalizzavi": "cristalizzare",
    "cristalizzavo": "cristalizzare",
    "cristalizzerai": "cristalizzare",
    "cristalizzeran": "cristalizzare",
    "cristalizzeranno": "cristalizzare",
    "cristalizzerebbe": "cristalizzare",
    "cristalizzerebber": "cristalizzare",
    "cristalizzerebbero": "cristalizzare",
    "cristalizzerei": "cristalizzare",
    "cristalizzeremmo": "cristalizzare",
    "cristalizzeremo": "cristalizzare",
    "cristalizzereste": "cristalizzare",
    "cristalizzeresti": "cristalizzare",
    "cristalizzerete": "cristalizzare",
    "cristalizzerà": "cristalizzare",
    "cristalizzerò": "cristalizzare",
    "cristalizzi": "cristalizzare",
    "cristalizziamo": "cristalizzare",
    "cristalizziate": "cristalizzare",
    "cristalizzin": "cristalizzare",
    "cristalizzino": "cristalizzare",
    "cristalizzo": "cristalizzare",
    "cristalizzò": "cristalizzare",
    "cristallerie": "cristalleria",
    "cristalli": "cristallo",
    "cristallina": "cristallino",
    "cristalline": "cristallino",
    "cristallini": "cristallino",
    "cristallizza": "cristallizzare",
    "cristallizzai": "cristallizzare",
    "cristallizzammo": "cristallizzare",
    "cristallizzan": "cristallizzare",
    "cristallizzando": "cristallizzare",
    "cristallizzano": "cristallizzare",
    "cristallizzante": "cristallizzare",
    "cristallizzanti": "cristallizzare",
    "cristallizzar": "cristallizzare",
    "cristallizzaron": "cristallizzare",
    "cristallizzarono": "cristallizzare",
    "cristallizzasse": "cristallizzare",
    "cristallizzasser": "cristallizzare",
    "cristallizzassero": "cristallizzare",
    "cristallizzassi": "cristallizzare",
    "cristallizzassimo": "cristallizzare",
    "cristallizzaste": "cristallizzare",
    "cristallizzasti": "cristallizzare",
    "cristallizzata": "cristallizzato",
    "cristallizzate": "cristallizzato",
    "cristallizzati": "cristallizzato",
    "cristallizzato": "cristallizzare",
    "cristallizzava": "cristallizzare",
    "cristallizzavamo": "cristallizzare",
    "cristallizzavan": "cristallizzare",
    "cristallizzavano": "cristallizzare",
    "cristallizzavate": "cristallizzare",
    "cristallizzavi": "cristallizzare",
    "cristallizzavo": "cristallizzare",
    "cristallizzazioni": "cristallizzazione",
    "cristallizzerai": "cristallizzare",
    "cristallizzeran": "cristallizzare",
    "cristallizzeranno": "cristallizzare",
    "cristallizzerebbe": "cristallizzare",
    "cristallizzerebber": "cristallizzare",
    "cristallizzerebbero": "cristallizzare",
    "cristallizzerei": "cristallizzare",
    "cristallizzeremmo": "cristallizzare",
    "cristallizzeremo": "cristallizzare",
    "cristallizzereste": "cristallizzare",
    "cristallizzeresti": "cristallizzare",
    "cristallizzerete": "cristallizzare",
    "cristallizzerà": "cristallizzare",
    "cristallizzerò": "cristallizzare",
    "cristallizzi": "cristallizzare",
    "cristallizziamo": "cristallizzare",
    "cristallizziate": "cristallizzare",
    "cristallizzin": "cristallizzare",
    "cristallizzino": "cristallizzare",
    "cristallizzo": "cristallizzare",
    "cristallizzò": "cristallizzare",
    "cristi": "cristo",
    "cristiana": "cristiano",
    "cristiane": "cristiano",
    "cristianesimi": "cristianesimo",
    "cristiani": "cristiano",
    "cristianizza": "cristianizzare",
    "cristianizzai": "cristianizzare",
    "cristianizzammo": "cristianizzare",
    "cristianizzan": "cristianizzare",
    "cristianizzando": "cristianizzare",
    "cristianizzano": "cristianizzare",
    "cristianizzante": "cristianizzare",
    "cristianizzanti": "cristianizzare",
    "cristianizzar": "cristianizzare",
    "cristianizzaron": "cristianizzare",
    "cristianizzarono": "cristianizzare",
    "cristianizzasse": "cristianizzare",
    "cristianizzasser": "cristianizzare",
    "cristianizzassero": "cristianizzare",
    "cristianizzassi": "cristianizzare",
    "cristianizzassimo": "cristianizzare",
    "cristianizzaste": "cristianizzare",
    "cristianizzasti": "cristianizzare",
    "cristianizzata": "cristianizzato",
    "cristianizzate": "cristianizzato",
    "cristianizzati": "cristianizzato",
    "cristianizzato": "cristianizzare",
    "cristianizzava": "cristianizzare",
    "cristianizzavamo": "cristianizzare",
    "cristianizzavan": "cristianizzare",
    "cristianizzavano": "cristianizzare",
    "cristianizzavate": "cristianizzare",
    "cristianizzavi": "cristianizzare",
    "cristianizzavo": "cristianizzare",
    "cristianizzazioni": "cristianizzazione",
    "cristianizzerai": "cristianizzare",
    "cristianizzeran": "cristianizzare",
    "cristianizzeranno": "cristianizzare",
    "cristianizzerebbe": "cristianizzare",
    "cristianizzerebber": "cristianizzare",
    "cristianizzerebbero": "cristianizzare",
    "cristianizzerei": "cristianizzare",
    "cristianizzeremmo": "cristianizzare",
    "cristianizzeremo": "cristianizzare",
    "cristianizzereste": "cristianizzare",
    "cristianizzeresti": "cristianizzare",
    "cristianizzerete": "cristianizzare",
    "cristianizzerà": "cristianizzare",
    "cristianizzerò": "cristianizzare",
    "cristianizzi": "cristianizzare",
    "cristianizziamo": "cristianizzare",
    "cristianizziate": "cristianizzare",
    "cristianizzin": "cristianizzare",
    "cristianizzino": "cristianizzare",
    "cristianizzo": "cristianizzare",
    "cristianizzò": "cristianizzare",
    "cristiano-animiste": "cristiano-animista",
    "cristiano-animisti": "cristiano-animista",
    "cristiano-conservatori": "cristiano-conservatore",
    "cristiano-conservatrice": "cristiano-conservatore",
    "cristiano-conservatrici": "cristiano-conservatore",
    "cristiano-democratica": "cristiano-democratico",
    "cristiano-democratiche": "cristiano-democratico",
    "cristiano-democratici": "cristiano-democratico",
    "cristiano-ortodossa": "cristiano-ortodosso",
    "cristiano-ortodosse": "cristiano-ortodosso",
    "cristiano-ortodossi": "cristiano-ortodosso",
    "cristiano-popolari": "cristiano-popolare",
    "cristiano-sociali": "cristiano-sociale",
    "cristologica": "cristologico",
    "cristologiche": "cristologico",
    "cristologici": "cristologico",
    "criteri": "criterio",
    "critica": "critico",
    "criticabili": "criticabile",
    "criticai": "criticare",
    "criticammo": "criticare",
    "critican": "criticare",
    "criticando": "criticare",
    "criticano": "criticare",
    "criticante": "criticare",
    "criticanti": "criticare",
    "criticar": "criticare",
    "criticaron": "criticare",
    "criticarono": "criticare",
    "criticasse": "criticare",
    "criticasser": "criticare",
    "criticassero": "criticare",
    "criticassi": "criticare",
    "criticassimo": "criticare",
    "criticaste": "criticare",
    "criticasti": "criticare",
    "criticata": "criticato",
    "criticate": "criticato",
    "criticati": "criticato",
    "criticato": "criticare",
    "criticava": "criticare",
    "criticavamo": "criticare",
    "criticavan": "criticare",
    "criticavano": "criticare",
    "criticavate": "criticare",
    "criticavi": "criticare",
    "criticavo": "criticare",
    "critiche": "critico",
    "criticherai": "criticare",
    "criticheran": "criticare",
    "criticheranno": "criticare",
    "criticherebbe": "criticare",
    "criticherebber": "criticare",
    "criticherebbero": "criticare",
    "criticherei": "criticare",
    "criticheremmo": "criticare",
    "criticheremo": "criticare",
    "critichereste": "criticare",
    "criticheresti": "criticare",
    "criticherete": "criticare",
    "criticherà": "criticare",
    "criticherò": "criticare",
    "critichi": "criticare",
    "critichiamo": "criticare",
    "critichiate": "criticare",
    "critichin": "criticare",
    "critichino": "criticare",
    "critici": "critico",
    "critico": "criticare",
    "criticò": "criticare",
    "crittografie": "crittografia",
    "crivella": "crivellare",
    "crivellai": "crivellare",
    "crivellammo": "crivellare",
    "crivellan": "crivellare",
    "crivellando": "crivellare",
    "crivellano": "crivellare",
    "crivellante": "crivellare",
    "crivellanti": "crivellare",
    "crivellar": "crivellare",
    "crivellaron": "crivellare",
    "crivellarono": "crivellare",
    "crivellasse": "crivellare",
    "crivellasser": "crivellare",
    "crivellassero": "crivellare",
    "crivellassi": "crivellare",
    "crivellassimo": "crivellare",
    "crivellaste": "crivellare",
    "crivellasti": "crivellare",
    "crivellata": "crivellare",
    "crivellate": "crivellare",
    "crivellati": "crivellare",
    "crivellato": "crivellare",
    "crivellava": "crivellare",
    "crivellavamo": "crivellare",
    "crivellavan": "crivellare",
    "crivellavano": "crivellare",
    "crivellavate": "crivellare",
    "crivellavi": "crivellare",
    "crivellavo": "crivellare",
    "crivellerai": "crivellare",
    "crivelleran": "crivellare",
    "crivelleranno": "crivellare",
    "crivellerebbe": "crivellare",
    "crivellerebber": "crivellare",
    "crivellerebbero": "crivellare",
    "crivellerei": "crivellare",
    "crivelleremmo": "crivellare",
    "crivelleremo": "crivellare",
    "crivellereste": "crivellare",
    "crivelleresti": "crivellare",
    "crivellerete": "crivellare",
    "crivellerà": "crivellare",
    "crivellerò": "crivellare",
    "crivelli": "crivellare",
    "crivelliamo": "crivellare",
    "crivelliate": "crivellare",
    "crivellin": "crivellare",
    "crivellino": "crivellare",
    "crivello": "crivellare",
    "crivellò": "crivellare",
    "croata": "croato",
    "croate": "croato",
    "croati": "croato",
    "croato-bosniaca": "croato-bosniaco",
    "croato-bosniache": "croato-bosniaco",
    "croato-bosniaci": "croato-bosniaco",
    "croato-musulmana": "croato-musulmano",
    "croato-musulmane": "croato-musulmano",
    "croato-musulmani": "croato-musulmano",
    "croatobosniaca": "croatobosniaco",
    "croatobosniache": "croatobosniaco",
    "croatobosniaci": "croatobosniaco",
    "croccanti": "croccante",
    "crocchi": "crocchio",
    "crocchia": "crocchiare",
    "crocchiai": "crocchiare",
    "crocchiammo": "crocchiare",
    "crocchiamo": "crocchiare",
    "crocchian": "crocchiare",
    "crocchiando": "crocchiare",
    "crocchiano": "crocchiare",
    "crocchiante": "crocchiare",
    "crocchianti": "crocchiare",
    "crocchiar": "crocchiare",
    "crocchiaron": "crocchiare",
    "crocchiarono": "crocchiare",
    "crocchiasse": "crocchiare",
    "crocchiasser": "crocchiare",
    "crocchiassero": "crocchiare",
    "crocchiassi": "crocchiare",
    "crocchiassimo": "crocchiare",
    "crocchiaste": "crocchiare",
    "crocchiasti": "crocchiare",
    "crocchiata": "crocchiare",
    "crocchiate": "crocchiare",
    "crocchiati": "crocchiare",
    "crocchiato": "crocchiare",
    "crocchiava": "crocchiare",
    "crocchiavamo": "crocchiare",
    "crocchiavan": "crocchiare",
    "crocchiavano": "crocchiare",
    "crocchiavate": "crocchiare",
    "crocchiavi": "crocchiare",
    "crocchiavo": "crocchiare",
    "crocchierai": "crocchiare",
    "crocchieran": "crocchiare",
    "crocchieranno": "crocchiare",
    "crocchierebbe": "crocchiare",
    "crocchierebber": "crocchiare",
    "crocchierebbero": "crocchiare",
    "crocchierei": "crocchiare",
    "crocchieremmo": "crocchiare",
    "crocchieremo": "crocchiare",
    "crocchiereste": "crocchiare",
    "crocchieresti": "crocchiare",
    "crocchierete": "crocchiare",
    "crocchierà": "crocchiare",
    "crocchierò": "crocchiare",
    "crocchin": "crocchiare",
    "crocchino": "crocchiare",
    "crocchio": "crocchiare",
    "crocchiò": "crocchiare",
    "crocefigga": "crocefiggere",
    "crocefiggan": "crocefiggere",
    "crocefiggano": "crocefiggere",
    "crocefigge": "crocefiggere",
    "crocefiggemmo": "crocefiggere",
    "crocefiggendo": "crocefiggere",
    "crocefiggente": "crocefiggere",
    "crocefiggenti": "crocefiggere",
    "crocefigger": "crocefiggere",
    "crocefiggerai": "crocefiggere",
    "crocefiggeran": "crocefiggere",
    "crocefiggeranno": "crocefiggere",
    "crocefiggerebbe": "crocefiggere",
    "crocefiggerebber": "crocefiggere",
    "crocefiggerebbero": "crocefiggere",
    "crocefiggerei": "crocefiggere",
    "crocefiggeremmo": "crocefiggere",
    "crocefiggeremo": "crocefiggere",
    "crocefiggereste": "crocefiggere",
    "crocefiggeresti": "crocefiggere",
    "crocefiggerete": "crocefiggere",
    "crocefiggerà": "crocefiggere",
    "crocefiggerò": "crocefiggere",
    "crocefiggesse": "crocefiggere",
    "crocefiggesser": "crocefiggere",
    "crocefiggessero": "crocefiggere",
    "crocefiggessi": "crocefiggere",
    "crocefiggessimo": "crocefiggere",
    "crocefiggeste": "crocefiggere",
    "crocefiggesti": "crocefiggere",
    "crocefiggete": "crocefiggere",
    "crocefiggeva": "crocefiggere",
    "crocefiggevamo": "crocefiggere",
    "crocefiggevan": "crocefiggere",
    "crocefiggevano": "crocefiggere",
    "crocefiggevate": "crocefiggere",
    "crocefiggevi": "crocefiggere",
    "crocefiggevo": "crocefiggere",
    "crocefiggi": "crocefiggere",
    "crocefiggiamo": "crocefiggere",
    "crocefiggiate": "crocefiggere",
    "crocefiggo": "crocefiggere",
    "crocefiggon": "crocefiggere",
    "crocefiggono": "crocefiggere",
    "crocefissa": "crocefisso",
    "crocefisse": "crocefisso",
    "crocefisser": "crocefiggere",
    "crocefissero": "crocefiggere",
    "crocefissi": "crocefisso",
    "crocefissioni": "crocefissione",
    "crocefissè": "crocefiggere",
    "crocefitta": "crocefiggere",
    "crocefitte": "crocefiggere",
    "crocefitti": "crocefiggere",
    "crocefitto": "crocefiggere",
    "crocerossine": "crocerossina",
    "crocette": "crocetta",
    "croci": "croce",
    "crociana": "crociano",
    "crociane": "crociano",
    "crociani": "crociano",
    "crociata": "crociato",
    "crociate": "crociato",
    "crociati": "crociato",
    "crocicchi": "crocicchio",
    "crocida": "crocidare",
    "crocidai": "crocidare",
    "crocidammo": "crocidare",
    "crocidan": "crocidare",
    "crocidando": "crocidare",
    "crocidano": "crocidare",
    "crocidante": "crocidare",
    "crocidanti": "crocidare",
    "crocidar": "crocidare",
    "crocidaron": "crocidare",
    "crocidarono": "crocidare",
    "crocidasse": "crocidare",
    "crocidasser": "crocidare",
    "crocidassero": "crocidare",
    "crocidassi": "crocidare",
    "crocidassimo": "crocidare",
    "crocidaste": "crocidare",
    "crocidasti": "crocidare",
    "crocidata": "crocidare",
    "crocidate": "crocidare",
    "crocidati": "crocidare",
    "crocidato": "crocidare",
    "crocidava": "crocidare",
    "crocidavamo": "crocidare",
    "crocidavan": "crocidare",
    "crocidavano": "crocidare",
    "crocidavate": "crocidare",
    "crocidavi": "crocidare",
    "crocidavo": "crocidare",
    "crociderai": "crocidare",
    "crocideran": "crocidare",
    "crocideranno": "crocidare",
    "crociderebbe": "crocidare",
    "crociderebber": "crocidare",
    "crociderebbero": "crocidare",
    "crociderei": "crocidare",
    "crocideremmo": "crocidare",
    "crocideremo": "crocidare",
    "crocidereste": "crocidare",
    "crocideresti": "crocidare",
    "crociderete": "crocidare",
    "crociderà": "crocidare",
    "crociderò": "crocidare",
    "crocidi": "crocidare",
    "crocidiamo": "crocidare",
    "crocidiate": "crocidare",
    "crocidin": "crocidare",
    "crocidino": "crocidare",
    "crocido": "crocidare",
    "crocidò": "crocidare",
    "crociere": "crociera",
    "crocieristi": "crocierista",
    "crocieristica": "crocieristico",
    "crocieristiche": "crocieristico",
    "crocieristici": "crocieristico",
    "crocifigga": "crocifiggere",
    "crocifiggan": "crocifiggere",
    "crocifiggano": "crocifiggere",
    "crocifigge": "crocifiggere",
    "crocifiggemmo": "crocifiggere",
    "crocifiggendo": "crocifiggere",
    "crocifiggente": "crocifiggere",
    "crocifiggenti": "crocifiggere",
    "crocifigger": "crocifiggere",
    "crocifiggerai": "crocifiggere",
    "crocifiggeran": "crocifiggere",
    "crocifiggeranno": "crocifiggere",
    "crocifiggerebbe": "crocifiggere",
    "crocifiggerebber": "crocifiggere",
    "crocifiggerebbero": "crocifiggere",
    "crocifiggerei": "crocifiggere",
    "crocifiggeremmo": "crocifiggere",
    "crocifiggeremo": "crocifiggere",
    "crocifiggereste": "crocifiggere",
    "crocifiggeresti": "crocifiggere",
    "crocifiggerete": "crocifiggere",
    "crocifiggerà": "crocifiggere",
    "crocifiggerò": "crocifiggere",
    "crocifiggesse": "crocifiggere",
    "crocifiggesser": "crocifiggere",
    "crocifiggessero": "crocifiggere",
    "crocifiggessi": "crocifiggere",
    "crocifiggessimo": "crocifiggere",
    "crocifiggeste": "crocifiggere",
    "crocifiggesti": "crocifiggere",
    "crocifiggete": "crocifiggere",
    "crocifiggeva": "crocifiggere",
    "crocifiggevamo": "crocifiggere",
    "crocifiggevan": "crocifiggere",
    "crocifiggevano": "crocifiggere",
    "crocifiggevate": "crocifiggere",
    "crocifiggevi": "crocifiggere",
    "crocifiggevo": "crocifiggere",
    "crocifiggi": "crocifiggere",
    "crocifiggiamo": "crocifiggere",
    "crocifiggiate": "crocifiggere",
    "crocifiggo": "crocifiggere",
    "crocifiggon": "crocifiggere",
    "crocifiggono": "crocifiggere",
    "crocifissa": "crocifisso",
    "crocifisse": "crocifisso",
    "crocifisser": "crocifiggere",
    "crocifissero": "crocifiggere",
    "crocifissi": "crocifisso",
    "crocifissioni": "crocifissione",
    "crocifissè": "crocifiggere",
    "crocifitta": "crocifiggere",
    "crocifitte": "crocifiggere",
    "crocifitti": "crocifiggere",
    "crocifitto": "crocifiggere",
    "crogiola": "crogiolare",
    "crogiolai": "crogiolare",
    "crogiolammo": "crogiolare",
    "crogiolan": "crogiolare",
    "crogiolando": "crogiolare",
    "crogiolano": "crogiolare",
    "crogiolante": "crogiolare",
    "crogiolanti": "crogiolare",
    "crogiolar": "crogiolare",
    "crogiolaron": "crogiolare",
    "crogiolarono": "crogiolare",
    "crogiolasse": "crogiolare",
    "crogiolasser": "crogiolare",
    "crogiolassero": "crogiolare",
    "crogiolassi": "crogiolare",
    "crogiolassimo": "crogiolare",
    "crogiolaste": "crogiolare",
    "crogiolasti": "crogiolare",
    "crogiolata": "crogiolare",
    "crogiolate": "crogiolare",
    "crogiolati": "crogiolare",
    "crogiolato": "crogiolare",
    "crogiolava": "crogiolare",
    "crogiolavamo": "crogiolare",
    "crogiolavan": "crogiolare",
    "crogiolavano": "crogiolare",
    "crogiolavate": "crogiolare",
    "crogiolavi": "crogiolare",
    "crogiolavo": "crogiolare",
    "crogiolerai": "crogiolare",
    "crogioleran": "crogiolare",
    "crogioleranno": "crogiolare",
    "crogiolerebbe": "crogiolare",
    "crogiolerebber": "crogiolare",
    "crogiolerebbero": "crogiolare",
    "crogiolerei": "crogiolare",
    "crogioleremmo": "crogiolare",
    "crogioleremo": "crogiolare",
    "crogiolereste": "crogiolare",
    "crogioleresti": "crogiolare",
    "crogiolerete": "crogiolare",
    "crogiolerà": "crogiolare",
    "crogiolerò": "crogiolare",
    "crogioli": "crogiolo",
    "crogioliamo": "crogiolare",
    "crogioliate": "crogiolare",
    "crogiolin": "crogiolare",
    "crogiolino": "crogiolare",
    "crogiolo": "crogiolare",
    "crogiolò": "crogiolare",
    "crogiuola": "crogiuolare",
    "crogiuolai": "crogiuolare",
    "crogiuolammo": "crogiuolare",
    "crogiuolan": "crogiuolare",
    "crogiuolando": "crogiuolare",
    "crogiuolano": "crogiuolare",
    "crogiuolante": "crogiuolare",
    "crogiuolanti": "crogiuolare",
    "crogiuolar": "crogiuolare",
    "crogiuolaron": "crogiuolare",
    "crogiuolarono": "crogiuolare",
    "crogiuolasse": "crogiuolare",
    "crogiuolasser": "crogiuolare",
    "crogiuolassero": "crogiuolare",
    "crogiuolassi": "crogiuolare",
    "crogiuolassimo": "crogiuolare",
    "crogiuolaste": "crogiuolare",
    "crogiuolasti": "crogiuolare",
    "crogiuolata": "crogiuolare",
    "crogiuolate": "crogiuolare",
    "crogiuolati": "crogiuolare",
    "crogiuolato": "crogiuolare",
    "crogiuolava": "crogiuolare",
    "crogiuolavamo": "crogiuolare",
    "crogiuolavan": "crogiuolare",
    "crogiuolavano": "crogiuolare",
    "crogiuolavate": "crogiuolare",
    "crogiuolavi": "crogiuolare",
    "crogiuolavo": "crogiuolare",
    "crogiuolerai": "crogiuolare",
    "crogiuoleran": "crogiuolare",
    "crogiuoleranno": "crogiuolare",
    "crogiuolerebbe": "crogiuolare",
    "crogiuolerebber": "crogiuolare",
    "crogiuolerebbero": "crogiuolare",
    "crogiuolerei": "crogiuolare",
    "crogiuoleremmo": "crogiuolare",
    "crogiuoleremo": "crogiuolare",
    "crogiuolereste": "crogiuolare",
    "crogiuoleresti": "crogiuolare",
    "crogiuolerete": "crogiuolare",
    "crogiuolerà": "crogiuolare",
    "crogiuolerò": "crogiuolare",
    "crogiuoli": "crogiuolo",
    "crogiuoliamo": "crogiuolare",
    "crogiuoliate": "crogiuolare",
    "crogiuolin": "crogiuolare",
    "crogiuolino": "crogiuolare",
    "crogiuolo": "crogiuolare",
    "crogiuolò": "crogiuolare",
    "crolla": "crollare",
    "crollai": "crollare",
    "crollammo": "crollare",
    "crollan": "crollare",
    "crollando": "crollare",
    "crollano": "crollare",
    "crollante": "crollare",
    "crollanti": "crollare",
    "crollar": "crollare",
    "crollaron": "crollare",
    "crollarono": "crollare",
    "crollasse": "crollare",
    "crollasser": "crollare",
    "crollassero": "crollare",
    "crollassi": "crollare",
    "crollassimo": "crollare",
    "crollaste": "crollare",
    "crollasti": "crollare",
    "crollata": "crollare",
    "crollate": "crollare",
    "crollati": "crollare",
    "crollato": "crollare",
    "crollava": "crollare",
    "crollavamo": "crollare",
    "crollavan": "crollare",
    "crollavano": "crollare",
    "crollavate": "crollare",
    "crollavi": "crollare",
    "crollavo": "crollare",
    "crollerai": "crollare",
    "crolleran": "crollare",
    "crolleranno": "crollare",
    "crollerebbe": "crollare",
    "crollerebber": "crollare",
    "crollerebbero": "crollare",
    "crollerei": "crollare",
    "crolleremmo": "crollare",
    "crolleremo": "crollare",
    "crollereste": "crollare",
    "crolleresti": "crollare",
    "crollerete": "crollare",
    "crollerà": "crollare",
    "crollerò": "crollare",
    "crolli": "crollo",
    "crolliamo": "crollare",
    "crolliate": "crollare",
    "crollin": "crollare",
    "crollino": "crollare",
    "crollo": "crollare",
    "crollò": "crollare",
    "croma": "cromare",
    "cromai": "cromare",
    "cromammo": "cromare",
    "croman": "cromare",
    "cromando": "cromare",
    "cromano": "cromare",
    "cromante": "cromare",
    "cromanti": "cromare",
    "cromar": "cromare",
    "cromaron": "cromare",
    "cromarono": "cromare",
    "cromasse": "cromare",
    "cromasser": "cromare",
    "cromassero": "cromare",
    "cromassi": "cromare",
    "cromassimo": "cromare",
    "cromaste": "cromare",
    "cromasti": "cromare",
    "cromata": "cromare",
    "cromate": "cromare",
    "cromati": "cromare",
    "cromatica": "cromatico",
    "cromatiche": "cromatico",
    "cromatici": "cromatico",
    "cromatismi": "cromatismo",
    "cromato": "cromare",
    "cromature": "cromatura",
    "cromava": "cromare",
    "cromavamo": "cromare",
    "cromavan": "cromare",
    "cromavano": "cromare",
    "cromavate": "cromare",
    "cromavi": "cromare",
    "cromavo": "cromare",
    "cromerai": "cromare",
    "cromeran": "cromare",
    "cromeranno": "cromare",
    "cromerebbe": "cromare",
    "cromerebber": "cromare",
    "cromerebbero": "cromare",
    "cromerei": "cromare",
    "cromeremmo": "cromare",
    "cromeremo": "cromare",
    "cromereste": "cromare",
    "cromeresti": "cromare",
    "cromerete": "cromare",
    "cromerà": "cromare",
    "cromerò": "cromare",
    "cromi": "cromare",
    "cromiamo": "cromare",
    "cromiate": "cromare",
    "cromie": "cromia",
    "cromin": "cromare",
    "cromino": "cromare",
    "cromo": "cromare",
    "cromosa": "cromoso",
    "cromose": "cromoso",
    "cromosi": "cromoso",
    "cromosomi": "cromosoma",
    "cromosomica": "cromosomico",
    "cromosomiche": "cromosomico",
    "cromosomici": "cromosomico",
    "cromò": "cromare",
    "cronache": "cronaca",
    "cronachistica": "cronachistico",
    "cronachistiche": "cronachistico",
    "cronachistici": "cronachistico",
    "cronica": "cronico",
    "cronicari": "cronicario",
    "croniche": "cronico",
    "cronici": "cronico",
    "croniste": "cronista",
    "cronisti": "cronista",
    "cronistica": "cronistico",
    "cronistiche": "cronistico",
    "cronistici": "cronistico",
    "cronistorie": "cronistoria",
    "cronografi": "cronografo",
    "cronologica": "cronologico",
    "cronologiche": "cronologico",
    "cronologici": "cronologico",
    "cronologie": "cronologia",
    "cronometra": "cronometrare",
    "cronometraggi": "cronometraggio",
    "cronometrai": "cronometrare",
    "cronometrammo": "cronometrare",
    "cronometran": "cronometrare",
    "cronometrando": "cronometrare",
    "cronometrano": "cronometrare",
    "cronometrante": "cronometrare",
    "cronometranti": "cronometrare",
    "cronometrar": "cronometrare",
    "cronometraron": "cronometrare",
    "cronometrarono": "cronometrare",
    "cronometrasse": "cronometrare",
    "cronometrasser": "cronometrare",
    "cronometrassero": "cronometrare",
    "cronometrassi": "cronometrare",
    "cronometrassimo": "cronometrare",
    "cronometraste": "cronometrare",
    "cronometrasti": "cronometrare",
    "cronometrata": "cronometrare",
    "cronometrate": "cronometrare",
    "cronometrati": "cronometrare",
    "cronometrato": "cronometrare",
    "cronometrava": "cronometrare",
    "cronometravamo": "cronometrare",
    "cronometravan": "cronometrare",
    "cronometravano": "cronometrare",
    "cronometravate": "cronometrare",
    "cronometravi": "cronometrare",
    "cronometravo": "cronometrare",
    "cronometrerai": "cronometrare",
    "cronometreran": "cronometrare",
    "cronometreranno": "cronometrare",
    "cronometrerebbe": "cronometrare",
    "cronometrerebber": "cronometrare",
    "cronometrerebbero": "cronometrare",
    "cronometrerei": "cronometrare",
    "cronometreremmo": "cronometrare",
    "cronometreremo": "cronometrare",
    "cronometrereste": "cronometrare",
    "cronometreresti": "cronometrare",
    "cronometrerete": "cronometrare",
    "cronometrerà": "cronometrare",
    "cronometrerò": "cronometrare",
    "cronometri": "cronometro",
    "cronometriamo": "cronometrare",
    "cronometriate": "cronometrare",
    "cronometrica": "cronometrico",
    "cronometriche": "cronometrico",
    "cronometrici": "cronometrico",
    "cronometrin": "cronometrare",
    "cronometrino": "cronometrare",
    "cronometristi": "cronometrista",
    "cronometro": "cronometrare",
    "cronometrò": "cronometrare",
    "cronoscalate": "cronoscalata",
    "cronotachigrafi": "cronotachigrafo",
    "croscerai": "crosciare",
    "crosceran": "crosciare",
    "crosceranno": "crosciare",
    "croscerebbe": "crosciare",
    "croscerebber": "crosciare",
    "croscerebbero": "crosciare",
    "croscerei": "crosciare",
    "crosceremmo": "crosciare",
    "crosceremo": "crosciare",
    "croscereste": "crosciare",
    "crosceresti": "crosciare",
    "croscerete": "crosciare",
    "croscerà": "crosciare",
    "croscerò": "crosciare",
    "crosci": "crosciare",
    "croscia": "crosciare",
    "crosciai": "crosciare",
    "crosciammo": "crosciare",
    "crosciamo": "crosciare",
    "croscian": "crosciare",
    "crosciando": "crosciare",
    "crosciano": "crosciare",
    "crosciante": "crosciare",
    "croscianti": "crosciare",
    "crosciar": "crosciare",
    "crosciaron": "crosciare",
    "crosciarono": "crosciare",
    "crosciasse": "crosciare",
    "crosciasser": "crosciare",
    "crosciassero": "crosciare",
    "crosciassi": "crosciare",
    "crosciassimo": "crosciare",
    "crosciaste": "crosciare",
    "crosciasti": "crosciare",
    "crosciata": "crosciare",
    "crosciate": "crosciare",
    "crosciati": "crosciare",
    "crosciato": "crosciare",
    "crosciava": "crosciare",
    "crosciavamo": "crosciare",
    "crosciavan": "crosciare",
    "crosciavano": "crosciare",
    "crosciavate": "crosciare",
    "crosciavi": "crosciare",
    "crosciavo": "crosciare",
    "croscin": "crosciare",
    "croscino": "crosciare",
    "croscio": "crosciare",
    "crosciò": "crosciare",
    "crossa": "crossare",
    "crossai": "crossare",
    "crossammo": "crossare",
    "crossan": "crossare",
    "crossando": "crossare",
    "crossano": "crossare",
    "crossante": "crossare",
    "crossanti": "crossare",
    "crossar": "crossare",
    "crossaron": "crossare",
    "crossarono": "crossare",
    "crossasse": "crossare",
    "crossasser": "crossare",
    "crossassero": "crossare",
    "crossassi": "crossare",
    "crossassimo": "crossare",
    "crossaste": "crossare",
    "crossasti": "crossare",
    "crossata": "crossare",
    "crossate": "crossare",
    "crossati": "crossare",
    "crossato": "crossare",
    "crossava": "crossare",
    "crossavamo": "crossare",
    "crossavan": "crossare",
    "crossavano": "crossare",
    "crossavate": "crossare",
    "crossavi": "crossare",
    "crossavo": "crossare",
    "crosserai": "crossare",
    "crosseran": "crossare",
    "crosseranno": "crossare",
    "crosserebbe": "crossare",
    "crosserebber": "crossare",
    "crosserebbero": "crossare",
    "crosserei": "crossare",
    "crosseremmo": "crossare",
    "crosseremo": "crossare",
    "crossereste": "crossare",
    "crosseresti": "crossare",
    "crosserete": "crossare",
    "crosserà": "crossare",
    "crosserò": "crossare",
    "crossi": "crossare",
    "crossiamo": "crossare",
    "crossiate": "crossare",
    "crossin": "crossare",
    "crossino": "crossare",
    "crosso": "crossare",
    "crossò": "crossare",
    "crostacei": "crostaceo",
    "crostate": "crostata",
    "croste": "crosta",
    "crostosa": "crostoso",
    "crostose": "crostoso",
    "crostosi": "crostoso",
    "crotonesi": "crotonese",
    "cruccerai": "crucciare",
    "crucceran": "crucciare",
    "crucceranno": "crucciare",
    "cruccerebbe": "crucciare",
    "cruccerebber": "crucciare",
    "cruccerebbero": "crucciare",
    "cruccerei": "crucciare",
    "crucceremmo": "crucciare",
    "crucceremo": "crucciare",
    "cruccereste": "crucciare",
    "crucceresti": "crucciare",
    "cruccerete": "crucciare",
    "cruccerà": "crucciare",
    "cruccerò": "crucciare",
    "crucchi": "crucco",
    "crucci": "cruccio",
    "cruccia": "crucciare",
    "crucciai": "crucciare",
    "crucciammo": "crucciare",
    "crucciamo": "crucciare",
    "cruccian": "crucciare",
    "crucciando": "crucciare",
    "crucciano": "crucciare",
    "crucciante": "crucciare",
    "cruccianti": "crucciare",
    "crucciar": "crucciare",
    "crucciaron": "crucciare",
    "crucciarono": "crucciare",
    "crucciasse": "crucciare",
    "crucciasser": "crucciare",
    "crucciassero": "crucciare",
    "crucciassi": "crucciare",
    "crucciassimo": "crucciare",
    "crucciaste": "crucciare",
    "crucciasti": "crucciare",
    "crucciata": "crucciato",
    "crucciate": "crucciato",
    "crucciati": "crucciato",
    "crucciato": "crucciare",
    "crucciava": "crucciare",
    "crucciavamo": "crucciare",
    "crucciavan": "crucciare",
    "crucciavano": "crucciare",
    "crucciavate": "crucciare",
    "crucciavi": "crucciare",
    "crucciavo": "crucciare",
    "cruccin": "crucciare",
    "cruccino": "crucciare",
    "cruccio": "crucciare",
    "crucciò": "crucciare",
    "cruciali": "cruciale",
    "cruciformi": "cruciforme",
    "cruda": "crudo",
    "crude": "crudo",
    "crudeli": "crudele",
    "crudezze": "crudezza",
    "crudi": "crudo",
    "cruenta": "cruento",
    "cruente": "cruento",
    "cruenti": "cruento",
    "crumiri": "crumiro",
    "cruscheggerai": "cruscheggiare",
    "cruscheggeran": "cruscheggiare",
    "cruscheggeranno": "cruscheggiare",
    "cruscheggerebbe": "cruscheggiare",
    "cruscheggerebber": "cruscheggiare",
    "cruscheggerebbero": "cruscheggiare",
    "cruscheggerei": "cruscheggiare",
    "cruscheggeremmo": "cruscheggiare",
    "cruscheggeremo": "cruscheggiare",
    "cruscheggereste": "cruscheggiare",
    "cruscheggeresti": "cruscheggiare",
    "cruscheggerete": "cruscheggiare",
    "cruscheggerà": "cruscheggiare",
    "cruscheggerò": "cruscheggiare",
    "cruscheggi": "cruscheggiare",
    "cruscheggia": "cruscheggiare",
    "cruscheggiai": "cruscheggiare",
    "cruscheggiammo": "cruscheggiare",
    "cruscheggiamo": "cruscheggiare",
    "cruscheggian": "cruscheggiare",
    "cruscheggiando": "cruscheggiare",
    "cruscheggiano": "cruscheggiare",
    "cruscheggiante": "cruscheggiare",
    "cruscheggianti": "cruscheggiare",
    "cruscheggiar": "cruscheggiare",
    "cruscheggiaron": "cruscheggiare",
    "cruscheggiarono": "cruscheggiare",
    "cruscheggiasse": "cruscheggiare",
    "cruscheggiasser": "cruscheggiare",
    "cruscheggiassero": "cruscheggiare",
    "cruscheggiassi": "cruscheggiare",
    "cruscheggiassimo": "cruscheggiare",
    "cruscheggiaste": "cruscheggiare",
    "cruscheggiasti": "cruscheggiare",
    "cruscheggiata": "cruscheggiare",
    "cruscheggiate": "cruscheggiare",
    "cruscheggiati": "cruscheggiare",
    "cruscheggiato": "cruscheggiare",
    "cruscheggiava": "cruscheggiare",
    "cruscheggiavamo": "cruscheggiare",
    "cruscheggiavan": "cruscheggiare",
    "cruscheggiavano": "cruscheggiare",
    "cruscheggiavate": "cruscheggiare",
    "cruscheggiavi": "cruscheggiare",
    "cruscheggiavo": "cruscheggiare",
    "cruscheggin": "cruscheggiare",
    "cruscheggino": "cruscheggiare",
    "cruscheggio": "cruscheggiare",
    "cruscheggiò": "cruscheggiare",
    "cruscotti": "cruscotto",
    "cuba": "cubare",
    "cubai": "cubare",
    "cubammo": "cubare",
    "cuban": "cubare",
    "cubana": "cubano",
    "cubando": "cubare",
    "cubane": "cubano",
    "cubani": "cubano",
    "cubano": "cubare",
    "cubano-americana": "cubano-americano",
    "cubano-americane": "cubano-americano",
    "cubano-americani": "cubano-americano",
    "cubante": "cubare",
    "cubanti": "cubare",
    "cubar": "cubare",
    "cubaron": "cubare",
    "cubarono": "cubare",
    "cubasse": "cubare",
    "cubasser": "cubare",
    "cubassero": "cubare",
    "cubassi": "cubare",
    "cubassimo": "cubare",
    "cubaste": "cubare",
    "cubasti": "cubare",
    "cubata": "cubare",
    "cubate": "cubare",
    "cubati": "cubare",
    "cubato": "cubare",
    "cubature": "cubatura",
    "cubava": "cubare",
    "cubavamo": "cubare",
    "cubavan": "cubare",
    "cubavano": "cubare",
    "cubavate": "cubare",
    "cubavi": "cubare",
    "cubavo": "cubare",
    "cuberai": "cubare",
    "cuberan": "cubare",
    "cuberanno": "cubare",
    "cuberebbe": "cubare",
    "cuberebber": "cubare",
    "cuberebbero": "cubare",
    "cuberei": "cubare",
    "cuberemmo": "cubare",
    "cuberemo": "cubare",
    "cubereste": "cubare",
    "cuberesti": "cubare",
    "cuberete": "cubare",
    "cuberà": "cubare",
    "cuberò": "cubare",
    "cubetti": "cubetto",
    "cubi": "cubo",
    "cubiamo": "cubare",
    "cubiate": "cubare",
    "cubica": "cubico",
    "cubiche": "cubico",
    "cubici": "cubico",
    "cubicoli": "cubicolo",
    "cubin": "cubare",
    "cubino": "cubare",
    "cubismi": "cubismo",
    "cubiste": "cubista",
    "cubisti": "cubista",
    "cubitali": "cubitale",
    "cubo": "cubare",
    "cubò": "cubare",
    "cucca": "cuccare",
    "cuccagne": "cuccagna",
    "cuccai": "cuccare",
    "cuccammo": "cuccare",
    "cuccan": "cuccare",
    "cuccando": "cuccare",
    "cuccano": "cuccare",
    "cuccante": "cuccare",
    "cuccanti": "cuccare",
    "cuccar": "cuccare",
    "cuccaron": "cuccare",
    "cuccarono": "cuccare",
    "cuccasse": "cuccare",
    "cuccasser": "cuccare",
    "cuccassero": "cuccare",
    "cuccassi": "cuccare",
    "cuccassimo": "cuccare",
    "cuccaste": "cuccare",
    "cuccasti": "cuccare",
    "cuccata": "cuccare",
    "cuccate": "cuccare",
    "cuccati": "cuccare",
    "cuccato": "cuccare",
    "cuccava": "cuccare",
    "cuccavamo": "cuccare",
    "cuccavan": "cuccare",
    "cuccavano": "cuccare",
    "cuccavate": "cuccare",
    "cuccavi": "cuccare",
    "cuccavo": "cuccare",
    "cucce": "cuccia",
    "cuccerai": "cucciare",
    "cucceran": "cucciare",
    "cucceranno": "cucciare",
    "cuccerebbe": "cucciare",
    "cuccerebber": "cucciare",
    "cuccerebbero": "cucciare",
    "cuccerei": "cucciare",
    "cucceremmo": "cucciare",
    "cucceremo": "cucciare",
    "cuccereste": "cucciare",
    "cucceresti": "cucciare",
    "cuccerete": "cucciare",
    "cuccerà": "cucciare",
    "cuccerò": "cucciare",
    "cuccette": "cuccetta",
    "cuccherai": "cuccare",
    "cuccheran": "cuccare",
    "cuccheranno": "cuccare",
    "cuccherebbe": "cuccare",
    "cuccherebber": "cuccare",
    "cuccherebbero": "cuccare",
    "cuccherei": "cuccare",
    "cuccheremmo": "cuccare",
    "cuccheremo": "cuccare",
    "cucchereste": "cuccare",
    "cuccheresti": "cuccare",
    "cuccherete": "cuccare",
    "cuccherà": "cuccare",
    "cuccherò": "cuccare",
    "cucchi": "cuccare",
    "cucchiai": "cucchiaio",
    "cucchiaiate": "cucchiaiata",
    "cucchiaini": "cucchiaino",
    "cucchiamo": "cuccare",
    "cucchiate": "cuccare",
    "cucchin": "cuccare",
    "cucchino": "cuccare",
    "cucci": "cucciare",
    "cuccia": "cucciare",
    "cucciai": "cucciare",
    "cucciammo": "cucciare",
    "cucciamo": "cucciare",
    "cuccian": "cucciare",
    "cucciando": "cucciare",
    "cucciano": "cucciare",
    "cucciante": "cucciare",
    "cuccianti": "cucciare",
    "cucciar": "cucciare",
    "cucciaron": "cucciare",
    "cucciarono": "cucciare",
    "cucciasse": "cucciare",
    "cucciasser": "cucciare",
    "cucciassero": "cucciare",
    "cucciassi": "cucciare",
    "cucciassimo": "cucciare",
    "cucciaste": "cucciare",
    "cucciasti": "cucciare",
    "cucciata": "cucciare",
    "cucciate": "cucciare",
    "cucciati": "cucciare",
    "cucciato": "cucciare",
    "cucciava": "cucciare",
    "cucciavamo": "cucciare",
    "cucciavan": "cucciare",
    "cucciavano": "cucciare",
    "cucciavate": "cucciare",
    "cucciavi": "cucciare",
    "cucciavo": "cucciare",
    "cuccin": "cucciare",
    "cuccino": "cucciare",
    "cuccio": "cucciare",
    "cuccioli": "cucciolo",
    "cucciò": "cucciare",
    "cucco": "cuccare",
    "cuccò": "cuccare",
    "cuce": "cucire",
    "cucendo": "cucire",
    "cucente": "cucire",
    "cucenti": "cucire",
    "cuci": "cucire",
    "cucia": "cucire",
    "cuciamo": "cucire",
    "cucian": "cucire",
    "cuciano": "cucire",
    "cuciate": "cucire",
    "cucii": "cucire",
    "cucimmo": "cucire",
    "cucina": "cucinare",
    "cucinai": "cucinare",
    "cucinammo": "cucinare",
    "cucinan": "cucinare",
    "cucinando": "cucinare",
    "cucinano": "cucinare",
    "cucinante": "cucinare",
    "cucinanti": "cucinare",
    "cucinar": "cucinare",
    "cucinaron": "cucinare",
    "cucinarono": "cucinare",
    "cucinasse": "cucinare",
    "cucinasser": "cucinare",
    "cucinassero": "cucinare",
    "cucinassi": "cucinare",
    "cucinassimo": "cucinare",
    "cucinaste": "cucinare",
    "cucinasti": "cucinare",
    "cucinata": "cucinare",
    "cucinate": "cucinare",
    "cucinati": "cucinare",
    "cucinato": "cucinare",
    "cucinava": "cucinare",
    "cucinavamo": "cucinare",
    "cucinavan": "cucinare",
    "cucinavano": "cucinare",
    "cucinavate": "cucinare",
    "cucinavi": "cucinare",
    "cucinavo": "cucinare",
    "cucine": "cucina",
    "cucinerai": "cucinare",
    "cucineran": "cucinare",
    "cucineranno": "cucinare",
    "cucinerebbe": "cucinare",
    "cucinerebber": "cucinare",
    "cucinerebbero": "cucinare",
    "cucinerei": "cucinare",
    "cucineremmo": "cucinare",
    "cucineremo": "cucinare",
    "cucinereste": "cucinare",
    "cucineresti": "cucinare",
    "cucinerete": "cucinare",
    "cucinerà": "cucinare",
    "cucinerò": "cucinare",
    "cucini": "cucinare",
    "cuciniamo": "cucinare",
    "cuciniate": "cucinare",
    "cucinieri": "cuciniere",
    "cucinin": "cucinare",
    "cucinino": "cucinare",
    "cucino": "cucinare",
    "cucinò": "cucinare",
    "cucio": "cucire",
    "cucion": "cucire",
    "cuciono": "cucire",
    "cucir": "cucire",
    "cucirai": "cucire",
    "cuciran": "cucire",
    "cuciranno": "cucire",
    "cucirebbe": "cucire",
    "cucirebber": "cucire",
    "cucirebbero": "cucire",
    "cucirei": "cucire",
    "cuciremmo": "cucire",
    "cuciremo": "cucire",
    "cucireste": "cucire",
    "cuciresti": "cucire",
    "cucirete": "cucire",
    "cuciron": "cucire",
    "cucirono": "cucire",
    "cucirà": "cucire",
    "cucirò": "cucire",
    "cucisse": "cucire",
    "cucisser": "cucire",
    "cucissero": "cucire",
    "cucissi": "cucire",
    "cucissimo": "cucire",
    "cuciste": "cucire",
    "cucisti": "cucire",
    "cucita": "cucito",
    "cucite": "cucito",
    "cuciti": "cucito",
    "cucito": "cucire",
    "cuciture": "cucitura",
    "cuciva": "cucire",
    "cucivamo": "cucire",
    "cucivan": "cucire",
    "cucivano": "cucire",
    "cucivate": "cucire",
    "cucivi": "cucire",
    "cucivo": "cucire",
    "cucì": "cucire",
    "cuffie": "cuffia",
    "cuffiette": "cuffietta",
    "cugine": "cugina",
    "cuginette": "cuginetta",
    "cuginetti": "cuginetto",
    "cugini": "cugino",
    "culattoni": "culattone",
    "culetti": "culetto",
    "culinari": "culinario",
    "culinaria": "culinario",
    "culinarie": "culinario",
    "culla": "cullare",
    "cullai": "cullare",
    "cullammo": "cullare",
    "cullan": "cullare",
    "cullando": "cullare",
    "cullano": "cullare",
    "cullante": "cullare",
    "cullanti": "cullare",
    "cullar": "cullare",
    "cullaron": "cullare",
    "cullarono": "cullare",
    "cullasse": "cullare",
    "cullasser": "cullare",
    "cullassero": "cullare",
    "cullassi": "cullare",
    "cullassimo": "cullare",
    "cullaste": "cullare",
    "cullasti": "cullare",
    "cullata": "cullare",
    "cullate": "cullare",
    "cullati": "cullare",
    "cullato": "cullare",
    "cullava": "cullare",
    "cullavamo": "cullare",
    "cullavan": "cullare",
    "cullavano": "cullare",
    "cullavate": "cullare",
    "cullavi": "cullare",
    "cullavo": "cullare",
    "culle": "culla",
    "cullerai": "cullare",
    "culleran": "cullare",
    "culleranno": "cullare",
    "cullerebbe": "cullare",
    "cullerebber": "cullare",
    "cullerebbero": "cullare",
    "cullerei": "cullare",
    "culleremmo": "cullare",
    "culleremo": "cullare",
    "cullereste": "cullare",
    "culleresti": "cullare",
    "cullerete": "cullare",
    "cullerà": "cullare",
    "cullerò": "cullare",
    "culli": "cullare",
    "culliamo": "cullare",
    "culliate": "cullare",
    "cullin": "cullare",
    "cullino": "cullare",
    "cullo": "cullare",
    "cullò": "cullare",
    "culmina": "culminare",
    "culminai": "culminare",
    "culminammo": "culminare",
    "culminan": "culminare",
    "culminando": "culminare",
    "culminano": "culminare",
    "culminante": "culminare",
    "culminanti": "culminare",
    "culminar": "culminare",
    "culminaron": "culminare",
    "culminarono": "culminare",
    "culminasse": "culminare",
    "culminasser": "culminare",
    "culminassero": "culminare",
    "culminassi": "culminare",
    "culminassimo": "culminare",
    "culminaste": "culminare",
    "culminasti": "culminare",
    "culminata": "culminare",
    "culminate": "culminare",
    "culminati": "culminare",
    "culminato": "culminare",
    "culminava": "culminare",
    "culminavamo": "culminare",
    "culminavan": "culminare",
    "culminavano": "culminare",
    "culminavate": "culminare",
    "culminavi": "culminare",
    "culminavo": "culminare",
    "culminerai": "culminare",
    "culmineran": "culminare",
    "culmineranno": "culminare",
    "culminerebbe": "culminare",
    "culminerebber": "culminare",
    "culminerebbero": "culminare",
    "culminerei": "culminare",
    "culmineremmo": "culminare",
    "culmineremo": "culminare",
    "culminereste": "culminare",
    "culmineresti": "culminare",
    "culminerete": "culminare",
    "culminerà": "culminare",
    "culminerò": "culminare",
    "culmini": "culmine",
    "culminiamo": "culminare",
    "culminiate": "culminare",
    "culminin": "culminare",
    "culminino": "culminare",
    "culmino": "culminare",
    "culminò": "culminare",
    "culone": "culona",
    "culoni": "culone",
    "culti": "culto",
    "cultori": "cultore",
    "culturali": "culturale",
    "culture": "cultura",
    "culturisti": "culturista",
    "cumula": "cumulare",
    "cumulabili": "cumulabile",
    "cumulai": "cumulare",
    "cumulammo": "cumulare",
    "cumulan": "cumulare",
    "cumulando": "cumulare",
    "cumulano": "cumulare",
    "cumulante": "cumulare",
    "cumulanti": "cumulare",
    "cumular": "cumulare",
    "cumularon": "cumulare",
    "cumularono": "cumulare",
    "cumulasse": "cumulare",
    "cumulasser": "cumulare",
    "cumulassero": "cumulare",
    "cumulassi": "cumulare",
    "cumulassimo": "cumulare",
    "cumulaste": "cumulare",
    "cumulasti": "cumulare",
    "cumulata": "cumulare",
    "cumulate": "cumulare",
    "cumulati": "cumulare",
    "cumulativa": "cumulativo",
    "cumulative": "cumulativo",
    "cumulativi": "cumulativo",
    "cumulato": "cumulare",
    "cumulava": "cumulare",
    "cumulavamo": "cumulare",
    "cumulavan": "cumulare",
    "cumulavano": "cumulare",
    "cumulavate": "cumulare",
    "cumulavi": "cumulare",
    "cumulavo": "cumulare",
    "cumulerai": "cumulare",
    "cumuleran": "cumulare",
    "cumuleranno": "cumulare",
    "cumulerebbe": "cumulare",
    "cumulerebber": "cumulare",
    "cumulerebbero": "cumulare",
    "cumulerei": "cumulare",
    "cumuleremmo": "cumulare",
    "cumuleremo": "cumulare",
    "cumulereste": "cumulare",
    "cumuleresti": "cumulare",
    "cumulerete": "cumulare",
    "cumulerà": "cumulare",
    "cumulerò": "cumulare",
    "cumuli": "cumulo",
    "cumuliamo": "cumulare",
    "cumuliate": "cumulare",
    "cumulin": "cumulare",
    "cumulino": "cumulare",
    "cumulo": "cumulare",
    "cumulò": "cumulare",
    "cuneesi": "cuneese",
    "cunei": "cuneo",
    "cuneiformi": "cuneiforme",
    "cunette": "cunetta",
    "cunicola": "cunicolo",
    "cunicole": "cunicolo",
    "cunicoli": "cunicolo",
    "cuoce": "cuocere",
    "cuocei": "cuocere",
    "cuocemmo": "cuocere",
    "cuocendo": "cuocere",
    "cuocer": "cuocere",
    "cuocerai": "cuocere",
    "cuoceran": "cuocere",
    "cuoceranno": "cuocere",
    "cuocerebbe": "cuocere",
    "cuocerebber": "cuocere",
    "cuocerebbero": "cuocere",
    "cuocerei": "cuocere",
    "cuoceremmo": "cuocere",
    "cuoceremo": "cuocere",
    "cuocereste": "cuocere",
    "cuoceresti": "cuocere",
    "cuocerete": "cuocere",
    "cuoceron": "cuocere",
    "cuocerono": "cuocere",
    "cuocerà": "cuocere",
    "cuocerò": "cuocere",
    "cuocesse": "cuocere",
    "cuocesser": "cuocere",
    "cuocessero": "cuocere",
    "cuocessi": "cuocere",
    "cuocessimo": "cuocere",
    "cuoceste": "cuocere",
    "cuocesti": "cuocere",
    "cuocete": "cuocere",
    "cuoceva": "cuocere",
    "cuocevamo": "cuocere",
    "cuocevan": "cuocere",
    "cuocevano": "cuocere",
    "cuocevate": "cuocere",
    "cuocevi": "cuocere",
    "cuocevo": "cuocere",
    "cuoche": "cuoca",
    "cuochi": "cuoco",
    "cuoci": "cuocere",
    "cuocia": "cuocere",
    "cuociamo": "cuocere",
    "cuocian": "cuocere",
    "cuociano": "cuocere",
    "cuociate": "cuocere",
    "cuocio": "cuocere",
    "cuocion": "cuocere",
    "cuociono": "cuocere",
    "cuocè": "cuocere",
    "cuoi": "cuoio",
    "cuor": "cuore",
    "cuori": "cuore",
    "cuoricini": "cuoricino",
    "cupa": "cupo",
    "cupe": "cupo",
    "cupezze": "cupezza",
    "cupi": "cupo",
    "cupida": "cupido",
    "cupide": "cupido",
    "cupidi": "cupido",
    "cupidige": "cupidigia",
    "cupole": "cupola",
    "cupoloni": "cupolone",
    "cura": "curare",
    "curabili": "curabile",
    "curai": "curare",
    "curammo": "curare",
    "curan": "curare",
    "curando": "curare",
    "curano": "curare",
    "curante": "curare",
    "curanti": "curare",
    "curar": "curare",
    "curari": "curaro",
    "curaron": "curare",
    "curarono": "curare",
    "curasse": "curare",
    "curasser": "curare",
    "curassero": "curare",
    "curassi": "curare",
    "curassimo": "curare",
    "curaste": "curare",
    "curasti": "curare",
    "curata": "curato",
    "curate": "curato",
    "curati": "curato",
    "curativa": "curativo",
    "curative": "curativo",
    "curativi": "curativo",
    "curato": "curare",
    "curatori": "curatore",
    "curatrice": "curatore",
    "curatrici": "curatrice",
    "curava": "curare",
    "curavamo": "curare",
    "curavan": "curare",
    "curavano": "curare",
    "curavate": "curare",
    "curavi": "curare",
    "curavo": "curare",
    "curda": "curdo",
    "curde": "curdo",
    "curdi": "curdo",
    "cure": "cura",
    "curerai": "curare",
    "cureran": "curare",
    "cureranno": "curare",
    "curerebbe": "curare",
    "curerebber": "curare",
    "curerebbero": "curare",
    "curerei": "curare",
    "cureremmo": "curare",
    "cureremo": "curare",
    "curereste": "curare",
    "cureresti": "curare",
    "curerete": "curare",
    "curerà": "curare",
    "curerò": "curare",
    "curi": "curare",
    "curiali": "curiale",
    "curiamo": "curare",
    "curiate": "curare",
    "curie": "curia",
    "curin": "curare",
    "curino": "curare",
    "curiosa": "curioso",
    "curiosai": "curiosare",
    "curiosammo": "curiosare",
    "curiosan": "curiosare",
    "curiosando": "curiosare",
    "curiosano": "curiosare",
    "curiosante": "curiosare",
    "curiosanti": "curiosare",
    "curiosar": "curiosare",
    "curiosaron": "curiosare",
    "curiosarono": "curiosare",
    "curiosasse": "curiosare",
    "curiosasser": "curiosare",
    "curiosassero": "curiosare",
    "curiosassi": "curiosare",
    "curiosassimo": "curiosare",
    "curiosaste": "curiosare",
    "curiosasti": "curiosare",
    "curiosata": "curiosare",
    "curiosate": "curiosare",
    "curiosati": "curiosare",
    "curiosato": "curiosare",
    "curiosava": "curiosare",
    "curiosavamo": "curiosare",
    "curiosavan": "curiosare",
    "curiosavano": "curiosare",
    "curiosavate": "curiosare",
    "curiosavi": "curiosare",
    "curiosavo": "curiosare",
    "curiose": "curioso",
    "curioserai": "curiosare",
    "curioseran": "curiosare",
    "curioseranno": "curiosare",
    "curioserebbe": "curiosare",
    "curioserebber": "curiosare",
    "curioserebbero": "curiosare",
    "curioserei": "curiosare",
    "curioseremmo": "curiosare",
    "curioseremo": "curiosare",
    "curiosereste": "curiosare",
    "curioseresti": "curiosare",
    "curioserete": "curiosare",
    "curioserà": "curiosare",
    "curioserò": "curiosare",
    "curiosi": "curioso",
    "curiosiamo": "curiosare",
    "curiosiate": "curiosare",
    "curiosin": "curiosare",
    "curiosino": "curiosare",
    "curioso": "curiosare",
    "curiosò": "curiosare",
    "curo": "curare",
    "curricula": "curriculum",
    "cursori": "cursore",
    "curva": "curvo",
    "curvai": "curvare",
    "curvammo": "curvare",
    "curvan": "curvare",
    "curvando": "curvare",
    "curvano": "curvare",
    "curvante": "curvare",
    "curvanti": "curvare",
    "curvar": "curvare",
    "curvaron": "curvare",
    "curvarono": "curvare",
    "curvasse": "curvare",
    "curvasser": "curvare",
    "curvassero": "curvare",
    "curvassi": "curvare",
    "curvassimo": "curvare",
    "curvaste": "curvare",
    "curvasti": "curvare",
    "curvata": "curvare",
    "curvate": "curvare",
    "curvati": "curvare",
    "curvato": "curvare",
    "curvature": "curvatura",
    "curvava": "curvare",
    "curvavamo": "curvare",
    "curvavan": "curvare",
    "curvavano": "curvare",
    "curvavate": "curvare",
    "curvavi": "curvare",
    "curvavo": "curvare",
    "curve": "curvo",
    "curverai": "curvare",
    "curveran": "curvare",
    "curveranno": "curvare",
    "curverebbe": "curvare",
    "curverebber": "curvare",
    "curverebbero": "curvare",
    "curverei": "curvare",
    "curveremmo": "curvare",
    "curveremo": "curvare",
    "curvereste": "curvare",
    "curveresti": "curvare",
    "curverete": "curvare",
    "curverà": "curvare",
    "curverò": "curvare",
    "curvi": "curvo",
    "curviamo": "curvare",
    "curviate": "curvare",
    "curvin": "curvare",
    "curvino": "curvare",
    "curvo": "curvare",
    "curvoni": "curvone",
    "curvò": "curvare",
    "curò": "curare",
    "cuscinetti": "cuscinetto",
    "cuscini": "cuscino",
    "cuspidali": "cuspidale",
    "custodendo": "custodire",
    "custodente": "custodire",
    "custodenti": "custodire",
    "custodi": "custode",
    "custodiamo": "custodire",
    "custodiate": "custodire",
    "custodie": "custodia",
    "custodii": "custodire",
    "custodimmo": "custodire",
    "custodir": "custodire",
    "custodirai": "custodire",
    "custodiran": "custodire",
    "custodiranno": "custodire",
    "custodirebbe": "custodire",
    "custodirebber": "custodire",
    "custodirebbero": "custodire",
    "custodirei": "custodire",
    "custodiremmo": "custodire",
    "custodiremo": "custodire",
    "custodireste": "custodire",
    "custodiresti": "custodire",
    "custodirete": "custodire",
    "custodiron": "custodire",
    "custodirono": "custodire",
    "custodirà": "custodire",
    "custodirò": "custodire",
    "custodisca": "custodire",
    "custodiscan": "custodire",
    "custodiscano": "custodire",
    "custodisce": "custodire",
    "custodisci": "custodire",
    "custodisco": "custodire",
    "custodiscon": "custodire",
    "custodiscono": "custodire",
    "custodisse": "custodire",
    "custodisser": "custodire",
    "custodissero": "custodire",
    "custodissi": "custodire",
    "custodissimo": "custodire",
    "custodiste": "custodire",
    "custodisti": "custodire",
    "custodita": "custodire",
    "custodite": "custodire",
    "custoditi": "custodire",
    "custodito": "custodire",
    "custodiva": "custodire",
    "custodivamo": "custodire",
    "custodivan": "custodire",
    "custodivano": "custodire",
    "custodivate": "custodire",
    "custodivi": "custodire",
    "custodivo": "custodire",
    "custodì": "custodire",
    "cutanea": "cutaneo",
    "cutanee": "cutaneo",
    "cutanei": "cutaneo",
    "cuti": "cute",
    "cutoliana": "cutoliano",
    "cutoliane": "cutoliano",
    "cutoliani": "cutoliano",
    "cybernetica": "cybernetico",
    "cybernetiche": "cybernetico",
    "cybernetici": "cybernetico",
    "cyberspazi": "cyberspazio",
    "cyclettes": "cyclette",
    "cèchi": "cèco",
    "d'": "di",
    "da'": "dare",
    "dabbenaggini": "dabbenaggine",
    "dabbeni": "dabbene",
    "dacie": "dacia",
    "dadaismi": "dadaismo",
    "dadaisti": "dadaista",
    "dadi": "dado",
    "dagherrotipi": "dagherrotipo",
    "dagl'": "dal",
    "dagli": "dal",
    "dai": "dare",
    "daini": "daino",
    "dalemiana": "dalemiano",
    "dalemiane": "dalemiano",
    "dalemiani": "dalemiano",
    "dall'": "dalla",
    "dalle": "dalla",
    "dallo": "dal",
    "dalmata": "dalmato",
    "dalmate": "dalmato",
    "dalmati": "dalmato",
    "daltonica": "daltonico",
    "daltoniche": "daltonico",
    "daltonici": "daltonico",
    "damasca": "damascare",
    "damascai": "damascare",
    "damascammo": "damascare",
    "damascan": "damascare",
    "damascando": "damascare",
    "damascano": "damascare",
    "damascante": "damascare",
    "damascanti": "damascare",
    "damascar": "damascare",
    "damascaron": "damascare",
    "damascarono": "damascare",
    "damascasse": "damascare",
    "damascasser": "damascare",
    "damascassero": "damascare",
    "damascassi": "damascare",
    "damascassimo": "damascare",
    "damascaste": "damascare",
    "damascasti": "damascare",
    "damascata": "damascare",
    "damascate": "damascare",
    "damascati": "damascare",
    "damascato": "damascare",
    "damascava": "damascare",
    "damascavamo": "damascare",
    "damascavan": "damascare",
    "damascavano": "damascare",
    "damascavate": "damascare",
    "damascavi": "damascare",
    "damascavo": "damascare",
    "damascherai": "damascare",
    "damascheran": "damascare",
    "damascheranno": "damascare",
    "damascherebbe": "damascare",
    "damascherebber": "damascare",
    "damascherebbero": "damascare",
    "damascherei": "damascare",
    "damascheremmo": "damascare",
    "damascheremo": "damascare",
    "damaschereste": "damascare",
    "damascheresti": "damascare",
    "damascherete": "damascare",
    "damascherà": "damascare",
    "damascherò": "damascare",
    "damaschi": "damascare",
    "damaschiamo": "damascare",
    "damaschiate": "damascare",
    "damaschin": "damascare",
    "damaschina": "damaschinare",
    "damaschinai": "damaschinare",
    "damaschinammo": "damaschinare",
    "damaschinan": "damaschinare",
    "damaschinando": "damaschinare",
    "damaschinano": "damaschinare",
    "damaschinante": "damaschinare",
    "damaschinanti": "damaschinare",
    "damaschinar": "damaschinare",
    "damaschinaron": "damaschinare",
    "damaschinarono": "damaschinare",
    "damaschinasse": "damaschinare",
    "damaschinasser": "damaschinare",
    "damaschinassero": "damaschinare",
    "damaschinassi": "damaschinare",
    "damaschinassimo": "damaschinare",
    "damaschinaste": "damaschinare",
    "damaschinasti": "damaschinare",
    "damaschinata": "damaschinare",
    "damaschinate": "damaschinare",
    "damaschinati": "damaschinare",
    "damaschinato": "damaschinare",
    "damaschinava": "damaschinare",
    "damaschinavamo": "damaschinare",
    "damaschinavan": "damaschinare",
    "damaschinavano": "damaschinare",
    "damaschinavate": "damaschinare",
    "damaschinavi": "damaschinare",
    "damaschinavo": "damaschinare",
    "damaschinerai": "damaschinare",
    "damaschineran": "damaschinare",
    "damaschineranno": "damaschinare",
    "damaschinerebbe": "damaschinare",
    "damaschinerebber": "damaschinare",
    "damaschinerebbero": "damaschinare",
    "damaschinerei": "damaschinare",
    "damaschineremmo": "damaschinare",
    "damaschineremo": "damaschinare",
    "damaschinereste": "damaschinare",
    "damaschineresti": "damaschinare",
    "damaschinerete": "damaschinare",
    "damaschinerà": "damaschinare",
    "damaschinerò": "damaschinare",
    "damaschini": "damaschinare",
    "damaschiniamo": "damaschinare",
    "damaschiniate": "damaschinare",
    "damaschinin": "damaschinare",
    "damaschinino": "damaschinare",
    "damaschino": "damaschinare",
    "damaschinò": "damaschinare",
    "damasco": "damascare",
    "damascò": "damascare",
    "damazze": "damazza",
    "dame": "dama",
    "damerini": "damerino",
    "damigelle": "damigella",
    "damigiane": "damigiana",
    "dan": "dare",
    "danari": "danaro",
    "danarosa": "danaroso",
    "danarose": "danaroso",
    "danarosi": "danaroso",
    "dando": "dare",
    "dandystica": "dandystico",
    "dandystiche": "dandystico",
    "dandystici": "dandystico",
    "danesi": "danese",
    "danna": "dannare",
    "dannai": "dannare",
    "dannammo": "dannare",
    "dannan": "dannare",
    "dannando": "dannare",
    "dannano": "dannare",
    "dannante": "dannare",
    "dannanti": "dannare",
    "dannar": "dannare",
    "dannaron": "dannare",
    "dannarono": "dannare",
    "dannasse": "dannare",
    "dannasser": "dannare",
    "dannassero": "dannare",
    "dannassi": "dannare",
    "dannassimo": "dannare",
    "dannaste": "dannare",
    "dannasti": "dannare",
    "dannata": "dannato",
    "dannate": "dannato",
    "dannati": "dannato",
    "dannato": "dannare",
    "dannava": "dannare",
    "dannavamo": "dannare",
    "dannavan": "dannare",
    "dannavano": "dannare",
    "dannavate": "dannare",
    "dannavi": "dannare",
    "dannavo": "dannare",
    "dannazioni": "dannazione",
    "danneggerai": "danneggiare",
    "danneggeran": "danneggiare",
    "danneggeranno": "danneggiare",
    "danneggerebbe": "danneggiare",
    "danneggerebber": "danneggiare",
    "danneggerebbero": "danneggiare",
    "danneggerei": "danneggiare",
    "danneggeremmo": "danneggiare",
    "danneggeremo": "danneggiare",
    "danneggereste": "danneggiare",
    "danneggeresti": "danneggiare",
    "danneggerete": "danneggiare",
    "danneggerà": "danneggiare",
    "danneggerò": "danneggiare",
    "danneggi": "danneggiare",
    "danneggia": "danneggiare",
    "danneggiai": "danneggiare",
    "danneggiamenti": "danneggiamento",
    "danneggiammo": "danneggiare",
    "danneggiamo": "danneggiare",
    "danneggian": "danneggiare",
    "danneggiando": "danneggiare",
    "danneggiano": "danneggiare",
    "danneggiante": "danneggiare",
    "danneggianti": "danneggiare",
    "danneggiar": "danneggiare",
    "danneggiaron": "danneggiare",
    "danneggiarono": "danneggiare",
    "danneggiasse": "danneggiare",
    "danneggiasser": "danneggiare",
    "danneggiassero": "danneggiare",
    "danneggiassi": "danneggiare",
    "danneggiassimo": "danneggiare",
    "danneggiaste": "danneggiare",
    "danneggiasti": "danneggiare",
    "danneggiata": "danneggiato",
    "danneggiate": "danneggiato",
    "danneggiati": "danneggiato",
    "danneggiato": "danneggiare",
    "danneggiava": "danneggiare",
    "danneggiavamo": "danneggiare",
    "danneggiavan": "danneggiare",
    "danneggiavano": "danneggiare",
    "danneggiavate": "danneggiare",
    "danneggiavi": "danneggiare",
    "danneggiavo": "danneggiare",
    "danneggin": "danneggiare",
    "danneggino": "danneggiare",
    "danneggio": "danneggiare",
    "danneggiò": "danneggiare",
    "dannerai": "dannare",
    "danneran": "dannare",
    "danneranno": "dannare",
    "dannerebbe": "dannare",
    "dannerebber": "dannare",
    "dannerebbero": "dannare",
    "dannerei": "dannare",
    "danneremmo": "dannare",
    "danneremo": "dannare",
    "dannereste": "dannare",
    "danneresti": "dannare",
    "dannerete": "dannare",
    "dannerà": "dannare",
    "dannerò": "dannare",
    "danni": "danno",
    "danniamo": "dannare",
    "danniate": "dannare",
    "dannin": "dannare",
    "dannino": "dannare",
    "danno": "dare",
    "dannosa": "dannoso",
    "dannose": "dannoso",
    "dannosi": "dannoso",
    "dannunziana": "dannunziano",
    "dannunziane": "dannunziano",
    "dannunziani": "dannunziano",
    "dannò": "dannare",
    "dante": "dare",
    "dantesca": "dantesco",
    "dantesche": "dantesco",
    "danteschi": "dantesco",
    "danti": "dare",
    "dantoniana": "dantoniano",
    "dantoniane": "dantoniano",
    "dantoniani": "dantoniano",
    "danza": "danzare",
    "danzai": "danzare",
    "danzammo": "danzare",
    "danzan": "danzare",
    "danzando": "danzare",
    "danzano": "danzare",
    "danzante": "danzare",
    "danzanti": "danzare",
    "danzar": "danzare",
    "danzaron": "danzare",
    "danzarono": "danzare",
    "danzasse": "danzare",
    "danzasser": "danzare",
    "danzassero": "danzare",
    "danzassi": "danzare",
    "danzassimo": "danzare",
    "danzaste": "danzare",
    "danzasti": "danzare",
    "danzata": "danzare",
    "danzate": "danzare",
    "danzati": "danzare",
    "danzato": "danzare",
    "danzatori": "danzatore",
    "danzatrici": "danzatrice",
    "danzava": "danzare",
    "danzavamo": "danzare",
    "danzavan": "danzare",
    "danzavano": "danzare",
    "danzavate": "danzare",
    "danzavi": "danzare",
    "danzavo": "danzare",
    "danze": "danza",
    "danzerai": "danzare",
    "danzeran": "danzare",
    "danzeranno": "danzare",
    "danzerebbe": "danzare",
    "danzerebber": "danzare",
    "danzerebbero": "danzare",
    "danzerei": "danzare",
    "danzeremmo": "danzare",
    "danzeremo": "danzare",
    "danzereste": "danzare",
    "danzeresti": "danzare",
    "danzerete": "danzare",
    "danzerà": "danzare",
    "danzerò": "danzare",
    "danzi": "danzare",
    "danziamo": "danzare",
    "danziate": "danzare",
    "danzin": "danzare",
    "danzino": "danzare",
    "danzo": "danzare",
    "danzò": "danzare",
    "dar": "dare",
    "darai": "dare",
    "daran": "dare",
    "daranno": "dare",
    "dardeggerai": "dardeggiare",
    "dardeggeran": "dardeggiare",
    "dardeggeranno": "dardeggiare",
    "dardeggerebbe": "dardeggiare",
    "dardeggerebber": "dardeggiare",
    "dardeggerebbero": "dardeggiare",
    "dardeggerei": "dardeggiare",
    "dardeggeremmo": "dardeggiare",
    "dardeggeremo": "dardeggiare",
    "dardeggereste": "dardeggiare",
    "dardeggeresti": "dardeggiare",
    "dardeggerete": "dardeggiare",
    "dardeggerà": "dardeggiare",
    "dardeggerò": "dardeggiare",
    "dardeggi": "dardeggiare",
    "dardeggia": "dardeggiare",
    "dardeggiai": "dardeggiare",
    "dardeggiammo": "dardeggiare",
    "dardeggiamo": "dardeggiare",
    "dardeggian": "dardeggiare",
    "dardeggiando": "dardeggiare",
    "dardeggiano": "dardeggiare",
    "dardeggiante": "dardeggiare",
    "dardeggianti": "dardeggiare",
    "dardeggiar": "dardeggiare",
    "dardeggiaron": "dardeggiare",
    "dardeggiarono": "dardeggiare",
    "dardeggiasse": "dardeggiare",
    "dardeggiasser": "dardeggiare",
    "dardeggiassero": "dardeggiare",
    "dardeggiassi": "dardeggiare",
    "dardeggiassimo": "dardeggiare",
    "dardeggiaste": "dardeggiare",
    "dardeggiasti": "dardeggiare",
    "dardeggiata": "dardeggiare",
    "dardeggiate": "dardeggiare",
    "dardeggiati": "dardeggiare",
    "dardeggiato": "dardeggiare",
    "dardeggiava": "dardeggiare",
    "dardeggiavamo": "dardeggiare",
    "dardeggiavan": "dardeggiare",
    "dardeggiavano": "dardeggiare",
    "dardeggiavate": "dardeggiare",
    "dardeggiavi": "dardeggiare",
    "dardeggiavo": "dardeggiare",
    "dardeggin": "dardeggiare",
    "dardeggino": "dardeggiare",
    "dardeggio": "dardeggiare",
    "dardeggiò": "dardeggiare",
    "dardi": "dardo",
    "darebbe": "dare",
    "darebber": "dare",
    "darebbero": "dare",
    "darei": "dare",
    "daremmo": "dare",
    "daremo": "dare",
    "dareste": "dare",
    "daresti": "dare",
    "darete": "dare",
    "darsene": "darsena",
    "darwiniana": "darwiniano",
    "darwiniane": "darwiniano",
    "darwiniani": "darwiniano",
    "darwinismi": "darwinismo",
    "darà": "dare",
    "darò": "dare",
    "data": "dato",
    "databili": "databile",
    "datai": "datare",
    "datammo": "datare",
    "datan": "datare",
    "datando": "datare",
    "datano": "datare",
    "datante": "datare",
    "datanti": "datare",
    "datar": "datare",
    "dataron": "datare",
    "datarono": "datare",
    "datasse": "datare",
    "datasser": "datare",
    "datassero": "datare",
    "datassi": "datare",
    "datassimo": "datare",
    "dataste": "datare",
    "datasti": "datare",
    "datata": "datato",
    "datate": "datato",
    "datati": "datato",
    "datato": "datare",
    "datava": "datare",
    "datavamo": "datare",
    "datavan": "datare",
    "datavano": "datare",
    "datavate": "datare",
    "datavi": "datare",
    "datavo": "datare",
    "datazioni": "datazione",
    "date": "dato",
    "daterai": "datare",
    "dateran": "datare",
    "dateranno": "datare",
    "daterebbe": "datare",
    "daterebber": "datare",
    "daterebbero": "datare",
    "daterei": "datare",
    "dateremmo": "datare",
    "dateremo": "datare",
    "datereste": "datare",
    "dateresti": "datare",
    "daterete": "datare",
    "daterà": "datare",
    "daterò": "datare",
    "dati": "dato",
    "datiamo": "datare",
    "datiate": "datare",
    "datin": "datare",
    "datino": "datare",
    "dato": "datare",
    "datori": "datore",
    "datteri": "dattero",
    "dattilica": "dattilico",
    "dattiliche": "dattilico",
    "dattilici": "dattilico",
    "dattilografa": "dattilografare",
    "dattilografai": "dattilografare",
    "dattilografammo": "dattilografare",
    "dattilografan": "dattilografare",
    "dattilografando": "dattilografare",
    "dattilografano": "dattilografare",
    "dattilografante": "dattilografare",
    "dattilografanti": "dattilografare",
    "dattilografar": "dattilografare",
    "dattilografaron": "dattilografare",
    "dattilografarono": "dattilografare",
    "dattilografasse": "dattilografare",
    "dattilografasser": "dattilografare",
    "dattilografassero": "dattilografare",
    "dattilografassi": "dattilografare",
    "dattilografassimo": "dattilografare",
    "dattilografaste": "dattilografare",
    "dattilografasti": "dattilografare",
    "dattilografata": "dattilografare",
    "dattilografate": "dattilografare",
    "dattilografati": "dattilografare",
    "dattilografato": "dattilografare",
    "dattilografava": "dattilografare",
    "dattilografavamo": "dattilografare",
    "dattilografavan": "dattilografare",
    "dattilografavano": "dattilografare",
    "dattilografavate": "dattilografare",
    "dattilografavi": "dattilografare",
    "dattilografavo": "dattilografare",
    "dattilografe": "dattilografa",
    "dattilograferai": "dattilografare",
    "dattilograferan": "dattilografare",
    "dattilograferanno": "dattilografare",
    "dattilograferebbe": "dattilografare",
    "dattilograferebber": "dattilografare",
    "dattilograferebbero": "dattilografare",
    "dattilograferei": "dattilografare",
    "dattilograferemmo": "dattilografare",
    "dattilograferemo": "dattilografare",
    "dattilografereste": "dattilografare",
    "dattilograferesti": "dattilografare",
    "dattilograferete": "dattilografare",
    "dattilograferà": "dattilografare",
    "dattilograferò": "dattilografare",
    "dattilografi": "dattilografo",
    "dattilografiamo": "dattilografare",
    "dattilografiate": "dattilografare",
    "dattilografin": "dattilografare",
    "dattilografino": "dattilografare",
    "dattilografo": "dattilografare",
    "dattilografò": "dattilografare",
    "dattiloscritta": "dattiloscritto",
    "dattiloscritte": "dattiloscritto",
    "dattiloscritti": "dattiloscritto",
    "dattiloscriva": "dattiloscrivere",
    "dattiloscrivan": "dattiloscrivere",
    "dattiloscrivano": "dattiloscrivere",
    "dattiloscrive": "dattiloscrivere",
    "dattiloscrivei": "dattiloscrivere",
    "dattiloscrivemmo": "dattiloscrivere",
    "dattiloscrivendo": "dattiloscrivere",
    "dattiloscrivente": "dattiloscrivere",
    "dattiloscriventi": "dattiloscrivere",
    "dattiloscriver": "dattiloscrivere",
    "dattiloscriverai": "dattiloscrivere",
    "dattiloscriveran": "dattiloscrivere",
    "dattiloscriveranno": "dattiloscrivere",
    "dattiloscriverebbe": "dattiloscrivere",
    "dattiloscriverebber": "dattiloscrivere",
    "dattiloscriverebbero": "dattiloscrivere",
    "dattiloscriverei": "dattiloscrivere",
    "dattiloscriveremmo": "dattiloscrivere",
    "dattiloscriveremo": "dattiloscrivere",
    "dattiloscrivereste": "dattiloscrivere",
    "dattiloscriveresti": "dattiloscrivere",
    "dattiloscriverete": "dattiloscrivere",
    "dattiloscriveron": "dattiloscrivere",
    "dattiloscriverono": "dattiloscrivere",
    "dattiloscriverà": "dattiloscrivere",
    "dattiloscriverò": "dattiloscrivere",
    "dattiloscrivesse": "dattiloscrivere",
    "dattiloscrivesser": "dattiloscrivere",
    "dattiloscrivessero": "dattiloscrivere",
    "dattiloscrivessi": "dattiloscrivere",
    "dattiloscrivessimo": "dattiloscrivere",
    "dattiloscriveste": "dattiloscrivere",
    "dattiloscrivesti": "dattiloscrivere",
    "dattiloscrivete": "dattiloscrivere",
    "dattiloscriveva": "dattiloscrivere",
    "dattiloscrivevamo": "dattiloscrivere",
    "dattiloscrivevan": "dattiloscrivere",
    "dattiloscrivevano": "dattiloscrivere",
    "dattiloscrivevate": "dattiloscrivere",
    "dattiloscrivevi": "dattiloscrivere",
    "dattiloscrivevo": "dattiloscrivere",
    "dattiloscrivi": "dattiloscrivere",
    "dattiloscriviamo": "dattiloscrivere",
    "dattiloscriviate": "dattiloscrivere",
    "dattiloscrivo": "dattiloscrivere",
    "dattiloscrivon": "dattiloscrivere",
    "dattiloscrivono": "dattiloscrivere",
    "dattiloscrivuta": "dattiloscrivere",
    "dattiloscrivute": "dattiloscrivere",
    "dattiloscrivuti": "dattiloscrivere",
    "dattiloscrivuto": "dattiloscrivere",
    "dattiloscrivè": "dattiloscrivere",
    "datò": "datare",
    "dava": "dare",
    "davamo": "dare",
    "davan": "dare",
    "davano": "dare",
    "davanzali": "davanzale",
    "davate": "dare",
    "davi": "dare",
    "davo": "dare",
    "dazi": "dazio",
    "dazia": "daziare",
    "daziai": "daziare",
    "daziammo": "daziare",
    "daziamo": "daziare",
    "dazian": "daziare",
    "daziando": "daziare",
    "daziano": "daziare",
    "daziante": "daziare",
    "dazianti": "daziare",
    "daziar": "daziare",
    "daziari": "daziario",
    "daziaria": "daziario",
    "daziarie": "daziario",
    "daziaron": "daziare",
    "daziarono": "daziare",
    "daziasse": "daziare",
    "daziasser": "daziare",
    "daziassero": "daziare",
    "daziassi": "daziare",
    "daziassimo": "daziare",
    "daziaste": "daziare",
    "daziasti": "daziare",
    "daziata": "daziare",
    "daziate": "daziare",
    "daziati": "daziare",
    "daziato": "daziare",
    "daziava": "daziare",
    "daziavamo": "daziare",
    "daziavan": "daziare",
    "daziavano": "daziare",
    "daziavate": "daziare",
    "daziavi": "daziare",
    "daziavo": "daziare",
    "dazierai": "daziare",
    "dazieran": "daziare",
    "dazieranno": "daziare",
    "dazierebbe": "daziare",
    "dazierebber": "daziare",
    "dazierebbero": "daziare",
    "dazierei": "daziare",
    "dazieremmo": "daziare",
    "dazieremo": "daziare",
    "daziereste": "daziare",
    "dazieresti": "daziare",
    "dazierete": "daziare",
    "dazierà": "daziare",
    "dazierò": "daziare",
    "dazin": "daziare",
    "dazino": "daziare",
    "dazio": "daziare",
    "dazioni": "dazione",
    "daziò": "daziare",
    "dealers": "dealer",
    "deambula": "deambulare",
    "deambulai": "deambulare",
    "deambulammo": "deambulare",
    "deambulan": "deambulare",
    "deambulando": "deambulare",
    "deambulano": "deambulare",
    "deambulante": "deambulare",
    "deambulanti": "deambulare",
    "deambular": "deambulare",
    "deambularon": "deambulare",
    "deambularono": "deambulare",
    "deambulasse": "deambulare",
    "deambulasser": "deambulare",
    "deambulassero": "deambulare",
    "deambulassi": "deambulare",
    "deambulassimo": "deambulare",
    "deambulaste": "deambulare",
    "deambulasti": "deambulare",
    "deambulata": "deambulare",
    "deambulate": "deambulare",
    "deambulati": "deambulare",
    "deambulato": "deambulare",
    "deambulava": "deambulare",
    "deambulavamo": "deambulare",
    "deambulavan": "deambulare",
    "deambulavano": "deambulare",
    "deambulavate": "deambulare",
    "deambulavi": "deambulare",
    "deambulavo": "deambulare",
    "deambulazioni": "deambulazione",
    "deambulerai": "deambulare",
    "deambuleran": "deambulare",
    "deambuleranno": "deambulare",
    "deambulerebbe": "deambulare",
    "deambulerebber": "deambulare",
    "deambulerebbero": "deambulare",
    "deambulerei": "deambulare",
    "deambuleremmo": "deambulare",
    "deambuleremo": "deambulare",
    "deambulereste": "deambulare",
    "deambuleresti": "deambulare",
    "deambulerete": "deambulare",
    "deambulerà": "deambulare",
    "deambulerò": "deambulare",
    "deambuli": "deambulare",
    "deambuliamo": "deambulare",
    "deambuliate": "deambulare",
    "deambulin": "deambulare",
    "deambulino": "deambulare",
    "deambulo": "deambulare",
    "deambulò": "deambulare",
    "deamicisiana": "deamicisiano",
    "deamicisiane": "deamicisiano",
    "deamicisiani": "deamicisiano",
    "debba": "dovere",
    "debban": "dovere",
    "debbano": "dovere",
    "debbi": "debbiare",
    "debbia": "debbiare",
    "debbiai": "debbiare",
    "debbiammo": "debbiare",
    "debbiamo": "debbiare",
    "debbian": "debbiare",
    "debbiando": "debbiare",
    "debbiano": "debbiare",
    "debbiante": "debbiare",
    "debbianti": "debbiare",
    "debbiar": "debbiare",
    "debbiaron": "debbiare",
    "debbiarono": "debbiare",
    "debbiasse": "debbiare",
    "debbiasser": "debbiare",
    "debbiassero": "debbiare",
    "debbiassi": "debbiare",
    "debbiassimo": "debbiare",
    "debbiaste": "debbiare",
    "debbiasti": "debbiare",
    "debbiata": "debbiare",
    "debbiate": "debbiare",
    "debbiati": "debbiare",
    "debbiato": "debbiare",
    "debbiava": "debbiare",
    "debbiavamo": "debbiare",
    "debbiavan": "debbiare",
    "debbiavano": "debbiare",
    "debbiavate": "debbiare",
    "debbiavi": "debbiare",
    "debbiavo": "debbiare",
    "debbierai": "debbiare",
    "debbieran": "debbiare",
    "debbieranno": "debbiare",
    "debbierebbe": "debbiare",
    "debbierebber": "debbiare",
    "debbierebbero": "debbiare",
    "debbierei": "debbiare",
    "debbieremmo": "debbiare",
    "debbieremo": "debbiare",
    "debbiereste": "debbiare",
    "debbieresti": "debbiare",
    "debbierete": "debbiare",
    "debbierà": "debbiare",
    "debbierò": "debbiare",
    "debbin": "debbiare",
    "debbino": "debbiare",
    "debbio": "debbiare",
    "debbiò": "debbiare",
    "debella": "debellare",
    "debellai": "debellare",
    "debellammo": "debellare",
    "debellan": "debellare",
    "debellando": "debellare",
    "debellano": "debellare",
    "debellante": "debellare",
    "debellanti": "debellare",
    "debellar": "debellare",
    "debellaron": "debellare",
    "debellarono": "debellare",
    "debellasse": "debellare",
    "debellasser": "debellare",
    "debellassero": "debellare",
    "debellassi": "debellare",
    "debellassimo": "debellare",
    "debellaste": "debellare",
    "debellasti": "debellare",
    "debellata": "debellare",
    "debellate": "debellare",
    "debellati": "debellare",
    "debellato": "debellare",
    "debellava": "debellare",
    "debellavamo": "debellare",
    "debellavan": "debellare",
    "debellavano": "debellare",
    "debellavate": "debellare",
    "debellavi": "debellare",
    "debellavo": "debellare",
    "debellerai": "debellare",
    "debelleran": "debellare",
    "debelleranno": "debellare",
    "debellerebbe": "debellare",
    "debellerebber": "debellare",
    "debellerebbero": "debellare",
    "debellerei": "debellare",
    "debelleremmo": "debellare",
    "debelleremo": "debellare",
    "debellereste": "debellare",
    "debelleresti": "debellare",
    "debellerete": "debellare",
    "debellerà": "debellare",
    "debellerò": "debellare",
    "debelli": "debellare",
    "debelliamo": "debellare",
    "debelliate": "debellare",
    "debellin": "debellare",
    "debellino": "debellare",
    "debello": "debellare",
    "debellò": "debellare",
    "debenedettiana": "debenedettiano",
    "debenedettiane": "debenedettiano",
    "debenedettiani": "debenedettiano",
    "debilita": "debilitare",
    "debilitai": "debilitare",
    "debilitammo": "debilitare",
    "debilitan": "debilitare",
    "debilitando": "debilitare",
    "debilitano": "debilitare",
    "debilitante": "debilitare",
    "debilitanti": "debilitare",
    "debilitar": "debilitare",
    "debilitaron": "debilitare",
    "debilitarono": "debilitare",
    "debilitasse": "debilitare",
    "debilitasser": "debilitare",
    "debilitassero": "debilitare",
    "debilitassi": "debilitare",
    "debilitassimo": "debilitare",
    "debilitaste": "debilitare",
    "debilitasti": "debilitare",
    "debilitata": "debilitare",
    "debilitate": "debilitare",
    "debilitati": "debilitare",
    "debilitato": "debilitare",
    "debilitava": "debilitare",
    "debilitavamo": "debilitare",
    "debilitavan": "debilitare",
    "debilitavano": "debilitare",
    "debilitavate": "debilitare",
    "debilitavi": "debilitare",
    "debilitavo": "debilitare",
    "debiliterai": "debilitare",
    "debiliteran": "debilitare",
    "debiliteranno": "debilitare",
    "debiliterebbe": "debilitare",
    "debiliterebber": "debilitare",
    "debiliterebbero": "debilitare",
    "debiliterei": "debilitare",
    "debiliteremmo": "debilitare",
    "debiliteremo": "debilitare",
    "debilitereste": "debilitare",
    "debiliteresti": "debilitare",
    "debiliterete": "debilitare",
    "debiliterà": "debilitare",
    "debiliterò": "debilitare",
    "debiliti": "debilitare",
    "debilitiamo": "debilitare",
    "debilitiate": "debilitare",
    "debilitin": "debilitare",
    "debilitino": "debilitare",
    "debilito": "debilitare",
    "debilitò": "debilitare",
    "debita": "debito",
    "debite": "debito",
    "debiti": "debito",
    "debitori": "debitorio",
    "debitoria": "debitorio",
    "debitorie": "debitorio",
    "debitrice": "debitore",
    "debitrici": "debitore",
    "debolezze": "debolezza",
    "deboli": "debole",
    "deborda": "debordare",
    "debordai": "debordare",
    "debordammo": "debordare",
    "debordan": "debordare",
    "debordando": "debordare",
    "debordano": "debordare",
    "debordante": "debordare",
    "debordanti": "debordare",
    "debordar": "debordare",
    "debordaron": "debordare",
    "debordarono": "debordare",
    "debordasse": "debordare",
    "debordasser": "debordare",
    "debordassero": "debordare",
    "debordassi": "debordare",
    "debordassimo": "debordare",
    "debordaste": "debordare",
    "debordasti": "debordare",
    "debordata": "debordare",
    "debordate": "debordare",
    "debordati": "debordare",
    "debordato": "debordare",
    "debordava": "debordare",
    "debordavamo": "debordare",
    "debordavan": "debordare",
    "debordavano": "debordare",
    "debordavate": "debordare",
    "debordavi": "debordare",
    "debordavo": "debordare",
    "deborderai": "debordare",
    "deborderan": "debordare",
    "deborderanno": "debordare",
    "deborderebbe": "debordare",
    "deborderebber": "debordare",
    "deborderebbero": "debordare",
    "deborderei": "debordare",
    "deborderemmo": "debordare",
    "deborderemo": "debordare",
    "debordereste": "debordare",
    "deborderesti": "debordare",
    "deborderete": "debordare",
    "deborderà": "debordare",
    "deborderò": "debordare",
    "debordi": "debordare",
    "debordiamo": "debordare",
    "debordiate": "debordare",
    "debordin": "debordare",
    "debordino": "debordare",
    "debordo": "debordare",
    "debordò": "debordare",
    "debosciata": "debosciato",
    "debosciate": "debosciato",
    "debosciati": "debosciato",
    "deburocratizza": "deburocratizzare",
    "deburocratizzai": "deburocratizzare",
    "deburocratizzammo": "deburocratizzare",
    "deburocratizzan": "deburocratizzare",
    "deburocratizzando": "deburocratizzare",
    "deburocratizzano": "deburocratizzare",
    "deburocratizzante": "deburocratizzare",
    "deburocratizzanti": "deburocratizzare",
    "deburocratizzar": "deburocratizzare",
    "deburocratizzaron": "deburocratizzare",
    "deburocratizzarono": "deburocratizzare",
    "deburocratizzasse": "deburocratizzare",
    "deburocratizzasser": "deburocratizzare",
    "deburocratizzassero": "deburocratizzare",
    "deburocratizzassi": "deburocratizzare",
    "deburocratizzassimo": "deburocratizzare",
    "deburocratizzaste": "deburocratizzare",
    "deburocratizzasti": "deburocratizzare",
    "deburocratizzata": "deburocratizzare",
    "deburocratizzate": "deburocratizzare",
    "deburocratizzati": "deburocratizzare",
    "deburocratizzato": "deburocratizzare",
    "deburocratizzava": "deburocratizzare",
    "deburocratizzavamo": "deburocratizzare",
    "deburocratizzavan": "deburocratizzare",
    "deburocratizzavano": "deburocratizzare",
    "deburocratizzavate": "deburocratizzare",
    "deburocratizzavi": "deburocratizzare",
    "deburocratizzavo": "deburocratizzare",
    "deburocratizzerai": "deburocratizzare",
    "deburocratizzeran": "deburocratizzare",
    "deburocratizzeranno": "deburocratizzare",
    "deburocratizzerebbe": "deburocratizzare",
    "deburocratizzerebber": "deburocratizzare",
    "deburocratizzerebbero": "deburocratizzare",
    "deburocratizzerei": "deburocratizzare",
    "deburocratizzeremmo": "deburocratizzare",
    "deburocratizzeremo": "deburocratizzare",
    "deburocratizzereste": "deburocratizzare",
    "deburocratizzeresti": "deburocratizzare",
    "deburocratizzerete": "deburocratizzare",
    "deburocratizzerà": "deburocratizzare",
    "deburocratizzerò": "deburocratizzare",
    "deburocratizzi": "deburocratizzare",
    "deburocratizziamo": "deburocratizzare",
    "deburocratizziate": "deburocratizzare",
    "deburocratizzin": "deburocratizzare",
    "deburocratizzino": "deburocratizzare",
    "deburocratizzo": "deburocratizzare",
    "deburocratizzò": "deburocratizzare",
    "debutta": "debuttare",
    "debuttai": "debuttare",
    "debuttammo": "debuttare",
    "debuttan": "debuttare",
    "debuttando": "debuttare",
    "debuttano": "debuttare",
    "debuttante": "debuttare",
    "debuttanti": "debuttare",
    "debuttar": "debuttare",
    "debuttaron": "debuttare",
    "debuttarono": "debuttare",
    "debuttasse": "debuttare",
    "debuttasser": "debuttare",
    "debuttassero": "debuttare",
    "debuttassi": "debuttare",
    "debuttassimo": "debuttare",
    "debuttaste": "debuttare",
    "debuttasti": "debuttare",
    "debuttata": "debuttare",
    "debuttate": "debuttare",
    "debuttati": "debuttare",
    "debuttato": "debuttare",
    "debuttava": "debuttare",
    "debuttavamo": "debuttare",
    "debuttavan": "debuttare",
    "debuttavano": "debuttare",
    "debuttavate": "debuttare",
    "debuttavi": "debuttare",
    "debuttavo": "debuttare",
    "debutterai": "debuttare",
    "debutteran": "debuttare",
    "debutteranno": "debuttare",
    "debutterebbe": "debuttare",
    "debutterebber": "debuttare",
    "debutterebbero": "debuttare",
    "debutterei": "debuttare",
    "debutteremmo": "debuttare",
    "debutteremo": "debuttare",
    "debuttereste": "debuttare",
    "debutteresti": "debuttare",
    "debutterete": "debuttare",
    "debutterà": "debuttare",
    "debutterò": "debuttare",
    "debutti": "debutto",
    "debuttiamo": "debuttare",
    "debuttiate": "debuttare",
    "debuttin": "debuttare",
    "debuttino": "debuttare",
    "debutto": "debuttare",
    "debuttò": "debuttare",
    "decada": "decadere",
    "decadan": "decadere",
    "decadano": "decadere",
    "decadde": "decadere",
    "decadder": "decadere",
    "decaddero": "decadere",
    "decaddi": "decadere",
    "decade": "decadere",
    "decademmo": "decadere",
    "decadendo": "decadere",
    "decadente": "decadere",
    "decadenti": "decadere",
    "decadentismi": "decadentismo",
    "decadenze": "decadenza",
    "decader": "decadere",
    "decadesse": "decadere",
    "decadesser": "decadere",
    "decadessero": "decadere",
    "decadessi": "decadere",
    "decadessimo": "decadere",
    "decadeste": "decadere",
    "decadesti": "decadere",
    "decadete": "decadere",
    "decadeva": "decadere",
    "decadevamo": "decadere",
    "decadevan": "decadere",
    "decadevano": "decadere",
    "decadevate": "decadere",
    "decadevi": "decadere",
    "decadevo": "decadere",
    "decadi": "decadere",
    "decadiamo": "decadere",
    "decadiate": "decadere",
    "decadimenti": "decadimento",
    "decado": "decadere",
    "decadon": "decadere",
    "decadono": "decadere",
    "decadrai": "decadere",
    "decadran": "decadere",
    "decadranno": "decadere",
    "decadrebbe": "decadere",
    "decadrebber": "decadere",
    "decadrebbero": "decadere",
    "decadrei": "decadere",
    "decadremmo": "decadere",
    "decadremo": "decadere",
    "decadreste": "decadere",
    "decadresti": "decadere",
    "decadrete": "decadere",
    "decadrà": "decadere",
    "decadrò": "decadere",
    "decaduta": "decaduto",
    "decadute": "decaduto",
    "decaduti": "decaduto",
    "decaduto": "decadere",
    "decaffeina": "decaffeinare",
    "decaffeinai": "decaffeinare",
    "decaffeinammo": "decaffeinare",
    "decaffeinan": "decaffeinare",
    "decaffeinando": "decaffeinare",
    "decaffeinano": "decaffeinare",
    "decaffeinante": "decaffeinare",
    "decaffeinanti": "decaffeinare",
    "decaffeinar": "decaffeinare",
    "decaffeinaron": "decaffeinare",
    "decaffeinarono": "decaffeinare",
    "decaffeinasse": "decaffeinare",
    "decaffeinasser": "decaffeinare",
    "decaffeinassero": "decaffeinare",
    "decaffeinassi": "decaffeinare",
    "decaffeinassimo": "decaffeinare",
    "decaffeinaste": "decaffeinare",
    "decaffeinasti": "decaffeinare",
    "decaffeinata": "decaffeinare",
    "decaffeinate": "decaffeinare",
    "decaffeinati": "decaffeinare",
    "decaffeinato": "decaffeinare",
    "decaffeinava": "decaffeinare",
    "decaffeinavamo": "decaffeinare",
    "decaffeinavan": "decaffeinare",
    "decaffeinavano": "decaffeinare",
    "decaffeinavate": "decaffeinare",
    "decaffeinavi": "decaffeinare",
    "decaffeinavo": "decaffeinare",
    "decaffeinerai": "decaffeinare",
    "decaffeineran": "decaffeinare",
    "decaffeineranno": "decaffeinare",
    "decaffeinerebbe": "decaffeinare",
    "decaffeinerebber": "decaffeinare",
    "decaffeinerebbero": "decaffeinare",
    "decaffeinerei": "decaffeinare",
    "decaffeineremmo": "decaffeinare",
    "decaffeineremo": "decaffeinare",
    "decaffeinereste": "decaffeinare",
    "decaffeineresti": "decaffeinare",
    "decaffeinerete": "decaffeinare",
    "decaffeinerà": "decaffeinare",
    "decaffeinerò": "decaffeinare",
    "decaffeini": "decaffeinare",
    "decaffeiniamo": "decaffeinare",
    "decaffeiniate": "decaffeinare",
    "decaffeinin": "decaffeinare",
    "decaffeinino": "decaffeinare",
    "decaffeino": "decaffeinare",
    "decaffeinò": "decaffeinare",
    "decalcifica": "decalcificare",
    "decalcificai": "decalcificare",
    "decalcificammo": "decalcificare",
    "decalcifican": "decalcificare",
    "decalcificando": "decalcificare",
    "decalcificano": "decalcificare",
    "decalcificante": "decalcificare",
    "decalcificanti": "decalcificare",
    "decalcificar": "decalcificare",
    "decalcificaron": "decalcificare",
    "decalcificarono": "decalcificare",
    "decalcificasse": "decalcificare",
    "decalcificasser": "decalcificare",
    "decalcificassero": "decalcificare",
    "decalcificassi": "decalcificare",
    "decalcificassimo": "decalcificare",
    "decalcificaste": "decalcificare",
    "decalcificasti": "decalcificare",
    "decalcificata": "decalcificare",
    "decalcificate": "decalcificare",
    "decalcificati": "decalcificare",
    "decalcificato": "decalcificare",
    "decalcificava": "decalcificare",
    "decalcificavamo": "decalcificare",
    "decalcificavan": "decalcificare",
    "decalcificavano": "decalcificare",
    "decalcificavate": "decalcificare",
    "decalcificavi": "decalcificare",
    "decalcificavo": "decalcificare",
    "decalcificherai": "decalcificare",
    "decalcificheran": "decalcificare",
    "decalcificheranno": "decalcificare",
    "decalcificherebbe": "decalcificare",
    "decalcificherebber": "decalcificare",
    "decalcificherebbero": "decalcificare",
    "decalcificherei": "decalcificare",
    "decalcificheremmo": "decalcificare",
    "decalcificheremo": "decalcificare",
    "decalcifichereste": "decalcificare",
    "decalcificheresti": "decalcificare",
    "decalcificherete": "decalcificare",
    "decalcificherà": "decalcificare",
    "decalcificherò": "decalcificare",
    "decalcifichi": "decalcificare",
    "decalcifichiamo": "decalcificare",
    "decalcifichiate": "decalcificare",
    "decalcifichin": "decalcificare",
    "decalcifichino": "decalcificare",
    "decalcifico": "decalcificare",
    "decalcificò": "decalcificare",
    "decalcomanie": "decalcomania",
    "decaloghi": "decalogo",
    "decane": "decana",
    "decani": "decano",
    "decanta": "decantare",
    "decantai": "decantare",
    "decantammo": "decantare",
    "decantan": "decantare",
    "decantando": "decantare",
    "decantano": "decantare",
    "decantante": "decantare",
    "decantanti": "decantare",
    "decantar": "decantare",
    "decantaron": "decantare",
    "decantarono": "decantare",
    "decantasse": "decantare",
    "decantasser": "decantare",
    "decantassero": "decantare",
    "decantassi": "decantare",
    "decantassimo": "decantare",
    "decantaste": "decantare",
    "decantasti": "decantare",
    "decantata": "decantare",
    "decantate": "decantare",
    "decantati": "decantare",
    "decantato": "decantare",
    "decantava": "decantare",
    "decantavamo": "decantare",
    "decantavan": "decantare",
    "decantavano": "decantare",
    "decantavate": "decantare",
    "decantavi": "decantare",
    "decantavo": "decantare",
    "decanterai": "decantare",
    "decanteran": "decantare",
    "decanteranno": "decantare",
    "decanterebbe": "decantare",
    "decanterebber": "decantare",
    "decanterebbero": "decantare",
    "decanterei": "decantare",
    "decanteremmo": "decantare",
    "decanteremo": "decantare",
    "decantereste": "decantare",
    "decanteresti": "decantare",
    "decanterete": "decantare",
    "decanterà": "decantare",
    "decanterò": "decantare",
    "decanti": "decantare",
    "decantiamo": "decantare",
    "decantiate": "decantare",
    "decantin": "decantare",
    "decantino": "decantare",
    "decanto": "decantare",
    "decantò": "decantare",
    "decapita": "decapitare",
    "decapitai": "decapitare",
    "decapitammo": "decapitare",
    "decapitan": "decapitare",
    "decapitando": "decapitare",
    "decapitano": "decapitare",
    "decapitante": "decapitare",
    "decapitanti": "decapitare",
    "decapitar": "decapitare",
    "decapitaron": "decapitare",
    "decapitarono": "decapitare",
    "decapitasse": "decapitare",
    "decapitasser": "decapitare",
    "decapitassero": "decapitare",
    "decapitassi": "decapitare",
    "decapitassimo": "decapitare",
    "decapitaste": "decapitare",
    "decapitasti": "decapitare",
    "decapitata": "decapitare",
    "decapitate": "decapitare",
    "decapitati": "decapitare",
    "decapitato": "decapitare",
    "decapitava": "decapitare",
    "decapitavamo": "decapitare",
    "decapitavan": "decapitare",
    "decapitavano": "decapitare",
    "decapitavate": "decapitare",
    "decapitavi": "decapitare",
    "decapitavo": "decapitare",
    "decapitazioni": "decapitazione",
    "decapiterai": "decapitare",
    "decapiteran": "decapitare",
    "decapiteranno": "decapitare",
    "decapiterebbe": "decapitare",
    "decapiterebber": "decapitare",
    "decapiterebbero": "decapitare",
    "decapiterei": "decapitare",
    "decapiteremmo": "decapitare",
    "decapiteremo": "decapitare",
    "decapitereste": "decapitare",
    "decapiteresti": "decapitare",
    "decapiterete": "decapitare",
    "decapiterà": "decapitare",
    "decapiterò": "decapitare",
    "decapiti": "decapitare",
    "decapitiamo": "decapitare",
    "decapitiate": "decapitare",
    "decapitin": "decapitare",
    "decapitino": "decapitare",
    "decapito": "decapitare",
    "decapitò": "decapitare",
    "decapottabili": "decapottabile",
    "decappotta": "decappottare",
    "decappottabili": "decappottabile",
    "decappottai": "decappottare",
    "decappottammo": "decappottare",
    "decappottan": "decappottare",
    "decappottando": "decappottare",
    "decappottano": "decappottare",
    "decappottante": "decappottare",
    "decappottanti": "decappottare",
    "decappottar": "decappottare",
    "decappottaron": "decappottare",
    "decappottarono": "decappottare",
    "decappottasse": "decappottare",
    "decappottasser": "decappottare",
    "decappottassero": "decappottare",
    "decappottassi": "decappottare",
    "decappottassimo": "decappottare",
    "decappottaste": "decappottare",
    "decappottasti": "decappottare",
    "decappottata": "decappottare",
    "decappottate": "decappottare",
    "decappottati": "decappottare",
    "decappottato": "decappottare",
    "decappottava": "decappottare",
    "decappottavamo": "decappottare",
    "decappottavan": "decappottare",
    "decappottavano": "decappottare",
    "decappottavate": "decappottare",
    "decappottavi": "decappottare",
    "decappottavo": "decappottare",
    "decappotterai": "decappottare",
    "decappotteran": "decappottare",
    "decappotteranno": "decappottare",
    "decappotterebbe": "decappottare",
    "decappotterebber": "decappottare",
    "decappotterebbero": "decappottare",
    "decappotterei": "decappottare",
    "decappotteremmo": "decappottare",
    "decappotteremo": "decappottare",
    "decappottereste": "decappottare",
    "decappotteresti": "decappottare",
    "decappotterete": "decappottare",
    "decappotterà": "decappottare",
    "decappotterò": "decappottare",
    "decappotti": "decappottare",
    "decappottiamo": "decappottare",
    "decappottiate": "decappottare",
    "decappottin": "decappottare",
    "decappottino": "decappottare",
    "decappotto": "decappottare",
    "decappottò": "decappottare",
    "deceda": "decedere",
    "decedan": "decedere",
    "decedano": "decedere",
    "decede": "decedere",
    "decedemmo": "decedere",
    "decedendo": "decedere",
    "decedente": "decedere",
    "decedenti": "decedere",
    "deceder": "decedere",
    "decederai": "decedere",
    "decederan": "decedere",
    "decederanno": "decedere",
    "decederebbe": "decedere",
    "decederebber": "decedere",
    "decederebbero": "decedere",
    "decederei": "decedere",
    "decederemmo": "decedere",
    "decederemo": "decedere",
    "decedereste": "decedere",
    "decederesti": "decedere",
    "decederete": "decedere",
    "decederà": "decedere",
    "decederò": "decedere",
    "decedesse": "decedere",
    "decedesser": "decedere",
    "decedessero": "decedere",
    "decedessi": "decedere",
    "decedessimo": "decedere",
    "decedeste": "decedere",
    "decedesti": "decedere",
    "decedete": "decedere",
    "decedette": "decedere",
    "decedetter": "decedere",
    "decedettero": "decedere",
    "decedetti": "decedere",
    "decedeva": "decedere",
    "decedevamo": "decedere",
    "decedevan": "decedere",
    "decedevano": "decedere",
    "decedevate": "decedere",
    "decedevi": "decedere",
    "decedevo": "decedere",
    "decedi": "decedere",
    "decediamo": "decedere",
    "decediate": "decedere",
    "decedo": "decedere",
    "decedon": "decedere",
    "decedono": "decedere",
    "deceduta": "deceduto",
    "decedute": "deceduto",
    "deceduti": "deceduto",
    "deceduto": "decedere",
    "decelera": "decelerare",
    "decelerai": "decelerare",
    "decelerammo": "decelerare",
    "deceleran": "decelerare",
    "decelerando": "decelerare",
    "decelerano": "decelerare",
    "decelerante": "decelerare",
    "deceleranti": "decelerare",
    "decelerar": "decelerare",
    "deceleraron": "decelerare",
    "decelerarono": "decelerare",
    "decelerasse": "decelerare",
    "decelerasser": "decelerare",
    "decelerassero": "decelerare",
    "decelerassi": "decelerare",
    "decelerassimo": "decelerare",
    "deceleraste": "decelerare",
    "decelerasti": "decelerare",
    "decelerata": "decelerare",
    "decelerate": "decelerare",
    "decelerati": "decelerare",
    "decelerato": "decelerare",
    "decelerava": "decelerare",
    "deceleravamo": "decelerare",
    "deceleravan": "decelerare",
    "deceleravano": "decelerare",
    "deceleravate": "decelerare",
    "deceleravi": "decelerare",
    "deceleravo": "decelerare",
    "decelerazioni": "decelerazione",
    "decelererai": "decelerare",
    "decelereran": "decelerare",
    "decelereranno": "decelerare",
    "decelererebbe": "decelerare",
    "decelererebber": "decelerare",
    "decelererebbero": "decelerare",
    "decelererei": "decelerare",
    "decelereremmo": "decelerare",
    "decelereremo": "decelerare",
    "decelerereste": "decelerare",
    "decelereresti": "decelerare",
    "decelererete": "decelerare",
    "decelererà": "decelerare",
    "decelererò": "decelerare",
    "deceleri": "decelerare",
    "deceleriamo": "decelerare",
    "deceleriate": "decelerare",
    "decelerin": "decelerare",
    "decelerino": "decelerare",
    "decelero": "decelerare",
    "decelerò": "decelerare",
    "decennali": "decennale",
    "decenni": "decennio",
    "decenti": "decente",
    "decentra": "decentrare",
    "decentrabili": "decentrabile",
    "decentrai": "decentrare",
    "decentralizza": "decentralizzare",
    "decentralizzai": "decentralizzare",
    "decentralizzammo": "decentralizzare",
    "decentralizzan": "decentralizzare",
    "decentralizzando": "decentralizzare",
    "decentralizzano": "decentralizzare",
    "decentralizzante": "decentralizzare",
    "decentralizzanti": "decentralizzare",
    "decentralizzar": "decentralizzare",
    "decentralizzaron": "decentralizzare",
    "decentralizzarono": "decentralizzare",
    "decentralizzasse": "decentralizzare",
    "decentralizzasser": "decentralizzare",
    "decentralizzassero": "decentralizzare",
    "decentralizzassi": "decentralizzare",
    "decentralizzassimo": "decentralizzare",
    "decentralizzaste": "decentralizzare",
    "decentralizzasti": "decentralizzare",
    "decentralizzata": "decentralizzare",
    "decentralizzate": "decentralizzare",
    "decentralizzati": "decentralizzare",
    "decentralizzato": "decentralizzare",
    "decentralizzava": "decentralizzare",
    "decentralizzavamo": "decentralizzare",
    "decentralizzavan": "decentralizzare",
    "decentralizzavano": "decentralizzare",
    "decentralizzavate": "decentralizzare",
    "decentralizzavi": "decentralizzare",
    "decentralizzavo": "decentralizzare",
    "decentralizzazioni": "decentralizzazione",
    "decentralizzerai": "decentralizzare",
    "decentralizzeran": "decentralizzare",
    "decentralizzeranno": "decentralizzare",
    "decentralizzerebbe": "decentralizzare",
    "decentralizzerebber": "decentralizzare",
    "decentralizzerebbero": "decentralizzare",
    "decentralizzerei": "decentralizzare",
    "decentralizzeremmo": "decentralizzare",
    "decentralizzeremo": "decentralizzare",
    "decentralizzereste": "decentralizzare",
    "decentralizzeresti": "decentralizzare",
    "decentralizzerete": "decentralizzare",
    "decentralizzerà": "decentralizzare",
    "decentralizzerò": "decentralizzare",
    "decentralizzi": "decentralizzare",
    "decentralizziamo": "decentralizzare",
    "decentralizziate": "decentralizzare",
    "decentralizzin": "decentralizzare",
    "decentralizzino": "decentralizzare",
    "decentralizzo": "decentralizzare",
    "decentralizzò": "decentralizzare",
    "decentramenti": "decentramento",
    "decentrammo": "decentrare",
    "decentran": "decentrare",
    "decentrando": "decentrare",
    "decentrano": "decentrare",
    "decentrante": "decentrare",
    "decentranti": "decentrare",
    "decentrar": "decentrare",
    "decentraron": "decentrare",
    "decentrarono": "decentrare",
    "decentrasse": "decentrare",
    "decentrasser": "decentrare",
    "decentrassero": "decentrare",
    "decentrassi": "decentrare",
    "decentrassimo": "decentrare",
    "decentraste": "decentrare",
    "decentrasti": "decentrare",
    "decentrata": "decentrare",
    "decentrate": "decentrare",
    "decentrati": "decentrare",
    "decentrato": "decentrare",
    "decentrava": "decentrare",
    "decentravamo": "decentrare",
    "decentravan": "decentrare",
    "decentravano": "decentrare",
    "decentravate": "decentrare",
    "decentravi": "decentrare",
    "decentravo": "decentrare",
    "decentrerai": "decentrare",
    "decentreran": "decentrare",
    "decentreranno": "decentrare",
    "decentrerebbe": "decentrare",
    "decentrerebber": "decentrare",
    "decentrerebbero": "decentrare",
    "decentrerei": "decentrare",
    "decentreremmo": "decentrare",
    "decentreremo": "decentrare",
    "decentrereste": "decentrare",
    "decentreresti": "decentrare",
    "decentrerete": "decentrare",
    "decentrerà": "decentrare",
    "decentrerò": "decentrare",
    "decentri": "decentrare",
    "decentriamo": "decentrare",
    "decentriate": "decentrare",
    "decentrin": "decentrare",
    "decentrino": "decentrare",
    "decentro": "decentrare",
    "decentrò": "decentrare",
    "decenze": "decenza",
    "decessi": "decesso",
    "decida": "decidere",
    "decidan": "decidere",
    "decidano": "decidere",
    "decide": "decidere",
    "decidemmo": "decidere",
    "decidendo": "decidere",
    "decidente": "decidere",
    "decidenti": "decidere",
    "decider": "decidere",
    "deciderai": "decidere",
    "decideran": "decidere",
    "decideranno": "decidere",
    "deciderebbe": "decidere",
    "deciderebber": "decidere",
    "deciderebbero": "decidere",
    "deciderei": "decidere",
    "decideremmo": "decidere",
    "decideremo": "decidere",
    "decidereste": "decidere",
    "decideresti": "decidere",
    "deciderete": "decidere",
    "deciderà": "decidere",
    "deciderò": "decidere",
    "decidesse": "decidere",
    "decidesser": "decidere",
    "decidessero": "decidere",
    "decidessi": "decidere",
    "decidessimo": "decidere",
    "decideste": "decidere",
    "decidesti": "decidere",
    "decidete": "decidere",
    "decideva": "decidere",
    "decidevamo": "decidere",
    "decidevan": "decidere",
    "decidevano": "decidere",
    "decidevate": "decidere",
    "decidevi": "decidere",
    "decidevo": "decidere",
    "decidi": "decidere",
    "decidiamo": "decidere",
    "decidiate": "decidere",
    "decido": "decidere",
    "decidon": "decidere",
    "decidono": "decidere",
    "decifra": "decifrare",
    "decifrabili": "decifrabile",
    "decifrai": "decifrare",
    "deciframmo": "decifrare",
    "decifran": "decifrare",
    "decifrando": "decifrare",
    "decifrano": "decifrare",
    "decifrante": "decifrare",
    "decifranti": "decifrare",
    "decifrar": "decifrare",
    "decifraron": "decifrare",
    "decifrarono": "decifrare",
    "decifrasse": "decifrare",
    "decifrasser": "decifrare",
    "decifrassero": "decifrare",
    "decifrassi": "decifrare",
    "decifrassimo": "decifrare",
    "decifraste": "decifrare",
    "decifrasti": "decifrare",
    "decifrata": "decifrare",
    "decifrate": "decifrare",
    "decifrati": "decifrare",
    "decifrato": "decifrare",
    "decifrava": "decifrare",
    "decifravamo": "decifrare",
    "decifravan": "decifrare",
    "decifravano": "decifrare",
    "decifravate": "decifrare",
    "decifravi": "decifrare",
    "decifravo": "decifrare",
    "decifrazioni": "decifrazione",
    "decifrerai": "decifrare",
    "decifreran": "decifrare",
    "decifreranno": "decifrare",
    "decifrerebbe": "decifrare",
    "decifrerebber": "decifrare",
    "decifrerebbero": "decifrare",
    "decifrerei": "decifrare",
    "decifreremmo": "decifrare",
    "decifreremo": "decifrare",
    "decifrereste": "decifrare",
    "decifreresti": "decifrare",
    "decifrerete": "decifrare",
    "decifrerà": "decifrare",
    "decifrerò": "decifrare",
    "decifri": "decifrare",
    "decifriamo": "decifrare",
    "decifriate": "decifrare",
    "decifrin": "decifrare",
    "decifrino": "decifrare",
    "decifro": "decifrare",
    "decifrò": "decifrare",
    "decima": "decimo",
    "decimai": "decimare",
    "decimali": "decimale",
    "decimammo": "decimare",
    "deciman": "decimare",
    "decimando": "decimare",
    "decimano": "decimare",
    "decimante": "decimare",
    "decimanti": "decimare",
    "decimar": "decimare",
    "decimaron": "decimare",
    "decimarono": "decimare",
    "decimasse": "decimare",
    "decimasser": "decimare",
    "decimassero": "decimare",
    "decimassi": "decimare",
    "decimassimo": "decimare",
    "decimaste": "decimare",
    "decimasti": "decimare",
    "decimata": "decimare",
    "decimate": "decimare",
    "decimati": "decimare",
    "decimato": "decimare",
    "decimava": "decimare",
    "decimavamo": "decimare",
    "decimavan": "decimare",
    "decimavano": "decimare",
    "decimavate": "decimare",
    "decimavi": "decimare",
    "decimavo": "decimare",
    "decimazioni": "decimazione",
    "decime": "decimo",
    "decimerai": "decimare",
    "decimeran": "decimare",
    "decimeranno": "decimare",
    "decimerebbe": "decimare",
    "decimerebber": "decimare",
    "decimerebbero": "decimare",
    "decimerei": "decimare",
    "decimeremmo": "decimare",
    "decimeremo": "decimare",
    "decimereste": "decimare",
    "decimeresti": "decimare",
    "decimerete": "decimare",
    "decimerà": "decimare",
    "decimerò": "decimare",
    "decimi": "decimo",
    "decimiamo": "decimare",
    "decimiate": "decimare",
    "decimin": "decimare",
    "decimino": "decimare",
    "decimo": "decimare",
    "decimò": "decimare",
    "decine": "decina",
    "decisa": "deciso",
    "decise": "deciso",
    "deciser": "decidere",
    "decisero": "decidere",
    "decisi": "deciso",
    "decisionali": "decisionale",
    "decisioni": "decisione",
    "decisionismi": "decisionismo",
    "decisionisti": "decisionista",
    "decisiva": "decisivo",
    "decisive": "decisivo",
    "decisivi": "decisivo",
    "deciso": "decidere",
    "decisoni": "decisone",
    "decisori": "decisore",
    "declama": "declamare",
    "declamai": "declamare",
    "declamammo": "declamare",
    "declaman": "declamare",
    "declamando": "declamare",
    "declamano": "declamare",
    "declamante": "declamare",
    "declamanti": "declamare",
    "declamar": "declamare",
    "declamaron": "declamare",
    "declamarono": "declamare",
    "declamasse": "declamare",
    "declamasser": "declamare",
    "declamassero": "declamare",
    "declamassi": "declamare",
    "declamassimo": "declamare",
    "declamaste": "declamare",
    "declamasti": "declamare",
    "declamata": "declamare",
    "declamate": "declamare",
    "declamati": "declamare",
    "declamato": "declamare",
    "declamatori": "declamatorio",
    "declamatoria": "declamatorio",
    "declamatorie": "declamatorio",
    "declamava": "declamare",
    "declamavamo": "declamare",
    "declamavan": "declamare",
    "declamavano": "declamare",
    "declamavate": "declamare",
    "declamavi": "declamare",
    "declamavo": "declamare",
    "declamazioni": "declamazione",
    "declamerai": "declamare",
    "declameran": "declamare",
    "declameranno": "declamare",
    "declamerebbe": "declamare",
    "declamerebber": "declamare",
    "declamerebbero": "declamare",
    "declamerei": "declamare",
    "declameremmo": "declamare",
    "declameremo": "declamare",
    "declamereste": "declamare",
    "declameresti": "declamare",
    "declamerete": "declamare",
    "declamerà": "declamare",
    "declamerò": "declamare",
    "declami": "declamare",
    "declamiamo": "declamare",
    "declamiate": "declamare",
    "declamin": "declamare",
    "declamino": "declamare",
    "declamo": "declamare",
    "declamò": "declamare",
    "declassa": "declassare",
    "declassai": "declassare",
    "declassamenti": "declassamento",
    "declassammo": "declassare",
    "declassan": "declassare",
    "declassando": "declassare",
    "declassano": "declassare",
    "declassante": "declassare",
    "declassanti": "declassare",
    "declassar": "declassare",
    "declassaron": "declassare",
    "declassarono": "declassare",
    "declassasse": "declassare",
    "declassasser": "declassare",
    "declassassero": "declassare",
    "declassassi": "declassare",
    "declassassimo": "declassare",
    "declassaste": "declassare",
    "declassasti": "declassare",
    "declassata": "declassare",
    "declassate": "declassare",
    "declassati": "declassare",
    "declassato": "declassare",
    "declassava": "declassare",
    "declassavamo": "declassare",
    "declassavan": "declassare",
    "declassavano": "declassare",
    "declassavate": "declassare",
    "declassavi": "declassare",
    "declassavo": "declassare",
    "declasserai": "declassare",
    "declasseran": "declassare",
    "declasseranno": "declassare",
    "declasserebbe": "declassare",
    "declasserebber": "declassare",
    "declasserebbero": "declassare",
    "declasserei": "declassare",
    "declasseremmo": "declassare",
    "declasseremo": "declassare",
    "declassereste": "declassare",
    "declasseresti": "declassare",
    "declasserete": "declassare",
    "declasserà": "declassare",
    "declasserò": "declassare",
    "declassi": "declassare",
    "declassiamo": "declassare",
    "declassiate": "declassare",
    "declassifica": "declassificare",
    "declassificai": "declassificare",
    "declassificammo": "declassificare",
    "declassifican": "declassificare",
    "declassificando": "declassificare",
    "declassificano": "declassificare",
    "declassificante": "declassificare",
    "declassificanti": "declassificare",
    "declassificar": "declassificare",
    "declassificaron": "declassificare",
    "declassificarono": "declassificare",
    "declassificasse": "declassificare",
    "declassificasser": "declassificare",
    "declassificassero": "declassificare",
    "declassificassi": "declassificare",
    "declassificassimo": "declassificare",
    "declassificaste": "declassificare",
    "declassificasti": "declassificare",
    "declassificata": "declassificare",
    "declassificate": "declassificare",
    "declassificati": "declassificare",
    "declassificato": "declassificare",
    "declassificava": "declassificare",
    "declassificavamo": "declassificare",
    "declassificavan": "declassificare",
    "declassificavano": "declassificare",
    "declassificavate": "declassificare",
    "declassificavi": "declassificare",
    "declassificavo": "declassificare",
    "declassificherai": "declassificare",
    "declassificheran": "declassificare",
    "declassificheranno": "declassificare",
    "declassificherebbe": "declassificare",
    "declassificherebber": "declassificare",
    "declassificherebbero": "declassificare",
    "declassificherei": "declassificare",
    "declassificheremmo": "declassificare",
    "declassificheremo": "declassificare",
    "declassifichereste": "declassificare",
    "declassificheresti": "declassificare",
    "declassificherete": "declassificare",
    "declassificherà": "declassificare",
    "declassificherò": "declassificare",
    "declassifichi": "declassificare",
    "declassifichiamo": "declassificare",
    "declassifichiate": "declassificare",
    "declassifichin": "declassificare",
    "declassifichino": "declassificare",
    "declassifico": "declassificare",
    "declassificò": "declassificare",
    "declassin": "declassare",
    "declassino": "declassare",
    "declasso": "declassare",
    "declassò": "declassare",
    "declina": "declinare",
    "declinai": "declinare",
    "declinammo": "declinare",
    "declinan": "declinare",
    "declinando": "declinare",
    "declinano": "declinare",
    "declinante": "declinare",
    "declinanti": "declinare",
    "declinar": "declinare",
    "declinaron": "declinare",
    "declinarono": "declinare",
    "declinasse": "declinare",
    "declinasser": "declinare",
    "declinassero": "declinare",
    "declinassi": "declinare",
    "declinassimo": "declinare",
    "declinaste": "declinare",
    "declinasti": "declinare",
    "declinata": "declinare",
    "declinate": "declinare",
    "declinati": "declinare",
    "declinato": "declinare",
    "declinava": "declinare",
    "declinavamo": "declinare",
    "declinavan": "declinare",
    "declinavano": "declinare",
    "declinavate": "declinare",
    "declinavi": "declinare",
    "declinavo": "declinare",
    "declinazioni": "declinazione",
    "declinerai": "declinare",
    "declineran": "declinare",
    "declineranno": "declinare",
    "declinerebbe": "declinare",
    "declinerebber": "declinare",
    "declinerebbero": "declinare",
    "declinerei": "declinare",
    "declineremmo": "declinare",
    "declineremo": "declinare",
    "declinereste": "declinare",
    "declineresti": "declinare",
    "declinerete": "declinare",
    "declinerà": "declinare",
    "declinerò": "declinare",
    "declini": "declino",
    "decliniamo": "declinare",
    "decliniate": "declinare",
    "declinin": "declinare",
    "declinino": "declinare",
    "declino": "declinare",
    "declinò": "declinare",
    "declivi": "declivio",
    "declivia": "declivio",
    "declivie": "declivio",
    "decodifica": "decodificare",
    "decodificai": "decodificare",
    "decodificammo": "decodificare",
    "decodifican": "decodificare",
    "decodificando": "decodificare",
    "decodificano": "decodificare",
    "decodificante": "decodificare",
    "decodificanti": "decodificare",
    "decodificar": "decodificare",
    "decodificaron": "decodificare",
    "decodificarono": "decodificare",
    "decodificasse": "decodificare",
    "decodificasser": "decodificare",
    "decodificassero": "decodificare",
    "decodificassi": "decodificare",
    "decodificassimo": "decodificare",
    "decodificaste": "decodificare",
    "decodificasti": "decodificare",
    "decodificata": "decodificare",
    "decodificate": "decodificare",
    "decodificati": "decodificare",
    "decodificato": "decodificare",
    "decodificatori": "decodificatore",
    "decodificava": "decodificare",
    "decodificavamo": "decodificare",
    "decodificavan": "decodificare",
    "decodificavano": "decodificare",
    "decodificavate": "decodificare",
    "decodificavi": "decodificare",
    "decodificavo": "decodificare",
    "decodificazioni": "decodificazione",
    "decodificherai": "decodificare",
    "decodificheran": "decodificare",
    "decodificheranno": "decodificare",
    "decodificherebbe": "decodificare",
    "decodificherebber": "decodificare",
    "decodificherebbero": "decodificare",
    "decodificherei": "decodificare",
    "decodificheremmo": "decodificare",
    "decodificheremo": "decodificare",
    "decodifichereste": "decodificare",
    "decodificheresti": "decodificare",
    "decodificherete": "decodificare",
    "decodificherà": "decodificare",
    "decodificherò": "decodificare",
    "decodifichi": "decodificare",
    "decodifichiamo": "decodificare",
    "decodifichiate": "decodificare",
    "decodifichin": "decodificare",
    "decodifichino": "decodificare",
    "decodifico": "decodificare",
    "decodificò": "decodificare",
    "decolla": "decollare",
    "decollai": "decollare",
    "decollammo": "decollare",
    "decollan": "decollare",
    "decollando": "decollare",
    "decollano": "decollare",
    "decollante": "decollare",
    "decollanti": "decollare",
    "decollar": "decollare",
    "decollaron": "decollare",
    "decollarono": "decollare",
    "decollasse": "decollare",
    "decollasser": "decollare",
    "decollassero": "decollare",
    "decollassi": "decollare",
    "decollassimo": "decollare",
    "decollaste": "decollare",
    "decollasti": "decollare",
    "decollata": "decollare",
    "decollate": "decollare",
    "decollati": "decollare",
    "decollato": "decollare",
    "decollava": "decollare",
    "decollavamo": "decollare",
    "decollavan": "decollare",
    "decollavano": "decollare",
    "decollavate": "decollare",
    "decollavi": "decollare",
    "decollavo": "decollare",
    "decollerai": "decollare",
    "decolleran": "decollare",
    "decolleranno": "decollare",
    "decollerebbe": "decollare",
    "decollerebber": "decollare",
    "decollerebbero": "decollare",
    "decollerei": "decollare",
    "decolleremmo": "decollare",
    "decolleremo": "decollare",
    "decollereste": "decollare",
    "decolleresti": "decollare",
    "decollerete": "decollare",
    "decollerà": "decollare",
    "decollerò": "decollare",
    "decolli": "decollo",
    "decolliamo": "decollare",
    "decolliate": "decollare",
    "decollin": "decollare",
    "decollino": "decollare",
    "decollo": "decollare",
    "decollò": "decollare",
    "decolonizza": "decolonizzare",
    "decolonizzai": "decolonizzare",
    "decolonizzammo": "decolonizzare",
    "decolonizzan": "decolonizzare",
    "decolonizzando": "decolonizzare",
    "decolonizzano": "decolonizzare",
    "decolonizzante": "decolonizzare",
    "decolonizzanti": "decolonizzare",
    "decolonizzar": "decolonizzare",
    "decolonizzaron": "decolonizzare",
    "decolonizzarono": "decolonizzare",
    "decolonizzasse": "decolonizzare",
    "decolonizzasser": "decolonizzare",
    "decolonizzassero": "decolonizzare",
    "decolonizzassi": "decolonizzare",
    "decolonizzassimo": "decolonizzare",
    "decolonizzaste": "decolonizzare",
    "decolonizzasti": "decolonizzare",
    "decolonizzata": "decolonizzare",
    "decolonizzate": "decolonizzare",
    "decolonizzati": "decolonizzare",
    "decolonizzato": "decolonizzare",
    "decolonizzava": "decolonizzare",
    "decolonizzavamo": "decolonizzare",
    "decolonizzavan": "decolonizzare",
    "decolonizzavano": "decolonizzare",
    "decolonizzavate": "decolonizzare",
    "decolonizzavi": "decolonizzare",
    "decolonizzavo": "decolonizzare",
    "decolonizzazioni": "decolonizzazione",
    "decolonizzerai": "decolonizzare",
    "decolonizzeran": "decolonizzare",
    "decolonizzeranno": "decolonizzare",
    "decolonizzerebbe": "decolonizzare",
    "decolonizzerebber": "decolonizzare",
    "decolonizzerebbero": "decolonizzare",
    "decolonizzerei": "decolonizzare",
    "decolonizzeremmo": "decolonizzare",
    "decolonizzeremo": "decolonizzare",
    "decolonizzereste": "decolonizzare",
    "decolonizzeresti": "decolonizzare",
    "decolonizzerete": "decolonizzare",
    "decolonizzerà": "decolonizzare",
    "decolonizzerò": "decolonizzare",
    "decolonizzi": "decolonizzare",
    "decolonizziamo": "decolonizzare",
    "decolonizziate": "decolonizzare",
    "decolonizzin": "decolonizzare",
    "decolonizzino": "decolonizzare",
    "decolonizzo": "decolonizzare",
    "decolonizzò": "decolonizzare",
    "decolora": "decolorare",
    "decolorai": "decolorare",
    "decolorammo": "decolorare",
    "decoloran": "decolorare",
    "decolorando": "decolorare",
    "decolorano": "decolorare",
    "decolorante": "decolorare",
    "decoloranti": "decolorare",
    "decolorar": "decolorare",
    "decoloraron": "decolorare",
    "decolorarono": "decolorare",
    "decolorasse": "decolorare",
    "decolorasser": "decolorare",
    "decolorassero": "decolorare",
    "decolorassi": "decolorare",
    "decolorassimo": "decolorare",
    "decoloraste": "decolorare",
    "decolorasti": "decolorare",
    "decolorata": "decolorare",
    "decolorate": "decolorare",
    "decolorati": "decolorare",
    "decolorato": "decolorare",
    "decolorava": "decolorare",
    "decoloravamo": "decolorare",
    "decoloravan": "decolorare",
    "decoloravano": "decolorare",
    "decoloravate": "decolorare",
    "decoloravi": "decolorare",
    "decoloravo": "decolorare",
    "decolorerai": "decolorare",
    "decoloreran": "decolorare",
    "decoloreranno": "decolorare",
    "decolorerebbe": "decolorare",
    "decolorerebber": "decolorare",
    "decolorerebbero": "decolorare",
    "decolorerei": "decolorare",
    "decoloreremmo": "decolorare",
    "decoloreremo": "decolorare",
    "decolorereste": "decolorare",
    "decoloreresti": "decolorare",
    "decolorerete": "decolorare",
    "decolorerà": "decolorare",
    "decolorerò": "decolorare",
    "decolori": "decolorare",
    "decoloriamo": "decolorare",
    "decoloriate": "decolorare",
    "decolorin": "decolorare",
    "decolorino": "decolorare",
    "decoloro": "decolorare",
    "decolorò": "decolorare",
    "decompone": "decomporre",
    "decomponemmo": "decomporre",
    "decomponendo": "decomporre",
    "decomponente": "decomporre",
    "decomponenti": "decomporre",
    "decomponesse": "decomporre",
    "decomponesser": "decomporre",
    "decomponessero": "decomporre",
    "decomponessi": "decomporre",
    "decomponessimo": "decomporre",
    "decomponeste": "decomporre",
    "decomponesti": "decomporre",
    "decomponete": "decomporre",
    "decomponeva": "decomporre",
    "decomponevamo": "decomporre",
    "decomponevan": "decomporre",
    "decomponevano": "decomporre",
    "decomponevate": "decomporre",
    "decomponevi": "decomporre",
    "decomponevo": "decomporre",
    "decomponga": "decomporre",
    "decompongan": "decomporre",
    "decompongano": "decomporre",
    "decompongo": "decomporre",
    "decompongon": "decomporre",
    "decompongono": "decomporre",
    "decomponi": "decomporre",
    "decomponiamo": "decomporre",
    "decomponiate": "decomporre",
    "decomporr": "decomporre",
    "decomporrai": "decomporre",
    "decomporran": "decomporre",
    "decomporranno": "decomporre",
    "decomporrebbe": "decomporre",
    "decomporrebber": "decomporre",
    "decomporrebbero": "decomporre",
    "decomporrei": "decomporre",
    "decomporremmo": "decomporre",
    "decomporremo": "decomporre",
    "decomporreste": "decomporre",
    "decomporresti": "decomporre",
    "decomporrete": "decomporre",
    "decomporrà": "decomporre",
    "decomporrò": "decomporre",
    "decompose": "decomporre",
    "decomposer": "decomporre",
    "decomposero": "decomporre",
    "decomposi": "decomporre",
    "decomposizioni": "decomposizione",
    "decomposta": "decomporre",
    "decomposte": "decomporre",
    "decomposti": "decomporre",
    "decomposto": "decomporre",
    "decomprima": "decomprimere",
    "decompriman": "decomprimere",
    "decomprimano": "decomprimere",
    "decomprime": "decomprimere",
    "decomprimei": "decomprimere",
    "decomprimemmo": "decomprimere",
    "decomprimendo": "decomprimere",
    "decomprimente": "decomprimere",
    "decomprimenti": "decomprimere",
    "decomprimer": "decomprimere",
    "decomprimerai": "decomprimere",
    "decomprimeran": "decomprimere",
    "decomprimeranno": "decomprimere",
    "decomprimerebbe": "decomprimere",
    "decomprimerebber": "decomprimere",
    "decomprimerebbero": "decomprimere",
    "decomprimerei": "decomprimere",
    "decomprimeremmo": "decomprimere",
    "decomprimeremo": "decomprimere",
    "decomprimereste": "decomprimere",
    "decomprimeresti": "decomprimere",
    "decomprimerete": "decomprimere",
    "decomprimeron": "decomprimere",
    "decomprimerono": "decomprimere",
    "decomprimerà": "decomprimere",
    "decomprimerò": "decomprimere",
    "decomprimesse": "decomprimere",
    "decomprimesser": "decomprimere",
    "decomprimessero": "decomprimere",
    "decomprimessi": "decomprimere",
    "decomprimessimo": "decomprimere",
    "decomprimeste": "decomprimere",
    "decomprimesti": "decomprimere",
    "decomprimete": "decomprimere",
    "decomprimeva": "decomprimere",
    "decomprimevamo": "decomprimere",
    "decomprimevan": "decomprimere",
    "decomprimevano": "decomprimere",
    "decomprimevate": "decomprimere",
    "decomprimevi": "decomprimere",
    "decomprimevo": "decomprimere",
    "decomprimi": "decomprimere",
    "decomprimiamo": "decomprimere",
    "decomprimiate": "decomprimere",
    "decomprimo": "decomprimere",
    "decomprimon": "decomprimere",
    "decomprimono": "decomprimere",
    "decomprimuta": "decomprimere",
    "decomprimute": "decomprimere",
    "decomprimuti": "decomprimere",
    "decomprimuto": "decomprimere",
    "decomprimè": "decomprimere",
    "deconcentra": "deconcentrare",
    "deconcentrai": "deconcentrare",
    "deconcentrammo": "deconcentrare",
    "deconcentran": "deconcentrare",
    "deconcentrando": "deconcentrare",
    "deconcentrano": "deconcentrare",
    "deconcentrante": "deconcentrare",
    "deconcentranti": "deconcentrare",
    "deconcentrar": "deconcentrare",
    "deconcentraron": "deconcentrare",
    "deconcentrarono": "deconcentrare",
    "deconcentrasse": "deconcentrare",
    "deconcentrasser": "deconcentrare",
    "deconcentrassero": "deconcentrare",
    "deconcentrassi": "deconcentrare",
    "deconcentrassimo": "deconcentrare",
    "deconcentraste": "deconcentrare",
    "deconcentrasti": "deconcentrare",
    "deconcentrata": "deconcentrare",
    "deconcentrate": "deconcentrare",
    "deconcentrati": "deconcentrare",
    "deconcentrato": "deconcentrare",
    "deconcentrava": "deconcentrare",
    "deconcentravamo": "deconcentrare",
    "deconcentravan": "deconcentrare",
    "deconcentravano": "deconcentrare",
    "deconcentravate": "deconcentrare",
    "deconcentravi": "deconcentrare",
    "deconcentravo": "deconcentrare",
    "deconcentrerai": "deconcentrare",
    "deconcentreran": "deconcentrare",
    "deconcentreranno": "deconcentrare",
    "deconcentrerebbe": "deconcentrare",
    "deconcentrerebber": "deconcentrare",
    "deconcentrerebbero": "deconcentrare",
    "deconcentrerei": "deconcentrare",
    "deconcentreremmo": "deconcentrare",
    "deconcentreremo": "deconcentrare",
    "deconcentrereste": "deconcentrare",
    "deconcentreresti": "deconcentrare",
    "deconcentrerete": "deconcentrare",
    "deconcentrerà": "deconcentrare",
    "deconcentrerò": "deconcentrare",
    "deconcentri": "deconcentrare",
    "deconcentriamo": "deconcentrare",
    "deconcentriate": "deconcentrare",
    "deconcentrin": "deconcentrare",
    "deconcentrino": "deconcentrare",
    "deconcentro": "deconcentrare",
    "deconcentrò": "deconcentrare",
    "decongela": "decongelare",
    "decongelai": "decongelare",
    "decongelammo": "decongelare",
    "decongelan": "decongelare",
    "decongelando": "decongelare",
    "decongelano": "decongelare",
    "decongelante": "decongelare",
    "decongelanti": "decongelare",
    "decongelar": "decongelare",
    "decongelaron": "decongelare",
    "decongelarono": "decongelare",
    "decongelasse": "decongelare",
    "decongelasser": "decongelare",
    "decongelassero": "decongelare",
    "decongelassi": "decongelare",
    "decongelassimo": "decongelare",
    "decongelaste": "decongelare",
    "decongelasti": "decongelare",
    "decongelata": "decongelare",
    "decongelate": "decongelare",
    "decongelati": "decongelare",
    "decongelato": "decongelare",
    "decongelava": "decongelare",
    "decongelavamo": "decongelare",
    "decongelavan": "decongelare",
    "decongelavano": "decongelare",
    "decongelavate": "decongelare",
    "decongelavi": "decongelare",
    "decongelavo": "decongelare",
    "decongelerai": "decongelare",
    "decongeleran": "decongelare",
    "decongeleranno": "decongelare",
    "decongelerebbe": "decongelare",
    "decongelerebber": "decongelare",
    "decongelerebbero": "decongelare",
    "decongelerei": "decongelare",
    "decongeleremmo": "decongelare",
    "decongeleremo": "decongelare",
    "decongelereste": "decongelare",
    "decongeleresti": "decongelare",
    "decongelerete": "decongelare",
    "decongelerà": "decongelare",
    "decongelerò": "decongelare",
    "decongeli": "decongelare",
    "decongeliamo": "decongelare",
    "decongeliate": "decongelare",
    "decongelin": "decongelare",
    "decongelino": "decongelare",
    "decongelo": "decongelare",
    "decongelò": "decongelare",
    "decongestiona": "decongestionare",
    "decongestionai": "decongestionare",
    "decongestionammo": "decongestionare",
    "decongestionan": "decongestionare",
    "decongestionando": "decongestionare",
    "decongestionano": "decongestionare",
    "decongestionante": "decongestionare",
    "decongestionanti": "decongestionare",
    "decongestionar": "decongestionare",
    "decongestionaron": "decongestionare",
    "decongestionarono": "decongestionare",
    "decongestionasse": "decongestionare",
    "decongestionasser": "decongestionare",
    "decongestionassero": "decongestionare",
    "decongestionassi": "decongestionare",
    "decongestionassimo": "decongestionare",
    "decongestionaste": "decongestionare",
    "decongestionasti": "decongestionare",
    "decongestionata": "decongestionare",
    "decongestionate": "decongestionare",
    "decongestionati": "decongestionare",
    "decongestionato": "decongestionare",
    "decongestionava": "decongestionare",
    "decongestionavamo": "decongestionare",
    "decongestionavan": "decongestionare",
    "decongestionavano": "decongestionare",
    "decongestionavate": "decongestionare",
    "decongestionavi": "decongestionare",
    "decongestionavo": "decongestionare",
    "decongestionerai": "decongestionare",
    "decongestioneran": "decongestionare",
    "decongestioneranno": "decongestionare",
    "decongestionerebbe": "decongestionare",
    "decongestionerebber": "decongestionare",
    "decongestionerebbero": "decongestionare",
    "decongestionerei": "decongestionare",
    "decongestioneremmo": "decongestionare",
    "decongestioneremo": "decongestionare",
    "decongestionereste": "decongestionare",
    "decongestioneresti": "decongestionare",
    "decongestionerete": "decongestionare",
    "decongestionerà": "decongestionare",
    "decongestionerò": "decongestionare",
    "decongestioni": "decongestionare",
    "decongestioniamo": "decongestionare",
    "decongestioniate": "decongestionare",
    "decongestionin": "decongestionare",
    "decongestionino": "decongestionare",
    "decongestiono": "decongestionare",
    "decongestionò": "decongestionare",
    "decontamina": "decontaminare",
    "decontaminai": "decontaminare",
    "decontaminammo": "decontaminare",
    "decontaminan": "decontaminare",
    "decontaminando": "decontaminare",
    "decontaminano": "decontaminare",
    "decontaminante": "decontaminare",
    "decontaminanti": "decontaminare",
    "decontaminar": "decontaminare",
    "decontaminaron": "decontaminare",
    "decontaminarono": "decontaminare",
    "decontaminasse": "decontaminare",
    "decontaminasser": "decontaminare",
    "decontaminassero": "decontaminare",
    "decontaminassi": "decontaminare",
    "decontaminassimo": "decontaminare",
    "decontaminaste": "decontaminare",
    "decontaminasti": "decontaminare",
    "decontaminata": "decontaminare",
    "decontaminate": "decontaminare",
    "decontaminati": "decontaminare",
    "decontaminato": "decontaminare",
    "decontaminava": "decontaminare",
    "decontaminavamo": "decontaminare",
    "decontaminavan": "decontaminare",
    "decontaminavano": "decontaminare",
    "decontaminavate": "decontaminare",
    "decontaminavi": "decontaminare",
    "decontaminavo": "decontaminare",
    "decontaminerai": "decontaminare",
    "decontamineran": "decontaminare",
    "decontamineranno": "decontaminare",
    "decontaminerebbe": "decontaminare",
    "decontaminerebber": "decontaminare",
    "decontaminerebbero": "decontaminare",
    "decontaminerei": "decontaminare",
    "decontamineremmo": "decontaminare",
    "decontamineremo": "decontaminare",
    "decontaminereste": "decontaminare",
    "decontamineresti": "decontaminare",
    "decontaminerete": "decontaminare",
    "decontaminerà": "decontaminare",
    "decontaminerò": "decontaminare",
    "decontamini": "decontaminare",
    "decontaminiamo": "decontaminare",
    "decontaminiate": "decontaminare",
    "decontaminin": "decontaminare",
    "decontaminino": "decontaminare",
    "decontamino": "decontaminare",
    "decontaminò": "decontaminare",
    "decontestualizza": "decontestualizzare",
    "decontestualizzai": "decontestualizzare",
    "decontestualizzammo": "decontestualizzare",
    "decontestualizzan": "decontestualizzare",
    "decontestualizzando": "decontestualizzare",
    "decontestualizzano": "decontestualizzare",
    "decontestualizzante": "decontestualizzare",
    "decontestualizzanti": "decontestualizzare",
    "decontestualizzar": "decontestualizzare",
    "decontestualizzaron": "decontestualizzare",
    "decontestualizzarono": "decontestualizzare",
    "decontestualizzasse": "decontestualizzare",
    "decontestualizzasser": "decontestualizzare",
    "decontestualizzassero": "decontestualizzare",
    "decontestualizzassi": "decontestualizzare",
    "decontestualizzassimo": "decontestualizzare",
    "decontestualizzaste": "decontestualizzare",
    "decontestualizzasti": "decontestualizzare",
    "decontestualizzata": "decontestualizzare",
    "decontestualizzate": "decontestualizzare",
    "decontestualizzati": "decontestualizzare",
    "decontestualizzato": "decontestualizzare",
    "decontestualizzava": "decontestualizzare",
    "decontestualizzavamo": "decontestualizzare",
    "decontestualizzavan": "decontestualizzare",
    "decontestualizzavano": "decontestualizzare",
    "decontestualizzavate": "decontestualizzare",
    "decontestualizzavi": "decontestualizzare",
    "decontestualizzavo": "decontestualizzare",
    "decontestualizzerai": "decontestualizzare",
    "decontestualizzeran": "decontestualizzare",
    "decontestualizzeranno": "decontestualizzare",
    "decontestualizzerebbe": "decontestualizzare",
    "decontestualizzerebber": "decontestualizzare",
    "decontestualizzerebbero": "decontestualizzare",
    "decontestualizzerei": "decontestualizzare",
    "decontestualizzeremmo": "decontestualizzare",
    "decontestualizzeremo": "decontestualizzare",
    "decontestualizzereste": "decontestualizzare",
    "decontestualizzeresti": "decontestualizzare",
    "decontestualizzerete": "decontestualizzare",
    "decontestualizzerà": "decontestualizzare",
    "decontestualizzerò": "decontestualizzare",
    "decontestualizzi": "decontestualizzare",
    "decontestualizziamo": "decontestualizzare",
    "decontestualizziate": "decontestualizzare",
    "decontestualizzin": "decontestualizzare",
    "decontestualizzino": "decontestualizzare",
    "decontestualizzo": "decontestualizzare",
    "decontestualizzò": "decontestualizzare",
    "decontribuzioni": "decontribuzione",
    "decora": "decorare",
    "decorai": "decorare",
    "decorammo": "decorare",
    "decoran": "decorare",
    "decorando": "decorare",
    "decorano": "decorare",
    "decorante": "decorare",
    "decoranti": "decorare",
    "decorar": "decorare",
    "decoraron": "decorare",
    "decorarono": "decorare",
    "decorasse": "decorare",
    "decorasser": "decorare",
    "decorassero": "decorare",
    "decorassi": "decorare",
    "decorassimo": "decorare",
    "decoraste": "decorare",
    "decorasti": "decorare",
    "decorata": "decorato",
    "decorate": "decorato",
    "decorati": "decorato",
    "decorativa": "decorativo",
    "decorative": "decorativo",
    "decorativi": "decorativo",
    "decorato": "decorare",
    "decoratori": "decoratore",
    "decorava": "decorare",
    "decoravamo": "decorare",
    "decoravan": "decorare",
    "decoravano": "decorare",
    "decoravate": "decorare",
    "decoravi": "decorare",
    "decoravo": "decorare",
    "decorazioni": "decorazione",
    "decorerai": "decorare",
    "decoreran": "decorare",
    "decoreranno": "decorare",
    "decorerebbe": "decorare",
    "decorerebber": "decorare",
    "decorerebbero": "decorare",
    "decorerei": "decorare",
    "decoreremmo": "decorare",
    "decoreremo": "decorare",
    "decorereste": "decorare",
    "decoreresti": "decorare",
    "decorerete": "decorare",
    "decorerà": "decorare",
    "decorerò": "decorare",
    "decori": "decoro",
    "decoriamo": "decorare",
    "decoriate": "decorare",
    "decorin": "decorare",
    "decorino": "decorare",
    "decoro": "decorare",
    "decorosa": "decoroso",
    "decorose": "decoroso",
    "decorosi": "decoroso",
    "decorra": "decorrere",
    "decorran": "decorrere",
    "decorrano": "decorrere",
    "decorre": "decorrere",
    "decorremmo": "decorrere",
    "decorrendo": "decorrere",
    "decorrente": "decorrere",
    "decorrenti": "decorrere",
    "decorrenze": "decorrenza",
    "decorrer": "decorrere",
    "decorrerai": "decorrere",
    "decorreran": "decorrere",
    "decorreranno": "decorrere",
    "decorrerebbe": "decorrere",
    "decorrerebber": "decorrere",
    "decorrerebbero": "decorrere",
    "decorrerei": "decorrere",
    "decorreremmo": "decorrere",
    "decorreremo": "decorrere",
    "decorrereste": "decorrere",
    "decorreresti": "decorrere",
    "decorrerete": "decorrere",
    "decorrerà": "decorrere",
    "decorrerò": "decorrere",
    "decorresse": "decorrere",
    "decorresser": "decorrere",
    "decorressero": "decorrere",
    "decorressi": "decorrere",
    "decorressimo": "decorrere",
    "decorreste": "decorrere",
    "decorresti": "decorrere",
    "decorrete": "decorrere",
    "decorreva": "decorrere",
    "decorrevamo": "decorrere",
    "decorrevan": "decorrere",
    "decorrevano": "decorrere",
    "decorrevate": "decorrere",
    "decorrevi": "decorrere",
    "decorrevo": "decorrere",
    "decorri": "decorrere",
    "decorriamo": "decorrere",
    "decorriate": "decorrere",
    "decorro": "decorrere",
    "decorron": "decorrere",
    "decorrono": "decorrere",
    "decorsa": "decorrere",
    "decorse": "decorrere",
    "decorser": "decorrere",
    "decorsero": "decorrere",
    "decorsi": "decorso",
    "decorso": "decorrere",
    "decortica": "decorticare",
    "decorticai": "decorticare",
    "decorticammo": "decorticare",
    "decortican": "decorticare",
    "decorticando": "decorticare",
    "decorticano": "decorticare",
    "decorticante": "decorticare",
    "decorticanti": "decorticare",
    "decorticar": "decorticare",
    "decorticaron": "decorticare",
    "decorticarono": "decorticare",
    "decorticasse": "decorticare",
    "decorticasser": "decorticare",
    "decorticassero": "decorticare",
    "decorticassi": "decorticare",
    "decorticassimo": "decorticare",
    "decorticaste": "decorticare",
    "decorticasti": "decorticare",
    "decorticata": "decorticare",
    "decorticate": "decorticare",
    "decorticati": "decorticare",
    "decorticato": "decorticare",
    "decorticava": "decorticare",
    "decorticavamo": "decorticare",
    "decorticavan": "decorticare",
    "decorticavano": "decorticare",
    "decorticavate": "decorticare",
    "decorticavi": "decorticare",
    "decorticavo": "decorticare",
    "decorticherai": "decorticare",
    "decorticheran": "decorticare",
    "decorticheranno": "decorticare",
    "decorticherebbe": "decorticare",
    "decorticherebber": "decorticare",
    "decorticherebbero": "decorticare",
    "decorticherei": "decorticare",
    "decorticheremmo": "decorticare",
    "decorticheremo": "decorticare",
    "decortichereste": "decorticare",
    "decorticheresti": "decorticare",
    "decorticherete": "decorticare",
    "decorticherà": "decorticare",
    "decorticherò": "decorticare",
    "decortichi": "decorticare",
    "decortichiamo": "decorticare",
    "decortichiate": "decorticare",
    "decortichin": "decorticare",
    "decortichino": "decorticare",
    "decortico": "decorticare",
    "decorticò": "decorticare",
    "decorò": "decorare",
    "decostrua": "decostruire",
    "decostruan": "decostruire",
    "decostruano": "decostruire",
    "decostrue": "decostruire",
    "decostruendo": "decostruire",
    "decostruente": "decostruire",
    "decostruenti": "decostruire",
    "decostrui": "decostruire",
    "decostruiamo": "decostruire",
    "decostruiate": "decostruire",
    "decostruii": "decostruire",
    "decostruimmo": "decostruire",
    "decostruir": "decostruire",
    "decostruirai": "decostruire",
    "decostruiran": "decostruire",
    "decostruiranno": "decostruire",
    "decostruirebbe": "decostruire",
    "decostruirebber": "decostruire",
    "decostruirebbero": "decostruire",
    "decostruirei": "decostruire",
    "decostruiremmo": "decostruire",
    "decostruiremo": "decostruire",
    "decostruireste": "decostruire",
    "decostruiresti": "decostruire",
    "decostruirete": "decostruire",
    "decostruiron": "decostruire",
    "decostruirono": "decostruire",
    "decostruirà": "decostruire",
    "decostruirò": "decostruire",
    "decostruisse": "decostruire",
    "decostruisser": "decostruire",
    "decostruissero": "decostruire",
    "decostruissi": "decostruire",
    "decostruissimo": "decostruire",
    "decostruiste": "decostruire",
    "decostruisti": "decostruire",
    "decostruita": "decostruire",
    "decostruite": "decostruire",
    "decostruiti": "decostruire",
    "decostruito": "decostruire",
    "decostruiva": "decostruire",
    "decostruivamo": "decostruire",
    "decostruivan": "decostruire",
    "decostruivano": "decostruire",
    "decostruivate": "decostruire",
    "decostruivi": "decostruire",
    "decostruivo": "decostruire",
    "decostruo": "decostruire",
    "decostruon": "decostruire",
    "decostruono": "decostruire",
    "decostruzioni": "decostruzione",
    "decostruì": "decostruire",
    "decotte": "decotta",
    "decotti": "decotto",
    "decrementi": "decremento",
    "decrepita": "decrepito",
    "decrepite": "decrepito",
    "decrepiti": "decrepito",
    "decresca": "decrescere",
    "decrescan": "decrescere",
    "decrescano": "decrescere",
    "decresce": "decrescere",
    "decrescei": "decrescere",
    "decrescemmo": "decrescere",
    "decrescendo": "decrescere",
    "decrescente": "decrescere",
    "decrescenti": "decrescere",
    "decrescer": "decrescere",
    "decrescerai": "decrescere",
    "decresceran": "decrescere",
    "decresceranno": "decrescere",
    "decrescerebbe": "decrescere",
    "decrescerebber": "decrescere",
    "decrescerebbero": "decrescere",
    "decrescerei": "decrescere",
    "decresceremmo": "decrescere",
    "decresceremo": "decrescere",
    "decrescereste": "decrescere",
    "decresceresti": "decrescere",
    "decrescerete": "decrescere",
    "decresceron": "decrescere",
    "decrescerono": "decrescere",
    "decrescerà": "decrescere",
    "decrescerò": "decrescere",
    "decrescesse": "decrescere",
    "decrescesser": "decrescere",
    "decrescessero": "decrescere",
    "decrescessi": "decrescere",
    "decrescessimo": "decrescere",
    "decresceste": "decrescere",
    "decrescesti": "decrescere",
    "decrescete": "decrescere",
    "decresceva": "decrescere",
    "decrescevamo": "decrescere",
    "decrescevan": "decrescere",
    "decrescevano": "decrescere",
    "decrescevate": "decrescere",
    "decrescevi": "decrescere",
    "decrescevo": "decrescere",
    "decresci": "decrescere",
    "decresciamo": "decrescere",
    "decresciate": "decrescere",
    "decresciuta": "decrescere",
    "decresciute": "decrescere",
    "decresciuti": "decrescere",
    "decresciuto": "decrescere",
    "decresco": "decrescere",
    "decrescon": "decrescere",
    "decrescono": "decrescere",
    "decrescè": "decrescere",
    "decreta": "decretare",
    "decretai": "decretare",
    "decretammo": "decretare",
    "decretan": "decretare",
    "decretando": "decretare",
    "decretano": "decretare",
    "decretante": "decretare",
    "decretanti": "decretare",
    "decretar": "decretare",
    "decretaron": "decretare",
    "decretarono": "decretare",
    "decretasse": "decretare",
    "decretasser": "decretare",
    "decretassero": "decretare",
    "decretassi": "decretare",
    "decretassimo": "decretare",
    "decretaste": "decretare",
    "decretasti": "decretare",
    "decretata": "decretare",
    "decretate": "decretare",
    "decretati": "decretare",
    "decretato": "decretare",
    "decretava": "decretare",
    "decretavamo": "decretare",
    "decretavan": "decretare",
    "decretavano": "decretare",
    "decretavate": "decretare",
    "decretavi": "decretare",
    "decretavo": "decretare",
    "decretazioni": "decretazione",
    "decreterai": "decretare",
    "decreteran": "decretare",
    "decreteranno": "decretare",
    "decreterebbe": "decretare",
    "decreterebber": "decretare",
    "decreterebbero": "decretare",
    "decreterei": "decretare",
    "decreteremmo": "decretare",
    "decreteremo": "decretare",
    "decretereste": "decretare",
    "decreteresti": "decretare",
    "decreterete": "decretare",
    "decreterà": "decretare",
    "decreterò": "decretare",
    "decreti": "decreto",
    "decreti-legge": "decreto-legge",
    "decretiamo": "decretare",
    "decretiate": "decretare",
    "decretin": "decretare",
    "decretino": "decretare",
    "decreto": "decretare",
    "decretoni": "decretone",
    "decretò": "decretare",
    "decriminalizza": "decriminalizzare",
    "decriminalizzai": "decriminalizzare",
    "decriminalizzammo": "decriminalizzare",
    "decriminalizzan": "decriminalizzare",
    "decriminalizzando": "decriminalizzare",
    "decriminalizzano": "decriminalizzare",
    "decriminalizzante": "decriminalizzare",
    "decriminalizzanti": "decriminalizzare",
    "decriminalizzar": "decriminalizzare",
    "decriminalizzaron": "decriminalizzare",
    "decriminalizzarono": "decriminalizzare",
    "decriminalizzasse": "decriminalizzare",
    "decriminalizzasser": "decriminalizzare",
    "decriminalizzassero": "decriminalizzare",
    "decriminalizzassi": "decriminalizzare",
    "decriminalizzassimo": "decriminalizzare",
    "decriminalizzaste": "decriminalizzare",
    "decriminalizzasti": "decriminalizzare",
    "decriminalizzata": "decriminalizzare",
    "decriminalizzate": "decriminalizzare",
    "decriminalizzati": "decriminalizzare",
    "decriminalizzato": "decriminalizzare",
    "decriminalizzava": "decriminalizzare",
    "decriminalizzavamo": "decriminalizzare",
    "decriminalizzavan": "decriminalizzare",
    "decriminalizzavano": "decriminalizzare",
    "decriminalizzavate": "decriminalizzare",
    "decriminalizzavi": "decriminalizzare",
    "decriminalizzavo": "decriminalizzare",
    "decriminalizzerai": "decriminalizzare",
    "decriminalizzeran": "decriminalizzare",
    "decriminalizzeranno": "decriminalizzare",
    "decriminalizzerebbe": "decriminalizzare",
    "decriminalizzerebber": "decriminalizzare",
    "decriminalizzerebbero": "decriminalizzare",
    "decriminalizzerei": "decriminalizzare",
    "decriminalizzeremmo": "decriminalizzare",
    "decriminalizzeremo": "decriminalizzare",
    "decriminalizzereste": "decriminalizzare",
    "decriminalizzeresti": "decriminalizzare",
    "decriminalizzerete": "decriminalizzare",
    "decriminalizzerà": "decriminalizzare",
    "decriminalizzerò": "decriminalizzare",
    "decriminalizzi": "decriminalizzare",
    "decriminalizziamo": "decriminalizzare",
    "decriminalizziate": "decriminalizzare",
    "decriminalizzin": "decriminalizzare",
    "decriminalizzino": "decriminalizzare",
    "decriminalizzo": "decriminalizzare",
    "decriminalizzò": "decriminalizzare",
    "decritta": "decrittare",
    "decrittai": "decrittare",
    "decrittammo": "decrittare",
    "decrittan": "decrittare",
    "decrittando": "decrittare",
    "decrittano": "decrittare",
    "decrittante": "decrittare",
    "decrittanti": "decrittare",
    "decrittar": "decrittare",
    "decrittaron": "decrittare",
    "decrittarono": "decrittare",
    "decrittasse": "decrittare",
    "decrittasser": "decrittare",
    "decrittassero": "decrittare",
    "decrittassi": "decrittare",
    "decrittassimo": "decrittare",
    "decrittaste": "decrittare",
    "decrittasti": "decrittare",
    "decrittata": "decrittare",
    "decrittate": "decrittare",
    "decrittati": "decrittare",
    "decrittato": "decrittare",
    "decrittava": "decrittare",
    "decrittavamo": "decrittare",
    "decrittavan": "decrittare",
    "decrittavano": "decrittare",
    "decrittavate": "decrittare",
    "decrittavi": "decrittare",
    "decrittavo": "decrittare",
    "decritterai": "decrittare",
    "decritteran": "decrittare",
    "decritteranno": "decrittare",
    "decritterebbe": "decrittare",
    "decritterebber": "decrittare",
    "decritterebbero": "decrittare",
    "decritterei": "decrittare",
    "decritteremmo": "decrittare",
    "decritteremo": "decrittare",
    "decrittereste": "decrittare",
    "decritteresti": "decrittare",
    "decritterete": "decrittare",
    "decritterà": "decrittare",
    "decritterò": "decrittare",
    "decritti": "decrittare",
    "decrittiamo": "decrittare",
    "decrittiate": "decrittare",
    "decrittin": "decrittare",
    "decrittino": "decrittare",
    "decritto": "decrittare",
    "decrittò": "decrittare",
    "decuplica": "decuplicare",
    "decuplicai": "decuplicare",
    "decuplicammo": "decuplicare",
    "decuplican": "decuplicare",
    "decuplicando": "decuplicare",
    "decuplicano": "decuplicare",
    "decuplicante": "decuplicare",
    "decuplicanti": "decuplicare",
    "decuplicar": "decuplicare",
    "decuplicaron": "decuplicare",
    "decuplicarono": "decuplicare",
    "decuplicasse": "decuplicare",
    "decuplicasser": "decuplicare",
    "decuplicassero": "decuplicare",
    "decuplicassi": "decuplicare",
    "decuplicassimo": "decuplicare",
    "decuplicaste": "decuplicare",
    "decuplicasti": "decuplicare",
    "decuplicata": "decuplicare",
    "decuplicate": "decuplicare",
    "decuplicati": "decuplicare",
    "decuplicato": "decuplicare",
    "decuplicava": "decuplicare",
    "decuplicavamo": "decuplicare",
    "decuplicavan": "decuplicare",
    "decuplicavano": "decuplicare",
    "decuplicavate": "decuplicare",
    "decuplicavi": "decuplicare",
    "decuplicavo": "decuplicare",
    "decuplicherai": "decuplicare",
    "decuplicheran": "decuplicare",
    "decuplicheranno": "decuplicare",
    "decuplicherebbe": "decuplicare",
    "decuplicherebber": "decuplicare",
    "decuplicherebbero": "decuplicare",
    "decuplicherei": "decuplicare",
    "decuplicheremmo": "decuplicare",
    "decuplicheremo": "decuplicare",
    "decuplichereste": "decuplicare",
    "decuplicheresti": "decuplicare",
    "decuplicherete": "decuplicare",
    "decuplicherà": "decuplicare",
    "decuplicherò": "decuplicare",
    "decuplichi": "decuplicare",
    "decuplichiamo": "decuplicare",
    "decuplichiate": "decuplicare",
    "decuplichin": "decuplicare",
    "decuplichino": "decuplicare",
    "decuplico": "decuplicare",
    "decuplicò": "decuplicare",
    "decurta": "decurtare",
    "decurtai": "decurtare",
    "decurtammo": "decurtare",
    "decurtan": "decurtare",
    "decurtando": "decurtare",
    "decurtano": "decurtare",
    "decurtante": "decurtare",
    "decurtanti": "decurtare",
    "decurtar": "decurtare",
    "decurtaron": "decurtare",
    "decurtarono": "decurtare",
    "decurtasse": "decurtare",
    "decurtasser": "decurtare",
    "decurtassero": "decurtare",
    "decurtassi": "decurtare",
    "decurtassimo": "decurtare",
    "decurtaste": "decurtare",
    "decurtasti": "decurtare",
    "decurtata": "decurtare",
    "decurtate": "decurtare",
    "decurtati": "decurtare",
    "decurtato": "decurtare",
    "decurtava": "decurtare",
    "decurtavamo": "decurtare",
    "decurtavan": "decurtare",
    "decurtavano": "decurtare",
    "decurtavate": "decurtare",
    "decurtavi": "decurtare",
    "decurtavo": "decurtare",
    "decurtazioni": "decurtazione",
    "decurterai": "decurtare",
    "decurteran": "decurtare",
    "decurteranno": "decurtare",
    "decurterebbe": "decurtare",
    "decurterebber": "decurtare",
    "decurterebbero": "decurtare",
    "decurterei": "decurtare",
    "decurteremmo": "decurtare",
    "decurteremo": "decurtare",
    "decurtereste": "decurtare",
    "decurteresti": "decurtare",
    "decurterete": "decurtare",
    "decurterà": "decurtare",
    "decurterò": "decurtare",
    "decurti": "decurtare",
    "decurtiamo": "decurtare",
    "decurtiate": "decurtare",
    "decurtin": "decurtare",
    "decurtino": "decurtare",
    "decurto": "decurtare",
    "decurtò": "decurtare",
    "dedali": "dedalo",
    "dedica": "dedicare",
    "dedicai": "dedicare",
    "dedicammo": "dedicare",
    "dedican": "dedicare",
    "dedicando": "dedicare",
    "dedicano": "dedicare",
    "dedicante": "dedicare",
    "dedicanti": "dedicare",
    "dedicar": "dedicare",
    "dedicaron": "dedicare",
    "dedicarono": "dedicare",
    "dedicasse": "dedicare",
    "dedicasser": "dedicare",
    "dedicassero": "dedicare",
    "dedicassi": "dedicare",
    "dedicassimo": "dedicare",
    "dedicaste": "dedicare",
    "dedicasti": "dedicare",
    "dedicata": "dedicare",
    "dedicate": "dedicare",
    "dedicati": "dedicare",
    "dedicato": "dedicare",
    "dedicava": "dedicare",
    "dedicavamo": "dedicare",
    "dedicavan": "dedicare",
    "dedicavano": "dedicare",
    "dedicavate": "dedicare",
    "dedicavi": "dedicare",
    "dedicavo": "dedicare",
    "dediche": "dedica",
    "dedicherai": "dedicare",
    "dedicheran": "dedicare",
    "dedicheranno": "dedicare",
    "dedicherebbe": "dedicare",
    "dedicherebber": "dedicare",
    "dedicherebbero": "dedicare",
    "dedicherei": "dedicare",
    "dedicheremmo": "dedicare",
    "dedicheremo": "dedicare",
    "dedichereste": "dedicare",
    "dedicheresti": "dedicare",
    "dedicherete": "dedicare",
    "dedicherà": "dedicare",
    "dedicherò": "dedicare",
    "dedichi": "dedicare",
    "dedichiamo": "dedicare",
    "dedichiate": "dedicare",
    "dedichin": "dedicare",
    "dedichino": "dedicare",
    "dedico": "dedicare",
    "dedicò": "dedicare",
    "dedita": "dedito",
    "dedite": "dedito",
    "dediti": "dedito",
    "dedizioni": "dedizione",
    "dedotta": "dedurre",
    "dedotte": "dedurre",
    "dedotti": "dedurre",
    "dedotto": "dedurre",
    "deduca": "dedurre",
    "deducan": "dedurre",
    "deducano": "dedurre",
    "deduce": "dedurre",
    "deducemmo": "dedurre",
    "deducendo": "dedurre",
    "deducente": "dedurre",
    "deducenti": "dedurre",
    "deducesse": "dedurre",
    "deducesser": "dedurre",
    "deducessero": "dedurre",
    "deducessi": "dedurre",
    "deducessimo": "dedurre",
    "deduceste": "dedurre",
    "deducesti": "dedurre",
    "deducete": "dedurre",
    "deduceva": "dedurre",
    "deducevamo": "dedurre",
    "deducevan": "dedurre",
    "deducevano": "dedurre",
    "deducevate": "dedurre",
    "deducevi": "dedurre",
    "deducevo": "dedurre",
    "deduci": "dedurre",
    "deduciamo": "dedurre",
    "deduciate": "dedurre",
    "deducibili": "deducibile",
    "deduco": "dedurre",
    "deducon": "dedurre",
    "deducono": "dedurre",
    "dedurr": "dedurre",
    "dedurrai": "dedurre",
    "dedurran": "dedurre",
    "dedurranno": "dedurre",
    "dedurrebbe": "dedurre",
    "dedurrebber": "dedurre",
    "dedurrebbero": "dedurre",
    "dedurrei": "dedurre",
    "dedurremmo": "dedurre",
    "dedurremo": "dedurre",
    "dedurreste": "dedurre",
    "dedurresti": "dedurre",
    "dedurrete": "dedurre",
    "dedurrà": "dedurre",
    "dedurrò": "dedurre",
    "dedusse": "dedurre",
    "dedusser": "dedurre",
    "dedussero": "dedurre",
    "dedussi": "dedurre",
    "deduttiva": "deduttivo",
    "deduttive": "deduttivo",
    "deduttivi": "deduttivo",
    "deduzioni": "deduzione",
    "dee": "dea",
    "defalca": "defalcare",
    "defalcai": "defalcare",
    "defalcammo": "defalcare",
    "defalcan": "defalcare",
    "defalcando": "defalcare",
    "defalcano": "defalcare",
    "defalcante": "defalcare",
    "defalcanti": "defalcare",
    "defalcar": "defalcare",
    "defalcaron": "defalcare",
    "defalcarono": "defalcare",
    "defalcasse": "defalcare",
    "defalcasser": "defalcare",
    "defalcassero": "defalcare",
    "defalcassi": "defalcare",
    "defalcassimo": "defalcare",
    "defalcaste": "defalcare",
    "defalcasti": "defalcare",
    "defalcata": "defalcare",
    "defalcate": "defalcare",
    "defalcati": "defalcare",
    "defalcato": "defalcare",
    "defalcava": "defalcare",
    "defalcavamo": "defalcare",
    "defalcavan": "defalcare",
    "defalcavano": "defalcare",
    "defalcavate": "defalcare",
    "defalcavi": "defalcare",
    "defalcavo": "defalcare",
    "defalcherai": "defalcare",
    "defalcheran": "defalcare",
    "defalcheranno": "defalcare",
    "defalcherebbe": "defalcare",
    "defalcherebber": "defalcare",
    "defalcherebbero": "defalcare",
    "defalcherei": "defalcare",
    "defalcheremmo": "defalcare",
    "defalcheremo": "defalcare",
    "defalchereste": "defalcare",
    "defalcheresti": "defalcare",
    "defalcherete": "defalcare",
    "defalcherà": "defalcare",
    "defalcherò": "defalcare",
    "defalchi": "defalcare",
    "defalchiamo": "defalcare",
    "defalchiate": "defalcare",
    "defalchin": "defalcare",
    "defalchino": "defalcare",
    "defalco": "defalcare",
    "defalcò": "defalcare",
    "defatica": "defaticare",
    "defaticai": "defaticare",
    "defaticammo": "defaticare",
    "defatican": "defaticare",
    "defaticando": "defaticare",
    "defaticano": "defaticare",
    "defaticar": "defaticare",
    "defaticaron": "defaticare",
    "defaticarono": "defaticare",
    "defaticasse": "defaticare",
    "defaticasser": "defaticare",
    "defaticassero": "defaticare",
    "defaticassi": "defaticare",
    "defaticassimo": "defaticare",
    "defaticaste": "defaticare",
    "defaticasti": "defaticare",
    "defaticata": "defaticare",
    "defaticate": "defaticare",
    "defaticati": "defaticare",
    "defaticato": "defaticare",
    "defaticava": "defaticare",
    "defaticavamo": "defaticare",
    "defaticavan": "defaticare",
    "defaticavano": "defaticare",
    "defaticavate": "defaticare",
    "defaticavi": "defaticare",
    "defaticavo": "defaticare",
    "defaticherai": "defaticare",
    "defaticheran": "defaticare",
    "defaticheranno": "defaticare",
    "defaticherebbe": "defaticare",
    "defaticherebber": "defaticare",
    "defaticherebbero": "defaticare",
    "defaticherei": "defaticare",
    "defaticheremmo": "defaticare",
    "defaticheremo": "defaticare",
    "defatichereste": "defaticare",
    "defaticheresti": "defaticare",
    "defaticherete": "defaticare",
    "defaticherà": "defaticare",
    "defaticherò": "defaticare",
    "defatichi": "defaticare",
    "defatichiamo": "defaticare",
    "defatichiate": "defaticare",
    "defatichin": "defaticare",
    "defatichino": "defaticare",
    "defatico": "defaticare",
    "defaticò": "defaticare",
    "defatiga": "defatigare",
    "defatigai": "defatigare",
    "defatigammo": "defatigare",
    "defatigan": "defatigare",
    "defatigando": "defatigare",
    "defatigano": "defatigare",
    "defatigante": "defatigare",
    "defatiganti": "defatigare",
    "defatigar": "defatigare",
    "defatigaron": "defatigare",
    "defatigarono": "defatigare",
    "defatigasse": "defatigare",
    "defatigasser": "defatigare",
    "defatigassero": "defatigare",
    "defatigassi": "defatigare",
    "defatigassimo": "defatigare",
    "defatigaste": "defatigare",
    "defatigasti": "defatigare",
    "defatigata": "defatigare",
    "defatigate": "defatigare",
    "defatigati": "defatigare",
    "defatigato": "defatigare",
    "defatigava": "defatigare",
    "defatigavamo": "defatigare",
    "defatigavan": "defatigare",
    "defatigavano": "defatigare",
    "defatigavate": "defatigare",
    "defatigavi": "defatigare",
    "defatigavo": "defatigare",
    "defatigherai": "defatigare",
    "defatigheran": "defatigare",
    "defatigheranno": "defatigare",
    "defatigherebbe": "defatigare",
    "defatigherebber": "defatigare",
    "defatigherebbero": "defatigare",
    "defatigherei": "defatigare",
    "defatigheremmo": "defatigare",
    "defatigheremo": "defatigare",
    "defatighereste": "defatigare",
    "defatigheresti": "defatigare",
    "defatigherete": "defatigare",
    "defatigherà": "defatigare",
    "defatigherò": "defatigare",
    "defatighi": "defatigare",
    "defatighiamo": "defatigare",
    "defatighiate": "defatigare",
    "defatighin": "defatigare",
    "defatighino": "defatigare",
    "defatigo": "defatigare",
    "defatigò": "defatigare",
    "defeca": "defecare",
    "defecai": "defecare",
    "defecammo": "defecare",
    "defecan": "defecare",
    "defecando": "defecare",
    "defecano": "defecare",
    "defecante": "defecare",
    "defecanti": "defecare",
    "defecar": "defecare",
    "defecaron": "defecare",
    "defecarono": "defecare",
    "defecasse": "defecare",
    "defecasser": "defecare",
    "defecassero": "defecare",
    "defecassi": "defecare",
    "defecassimo": "defecare",
    "defecaste": "defecare",
    "defecasti": "defecare",
    "defecata": "defecare",
    "defecate": "defecare",
    "defecati": "defecare",
    "defecato": "defecare",
    "defecava": "defecare",
    "defecavamo": "defecare",
    "defecavan": "defecare",
    "defecavano": "defecare",
    "defecavate": "defecare",
    "defecavi": "defecare",
    "defecavo": "defecare",
    "defecherai": "defecare",
    "defecheran": "defecare",
    "defecheranno": "defecare",
    "defecherebbe": "defecare",
    "defecherebber": "defecare",
    "defecherebbero": "defecare",
    "defecherei": "defecare",
    "defecheremmo": "defecare",
    "defecheremo": "defecare",
    "defechereste": "defecare",
    "defecheresti": "defecare",
    "defecherete": "defecare",
    "defecherà": "defecare",
    "defecherò": "defecare",
    "defechi": "defecare",
    "defechiamo": "defecare",
    "defechiate": "defecare",
    "defechin": "defecare",
    "defechino": "defecare",
    "defeco": "defecare",
    "defecò": "defecare",
    "defeliciana": "defeliciano",
    "defeliciane": "defeliciano",
    "defeliciani": "defeliciano",
    "defenestra": "defenestrare",
    "defenestrai": "defenestrare",
    "defenestrammo": "defenestrare",
    "defenestran": "defenestrare",
    "defenestrando": "defenestrare",
    "defenestrano": "defenestrare",
    "defenestrante": "defenestrare",
    "defenestranti": "defenestrare",
    "defenestrar": "defenestrare",
    "defenestraron": "defenestrare",
    "defenestrarono": "defenestrare",
    "defenestrasse": "defenestrare",
    "defenestrasser": "defenestrare",
    "defenestrassero": "defenestrare",
    "defenestrassi": "defenestrare",
    "defenestrassimo": "defenestrare",
    "defenestraste": "defenestrare",
    "defenestrasti": "defenestrare",
    "defenestrata": "defenestrare",
    "defenestrate": "defenestrare",
    "defenestrati": "defenestrare",
    "defenestrato": "defenestrare",
    "defenestrava": "defenestrare",
    "defenestravamo": "defenestrare",
    "defenestravan": "defenestrare",
    "defenestravano": "defenestrare",
    "defenestravate": "defenestrare",
    "defenestravi": "defenestrare",
    "defenestravo": "defenestrare",
    "defenestrazioni": "defenestrazione",
    "defenestrerai": "defenestrare",
    "defenestreran": "defenestrare",
    "defenestreranno": "defenestrare",
    "defenestrerebbe": "defenestrare",
    "defenestrerebber": "defenestrare",
    "defenestrerebbero": "defenestrare",
    "defenestrerei": "defenestrare",
    "defenestreremmo": "defenestrare",
    "defenestreremo": "defenestrare",
    "defenestrereste": "defenestrare",
    "defenestreresti": "defenestrare",
    "defenestrerete": "defenestrare",
    "defenestrerà": "defenestrare",
    "defenestrerò": "defenestrare",
    "defenestri": "defenestrare",
    "defenestriamo": "defenestrare",
    "defenestriate": "defenestrare",
    "defenestrin": "defenestrare",
    "defenestrino": "defenestrare",
    "defenestro": "defenestrare",
    "defenestrò": "defenestrare",
    "deferendo": "deferire",
    "deferente": "deferire",
    "deferenti": "deferire",
    "deferenze": "deferenza",
    "deferiamo": "deferire",
    "deferiate": "deferire",
    "deferii": "deferire",
    "deferimenti": "deferimento",
    "deferimmo": "deferire",
    "deferir": "deferire",
    "deferirai": "deferire",
    "deferiran": "deferire",
    "deferiranno": "deferire",
    "deferirebbe": "deferire",
    "deferirebber": "deferire",
    "deferirebbero": "deferire",
    "deferirei": "deferire",
    "deferiremmo": "deferire",
    "deferiremo": "deferire",
    "deferireste": "deferire",
    "deferiresti": "deferire",
    "deferirete": "deferire",
    "deferiron": "deferire",
    "deferirono": "deferire",
    "deferirà": "deferire",
    "deferirò": "deferire",
    "deferisca": "deferire",
    "deferiscan": "deferire",
    "deferiscano": "deferire",
    "deferisce": "deferire",
    "deferisci": "deferire",
    "deferisco": "deferire",
    "deferiscon": "deferire",
    "deferiscono": "deferire",
    "deferisse": "deferire",
    "deferisser": "deferire",
    "deferissero": "deferire",
    "deferissi": "deferire",
    "deferissimo": "deferire",
    "deferiste": "deferire",
    "deferisti": "deferire",
    "deferita": "deferire",
    "deferite": "deferire",
    "deferiti": "deferire",
    "deferito": "deferire",
    "deferiva": "deferire",
    "deferivamo": "deferire",
    "deferivan": "deferire",
    "deferivano": "deferire",
    "deferivate": "deferire",
    "deferivi": "deferire",
    "deferivo": "deferire",
    "deferì": "deferire",
    "defeziona": "defezionare",
    "defezionai": "defezionare",
    "defezionammo": "defezionare",
    "defezionan": "defezionare",
    "defezionando": "defezionare",
    "defezionano": "defezionare",
    "defezionante": "defezionare",
    "defezionanti": "defezionare",
    "defezionar": "defezionare",
    "defezionaron": "defezionare",
    "defezionarono": "defezionare",
    "defezionasse": "defezionare",
    "defezionasser": "defezionare",
    "defezionassero": "defezionare",
    "defezionassi": "defezionare",
    "defezionassimo": "defezionare",
    "defezionaste": "defezionare",
    "defezionasti": "defezionare",
    "defezionata": "defezionare",
    "defezionate": "defezionare",
    "defezionati": "defezionare",
    "defezionato": "defezionare",
    "defezionava": "defezionare",
    "defezionavamo": "defezionare",
    "defezionavan": "defezionare",
    "defezionavano": "defezionare",
    "defezionavate": "defezionare",
    "defezionavi": "defezionare",
    "defezionavo": "defezionare",
    "defezionerai": "defezionare",
    "defezioneran": "defezionare",
    "defezioneranno": "defezionare",
    "defezionerebbe": "defezionare",
    "defezionerebber": "defezionare",
    "defezionerebbero": "defezionare",
    "defezionerei": "defezionare",
    "defezioneremmo": "defezionare",
    "defezioneremo": "defezionare",
    "defezionereste": "defezionare",
    "defezioneresti": "defezionare",
    "defezionerete": "defezionare",
    "defezionerà": "defezionare",
    "defezionerò": "defezionare",
    "defezioni": "defezione",
    "defezioniamo": "defezionare",
    "defezioniate": "defezionare",
    "defezionin": "defezionare",
    "defezionino": "defezionare",
    "defeziono": "defezionare",
    "defezionò": "defezionare",
    "defibrillatori": "defibrillatore",
    "deficienti": "deficiente",
    "deficienze": "deficienza",
    "deficitari": "deficitario",
    "deficitaria": "deficitario",
    "deficitarie": "deficitario",
    "defigga": "defiggere",
    "defiggan": "defiggere",
    "defiggano": "defiggere",
    "defigge": "defiggere",
    "defiggemmo": "defiggere",
    "defiggendo": "defiggere",
    "defiggente": "defiggere",
    "defiggenti": "defiggere",
    "defigger": "defiggere",
    "defiggerai": "defiggere",
    "defiggeran": "defiggere",
    "defiggeranno": "defiggere",
    "defiggerebbe": "defiggere",
    "defiggerebber": "defiggere",
    "defiggerebbero": "defiggere",
    "defiggerei": "defiggere",
    "defiggeremmo": "defiggere",
    "defiggeremo": "defiggere",
    "defiggereste": "defiggere",
    "defiggeresti": "defiggere",
    "defiggerete": "defiggere",
    "defiggerà": "defiggere",
    "defiggerò": "defiggere",
    "defiggesse": "defiggere",
    "defiggesser": "defiggere",
    "defiggessero": "defiggere",
    "defiggessi": "defiggere",
    "defiggessimo": "defiggere",
    "defiggeste": "defiggere",
    "defiggesti": "defiggere",
    "defiggete": "defiggere",
    "defiggeva": "defiggere",
    "defiggevamo": "defiggere",
    "defiggevan": "defiggere",
    "defiggevano": "defiggere",
    "defiggevate": "defiggere",
    "defiggevi": "defiggere",
    "defiggevo": "defiggere",
    "defiggi": "defiggere",
    "defiggiamo": "defiggere",
    "defiggiate": "defiggere",
    "defiggo": "defiggere",
    "defiggon": "defiggere",
    "defiggono": "defiggere",
    "defila": "defilare",
    "defilai": "defilare",
    "defilammo": "defilare",
    "defilan": "defilare",
    "defilando": "defilare",
    "defilano": "defilare",
    "defilante": "defilare",
    "defilanti": "defilare",
    "defilar": "defilare",
    "defilaron": "defilare",
    "defilarono": "defilare",
    "defilasse": "defilare",
    "defilasser": "defilare",
    "defilassero": "defilare",
    "defilassi": "defilare",
    "defilassimo": "defilare",
    "defilaste": "defilare",
    "defilasti": "defilare",
    "defilata": "defilato",
    "defilate": "defilato",
    "defilati": "defilato",
    "defilato": "defilare",
    "defilava": "defilare",
    "defilavamo": "defilare",
    "defilavan": "defilare",
    "defilavano": "defilare",
    "defilavate": "defilare",
    "defilavi": "defilare",
    "defilavo": "defilare",
    "defilerai": "defilare",
    "defileran": "defilare",
    "defileranno": "defilare",
    "defilerebbe": "defilare",
    "defilerebber": "defilare",
    "defilerebbero": "defilare",
    "defilerei": "defilare",
    "defileremmo": "defilare",
    "defileremo": "defilare",
    "defilereste": "defilare",
    "defileresti": "defilare",
    "defilerete": "defilare",
    "defilerà": "defilare",
    "defilerò": "defilare",
    "defili": "defilare",
    "defiliamo": "defilare",
    "defiliate": "defilare",
    "defilin": "defilare",
    "defilino": "defilare",
    "defilo": "defilare",
    "defilò": "defilare",
    "definendo": "definire",
    "definente": "definire",
    "definenti": "definire",
    "definiamo": "definire",
    "definiate": "definire",
    "definibili": "definibile",
    "definii": "definire",
    "definimmo": "definire",
    "definir": "definire",
    "definirai": "definire",
    "definiran": "definire",
    "definiranno": "definire",
    "definirebbe": "definire",
    "definirebber": "definire",
    "definirebbero": "definire",
    "definirei": "definire",
    "definiremmo": "definire",
    "definiremo": "definire",
    "definireste": "definire",
    "definiresti": "definire",
    "definirete": "definire",
    "definiron": "definire",
    "definirono": "definire",
    "definirà": "definire",
    "definirò": "definire",
    "definisca": "definire",
    "definiscan": "definire",
    "definiscano": "definire",
    "definisce": "definire",
    "definisci": "definire",
    "definisco": "definire",
    "definiscon": "definire",
    "definiscono": "definire",
    "definisse": "definire",
    "definisser": "definire",
    "definissero": "definire",
    "definissi": "definire",
    "definissimo": "definire",
    "definiste": "definire",
    "definisti": "definire",
    "definita": "definito",
    "definite": "definito",
    "definiti": "definito",
    "definitiva": "definitivo",
    "definitive": "definitivo",
    "definitivi": "definitivo",
    "definito": "definire",
    "definiva": "definire",
    "definivamo": "definire",
    "definivan": "definire",
    "definivano": "definire",
    "definivate": "definire",
    "definivi": "definire",
    "definivo": "definire",
    "definizioni": "definizione",
    "definì": "definire",
    "defiscalizza": "defiscalizzare",
    "defiscalizzai": "defiscalizzare",
    "defiscalizzammo": "defiscalizzare",
    "defiscalizzan": "defiscalizzare",
    "defiscalizzando": "defiscalizzare",
    "defiscalizzano": "defiscalizzare",
    "defiscalizzante": "defiscalizzare",
    "defiscalizzanti": "defiscalizzare",
    "defiscalizzar": "defiscalizzare",
    "defiscalizzaron": "defiscalizzare",
    "defiscalizzarono": "defiscalizzare",
    "defiscalizzasse": "defiscalizzare",
    "defiscalizzasser": "defiscalizzare",
    "defiscalizzassero": "defiscalizzare",
    "defiscalizzassi": "defiscalizzare",
    "defiscalizzassimo": "defiscalizzare",
    "defiscalizzaste": "defiscalizzare",
    "defiscalizzasti": "defiscalizzare",
    "defiscalizzata": "defiscalizzare",
    "defiscalizzate": "defiscalizzare",
    "defiscalizzati": "defiscalizzare",
    "defiscalizzato": "defiscalizzare",
    "defiscalizzava": "defiscalizzare",
    "defiscalizzavamo": "defiscalizzare",
    "defiscalizzavan": "defiscalizzare",
    "defiscalizzavano": "defiscalizzare",
    "defiscalizzavate": "defiscalizzare",
    "defiscalizzavi": "defiscalizzare",
    "defiscalizzavo": "defiscalizzare",
    "defiscalizzazioni": "defiscalizzazione",
    "defiscalizzerai": "defiscalizzare",
    "defiscalizzeran": "defiscalizzare",
    "defiscalizzeranno": "defiscalizzare",
    "defiscalizzerebbe": "defiscalizzare",
    "defiscalizzerebber": "defiscalizzare",
    "defiscalizzerebbero": "defiscalizzare",
    "defiscalizzerei": "defiscalizzare",
    "defiscalizzeremmo": "defiscalizzare",
    "defiscalizzeremo": "defiscalizzare",
    "defiscalizzereste": "defiscalizzare",
    "defiscalizzeresti": "defiscalizzare",
    "defiscalizzerete": "defiscalizzare",
    "defiscalizzerà": "defiscalizzare",
    "defiscalizzerò": "defiscalizzare",
    "defiscalizzi": "defiscalizzare",
    "defiscalizziamo": "defiscalizzare",
    "defiscalizziate": "defiscalizzare",
    "defiscalizzin": "defiscalizzare",
    "defiscalizzino": "defiscalizzare",
    "defiscalizzo": "defiscalizzare",
    "defiscalizzò": "defiscalizzare",
    "defisser": "defiggere",
    "defissero": "defiggere",
    "defissi": "defiggere",
    "defissè": "defiggere",
    "defitta": "defiggere",
    "defitte": "defiggere",
    "defitti": "defiggere",
    "defitto": "defiggere",
    "deflagra": "deflagrare",
    "deflagrai": "deflagrare",
    "deflagrammo": "deflagrare",
    "deflagran": "deflagrare",
    "deflagrando": "deflagrare",
    "deflagrano": "deflagrare",
    "deflagrante": "deflagrare",
    "deflagranti": "deflagrare",
    "deflagrar": "deflagrare",
    "deflagraron": "deflagrare",
    "deflagrarono": "deflagrare",
    "deflagrasse": "deflagrare",
    "deflagrasser": "deflagrare",
    "deflagrassero": "deflagrare",
    "deflagrassi": "deflagrare",
    "deflagrassimo": "deflagrare",
    "deflagraste": "deflagrare",
    "deflagrasti": "deflagrare",
    "deflagrata": "deflagrare",
    "deflagrate": "deflagrare",
    "deflagrati": "deflagrare",
    "deflagrato": "deflagrare",
    "deflagrava": "deflagrare",
    "deflagravamo": "deflagrare",
    "deflagravan": "deflagrare",
    "deflagravano": "deflagrare",
    "deflagravate": "deflagrare",
    "deflagravi": "deflagrare",
    "deflagravo": "deflagrare",
    "deflagrazioni": "deflagrazione",
    "deflagrerai": "deflagrare",
    "deflagreran": "deflagrare",
    "deflagreranno": "deflagrare",
    "deflagrerebbe": "deflagrare",
    "deflagrerebber": "deflagrare",
    "deflagrerebbero": "deflagrare",
    "deflagrerei": "deflagrare",
    "deflagreremmo": "deflagrare",
    "deflagreremo": "deflagrare",
    "deflagrereste": "deflagrare",
    "deflagreresti": "deflagrare",
    "deflagrerete": "deflagrare",
    "deflagrerà": "deflagrare",
    "deflagrerò": "deflagrare",
    "deflagri": "deflagrare",
    "deflagriamo": "deflagrare",
    "deflagriate": "deflagrare",
    "deflagrin": "deflagrare",
    "deflagrino": "deflagrare",
    "deflagro": "deflagrare",
    "deflagrò": "deflagrare",
    "deflattiva": "deflattivo",
    "deflattive": "deflattivo",
    "deflattivi": "deflattivo",
    "deflaziona": "deflazionare",
    "deflazionai": "deflazionare",
    "deflazionammo": "deflazionare",
    "deflazionan": "deflazionare",
    "deflazionando": "deflazionare",
    "deflazionano": "deflazionare",
    "deflazionante": "deflazionare",
    "deflazionanti": "deflazionare",
    "deflazionar": "deflazionare",
    "deflazionaron": "deflazionare",
    "deflazionarono": "deflazionare",
    "deflazionasse": "deflazionare",
    "deflazionasser": "deflazionare",
    "deflazionassero": "deflazionare",
    "deflazionassi": "deflazionare",
    "deflazionassimo": "deflazionare",
    "deflazionaste": "deflazionare",
    "deflazionasti": "deflazionare",
    "deflazionata": "deflazionare",
    "deflazionate": "deflazionare",
    "deflazionati": "deflazionare",
    "deflazionato": "deflazionare",
    "deflazionava": "deflazionare",
    "deflazionavamo": "deflazionare",
    "deflazionavan": "deflazionare",
    "deflazionavano": "deflazionare",
    "deflazionavate": "deflazionare",
    "deflazionavi": "deflazionare",
    "deflazionavo": "deflazionare",
    "deflazionerai": "deflazionare",
    "deflazioneran": "deflazionare",
    "deflazioneranno": "deflazionare",
    "deflazionerebbe": "deflazionare",
    "deflazionerebber": "deflazionare",
    "deflazionerebbero": "deflazionare",
    "deflazionerei": "deflazionare",
    "deflazioneremmo": "deflazionare",
    "deflazioneremo": "deflazionare",
    "deflazionereste": "deflazionare",
    "deflazioneresti": "deflazionare",
    "deflazionerete": "deflazionare",
    "deflazionerà": "deflazionare",
    "deflazionerò": "deflazionare",
    "deflazioni": "deflazione",
    "deflazioniamo": "deflazionare",
    "deflazioniate": "deflazionare",
    "deflazionin": "deflazionare",
    "deflazionino": "deflazionare",
    "deflaziono": "deflazionare",
    "deflazionò": "deflazionare",
    "defletta": "deflettere",
    "deflettan": "deflettere",
    "deflettano": "deflettere",
    "deflette": "deflettere",
    "deflettei": "deflettere",
    "deflettemmo": "deflettere",
    "deflettendo": "deflettere",
    "deflettente": "deflettere",
    "deflettenti": "deflettere",
    "defletter": "deflettere",
    "defletterai": "deflettere",
    "defletteran": "deflettere",
    "defletteranno": "deflettere",
    "defletterebbe": "deflettere",
    "defletterebber": "deflettere",
    "defletterebbero": "deflettere",
    "defletterei": "deflettere",
    "defletteremmo": "deflettere",
    "defletteremo": "deflettere",
    "deflettereste": "deflettere",
    "defletteresti": "deflettere",
    "defletterete": "deflettere",
    "defletteron": "deflettere",
    "defletterono": "deflettere",
    "defletterà": "deflettere",
    "defletterò": "deflettere",
    "deflettesse": "deflettere",
    "deflettesser": "deflettere",
    "deflettessero": "deflettere",
    "deflettessi": "deflettere",
    "deflettessimo": "deflettere",
    "defletteste": "deflettere",
    "deflettesti": "deflettere",
    "deflettete": "deflettere",
    "defletteva": "deflettere",
    "deflettevamo": "deflettere",
    "deflettevan": "deflettere",
    "deflettevano": "deflettere",
    "deflettevate": "deflettere",
    "deflettevi": "deflettere",
    "deflettevo": "deflettere",
    "defletti": "deflettere",
    "deflettiamo": "deflettere",
    "deflettiate": "deflettere",
    "defletto": "deflettere",
    "defletton": "deflettere",
    "deflettono": "deflettere",
    "deflettori": "deflettore",
    "deflettuta": "deflettere",
    "deflettute": "deflettere",
    "deflettuti": "deflettere",
    "deflettuto": "deflettere",
    "deflettè": "deflettere",
    "deflora": "deflorare",
    "deflorai": "deflorare",
    "deflorammo": "deflorare",
    "defloran": "deflorare",
    "deflorando": "deflorare",
    "deflorano": "deflorare",
    "deflorante": "deflorare",
    "defloranti": "deflorare",
    "deflorar": "deflorare",
    "defloraron": "deflorare",
    "deflorarono": "deflorare",
    "deflorasse": "deflorare",
    "deflorasser": "deflorare",
    "deflorassero": "deflorare",
    "deflorassi": "deflorare",
    "deflorassimo": "deflorare",
    "defloraste": "deflorare",
    "deflorasti": "deflorare",
    "deflorata": "deflorare",
    "deflorate": "deflorare",
    "deflorati": "deflorare",
    "deflorato": "deflorare",
    "deflorava": "deflorare",
    "defloravamo": "deflorare",
    "defloravan": "deflorare",
    "defloravano": "deflorare",
    "defloravate": "deflorare",
    "defloravi": "deflorare",
    "defloravo": "deflorare",
    "deflorerai": "deflorare",
    "defloreran": "deflorare",
    "defloreranno": "deflorare",
    "deflorerebbe": "deflorare",
    "deflorerebber": "deflorare",
    "deflorerebbero": "deflorare",
    "deflorerei": "deflorare",
    "defloreremmo": "deflorare",
    "defloreremo": "deflorare",
    "deflorereste": "deflorare",
    "defloreresti": "deflorare",
    "deflorerete": "deflorare",
    "deflorerà": "deflorare",
    "deflorerò": "deflorare",
    "deflori": "deflorare",
    "defloriamo": "deflorare",
    "defloriate": "deflorare",
    "deflorin": "deflorare",
    "deflorino": "deflorare",
    "defloro": "deflorare",
    "deflorò": "deflorare",
    "defluendo": "defluire",
    "defluente": "defluire",
    "defluenti": "defluire",
    "defluiamo": "defluire",
    "defluiate": "defluire",
    "defluii": "defluire",
    "defluimmo": "defluire",
    "defluir": "defluire",
    "defluirai": "defluire",
    "defluiran": "defluire",
    "defluiranno": "defluire",
    "defluirebbe": "defluire",
    "defluirebber": "defluire",
    "defluirebbero": "defluire",
    "defluirei": "defluire",
    "defluiremmo": "defluire",
    "defluiremo": "defluire",
    "defluireste": "defluire",
    "defluiresti": "defluire",
    "defluirete": "defluire",
    "defluiron": "defluire",
    "defluirono": "defluire",
    "defluirà": "defluire",
    "defluirò": "defluire",
    "defluisca": "defluire",
    "defluiscan": "defluire",
    "defluiscano": "defluire",
    "defluisce": "defluire",
    "defluisci": "defluire",
    "defluisco": "defluire",
    "defluiscon": "defluire",
    "defluiscono": "defluire",
    "defluisse": "defluire",
    "defluisser": "defluire",
    "defluissero": "defluire",
    "defluissi": "defluire",
    "defluissimo": "defluire",
    "defluiste": "defluire",
    "defluisti": "defluire",
    "defluita": "defluire",
    "defluite": "defluire",
    "defluiti": "defluire",
    "defluito": "defluire",
    "defluiva": "defluire",
    "defluivamo": "defluire",
    "defluivan": "defluire",
    "defluivano": "defluire",
    "defluivate": "defluire",
    "defluivi": "defluire",
    "defluivo": "defluire",
    "deflussi": "deflusso",
    "defluì": "defluire",
    "deforestazioni": "deforestazione",
    "deforma": "deformare",
    "deformai": "deformare",
    "deformammo": "deformare",
    "deforman": "deformare",
    "deformando": "deformare",
    "deformano": "deformare",
    "deformante": "deformare",
    "deformanti": "deformare",
    "deformar": "deformare",
    "deformaron": "deformare",
    "deformarono": "deformare",
    "deformasse": "deformare",
    "deformasser": "deformare",
    "deformassero": "deformare",
    "deformassi": "deformare",
    "deformassimo": "deformare",
    "deformaste": "deformare",
    "deformasti": "deformare",
    "deformata": "deformare",
    "deformate": "deformare",
    "deformati": "deformare",
    "deformato": "deformare",
    "deformava": "deformare",
    "deformavamo": "deformare",
    "deformavan": "deformare",
    "deformavano": "deformare",
    "deformavate": "deformare",
    "deformavi": "deformare",
    "deformavo": "deformare",
    "deformazioni": "deformazione",
    "deformerai": "deformare",
    "deformeran": "deformare",
    "deformeranno": "deformare",
    "deformerebbe": "deformare",
    "deformerebber": "deformare",
    "deformerebbero": "deformare",
    "deformerei": "deformare",
    "deformeremmo": "deformare",
    "deformeremo": "deformare",
    "deformereste": "deformare",
    "deformeresti": "deformare",
    "deformerete": "deformare",
    "deformerà": "deformare",
    "deformerò": "deformare",
    "deformi": "deforme",
    "deformiamo": "deformare",
    "deformiate": "deformare",
    "deformin": "deformare",
    "deformino": "deformare",
    "deformo": "deformare",
    "deformò": "deformare",
    "defrauda": "defraudare",
    "defraudai": "defraudare",
    "defraudammo": "defraudare",
    "defraudan": "defraudare",
    "defraudando": "defraudare",
    "defraudano": "defraudare",
    "defraudante": "defraudare",
    "defraudanti": "defraudare",
    "defraudar": "defraudare",
    "defraudaron": "defraudare",
    "defraudarono": "defraudare",
    "defraudasse": "defraudare",
    "defraudasser": "defraudare",
    "defraudassero": "defraudare",
    "defraudassi": "defraudare",
    "defraudassimo": "defraudare",
    "defraudaste": "defraudare",
    "defraudasti": "defraudare",
    "defraudata": "defraudare",
    "defraudate": "defraudare",
    "defraudati": "defraudare",
    "defraudato": "defraudare",
    "defraudava": "defraudare",
    "defraudavamo": "defraudare",
    "defraudavan": "defraudare",
    "defraudavano": "defraudare",
    "defraudavate": "defraudare",
    "defraudavi": "defraudare",
    "defraudavo": "defraudare",
    "defrauderai": "defraudare",
    "defrauderan": "defraudare",
    "defrauderanno": "defraudare",
    "defrauderebbe": "defraudare",
    "defrauderebber": "defraudare",
    "defrauderebbero": "defraudare",
    "defrauderei": "defraudare",
    "defrauderemmo": "defraudare",
    "defrauderemo": "defraudare",
    "defraudereste": "defraudare",
    "defrauderesti": "defraudare",
    "defrauderete": "defraudare",
    "defrauderà": "defraudare",
    "defrauderò": "defraudare",
    "defraudi": "defraudare",
    "defraudiamo": "defraudare",
    "defraudiate": "defraudare",
    "defraudin": "defraudare",
    "defraudino": "defraudare",
    "defraudo": "defraudare",
    "defraudò": "defraudare",
    "defunta": "defunto",
    "defunte": "defunto",
    "defunti": "defunto",
    "degasperiana": "degasperiano",
    "degasperiane": "degasperiano",
    "degasperiani": "degasperiano",
    "degenera": "degenerare",
    "degenerai": "degenerare",
    "degenerammo": "degenerare",
    "degeneran": "degenerare",
    "degenerando": "degenerare",
    "degenerano": "degenerare",
    "degenerante": "degenerare",
    "degeneranti": "degenerare",
    "degenerar": "degenerare",
    "degeneraron": "degenerare",
    "degenerarono": "degenerare",
    "degenerasse": "degenerare",
    "degenerasser": "degenerare",
    "degenerassero": "degenerare",
    "degenerassi": "degenerare",
    "degenerassimo": "degenerare",
    "degeneraste": "degenerare",
    "degenerasti": "degenerare",
    "degenerata": "degenerato",
    "degenerate": "degenerato",
    "degenerati": "degenerato",
    "degenerativa": "degenerativo",
    "degenerative": "degenerativo",
    "degenerativi": "degenerativo",
    "degenerato": "degenerare",
    "degenerava": "degenerare",
    "degeneravamo": "degenerare",
    "degeneravan": "degenerare",
    "degeneravano": "degenerare",
    "degeneravate": "degenerare",
    "degeneravi": "degenerare",
    "degeneravo": "degenerare",
    "degenerazioni": "degenerazione",
    "degenererai": "degenerare",
    "degenereran": "degenerare",
    "degenereranno": "degenerare",
    "degenererebbe": "degenerare",
    "degenererebber": "degenerare",
    "degenererebbero": "degenerare",
    "degenererei": "degenerare",
    "degenereremmo": "degenerare",
    "degenereremo": "degenerare",
    "degenerereste": "degenerare",
    "degenereresti": "degenerare",
    "degenererete": "degenerare",
    "degenererà": "degenerare",
    "degenererò": "degenerare",
    "degeneri": "degenere",
    "degeneriamo": "degenerare",
    "degeneriate": "degenerare",
    "degenerin": "degenerare",
    "degenerino": "degenerare",
    "degenero": "degenerare",
    "degenerò": "degenerare",
    "degenti": "degente",
    "degenze": "degenza",
    "degli": "del",
    "deglutendo": "deglutire",
    "deglutente": "deglutire",
    "deglutenti": "deglutire",
    "deglutiamo": "deglutire",
    "deglutiate": "deglutire",
    "deglutii": "deglutire",
    "deglutimmo": "deglutire",
    "deglutir": "deglutire",
    "deglutirai": "deglutire",
    "deglutiran": "deglutire",
    "deglutiranno": "deglutire",
    "deglutirebbe": "deglutire",
    "deglutirebber": "deglutire",
    "deglutirebbero": "deglutire",
    "deglutirei": "deglutire",
    "deglutiremmo": "deglutire",
    "deglutiremo": "deglutire",
    "deglutireste": "deglutire",
    "deglutiresti": "deglutire",
    "deglutirete": "deglutire",
    "deglutiron": "deglutire",
    "deglutirono": "deglutire",
    "deglutirà": "deglutire",
    "deglutirò": "deglutire",
    "deglutisca": "deglutire",
    "deglutiscan": "deglutire",
    "deglutiscano": "deglutire",
    "deglutisce": "deglutire",
    "deglutisci": "deglutire",
    "deglutisco": "deglutire",
    "deglutiscon": "deglutire",
    "deglutiscono": "deglutire",
    "deglutisse": "deglutire",
    "deglutisser": "deglutire",
    "deglutissero": "deglutire",
    "deglutissi": "deglutire",
    "deglutissimo": "deglutire",
    "deglutiste": "deglutire",
    "deglutisti": "deglutire",
    "deglutita": "deglutire",
    "deglutite": "deglutire",
    "deglutiti": "deglutire",
    "deglutito": "deglutire",
    "deglutiva": "deglutire",
    "deglutivamo": "deglutire",
    "deglutivan": "deglutire",
    "deglutivano": "deglutire",
    "deglutivate": "deglutire",
    "deglutivi": "deglutire",
    "deglutivo": "deglutire",
    "deglutì": "deglutire",
    "degna": "degno",
    "degnai": "degnare",
    "degnammo": "degnare",
    "degnan": "degnare",
    "degnando": "degnare",
    "degnano": "degnare",
    "degnante": "degnare",
    "degnanti": "degnare",
    "degnar": "degnare",
    "degnaron": "degnare",
    "degnarono": "degnare",
    "degnasse": "degnare",
    "degnasser": "degnare",
    "degnassero": "degnare",
    "degnassi": "degnare",
    "degnassimo": "degnare",
    "degnaste": "degnare",
    "degnasti": "degnare",
    "degnata": "degnare",
    "degnate": "degnare",
    "degnati": "degnare",
    "degnato": "degnare",
    "degnava": "degnare",
    "degnavamo": "degnare",
    "degnavan": "degnare",
    "degnavano": "degnare",
    "degnavate": "degnare",
    "degnavi": "degnare",
    "degnavo": "degnare",
    "degne": "degno",
    "degnerai": "degnare",
    "degneran": "degnare",
    "degneranno": "degnare",
    "degnerebbe": "degnare",
    "degnerebber": "degnare",
    "degnerebbero": "degnare",
    "degnerei": "degnare",
    "degneremmo": "degnare",
    "degneremo": "degnare",
    "degnereste": "degnare",
    "degneresti": "degnare",
    "degnerete": "degnare",
    "degnerà": "degnare",
    "degnerò": "degnare",
    "degni": "degno",
    "degniamo": "degnare",
    "degniate": "degnare",
    "degnin": "degnare",
    "degnino": "degnare",
    "degno": "degnare",
    "degnò": "degnare",
    "degrada": "degradare",
    "degradai": "degradare",
    "degradammo": "degradare",
    "degradan": "degradare",
    "degradando": "degradare",
    "degradano": "degradare",
    "degradante": "degradare",
    "degradanti": "degradare",
    "degradar": "degradare",
    "degradaron": "degradare",
    "degradarono": "degradare",
    "degradasse": "degradare",
    "degradasser": "degradare",
    "degradassero": "degradare",
    "degradassi": "degradare",
    "degradassimo": "degradare",
    "degradaste": "degradare",
    "degradasti": "degradare",
    "degradata": "degradare",
    "degradate": "degradare",
    "degradati": "degradare",
    "degradato": "degradare",
    "degradava": "degradare",
    "degradavamo": "degradare",
    "degradavan": "degradare",
    "degradavano": "degradare",
    "degradavate": "degradare",
    "degradavi": "degradare",
    "degradavo": "degradare",
    "degradazioni": "degradazione",
    "degraderai": "degradare",
    "degraderan": "degradare",
    "degraderanno": "degradare",
    "degraderebbe": "degradare",
    "degraderebber": "degradare",
    "degraderebbero": "degradare",
    "degraderei": "degradare",
    "degraderemmo": "degradare",
    "degraderemo": "degradare",
    "degradereste": "degradare",
    "degraderesti": "degradare",
    "degraderete": "degradare",
    "degraderà": "degradare",
    "degraderò": "degradare",
    "degradi": "degradare",
    "degradiamo": "degradare",
    "degradiate": "degradare",
    "degradin": "degradare",
    "degradino": "degradare",
    "degrado": "degradare",
    "degradò": "degradare",
    "degusta": "degustare",
    "degustai": "degustare",
    "degustammo": "degustare",
    "degustan": "degustare",
    "degustando": "degustare",
    "degustano": "degustare",
    "degustante": "degustare",
    "degustanti": "degustare",
    "degustar": "degustare",
    "degustaron": "degustare",
    "degustarono": "degustare",
    "degustasse": "degustare",
    "degustasser": "degustare",
    "degustassero": "degustare",
    "degustassi": "degustare",
    "degustassimo": "degustare",
    "degustaste": "degustare",
    "degustasti": "degustare",
    "degustata": "degustare",
    "degustate": "degustare",
    "degustati": "degustare",
    "degustato": "degustare",
    "degustava": "degustare",
    "degustavamo": "degustare",
    "degustavan": "degustare",
    "degustavano": "degustare",
    "degustavate": "degustare",
    "degustavi": "degustare",
    "degustavo": "degustare",
    "degustazioni": "degustazione",
    "degusterai": "degustare",
    "degusteran": "degustare",
    "degusteranno": "degustare",
    "degusterebbe": "degustare",
    "degusterebber": "degustare",
    "degusterebbero": "degustare",
    "degusterei": "degustare",
    "degusteremmo": "degustare",
    "degusteremo": "degustare",
    "degustereste": "degustare",
    "degusteresti": "degustare",
    "degusterete": "degustare",
    "degusterà": "degustare",
    "degusterò": "degustare",
    "degusti": "degustare",
    "degustiamo": "degustare",
    "degustiate": "degustare",
    "degustin": "degustare",
    "degustino": "degustare",
    "degusto": "degustare",
    "degustò": "degustare",
    "dei": "dio",
    "deidrata": "deidratare",
    "deidratai": "deidratare",
    "deidratammo": "deidratare",
    "deidratan": "deidratare",
    "deidratando": "deidratare",
    "deidratano": "deidratare",
    "deidratante": "deidratare",
    "deidratanti": "deidratare",
    "deidratar": "deidratare",
    "deidrataron": "deidratare",
    "deidratarono": "deidratare",
    "deidratasse": "deidratare",
    "deidratasser": "deidratare",
    "deidratassero": "deidratare",
    "deidratassi": "deidratare",
    "deidratassimo": "deidratare",
    "deidrataste": "deidratare",
    "deidratasti": "deidratare",
    "deidratata": "deidratare",
    "deidratate": "deidratare",
    "deidratati": "deidratare",
    "deidratato": "deidratare",
    "deidratava": "deidratare",
    "deidratavamo": "deidratare",
    "deidratavan": "deidratare",
    "deidratavano": "deidratare",
    "deidratavate": "deidratare",
    "deidratavi": "deidratare",
    "deidratavo": "deidratare",
    "deidraterai": "deidratare",
    "deidrateran": "deidratare",
    "deidrateranno": "deidratare",
    "deidraterebbe": "deidratare",
    "deidraterebber": "deidratare",
    "deidraterebbero": "deidratare",
    "deidraterei": "deidratare",
    "deidrateremmo": "deidratare",
    "deidrateremo": "deidratare",
    "deidratereste": "deidratare",
    "deidrateresti": "deidratare",
    "deidraterete": "deidratare",
    "deidraterà": "deidratare",
    "deidraterò": "deidratare",
    "deidrati": "deidratare",
    "deidratiamo": "deidratare",
    "deidratiate": "deidratare",
    "deidratin": "deidratare",
    "deidratino": "deidratare",
    "deidrato": "deidratare",
    "deidratò": "deidratare",
    "deiezioni": "deiezione",
    "deifica": "deificare",
    "deificai": "deificare",
    "deificammo": "deificare",
    "deifican": "deificare",
    "deificando": "deificare",
    "deificano": "deificare",
    "deificante": "deificare",
    "deificanti": "deificare",
    "deificar": "deificare",
    "deificaron": "deificare",
    "deificarono": "deificare",
    "deificasse": "deificare",
    "deificasser": "deificare",
    "deificassero": "deificare",
    "deificassi": "deificare",
    "deificassimo": "deificare",
    "deificaste": "deificare",
    "deificasti": "deificare",
    "deificata": "deificare",
    "deificate": "deificare",
    "deificati": "deificare",
    "deificato": "deificare",
    "deificava": "deificare",
    "deificavamo": "deificare",
    "deificavan": "deificare",
    "deificavano": "deificare",
    "deificavate": "deificare",
    "deificavi": "deificare",
    "deificavo": "deificare",
    "deificherai": "deificare",
    "deificheran": "deificare",
    "deificheranno": "deificare",
    "deificherebbe": "deificare",
    "deificherebber": "deificare",
    "deificherebbero": "deificare",
    "deificherei": "deificare",
    "deificheremmo": "deificare",
    "deificheremo": "deificare",
    "deifichereste": "deificare",
    "deificheresti": "deificare",
    "deificherete": "deificare",
    "deificherà": "deificare",
    "deificherò": "deificare",
    "deifichi": "deificare",
    "deifichiamo": "deificare",
    "deifichiate": "deificare",
    "deifichin": "deificare",
    "deifichino": "deificare",
    "deifico": "deificare",
    "deificò": "deificare",
    "deindicizza": "deindicizzare",
    "deindicizzai": "deindicizzare",
    "deindicizzammo": "deindicizzare",
    "deindicizzan": "deindicizzare",
    "deindicizzando": "deindicizzare",
    "deindicizzano": "deindicizzare",
    "deindicizzante": "deindicizzare",
    "deindicizzanti": "deindicizzare",
    "deindicizzar": "deindicizzare",
    "deindicizzaron": "deindicizzare",
    "deindicizzarono": "deindicizzare",
    "deindicizzasse": "deindicizzare",
    "deindicizzasser": "deindicizzare",
    "deindicizzassero": "deindicizzare",
    "deindicizzassi": "deindicizzare",
    "deindicizzassimo": "deindicizzare",
    "deindicizzaste": "deindicizzare",
    "deindicizzasti": "deindicizzare",
    "deindicizzata": "deindicizzare",
    "deindicizzate": "deindicizzare",
    "deindicizzati": "deindicizzare",
    "deindicizzato": "deindicizzare",
    "deindicizzava": "deindicizzare",
    "deindicizzavamo": "deindicizzare",
    "deindicizzavan": "deindicizzare",
    "deindicizzavano": "deindicizzare",
    "deindicizzavate": "deindicizzare",
    "deindicizzavi": "deindicizzare",
    "deindicizzavo": "deindicizzare",
    "deindicizzerai": "deindicizzare",
    "deindicizzeran": "deindicizzare",
    "deindicizzeranno": "deindicizzare",
    "deindicizzerebbe": "deindicizzare",
    "deindicizzerebber": "deindicizzare",
    "deindicizzerebbero": "deindicizzare",
    "deindicizzerei": "deindicizzare",
    "deindicizzeremmo": "deindicizzare",
    "deindicizzeremo": "deindicizzare",
    "deindicizzereste": "deindicizzare",
    "deindicizzeresti": "deindicizzare",
    "deindicizzerete": "deindicizzare",
    "deindicizzerà": "deindicizzare",
    "deindicizzerò": "deindicizzare",
    "deindicizzi": "deindicizzare",
    "deindicizziamo": "deindicizzare",
    "deindicizziate": "deindicizzare",
    "deindicizzin": "deindicizzare",
    "deindicizzino": "deindicizzare",
    "deindicizzo": "deindicizzare",
    "deindicizzò": "deindicizzare",
    "deindustrializzata": "deindustrializzato",
    "deindustrializzate": "deindustrializzato",
    "deindustrializzati": "deindustrializzato",
    "deindustrializzazioni": "deindustrializzazione",
    "delatori": "delatore",
    "delazioni": "delazione",
    "delega": "delegare",
    "delegai": "delegare",
    "delegammo": "delegare",
    "delegan": "delegare",
    "delegando": "delegare",
    "delegano": "delegare",
    "delegante": "delegare",
    "deleganti": "delegare",
    "delegar": "delegare",
    "delegaron": "delegare",
    "delegarono": "delegare",
    "delegasse": "delegare",
    "delegasser": "delegare",
    "delegassero": "delegare",
    "delegassi": "delegare",
    "delegassimo": "delegare",
    "delegaste": "delegare",
    "delegasti": "delegare",
    "delegata": "delegato",
    "delegate": "delegato",
    "delegati": "delegato",
    "delegato": "delegare",
    "delegava": "delegare",
    "delegavamo": "delegare",
    "delegavan": "delegare",
    "delegavano": "delegare",
    "delegavate": "delegare",
    "delegavi": "delegare",
    "delegavo": "delegare",
    "delegazioni": "delegazione",
    "deleghe": "delega",
    "delegherai": "delegare",
    "delegheran": "delegare",
    "delegheranno": "delegare",
    "delegherebbe": "delegare",
    "delegherebber": "delegare",
    "delegherebbero": "delegare",
    "delegherei": "delegare",
    "delegheremmo": "delegare",
    "delegheremo": "delegare",
    "deleghereste": "delegare",
    "delegheresti": "delegare",
    "delegherete": "delegare",
    "delegherà": "delegare",
    "delegherò": "delegare",
    "deleghi": "delegare",
    "deleghiamo": "delegare",
    "deleghiate": "delegare",
    "deleghin": "delegare",
    "deleghino": "delegare",
    "delegificazioni": "delegificazione",
    "delegittima": "delegittimare",
    "delegittimai": "delegittimare",
    "delegittimammo": "delegittimare",
    "delegittiman": "delegittimare",
    "delegittimando": "delegittimare",
    "delegittimano": "delegittimare",
    "delegittimante": "delegittimare",
    "delegittimanti": "delegittimare",
    "delegittimar": "delegittimare",
    "delegittimaron": "delegittimare",
    "delegittimarono": "delegittimare",
    "delegittimasse": "delegittimare",
    "delegittimasser": "delegittimare",
    "delegittimassero": "delegittimare",
    "delegittimassi": "delegittimare",
    "delegittimassimo": "delegittimare",
    "delegittimaste": "delegittimare",
    "delegittimasti": "delegittimare",
    "delegittimata": "delegittimare",
    "delegittimate": "delegittimare",
    "delegittimati": "delegittimare",
    "delegittimato": "delegittimare",
    "delegittimava": "delegittimare",
    "delegittimavamo": "delegittimare",
    "delegittimavan": "delegittimare",
    "delegittimavano": "delegittimare",
    "delegittimavate": "delegittimare",
    "delegittimavi": "delegittimare",
    "delegittimavo": "delegittimare",
    "delegittimazioni": "delegittimazione",
    "delegittimerai": "delegittimare",
    "delegittimeran": "delegittimare",
    "delegittimeranno": "delegittimare",
    "delegittimerebbe": "delegittimare",
    "delegittimerebber": "delegittimare",
    "delegittimerebbero": "delegittimare",
    "delegittimerei": "delegittimare",
    "delegittimeremmo": "delegittimare",
    "delegittimeremo": "delegittimare",
    "delegittimereste": "delegittimare",
    "delegittimeresti": "delegittimare",
    "delegittimerete": "delegittimare",
    "delegittimerà": "delegittimare",
    "delegittimerò": "delegittimare",
    "delegittimi": "delegittimare",
    "delegittimiamo": "delegittimare",
    "delegittimiate": "delegittimare",
    "delegittimin": "delegittimare",
    "delegittimino": "delegittimare",
    "delegittimo": "delegittimare",
    "delegittimò": "delegittimare",
    "delego": "delegare",
    "delegò": "delegare",
    "deleteri": "deleterio",
    "deleteria": "deleterio",
    "deleterie": "deleterio",
    "delfini": "delfino",
    "deliba": "delibare",
    "delibai": "delibare",
    "delibammo": "delibare",
    "deliban": "delibare",
    "delibando": "delibare",
    "delibano": "delibare",
    "delibante": "delibare",
    "delibanti": "delibare",
    "delibar": "delibare",
    "delibaron": "delibare",
    "delibarono": "delibare",
    "delibasse": "delibare",
    "delibasser": "delibare",
    "delibassero": "delibare",
    "delibassi": "delibare",
    "delibassimo": "delibare",
    "delibaste": "delibare",
    "delibasti": "delibare",
    "delibata": "delibare",
    "delibate": "delibare",
    "delibati": "delibare",
    "delibato": "delibare",
    "delibava": "delibare",
    "delibavamo": "delibare",
    "delibavan": "delibare",
    "delibavano": "delibare",
    "delibavate": "delibare",
    "delibavi": "delibare",
    "delibavo": "delibare",
    "delibazioni": "delibazione",
    "delibera": "deliberare",
    "deliberai": "deliberare",
    "deliberammo": "deliberare",
    "deliberan": "deliberare",
    "deliberando": "deliberare",
    "deliberanno": "delibare",
    "deliberano": "deliberare",
    "deliberante": "deliberare",
    "deliberanti": "deliberare",
    "deliberar": "deliberare",
    "deliberaron": "deliberare",
    "deliberarono": "deliberare",
    "deliberasse": "deliberare",
    "deliberasser": "deliberare",
    "deliberassero": "deliberare",
    "deliberassi": "deliberare",
    "deliberassimo": "deliberare",
    "deliberaste": "deliberare",
    "deliberasti": "deliberare",
    "deliberata": "deliberato",
    "deliberate": "deliberato",
    "deliberati": "deliberato",
    "deliberativa": "deliberativo",
    "deliberative": "deliberativo",
    "deliberativi": "deliberativo",
    "deliberato": "deliberare",
    "deliberava": "deliberare",
    "deliberavamo": "deliberare",
    "deliberavan": "deliberare",
    "deliberavano": "deliberare",
    "deliberavate": "deliberare",
    "deliberavi": "deliberare",
    "deliberavo": "deliberare",
    "deliberazioni": "deliberazione",
    "delibere": "delibera",
    "deliberebbe": "delibare",
    "deliberebber": "delibare",
    "deliberebbero": "delibare",
    "deliberei": "delibare",
    "deliberemmo": "delibare",
    "deliberemo": "delibare",
    "delibererai": "deliberare",
    "delibereran": "deliberare",
    "delibereranno": "deliberare",
    "delibererebbe": "deliberare",
    "delibererebber": "deliberare",
    "delibererebbero": "deliberare",
    "delibererei": "deliberare",
    "delibereremmo": "deliberare",
    "delibereremo": "deliberare",
    "deliberereste": "deliberare",
    "delibereresti": "deliberare",
    "delibererete": "deliberare",
    "delibererà": "deliberare",
    "delibererò": "deliberare",
    "delibereste": "delibare",
    "deliberesti": "delibare",
    "deliberete": "delibare",
    "deliberi": "deliberare",
    "deliberiamo": "deliberare",
    "deliberiate": "deliberare",
    "deliberin": "deliberare",
    "deliberino": "deliberare",
    "delibero": "deliberare",
    "deliberà": "delibare",
    "deliberò": "deliberare",
    "delibi": "delibare",
    "delibiamo": "delibare",
    "delibiate": "delibare",
    "delibin": "delibare",
    "delibino": "delibare",
    "delibo": "delibare",
    "delibò": "delibare",
    "delicata": "delicato",
    "delicate": "delicato",
    "delicatezze": "delicatezza",
    "delicati": "delicato",
    "delimita": "delimitare",
    "delimitai": "delimitare",
    "delimitammo": "delimitare",
    "delimitan": "delimitare",
    "delimitando": "delimitare",
    "delimitano": "delimitare",
    "delimitante": "delimitare",
    "delimitanti": "delimitare",
    "delimitar": "delimitare",
    "delimitaron": "delimitare",
    "delimitarono": "delimitare",
    "delimitasse": "delimitare",
    "delimitasser": "delimitare",
    "delimitassero": "delimitare",
    "delimitassi": "delimitare",
    "delimitassimo": "delimitare",
    "delimitaste": "delimitare",
    "delimitasti": "delimitare",
    "delimitata": "delimitare",
    "delimitate": "delimitare",
    "delimitati": "delimitare",
    "delimitato": "delimitare",
    "delimitava": "delimitare",
    "delimitavamo": "delimitare",
    "delimitavan": "delimitare",
    "delimitavano": "delimitare",
    "delimitavate": "delimitare",
    "delimitavi": "delimitare",
    "delimitavo": "delimitare",
    "delimitazioni": "delimitazione",
    "delimiterai": "delimitare",
    "delimiteran": "delimitare",
    "delimiteranno": "delimitare",
    "delimiterebbe": "delimitare",
    "delimiterebber": "delimitare",
    "delimiterebbero": "delimitare",
    "delimiterei": "delimitare",
    "delimiteremmo": "delimitare",
    "delimiteremo": "delimitare",
    "delimitereste": "delimitare",
    "delimiteresti": "delimitare",
    "delimiterete": "delimitare",
    "delimiterà": "delimitare",
    "delimiterò": "delimitare",
    "delimiti": "delimitare",
    "delimitiamo": "delimitare",
    "delimitiate": "delimitare",
    "delimitin": "delimitare",
    "delimitino": "delimitare",
    "delimito": "delimitare",
    "delimitò": "delimitare",
    "delinea": "delineare",
    "delineai": "delineare",
    "delineammo": "delineare",
    "delinean": "delineare",
    "delineando": "delineare",
    "delineano": "delineare",
    "delineante": "delineare",
    "delineanti": "delineare",
    "delinear": "delineare",
    "delinearon": "delineare",
    "delinearono": "delineare",
    "delineasse": "delineare",
    "delineasser": "delineare",
    "delineassero": "delineare",
    "delineassi": "delineare",
    "delineassimo": "delineare",
    "delineaste": "delineare",
    "delineasti": "delineare",
    "delineata": "delineare",
    "delineate": "delineare",
    "delineati": "delineare",
    "delineato": "delineare",
    "delineava": "delineare",
    "delineavamo": "delineare",
    "delineavan": "delineare",
    "delineavano": "delineare",
    "delineavate": "delineare",
    "delineavi": "delineare",
    "delineavo": "delineare",
    "delineerai": "delineare",
    "delineeran": "delineare",
    "delineeranno": "delineare",
    "delineerebbe": "delineare",
    "delineerebber": "delineare",
    "delineerebbero": "delineare",
    "delineerei": "delineare",
    "delineeremmo": "delineare",
    "delineeremo": "delineare",
    "delineereste": "delineare",
    "delineeresti": "delineare",
    "delineerete": "delineare",
    "delineerà": "delineare",
    "delineerò": "delineare",
    "delinei": "delineare",
    "delineiamo": "delineare",
    "delineiate": "delineare",
    "delinein": "delineare",
    "delineino": "delineare",
    "delineo": "delineare",
    "delineò": "delineare",
    "delinqua": "delinquere",
    "delinquan": "delinquere",
    "delinquano": "delinquere",
    "delinque": "delinquere",
    "delinquei": "delinquere",
    "delinquemmo": "delinquere",
    "delinquendo": "delinquere",
    "delinquente": "delinquere",
    "delinquenti": "delinquere",
    "delinquenze": "delinquenza",
    "delinquenziali": "delinquenziale",
    "delinquer": "delinquere",
    "delinquerai": "delinquere",
    "delinqueran": "delinquere",
    "delinqueranno": "delinquere",
    "delinquerebbe": "delinquere",
    "delinquerebber": "delinquere",
    "delinquerebbero": "delinquere",
    "delinquerei": "delinquere",
    "delinqueremmo": "delinquere",
    "delinqueremo": "delinquere",
    "delinquereste": "delinquere",
    "delinqueresti": "delinquere",
    "delinquerete": "delinquere",
    "delinqueron": "delinquere",
    "delinquerono": "delinquere",
    "delinquerà": "delinquere",
    "delinquerò": "delinquere",
    "delinquesse": "delinquere",
    "delinquesser": "delinquere",
    "delinquessero": "delinquere",
    "delinquessi": "delinquere",
    "delinquessimo": "delinquere",
    "delinqueste": "delinquere",
    "delinquesti": "delinquere",
    "delinquete": "delinquere",
    "delinqueva": "delinquere",
    "delinquevamo": "delinquere",
    "delinquevan": "delinquere",
    "delinquevano": "delinquere",
    "delinquevate": "delinquere",
    "delinquevi": "delinquere",
    "delinquevo": "delinquere",
    "delinqui": "delinquere",
    "delinquiamo": "delinquere",
    "delinquiate": "delinquere",
    "delinquo": "delinquere",
    "delinquon": "delinquere",
    "delinquono": "delinquere",
    "delinquuta": "delinquere",
    "delinquute": "delinquere",
    "delinquuti": "delinquere",
    "delinquuto": "delinquere",
    "delinquè": "delinquere",
    "delira": "delirare",
    "delirai": "delirare",
    "delirammo": "delirare",
    "deliran": "delirare",
    "delirando": "delirare",
    "delirano": "delirare",
    "delirante": "delirare",
    "deliranti": "delirare",
    "delirar": "delirare",
    "deliraron": "delirare",
    "delirarono": "delirare",
    "delirasse": "delirare",
    "delirasser": "delirare",
    "delirassero": "delirare",
    "delirassi": "delirare",
    "delirassimo": "delirare",
    "deliraste": "delirare",
    "delirasti": "delirare",
    "delirata": "delirare",
    "delirate": "delirare",
    "delirati": "delirare",
    "delirato": "delirare",
    "delirava": "delirare",
    "deliravamo": "delirare",
    "deliravan": "delirare",
    "deliravano": "delirare",
    "deliravate": "delirare",
    "deliravi": "delirare",
    "deliravo": "delirare",
    "delirerai": "delirare",
    "delireran": "delirare",
    "delireranno": "delirare",
    "delirerebbe": "delirare",
    "delirerebber": "delirare",
    "delirerebbero": "delirare",
    "delirerei": "delirare",
    "delireremmo": "delirare",
    "delireremo": "delirare",
    "delirereste": "delirare",
    "delireresti": "delirare",
    "delirerete": "delirare",
    "delirerà": "delirare",
    "delirerò": "delirare",
    "deliri": "delirio",
    "deliriamo": "delirare",
    "deliriate": "delirare",
    "delirin": "delirare",
    "delirino": "delirare",
    "deliro": "delirare",
    "delirò": "delirare",
    "delitti": "delitto",
    "delittuosa": "delittuoso",
    "delittuose": "delittuoso",
    "delittuosi": "delittuoso",
    "delizi": "deliziare",
    "delizia": "deliziare",
    "deliziai": "deliziare",
    "deliziammo": "deliziare",
    "deliziamo": "deliziare",
    "delizian": "deliziare",
    "deliziando": "deliziare",
    "deliziano": "deliziare",
    "deliziante": "deliziare",
    "delizianti": "deliziare",
    "deliziar": "deliziare",
    "deliziaron": "deliziare",
    "deliziarono": "deliziare",
    "deliziasse": "deliziare",
    "deliziasser": "deliziare",
    "deliziassero": "deliziare",
    "deliziassi": "deliziare",
    "deliziassimo": "deliziare",
    "deliziaste": "deliziare",
    "deliziasti": "deliziare",
    "deliziata": "deliziare",
    "deliziate": "deliziare",
    "deliziati": "deliziare",
    "deliziato": "deliziare",
    "deliziava": "deliziare",
    "deliziavamo": "deliziare",
    "deliziavan": "deliziare",
    "deliziavano": "deliziare",
    "deliziavate": "deliziare",
    "deliziavi": "deliziare",
    "deliziavo": "deliziare",
    "delizie": "delizia",
    "delizierai": "deliziare",
    "delizieran": "deliziare",
    "delizieranno": "deliziare",
    "delizierebbe": "deliziare",
    "delizierebber": "deliziare",
    "delizierebbero": "deliziare",
    "delizierei": "deliziare",
    "delizieremmo": "deliziare",
    "delizieremo": "deliziare",
    "deliziereste": "deliziare",
    "delizieresti": "deliziare",
    "delizierete": "deliziare",
    "delizierà": "deliziare",
    "delizierò": "deliziare",
    "delizin": "deliziare",
    "delizino": "deliziare",
    "delizio": "deliziare",
    "deliziosa": "delizioso",
    "deliziose": "delizioso",
    "deliziosi": "delizioso",
    "deliziò": "deliziare",
    "dell'": "della",
    "delle": "della",
    "dello": "del",
    "delocalizza": "delocalizzare",
    "delocalizzai": "delocalizzare",
    "delocalizzammo": "delocalizzare",
    "delocalizzan": "delocalizzare",
    "delocalizzando": "delocalizzare",
    "delocalizzano": "delocalizzare",
    "delocalizzante": "delocalizzare",
    "delocalizzanti": "delocalizzare",
    "delocalizzar": "delocalizzare",
    "delocalizzaron": "delocalizzare",
    "delocalizzarono": "delocalizzare",
    "delocalizzasse": "delocalizzare",
    "delocalizzasser": "delocalizzare",
    "delocalizzassero": "delocalizzare",
    "delocalizzassi": "delocalizzare",
    "delocalizzassimo": "delocalizzare",
    "delocalizzaste": "delocalizzare",
    "delocalizzasti": "delocalizzare",
    "delocalizzata": "delocalizzare",
    "delocalizzate": "delocalizzare",
    "delocalizzati": "delocalizzare",
    "delocalizzato": "delocalizzare",
    "delocalizzava": "delocalizzare",
    "delocalizzavamo": "delocalizzare",
    "delocalizzavan": "delocalizzare",
    "delocalizzavano": "delocalizzare",
    "delocalizzavate": "delocalizzare",
    "delocalizzavi": "delocalizzare",
    "delocalizzavo": "delocalizzare",
    "delocalizzazioni": "delocalizzazione",
    "delocalizzerai": "delocalizzare",
    "delocalizzeran": "delocalizzare",
    "delocalizzeranno": "delocalizzare",
    "delocalizzerebbe": "delocalizzare",
    "delocalizzerebber": "delocalizzare",
    "delocalizzerebbero": "delocalizzare",
    "delocalizzerei": "delocalizzare",
    "delocalizzeremmo": "delocalizzare",
    "delocalizzeremo": "delocalizzare",
    "delocalizzereste": "delocalizzare",
    "delocalizzeresti": "delocalizzare",
    "delocalizzerete": "delocalizzare",
    "delocalizzerà": "delocalizzare",
    "delocalizzerò": "delocalizzare",
    "delocalizzi": "delocalizzare",
    "delocalizziamo": "delocalizzare",
    "delocalizziate": "delocalizzare",
    "delocalizzin": "delocalizzare",
    "delocalizzino": "delocalizzare",
    "delocalizzo": "delocalizzare",
    "delocalizzò": "delocalizzare",
    "deltaplani": "deltaplano",
    "delucida": "delucidare",
    "delucidai": "delucidare",
    "delucidammo": "delucidare",
    "delucidan": "delucidare",
    "delucidando": "delucidare",
    "delucidano": "delucidare",
    "delucidante": "delucidare",
    "delucidanti": "delucidare",
    "delucidar": "delucidare",
    "delucidaron": "delucidare",
    "delucidarono": "delucidare",
    "delucidasse": "delucidare",
    "delucidasser": "delucidare",
    "delucidassero": "delucidare",
    "delucidassi": "delucidare",
    "delucidassimo": "delucidare",
    "delucidaste": "delucidare",
    "delucidasti": "delucidare",
    "delucidata": "delucidare",
    "delucidate": "delucidare",
    "delucidati": "delucidare",
    "delucidato": "delucidare",
    "delucidava": "delucidare",
    "delucidavamo": "delucidare",
    "delucidavan": "delucidare",
    "delucidavano": "delucidare",
    "delucidavate": "delucidare",
    "delucidavi": "delucidare",
    "delucidavo": "delucidare",
    "delucidazioni": "delucidazione",
    "deluciderai": "delucidare",
    "delucideran": "delucidare",
    "delucideranno": "delucidare",
    "deluciderebbe": "delucidare",
    "deluciderebber": "delucidare",
    "deluciderebbero": "delucidare",
    "deluciderei": "delucidare",
    "delucideremmo": "delucidare",
    "delucideremo": "delucidare",
    "delucidereste": "delucidare",
    "delucideresti": "delucidare",
    "deluciderete": "delucidare",
    "deluciderà": "delucidare",
    "deluciderò": "delucidare",
    "delucidi": "delucidare",
    "delucidiamo": "delucidare",
    "delucidiate": "delucidare",
    "delucidin": "delucidare",
    "delucidino": "delucidare",
    "delucido": "delucidare",
    "delucidò": "delucidare",
    "deluda": "deludere",
    "deludan": "deludere",
    "deludano": "deludere",
    "delude": "deludere",
    "deludemmo": "deludere",
    "deludendo": "deludere",
    "deludente": "deludere",
    "deludenti": "deludere",
    "deluder": "deludere",
    "deluderai": "deludere",
    "deluderan": "deludere",
    "deluderanno": "deludere",
    "deluderebbe": "deludere",
    "deluderebber": "deludere",
    "deluderebbero": "deludere",
    "deluderei": "deludere",
    "deluderemmo": "deludere",
    "deluderemo": "deludere",
    "deludereste": "deludere",
    "deluderesti": "deludere",
    "deluderete": "deludere",
    "deluderà": "deludere",
    "deluderò": "deludere",
    "deludesse": "deludere",
    "deludesser": "deludere",
    "deludessero": "deludere",
    "deludessi": "deludere",
    "deludessimo": "deludere",
    "deludeste": "deludere",
    "deludesti": "deludere",
    "deludete": "deludere",
    "deludeva": "deludere",
    "deludevamo": "deludere",
    "deludevan": "deludere",
    "deludevano": "deludere",
    "deludevate": "deludere",
    "deludevi": "deludere",
    "deludevo": "deludere",
    "deludi": "deludere",
    "deludiamo": "deludere",
    "deludiate": "deludere",
    "deludo": "deludere",
    "deludon": "deludere",
    "deludono": "deludere",
    "delusa": "deluso",
    "deluse": "deluso",
    "deluser": "deludere",
    "delusero": "deludere",
    "delusi": "deluso",
    "delusioni": "delusione",
    "deluso": "deludere",
    "demagoghi": "demagogo",
    "demagogica": "demagogico",
    "demagogiche": "demagogico",
    "demagogici": "demagogico",
    "demagogie": "demagogia",
    "demanda": "demandare",
    "demandai": "demandare",
    "demandammo": "demandare",
    "demandan": "demandare",
    "demandando": "demandare",
    "demandano": "demandare",
    "demandante": "demandare",
    "demandanti": "demandare",
    "demandar": "demandare",
    "demandaron": "demandare",
    "demandarono": "demandare",
    "demandasse": "demandare",
    "demandasser": "demandare",
    "demandassero": "demandare",
    "demandassi": "demandare",
    "demandassimo": "demandare",
    "demandaste": "demandare",
    "demandasti": "demandare",
    "demandata": "demandare",
    "demandate": "demandare",
    "demandati": "demandare",
    "demandato": "demandare",
    "demandava": "demandare",
    "demandavamo": "demandare",
    "demandavan": "demandare",
    "demandavano": "demandare",
    "demandavate": "demandare",
    "demandavi": "demandare",
    "demandavo": "demandare",
    "demanderai": "demandare",
    "demanderan": "demandare",
    "demanderanno": "demandare",
    "demanderebbe": "demandare",
    "demanderebber": "demandare",
    "demanderebbero": "demandare",
    "demanderei": "demandare",
    "demanderemmo": "demandare",
    "demanderemo": "demandare",
    "demandereste": "demandare",
    "demanderesti": "demandare",
    "demanderete": "demandare",
    "demanderà": "demandare",
    "demanderò": "demandare",
    "demandi": "demandare",
    "demandiamo": "demandare",
    "demandiate": "demandare",
    "demandin": "demandare",
    "demandino": "demandare",
    "demando": "demandare",
    "demandò": "demandare",
    "demani": "demanio",
    "demaniali": "demaniale",
    "demarca": "demarcare",
    "demarcai": "demarcare",
    "demarcammo": "demarcare",
    "demarcan": "demarcare",
    "demarcando": "demarcare",
    "demarcano": "demarcare",
    "demarcante": "demarcare",
    "demarcanti": "demarcare",
    "demarcar": "demarcare",
    "demarcaron": "demarcare",
    "demarcarono": "demarcare",
    "demarcasse": "demarcare",
    "demarcasser": "demarcare",
    "demarcassero": "demarcare",
    "demarcassi": "demarcare",
    "demarcassimo": "demarcare",
    "demarcaste": "demarcare",
    "demarcasti": "demarcare",
    "demarcata": "demarcare",
    "demarcate": "demarcare",
    "demarcati": "demarcare",
    "demarcato": "demarcare",
    "demarcava": "demarcare",
    "demarcavamo": "demarcare",
    "demarcavan": "demarcare",
    "demarcavano": "demarcare",
    "demarcavate": "demarcare",
    "demarcavi": "demarcare",
    "demarcavo": "demarcare",
    "demarcazioni": "demarcazione",
    "demarcherai": "demarcare",
    "demarcheran": "demarcare",
    "demarcheranno": "demarcare",
    "demarcherebbe": "demarcare",
    "demarcherebber": "demarcare",
    "demarcherebbero": "demarcare",
    "demarcherei": "demarcare",
    "demarcheremmo": "demarcare",
    "demarcheremo": "demarcare",
    "demarchereste": "demarcare",
    "demarcheresti": "demarcare",
    "demarcherete": "demarcare",
    "demarcherà": "demarcare",
    "demarcherò": "demarcare",
    "demarchi": "demarcare",
    "demarchiamo": "demarcare",
    "demarchiate": "demarcare",
    "demarchin": "demarcare",
    "demarchino": "demarcare",
    "demarco": "demarcare",
    "demarcò": "demarcare",
    "demartiniana": "demartiniano",
    "demartiniane": "demartiniano",
    "demartiniani": "demartiniano",
    "dementi": "demente",
    "demenze": "demenza",
    "demenziali": "demenziale",
    "demerita": "demeritare",
    "demeritai": "demeritare",
    "demeritammo": "demeritare",
    "demeritan": "demeritare",
    "demeritando": "demeritare",
    "demeritano": "demeritare",
    "demeritante": "demeritare",
    "demeritanti": "demeritare",
    "demeritar": "demeritare",
    "demeritaron": "demeritare",
    "demeritarono": "demeritare",
    "demeritasse": "demeritare",
    "demeritasser": "demeritare",
    "demeritassero": "demeritare",
    "demeritassi": "demeritare",
    "demeritassimo": "demeritare",
    "demeritaste": "demeritare",
    "demeritasti": "demeritare",
    "demeritata": "demeritare",
    "demeritate": "demeritare",
    "demeritati": "demeritare",
    "demeritato": "demeritare",
    "demeritava": "demeritare",
    "demeritavamo": "demeritare",
    "demeritavan": "demeritare",
    "demeritavano": "demeritare",
    "demeritavate": "demeritare",
    "demeritavi": "demeritare",
    "demeritavo": "demeritare",
    "demeriterai": "demeritare",
    "demeriteran": "demeritare",
    "demeriteranno": "demeritare",
    "demeriterebbe": "demeritare",
    "demeriterebber": "demeritare",
    "demeriterebbero": "demeritare",
    "demeriterei": "demeritare",
    "demeriteremmo": "demeritare",
    "demeriteremo": "demeritare",
    "demeritereste": "demeritare",
    "demeriteresti": "demeritare",
    "demeriterete": "demeritare",
    "demeriterà": "demeritare",
    "demeriterò": "demeritare",
    "demeriti": "demerito",
    "demeritiamo": "demeritare",
    "demeritiate": "demeritare",
    "demeritin": "demeritare",
    "demeritino": "demeritare",
    "demerito": "demeritare",
    "demeritò": "demeritare",
    "demilitarizza": "demilitarizzare",
    "demilitarizzai": "demilitarizzare",
    "demilitarizzammo": "demilitarizzare",
    "demilitarizzan": "demilitarizzare",
    "demilitarizzando": "demilitarizzare",
    "demilitarizzano": "demilitarizzare",
    "demilitarizzante": "demilitarizzare",
    "demilitarizzanti": "demilitarizzare",
    "demilitarizzar": "demilitarizzare",
    "demilitarizzaron": "demilitarizzare",
    "demilitarizzarono": "demilitarizzare",
    "demilitarizzasse": "demilitarizzare",
    "demilitarizzasser": "demilitarizzare",
    "demilitarizzassero": "demilitarizzare",
    "demilitarizzassi": "demilitarizzare",
    "demilitarizzassimo": "demilitarizzare",
    "demilitarizzaste": "demilitarizzare",
    "demilitarizzasti": "demilitarizzare",
    "demilitarizzata": "demilitarizzare",
    "demilitarizzate": "demilitarizzare",
    "demilitarizzati": "demilitarizzare",
    "demilitarizzato": "demilitarizzare",
    "demilitarizzava": "demilitarizzare",
    "demilitarizzavamo": "demilitarizzare",
    "demilitarizzavan": "demilitarizzare",
    "demilitarizzavano": "demilitarizzare",
    "demilitarizzavate": "demilitarizzare",
    "demilitarizzavi": "demilitarizzare",
    "demilitarizzavo": "demilitarizzare",
    "demilitarizzerai": "demilitarizzare",
    "demilitarizzeran": "demilitarizzare",
    "demilitarizzeranno": "demilitarizzare",
    "demilitarizzerebbe": "demilitarizzare",
    "demilitarizzerebber": "demilitarizzare",
    "demilitarizzerebbero": "demilitarizzare",
    "demilitarizzerei": "demilitarizzare",
    "demilitarizzeremmo": "demilitarizzare",
    "demilitarizzeremo": "demilitarizzare",
    "demilitarizzereste": "demilitarizzare",
    "demilitarizzeresti": "demilitarizzare",
    "demilitarizzerete": "demilitarizzare",
    "demilitarizzerà": "demilitarizzare",
    "demilitarizzerò": "demilitarizzare",
    "demilitarizzi": "demilitarizzare",
    "demilitarizziamo": "demilitarizzare",
    "demilitarizziate": "demilitarizzare",
    "demilitarizzin": "demilitarizzare",
    "demilitarizzino": "demilitarizzare",
    "demilitarizzo": "demilitarizzare",
    "demilitarizzò": "demilitarizzare",
    "demineralizza": "demineralizzare",
    "demineralizzai": "demineralizzare",
    "demineralizzammo": "demineralizzare",
    "demineralizzan": "demineralizzare",
    "demineralizzando": "demineralizzare",
    "demineralizzano": "demineralizzare",
    "demineralizzante": "demineralizzare",
    "demineralizzanti": "demineralizzare",
    "demineralizzar": "demineralizzare",
    "demineralizzaron": "demineralizzare",
    "demineralizzarono": "demineralizzare",
    "demineralizzasse": "demineralizzare",
    "demineralizzasser": "demineralizzare",
    "demineralizzassero": "demineralizzare",
    "demineralizzassi": "demineralizzare",
    "demineralizzassimo": "demineralizzare",
    "demineralizzaste": "demineralizzare",
    "demineralizzasti": "demineralizzare",
    "demineralizzata": "demineralizzare",
    "demineralizzate": "demineralizzare",
    "demineralizzati": "demineralizzare",
    "demineralizzato": "demineralizzare",
    "demineralizzava": "demineralizzare",
    "demineralizzavamo": "demineralizzare",
    "demineralizzavan": "demineralizzare",
    "demineralizzavano": "demineralizzare",
    "demineralizzavate": "demineralizzare",
    "demineralizzavi": "demineralizzare",
    "demineralizzavo": "demineralizzare",
    "demineralizzerai": "demineralizzare",
    "demineralizzeran": "demineralizzare",
    "demineralizzeranno": "demineralizzare",
    "demineralizzerebbe": "demineralizzare",
    "demineralizzerebber": "demineralizzare",
    "demineralizzerebbero": "demineralizzare",
    "demineralizzerei": "demineralizzare",
    "demineralizzeremmo": "demineralizzare",
    "demineralizzeremo": "demineralizzare",
    "demineralizzereste": "demineralizzare",
    "demineralizzeresti": "demineralizzare",
    "demineralizzerete": "demineralizzare",
    "demineralizzerà": "demineralizzare",
    "demineralizzerò": "demineralizzare",
    "demineralizzi": "demineralizzare",
    "demineralizziamo": "demineralizzare",
    "demineralizziate": "demineralizzare",
    "demineralizzin": "demineralizzare",
    "demineralizzino": "demineralizzare",
    "demineralizzo": "demineralizzare",
    "demineralizzò": "demineralizzare",
    "demistifica": "demistificare",
    "demistificai": "demistificare",
    "demistificammo": "demistificare",
    "demistifican": "demistificare",
    "demistificando": "demistificare",
    "demistificano": "demistificare",
    "demistificante": "demistificare",
    "demistificanti": "demistificare",
    "demistificar": "demistificare",
    "demistificaron": "demistificare",
    "demistificarono": "demistificare",
    "demistificasse": "demistificare",
    "demistificasser": "demistificare",
    "demistificassero": "demistificare",
    "demistificassi": "demistificare",
    "demistificassimo": "demistificare",
    "demistificaste": "demistificare",
    "demistificasti": "demistificare",
    "demistificata": "demistificare",
    "demistificate": "demistificare",
    "demistificati": "demistificare",
    "demistificato": "demistificare",
    "demistificava": "demistificare",
    "demistificavamo": "demistificare",
    "demistificavan": "demistificare",
    "demistificavano": "demistificare",
    "demistificavate": "demistificare",
    "demistificavi": "demistificare",
    "demistificavo": "demistificare",
    "demistificazioni": "demistificazione",
    "demistificherai": "demistificare",
    "demistificheran": "demistificare",
    "demistificheranno": "demistificare",
    "demistificherebbe": "demistificare",
    "demistificherebber": "demistificare",
    "demistificherebbero": "demistificare",
    "demistificherei": "demistificare",
    "demistificheremmo": "demistificare",
    "demistificheremo": "demistificare",
    "demistifichereste": "demistificare",
    "demistificheresti": "demistificare",
    "demistificherete": "demistificare",
    "demistificherà": "demistificare",
    "demistificherò": "demistificare",
    "demistifichi": "demistificare",
    "demistifichiamo": "demistificare",
    "demistifichiate": "demistificare",
    "demistifichin": "demistificare",
    "demistifichino": "demistificare",
    "demistifico": "demistificare",
    "demistificò": "demistificare",
    "demitiana": "demitiano",
    "demitiane": "demitiano",
    "demitiani": "demitiano",
    "demitizza": "demitizzare",
    "demitizzai": "demitizzare",
    "demitizzammo": "demitizzare",
    "demitizzan": "demitizzare",
    "demitizzando": "demitizzare",
    "demitizzano": "demitizzare",
    "demitizzante": "demitizzare",
    "demitizzanti": "demitizzare",
    "demitizzar": "demitizzare",
    "demitizzaron": "demitizzare",
    "demitizzarono": "demitizzare",
    "demitizzasse": "demitizzare",
    "demitizzasser": "demitizzare",
    "demitizzassero": "demitizzare",
    "demitizzassi": "demitizzare",
    "demitizzassimo": "demitizzare",
    "demitizzaste": "demitizzare",
    "demitizzasti": "demitizzare",
    "demitizzata": "demitizzare",
    "demitizzate": "demitizzare",
    "demitizzati": "demitizzare",
    "demitizzato": "demitizzare",
    "demitizzava": "demitizzare",
    "demitizzavamo": "demitizzare",
    "demitizzavan": "demitizzare",
    "demitizzavano": "demitizzare",
    "demitizzavate": "demitizzare",
    "demitizzavi": "demitizzare",
    "demitizzavo": "demitizzare",
    "demitizzerai": "demitizzare",
    "demitizzeran": "demitizzare",
    "demitizzeranno": "demitizzare",
    "demitizzerebbe": "demitizzare",
    "demitizzerebber": "demitizzare",
    "demitizzerebbero": "demitizzare",
    "demitizzerei": "demitizzare",
    "demitizzeremmo": "demitizzare",
    "demitizzeremo": "demitizzare",
    "demitizzereste": "demitizzare",
    "demitizzeresti": "demitizzare",
    "demitizzerete": "demitizzare",
    "demitizzerà": "demitizzare",
    "demitizzerò": "demitizzare",
    "demitizzi": "demitizzare",
    "demitizziamo": "demitizzare",
    "demitizziate": "demitizzare",
    "demitizzin": "demitizzare",
    "demitizzino": "demitizzare",
    "demitizzo": "demitizzare",
    "demitizzò": "demitizzare",
    "demiurghi": "demiurgo",
    "demiurgica": "demiurgico",
    "demiurgiche": "demiurgico",
    "demiurgici": "demiurgico",
    "demmo": "dare",
    "democratica": "democratico",
    "democratiche": "democratico",
    "democratici": "democratico",
    "democratizza": "democratizzare",
    "democratizzai": "democratizzare",
    "democratizzammo": "democratizzare",
    "democratizzan": "democratizzare",
    "democratizzando": "democratizzare",
    "democratizzano": "democratizzare",
    "democratizzante": "democratizzare",
    "democratizzanti": "democratizzare",
    "democratizzar": "democratizzare",
    "democratizzaron": "democratizzare",
    "democratizzarono": "democratizzare",
    "democratizzasse": "democratizzare",
    "democratizzasser": "democratizzare",
    "democratizzassero": "democratizzare",
    "democratizzassi": "democratizzare",
    "democratizzassimo": "democratizzare",
    "democratizzaste": "democratizzare",
    "democratizzasti": "democratizzare",
    "democratizzata": "democratizzare",
    "democratizzate": "democratizzare",
    "democratizzati": "democratizzare",
    "democratizzato": "democratizzare",
    "democratizzava": "democratizzare",
    "democratizzavamo": "democratizzare",
    "democratizzavan": "democratizzare",
    "democratizzavano": "democratizzare",
    "democratizzavate": "democratizzare",
    "democratizzavi": "democratizzare",
    "democratizzavo": "democratizzare",
    "democratizzazioni": "democratizzazione",
    "democratizzerai": "democratizzare",
    "democratizzeran": "democratizzare",
    "democratizzeranno": "democratizzare",
    "democratizzerebbe": "democratizzare",
    "democratizzerebber": "democratizzare",
    "democratizzerebbero": "democratizzare",
    "democratizzerei": "democratizzare",
    "democratizzeremmo": "democratizzare",
    "democratizzeremo": "democratizzare",
    "democratizzereste": "democratizzare",
    "democratizzeresti": "democratizzare",
    "democratizzerete": "democratizzare",
    "democratizzerà": "democratizzare",
    "democratizzerò": "democratizzare",
    "democratizzi": "democratizzare",
    "democratizziamo": "democratizzare",
    "democratizziate": "democratizzare",
    "democratizzin": "democratizzare",
    "democratizzino": "democratizzare",
    "democratizzo": "democratizzare",
    "democratizzò": "democratizzare",
    "democrazie": "democrazia",
    "democristana": "democristano",
    "democristane": "democristano",
    "democristani": "democristano",
    "democristiana": "democristiano",
    "democristiane": "democristiano",
    "democristiani": "democristiano",
    "demoetnoantropologica": "demoetnoantropologico",
    "demoetnoantropologiche": "demoetnoantropologico",
    "demoetnoantropologici": "demoetnoantropologico",
    "demografi": "demografo",
    "demografica": "demografico",
    "demografiche": "demografico",
    "demografici": "demografico",
    "demografie": "demografia",
    "demolendo": "demolire",
    "demolente": "demolire",
    "demolenti": "demolire",
    "demoliamo": "demolire",
    "demoliate": "demolire",
    "demolii": "demolire",
    "demolimmo": "demolire",
    "demolir": "demolire",
    "demolirai": "demolire",
    "demoliran": "demolire",
    "demoliranno": "demolire",
    "demolirebbe": "demolire",
    "demolirebber": "demolire",
    "demolirebbero": "demolire",
    "demolirei": "demolire",
    "demoliremmo": "demolire",
    "demoliremo": "demolire",
    "demolireste": "demolire",
    "demoliresti": "demolire",
    "demolirete": "demolire",
    "demoliron": "demolire",
    "demolirono": "demolire",
    "demolirà": "demolire",
    "demolirò": "demolire",
    "demolisca": "demolire",
    "demoliscan": "demolire",
    "demoliscano": "demolire",
    "demolisce": "demolire",
    "demolisci": "demolire",
    "demolisco": "demolire",
    "demoliscon": "demolire",
    "demoliscono": "demolire",
    "demolisse": "demolire",
    "demolisser": "demolire",
    "demolissero": "demolire",
    "demolissi": "demolire",
    "demolissimo": "demolire",
    "demoliste": "demolire",
    "demolisti": "demolire",
    "demolita": "demolire",
    "demolite": "demolire",
    "demoliti": "demolire",
    "demolito": "demolire",
    "demolitori": "demolitore",
    "demolitrice": "demolitore",
    "demolitrici": "demolitore",
    "demoliva": "demolire",
    "demolivamo": "demolire",
    "demolivan": "demolire",
    "demolivano": "demolire",
    "demolivate": "demolire",
    "demolivi": "demolire",
    "demolivo": "demolire",
    "demolizioni": "demolizione",
    "demoltiplica": "demoltiplicare",
    "demoltiplicai": "demoltiplicare",
    "demoltiplicammo": "demoltiplicare",
    "demoltiplican": "demoltiplicare",
    "demoltiplicando": "demoltiplicare",
    "demoltiplicano": "demoltiplicare",
    "demoltiplicante": "demoltiplicare",
    "demoltiplicanti": "demoltiplicare",
    "demoltiplicar": "demoltiplicare",
    "demoltiplicaron": "demoltiplicare",
    "demoltiplicarono": "demoltiplicare",
    "demoltiplicasse": "demoltiplicare",
    "demoltiplicasser": "demoltiplicare",
    "demoltiplicassero": "demoltiplicare",
    "demoltiplicassi": "demoltiplicare",
    "demoltiplicassimo": "demoltiplicare",
    "demoltiplicaste": "demoltiplicare",
    "demoltiplicasti": "demoltiplicare",
    "demoltiplicata": "demoltiplicare",
    "demoltiplicate": "demoltiplicare",
    "demoltiplicati": "demoltiplicare",
    "demoltiplicato": "demoltiplicare",
    "demoltiplicava": "demoltiplicare",
    "demoltiplicavamo": "demoltiplicare",
    "demoltiplicavan": "demoltiplicare",
    "demoltiplicavano": "demoltiplicare",
    "demoltiplicavate": "demoltiplicare",
    "demoltiplicavi": "demoltiplicare",
    "demoltiplicavo": "demoltiplicare",
    "demoltiplicherai": "demoltiplicare",
    "demoltiplicheran": "demoltiplicare",
    "demoltiplicheranno": "demoltiplicare",
    "demoltiplicherebbe": "demoltiplicare",
    "demoltiplicherebber": "demoltiplicare",
    "demoltiplicherebbero": "demoltiplicare",
    "demoltiplicherei": "demoltiplicare",
    "demoltiplicheremmo": "demoltiplicare",
    "demoltiplicheremo": "demoltiplicare",
    "demoltiplichereste": "demoltiplicare",
    "demoltiplicheresti": "demoltiplicare",
    "demoltiplicherete": "demoltiplicare",
    "demoltiplicherà": "demoltiplicare",
    "demoltiplicherò": "demoltiplicare",
    "demoltiplichi": "demoltiplicare",
    "demoltiplichiamo": "demoltiplicare",
    "demoltiplichiate": "demoltiplicare",
    "demoltiplichin": "demoltiplicare",
    "demoltiplichino": "demoltiplicare",
    "demoltiplico": "demoltiplicare",
    "demoltiplicò": "demoltiplicare",
    "demolì": "demolire",
    "demonetizza": "demonetizzare",
    "demonetizzai": "demonetizzare",
    "demonetizzammo": "demonetizzare",
    "demonetizzan": "demonetizzare",
    "demonetizzando": "demonetizzare",
    "demonetizzano": "demonetizzare",
    "demonetizzante": "demonetizzare",
    "demonetizzanti": "demonetizzare",
    "demonetizzar": "demonetizzare",
    "demonetizzaron": "demonetizzare",
    "demonetizzarono": "demonetizzare",
    "demonetizzasse": "demonetizzare",
    "demonetizzasser": "demonetizzare",
    "demonetizzassero": "demonetizzare",
    "demonetizzassi": "demonetizzare",
    "demonetizzassimo": "demonetizzare",
    "demonetizzaste": "demonetizzare",
    "demonetizzasti": "demonetizzare",
    "demonetizzata": "demonetizzare",
    "demonetizzate": "demonetizzare",
    "demonetizzati": "demonetizzare",
    "demonetizzato": "demonetizzare",
    "demonetizzava": "demonetizzare",
    "demonetizzavamo": "demonetizzare",
    "demonetizzavan": "demonetizzare",
    "demonetizzavano": "demonetizzare",
    "demonetizzavate": "demonetizzare",
    "demonetizzavi": "demonetizzare",
    "demonetizzavo": "demonetizzare",
    "demonetizzerai": "demonetizzare",
    "demonetizzeran": "demonetizzare",
    "demonetizzeranno": "demonetizzare",
    "demonetizzerebbe": "demonetizzare",
    "demonetizzerebber": "demonetizzare",
    "demonetizzerebbero": "demonetizzare",
    "demonetizzerei": "demonetizzare",
    "demonetizzeremmo": "demonetizzare",
    "demonetizzeremo": "demonetizzare",
    "demonetizzereste": "demonetizzare",
    "demonetizzeresti": "demonetizzare",
    "demonetizzerete": "demonetizzare",
    "demonetizzerà": "demonetizzare",
    "demonetizzerò": "demonetizzare",
    "demonetizzi": "demonetizzare",
    "demonetizziamo": "demonetizzare",
    "demonetizziate": "demonetizzare",
    "demonetizzin": "demonetizzare",
    "demonetizzino": "demonetizzare",
    "demonetizzo": "demonetizzare",
    "demonetizzò": "demonetizzare",
    "demoni": "demonio",
    "demoniaca": "demoniaco",
    "demoniache": "demoniaco",
    "demoniaci": "demoniaco",
    "demonietti": "demonietto",
    "demonizza": "demonizzare",
    "demonizzai": "demonizzare",
    "demonizzammo": "demonizzare",
    "demonizzan": "demonizzare",
    "demonizzando": "demonizzare",
    "demonizzano": "demonizzare",
    "demonizzante": "demonizzare",
    "demonizzanti": "demonizzare",
    "demonizzar": "demonizzare",
    "demonizzaron": "demonizzare",
    "demonizzarono": "demonizzare",
    "demonizzasse": "demonizzare",
    "demonizzasser": "demonizzare",
    "demonizzassero": "demonizzare",
    "demonizzassi": "demonizzare",
    "demonizzassimo": "demonizzare",
    "demonizzaste": "demonizzare",
    "demonizzasti": "demonizzare",
    "demonizzata": "demonizzare",
    "demonizzate": "demonizzare",
    "demonizzati": "demonizzare",
    "demonizzato": "demonizzare",
    "demonizzava": "demonizzare",
    "demonizzavamo": "demonizzare",
    "demonizzavan": "demonizzare",
    "demonizzavano": "demonizzare",
    "demonizzavate": "demonizzare",
    "demonizzavi": "demonizzare",
    "demonizzavo": "demonizzare",
    "demonizzazioni": "demonizzazione",
    "demonizzerai": "demonizzare",
    "demonizzeran": "demonizzare",
    "demonizzeranno": "demonizzare",
    "demonizzerebbe": "demonizzare",
    "demonizzerebber": "demonizzare",
    "demonizzerebbero": "demonizzare",
    "demonizzerei": "demonizzare",
    "demonizzeremmo": "demonizzare",
    "demonizzeremo": "demonizzare",
    "demonizzereste": "demonizzare",
    "demonizzeresti": "demonizzare",
    "demonizzerete": "demonizzare",
    "demonizzerà": "demonizzare",
    "demonizzerò": "demonizzare",
    "demonizzi": "demonizzare",
    "demonizziamo": "demonizzare",
    "demonizziate": "demonizzare",
    "demonizzin": "demonizzare",
    "demonizzino": "demonizzare",
    "demonizzo": "demonizzare",
    "demonizzò": "demonizzare",
    "demoproletari": "demoproletario",
    "demoproletaria": "demoproletario",
    "demoproletarie": "demoproletario",
    "demoralizza": "demoralizzare",
    "demoralizzai": "demoralizzare",
    "demoralizzammo": "demoralizzare",
    "demoralizzan": "demoralizzare",
    "demoralizzando": "demoralizzare",
    "demoralizzano": "demoralizzare",
    "demoralizzante": "demoralizzare",
    "demoralizzanti": "demoralizzare",
    "demoralizzar": "demoralizzare",
    "demoralizzaron": "demoralizzare",
    "demoralizzarono": "demoralizzare",
    "demoralizzasse": "demoralizzare",
    "demoralizzasser": "demoralizzare",
    "demoralizzassero": "demoralizzare",
    "demoralizzassi": "demoralizzare",
    "demoralizzassimo": "demoralizzare",
    "demoralizzaste": "demoralizzare",
    "demoralizzasti": "demoralizzare",
    "demoralizzata": "demoralizzato",
    "demoralizzate": "demoralizzato",
    "demoralizzati": "demoralizzato",
    "demoralizzato": "demoralizzare",
    "demoralizzava": "demoralizzare",
    "demoralizzavamo": "demoralizzare",
    "demoralizzavan": "demoralizzare",
    "demoralizzavano": "demoralizzare",
    "demoralizzavate": "demoralizzare",
    "demoralizzavi": "demoralizzare",
    "demoralizzavo": "demoralizzare",
    "demoralizzerai": "demoralizzare",
    "demoralizzeran": "demoralizzare",
    "demoralizzeranno": "demoralizzare",
    "demoralizzerebbe": "demoralizzare",
    "demoralizzerebber": "demoralizzare",
    "demoralizzerebbero": "demoralizzare",
    "demoralizzerei": "demoralizzare",
    "demoralizzeremmo": "demoralizzare",
    "demoralizzeremo": "demoralizzare",
    "demoralizzereste": "demoralizzare",
    "demoralizzeresti": "demoralizzare",
    "demoralizzerete": "demoralizzare",
    "demoralizzerà": "demoralizzare",
    "demoralizzerò": "demoralizzare",
    "demoralizzi": "demoralizzare",
    "demoralizziamo": "demoralizzare",
    "demoralizziate": "demoralizzare",
    "demoralizzin": "demoralizzare",
    "demoralizzino": "demoralizzare",
    "demoralizzo": "demoralizzare",
    "demoralizzò": "demoralizzare",
    "demorda": "demordere",
    "demordan": "demordere",
    "demordano": "demordere",
    "demorde": "demordere",
    "demordemmo": "demordere",
    "demordendo": "demordere",
    "demordente": "demordere",
    "demordenti": "demordere",
    "demorder": "demordere",
    "demorderai": "demordere",
    "demorderan": "demordere",
    "demorderanno": "demordere",
    "demorderebbe": "demordere",
    "demorderebber": "demordere",
    "demorderebbero": "demordere",
    "demorderei": "demordere",
    "demorderemmo": "demordere",
    "demorderemo": "demordere",
    "demordereste": "demordere",
    "demorderesti": "demordere",
    "demorderete": "demordere",
    "demorderà": "demordere",
    "demorderò": "demordere",
    "demordesse": "demordere",
    "demordesser": "demordere",
    "demordessero": "demordere",
    "demordessi": "demordere",
    "demordessimo": "demordere",
    "demordeste": "demordere",
    "demordesti": "demordere",
    "demordete": "demordere",
    "demordeva": "demordere",
    "demordevamo": "demordere",
    "demordevan": "demordere",
    "demordevano": "demordere",
    "demordevate": "demordere",
    "demordevi": "demordere",
    "demordevo": "demordere",
    "demordi": "demordere",
    "demordiamo": "demordere",
    "demordiate": "demordere",
    "demordo": "demordere",
    "demordon": "demordere",
    "demordono": "demordere",
    "demorsa": "demordere",
    "demorse": "demordere",
    "demorser": "demordere",
    "demorsero": "demordere",
    "demorsi": "demordere",
    "demorso": "demordere",
    "demorsè": "demordere",
    "demoscopica": "demoscopico",
    "demoscopiche": "demoscopico",
    "demoscopici": "demoscopico",
    "demotiva": "demotivare",
    "demotivai": "demotivare",
    "demotivammo": "demotivare",
    "demotivan": "demotivare",
    "demotivando": "demotivare",
    "demotivano": "demotivare",
    "demotivante": "demotivare",
    "demotivanti": "demotivare",
    "demotivar": "demotivare",
    "demotivaron": "demotivare",
    "demotivarono": "demotivare",
    "demotivasse": "demotivare",
    "demotivasser": "demotivare",
    "demotivassero": "demotivare",
    "demotivassi": "demotivare",
    "demotivassimo": "demotivare",
    "demotivaste": "demotivare",
    "demotivasti": "demotivare",
    "demotivata": "demotivare",
    "demotivate": "demotivare",
    "demotivati": "demotivare",
    "demotivato": "demotivare",
    "demotivava": "demotivare",
    "demotivavamo": "demotivare",
    "demotivavan": "demotivare",
    "demotivavano": "demotivare",
    "demotivavate": "demotivare",
    "demotivavi": "demotivare",
    "demotivavo": "demotivare",
    "demotiverai": "demotivare",
    "demotiveran": "demotivare",
    "demotiveranno": "demotivare",
    "demotiverebbe": "demotivare",
    "demotiverebber": "demotivare",
    "demotiverebbero": "demotivare",
    "demotiverei": "demotivare",
    "demotiveremmo": "demotivare",
    "demotiveremo": "demotivare",
    "demotivereste": "demotivare",
    "demotiveresti": "demotivare",
    "demotiverete": "demotivare",
    "demotiverà": "demotivare",
    "demotiverò": "demotivare",
    "demotivi": "demotivare",
    "demotiviamo": "demotivare",
    "demotiviate": "demotivare",
    "demotivin": "demotivare",
    "demotivino": "demotivare",
    "demotivo": "demotivare",
    "demotivò": "demotivare",
    "denari": "denaro",
    "denatura": "denaturare",
    "denaturai": "denaturare",
    "denaturammo": "denaturare",
    "denaturan": "denaturare",
    "denaturando": "denaturare",
    "denaturano": "denaturare",
    "denaturante": "denaturare",
    "denaturanti": "denaturare",
    "denaturar": "denaturare",
    "denaturaron": "denaturare",
    "denaturarono": "denaturare",
    "denaturasse": "denaturare",
    "denaturasser": "denaturare",
    "denaturassero": "denaturare",
    "denaturassi": "denaturare",
    "denaturassimo": "denaturare",
    "denaturaste": "denaturare",
    "denaturasti": "denaturare",
    "denaturata": "denaturare",
    "denaturate": "denaturare",
    "denaturati": "denaturare",
    "denaturato": "denaturare",
    "denaturava": "denaturare",
    "denaturavamo": "denaturare",
    "denaturavan": "denaturare",
    "denaturavano": "denaturare",
    "denaturavate": "denaturare",
    "denaturavi": "denaturare",
    "denaturavo": "denaturare",
    "denaturerai": "denaturare",
    "denatureran": "denaturare",
    "denatureranno": "denaturare",
    "denaturerebbe": "denaturare",
    "denaturerebber": "denaturare",
    "denaturerebbero": "denaturare",
    "denaturerei": "denaturare",
    "denatureremmo": "denaturare",
    "denatureremo": "denaturare",
    "denaturereste": "denaturare",
    "denatureresti": "denaturare",
    "denaturerete": "denaturare",
    "denaturerà": "denaturare",
    "denaturerò": "denaturare",
    "denaturi": "denaturare",
    "denaturiamo": "denaturare",
    "denaturiate": "denaturare",
    "denaturin": "denaturare",
    "denaturino": "denaturare",
    "denaturo": "denaturare",
    "denaturò": "denaturare",
    "denazionalizza": "denazionalizzare",
    "denazionalizzai": "denazionalizzare",
    "denazionalizzammo": "denazionalizzare",
    "denazionalizzan": "denazionalizzare",
    "denazionalizzando": "denazionalizzare",
    "denazionalizzano": "denazionalizzare",
    "denazionalizzante": "denazionalizzare",
    "denazionalizzanti": "denazionalizzare",
    "denazionalizzar": "denazionalizzare",
    "denazionalizzaron": "denazionalizzare",
    "denazionalizzarono": "denazionalizzare",
    "denazionalizzasse": "denazionalizzare",
    "denazionalizzasser": "denazionalizzare",
    "denazionalizzassero": "denazionalizzare",
    "denazionalizzassi": "denazionalizzare",
    "denazionalizzassimo": "denazionalizzare",
    "denazionalizzaste": "denazionalizzare",
    "denazionalizzasti": "denazionalizzare",
    "denazionalizzata": "denazionalizzare",
    "denazionalizzate": "denazionalizzare",
    "denazionalizzati": "denazionalizzare",
    "denazionalizzato": "denazionalizzare",
    "denazionalizzava": "denazionalizzare",
    "denazionalizzavamo": "denazionalizzare",
    "denazionalizzavan": "denazionalizzare",
    "denazionalizzavano": "denazionalizzare",
    "denazionalizzavate": "denazionalizzare",
    "denazionalizzavi": "denazionalizzare",
    "denazionalizzavo": "denazionalizzare",
    "denazionalizzazioni": "denazionalizzazione",
    "denazionalizzerai": "denazionalizzare",
    "denazionalizzeran": "denazionalizzare",
    "denazionalizzeranno": "denazionalizzare",
    "denazionalizzerebbe": "denazionalizzare",
    "denazionalizzerebber": "denazionalizzare",
    "denazionalizzerebbero": "denazionalizzare",
    "denazionalizzerei": "denazionalizzare",
    "denazionalizzeremmo": "denazionalizzare",
    "denazionalizzeremo": "denazionalizzare",
    "denazionalizzereste": "denazionalizzare",
    "denazionalizzeresti": "denazionalizzare",
    "denazionalizzerete": "denazionalizzare",
    "denazionalizzerà": "denazionalizzare",
    "denazionalizzerò": "denazionalizzare",
    "denazionalizzi": "denazionalizzare",
    "denazionalizziamo": "denazionalizzare",
    "denazionalizziate": "denazionalizzare",
    "denazionalizzin": "denazionalizzare",
    "denazionalizzino": "denazionalizzare",
    "denazionalizzo": "denazionalizzare",
    "denazionalizzò": "denazionalizzare",
    "denega": "denegare",
    "denegai": "denegare",
    "denegammo": "denegare",
    "denegan": "denegare",
    "denegando": "denegare",
    "denegano": "denegare",
    "denegante": "denegare",
    "deneganti": "denegare",
    "denegar": "denegare",
    "denegaron": "denegare",
    "denegarono": "denegare",
    "denegasse": "denegare",
    "denegasser": "denegare",
    "denegassero": "denegare",
    "denegassi": "denegare",
    "denegassimo": "denegare",
    "denegaste": "denegare",
    "denegasti": "denegare",
    "denegata": "denegare",
    "denegate": "denegare",
    "denegati": "denegare",
    "denegato": "denegare",
    "denegava": "denegare",
    "denegavamo": "denegare",
    "denegavan": "denegare",
    "denegavano": "denegare",
    "denegavate": "denegare",
    "denegavi": "denegare",
    "denegavo": "denegare",
    "denegherai": "denegare",
    "denegheran": "denegare",
    "denegheranno": "denegare",
    "denegherebbe": "denegare",
    "denegherebber": "denegare",
    "denegherebbero": "denegare",
    "denegherei": "denegare",
    "denegheremmo": "denegare",
    "denegheremo": "denegare",
    "deneghereste": "denegare",
    "denegheresti": "denegare",
    "denegherete": "denegare",
    "denegherà": "denegare",
    "denegherò": "denegare",
    "deneghi": "denegare",
    "deneghiamo": "denegare",
    "deneghiate": "denegare",
    "deneghin": "denegare",
    "deneghino": "denegare",
    "denego": "denegare",
    "denegò": "denegare",
    "denigra": "denigrare",
    "denigrai": "denigrare",
    "denigrammo": "denigrare",
    "denigran": "denigrare",
    "denigrando": "denigrare",
    "denigrano": "denigrare",
    "denigrante": "denigrare",
    "denigranti": "denigrare",
    "denigrar": "denigrare",
    "denigraron": "denigrare",
    "denigrarono": "denigrare",
    "denigrasse": "denigrare",
    "denigrasser": "denigrare",
    "denigrassero": "denigrare",
    "denigrassi": "denigrare",
    "denigrassimo": "denigrare",
    "denigraste": "denigrare",
    "denigrasti": "denigrare",
    "denigrata": "denigrare",
    "denigrate": "denigrare",
    "denigrati": "denigrare",
    "denigrato": "denigrare",
    "denigratori": "denigratorio",
    "denigratoria": "denigratorio",
    "denigratorie": "denigratorio",
    "denigratrice": "denigratore",
    "denigratrici": "denigratore",
    "denigrava": "denigrare",
    "denigravamo": "denigrare",
    "denigravan": "denigrare",
    "denigravano": "denigrare",
    "denigravate": "denigrare",
    "denigravi": "denigrare",
    "denigravo": "denigrare",
    "denigrazioni": "denigrazione",
    "denigrerai": "denigrare",
    "denigreran": "denigrare",
    "denigreranno": "denigrare",
    "denigrerebbe": "denigrare",
    "denigrerebber": "denigrare",
    "denigrerebbero": "denigrare",
    "denigrerei": "denigrare",
    "denigreremmo": "denigrare",
    "denigreremo": "denigrare",
    "denigrereste": "denigrare",
    "denigreresti": "denigrare",
    "denigrerete": "denigrare",
    "denigrerà": "denigrare",
    "denigrerò": "denigrare",
    "denigri": "denigrare",
    "denigriamo": "denigrare",
    "denigriate": "denigrare",
    "denigrin": "denigrare",
    "denigrino": "denigrare",
    "denigro": "denigrare",
    "denigrò": "denigrare",
    "denomina": "denominare",
    "denominai": "denominare",
    "denominammo": "denominare",
    "denominan": "denominare",
    "denominando": "denominare",
    "denominano": "denominare",
    "denominante": "denominare",
    "denominanti": "denominare",
    "denominar": "denominare",
    "denominaron": "denominare",
    "denominarono": "denominare",
    "denominasse": "denominare",
    "denominasser": "denominare",
    "denominassero": "denominare",
    "denominassi": "denominare",
    "denominassimo": "denominare",
    "denominaste": "denominare",
    "denominasti": "denominare",
    "denominata": "denominare",
    "denominate": "denominare",
    "denominati": "denominare",
    "denominato": "denominare",
    "denominatori": "denominatore",
    "denominava": "denominare",
    "denominavamo": "denominare",
    "denominavan": "denominare",
    "denominavano": "denominare",
    "denominavate": "denominare",
    "denominavi": "denominare",
    "denominavo": "denominare",
    "denominazioni": "denominazione",
    "denominerai": "denominare",
    "denomineran": "denominare",
    "denomineranno": "denominare",
    "denominerebbe": "denominare",
    "denominerebber": "denominare",
    "denominerebbero": "denominare",
    "denominerei": "denominare",
    "denomineremmo": "denominare",
    "denomineremo": "denominare",
    "denominereste": "denominare",
    "denomineresti": "denominare",
    "denominerete": "denominare",
    "denominerà": "denominare",
    "denominerò": "denominare",
    "denomini": "denominare",
    "denominiamo": "denominare",
    "denominiate": "denominare",
    "denominin": "denominare",
    "denominino": "denominare",
    "denomino": "denominare",
    "denominò": "denominare",
    "denota": "denotare",
    "denotai": "denotare",
    "denotammo": "denotare",
    "denotan": "denotare",
    "denotando": "denotare",
    "denotano": "denotare",
    "denotante": "denotare",
    "denotanti": "denotare",
    "denotar": "denotare",
    "denotaron": "denotare",
    "denotarono": "denotare",
    "denotasse": "denotare",
    "denotasser": "denotare",
    "denotassero": "denotare",
    "denotassi": "denotare",
    "denotassimo": "denotare",
    "denotaste": "denotare",
    "denotasti": "denotare",
    "denotata": "denotare",
    "denotate": "denotare",
    "denotati": "denotare",
    "denotato": "denotare",
    "denotava": "denotare",
    "denotavamo": "denotare",
    "denotavan": "denotare",
    "denotavano": "denotare",
    "denotavate": "denotare",
    "denotavi": "denotare",
    "denotavo": "denotare",
    "denoterai": "denotare",
    "denoteran": "denotare",
    "denoteranno": "denotare",
    "denoterebbe": "denotare",
    "denoterebber": "denotare",
    "denoterebbero": "denotare",
    "denoterei": "denotare",
    "denoteremmo": "denotare",
    "denoteremo": "denotare",
    "denotereste": "denotare",
    "denoteresti": "denotare",
    "denoterete": "denotare",
    "denoterà": "denotare",
    "denoterò": "denotare",
    "denoti": "denotare",
    "denotiamo": "denotare",
    "denotiate": "denotare",
    "denotin": "denotare",
    "denotino": "denotare",
    "denoto": "denotare",
    "denotò": "denotare",
    "densa": "denso",
    "dense": "denso",
    "densi": "denso",
    "dentali": "dentale",
    "dentari": "dentario",
    "dentaria": "dentario",
    "dentarie": "dentario",
    "dentata": "dentato",
    "dentate": "dentato",
    "dentati": "dentato",
    "dentature": "dentatura",
    "dentella": "dentellare",
    "dentellai": "dentellare",
    "dentellammo": "dentellare",
    "dentellan": "dentellare",
    "dentellando": "dentellare",
    "dentellano": "dentellare",
    "dentellante": "dentellare",
    "dentellanti": "dentellare",
    "dentellar": "dentellare",
    "dentellaron": "dentellare",
    "dentellarono": "dentellare",
    "dentellasse": "dentellare",
    "dentellasser": "dentellare",
    "dentellassero": "dentellare",
    "dentellassi": "dentellare",
    "dentellassimo": "dentellare",
    "dentellaste": "dentellare",
    "dentellasti": "dentellare",
    "dentellata": "dentellare",
    "dentellate": "dentellare",
    "dentellati": "dentellare",
    "dentellato": "dentellare",
    "dentellava": "dentellare",
    "dentellavamo": "dentellare",
    "dentellavan": "dentellare",
    "dentellavano": "dentellare",
    "dentellavate": "dentellare",
    "dentellavi": "dentellare",
    "dentellavo": "dentellare",
    "dentellerai": "dentellare",
    "dentelleran": "dentellare",
    "dentelleranno": "dentellare",
    "dentellerebbe": "dentellare",
    "dentellerebber": "dentellare",
    "dentellerebbero": "dentellare",
    "dentellerei": "dentellare",
    "dentelleremmo": "dentellare",
    "dentelleremo": "dentellare",
    "dentellereste": "dentellare",
    "dentelleresti": "dentellare",
    "dentellerete": "dentellare",
    "dentellerà": "dentellare",
    "dentellerò": "dentellare",
    "dentelli": "dentellare",
    "dentelliamo": "dentellare",
    "dentelliate": "dentellare",
    "dentellin": "dentellare",
    "dentellino": "dentellare",
    "dentello": "dentellare",
    "dentellò": "dentellare",
    "denti": "dente",
    "dentiere": "dentiera",
    "dentifrici": "dentifricio",
    "dentini": "dentino",
    "dentisti": "dentista",
    "dentistica": "dentistico",
    "dentistiche": "dentistico",
    "dentistici": "dentistico",
    "dentoni": "dentone",
    "denuclearizza": "denuclearizzare",
    "denuclearizzai": "denuclearizzare",
    "denuclearizzammo": "denuclearizzare",
    "denuclearizzan": "denuclearizzare",
    "denuclearizzando": "denuclearizzare",
    "denuclearizzano": "denuclearizzare",
    "denuclearizzante": "denuclearizzare",
    "denuclearizzanti": "denuclearizzare",
    "denuclearizzar": "denuclearizzare",
    "denuclearizzaron": "denuclearizzare",
    "denuclearizzarono": "denuclearizzare",
    "denuclearizzasse": "denuclearizzare",
    "denuclearizzasser": "denuclearizzare",
    "denuclearizzassero": "denuclearizzare",
    "denuclearizzassi": "denuclearizzare",
    "denuclearizzassimo": "denuclearizzare",
    "denuclearizzaste": "denuclearizzare",
    "denuclearizzasti": "denuclearizzare",
    "denuclearizzata": "denuclearizzare",
    "denuclearizzate": "denuclearizzare",
    "denuclearizzati": "denuclearizzare",
    "denuclearizzato": "denuclearizzare",
    "denuclearizzava": "denuclearizzare",
    "denuclearizzavamo": "denuclearizzare",
    "denuclearizzavan": "denuclearizzare",
    "denuclearizzavano": "denuclearizzare",
    "denuclearizzavate": "denuclearizzare",
    "denuclearizzavi": "denuclearizzare",
    "denuclearizzavo": "denuclearizzare",
    "denuclearizzazioni": "denuclearizzazione",
    "denuclearizzerai": "denuclearizzare",
    "denuclearizzeran": "denuclearizzare",
    "denuclearizzeranno": "denuclearizzare",
    "denuclearizzerebbe": "denuclearizzare",
    "denuclearizzerebber": "denuclearizzare",
    "denuclearizzerebbero": "denuclearizzare",
    "denuclearizzerei": "denuclearizzare",
    "denuclearizzeremmo": "denuclearizzare",
    "denuclearizzeremo": "denuclearizzare",
    "denuclearizzereste": "denuclearizzare",
    "denuclearizzeresti": "denuclearizzare",
    "denuclearizzerete": "denuclearizzare",
    "denuclearizzerà": "denuclearizzare",
    "denuclearizzerò": "denuclearizzare",
    "denuclearizzi": "denuclearizzare",
    "denuclearizziamo": "denuclearizzare",
    "denuclearizziate": "denuclearizzare",
    "denuclearizzin": "denuclearizzare",
    "denuclearizzino": "denuclearizzare",
    "denuclearizzo": "denuclearizzare",
    "denuclearizzò": "denuclearizzare",
    "denuda": "denudare",
    "denudai": "denudare",
    "denudammo": "denudare",
    "denudan": "denudare",
    "denudando": "denudare",
    "denudano": "denudare",
    "denudante": "denudare",
    "denudanti": "denudare",
    "denudar": "denudare",
    "denudaron": "denudare",
    "denudarono": "denudare",
    "denudasse": "denudare",
    "denudasser": "denudare",
    "denudassero": "denudare",
    "denudassi": "denudare",
    "denudassimo": "denudare",
    "denudaste": "denudare",
    "denudasti": "denudare",
    "denudata": "denudare",
    "denudate": "denudare",
    "denudati": "denudare",
    "denudato": "denudare",
    "denudava": "denudare",
    "denudavamo": "denudare",
    "denudavan": "denudare",
    "denudavano": "denudare",
    "denudavate": "denudare",
    "denudavi": "denudare",
    "denudavo": "denudare",
    "denuderai": "denudare",
    "denuderan": "denudare",
    "denuderanno": "denudare",
    "denuderebbe": "denudare",
    "denuderebber": "denudare",
    "denuderebbero": "denudare",
    "denuderei": "denudare",
    "denuderemmo": "denudare",
    "denuderemo": "denudare",
    "denudereste": "denudare",
    "denuderesti": "denudare",
    "denuderete": "denudare",
    "denuderà": "denudare",
    "denuderò": "denudare",
    "denudi": "denudare",
    "denudiamo": "denudare",
    "denudiate": "denudare",
    "denudin": "denudare",
    "denudino": "denudare",
    "denudo": "denudare",
    "denudò": "denudare",
    "denunce": "denuncia",
    "denuncerai": "denunciare",
    "denunceran": "denunciare",
    "denunceranno": "denunciare",
    "denuncerebbe": "denunciare",
    "denuncerebber": "denunciare",
    "denuncerebbero": "denunciare",
    "denuncerei": "denunciare",
    "denunceremmo": "denunciare",
    "denunceremo": "denunciare",
    "denuncereste": "denunciare",
    "denunceresti": "denunciare",
    "denuncerete": "denunciare",
    "denuncerà": "denunciare",
    "denuncerò": "denunciare",
    "denunci": "denunciare",
    "denuncia": "denunciare",
    "denunciai": "denunciare",
    "denunciammo": "denunciare",
    "denunciamo": "denunciare",
    "denuncian": "denunciare",
    "denunciando": "denunciare",
    "denunciano": "denunciare",
    "denunciante": "denunciare",
    "denuncianti": "denunciare",
    "denunciar": "denunciare",
    "denunciaron": "denunciare",
    "denunciarono": "denunciare",
    "denunciasse": "denunciare",
    "denunciasser": "denunciare",
    "denunciassero": "denunciare",
    "denunciassi": "denunciare",
    "denunciassimo": "denunciare",
    "denunciaste": "denunciare",
    "denunciasti": "denunciare",
    "denunciata": "denunciare",
    "denunciate": "denunciare",
    "denunciati": "denunciare",
    "denunciato": "denunciare",
    "denunciava": "denunciare",
    "denunciavamo": "denunciare",
    "denunciavan": "denunciare",
    "denunciavano": "denunciare",
    "denunciavate": "denunciare",
    "denunciavi": "denunciare",
    "denunciavo": "denunciare",
    "denuncie": "denuncia",
    "denuncin": "denunciare",
    "denuncino": "denunciare",
    "denuncio": "denunciare",
    "denunciò": "denunciare",
    "denunzi": "denunziare",
    "denunzia": "denunziare",
    "denunziai": "denunziare",
    "denunziammo": "denunziare",
    "denunziamo": "denunziare",
    "denunzian": "denunziare",
    "denunziando": "denunziare",
    "denunziano": "denunziare",
    "denunziante": "denunziare",
    "denunzianti": "denunziare",
    "denunziar": "denunziare",
    "denunziaron": "denunziare",
    "denunziarono": "denunziare",
    "denunziasse": "denunziare",
    "denunziasser": "denunziare",
    "denunziassero": "denunziare",
    "denunziassi": "denunziare",
    "denunziassimo": "denunziare",
    "denunziaste": "denunziare",
    "denunziasti": "denunziare",
    "denunziata": "denunziare",
    "denunziate": "denunziare",
    "denunziati": "denunziare",
    "denunziato": "denunziare",
    "denunziava": "denunziare",
    "denunziavamo": "denunziare",
    "denunziavan": "denunziare",
    "denunziavano": "denunziare",
    "denunziavate": "denunziare",
    "denunziavi": "denunziare",
    "denunziavo": "denunziare",
    "denunzie": "denunzia",
    "denunzierai": "denunziare",
    "denunzieran": "denunziare",
    "denunzieranno": "denunziare",
    "denunzierebbe": "denunziare",
    "denunzierebber": "denunziare",
    "denunzierebbero": "denunziare",
    "denunzierei": "denunziare",
    "denunzieremmo": "denunziare",
    "denunzieremo": "denunziare",
    "denunziereste": "denunziare",
    "denunzieresti": "denunziare",
    "denunzierete": "denunziare",
    "denunzierà": "denunziare",
    "denunzierò": "denunziare",
    "denunzin": "denunziare",
    "denunzino": "denunziare",
    "denunzio": "denunziare",
    "denunziò": "denunziare",
    "denutrita": "denutrito",
    "denutrite": "denutrito",
    "denutriti": "denutrito",
    "denutrizioni": "denutrizione",
    "deodora": "deodorare",
    "deodorai": "deodorare",
    "deodorammo": "deodorare",
    "deodoran": "deodorare",
    "deodorando": "deodorare",
    "deodorano": "deodorare",
    "deodorante": "deodorare",
    "deodoranti": "deodorare",
    "deodorar": "deodorare",
    "deodoraron": "deodorare",
    "deodorarono": "deodorare",
    "deodorasse": "deodorare",
    "deodorasser": "deodorare",
    "deodorassero": "deodorare",
    "deodorassi": "deodorare",
    "deodorassimo": "deodorare",
    "deodoraste": "deodorare",
    "deodorasti": "deodorare",
    "deodorata": "deodorare",
    "deodorate": "deodorare",
    "deodorati": "deodorare",
    "deodorato": "deodorare",
    "deodorava": "deodorare",
    "deodoravamo": "deodorare",
    "deodoravan": "deodorare",
    "deodoravano": "deodorare",
    "deodoravate": "deodorare",
    "deodoravi": "deodorare",
    "deodoravo": "deodorare",
    "deodorerai": "deodorare",
    "deodoreran": "deodorare",
    "deodoreranno": "deodorare",
    "deodorerebbe": "deodorare",
    "deodorerebber": "deodorare",
    "deodorerebbero": "deodorare",
    "deodorerei": "deodorare",
    "deodoreremmo": "deodorare",
    "deodoreremo": "deodorare",
    "deodorereste": "deodorare",
    "deodoreresti": "deodorare",
    "deodorerete": "deodorare",
    "deodorerà": "deodorare",
    "deodorerò": "deodorare",
    "deodori": "deodorare",
    "deodoriamo": "deodorare",
    "deodoriate": "deodorare",
    "deodorin": "deodorare",
    "deodorino": "deodorare",
    "deodoro": "deodorare",
    "deodorò": "deodorare",
    "deontologica": "deontologico",
    "deontologiche": "deontologico",
    "deontologici": "deontologico",
    "deontologie": "deontologia",
    "depaupera": "depauperare",
    "depauperai": "depauperare",
    "depauperamenti": "depauperamento",
    "depauperammo": "depauperare",
    "depauperan": "depauperare",
    "depauperando": "depauperare",
    "depauperano": "depauperare",
    "depauperante": "depauperare",
    "depauperanti": "depauperare",
    "depauperar": "depauperare",
    "depauperaron": "depauperare",
    "depauperarono": "depauperare",
    "depauperasse": "depauperare",
    "depauperasser": "depauperare",
    "depauperassero": "depauperare",
    "depauperassi": "depauperare",
    "depauperassimo": "depauperare",
    "depauperaste": "depauperare",
    "depauperasti": "depauperare",
    "depauperata": "depauperare",
    "depauperate": "depauperare",
    "depauperati": "depauperare",
    "depauperato": "depauperare",
    "depauperava": "depauperare",
    "depauperavamo": "depauperare",
    "depauperavan": "depauperare",
    "depauperavano": "depauperare",
    "depauperavate": "depauperare",
    "depauperavi": "depauperare",
    "depauperavo": "depauperare",
    "depaupererai": "depauperare",
    "depaupereran": "depauperare",
    "depaupereranno": "depauperare",
    "depaupererebbe": "depauperare",
    "depaupererebber": "depauperare",
    "depaupererebbero": "depauperare",
    "depaupererei": "depauperare",
    "depaupereremmo": "depauperare",
    "depaupereremo": "depauperare",
    "depauperereste": "depauperare",
    "depaupereresti": "depauperare",
    "depaupererete": "depauperare",
    "depaupererà": "depauperare",
    "depaupererò": "depauperare",
    "depauperi": "depauperare",
    "depauperiamo": "depauperare",
    "depauperiate": "depauperare",
    "depauperin": "depauperare",
    "depauperino": "depauperare",
    "depaupero": "depauperare",
    "depauperò": "depauperare",
    "depenalizza": "depenalizzare",
    "depenalizzai": "depenalizzare",
    "depenalizzammo": "depenalizzare",
    "depenalizzan": "depenalizzare",
    "depenalizzando": "depenalizzare",
    "depenalizzano": "depenalizzare",
    "depenalizzante": "depenalizzare",
    "depenalizzanti": "depenalizzare",
    "depenalizzar": "depenalizzare",
    "depenalizzaron": "depenalizzare",
    "depenalizzarono": "depenalizzare",
    "depenalizzasse": "depenalizzare",
    "depenalizzasser": "depenalizzare",
    "depenalizzassero": "depenalizzare",
    "depenalizzassi": "depenalizzare",
    "depenalizzassimo": "depenalizzare",
    "depenalizzaste": "depenalizzare",
    "depenalizzasti": "depenalizzare",
    "depenalizzata": "depenalizzato",
    "depenalizzate": "depenalizzato",
    "depenalizzati": "depenalizzato",
    "depenalizzato": "depenalizzare",
    "depenalizzava": "depenalizzare",
    "depenalizzavamo": "depenalizzare",
    "depenalizzavan": "depenalizzare",
    "depenalizzavano": "depenalizzare",
    "depenalizzavate": "depenalizzare",
    "depenalizzavi": "depenalizzare",
    "depenalizzavo": "depenalizzare",
    "depenalizzazioni": "depenalizzazione",
    "depenalizzerai": "depenalizzare",
    "depenalizzeran": "depenalizzare",
    "depenalizzeranno": "depenalizzare",
    "depenalizzerebbe": "depenalizzare",
    "depenalizzerebber": "depenalizzare",
    "depenalizzerebbero": "depenalizzare",
    "depenalizzerei": "depenalizzare",
    "depenalizzeremmo": "depenalizzare",
    "depenalizzeremo": "depenalizzare",
    "depenalizzereste": "depenalizzare",
    "depenalizzeresti": "depenalizzare",
    "depenalizzerete": "depenalizzare",
    "depenalizzerà": "depenalizzare",
    "depenalizzerò": "depenalizzare",
    "depenalizzi": "depenalizzare",
    "depenalizziamo": "depenalizzare",
    "depenalizziate": "depenalizzare",
    "depenalizzin": "depenalizzare",
    "depenalizzino": "depenalizzare",
    "depenalizzo": "depenalizzare",
    "depenalizzò": "depenalizzare",
    "dependances": "dependance",
    "depenna": "depennare",
    "depennai": "depennare",
    "depennammo": "depennare",
    "depennan": "depennare",
    "depennando": "depennare",
    "depennano": "depennare",
    "depennante": "depennare",
    "depennanti": "depennare",
    "depennar": "depennare",
    "depennaron": "depennare",
    "depennarono": "depennare",
    "depennasse": "depennare",
    "depennasser": "depennare",
    "depennassero": "depennare",
    "depennassi": "depennare",
    "depennassimo": "depennare",
    "depennaste": "depennare",
    "depennasti": "depennare",
    "depennata": "depennare",
    "depennate": "depennare",
    "depennati": "depennare",
    "depennato": "depennare",
    "depennava": "depennare",
    "depennavamo": "depennare",
    "depennavan": "depennare",
    "depennavano": "depennare",
    "depennavate": "depennare",
    "depennavi": "depennare",
    "depennavo": "depennare",
    "depennerai": "depennare",
    "depenneran": "depennare",
    "depenneranno": "depennare",
    "depennerebbe": "depennare",
    "depennerebber": "depennare",
    "depennerebbero": "depennare",
    "depennerei": "depennare",
    "depenneremmo": "depennare",
    "depenneremo": "depennare",
    "depennereste": "depennare",
    "depenneresti": "depennare",
    "depennerete": "depennare",
    "depennerà": "depennare",
    "depennerò": "depennare",
    "depenni": "depennare",
    "depenniamo": "depennare",
    "depenniate": "depennare",
    "depennin": "depennare",
    "depennino": "depennare",
    "depenno": "depennare",
    "depennò": "depennare",
    "deperendo": "deperire",
    "deperente": "deperire",
    "deperenti": "deperire",
    "deperiamo": "deperire",
    "deperiate": "deperire",
    "deperibili": "deperibile",
    "deperii": "deperire",
    "deperimenti": "deperimento",
    "deperimmo": "deperire",
    "deperir": "deperire",
    "deperirai": "deperire",
    "deperiran": "deperire",
    "deperiranno": "deperire",
    "deperirebbe": "deperire",
    "deperirebber": "deperire",
    "deperirebbero": "deperire",
    "deperirei": "deperire",
    "deperiremmo": "deperire",
    "deperiremo": "deperire",
    "deperireste": "deperire",
    "deperiresti": "deperire",
    "deperirete": "deperire",
    "deperiron": "deperire",
    "deperirono": "deperire",
    "deperirà": "deperire",
    "deperirò": "deperire",
    "deperisca": "deperire",
    "deperiscan": "deperire",
    "deperiscano": "deperire",
    "deperisce": "deperire",
    "deperisci": "deperire",
    "deperisco": "deperire",
    "deperiscon": "deperire",
    "deperiscono": "deperire",
    "deperisse": "deperire",
    "deperisser": "deperire",
    "deperissero": "deperire",
    "deperissi": "deperire",
    "deperissimo": "deperire",
    "deperiste": "deperire",
    "deperisti": "deperire",
    "deperita": "deperire",
    "deperite": "deperire",
    "deperiti": "deperire",
    "deperito": "deperire",
    "deperiva": "deperire",
    "deperivamo": "deperire",
    "deperivan": "deperire",
    "deperivano": "deperire",
    "deperivate": "deperire",
    "deperivi": "deperire",
    "deperivo": "deperire",
    "deperì": "deperire",
    "depila": "depilare",
    "depilai": "depilare",
    "depilammo": "depilare",
    "depilan": "depilare",
    "depilando": "depilare",
    "depilano": "depilare",
    "depilante": "depilare",
    "depilanti": "depilare",
    "depilar": "depilare",
    "depilaron": "depilare",
    "depilarono": "depilare",
    "depilasse": "depilare",
    "depilasser": "depilare",
    "depilassero": "depilare",
    "depilassi": "depilare",
    "depilassimo": "depilare",
    "depilaste": "depilare",
    "depilasti": "depilare",
    "depilata": "depilare",
    "depilate": "depilare",
    "depilati": "depilare",
    "depilato": "depilare",
    "depilava": "depilare",
    "depilavamo": "depilare",
    "depilavan": "depilare",
    "depilavano": "depilare",
    "depilavate": "depilare",
    "depilavi": "depilare",
    "depilavo": "depilare",
    "depilerai": "depilare",
    "depileran": "depilare",
    "depileranno": "depilare",
    "depilerebbe": "depilare",
    "depilerebber": "depilare",
    "depilerebbero": "depilare",
    "depilerei": "depilare",
    "depileremmo": "depilare",
    "depileremo": "depilare",
    "depilereste": "depilare",
    "depileresti": "depilare",
    "depilerete": "depilare",
    "depilerà": "depilare",
    "depilerò": "depilare",
    "depili": "depilare",
    "depiliamo": "depilare",
    "depiliate": "depilare",
    "depilin": "depilare",
    "depilino": "depilare",
    "depilo": "depilare",
    "depilò": "depilare",
    "depista": "depistare",
    "depistaggi": "depistaggio",
    "depistai": "depistare",
    "depistammo": "depistare",
    "depistan": "depistare",
    "depistando": "depistare",
    "depistano": "depistare",
    "depistante": "depistare",
    "depistanti": "depistare",
    "depistar": "depistare",
    "depistaron": "depistare",
    "depistarono": "depistare",
    "depistasse": "depistare",
    "depistasser": "depistare",
    "depistassero": "depistare",
    "depistassi": "depistare",
    "depistassimo": "depistare",
    "depistaste": "depistare",
    "depistasti": "depistare",
    "depistata": "depistare",
    "depistate": "depistare",
    "depistati": "depistare",
    "depistato": "depistare",
    "depistatori": "depistatore",
    "depistava": "depistare",
    "depistavamo": "depistare",
    "depistavan": "depistare",
    "depistavano": "depistare",
    "depistavate": "depistare",
    "depistavi": "depistare",
    "depistavo": "depistare",
    "depisterai": "depistare",
    "depisteran": "depistare",
    "depisteranno": "depistare",
    "depisterebbe": "depistare",
    "depisterebber": "depistare",
    "depisterebbero": "depistare",
    "depisterei": "depistare",
    "depisteremmo": "depistare",
    "depisteremo": "depistare",
    "depistereste": "depistare",
    "depisteresti": "depistare",
    "depisterete": "depistare",
    "depisterà": "depistare",
    "depisterò": "depistare",
    "depisti": "depistare",
    "depistiamo": "depistare",
    "depistiate": "depistare",
    "depistin": "depistare",
    "depistino": "depistare",
    "depisto": "depistare",
    "depistò": "depistare",
    "deplora": "deplorare",
    "deplorabili": "deplorabile",
    "deplorai": "deplorare",
    "deplorammo": "deplorare",
    "deploran": "deplorare",
    "deplorando": "deplorare",
    "deplorano": "deplorare",
    "deplorante": "deplorare",
    "deploranti": "deplorare",
    "deplorar": "deplorare",
    "deploraron": "deplorare",
    "deplorarono": "deplorare",
    "deplorasse": "deplorare",
    "deplorasser": "deplorare",
    "deplorassero": "deplorare",
    "deplorassi": "deplorare",
    "deplorassimo": "deplorare",
    "deploraste": "deplorare",
    "deplorasti": "deplorare",
    "deplorata": "deplorare",
    "deplorate": "deplorare",
    "deplorati": "deplorare",
    "deplorato": "deplorare",
    "deplorava": "deplorare",
    "deploravamo": "deplorare",
    "deploravan": "deplorare",
    "deploravano": "deplorare",
    "deploravate": "deplorare",
    "deploravi": "deplorare",
    "deploravo": "deplorare",
    "deplorazioni": "deplorazione",
    "deplorerai": "deplorare",
    "deploreran": "deplorare",
    "deploreranno": "deplorare",
    "deplorerebbe": "deplorare",
    "deplorerebber": "deplorare",
    "deplorerebbero": "deplorare",
    "deplorerei": "deplorare",
    "deploreremmo": "deplorare",
    "deploreremo": "deplorare",
    "deplorereste": "deplorare",
    "deploreresti": "deplorare",
    "deplorerete": "deplorare",
    "deplorerà": "deplorare",
    "deplorerò": "deplorare",
    "deplorevoli": "deplorevole",
    "deplori": "deplorare",
    "deploriamo": "deplorare",
    "deploriate": "deplorare",
    "deplorin": "deplorare",
    "deplorino": "deplorare",
    "deploro": "deplorare",
    "deplorò": "deplorare",
    "depoliticizza": "depoliticizzare",
    "depoliticizzai": "depoliticizzare",
    "depoliticizzammo": "depoliticizzare",
    "depoliticizzan": "depoliticizzare",
    "depoliticizzando": "depoliticizzare",
    "depoliticizzano": "depoliticizzare",
    "depoliticizzante": "depoliticizzare",
    "depoliticizzanti": "depoliticizzare",
    "depoliticizzar": "depoliticizzare",
    "depoliticizzaron": "depoliticizzare",
    "depoliticizzarono": "depoliticizzare",
    "depoliticizzasse": "depoliticizzare",
    "depoliticizzasser": "depoliticizzare",
    "depoliticizzassero": "depoliticizzare",
    "depoliticizzassi": "depoliticizzare",
    "depoliticizzassimo": "depoliticizzare",
    "depoliticizzaste": "depoliticizzare",
    "depoliticizzasti": "depoliticizzare",
    "depoliticizzata": "depoliticizzare",
    "depoliticizzate": "depoliticizzare",
    "depoliticizzati": "depoliticizzare",
    "depoliticizzato": "depoliticizzare",
    "depoliticizzava": "depoliticizzare",
    "depoliticizzavamo": "depoliticizzare",
    "depoliticizzavan": "depoliticizzare",
    "depoliticizzavano": "depoliticizzare",
    "depoliticizzavate": "depoliticizzare",
    "depoliticizzavi": "depoliticizzare",
    "depoliticizzavo": "depoliticizzare",
    "depoliticizzerai": "depoliticizzare",
    "depoliticizzeran": "depoliticizzare",
    "depoliticizzeranno": "depoliticizzare",
    "depoliticizzerebbe": "depoliticizzare",
    "depoliticizzerebber": "depoliticizzare",
    "depoliticizzerebbero": "depoliticizzare",
    "depoliticizzerei": "depoliticizzare",
    "depoliticizzeremmo": "depoliticizzare",
    "depoliticizzeremo": "depoliticizzare",
    "depoliticizzereste": "depoliticizzare",
    "depoliticizzeresti": "depoliticizzare",
    "depoliticizzerete": "depoliticizzare",
    "depoliticizzerà": "depoliticizzare",
    "depoliticizzerò": "depoliticizzare",
    "depoliticizzi": "depoliticizzare",
    "depoliticizziamo": "depoliticizzare",
    "depoliticizziate": "depoliticizzare",
    "depoliticizzin": "depoliticizzare",
    "depoliticizzino": "depoliticizzare",
    "depoliticizzo": "depoliticizzare",
    "depoliticizzò": "depoliticizzare",
    "depone": "deporre",
    "deponemmo": "deporre",
    "deponendo": "deporre",
    "deponente": "deporre",
    "deponenti": "deporre",
    "deponesse": "deporre",
    "deponesser": "deporre",
    "deponessero": "deporre",
    "deponessi": "deporre",
    "deponessimo": "deporre",
    "deponeste": "deporre",
    "deponesti": "deporre",
    "deponete": "deporre",
    "deponeva": "deporre",
    "deponevamo": "deporre",
    "deponevan": "deporre",
    "deponevano": "deporre",
    "deponevate": "deporre",
    "deponevi": "deporre",
    "deponevo": "deporre",
    "deponga": "deporre",
    "depongan": "deporre",
    "depongano": "deporre",
    "depongo": "deporre",
    "depongon": "deporre",
    "depongono": "deporre",
    "deponi": "deporre",
    "deponiamo": "deporre",
    "deponiate": "deporre",
    "deporr": "deporre",
    "deporrai": "deporre",
    "deporran": "deporre",
    "deporranno": "deporre",
    "deporrebbe": "deporre",
    "deporrebber": "deporre",
    "deporrebbero": "deporre",
    "deporrei": "deporre",
    "deporremmo": "deporre",
    "deporremo": "deporre",
    "deporreste": "deporre",
    "deporresti": "deporre",
    "deporrete": "deporre",
    "deporrà": "deporre",
    "deporrò": "deporre",
    "deporta": "deportare",
    "deportai": "deportare",
    "deportammo": "deportare",
    "deportan": "deportare",
    "deportando": "deportare",
    "deportano": "deportare",
    "deportante": "deportare",
    "deportanti": "deportare",
    "deportar": "deportare",
    "deportaron": "deportare",
    "deportarono": "deportare",
    "deportasse": "deportare",
    "deportasser": "deportare",
    "deportassero": "deportare",
    "deportassi": "deportare",
    "deportassimo": "deportare",
    "deportaste": "deportare",
    "deportasti": "deportare",
    "deportata": "deportato",
    "deportate": "deportato",
    "deportati": "deportato",
    "deportato": "deportare",
    "deportava": "deportare",
    "deportavamo": "deportare",
    "deportavan": "deportare",
    "deportavano": "deportare",
    "deportavate": "deportare",
    "deportavi": "deportare",
    "deportavo": "deportare",
    "deportazioni": "deportazione",
    "deporterai": "deportare",
    "deporteran": "deportare",
    "deporteranno": "deportare",
    "deporterebbe": "deportare",
    "deporterebber": "deportare",
    "deporterebbero": "deportare",
    "deporterei": "deportare",
    "deporteremmo": "deportare",
    "deporteremo": "deportare",
    "deportereste": "deportare",
    "deporteresti": "deportare",
    "deporterete": "deportare",
    "deporterà": "deportare",
    "deporterò": "deportare",
    "deporti": "deportare",
    "deportiamo": "deportare",
    "deportiate": "deportare",
    "deportin": "deportare",
    "deportino": "deportare",
    "deporto": "deportare",
    "deportò": "deportare",
    "depose": "deporre",
    "deposer": "deporre",
    "deposero": "deporre",
    "deposi": "deporre",
    "deposita": "depositare",
    "depositai": "depositare",
    "depositammo": "depositare",
    "depositan": "depositare",
    "depositando": "depositare",
    "depositano": "depositare",
    "depositante": "depositare",
    "depositanti": "depositare",
    "depositar": "depositare",
    "depositari": "depositario",
    "depositaron": "depositare",
    "depositarono": "depositare",
    "depositasse": "depositare",
    "depositasser": "depositare",
    "depositassero": "depositare",
    "depositassi": "depositare",
    "depositassimo": "depositare",
    "depositaste": "depositare",
    "depositasti": "depositare",
    "depositata": "depositare",
    "depositate": "depositare",
    "depositati": "depositare",
    "depositato": "depositare",
    "depositava": "depositare",
    "depositavamo": "depositare",
    "depositavan": "depositare",
    "depositavano": "depositare",
    "depositavate": "depositare",
    "depositavi": "depositare",
    "depositavo": "depositare",
    "depositerai": "depositare",
    "depositeran": "depositare",
    "depositeranno": "depositare",
    "depositerebbe": "depositare",
    "depositerebber": "depositare",
    "depositerebbero": "depositare",
    "depositerei": "depositare",
    "depositeremmo": "depositare",
    "depositeremo": "depositare",
    "depositereste": "depositare",
    "depositeresti": "depositare",
    "depositerete": "depositare",
    "depositerà": "depositare",
    "depositerò": "depositare",
    "depositi": "deposito",
    "depositiamo": "depositare",
    "depositiate": "depositare",
    "depositin": "depositare",
    "depositino": "depositare",
    "deposito": "depositare",
    "depositò": "depositare",
    "deposizioni": "deposizione",
    "deposta": "deporre",
    "deposte": "deporre",
    "deposti": "deposto",
    "deposto": "deporre",
    "depotenzi": "depotenziare",
    "depotenzia": "depotenziare",
    "depotenziai": "depotenziare",
    "depotenziammo": "depotenziare",
    "depotenziamo": "depotenziare",
    "depotenzian": "depotenziare",
    "depotenziando": "depotenziare",
    "depotenziano": "depotenziare",
    "depotenziante": "depotenziare",
    "depotenzianti": "depotenziare",
    "depotenziar": "depotenziare",
    "depotenziaron": "depotenziare",
    "depotenziarono": "depotenziare",
    "depotenziasse": "depotenziare",
    "depotenziasser": "depotenziare",
    "depotenziassero": "depotenziare",
    "depotenziassi": "depotenziare",
    "depotenziassimo": "depotenziare",
    "depotenziaste": "depotenziare",
    "depotenziasti": "depotenziare",
    "depotenziata": "depotenziare",
    "depotenziate": "depotenziare",
    "depotenziati": "depotenziare",
    "depotenziato": "depotenziare",
    "depotenziava": "depotenziare",
    "depotenziavamo": "depotenziare",
    "depotenziavan": "depotenziare",
    "depotenziavano": "depotenziare",
    "depotenziavate": "depotenziare",
    "depotenziavi": "depotenziare",
    "depotenziavo": "depotenziare",
    "depotenzierai": "depotenziare",
    "depotenzieran": "depotenziare",
    "depotenzieranno": "depotenziare",
    "depotenzierebbe": "depotenziare",
    "depotenzierebber": "depotenziare",
    "depotenzierebbero": "depotenziare",
    "depotenzierei": "depotenziare",
    "depotenzieremmo": "depotenziare",
    "depotenzieremo": "depotenziare",
    "depotenziereste": "depotenziare",
    "depotenzieresti": "depotenziare",
    "depotenzierete": "depotenziare",
    "depotenzierà": "depotenziare",
    "depotenzierò": "depotenziare",
    "depotenzin": "depotenziare",
    "depotenzino": "depotenziare",
    "depotenzio": "depotenziare",
    "depotenziò": "depotenziare",
    "deprava": "depravare",
    "depravai": "depravare",
    "depravammo": "depravare",
    "depravan": "depravare",
    "depravando": "depravare",
    "depravano": "depravare",
    "depravante": "depravare",
    "depravanti": "depravare",
    "depravar": "depravare",
    "depravaron": "depravare",
    "depravarono": "depravare",
    "depravasse": "depravare",
    "depravasser": "depravare",
    "depravassero": "depravare",
    "depravassi": "depravare",
    "depravassimo": "depravare",
    "depravaste": "depravare",
    "depravasti": "depravare",
    "depravata": "depravare",
    "depravate": "depravare",
    "depravati": "depravare",
    "depravato": "depravare",
    "depravava": "depravare",
    "depravavamo": "depravare",
    "depravavan": "depravare",
    "depravavano": "depravare",
    "depravavate": "depravare",
    "depravavi": "depravare",
    "depravavo": "depravare",
    "depravazioni": "depravazione",
    "depraverai": "depravare",
    "depraveran": "depravare",
    "depraveranno": "depravare",
    "depraverebbe": "depravare",
    "depraverebber": "depravare",
    "depraverebbero": "depravare",
    "depraverei": "depravare",
    "depraveremmo": "depravare",
    "depraveremo": "depravare",
    "depravereste": "depravare",
    "depraveresti": "depravare",
    "depraverete": "depravare",
    "depraverà": "depravare",
    "depraverò": "depravare",
    "depravi": "depravare",
    "depraviamo": "depravare",
    "depraviate": "depravare",
    "depravin": "depravare",
    "depravino": "depravare",
    "depravo": "depravare",
    "depravò": "depravare",
    "depreca": "deprecare",
    "deprecabili": "deprecabile",
    "deprecai": "deprecare",
    "deprecammo": "deprecare",
    "deprecan": "deprecare",
    "deprecando": "deprecare",
    "deprecano": "deprecare",
    "deprecante": "deprecare",
    "deprecanti": "deprecare",
    "deprecar": "deprecare",
    "deprecaron": "deprecare",
    "deprecarono": "deprecare",
    "deprecasse": "deprecare",
    "deprecasser": "deprecare",
    "deprecassero": "deprecare",
    "deprecassi": "deprecare",
    "deprecassimo": "deprecare",
    "deprecaste": "deprecare",
    "deprecasti": "deprecare",
    "deprecata": "deprecare",
    "deprecate": "deprecare",
    "deprecati": "deprecare",
    "deprecato": "deprecare",
    "deprecava": "deprecare",
    "deprecavamo": "deprecare",
    "deprecavan": "deprecare",
    "deprecavano": "deprecare",
    "deprecavate": "deprecare",
    "deprecavi": "deprecare",
    "deprecavo": "deprecare",
    "deprecherai": "deprecare",
    "deprecheran": "deprecare",
    "deprecheranno": "deprecare",
    "deprecherebbe": "deprecare",
    "deprecherebber": "deprecare",
    "deprecherebbero": "deprecare",
    "deprecherei": "deprecare",
    "deprecheremmo": "deprecare",
    "deprecheremo": "deprecare",
    "deprechereste": "deprecare",
    "deprecheresti": "deprecare",
    "deprecherete": "deprecare",
    "deprecherà": "deprecare",
    "deprecherò": "deprecare",
    "deprechi": "deprecare",
    "deprechiamo": "deprecare",
    "deprechiate": "deprecare",
    "deprechin": "deprecare",
    "deprechino": "deprecare",
    "depreco": "deprecare",
    "deprecò": "deprecare",
    "depreda": "depredare",
    "depredai": "depredare",
    "depredammo": "depredare",
    "depredan": "depredare",
    "depredando": "depredare",
    "depredano": "depredare",
    "depredante": "depredare",
    "depredanti": "depredare",
    "depredar": "depredare",
    "depredaron": "depredare",
    "depredarono": "depredare",
    "depredasse": "depredare",
    "depredasser": "depredare",
    "depredassero": "depredare",
    "depredassi": "depredare",
    "depredassimo": "depredare",
    "depredaste": "depredare",
    "depredasti": "depredare",
    "depredata": "depredare",
    "depredate": "depredare",
    "depredati": "depredare",
    "depredato": "depredare",
    "depredava": "depredare",
    "depredavamo": "depredare",
    "depredavan": "depredare",
    "depredavano": "depredare",
    "depredavate": "depredare",
    "depredavi": "depredare",
    "depredavo": "depredare",
    "deprederai": "depredare",
    "deprederan": "depredare",
    "deprederanno": "depredare",
    "deprederebbe": "depredare",
    "deprederebber": "depredare",
    "deprederebbero": "depredare",
    "deprederei": "depredare",
    "deprederemmo": "depredare",
    "deprederemo": "depredare",
    "depredereste": "depredare",
    "deprederesti": "depredare",
    "deprederete": "depredare",
    "deprederà": "depredare",
    "deprederò": "depredare",
    "depredi": "depredare",
    "deprediamo": "depredare",
    "deprediate": "depredare",
    "depredin": "depredare",
    "depredino": "depredare",
    "depredo": "depredare",
    "depredò": "depredare",
    "depressa": "deprimere",
    "depresse": "deprimere",
    "depresser": "deprimere",
    "depressero": "deprimere",
    "depressi": "deprimere",
    "depressioni": "depressione",
    "depressiva": "depressivo",
    "depressive": "depressivo",
    "depressivi": "depressivo",
    "depresso": "deprimere",
    "deprezza": "deprezzare",
    "deprezzai": "deprezzare",
    "deprezzamenti": "deprezzamento",
    "deprezzammo": "deprezzare",
    "deprezzan": "deprezzare",
    "deprezzando": "deprezzare",
    "deprezzano": "deprezzare",
    "deprezzante": "deprezzare",
    "deprezzanti": "deprezzare",
    "deprezzar": "deprezzare",
    "deprezzaron": "deprezzare",
    "deprezzarono": "deprezzare",
    "deprezzasse": "deprezzare",
    "deprezzasser": "deprezzare",
    "deprezzassero": "deprezzare",
    "deprezzassi": "deprezzare",
    "deprezzassimo": "deprezzare",
    "deprezzaste": "deprezzare",
    "deprezzasti": "deprezzare",
    "deprezzata": "deprezzare",
    "deprezzate": "deprezzare",
    "deprezzati": "deprezzare",
    "deprezzato": "deprezzare",
    "deprezzava": "deprezzare",
    "deprezzavamo": "deprezzare",
    "deprezzavan": "deprezzare",
    "deprezzavano": "deprezzare",
    "deprezzavate": "deprezzare",
    "deprezzavi": "deprezzare",
    "deprezzavo": "deprezzare",
    "deprezzerai": "deprezzare",
    "deprezzeran": "deprezzare",
    "deprezzeranno": "deprezzare",
    "deprezzerebbe": "deprezzare",
    "deprezzerebber": "deprezzare",
    "deprezzerebbero": "deprezzare",
    "deprezzerei": "deprezzare",
    "deprezzeremmo": "deprezzare",
    "deprezzeremo": "deprezzare",
    "deprezzereste": "deprezzare",
    "deprezzeresti": "deprezzare",
    "deprezzerete": "deprezzare",
    "deprezzerà": "deprezzare",
    "deprezzerò": "deprezzare",
    "deprezzi": "deprezzare",
    "deprezziamo": "deprezzare",
    "deprezziate": "deprezzare",
    "deprezzin": "deprezzare",
    "deprezzino": "deprezzare",
    "deprezzo": "deprezzare",
    "deprezzò": "deprezzare",
    "deprima": "deprimere",
    "depriman": "deprimere",
    "deprimano": "deprimere",
    "deprime": "deprimere",
    "deprimemmo": "deprimere",
    "deprimendo": "deprimere",
    "deprimente": "deprimere",
    "deprimenti": "deprimere",
    "deprimer": "deprimere",
    "deprimerai": "deprimere",
    "deprimeran": "deprimere",
    "deprimeranno": "deprimere",
    "deprimerebbe": "deprimere",
    "deprimerebber": "deprimere",
    "deprimerebbero": "deprimere",
    "deprimerei": "deprimere",
    "deprimeremmo": "deprimere",
    "deprimeremo": "deprimere",
    "deprimereste": "deprimere",
    "deprimeresti": "deprimere",
    "deprimerete": "deprimere",
    "deprimerà": "deprimere",
    "deprimerò": "deprimere",
    "deprimesse": "deprimere",
    "deprimesser": "deprimere",
    "deprimessero": "deprimere",
    "deprimessi": "deprimere",
    "deprimessimo": "deprimere",
    "deprimeste": "deprimere",
    "deprimesti": "deprimere",
    "deprimete": "deprimere",
    "deprimeva": "deprimere",
    "deprimevamo": "deprimere",
    "deprimevan": "deprimere",
    "deprimevano": "deprimere",
    "deprimevate": "deprimere",
    "deprimevi": "deprimere",
    "deprimevo": "deprimere",
    "deprimi": "deprimere",
    "deprimiamo": "deprimere",
    "deprimiate": "deprimere",
    "deprimibili": "deprimibile",
    "deprimo": "deprimere",
    "deprimon": "deprimere",
    "deprimono": "deprimere",
    "depriva": "deprivare",
    "deprivai": "deprivare",
    "deprivammo": "deprivare",
    "deprivan": "deprivare",
    "deprivando": "deprivare",
    "deprivano": "deprivare",
    "deprivante": "deprivare",
    "deprivanti": "deprivare",
    "deprivar": "deprivare",
    "deprivaron": "deprivare",
    "deprivarono": "deprivare",
    "deprivasse": "deprivare",
    "deprivasser": "deprivare",
    "deprivassero": "deprivare",
    "deprivassi": "deprivare",
    "deprivassimo": "deprivare",
    "deprivaste": "deprivare",
    "deprivasti": "deprivare",
    "deprivata": "deprivare",
    "deprivate": "deprivare",
    "deprivati": "deprivare",
    "deprivato": "deprivare",
    "deprivava": "deprivare",
    "deprivavamo": "deprivare",
    "deprivavan": "deprivare",
    "deprivavano": "deprivare",
    "deprivavate": "deprivare",
    "deprivavi": "deprivare",
    "deprivavo": "deprivare",
    "depriverai": "deprivare",
    "depriveran": "deprivare",
    "depriveranno": "deprivare",
    "depriverebbe": "deprivare",
    "depriverebber": "deprivare",
    "depriverebbero": "deprivare",
    "depriverei": "deprivare",
    "depriveremmo": "deprivare",
    "depriveremo": "deprivare",
    "deprivereste": "deprivare",
    "depriveresti": "deprivare",
    "depriverete": "deprivare",
    "depriverà": "deprivare",
    "depriverò": "deprivare",
    "deprivi": "deprivare",
    "depriviamo": "deprivare",
    "depriviate": "deprivare",
    "deprivin": "deprivare",
    "deprivino": "deprivare",
    "deprivo": "deprivare",
    "deprivò": "deprivare",
    "depura": "depurare",
    "depurai": "depurare",
    "depurammo": "depurare",
    "depuran": "depurare",
    "depurando": "depurare",
    "depurano": "depurare",
    "depurante": "depurare",
    "depuranti": "depurare",
    "depurar": "depurare",
    "depuraron": "depurare",
    "depurarono": "depurare",
    "depurasse": "depurare",
    "depurasser": "depurare",
    "depurassero": "depurare",
    "depurassi": "depurare",
    "depurassimo": "depurare",
    "depuraste": "depurare",
    "depurasti": "depurare",
    "depurata": "depurare",
    "depurate": "depurare",
    "depurati": "depurare",
    "depurato": "depurare",
    "depuratori": "depuratorio",
    "depuratoria": "depuratorio",
    "depuratorie": "depuratorio",
    "depuratrice": "depuratore",
    "depuratrici": "depuratore",
    "depurava": "depurare",
    "depuravamo": "depurare",
    "depuravan": "depurare",
    "depuravano": "depurare",
    "depuravate": "depurare",
    "depuravi": "depurare",
    "depuravo": "depurare",
    "depurazioni": "depurazione",
    "depurerai": "depurare",
    "depureran": "depurare",
    "depureranno": "depurare",
    "depurerebbe": "depurare",
    "depurerebber": "depurare",
    "depurerebbero": "depurare",
    "depurerei": "depurare",
    "depureremmo": "depurare",
    "depureremo": "depurare",
    "depurereste": "depurare",
    "depureresti": "depurare",
    "depurerete": "depurare",
    "depurerà": "depurare",
    "depurerò": "depurare",
    "depuri": "depurare",
    "depuriamo": "depurare",
    "depuriate": "depurare",
    "depurin": "depurare",
    "depurino": "depurare",
    "depuro": "depurare",
    "depurò": "depurare",
    "deputa": "deputare",
    "deputai": "deputare",
    "deputammo": "deputare",
    "deputan": "deputare",
    "deputando": "deputare",
    "deputano": "deputare",
    "deputante": "deputare",
    "deputanti": "deputare",
    "deputar": "deputare",
    "deputaron": "deputare",
    "deputarono": "deputare",
    "deputasse": "deputare",
    "deputasser": "deputare",
    "deputassero": "deputare",
    "deputassi": "deputare",
    "deputassimo": "deputare",
    "deputaste": "deputare",
    "deputasti": "deputare",
    "deputata": "deputare",
    "deputate": "deputata",
    "deputati": "deputato",
    "deputato": "deputare",
    "deputava": "deputare",
    "deputavamo": "deputare",
    "deputavan": "deputare",
    "deputavano": "deputare",
    "deputavate": "deputare",
    "deputavi": "deputare",
    "deputavo": "deputare",
    "deputazioni": "deputazione",
    "deputerai": "deputare",
    "deputeran": "deputare",
    "deputeranno": "deputare",
    "deputerebbe": "deputare",
    "deputerebber": "deputare",
    "deputerebbero": "deputare",
    "deputerei": "deputare",
    "deputeremmo": "deputare",
    "deputeremo": "deputare",
    "deputereste": "deputare",
    "deputeresti": "deputare",
    "deputerete": "deputare",
    "deputerà": "deputare",
    "deputerò": "deputare",
    "deputi": "deputare",
    "deputiamo": "deputare",
    "deputiate": "deputare",
    "deputin": "deputare",
    "deputino": "deputare",
    "deputo": "deputare",
    "deputò": "deputare",
    "dequalifica": "dequalificare",
    "dequalificai": "dequalificare",
    "dequalificammo": "dequalificare",
    "dequalifican": "dequalificare",
    "dequalificando": "dequalificare",
    "dequalificano": "dequalificare",
    "dequalificante": "dequalificare",
    "dequalificanti": "dequalificare",
    "dequalificar": "dequalificare",
    "dequalificaron": "dequalificare",
    "dequalificarono": "dequalificare",
    "dequalificasse": "dequalificare",
    "dequalificasser": "dequalificare",
    "dequalificassero": "dequalificare",
    "dequalificassi": "dequalificare",
    "dequalificassimo": "dequalificare",
    "dequalificaste": "dequalificare",
    "dequalificasti": "dequalificare",
    "dequalificata": "dequalificare",
    "dequalificate": "dequalificare",
    "dequalificati": "dequalificare",
    "dequalificato": "dequalificare",
    "dequalificava": "dequalificare",
    "dequalificavamo": "dequalificare",
    "dequalificavan": "dequalificare",
    "dequalificavano": "dequalificare",
    "dequalificavate": "dequalificare",
    "dequalificavi": "dequalificare",
    "dequalificavo": "dequalificare",
    "dequalificherai": "dequalificare",
    "dequalificheran": "dequalificare",
    "dequalificheranno": "dequalificare",
    "dequalificherebbe": "dequalificare",
    "dequalificherebber": "dequalificare",
    "dequalificherebbero": "dequalificare",
    "dequalificherei": "dequalificare",
    "dequalificheremmo": "dequalificare",
    "dequalificheremo": "dequalificare",
    "dequalifichereste": "dequalificare",
    "dequalificheresti": "dequalificare",
    "dequalificherete": "dequalificare",
    "dequalificherà": "dequalificare",
    "dequalificherò": "dequalificare",
    "dequalifichi": "dequalificare",
    "dequalifichiamo": "dequalificare",
    "dequalifichiate": "dequalificare",
    "dequalifichin": "dequalificare",
    "dequalifichino": "dequalificare",
    "dequalifico": "dequalificare",
    "dequalificò": "dequalificare",
    "deragli": "deragliare",
    "deraglia": "deragliare",
    "deragliai": "deragliare",
    "deragliamenti": "deragliamento",
    "deragliammo": "deragliare",
    "deragliamo": "deragliare",
    "deraglian": "deragliare",
    "deragliando": "deragliare",
    "deragliano": "deragliare",
    "deragliante": "deragliare",
    "deraglianti": "deragliare",
    "deragliar": "deragliare",
    "deragliaron": "deragliare",
    "deragliarono": "deragliare",
    "deragliasse": "deragliare",
    "deragliasser": "deragliare",
    "deragliassero": "deragliare",
    "deragliassi": "deragliare",
    "deragliassimo": "deragliare",
    "deragliaste": "deragliare",
    "deragliasti": "deragliare",
    "deragliata": "deragliare",
    "deragliate": "deragliare",
    "deragliati": "deragliare",
    "deragliato": "deragliare",
    "deragliava": "deragliare",
    "deragliavamo": "deragliare",
    "deragliavan": "deragliare",
    "deragliavano": "deragliare",
    "deragliavate": "deragliare",
    "deragliavi": "deragliare",
    "deragliavo": "deragliare",
    "deraglierai": "deragliare",
    "deraglieran": "deragliare",
    "deraglieranno": "deragliare",
    "deraglierebbe": "deragliare",
    "deraglierebber": "deragliare",
    "deraglierebbero": "deragliare",
    "deraglierei": "deragliare",
    "deraglieremmo": "deragliare",
    "deraglieremo": "deragliare",
    "deragliereste": "deragliare",
    "deraglieresti": "deragliare",
    "deraglierete": "deragliare",
    "deraglierà": "deragliare",
    "deraglierò": "deragliare",
    "deraglin": "deragliare",
    "deraglino": "deragliare",
    "deraglio": "deragliare",
    "deragliò": "deragliare",
    "derapa": "derapare",
    "derapai": "derapare",
    "derapammo": "derapare",
    "derapan": "derapare",
    "derapando": "derapare",
    "derapano": "derapare",
    "derapante": "derapare",
    "derapanti": "derapare",
    "derapar": "derapare",
    "deraparon": "derapare",
    "deraparono": "derapare",
    "derapasse": "derapare",
    "derapasser": "derapare",
    "derapassero": "derapare",
    "derapassi": "derapare",
    "derapassimo": "derapare",
    "derapaste": "derapare",
    "derapasti": "derapare",
    "derapata": "derapare",
    "derapate": "derapare",
    "derapati": "derapare",
    "derapato": "derapare",
    "derapava": "derapare",
    "derapavamo": "derapare",
    "derapavan": "derapare",
    "derapavano": "derapare",
    "derapavate": "derapare",
    "derapavi": "derapare",
    "derapavo": "derapare",
    "deraperai": "derapare",
    "deraperan": "derapare",
    "deraperanno": "derapare",
    "deraperebbe": "derapare",
    "deraperebber": "derapare",
    "deraperebbero": "derapare",
    "deraperei": "derapare",
    "deraperemmo": "derapare",
    "deraperemo": "derapare",
    "derapereste": "derapare",
    "deraperesti": "derapare",
    "deraperete": "derapare",
    "deraperà": "derapare",
    "deraperò": "derapare",
    "derapi": "derapare",
    "derapiamo": "derapare",
    "derapiate": "derapare",
    "derapin": "derapare",
    "derapino": "derapare",
    "derapo": "derapare",
    "derapò": "derapare",
    "derattizza": "derattizzare",
    "derattizzai": "derattizzare",
    "derattizzammo": "derattizzare",
    "derattizzan": "derattizzare",
    "derattizzando": "derattizzare",
    "derattizzano": "derattizzare",
    "derattizzante": "derattizzare",
    "derattizzanti": "derattizzare",
    "derattizzar": "derattizzare",
    "derattizzaron": "derattizzare",
    "derattizzarono": "derattizzare",
    "derattizzasse": "derattizzare",
    "derattizzasser": "derattizzare",
    "derattizzassero": "derattizzare",
    "derattizzassi": "derattizzare",
    "derattizzassimo": "derattizzare",
    "derattizzaste": "derattizzare",
    "derattizzasti": "derattizzare",
    "derattizzata": "derattizzare",
    "derattizzate": "derattizzare",
    "derattizzati": "derattizzare",
    "derattizzato": "derattizzare",
    "derattizzava": "derattizzare",
    "derattizzavamo": "derattizzare",
    "derattizzavan": "derattizzare",
    "derattizzavano": "derattizzare",
    "derattizzavate": "derattizzare",
    "derattizzavi": "derattizzare",
    "derattizzavo": "derattizzare",
    "derattizzerai": "derattizzare",
    "derattizzeran": "derattizzare",
    "derattizzeranno": "derattizzare",
    "derattizzerebbe": "derattizzare",
    "derattizzerebber": "derattizzare",
    "derattizzerebbero": "derattizzare",
    "derattizzerei": "derattizzare",
    "derattizzeremmo": "derattizzare",
    "derattizzeremo": "derattizzare",
    "derattizzereste": "derattizzare",
    "derattizzeresti": "derattizzare",
    "derattizzerete": "derattizzare",
    "derattizzerà": "derattizzare",
    "derattizzerò": "derattizzare",
    "derattizzi": "derattizzare",
    "derattizziamo": "derattizzare",
    "derattizziate": "derattizzare",
    "derattizzin": "derattizzare",
    "derattizzino": "derattizzare",
    "derattizzo": "derattizzare",
    "derattizzò": "derattizzare",
    "deregola": "deregolare",
    "deregolai": "deregolare",
    "deregolamenta": "deregolamentare",
    "deregolamentai": "deregolamentare",
    "deregolamentammo": "deregolamentare",
    "deregolamentan": "deregolamentare",
    "deregolamentando": "deregolamentare",
    "deregolamentano": "deregolamentare",
    "deregolamentante": "deregolamentare",
    "deregolamentanti": "deregolamentare",
    "deregolamentar": "deregolamentare",
    "deregolamentaron": "deregolamentare",
    "deregolamentarono": "deregolamentare",
    "deregolamentasse": "deregolamentare",
    "deregolamentasser": "deregolamentare",
    "deregolamentassero": "deregolamentare",
    "deregolamentassi": "deregolamentare",
    "deregolamentassimo": "deregolamentare",
    "deregolamentaste": "deregolamentare",
    "deregolamentasti": "deregolamentare",
    "deregolamentata": "deregolamentato",
    "deregolamentate": "deregolamentato",
    "deregolamentati": "deregolamentato",
    "deregolamentato": "deregolamentare",
    "deregolamentava": "deregolamentare",
    "deregolamentavamo": "deregolamentare",
    "deregolamentavan": "deregolamentare",
    "deregolamentavano": "deregolamentare",
    "deregolamentavate": "deregolamentare",
    "deregolamentavi": "deregolamentare",
    "deregolamentavo": "deregolamentare",
    "deregolamentazioni": "deregolamentazione",
    "deregolamenterai": "deregolamentare",
    "deregolamenteran": "deregolamentare",
    "deregolamenteranno": "deregolamentare",
    "deregolamenterebbe": "deregolamentare",
    "deregolamenterebber": "deregolamentare",
    "deregolamenterebbero": "deregolamentare",
    "deregolamenterei": "deregolamentare",
    "deregolamenteremmo": "deregolamentare",
    "deregolamenteremo": "deregolamentare",
    "deregolamentereste": "deregolamentare",
    "deregolamenteresti": "deregolamentare",
    "deregolamenterete": "deregolamentare",
    "deregolamenterà": "deregolamentare",
    "deregolamenterò": "deregolamentare",
    "deregolamenti": "deregolamentare",
    "deregolamentiamo": "deregolamentare",
    "deregolamentiate": "deregolamentare",
    "deregolamentin": "deregolamentare",
    "deregolamentino": "deregolamentare",
    "deregolamento": "deregolamentare",
    "deregolamentò": "deregolamentare",
    "deregolammo": "deregolare",
    "deregolan": "deregolare",
    "deregolando": "deregolare",
    "deregolano": "deregolare",
    "deregolante": "deregolare",
    "deregolanti": "deregolare",
    "deregolar": "deregolare",
    "deregolaron": "deregolare",
    "deregolarono": "deregolare",
    "deregolasse": "deregolare",
    "deregolasser": "deregolare",
    "deregolassero": "deregolare",
    "deregolassi": "deregolare",
    "deregolassimo": "deregolare",
    "deregolaste": "deregolare",
    "deregolasti": "deregolare",
    "deregolata": "deregolare",
    "deregolate": "deregolare",
    "deregolati": "deregolare",
    "deregolato": "deregolare",
    "deregolatori": "deregolatorio",
    "deregolatoria": "deregolatorio",
    "deregolatorie": "deregolatorio",
    "deregolatrici": "deregolatrice",
    "deregolava": "deregolare",
    "deregolavamo": "deregolare",
    "deregolavan": "deregolare",
    "deregolavano": "deregolare",
    "deregolavate": "deregolare",
    "deregolavi": "deregolare",
    "deregolavo": "deregolare",
    "deregolerai": "deregolare",
    "deregoleran": "deregolare",
    "deregoleranno": "deregolare",
    "deregolerebbe": "deregolare",
    "deregolerebber": "deregolare",
    "deregolerebbero": "deregolare",
    "deregolerei": "deregolare",
    "deregoleremmo": "deregolare",
    "deregoleremo": "deregolare",
    "deregolereste": "deregolare",
    "deregoleresti": "deregolare",
    "deregolerete": "deregolare",
    "deregolerà": "deregolare",
    "deregolerò": "deregolare",
    "deregoli": "deregolare",
    "deregoliamo": "deregolare",
    "deregoliate": "deregolare",
    "deregolin": "deregolare",
    "deregolino": "deregolare",
    "deregolo": "deregolare",
    "deregolò": "deregolare",
    "derelitta": "derelitto",
    "derelitte": "derelitto",
    "derelitti": "derelitto",
    "deresponsabilizza": "deresponsabilizzare",
    "deresponsabilizzai": "deresponsabilizzare",
    "deresponsabilizzammo": "deresponsabilizzare",
    "deresponsabilizzan": "deresponsabilizzare",
    "deresponsabilizzando": "deresponsabilizzare",
    "deresponsabilizzano": "deresponsabilizzare",
    "deresponsabilizzante": "deresponsabilizzare",
    "deresponsabilizzanti": "deresponsabilizzare",
    "deresponsabilizzar": "deresponsabilizzare",
    "deresponsabilizzaron": "deresponsabilizzare",
    "deresponsabilizzarono": "deresponsabilizzare",
    "deresponsabilizzasse": "deresponsabilizzare",
    "deresponsabilizzasser": "deresponsabilizzare",
    "deresponsabilizzassero": "deresponsabilizzare",
    "deresponsabilizzassi": "deresponsabilizzare",
    "deresponsabilizzassimo": "deresponsabilizzare",
    "deresponsabilizzaste": "deresponsabilizzare",
    "deresponsabilizzasti": "deresponsabilizzare",
    "deresponsabilizzata": "deresponsabilizzare",
    "deresponsabilizzate": "deresponsabilizzare",
    "deresponsabilizzati": "deresponsabilizzare",
    "deresponsabilizzato": "deresponsabilizzare",
    "deresponsabilizzava": "deresponsabilizzare",
    "deresponsabilizzavamo": "deresponsabilizzare",
    "deresponsabilizzavan": "deresponsabilizzare",
    "deresponsabilizzavano": "deresponsabilizzare",
    "deresponsabilizzavate": "deresponsabilizzare",
    "deresponsabilizzavi": "deresponsabilizzare",
    "deresponsabilizzavo": "deresponsabilizzare",
    "deresponsabilizzazioni": "deresponsabilizzazione",
    "deresponsabilizzerai": "deresponsabilizzare",
    "deresponsabilizzeran": "deresponsabilizzare",
    "deresponsabilizzeranno": "deresponsabilizzare",
    "deresponsabilizzerebbe": "deresponsabilizzare",
    "deresponsabilizzerebber": "deresponsabilizzare",
    "deresponsabilizzerebbero": "deresponsabilizzare",
    "deresponsabilizzerei": "deresponsabilizzare",
    "deresponsabilizzeremmo": "deresponsabilizzare",
    "deresponsabilizzeremo": "deresponsabilizzare",
    "deresponsabilizzereste": "deresponsabilizzare",
    "deresponsabilizzeresti": "deresponsabilizzare",
    "deresponsabilizzerete": "deresponsabilizzare",
    "deresponsabilizzerà": "deresponsabilizzare",
    "deresponsabilizzerò": "deresponsabilizzare",
    "deresponsabilizzi": "deresponsabilizzare",
    "deresponsabilizziamo": "deresponsabilizzare",
    "deresponsabilizziate": "deresponsabilizzare",
    "deresponsabilizzin": "deresponsabilizzare",
    "deresponsabilizzino": "deresponsabilizzare",
    "deresponsabilizzo": "deresponsabilizzare",
    "deresponsabilizzò": "deresponsabilizzare",
    "derida": "deridere",
    "deridan": "deridere",
    "deridano": "deridere",
    "deride": "deridere",
    "deridemmo": "deridere",
    "deridendo": "deridere",
    "deridente": "deridere",
    "deridenti": "deridere",
    "derider": "deridere",
    "deriderai": "deridere",
    "derideran": "deridere",
    "derideranno": "deridere",
    "deriderebbe": "deridere",
    "deriderebber": "deridere",
    "deriderebbero": "deridere",
    "deriderei": "deridere",
    "derideremmo": "deridere",
    "derideremo": "deridere",
    "deridereste": "deridere",
    "derideresti": "deridere",
    "deriderete": "deridere",
    "deriderà": "deridere",
    "deriderò": "deridere",
    "deridesse": "deridere",
    "deridesser": "deridere",
    "deridessero": "deridere",
    "deridessi": "deridere",
    "deridessimo": "deridere",
    "derideste": "deridere",
    "deridesti": "deridere",
    "deridete": "deridere",
    "derideva": "deridere",
    "deridevamo": "deridere",
    "deridevan": "deridere",
    "deridevano": "deridere",
    "deridevate": "deridere",
    "deridevi": "deridere",
    "deridevo": "deridere",
    "deridi": "deridere",
    "deridiamo": "deridere",
    "deridiate": "deridere",
    "derido": "deridere",
    "deridon": "deridere",
    "deridono": "deridere",
    "derisa": "deriso",
    "derise": "deriso",
    "deriser": "deridere",
    "derisero": "deridere",
    "derisi": "deriso",
    "derisioni": "derisione",
    "deriso": "deridere",
    "derisori": "derisorio",
    "derisoria": "derisorio",
    "derisorie": "derisorio",
    "deriva": "derivare",
    "derivai": "derivare",
    "derivammo": "derivare",
    "derivan": "derivare",
    "derivando": "derivare",
    "derivano": "derivare",
    "derivante": "derivare",
    "derivanti": "derivare",
    "derivar": "derivare",
    "derivaron": "derivare",
    "derivarono": "derivare",
    "derivasse": "derivare",
    "derivasser": "derivare",
    "derivassero": "derivare",
    "derivassi": "derivare",
    "derivassimo": "derivare",
    "derivaste": "derivare",
    "derivasti": "derivare",
    "derivata": "derivato",
    "derivate": "derivato",
    "derivati": "derivato",
    "derivativa": "derivativo",
    "derivative": "derivativo",
    "derivativi": "derivativo",
    "derivato": "derivare",
    "derivava": "derivare",
    "derivavamo": "derivare",
    "derivavan": "derivare",
    "derivavano": "derivare",
    "derivavate": "derivare",
    "derivavi": "derivare",
    "derivavo": "derivare",
    "derivazioni": "derivazione",
    "deriverai": "derivare",
    "deriveran": "derivare",
    "deriveranno": "derivare",
    "deriverebbe": "derivare",
    "deriverebber": "derivare",
    "deriverebbero": "derivare",
    "deriverei": "derivare",
    "deriveremmo": "derivare",
    "deriveremo": "derivare",
    "derivereste": "derivare",
    "deriveresti": "derivare",
    "deriverete": "derivare",
    "deriverà": "derivare",
    "deriverò": "derivare",
    "derivi": "derivare",
    "deriviamo": "derivare",
    "deriviate": "derivare",
    "derivin": "derivare",
    "derivino": "derivare",
    "derivo": "derivare",
    "derivò": "derivare",
    "dermatiti": "dermatite",
    "dermatologi": "dermatologo",
    "dermatologica": "dermatologico",
    "dermatologiche": "dermatologico",
    "dermatologici": "dermatologico",
    "deroga": "derogare",
    "derogai": "derogare",
    "derogammo": "derogare",
    "derogan": "derogare",
    "derogando": "derogare",
    "derogano": "derogare",
    "derogante": "derogare",
    "deroganti": "derogare",
    "derogar": "derogare",
    "derogaron": "derogare",
    "derogarono": "derogare",
    "derogasse": "derogare",
    "derogasser": "derogare",
    "derogassero": "derogare",
    "derogassi": "derogare",
    "derogassimo": "derogare",
    "derogaste": "derogare",
    "derogasti": "derogare",
    "derogata": "derogare",
    "derogate": "derogare",
    "derogati": "derogare",
    "derogato": "derogare",
    "derogatori": "derogatorio",
    "derogatoria": "derogatorio",
    "derogatorie": "derogatorio",
    "derogava": "derogare",
    "derogavamo": "derogare",
    "derogavan": "derogare",
    "derogavano": "derogare",
    "derogavate": "derogare",
    "derogavi": "derogare",
    "derogavo": "derogare",
    "deroghe": "deroga",
    "derogherai": "derogare",
    "derogheran": "derogare",
    "derogheranno": "derogare",
    "derogherebbe": "derogare",
    "derogherebber": "derogare",
    "derogherebbero": "derogare",
    "derogherei": "derogare",
    "derogheremmo": "derogare",
    "derogheremo": "derogare",
    "deroghereste": "derogare",
    "derogheresti": "derogare",
    "derogherete": "derogare",
    "derogherà": "derogare",
    "derogherò": "derogare",
    "deroghi": "derogare",
    "deroghiamo": "derogare",
    "deroghiate": "derogare",
    "deroghin": "derogare",
    "deroghino": "derogare",
    "derogo": "derogare",
    "derogò": "derogare",
    "derrate": "derrata",
    "derridiana": "derridiano",
    "derridiane": "derridiano",
    "derridiani": "derridiano",
    "deruba": "derubare",
    "derubai": "derubare",
    "derubammo": "derubare",
    "deruban": "derubare",
    "derubando": "derubare",
    "derubano": "derubare",
    "derubante": "derubare",
    "derubanti": "derubare",
    "derubar": "derubare",
    "derubaron": "derubare",
    "derubarono": "derubare",
    "derubasse": "derubare",
    "derubasser": "derubare",
    "derubassero": "derubare",
    "derubassi": "derubare",
    "derubassimo": "derubare",
    "derubaste": "derubare",
    "derubasti": "derubare",
    "derubata": "derubare",
    "derubate": "derubare",
    "derubati": "derubare",
    "derubato": "derubare",
    "derubava": "derubare",
    "derubavamo": "derubare",
    "derubavan": "derubare",
    "derubavano": "derubare",
    "derubavate": "derubare",
    "derubavi": "derubare",
    "derubavo": "derubare",
    "deruberai": "derubare",
    "deruberan": "derubare",
    "deruberanno": "derubare",
    "deruberebbe": "derubare",
    "deruberebber": "derubare",
    "deruberebbero": "derubare",
    "deruberei": "derubare",
    "deruberemmo": "derubare",
    "deruberemo": "derubare",
    "derubereste": "derubare",
    "deruberesti": "derubare",
    "deruberete": "derubare",
    "deruberà": "derubare",
    "deruberò": "derubare",
    "derubi": "derubare",
    "derubiamo": "derubare",
    "derubiate": "derubare",
    "derubin": "derubare",
    "derubino": "derubare",
    "derubo": "derubare",
    "derubrica": "derubricare",
    "derubricai": "derubricare",
    "derubricammo": "derubricare",
    "derubrican": "derubricare",
    "derubricando": "derubricare",
    "derubricano": "derubricare",
    "derubricante": "derubricare",
    "derubricanti": "derubricare",
    "derubricar": "derubricare",
    "derubricaron": "derubricare",
    "derubricarono": "derubricare",
    "derubricasse": "derubricare",
    "derubricasser": "derubricare",
    "derubricassero": "derubricare",
    "derubricassi": "derubricare",
    "derubricassimo": "derubricare",
    "derubricaste": "derubricare",
    "derubricasti": "derubricare",
    "derubricata": "derubricare",
    "derubricate": "derubricare",
    "derubricati": "derubricare",
    "derubricato": "derubricare",
    "derubricava": "derubricare",
    "derubricavamo": "derubricare",
    "derubricavan": "derubricare",
    "derubricavano": "derubricare",
    "derubricavate": "derubricare",
    "derubricavi": "derubricare",
    "derubricavo": "derubricare",
    "derubricherai": "derubricare",
    "derubricheran": "derubricare",
    "derubricheranno": "derubricare",
    "derubricherebbe": "derubricare",
    "derubricherebber": "derubricare",
    "derubricherebbero": "derubricare",
    "derubricherei": "derubricare",
    "derubricheremmo": "derubricare",
    "derubricheremo": "derubricare",
    "derubrichereste": "derubricare",
    "derubricheresti": "derubricare",
    "derubricherete": "derubricare",
    "derubricherà": "derubricare",
    "derubricherò": "derubricare",
    "derubrichi": "derubricare",
    "derubrichiamo": "derubricare",
    "derubrichiate": "derubricare",
    "derubrichin": "derubricare",
    "derubrichino": "derubricare",
    "derubrico": "derubricare",
    "derubricò": "derubricare",
    "derubò": "derubare",
    "dervisci": "derviscio",
    "desacralizza": "desacralizzare",
    "desacralizzai": "desacralizzare",
    "desacralizzammo": "desacralizzare",
    "desacralizzan": "desacralizzare",
    "desacralizzando": "desacralizzare",
    "desacralizzano": "desacralizzare",
    "desacralizzante": "desacralizzare",
    "desacralizzanti": "desacralizzare",
    "desacralizzar": "desacralizzare",
    "desacralizzaron": "desacralizzare",
    "desacralizzarono": "desacralizzare",
    "desacralizzasse": "desacralizzare",
    "desacralizzasser": "desacralizzare",
    "desacralizzassero": "desacralizzare",
    "desacralizzassi": "desacralizzare",
    "desacralizzassimo": "desacralizzare",
    "desacralizzaste": "desacralizzare",
    "desacralizzasti": "desacralizzare",
    "desacralizzata": "desacralizzare",
    "desacralizzate": "desacralizzare",
    "desacralizzati": "desacralizzare",
    "desacralizzato": "desacralizzare",
    "desacralizzava": "desacralizzare",
    "desacralizzavamo": "desacralizzare",
    "desacralizzavan": "desacralizzare",
    "desacralizzavano": "desacralizzare",
    "desacralizzavate": "desacralizzare",
    "desacralizzavi": "desacralizzare",
    "desacralizzavo": "desacralizzare",
    "desacralizzerai": "desacralizzare",
    "desacralizzeran": "desacralizzare",
    "desacralizzeranno": "desacralizzare",
    "desacralizzerebbe": "desacralizzare",
    "desacralizzerebber": "desacralizzare",
    "desacralizzerebbero": "desacralizzare",
    "desacralizzerei": "desacralizzare",
    "desacralizzeremmo": "desacralizzare",
    "desacralizzeremo": "desacralizzare",
    "desacralizzereste": "desacralizzare",
    "desacralizzeresti": "desacralizzare",
    "desacralizzerete": "desacralizzare",
    "desacralizzerà": "desacralizzare",
    "desacralizzerò": "desacralizzare",
    "desacralizzi": "desacralizzare",
    "desacralizziamo": "desacralizzare",
    "desacralizziate": "desacralizzare",
    "desacralizzin": "desacralizzare",
    "desacralizzino": "desacralizzare",
    "desacralizzo": "desacralizzare",
    "desacralizzò": "desacralizzare",
    "desalinizza": "desalinizzare",
    "desalinizzai": "desalinizzare",
    "desalinizzammo": "desalinizzare",
    "desalinizzan": "desalinizzare",
    "desalinizzando": "desalinizzare",
    "desalinizzano": "desalinizzare",
    "desalinizzante": "desalinizzare",
    "desalinizzanti": "desalinizzare",
    "desalinizzar": "desalinizzare",
    "desalinizzaron": "desalinizzare",
    "desalinizzarono": "desalinizzare",
    "desalinizzasse": "desalinizzare",
    "desalinizzasser": "desalinizzare",
    "desalinizzassero": "desalinizzare",
    "desalinizzassi": "desalinizzare",
    "desalinizzassimo": "desalinizzare",
    "desalinizzaste": "desalinizzare",
    "desalinizzasti": "desalinizzare",
    "desalinizzata": "desalinizzare",
    "desalinizzate": "desalinizzare",
    "desalinizzati": "desalinizzare",
    "desalinizzato": "desalinizzare",
    "desalinizzava": "desalinizzare",
    "desalinizzavamo": "desalinizzare",
    "desalinizzavan": "desalinizzare",
    "desalinizzavano": "desalinizzare",
    "desalinizzavate": "desalinizzare",
    "desalinizzavi": "desalinizzare",
    "desalinizzavo": "desalinizzare",
    "desalinizzerai": "desalinizzare",
    "desalinizzeran": "desalinizzare",
    "desalinizzeranno": "desalinizzare",
    "desalinizzerebbe": "desalinizzare",
    "desalinizzerebber": "desalinizzare",
    "desalinizzerebbero": "desalinizzare",
    "desalinizzerei": "desalinizzare",
    "desalinizzeremmo": "desalinizzare",
    "desalinizzeremo": "desalinizzare",
    "desalinizzereste": "desalinizzare",
    "desalinizzeresti": "desalinizzare",
    "desalinizzerete": "desalinizzare",
    "desalinizzerà": "desalinizzare",
    "desalinizzerò": "desalinizzare",
    "desalinizzi": "desalinizzare",
    "desalinizziamo": "desalinizzare",
    "desalinizziate": "desalinizzare",
    "desalinizzin": "desalinizzare",
    "desalinizzino": "desalinizzare",
    "desalinizzo": "desalinizzare",
    "desalinizzò": "desalinizzare",
    "desaparecidos": "desaparecido",
    "deschi": "desco",
    "descrisse": "descrivere",
    "descrisser": "descrivere",
    "descrissero": "descrivere",
    "descrissi": "descrivere",
    "descritta": "descrivere",
    "descritte": "descrivere",
    "descritti": "descrivere",
    "descrittiva": "descrittivo",
    "descrittive": "descrittivo",
    "descrittivi": "descrittivo",
    "descritto": "descrivere",
    "descriva": "descrivere",
    "descrivan": "descrivere",
    "descrivano": "descrivere",
    "descrive": "descrivere",
    "descrivemmo": "descrivere",
    "descrivendo": "descrivere",
    "descrivente": "descrivere",
    "descriventi": "descrivere",
    "descriver": "descrivere",
    "descriverai": "descrivere",
    "descriveran": "descrivere",
    "descriveranno": "descrivere",
    "descriverebbe": "descrivere",
    "descriverebber": "descrivere",
    "descriverebbero": "descrivere",
    "descriverei": "descrivere",
    "descriveremmo": "descrivere",
    "descriveremo": "descrivere",
    "descrivereste": "descrivere",
    "descriveresti": "descrivere",
    "descriverete": "descrivere",
    "descriverà": "descrivere",
    "descriverò": "descrivere",
    "descrivesse": "descrivere",
    "descrivesser": "descrivere",
    "descrivessero": "descrivere",
    "descrivessi": "descrivere",
    "descrivessimo": "descrivere",
    "descriveste": "descrivere",
    "descrivesti": "descrivere",
    "descrivete": "descrivere",
    "descriveva": "descrivere",
    "descrivevamo": "descrivere",
    "descrivevan": "descrivere",
    "descrivevano": "descrivere",
    "descrivevate": "descrivere",
    "descrivevi": "descrivere",
    "descrivevo": "descrivere",
    "descrivi": "descrivere",
    "descriviamo": "descrivere",
    "descriviate": "descrivere",
    "descrivibili": "descrivibile",
    "descrivo": "descrivere",
    "descrivon": "descrivere",
    "descrivono": "descrivere",
    "descrizioni": "descrizione",
    "desecreta": "desecretare",
    "desecretai": "desecretare",
    "desecretammo": "desecretare",
    "desecretan": "desecretare",
    "desecretando": "desecretare",
    "desecretano": "desecretare",
    "desecretante": "desecretare",
    "desecretanti": "desecretare",
    "desecretar": "desecretare",
    "desecretaron": "desecretare",
    "desecretarono": "desecretare",
    "desecretasse": "desecretare",
    "desecretasser": "desecretare",
    "desecretassero": "desecretare",
    "desecretassi": "desecretare",
    "desecretassimo": "desecretare",
    "desecretaste": "desecretare",
    "desecretasti": "desecretare",
    "desecretata": "desecretare",
    "desecretate": "desecretare",
    "desecretati": "desecretare",
    "desecretato": "desecretare",
    "desecretava": "desecretare",
    "desecretavamo": "desecretare",
    "desecretavan": "desecretare",
    "desecretavano": "desecretare",
    "desecretavate": "desecretare",
    "desecretavi": "desecretare",
    "desecretavo": "desecretare",
    "desecreterai": "desecretare",
    "desecreteran": "desecretare",
    "desecreteranno": "desecretare",
    "desecreterebbe": "desecretare",
    "desecreterebber": "desecretare",
    "desecreterebbero": "desecretare",
    "desecreterei": "desecretare",
    "desecreteremmo": "desecretare",
    "desecreteremo": "desecretare",
    "desecretereste": "desecretare",
    "desecreteresti": "desecretare",
    "desecreterete": "desecretare",
    "desecreterà": "desecretare",
    "desecreterò": "desecretare",
    "desecreti": "desecretare",
    "desecretiamo": "desecretare",
    "desecretiate": "desecretare",
    "desecretin": "desecretare",
    "desecretino": "desecretare",
    "desecreto": "desecretare",
    "desecretò": "desecretare",
    "deserta": "deserto",
    "deserte": "deserto",
    "deserti": "deserto",
    "desertica": "desertico",
    "desertiche": "desertico",
    "desertici": "desertico",
    "desertifica": "desertificare",
    "desertificai": "desertificare",
    "desertificammo": "desertificare",
    "desertifican": "desertificare",
    "desertificando": "desertificare",
    "desertificano": "desertificare",
    "desertificante": "desertificare",
    "desertificanti": "desertificare",
    "desertificar": "desertificare",
    "desertificaron": "desertificare",
    "desertificarono": "desertificare",
    "desertificasse": "desertificare",
    "desertificasser": "desertificare",
    "desertificassero": "desertificare",
    "desertificassi": "desertificare",
    "desertificassimo": "desertificare",
    "desertificaste": "desertificare",
    "desertificasti": "desertificare",
    "desertificata": "desertificato",
    "desertificate": "desertificato",
    "desertificati": "desertificato",
    "desertificato": "desertificare",
    "desertificava": "desertificare",
    "desertificavamo": "desertificare",
    "desertificavan": "desertificare",
    "desertificavano": "desertificare",
    "desertificavate": "desertificare",
    "desertificavi": "desertificare",
    "desertificavo": "desertificare",
    "desertificazioni": "desertificazione",
    "desertificherai": "desertificare",
    "desertificheran": "desertificare",
    "desertificheranno": "desertificare",
    "desertificherebbe": "desertificare",
    "desertificherebber": "desertificare",
    "desertificherebbero": "desertificare",
    "desertificherei": "desertificare",
    "desertificheremmo": "desertificare",
    "desertificheremo": "desertificare",
    "desertifichereste": "desertificare",
    "desertificheresti": "desertificare",
    "desertificherete": "desertificare",
    "desertificherà": "desertificare",
    "desertificherò": "desertificare",
    "desertifichi": "desertificare",
    "desertifichiamo": "desertificare",
    "desertifichiate": "desertificare",
    "desertifichin": "desertificare",
    "desertifichino": "desertificare",
    "desertifico": "desertificare",
    "desertificò": "desertificare",
    "desi": "desiare",
    "desia": "desiare",
    "desiai": "desiare",
    "desiammo": "desiare",
    "desiamo": "desiare",
    "desian": "desiare",
    "desiando": "desiare",
    "desiano": "desiare",
    "desiante": "desiare",
    "desianti": "desiare",
    "desiar": "desiare",
    "desiaron": "desiare",
    "desiarono": "desiare",
    "desiasse": "desiare",
    "desiasser": "desiare",
    "desiassero": "desiare",
    "desiassi": "desiare",
    "desiassimo": "desiare",
    "desiaste": "desiare",
    "desiasti": "desiare",
    "desiata": "desiare",
    "desiate": "desiare",
    "desiati": "desiare",
    "desiato": "desiare",
    "desiava": "desiare",
    "desiavamo": "desiare",
    "desiavan": "desiare",
    "desiavano": "desiare",
    "desiavate": "desiare",
    "desiavi": "desiare",
    "desiavo": "desiare",
    "desidera": "desiderare",
    "desiderabili": "desiderabile",
    "desiderai": "desiderare",
    "desiderammo": "desiderare",
    "desideran": "desiderare",
    "desiderando": "desiderare",
    "desiderano": "desiderare",
    "desiderante": "desiderare",
    "desideranti": "desiderare",
    "desiderar": "desiderare",
    "desideraron": "desiderare",
    "desiderarono": "desiderare",
    "desiderasse": "desiderare",
    "desiderasser": "desiderare",
    "desiderassero": "desiderare",
    "desiderassi": "desiderare",
    "desiderassimo": "desiderare",
    "desideraste": "desiderare",
    "desiderasti": "desiderare",
    "desiderata": "desiderare",
    "desiderate": "desiderare",
    "desiderati": "desiderare",
    "desiderato": "desiderare",
    "desiderava": "desiderare",
    "desideravamo": "desiderare",
    "desideravan": "desiderare",
    "desideravano": "desiderare",
    "desideravate": "desiderare",
    "desideravi": "desiderare",
    "desideravo": "desiderare",
    "desidererai": "desiderare",
    "desidereran": "desiderare",
    "desidereranno": "desiderare",
    "desidererebbe": "desiderare",
    "desidererebber": "desiderare",
    "desidererebbero": "desiderare",
    "desidererei": "desiderare",
    "desidereremmo": "desiderare",
    "desidereremo": "desiderare",
    "desiderereste": "desiderare",
    "desidereresti": "desiderare",
    "desidererete": "desiderare",
    "desidererà": "desiderare",
    "desidererò": "desiderare",
    "desideri": "desidero",
    "desideriamo": "desiderare",
    "desideriate": "desiderare",
    "desiderin": "desiderare",
    "desiderino": "desiderare",
    "desidero": "desiderare",
    "desiderosa": "desideroso",
    "desiderose": "desideroso",
    "desiderosi": "desideroso",
    "desiderò": "desiderare",
    "desierai": "desiare",
    "desieran": "desiare",
    "desieranno": "desiare",
    "desierebbe": "desiare",
    "desierebber": "desiare",
    "desierebbero": "desiare",
    "desierei": "desiare",
    "desieremmo": "desiare",
    "desieremo": "desiare",
    "desiereste": "desiare",
    "desieresti": "desiare",
    "desierete": "desiare",
    "desierà": "desiare",
    "desierò": "desiare",
    "designa": "designare",
    "designai": "designare",
    "designammo": "designare",
    "designan": "designare",
    "designando": "designare",
    "designano": "designare",
    "designante": "designare",
    "designanti": "designare",
    "designar": "designare",
    "designaron": "designare",
    "designarono": "designare",
    "designasse": "designare",
    "designasser": "designare",
    "designassero": "designare",
    "designassi": "designare",
    "designassimo": "designare",
    "designaste": "designare",
    "designasti": "designare",
    "designata": "designare",
    "designate": "designare",
    "designati": "designare",
    "designato": "designare",
    "designatori": "designatore",
    "designava": "designare",
    "designavamo": "designare",
    "designavan": "designare",
    "designavano": "designare",
    "designavate": "designare",
    "designavi": "designare",
    "designavo": "designare",
    "designazioni": "designazione",
    "designerai": "designare",
    "designeran": "designare",
    "designeranno": "designare",
    "designerebbe": "designare",
    "designerebber": "designare",
    "designerebbero": "designare",
    "designerei": "designare",
    "designeremmo": "designare",
    "designeremo": "designare",
    "designereste": "designare",
    "designeresti": "designare",
    "designerete": "designare",
    "designerà": "designare",
    "designerò": "designare",
    "designi": "designare",
    "designiamo": "designare",
    "designiate": "designare",
    "designin": "designare",
    "designino": "designare",
    "designo": "designare",
    "designò": "designare",
    "desin": "desiare",
    "desina": "desinare",
    "desinai": "desinare",
    "desinammo": "desinare",
    "desinan": "desinare",
    "desinando": "desinare",
    "desinano": "desinare",
    "desinante": "desinare",
    "desinanti": "desinare",
    "desinar": "desinare",
    "desinaron": "desinare",
    "desinarono": "desinare",
    "desinasse": "desinare",
    "desinasser": "desinare",
    "desinassero": "desinare",
    "desinassi": "desinare",
    "desinassimo": "desinare",
    "desinaste": "desinare",
    "desinasti": "desinare",
    "desinata": "desinare",
    "desinate": "desinare",
    "desinati": "desinare",
    "desinato": "desinare",
    "desinava": "desinare",
    "desinavamo": "desinare",
    "desinavan": "desinare",
    "desinavano": "desinare",
    "desinavate": "desinare",
    "desinavi": "desinare",
    "desinavo": "desinare",
    "desinenze": "desinenza",
    "desinerai": "desinare",
    "desineran": "desinare",
    "desineranno": "desinare",
    "desinerebbe": "desinare",
    "desinerebber": "desinare",
    "desinerebbero": "desinare",
    "desinerei": "desinare",
    "desineremmo": "desinare",
    "desineremo": "desinare",
    "desinereste": "desinare",
    "desineresti": "desinare",
    "desinerete": "desinare",
    "desinerà": "desinare",
    "desinerò": "desinare",
    "desini": "desinare",
    "desiniamo": "desinare",
    "desiniate": "desinare",
    "desinin": "desinare",
    "desinino": "desinare",
    "desino": "desinare",
    "desinò": "desinare",
    "desio": "desiare",
    "desista": "desistere",
    "desistan": "desistere",
    "desistano": "desistere",
    "desiste": "desistere",
    "desistei": "desistere",
    "desistemmo": "desistere",
    "desistendo": "desistere",
    "desistente": "desistere",
    "desistenti": "desistere",
    "desistenze": "desistenza",
    "desister": "desistere",
    "desisterai": "desistere",
    "desisteran": "desistere",
    "desisteranno": "desistere",
    "desisterebbe": "desistere",
    "desisterebber": "desistere",
    "desisterebbero": "desistere",
    "desisterei": "desistere",
    "desisteremmo": "desistere",
    "desisteremo": "desistere",
    "desistereste": "desistere",
    "desisteresti": "desistere",
    "desisterete": "desistere",
    "desisterono": "desistere",
    "desisterà": "desistere",
    "desisterò": "desistere",
    "desistesse": "desistere",
    "desistesser": "desistere",
    "desistessero": "desistere",
    "desistessi": "desistere",
    "desistessimo": "desistere",
    "desisteste": "desistere",
    "desistesti": "desistere",
    "desistete": "desistere",
    "desisteva": "desistere",
    "desistevamo": "desistere",
    "desistevan": "desistere",
    "desistevano": "desistere",
    "desistevate": "desistere",
    "desistevi": "desistere",
    "desistevo": "desistere",
    "desisti": "desistere",
    "desistiamo": "desistere",
    "desistiate": "desistere",
    "desistita": "desistere",
    "desistite": "desistere",
    "desistiti": "desistere",
    "desistito": "desistere",
    "desisto": "desistere",
    "desiston": "desistere",
    "desistono": "desistere",
    "desistè": "desistere",
    "desiò": "desiare",
    "desnuda": "desnudo",
    "desnude": "desnudo",
    "desnudi": "desnudo",
    "desola": "desolare",
    "desolai": "desolare",
    "desolammo": "desolare",
    "desolan": "desolare",
    "desolando": "desolare",
    "desolano": "desolare",
    "desolante": "desolare",
    "desolanti": "desolare",
    "desolar": "desolare",
    "desolaron": "desolare",
    "desolarono": "desolare",
    "desolasse": "desolare",
    "desolasser": "desolare",
    "desolassero": "desolare",
    "desolassi": "desolare",
    "desolassimo": "desolare",
    "desolaste": "desolare",
    "desolasti": "desolare",
    "desolata": "desolato",
    "desolate": "desolato",
    "desolati": "desolato",
    "desolato": "desolare",
    "desolava": "desolare",
    "desolavamo": "desolare",
    "desolavan": "desolare",
    "desolavano": "desolare",
    "desolavate": "desolare",
    "desolavi": "desolare",
    "desolavo": "desolare",
    "desolazioni": "desolazione",
    "desolerai": "desolare",
    "desoleran": "desolare",
    "desoleranno": "desolare",
    "desolerebbe": "desolare",
    "desolerebber": "desolare",
    "desolerebbero": "desolare",
    "desolerei": "desolare",
    "desoleremmo": "desolare",
    "desoleremo": "desolare",
    "desolereste": "desolare",
    "desoleresti": "desolare",
    "desolerete": "desolare",
    "desolerà": "desolare",
    "desolerò": "desolare",
    "desoli": "desolare",
    "desoliamo": "desolare",
    "desoliate": "desolare",
    "desolin": "desolare",
    "desolino": "desolare",
    "desolo": "desolare",
    "desolò": "desolare",
    "despoti": "despota",
    "desse": "dare",
    "desser": "dare",
    "dessero": "dare",
    "dessi": "dare",
    "dessimo": "dare",
    "desta": "desto",
    "destabilizza": "destabilizzare",
    "destabilizzai": "destabilizzare",
    "destabilizzammo": "destabilizzare",
    "destabilizzan": "destabilizzare",
    "destabilizzando": "destabilizzare",
    "destabilizzano": "destabilizzare",
    "destabilizzante": "destabilizzare",
    "destabilizzanti": "destabilizzare",
    "destabilizzar": "destabilizzare",
    "destabilizzaron": "destabilizzare",
    "destabilizzarono": "destabilizzare",
    "destabilizzasse": "destabilizzare",
    "destabilizzasser": "destabilizzare",
    "destabilizzassero": "destabilizzare",
    "destabilizzassi": "destabilizzare",
    "destabilizzassimo": "destabilizzare",
    "destabilizzaste": "destabilizzare",
    "destabilizzasti": "destabilizzare",
    "destabilizzata": "destabilizzare",
    "destabilizzate": "destabilizzare",
    "destabilizzati": "destabilizzare",
    "destabilizzato": "destabilizzare",
    "destabilizzatori": "destabilizzatore",
    "destabilizzatrice": "destabilizzatore",
    "destabilizzatrici": "destabilizzatore",
    "destabilizzava": "destabilizzare",
    "destabilizzavamo": "destabilizzare",
    "destabilizzavan": "destabilizzare",
    "destabilizzavano": "destabilizzare",
    "destabilizzavate": "destabilizzare",
    "destabilizzavi": "destabilizzare",
    "destabilizzavo": "destabilizzare",
    "destabilizzazioni": "destabilizzazione",
    "destabilizzerai": "destabilizzare",
    "destabilizzeran": "destabilizzare",
    "destabilizzeranno": "destabilizzare",
    "destabilizzerebbe": "destabilizzare",
    "destabilizzerebber": "destabilizzare",
    "destabilizzerebbero": "destabilizzare",
    "destabilizzerei": "destabilizzare",
    "destabilizzeremmo": "destabilizzare",
    "destabilizzeremo": "destabilizzare",
    "destabilizzereste": "destabilizzare",
    "destabilizzeresti": "destabilizzare",
    "destabilizzerete": "destabilizzare",
    "destabilizzerà": "destabilizzare",
    "destabilizzerò": "destabilizzare",
    "destabilizzi": "destabilizzare",
    "destabilizziamo": "destabilizzare",
    "destabilizziate": "destabilizzare",
    "destabilizzin": "destabilizzare",
    "destabilizzino": "destabilizzare",
    "destabilizzo": "destabilizzare",
    "destabilizzò": "destabilizzare",
    "destagionalizzata": "destagionalizzato",
    "destagionalizzate": "destagionalizzato",
    "destagionalizzati": "destagionalizzato",
    "destai": "destare",
    "destalinizza": "destalinizzare",
    "destalinizzai": "destalinizzare",
    "destalinizzammo": "destalinizzare",
    "destalinizzan": "destalinizzare",
    "destalinizzando": "destalinizzare",
    "destalinizzano": "destalinizzare",
    "destalinizzante": "destalinizzare",
    "destalinizzanti": "destalinizzare",
    "destalinizzar": "destalinizzare",
    "destalinizzaron": "destalinizzare",
    "destalinizzarono": "destalinizzare",
    "destalinizzasse": "destalinizzare",
    "destalinizzasser": "destalinizzare",
    "destalinizzassero": "destalinizzare",
    "destalinizzassi": "destalinizzare",
    "destalinizzassimo": "destalinizzare",
    "destalinizzaste": "destalinizzare",
    "destalinizzasti": "destalinizzare",
    "destalinizzata": "destalinizzare",
    "destalinizzate": "destalinizzare",
    "destalinizzati": "destalinizzare",
    "destalinizzato": "destalinizzare",
    "destalinizzava": "destalinizzare",
    "destalinizzavamo": "destalinizzare",
    "destalinizzavan": "destalinizzare",
    "destalinizzavano": "destalinizzare",
    "destalinizzavate": "destalinizzare",
    "destalinizzavi": "destalinizzare",
    "destalinizzavo": "destalinizzare",
    "destalinizzazioni": "destalinizzazione",
    "destalinizzerai": "destalinizzare",
    "destalinizzeran": "destalinizzare",
    "destalinizzeranno": "destalinizzare",
    "destalinizzerebbe": "destalinizzare",
    "destalinizzerebber": "destalinizzare",
    "destalinizzerebbero": "destalinizzare",
    "destalinizzerei": "destalinizzare",
    "destalinizzeremmo": "destalinizzare",
    "destalinizzeremo": "destalinizzare",
    "destalinizzereste": "destalinizzare",
    "destalinizzeresti": "destalinizzare",
    "destalinizzerete": "destalinizzare",
    "destalinizzerà": "destalinizzare",
    "destalinizzerò": "destalinizzare",
    "destalinizzi": "destalinizzare",
    "destalinizziamo": "destalinizzare",
    "destalinizziate": "destalinizzare",
    "destalinizzin": "destalinizzare",
    "destalinizzino": "destalinizzare",
    "destalinizzo": "destalinizzare",
    "destalinizzò": "destalinizzare",
    "destammo": "destare",
    "destan": "destare",
    "destando": "destare",
    "destano": "destare",
    "destante": "destare",
    "destanti": "destare",
    "destar": "destare",
    "destaron": "destare",
    "destarono": "destare",
    "destasse": "destare",
    "destasser": "destare",
    "destassero": "destare",
    "destassi": "destare",
    "destassimo": "destare",
    "destaste": "destare",
    "destasti": "destare",
    "destata": "destare",
    "destate": "destare",
    "destati": "destare",
    "destato": "destare",
    "destava": "destare",
    "destavamo": "destare",
    "destavan": "destare",
    "destavano": "destare",
    "destavate": "destare",
    "destavi": "destare",
    "destavo": "destare",
    "deste": "desto",
    "desterai": "destare",
    "desteran": "destare",
    "desteranno": "destare",
    "desterebbe": "destare",
    "desterebber": "destare",
    "desterebbero": "destare",
    "desterei": "destare",
    "desteremmo": "destare",
    "desteremo": "destare",
    "destereste": "destare",
    "desteresti": "destare",
    "desterete": "destare",
    "desterà": "destare",
    "desterò": "destare",
    "desti": "desto",
    "destiamo": "destare",
    "destiate": "destare",
    "destin": "destare",
    "destina": "destinare",
    "destinai": "destinare",
    "destinammo": "destinare",
    "destinan": "destinare",
    "destinando": "destinare",
    "destinano": "destinare",
    "destinante": "destinare",
    "destinanti": "destinare",
    "destinar": "destinare",
    "destinaron": "destinare",
    "destinarono": "destinare",
    "destinasse": "destinare",
    "destinasser": "destinare",
    "destinassero": "destinare",
    "destinassi": "destinare",
    "destinassimo": "destinare",
    "destinaste": "destinare",
    "destinasti": "destinare",
    "destinata": "destinare",
    "destinatari": "destinatario",
    "destinatarie": "destinataria",
    "destinate": "destinare",
    "destinati": "destinare",
    "destinato": "destinare",
    "destinava": "destinare",
    "destinavamo": "destinare",
    "destinavan": "destinare",
    "destinavano": "destinare",
    "destinavate": "destinare",
    "destinavi": "destinare",
    "destinavo": "destinare",
    "destinazioni": "destinazione",
    "destinerai": "destinare",
    "destineran": "destinare",
    "destineranno": "destinare",
    "destinerebbe": "destinare",
    "destinerebber": "destinare",
    "destinerebbero": "destinare",
    "destinerei": "destinare",
    "destineremmo": "destinare",
    "destineremo": "destinare",
    "destinereste": "destinare",
    "destineresti": "destinare",
    "destinerete": "destinare",
    "destinerà": "destinare",
    "destinerò": "destinare",
    "destini": "destino",
    "destiniamo": "destinare",
    "destiniate": "destinare",
    "destinin": "destinare",
    "destinino": "destinare",
    "destino": "destinare",
    "destinò": "destinare",
    "destituendo": "destituire",
    "destituente": "destituire",
    "destituenti": "destituire",
    "destituiamo": "destituire",
    "destituiate": "destituire",
    "destituii": "destituire",
    "destituimmo": "destituire",
    "destituir": "destituire",
    "destituirai": "destituire",
    "destituiran": "destituire",
    "destituiranno": "destituire",
    "destituirebbe": "destituire",
    "destituirebber": "destituire",
    "destituirebbero": "destituire",
    "destituirei": "destituire",
    "destituiremmo": "destituire",
    "destituiremo": "destituire",
    "destituireste": "destituire",
    "destituiresti": "destituire",
    "destituirete": "destituire",
    "destituiron": "destituire",
    "destituirono": "destituire",
    "destituirà": "destituire",
    "destituirò": "destituire",
    "destituisca": "destituire",
    "destituiscan": "destituire",
    "destituiscano": "destituire",
    "destituisce": "destituire",
    "destituisci": "destituire",
    "destituisco": "destituire",
    "destituiscon": "destituire",
    "destituiscono": "destituire",
    "destituisse": "destituire",
    "destituisser": "destituire",
    "destituissero": "destituire",
    "destituissi": "destituire",
    "destituissimo": "destituire",
    "destituiste": "destituire",
    "destituisti": "destituire",
    "destituita": "destituito",
    "destituite": "destituito",
    "destituiti": "destituito",
    "destituito": "destituire",
    "destituiva": "destituire",
    "destituivamo": "destituire",
    "destituivan": "destituire",
    "destituivano": "destituire",
    "destituivate": "destituire",
    "destituivi": "destituire",
    "destituivo": "destituire",
    "destituzioni": "destituzione",
    "destituì": "destituire",
    "desto": "destare",
    "destra": "destro",
    "destre": "destro",
    "destreggerai": "destreggiare",
    "destreggeran": "destreggiare",
    "destreggeranno": "destreggiare",
    "destreggerebbe": "destreggiare",
    "destreggerebber": "destreggiare",
    "destreggerebbero": "destreggiare",
    "destreggerei": "destreggiare",
    "destreggeremmo": "destreggiare",
    "destreggeremo": "destreggiare",
    "destreggereste": "destreggiare",
    "destreggeresti": "destreggiare",
    "destreggerete": "destreggiare",
    "destreggerà": "destreggiare",
    "destreggerò": "destreggiare",
    "destreggi": "destreggiare",
    "destreggia": "destreggiare",
    "destreggiai": "destreggiare",
    "destreggiammo": "destreggiare",
    "destreggiamo": "destreggiare",
    "destreggian": "destreggiare",
    "destreggiando": "destreggiare",
    "destreggiano": "destreggiare",
    "destreggiante": "destreggiare",
    "destreggianti": "destreggiare",
    "destreggiar": "destreggiare",
    "destreggiaron": "destreggiare",
    "destreggiarono": "destreggiare",
    "destreggiasse": "destreggiare",
    "destreggiasser": "destreggiare",
    "destreggiassero": "destreggiare",
    "destreggiassi": "destreggiare",
    "destreggiassimo": "destreggiare",
    "destreggiaste": "destreggiare",
    "destreggiasti": "destreggiare",
    "destreggiata": "destreggiare",
    "destreggiate": "destreggiare",
    "destreggiati": "destreggiare",
    "destreggiato": "destreggiare",
    "destreggiava": "destreggiare",
    "destreggiavamo": "destreggiare",
    "destreggiavan": "destreggiare",
    "destreggiavano": "destreggiare",
    "destreggiavate": "destreggiare",
    "destreggiavi": "destreggiare",
    "destreggiavo": "destreggiare",
    "destreggin": "destreggiare",
    "destreggino": "destreggiare",
    "destreggio": "destreggiare",
    "destreggiò": "destreggiare",
    "destrezze": "destrezza",
    "destri": "destro",
    "destrieri": "destriero",
    "destrorsa": "destrorso",
    "destrorse": "destrorso",
    "destrorsi": "destrorso",
    "destruttura": "destrutturare",
    "destrutturai": "destrutturare",
    "destrutturammo": "destrutturare",
    "destrutturan": "destrutturare",
    "destrutturando": "destrutturare",
    "destrutturano": "destrutturare",
    "destrutturante": "destrutturare",
    "destrutturanti": "destrutturare",
    "destrutturar": "destrutturare",
    "destrutturaron": "destrutturare",
    "destrutturarono": "destrutturare",
    "destrutturasse": "destrutturare",
    "destrutturasser": "destrutturare",
    "destrutturassero": "destrutturare",
    "destrutturassi": "destrutturare",
    "destrutturassimo": "destrutturare",
    "destrutturaste": "destrutturare",
    "destrutturasti": "destrutturare",
    "destrutturata": "destrutturare",
    "destrutturate": "destrutturare",
    "destrutturati": "destrutturare",
    "destrutturato": "destrutturare",
    "destrutturava": "destrutturare",
    "destrutturavamo": "destrutturare",
    "destrutturavan": "destrutturare",
    "destrutturavano": "destrutturare",
    "destrutturavate": "destrutturare",
    "destrutturavi": "destrutturare",
    "destrutturavo": "destrutturare",
    "destrutturazioni": "destrutturazione",
    "destrutturerai": "destrutturare",
    "destruttureran": "destrutturare",
    "destruttureranno": "destrutturare",
    "destrutturerebbe": "destrutturare",
    "destrutturerebber": "destrutturare",
    "destrutturerebbero": "destrutturare",
    "destrutturerei": "destrutturare",
    "destruttureremmo": "destrutturare",
    "destruttureremo": "destrutturare",
    "destrutturereste": "destrutturare",
    "destruttureresti": "destrutturare",
    "destrutturerete": "destrutturare",
    "destrutturerà": "destrutturare",
    "destrutturerò": "destrutturare",
    "destrutturi": "destrutturare",
    "destrutturiamo": "destrutturare",
    "destrutturiate": "destrutturare",
    "destrutturin": "destrutturare",
    "destrutturino": "destrutturare",
    "destrutturo": "destrutturare",
    "destrutturò": "destrutturare",
    "destò": "destare",
    "desueta": "desueto",
    "desuete": "desueto",
    "desueti": "desueto",
    "desuma": "desumere",
    "desuman": "desumere",
    "desumano": "desumere",
    "desume": "desumere",
    "desumemmo": "desumere",
    "desumendo": "desumere",
    "desumente": "desumere",
    "desumenti": "desumere",
    "desumer": "desumere",
    "desumerai": "desumere",
    "desumeran": "desumere",
    "desumeranno": "desumere",
    "desumerebbe": "desumere",
    "desumerebber": "desumere",
    "desumerebbero": "desumere",
    "desumerei": "desumere",
    "desumeremmo": "desumere",
    "desumeremo": "desumere",
    "desumereste": "desumere",
    "desumeresti": "desumere",
    "desumerete": "desumere",
    "desumerà": "desumere",
    "desumerò": "desumere",
    "desumesse": "desumere",
    "desumesser": "desumere",
    "desumessero": "desumere",
    "desumessi": "desumere",
    "desumessimo": "desumere",
    "desumeste": "desumere",
    "desumesti": "desumere",
    "desumete": "desumere",
    "desumeva": "desumere",
    "desumevamo": "desumere",
    "desumevan": "desumere",
    "desumevano": "desumere",
    "desumevate": "desumere",
    "desumevi": "desumere",
    "desumevo": "desumere",
    "desumi": "desumere",
    "desumiamo": "desumere",
    "desumiate": "desumere",
    "desumibili": "desumibile",
    "desumo": "desumere",
    "desumon": "desumere",
    "desumono": "desumere",
    "desunse": "desumere",
    "desunser": "desumere",
    "desunsero": "desumere",
    "desunsi": "desumere",
    "desunta": "desumere",
    "desunte": "desumere",
    "desunti": "desumere",
    "desunto": "desumere",
    "detassa": "detassare",
    "detassai": "detassare",
    "detassammo": "detassare",
    "detassan": "detassare",
    "detassando": "detassare",
    "detassano": "detassare",
    "detassante": "detassare",
    "detassanti": "detassare",
    "detassar": "detassare",
    "detassaron": "detassare",
    "detassarono": "detassare",
    "detassasse": "detassare",
    "detassasser": "detassare",
    "detassassero": "detassare",
    "detassassi": "detassare",
    "detassassimo": "detassare",
    "detassaste": "detassare",
    "detassasti": "detassare",
    "detassata": "detassare",
    "detassate": "detassare",
    "detassati": "detassare",
    "detassato": "detassare",
    "detassava": "detassare",
    "detassavamo": "detassare",
    "detassavan": "detassare",
    "detassavano": "detassare",
    "detassavate": "detassare",
    "detassavi": "detassare",
    "detassavo": "detassare",
    "detassazioni": "detassazione",
    "detasserai": "detassare",
    "detasseran": "detassare",
    "detasseranno": "detassare",
    "detasserebbe": "detassare",
    "detasserebber": "detassare",
    "detasserebbero": "detassare",
    "detasserei": "detassare",
    "detasseremmo": "detassare",
    "detasseremo": "detassare",
    "detassereste": "detassare",
    "detasseresti": "detassare",
    "detasserete": "detassare",
    "detasserà": "detassare",
    "detasserò": "detassare",
    "detassi": "detassare",
    "detassiamo": "detassare",
    "detassiate": "detassare",
    "detassin": "detassare",
    "detassino": "detassare",
    "detasso": "detassare",
    "detassò": "detassare",
    "detenemmo": "detenere",
    "detenendo": "detenere",
    "detenente": "detenere",
    "detenenti": "detenere",
    "detener": "detenere",
    "detenesse": "detenere",
    "detenesser": "detenere",
    "detenessero": "detenere",
    "detenessi": "detenere",
    "detenessimo": "detenere",
    "deteneste": "detenere",
    "detenesti": "detenere",
    "detenete": "detenere",
    "deteneva": "detenere",
    "detenevamo": "detenere",
    "detenevan": "detenere",
    "detenevano": "detenere",
    "detenevate": "detenere",
    "detenevi": "detenere",
    "detenevo": "detenere",
    "detenga": "detenere",
    "detengan": "detenere",
    "detengano": "detenere",
    "detengo": "detenere",
    "detengon": "detenere",
    "detengono": "detenere",
    "deteniamo": "detenere",
    "deteniate": "detenere",
    "detenne": "detenere",
    "detenner": "detenere",
    "detennero": "detenere",
    "detenni": "detenere",
    "detentiva": "detentivo",
    "detentive": "detentivo",
    "detentivi": "detentivo",
    "detentori": "detentore",
    "detenuta": "detenere",
    "detenute": "detenuta",
    "detenuti": "detenuto",
    "detenuto": "detenere",
    "detenzioni": "detenzione",
    "deterga": "detergere",
    "detergan": "detergere",
    "detergano": "detergere",
    "deterge": "detergere",
    "detergemmo": "detergere",
    "detergendo": "detergere",
    "detergente": "detergere",
    "detergenti": "detergere",
    "detergenze": "detergenza",
    "deterger": "detergere",
    "detergerai": "detergere",
    "detergeran": "detergere",
    "detergeranno": "detergere",
    "detergerebbe": "detergere",
    "detergerebber": "detergere",
    "detergerebbero": "detergere",
    "detergerei": "detergere",
    "detergeremmo": "detergere",
    "detergeremo": "detergere",
    "detergereste": "detergere",
    "detergeresti": "detergere",
    "detergerete": "detergere",
    "detergerà": "detergere",
    "detergerò": "detergere",
    "detergesse": "detergere",
    "detergesser": "detergere",
    "detergessero": "detergere",
    "detergessi": "detergere",
    "detergessimo": "detergere",
    "detergeste": "detergere",
    "detergesti": "detergere",
    "detergete": "detergere",
    "detergeva": "detergere",
    "detergevamo": "detergere",
    "detergevan": "detergere",
    "detergevano": "detergere",
    "detergevate": "detergere",
    "detergevi": "detergere",
    "detergevo": "detergere",
    "detergi": "detergere",
    "detergiamo": "detergere",
    "detergiate": "detergere",
    "detergo": "detergere",
    "detergon": "detergere",
    "detergono": "detergere",
    "deteriora": "deteriorare",
    "deteriorabili": "deteriorabile",
    "deteriorai": "deteriorare",
    "deterioramenti": "deterioramento",
    "deteriorammo": "deteriorare",
    "deterioran": "deteriorare",
    "deteriorando": "deteriorare",
    "deteriorano": "deteriorare",
    "deteriorante": "deteriorare",
    "deterioranti": "deteriorare",
    "deteriorar": "deteriorare",
    "deterioraron": "deteriorare",
    "deteriorarono": "deteriorare",
    "deteriorasse": "deteriorare",
    "deteriorasser": "deteriorare",
    "deteriorassero": "deteriorare",
    "deteriorassi": "deteriorare",
    "deteriorassimo": "deteriorare",
    "deterioraste": "deteriorare",
    "deteriorasti": "deteriorare",
    "deteriorata": "deteriorare",
    "deteriorate": "deteriorare",
    "deteriorati": "deteriorare",
    "deteriorato": "deteriorare",
    "deteriorava": "deteriorare",
    "deterioravamo": "deteriorare",
    "deterioravan": "deteriorare",
    "deterioravano": "deteriorare",
    "deterioravate": "deteriorare",
    "deterioravi": "deteriorare",
    "deterioravo": "deteriorare",
    "deteriorerai": "deteriorare",
    "deterioreran": "deteriorare",
    "deterioreranno": "deteriorare",
    "deteriorerebbe": "deteriorare",
    "deteriorerebber": "deteriorare",
    "deteriorerebbero": "deteriorare",
    "deteriorerei": "deteriorare",
    "deterioreremmo": "deteriorare",
    "deterioreremo": "deteriorare",
    "deteriorereste": "deteriorare",
    "deterioreresti": "deteriorare",
    "deteriorerete": "deteriorare",
    "deteriorerà": "deteriorare",
    "deteriorerò": "deteriorare",
    "deteriori": "deteriore",
    "deterioriamo": "deteriorare",
    "deterioriate": "deteriorare",
    "deteriorin": "deteriorare",
    "deteriorino": "deteriorare",
    "deterioro": "deteriorare",
    "deteriorò": "deteriorare",
    "determina": "determinare",
    "determinai": "determinare",
    "determinammo": "determinare",
    "determinan": "determinare",
    "determinando": "determinare",
    "determinano": "determinare",
    "determinante": "determinare",
    "determinanti": "determinare",
    "determinar": "determinare",
    "determinaron": "determinare",
    "determinarono": "determinare",
    "determinasse": "determinare",
    "determinasser": "determinare",
    "determinassero": "determinare",
    "determinassi": "determinare",
    "determinassimo": "determinare",
    "determinaste": "determinare",
    "determinasti": "determinare",
    "determinata": "determinato",
    "determinate": "determinato",
    "determinati": "determinato",
    "determinato": "determinare",
    "determinava": "determinare",
    "determinavamo": "determinare",
    "determinavan": "determinare",
    "determinavano": "determinare",
    "determinavate": "determinare",
    "determinavi": "determinare",
    "determinavo": "determinare",
    "determinazioni": "determinazione",
    "determinerai": "determinare",
    "determineran": "determinare",
    "determineranno": "determinare",
    "determinerebbe": "determinare",
    "determinerebber": "determinare",
    "determinerebbero": "determinare",
    "determinerei": "determinare",
    "determineremmo": "determinare",
    "determineremo": "determinare",
    "determinereste": "determinare",
    "determineresti": "determinare",
    "determinerete": "determinare",
    "determinerà": "determinare",
    "determinerò": "determinare",
    "determini": "determinare",
    "determiniamo": "determinare",
    "determiniate": "determinare",
    "determinin": "determinare",
    "determinino": "determinare",
    "determinismi": "determinismo",
    "determino": "determinare",
    "determinò": "determinare",
    "deterrai": "detenere",
    "deterran": "detenere",
    "deterranno": "detenere",
    "deterrebbe": "detenere",
    "deterrebber": "detenere",
    "deterrebbero": "detenere",
    "deterrei": "detenere",
    "deterremmo": "detenere",
    "deterremo": "detenere",
    "deterrenti": "deterrente",
    "deterrenze": "deterrenza",
    "deterreste": "detenere",
    "deterresti": "detenere",
    "deterrete": "detenere",
    "deterrà": "detenere",
    "deterrò": "detenere",
    "deterser": "detergere",
    "detersero": "detergere",
    "detersi": "detergere",
    "detersiva": "detersivo",
    "detersive": "detersivo",
    "detersivi": "detersivo",
    "detersè": "detergere",
    "deterta": "detergere",
    "deterte": "detergere",
    "deterti": "detergere",
    "deterto": "detergere",
    "detesta": "detestare",
    "detestabili": "detestabile",
    "detestai": "detestare",
    "detestammo": "detestare",
    "detestan": "detestare",
    "detestando": "detestare",
    "detestano": "detestare",
    "detestante": "detestare",
    "detestanti": "detestare",
    "detestar": "detestare",
    "detestaron": "detestare",
    "detestarono": "detestare",
    "detestasse": "detestare",
    "detestasser": "detestare",
    "detestassero": "detestare",
    "detestassi": "detestare",
    "detestassimo": "detestare",
    "detestaste": "detestare",
    "detestasti": "detestare",
    "detestata": "detestare",
    "detestate": "detestare",
    "detestati": "detestare",
    "detestato": "detestare",
    "detestava": "detestare",
    "detestavamo": "detestare",
    "detestavan": "detestare",
    "detestavano": "detestare",
    "detestavate": "detestare",
    "detestavi": "detestare",
    "detestavo": "detestare",
    "detesterai": "detestare",
    "detesteran": "detestare",
    "detesteranno": "detestare",
    "detesterebbe": "detestare",
    "detesterebber": "detestare",
    "detesterebbero": "detestare",
    "detesterei": "detestare",
    "detesteremmo": "detestare",
    "detesteremo": "detestare",
    "detestereste": "detestare",
    "detesteresti": "detestare",
    "detesterete": "detestare",
    "detesterà": "detestare",
    "detesterò": "detestare",
    "detesti": "detestare",
    "detestiamo": "detestare",
    "detestiate": "detestare",
    "detestin": "detestare",
    "detestino": "detestare",
    "detesto": "detestare",
    "detestò": "detestare",
    "detiene": "detenere",
    "detieni": "detenere",
    "detona": "detonare",
    "detonai": "detonare",
    "detonammo": "detonare",
    "detonan": "detonare",
    "detonando": "detonare",
    "detonano": "detonare",
    "detonante": "detonare",
    "detonanti": "detonare",
    "detonar": "detonare",
    "detonaron": "detonare",
    "detonarono": "detonare",
    "detonasse": "detonare",
    "detonasser": "detonare",
    "detonassero": "detonare",
    "detonassi": "detonare",
    "detonassimo": "detonare",
    "detonaste": "detonare",
    "detonasti": "detonare",
    "detonata": "detonare",
    "detonate": "detonare",
    "detonati": "detonare",
    "detonato": "detonare",
    "detonatori": "detonatore",
    "detonava": "detonare",
    "detonavamo": "detonare",
    "detonavan": "detonare",
    "detonavano": "detonare",
    "detonavate": "detonare",
    "detonavi": "detonare",
    "detonavo": "detonare",
    "detonazioni": "detonazione",
    "detonerai": "detonare",
    "detoneran": "detonare",
    "detoneranno": "detonare",
    "detonerebbe": "detonare",
    "detonerebber": "detonare",
    "detonerebbero": "detonare",
    "detonerei": "detonare",
    "detoneremmo": "detonare",
    "detoneremo": "detonare",
    "detonereste": "detonare",
    "detoneresti": "detonare",
    "detonerete": "detonare",
    "detonerà": "detonare",
    "detonerò": "detonare",
    "detoni": "detonare",
    "detoniamo": "detonare",
    "detoniate": "detonare",
    "detonin": "detonare",
    "detonino": "detonare",
    "detono": "detonare",
    "detonò": "detonare",
    "detrae": "detrarre",
    "detraemmo": "detrarre",
    "detraendo": "detrarre",
    "detraente": "detrarre",
    "detraenti": "detrarre",
    "detraesse": "detrarre",
    "detraesser": "detrarre",
    "detraessero": "detrarre",
    "detraessi": "detrarre",
    "detraessimo": "detrarre",
    "detraeste": "detrarre",
    "detraesti": "detrarre",
    "detraete": "detrarre",
    "detraeva": "detrarre",
    "detraevamo": "detrarre",
    "detraevan": "detrarre",
    "detraevano": "detrarre",
    "detraevate": "detrarre",
    "detraevi": "detrarre",
    "detraevo": "detrarre",
    "detragga": "detrarre",
    "detraggan": "detrarre",
    "detraggano": "detrarre",
    "detraggo": "detrarre",
    "detraggon": "detrarre",
    "detraggono": "detrarre",
    "detrai": "detrarre",
    "detraiamo": "detrarre",
    "detraiate": "detrarre",
    "detraibili": "detraibile",
    "detrarr": "detrarre",
    "detrarrai": "detrarre",
    "detrarran": "detrarre",
    "detrarranno": "detrarre",
    "detrarrebbe": "detrarre",
    "detrarrebber": "detrarre",
    "detrarrebbero": "detrarre",
    "detrarrei": "detrarre",
    "detrarremmo": "detrarre",
    "detrarremo": "detrarre",
    "detrarreste": "detrarre",
    "detrarresti": "detrarre",
    "detrarrete": "detrarre",
    "detrarrà": "detrarre",
    "detrarrò": "detrarre",
    "detrasse": "detrarre",
    "detrasser": "detrarre",
    "detrassero": "detrarre",
    "detrassi": "detrarre",
    "detratta": "detrarre",
    "detratte": "detrarre",
    "detratti": "detrarre",
    "detratto": "detrarre",
    "detrattori": "detrattore",
    "detrazioni": "detrazione",
    "detriti": "detrito",
    "detronizza": "detronizzare",
    "detronizzai": "detronizzare",
    "detronizzammo": "detronizzare",
    "detronizzan": "detronizzare",
    "detronizzando": "detronizzare",
    "detronizzano": "detronizzare",
    "detronizzante": "detronizzare",
    "detronizzanti": "detronizzare",
    "detronizzar": "detronizzare",
    "detronizzaron": "detronizzare",
    "detronizzarono": "detronizzare",
    "detronizzasse": "detronizzare",
    "detronizzasser": "detronizzare",
    "detronizzassero": "detronizzare",
    "detronizzassi": "detronizzare",
    "detronizzassimo": "detronizzare",
    "detronizzaste": "detronizzare",
    "detronizzasti": "detronizzare",
    "detronizzata": "detronizzare",
    "detronizzate": "detronizzare",
    "detronizzati": "detronizzare",
    "detronizzato": "detronizzare",
    "detronizzava": "detronizzare",
    "detronizzavamo": "detronizzare",
    "detronizzavan": "detronizzare",
    "detronizzavano": "detronizzare",
    "detronizzavate": "detronizzare",
    "detronizzavi": "detronizzare",
    "detronizzavo": "detronizzare",
    "detronizzerai": "detronizzare",
    "detronizzeran": "detronizzare",
    "detronizzeranno": "detronizzare",
    "detronizzerebbe": "detronizzare",
    "detronizzerebber": "detronizzare",
    "detronizzerebbero": "detronizzare",
    "detronizzerei": "detronizzare",
    "detronizzeremmo": "detronizzare",
    "detronizzeremo": "detronizzare",
    "detronizzereste": "detronizzare",
    "detronizzeresti": "detronizzare",
    "detronizzerete": "detronizzare",
    "detronizzerà": "detronizzare",
    "detronizzerò": "detronizzare",
    "detronizzi": "detronizzare",
    "detronizziamo": "detronizzare",
    "detronizziate": "detronizzare",
    "detronizzin": "detronizzare",
    "detronizzino": "detronizzare",
    "detronizzo": "detronizzare",
    "detronizzò": "detronizzare",
    "detta": "dire",
    "dettagli": "dettaglio",
    "dettaglia": "dettagliare",
    "dettagliai": "dettagliare",
    "dettagliammo": "dettagliare",
    "dettagliamo": "dettagliare",
    "dettaglian": "dettagliare",
    "dettagliando": "dettagliare",
    "dettagliano": "dettagliare",
    "dettagliante": "dettagliare",
    "dettaglianti": "dettagliare",
    "dettagliar": "dettagliare",
    "dettagliaron": "dettagliare",
    "dettagliarono": "dettagliare",
    "dettagliasse": "dettagliare",
    "dettagliasser": "dettagliare",
    "dettagliassero": "dettagliare",
    "dettagliassi": "dettagliare",
    "dettagliassimo": "dettagliare",
    "dettagliaste": "dettagliare",
    "dettagliasti": "dettagliare",
    "dettagliata": "dettagliato",
    "dettagliate": "dettagliato",
    "dettagliati": "dettagliato",
    "dettagliato": "dettagliare",
    "dettagliava": "dettagliare",
    "dettagliavamo": "dettagliare",
    "dettagliavan": "dettagliare",
    "dettagliavano": "dettagliare",
    "dettagliavate": "dettagliare",
    "dettagliavi": "dettagliare",
    "dettagliavo": "dettagliare",
    "dettaglierai": "dettagliare",
    "dettaglieran": "dettagliare",
    "dettaglieranno": "dettagliare",
    "dettaglierebbe": "dettagliare",
    "dettaglierebber": "dettagliare",
    "dettaglierebbero": "dettagliare",
    "dettaglierei": "dettagliare",
    "dettaglieremmo": "dettagliare",
    "dettaglieremo": "dettagliare",
    "dettagliereste": "dettagliare",
    "dettaglieresti": "dettagliare",
    "dettaglierete": "dettagliare",
    "dettaglierà": "dettagliare",
    "dettaglierò": "dettagliare",
    "dettaglin": "dettagliare",
    "dettaglino": "dettagliare",
    "dettaglio": "dettagliare",
    "dettagliò": "dettagliare",
    "dettai": "dettare",
    "dettami": "dettame",
    "dettammo": "dettare",
    "dettan": "dettare",
    "dettando": "dettare",
    "dettano": "dettare",
    "dettante": "dettare",
    "dettanti": "dettare",
    "dettar": "dettare",
    "dettaron": "dettare",
    "dettarono": "dettare",
    "dettasse": "dettare",
    "dettasser": "dettare",
    "dettassero": "dettare",
    "dettassi": "dettare",
    "dettassimo": "dettare",
    "dettaste": "dettare",
    "dettasti": "dettare",
    "dettata": "dettato",
    "dettate": "dettato",
    "dettati": "dettato",
    "dettato": "dettare",
    "dettava": "dettare",
    "dettavamo": "dettare",
    "dettavan": "dettare",
    "dettavano": "dettare",
    "dettavate": "dettare",
    "dettavi": "dettare",
    "dettavo": "dettare",
    "dette": "dire",
    "detter": "dare",
    "detterai": "dettare",
    "detteran": "dettare",
    "detteranno": "dettare",
    "detterebbe": "dettare",
    "detterebber": "dettare",
    "detterebbero": "dettare",
    "detterei": "dettare",
    "detteremmo": "dettare",
    "detteremo": "dettare",
    "dettereste": "dettare",
    "detteresti": "dettare",
    "detterete": "dettare",
    "dettero": "dare",
    "detterà": "dettare",
    "detterò": "dettare",
    "detti": "dire",
    "dettiamo": "dettare",
    "dettiate": "dettare",
    "dettin": "dettare",
    "dettino": "dettare",
    "detto": "dire",
    "dettò": "dettare",
    "deturpa": "deturpare",
    "deturpai": "deturpare",
    "deturpammo": "deturpare",
    "deturpan": "deturpare",
    "deturpando": "deturpare",
    "deturpano": "deturpare",
    "deturpante": "deturpare",
    "deturpanti": "deturpare",
    "deturpar": "deturpare",
    "deturparon": "deturpare",
    "deturparono": "deturpare",
    "deturpasse": "deturpare",
    "deturpasser": "deturpare",
    "deturpassero": "deturpare",
    "deturpassi": "deturpare",
    "deturpassimo": "deturpare",
    "deturpaste": "deturpare",
    "deturpasti": "deturpare",
    "deturpata": "deturpare",
    "deturpate": "deturpare",
    "deturpati": "deturpare",
    "deturpato": "deturpare",
    "deturpava": "deturpare",
    "deturpavamo": "deturpare",
    "deturpavan": "deturpare",
    "deturpavano": "deturpare",
    "deturpavate": "deturpare",
    "deturpavi": "deturpare",
    "deturpavo": "deturpare",
    "deturperai": "deturpare",
    "deturperan": "deturpare",
    "deturperanno": "deturpare",
    "deturperebbe": "deturpare",
    "deturperebber": "deturpare",
    "deturperebbero": "deturpare",
    "deturperei": "deturpare",
    "deturperemmo": "deturpare",
    "deturperemo": "deturpare",
    "deturpereste": "deturpare",
    "deturperesti": "deturpare",
    "deturperete": "deturpare",
    "deturperà": "deturpare",
    "deturperò": "deturpare",
    "deturpi": "deturpare",
    "deturpiamo": "deturpare",
    "deturpiate": "deturpare",
    "deturpin": "deturpare",
    "deturpino": "deturpare",
    "deturpo": "deturpare",
    "deturpò": "deturpare",
    "deuteri": "deuterio",
    "devasta": "devastare",
    "devastai": "devastare",
    "devastammo": "devastare",
    "devastan": "devastare",
    "devastando": "devastare",
    "devastano": "devastare",
    "devastante": "devastare",
    "devastanti": "devastare",
    "devastar": "devastare",
    "devastaron": "devastare",
    "devastarono": "devastare",
    "devastasse": "devastare",
    "devastasser": "devastare",
    "devastassero": "devastare",
    "devastassi": "devastare",
    "devastassimo": "devastare",
    "devastaste": "devastare",
    "devastasti": "devastare",
    "devastata": "devastare",
    "devastate": "devastare",
    "devastati": "devastare",
    "devastato": "devastare",
    "devastatori": "devastatore",
    "devastatrice": "devastatore",
    "devastatrici": "devastatore",
    "devastava": "devastare",
    "devastavamo": "devastare",
    "devastavan": "devastare",
    "devastavano": "devastare",
    "devastavate": "devastare",
    "devastavi": "devastare",
    "devastavo": "devastare",
    "devastazioni": "devastazione",
    "devasterai": "devastare",
    "devasteran": "devastare",
    "devasteranno": "devastare",
    "devasterebbe": "devastare",
    "devasterebber": "devastare",
    "devasterebbero": "devastare",
    "devasterei": "devastare",
    "devasteremmo": "devastare",
    "devasteremo": "devastare",
    "devastereste": "devastare",
    "devasteresti": "devastare",
    "devasterete": "devastare",
    "devasterà": "devastare",
    "devasterò": "devastare",
    "devasti": "devastare",
    "devastiamo": "devastare",
    "devastiate": "devastare",
    "devastin": "devastare",
    "devastino": "devastare",
    "devasto": "devastare",
    "devastò": "devastare",
    "deve": "dovere",
    "devi": "dovere",
    "devia": "deviare",
    "deviai": "deviare",
    "deviammo": "deviare",
    "deviamo": "deviare",
    "devian": "deviare",
    "deviando": "deviare",
    "deviano": "deviare",
    "deviante": "deviare",
    "devianti": "deviare",
    "devianze": "devianza",
    "deviar": "deviare",
    "deviaron": "deviare",
    "deviarono": "deviare",
    "deviasse": "deviare",
    "deviasser": "deviare",
    "deviassero": "deviare",
    "deviassi": "deviare",
    "deviassimo": "deviare",
    "deviaste": "deviare",
    "deviasti": "deviare",
    "deviata": "deviare",
    "deviate": "deviare",
    "deviati": "deviare",
    "deviato": "deviare",
    "deviatori": "deviatore",
    "deviava": "deviare",
    "deviavamo": "deviare",
    "deviavan": "deviare",
    "deviavano": "deviare",
    "deviavate": "deviare",
    "deviavi": "deviare",
    "deviavo": "deviare",
    "deviazioni": "deviazione",
    "devierai": "deviare",
    "devieran": "deviare",
    "devieranno": "deviare",
    "devierebbe": "deviare",
    "devierebber": "deviare",
    "devierebbero": "deviare",
    "devierei": "deviare",
    "devieremmo": "deviare",
    "devieremo": "deviare",
    "deviereste": "deviare",
    "devieresti": "deviare",
    "devierete": "deviare",
    "devierà": "deviare",
    "devierò": "deviare",
    "devin": "deviare",
    "devino": "deviare",
    "devio": "deviare",
    "devitalizza": "devitalizzare",
    "devitalizzai": "devitalizzare",
    "devitalizzammo": "devitalizzare",
    "devitalizzan": "devitalizzare",
    "devitalizzando": "devitalizzare",
    "devitalizzano": "devitalizzare",
    "devitalizzante": "devitalizzare",
    "devitalizzanti": "devitalizzare",
    "devitalizzar": "devitalizzare",
    "devitalizzaron": "devitalizzare",
    "devitalizzarono": "devitalizzare",
    "devitalizzasse": "devitalizzare",
    "devitalizzasser": "devitalizzare",
    "devitalizzassero": "devitalizzare",
    "devitalizzassi": "devitalizzare",
    "devitalizzassimo": "devitalizzare",
    "devitalizzaste": "devitalizzare",
    "devitalizzasti": "devitalizzare",
    "devitalizzata": "devitalizzare",
    "devitalizzate": "devitalizzare",
    "devitalizzati": "devitalizzare",
    "devitalizzato": "devitalizzare",
    "devitalizzava": "devitalizzare",
    "devitalizzavamo": "devitalizzare",
    "devitalizzavan": "devitalizzare",
    "devitalizzavano": "devitalizzare",
    "devitalizzavate": "devitalizzare",
    "devitalizzavi": "devitalizzare",
    "devitalizzavo": "devitalizzare",
    "devitalizzerai": "devitalizzare",
    "devitalizzeran": "devitalizzare",
    "devitalizzeranno": "devitalizzare",
    "devitalizzerebbe": "devitalizzare",
    "devitalizzerebber": "devitalizzare",
    "devitalizzerebbero": "devitalizzare",
    "devitalizzerei": "devitalizzare",
    "devitalizzeremmo": "devitalizzare",
    "devitalizzeremo": "devitalizzare",
    "devitalizzereste": "devitalizzare",
    "devitalizzeresti": "devitalizzare",
    "devitalizzerete": "devitalizzare",
    "devitalizzerà": "devitalizzare",
    "devitalizzerò": "devitalizzare",
    "devitalizzi": "devitalizzare",
    "devitalizziamo": "devitalizzare",
    "devitalizziate": "devitalizzare",
    "devitalizzin": "devitalizzare",
    "devitalizzino": "devitalizzare",
    "devitalizzo": "devitalizzare",
    "devitalizzò": "devitalizzare",
    "deviò": "deviare",
    "devo": "dovere",
    "devolva": "devolvere",
    "devolvan": "devolvere",
    "devolvano": "devolvere",
    "devolve": "devolvere",
    "devolvei": "devolvere",
    "devolvemmo": "devolvere",
    "devolvendo": "devolvere",
    "devolvente": "devolvere",
    "devolventi": "devolvere",
    "devolver": "devolvere",
    "devolverai": "devolvere",
    "devolveran": "devolvere",
    "devolveranno": "devolvere",
    "devolverebbe": "devolvere",
    "devolverebber": "devolvere",
    "devolverebbero": "devolvere",
    "devolverei": "devolvere",
    "devolveremmo": "devolvere",
    "devolveremo": "devolvere",
    "devolvereste": "devolvere",
    "devolveresti": "devolvere",
    "devolverete": "devolvere",
    "devolveron": "devolvere",
    "devolverono": "devolvere",
    "devolverà": "devolvere",
    "devolverò": "devolvere",
    "devolvesse": "devolvere",
    "devolvesser": "devolvere",
    "devolvessero": "devolvere",
    "devolvessi": "devolvere",
    "devolvessimo": "devolvere",
    "devolveste": "devolvere",
    "devolvesti": "devolvere",
    "devolvete": "devolvere",
    "devolveva": "devolvere",
    "devolvevamo": "devolvere",
    "devolvevan": "devolvere",
    "devolvevano": "devolvere",
    "devolvevate": "devolvere",
    "devolvevi": "devolvere",
    "devolvevo": "devolvere",
    "devolvi": "devolvere",
    "devolviamo": "devolvere",
    "devolviate": "devolvere",
    "devolvo": "devolvere",
    "devolvon": "devolvere",
    "devolvono": "devolvere",
    "devolvuta": "devolvere",
    "devolvute": "devolvere",
    "devolvuti": "devolvere",
    "devolvuto": "devolvere",
    "devolvè": "devolvere",
    "devon": "dovere",
    "devono": "dovere",
    "devota": "devoto",
    "devote": "devoto",
    "devoti": "devoto",
    "devozionali": "devozionale",
    "devozioni": "devozione",
    "di'": "dire",
    "dia": "dare",
    "diabetica": "diabetico",
    "diabetiche": "diabetico",
    "diabetici": "diabetico",
    "diabetologi": "diabetologo",
    "diabolica": "diabolico",
    "diaboliche": "diabolico",
    "diabolici": "diabolico",
    "diaconi": "diacono",
    "diademi": "diadema",
    "diaframma": "diaframmare",
    "diaframmai": "diaframmare",
    "diaframmammo": "diaframmare",
    "diaframman": "diaframmare",
    "diaframmando": "diaframmare",
    "diaframmano": "diaframmare",
    "diaframmante": "diaframmare",
    "diaframmanti": "diaframmare",
    "diaframmar": "diaframmare",
    "diaframmaron": "diaframmare",
    "diaframmarono": "diaframmare",
    "diaframmasse": "diaframmare",
    "diaframmasser": "diaframmare",
    "diaframmassero": "diaframmare",
    "diaframmassi": "diaframmare",
    "diaframmassimo": "diaframmare",
    "diaframmaste": "diaframmare",
    "diaframmasti": "diaframmare",
    "diaframmata": "diaframmare",
    "diaframmate": "diaframmare",
    "diaframmati": "diaframmare",
    "diaframmatica": "diaframmatico",
    "diaframmatiche": "diaframmatico",
    "diaframmatici": "diaframmatico",
    "diaframmato": "diaframmare",
    "diaframmava": "diaframmare",
    "diaframmavamo": "diaframmare",
    "diaframmavan": "diaframmare",
    "diaframmavano": "diaframmare",
    "diaframmavate": "diaframmare",
    "diaframmavi": "diaframmare",
    "diaframmavo": "diaframmare",
    "diaframmerai": "diaframmare",
    "diaframmeran": "diaframmare",
    "diaframmeranno": "diaframmare",
    "diaframmerebbe": "diaframmare",
    "diaframmerebber": "diaframmare",
    "diaframmerebbero": "diaframmare",
    "diaframmerei": "diaframmare",
    "diaframmeremmo": "diaframmare",
    "diaframmeremo": "diaframmare",
    "diaframmereste": "diaframmare",
    "diaframmeresti": "diaframmare",
    "diaframmerete": "diaframmare",
    "diaframmerà": "diaframmare",
    "diaframmerò": "diaframmare",
    "diaframmi": "diaframmare",
    "diaframmiamo": "diaframmare",
    "diaframmiate": "diaframmare",
    "diaframmin": "diaframmare",
    "diaframmino": "diaframmare",
    "diaframmo": "diaframmare",
    "diaframmò": "diaframmare",
    "diagnostica": "diagnostico",
    "diagnosticai": "diagnosticare",
    "diagnosticammo": "diagnosticare",
    "diagnostican": "diagnosticare",
    "diagnosticando": "diagnosticare",
    "diagnosticano": "diagnosticare",
    "diagnosticante": "diagnosticare",
    "diagnosticanti": "diagnosticare",
    "diagnosticar": "diagnosticare",
    "diagnosticaron": "diagnosticare",
    "diagnosticarono": "diagnosticare",
    "diagnosticasse": "diagnosticare",
    "diagnosticasser": "diagnosticare",
    "diagnosticassero": "diagnosticare",
    "diagnosticassi": "diagnosticare",
    "diagnosticassimo": "diagnosticare",
    "diagnosticaste": "diagnosticare",
    "diagnosticasti": "diagnosticare",
    "diagnosticata": "diagnosticare",
    "diagnosticate": "diagnosticare",
    "diagnosticati": "diagnosticare",
    "diagnosticato": "diagnosticare",
    "diagnosticava": "diagnosticare",
    "diagnosticavamo": "diagnosticare",
    "diagnosticavan": "diagnosticare",
    "diagnosticavano": "diagnosticare",
    "diagnosticavate": "diagnosticare",
    "diagnosticavi": "diagnosticare",
    "diagnosticavo": "diagnosticare",
    "diagnostiche": "diagnostico",
    "diagnosticherai": "diagnosticare",
    "diagnosticheran": "diagnosticare",
    "diagnosticheranno": "diagnosticare",
    "diagnosticherebbe": "diagnosticare",
    "diagnosticherebber": "diagnosticare",
    "diagnosticherebbero": "diagnosticare",
    "diagnosticherei": "diagnosticare",
    "diagnosticheremmo": "diagnosticare",
    "diagnosticheremo": "diagnosticare",
    "diagnostichereste": "diagnosticare",
    "diagnosticheresti": "diagnosticare",
    "diagnosticherete": "diagnosticare",
    "diagnosticherà": "diagnosticare",
    "diagnosticherò": "diagnosticare",
    "diagnostichi": "diagnosticare",
    "diagnostichiamo": "diagnosticare",
    "diagnostichiate": "diagnosticare",
    "diagnostichin": "diagnosticare",
    "diagnostichino": "diagnosticare",
    "diagnostici": "diagnostico",
    "diagnostico": "diagnosticare",
    "diagnosticò": "diagnosticare",
    "diagonali": "diagonale",
    "diagramma": "diagrammare",
    "diagrammai": "diagrammare",
    "diagrammammo": "diagrammare",
    "diagramman": "diagrammare",
    "diagrammando": "diagrammare",
    "diagrammano": "diagrammare",
    "diagrammante": "diagrammare",
    "diagrammanti": "diagrammare",
    "diagrammar": "diagrammare",
    "diagrammaron": "diagrammare",
    "diagrammarono": "diagrammare",
    "diagrammasse": "diagrammare",
    "diagrammasser": "diagrammare",
    "diagrammassero": "diagrammare",
    "diagrammassi": "diagrammare",
    "diagrammassimo": "diagrammare",
    "diagrammaste": "diagrammare",
    "diagrammasti": "diagrammare",
    "diagrammata": "diagrammare",
    "diagrammate": "diagrammare",
    "diagrammati": "diagrammare",
    "diagrammato": "diagrammare",
    "diagrammava": "diagrammare",
    "diagrammavamo": "diagrammare",
    "diagrammavan": "diagrammare",
    "diagrammavano": "diagrammare",
    "diagrammavate": "diagrammare",
    "diagrammavi": "diagrammare",
    "diagrammavo": "diagrammare",
    "diagrammerai": "diagrammare",
    "diagrammeran": "diagrammare",
    "diagrammeranno": "diagrammare",
    "diagrammerebbe": "diagrammare",
    "diagrammerebber": "diagrammare",
    "diagrammerebbero": "diagrammare",
    "diagrammerei": "diagrammare",
    "diagrammeremmo": "diagrammare",
    "diagrammeremo": "diagrammare",
    "diagrammereste": "diagrammare",
    "diagrammeresti": "diagrammare",
    "diagrammerete": "diagrammare",
    "diagrammerà": "diagrammare",
    "diagrammerò": "diagrammare",
    "diagrammi": "diagrammare",
    "diagrammiamo": "diagrammare",
    "diagrammiate": "diagrammare",
    "diagrammin": "diagrammare",
    "diagrammino": "diagrammare",
    "diagrammo": "diagrammare",
    "diagrammò": "diagrammare",
    "dialettali": "dialettale",
    "dialetti": "dialetto",
    "dialettica": "dialettico",
    "dialettiche": "dialettico",
    "dialettici": "dialettico",
    "dialitica": "dialitico",
    "dialitiche": "dialitico",
    "dialitici": "dialitico",
    "dializza": "dializzare",
    "dializzai": "dializzare",
    "dializzammo": "dializzare",
    "dializzan": "dializzare",
    "dializzando": "dializzare",
    "dializzano": "dializzare",
    "dializzante": "dializzare",
    "dializzanti": "dializzare",
    "dializzar": "dializzare",
    "dializzaron": "dializzare",
    "dializzarono": "dializzare",
    "dializzasse": "dializzare",
    "dializzasser": "dializzare",
    "dializzassero": "dializzare",
    "dializzassi": "dializzare",
    "dializzassimo": "dializzare",
    "dializzaste": "dializzare",
    "dializzasti": "dializzare",
    "dializzata": "dializzare",
    "dializzate": "dializzare",
    "dializzati": "dializzato",
    "dializzato": "dializzare",
    "dializzava": "dializzare",
    "dializzavamo": "dializzare",
    "dializzavan": "dializzare",
    "dializzavano": "dializzare",
    "dializzavate": "dializzare",
    "dializzavi": "dializzare",
    "dializzavo": "dializzare",
    "dializzerai": "dializzare",
    "dializzeran": "dializzare",
    "dializzeranno": "dializzare",
    "dializzerebbe": "dializzare",
    "dializzerebber": "dializzare",
    "dializzerebbero": "dializzare",
    "dializzerei": "dializzare",
    "dializzeremmo": "dializzare",
    "dializzeremo": "dializzare",
    "dializzereste": "dializzare",
    "dializzeresti": "dializzare",
    "dializzerete": "dializzare",
    "dializzerà": "dializzare",
    "dializzerò": "dializzare",
    "dializzi": "dializzare",
    "dializziamo": "dializzare",
    "dializziate": "dializzare",
    "dializzin": "dializzare",
    "dializzino": "dializzare",
    "dializzo": "dializzare",
    "dializzò": "dializzare",
    "dialoga": "dialogare",
    "dialogai": "dialogare",
    "dialogammo": "dialogare",
    "dialogan": "dialogare",
    "dialogando": "dialogare",
    "dialogano": "dialogare",
    "dialogante": "dialogare",
    "dialoganti": "dialogare",
    "dialogar": "dialogare",
    "dialogaron": "dialogare",
    "dialogarono": "dialogare",
    "dialogasse": "dialogare",
    "dialogasser": "dialogare",
    "dialogassero": "dialogare",
    "dialogassi": "dialogare",
    "dialogassimo": "dialogare",
    "dialogaste": "dialogare",
    "dialogasti": "dialogare",
    "dialogata": "dialogare",
    "dialogate": "dialogare",
    "dialogati": "dialogare",
    "dialogato": "dialogare",
    "dialogava": "dialogare",
    "dialogavamo": "dialogare",
    "dialogavan": "dialogare",
    "dialogavano": "dialogare",
    "dialogavate": "dialogare",
    "dialogavi": "dialogare",
    "dialogavo": "dialogare",
    "dialogherai": "dialogare",
    "dialogheran": "dialogare",
    "dialogheranno": "dialogare",
    "dialogherebbe": "dialogare",
    "dialogherebber": "dialogare",
    "dialogherebbero": "dialogare",
    "dialogherei": "dialogare",
    "dialogheremmo": "dialogare",
    "dialogheremo": "dialogare",
    "dialoghereste": "dialogare",
    "dialogheresti": "dialogare",
    "dialogherete": "dialogare",
    "dialogherà": "dialogare",
    "dialogherò": "dialogare",
    "dialoghetti": "dialoghetto",
    "dialoghi": "dialogo",
    "dialoghiamo": "dialogare",
    "dialoghiate": "dialogare",
    "dialoghin": "dialogare",
    "dialoghino": "dialogare",
    "dialogica": "dialogico",
    "dialogiche": "dialogico",
    "dialogici": "dialogico",
    "dialogo": "dialogare",
    "dialogò": "dialogare",
    "diamanti": "diamante",
    "diamantifera": "diamantifero",
    "diamantifere": "diamantifero",
    "diamantiferi": "diamantifero",
    "diametri": "diametro",
    "diamo": "dare",
    "dian": "dare",
    "diano": "dare",
    "diapositive": "diapositiva",
    "diarchie": "diarchia",
    "diari": "diario",
    "diarie": "diaria",
    "diaristica": "diaristico",
    "diaristiche": "diaristico",
    "diaristici": "diaristico",
    "diarree": "diarrea",
    "diaspore": "diaspora",
    "diate": "dare",
    "diatonica": "diatonico",
    "diatoniche": "diatonico",
    "diatonici": "diatonico",
    "diatribe": "diatriba",
    "diavolerie": "diavoleria",
    "diavolesca": "diavolesco",
    "diavolesche": "diavolesco",
    "diavoleschi": "diavolesco",
    "diavoletti": "diavoletto",
    "diavoli": "diavolo",
    "dibatta": "dibattere",
    "dibattan": "dibattere",
    "dibattano": "dibattere",
    "dibatte": "dibattere",
    "dibattei": "dibattere",
    "dibattemmo": "dibattere",
    "dibattendo": "dibattere",
    "dibattente": "dibattere",
    "dibattenti": "dibattere",
    "dibatter": "dibattere",
    "dibatterai": "dibattere",
    "dibatteran": "dibattere",
    "dibatteranno": "dibattere",
    "dibatterebbe": "dibattere",
    "dibatterebber": "dibattere",
    "dibatterebbero": "dibattere",
    "dibatterei": "dibattere",
    "dibatteremmo": "dibattere",
    "dibatteremo": "dibattere",
    "dibattereste": "dibattere",
    "dibatteresti": "dibattere",
    "dibatterete": "dibattere",
    "dibatteron": "dibattere",
    "dibatterono": "dibattere",
    "dibatterà": "dibattere",
    "dibatterò": "dibattere",
    "dibattesse": "dibattere",
    "dibattesser": "dibattere",
    "dibattessero": "dibattere",
    "dibattessi": "dibattere",
    "dibattessimo": "dibattere",
    "dibatteste": "dibattere",
    "dibattesti": "dibattere",
    "dibattete": "dibattere",
    "dibatteva": "dibattere",
    "dibattevamo": "dibattere",
    "dibattevan": "dibattere",
    "dibattevano": "dibattere",
    "dibattevate": "dibattere",
    "dibattevi": "dibattere",
    "dibattevo": "dibattere",
    "dibatti": "dibattere",
    "dibattiamo": "dibattere",
    "dibattiate": "dibattere",
    "dibattimentali": "dibattimentale",
    "dibattimenti": "dibattimento",
    "dibattiti": "dibattito",
    "dibattitti": "dibattitto",
    "dibatto": "dibattere",
    "dibatton": "dibattere",
    "dibattono": "dibattere",
    "dibattuta": "dibattere",
    "dibattute": "dibattere",
    "dibattuti": "dibattere",
    "dibattuto": "dibattere",
    "dibattè": "dibattere",
    "dibosca": "diboscare",
    "diboscai": "diboscare",
    "diboscammo": "diboscare",
    "diboscan": "diboscare",
    "diboscando": "diboscare",
    "diboscano": "diboscare",
    "diboscante": "diboscare",
    "diboscanti": "diboscare",
    "diboscar": "diboscare",
    "diboscaron": "diboscare",
    "diboscarono": "diboscare",
    "diboscasse": "diboscare",
    "diboscasser": "diboscare",
    "diboscassero": "diboscare",
    "diboscassi": "diboscare",
    "diboscassimo": "diboscare",
    "diboscaste": "diboscare",
    "diboscasti": "diboscare",
    "diboscata": "diboscare",
    "diboscate": "diboscare",
    "diboscati": "diboscare",
    "diboscato": "diboscare",
    "diboscava": "diboscare",
    "diboscavamo": "diboscare",
    "diboscavan": "diboscare",
    "diboscavano": "diboscare",
    "diboscavate": "diboscare",
    "diboscavi": "diboscare",
    "diboscavo": "diboscare",
    "diboscherai": "diboscare",
    "diboscheran": "diboscare",
    "diboscheranno": "diboscare",
    "diboscherebbe": "diboscare",
    "diboscherebber": "diboscare",
    "diboscherebbero": "diboscare",
    "diboscherei": "diboscare",
    "diboscheremmo": "diboscare",
    "diboscheremo": "diboscare",
    "diboschereste": "diboscare",
    "diboscheresti": "diboscare",
    "diboscherete": "diboscare",
    "diboscherà": "diboscare",
    "diboscherò": "diboscare",
    "diboschi": "diboscare",
    "diboschiamo": "diboscare",
    "diboschiate": "diboscare",
    "diboschin": "diboscare",
    "diboschino": "diboscare",
    "dibosco": "diboscare",
    "diboscò": "diboscare",
    "dica": "dire",
    "dicai": "dicare",
    "dicammo": "dicare",
    "dican": "dire",
    "dicando": "dicare",
    "dicano": "dire",
    "dicante": "dicare",
    "dicanti": "dicare",
    "dicar": "dicare",
    "dicaron": "dicare",
    "dicarono": "dicare",
    "dicasse": "dicare",
    "dicasser": "dicare",
    "dicassero": "dicare",
    "dicassi": "dicare",
    "dicassimo": "dicare",
    "dicaste": "dicare",
    "dicasteri": "dicastero",
    "dicasti": "dicare",
    "dicata": "dicare",
    "dicate": "dicare",
    "dicati": "dicare",
    "dicato": "dicare",
    "dicava": "dicare",
    "dicavamo": "dicare",
    "dicavan": "dicare",
    "dicavano": "dicare",
    "dicavate": "dicare",
    "dicavi": "dicare",
    "dicavo": "dicare",
    "dice": "dire",
    "dicembri": "dicembre",
    "dicemmo": "dire",
    "dicendo": "dire",
    "dicente": "dire",
    "dicenti": "dire",
    "dicerie": "diceria",
    "dicesse": "dire",
    "dicesser": "dire",
    "dicessero": "dire",
    "dicessi": "dire",
    "dicessimo": "dire",
    "diceste": "dire",
    "dicesti": "dire",
    "diceva": "dire",
    "dicevamo": "dire",
    "dicevan": "dire",
    "dicevano": "dire",
    "dicevate": "dire",
    "dicevi": "dire",
    "dicevo": "dire",
    "dicherai": "dicare",
    "dicheran": "dicare",
    "dicheranno": "dicare",
    "dicherebbe": "dicare",
    "dicherebber": "dicare",
    "dicherebbero": "dicare",
    "dicherei": "dicare",
    "dicheremmo": "dicare",
    "dicheremo": "dicare",
    "dichereste": "dicare",
    "dicheresti": "dicare",
    "dicherete": "dicare",
    "dicherà": "dicare",
    "dicherò": "dicare",
    "dichi": "dicare",
    "dichiamo": "dicare",
    "dichiara": "dichiarare",
    "dichiarai": "dichiarare",
    "dichiarammo": "dichiarare",
    "dichiaran": "dichiarare",
    "dichiarando": "dichiarare",
    "dichiarano": "dichiarare",
    "dichiarante": "dichiarare",
    "dichiaranti": "dichiarare",
    "dichiarar": "dichiarare",
    "dichiararon": "dichiarare",
    "dichiararono": "dichiarare",
    "dichiarasse": "dichiarare",
    "dichiarasser": "dichiarare",
    "dichiarassero": "dichiarare",
    "dichiarassi": "dichiarare",
    "dichiarassimo": "dichiarare",
    "dichiaraste": "dichiarare",
    "dichiarasti": "dichiarare",
    "dichiarata": "dichiarato",
    "dichiarate": "dichiarato",
    "dichiarati": "dichiarato",
    "dichiarativa": "dichiarativo",
    "dichiarative": "dichiarativo",
    "dichiarativi": "dichiarativo",
    "dichiarato": "dichiarare",
    "dichiarava": "dichiarare",
    "dichiaravamo": "dichiarare",
    "dichiaravan": "dichiarare",
    "dichiaravano": "dichiarare",
    "dichiaravate": "dichiarare",
    "dichiaravi": "dichiarare",
    "dichiaravo": "dichiarare",
    "dichiarazioni": "dichiarazione",
    "dichiarerai": "dichiarare",
    "dichiareran": "dichiarare",
    "dichiareranno": "dichiarare",
    "dichiarerebbe": "dichiarare",
    "dichiarerebber": "dichiarare",
    "dichiarerebbero": "dichiarare",
    "dichiarerei": "dichiarare",
    "dichiareremmo": "dichiarare",
    "dichiareremo": "dichiarare",
    "dichiarereste": "dichiarare",
    "dichiareresti": "dichiarare",
    "dichiarerete": "dichiarare",
    "dichiarerà": "dichiarare",
    "dichiarerò": "dichiarare",
    "dichiari": "dichiarare",
    "dichiariamo": "dichiarare",
    "dichiariate": "dichiarare",
    "dichiarin": "dichiarare",
    "dichiarino": "dichiarare",
    "dichiaro": "dichiarare",
    "dichiarò": "dichiarare",
    "dichiate": "dicare",
    "dichin": "dicare",
    "dichino": "dicare",
    "dichirazioni": "dichirazione",
    "dici": "dire",
    "diciamo": "dire",
    "diciannovenni": "diciannovenne",
    "diciannovesima": "diciannovesimo",
    "diciannovesime": "diciannovesimo",
    "diciannovesimi": "diciannovesimo",
    "dicianovenni": "dicianovenne",
    "diciassettenni": "diciassettenne",
    "diciassettesima": "diciassettesimo",
    "diciassettesime": "diciassettesimo",
    "diciassettesimi": "diciassettesimo",
    "diciate": "dire",
    "dicibili": "dicibile",
    "diciottenni": "diciottenne",
    "diciottesima": "diciottesimo",
    "diciottesime": "diciottesimo",
    "diciottesimi": "diciottesimo",
    "diciture": "dicitura",
    "dickensiana": "dickensiano",
    "dickensiane": "dickensiano",
    "dickensiani": "dickensiano",
    "dico": "dire",
    "dicon": "dire",
    "dicono": "dire",
    "dicotomica": "dicotomico",
    "dicotomiche": "dicotomico",
    "dicotomici": "dicotomico",
    "dicotomie": "dicotomia",
    "dicò": "dicare",
    "didascalica": "didascalico",
    "didascaliche": "didascalico",
    "didascalici": "didascalico",
    "didascalie": "didascalia",
    "didascalismi": "didascalismo",
    "didascalizza": "didascalizzare",
    "didascalizzai": "didascalizzare",
    "didascalizzammo": "didascalizzare",
    "didascalizzan": "didascalizzare",
    "didascalizzando": "didascalizzare",
    "didascalizzano": "didascalizzare",
    "didascalizzante": "didascalizzare",
    "didascalizzanti": "didascalizzare",
    "didascalizzar": "didascalizzare",
    "didascalizzaron": "didascalizzare",
    "didascalizzarono": "didascalizzare",
    "didascalizzasse": "didascalizzare",
    "didascalizzasser": "didascalizzare",
    "didascalizzassero": "didascalizzare",
    "didascalizzassi": "didascalizzare",
    "didascalizzassimo": "didascalizzare",
    "didascalizzaste": "didascalizzare",
    "didascalizzasti": "didascalizzare",
    "didascalizzata": "didascalizzare",
    "didascalizzate": "didascalizzare",
    "didascalizzati": "didascalizzare",
    "didascalizzato": "didascalizzare",
    "didascalizzava": "didascalizzare",
    "didascalizzavamo": "didascalizzare",
    "didascalizzavan": "didascalizzare",
    "didascalizzavano": "didascalizzare",
    "didascalizzavate": "didascalizzare",
    "didascalizzavi": "didascalizzare",
    "didascalizzavo": "didascalizzare",
    "didascalizzerai": "didascalizzare",
    "didascalizzeran": "didascalizzare",
    "didascalizzeranno": "didascalizzare",
    "didascalizzerebbe": "didascalizzare",
    "didascalizzerebber": "didascalizzare",
    "didascalizzerebbero": "didascalizzare",
    "didascalizzerei": "didascalizzare",
    "didascalizzeremmo": "didascalizzare",
    "didascalizzeremo": "didascalizzare",
    "didascalizzereste": "didascalizzare",
    "didascalizzeresti": "didascalizzare",
    "didascalizzerete": "didascalizzare",
    "didascalizzerà": "didascalizzare",
    "didascalizzerò": "didascalizzare",
    "didascalizzi": "didascalizzare",
    "didascalizziamo": "didascalizzare",
    "didascalizziate": "didascalizzare",
    "didascalizzin": "didascalizzare",
    "didascalizzino": "didascalizzare",
    "didascalizzo": "didascalizzare",
    "didascalizzò": "didascalizzare",
    "didattica": "didattico",
    "didattiche": "didattico",
    "didattici": "didattico",
    "didattico-interpretativa": "didattico-interpretativo",
    "didattico-interpretative": "didattico-interpretativo",
    "didattico-interpretativi": "didattico-interpretativo",
    "diecimillesima": "diecimillesimo",
    "diecimillesime": "diecimillesimo",
    "diecimillesimi": "diecimillesimo",
    "diecine": "diecina",
    "diede": "dare",
    "dieder": "dare",
    "diedero": "dare",
    "diedi": "dare",
    "diessina": "diessino",
    "diessine": "diessino",
    "diessini": "diessino",
    "diete": "dieta",
    "dietetica": "dietetico",
    "dietetiche": "dietetico",
    "dietetici": "dietetico",
    "dietologi": "dietologo",
    "dietrologi": "dietrologo",
    "dietrologica": "dietrologico",
    "dietrologiche": "dietrologico",
    "dietrologici": "dietrologico",
    "dietrologie": "dietrologia",
    "difenda": "difendere",
    "difendan": "difendere",
    "difendano": "difendere",
    "difende": "difendere",
    "difendemmo": "difendere",
    "difendendo": "difendere",
    "difendente": "difendere",
    "difendenti": "difendere",
    "difender": "difendere",
    "difenderai": "difendere",
    "difenderan": "difendere",
    "difenderanno": "difendere",
    "difenderebbe": "difendere",
    "difenderebber": "difendere",
    "difenderebbero": "difendere",
    "difenderei": "difendere",
    "difenderemmo": "difendere",
    "difenderemo": "difendere",
    "difendereste": "difendere",
    "difenderesti": "difendere",
    "difenderete": "difendere",
    "difenderà": "difendere",
    "difenderò": "difendere",
    "difendesse": "difendere",
    "difendesser": "difendere",
    "difendessero": "difendere",
    "difendessi": "difendere",
    "difendessimo": "difendere",
    "difendeste": "difendere",
    "difendesti": "difendere",
    "difendete": "difendere",
    "difendeva": "difendere",
    "difendevamo": "difendere",
    "difendevan": "difendere",
    "difendevano": "difendere",
    "difendevate": "difendere",
    "difendevi": "difendere",
    "difendevo": "difendere",
    "difendi": "difendere",
    "difendiamo": "difendere",
    "difendiate": "difendere",
    "difendibili": "difendibile",
    "difendo": "difendere",
    "difendon": "difendere",
    "difendono": "difendere",
    "difensiva": "difensivo",
    "difensive": "difensivo",
    "difensivi": "difensivo",
    "difensivismi": "difensivismo",
    "difensiviste": "difensivista",
    "difensivisti": "difensivista",
    "difensivistica": "difensivistico",
    "difensivistiche": "difensivistico",
    "difensivistici": "difensivistico",
    "difensori": "difensore",
    "difesa": "difeso",
    "difese": "difeso",
    "difeser": "difendere",
    "difesero": "difendere",
    "difesi": "difeso",
    "difeso": "difendere",
    "difesè": "difendere",
    "difetta": "difettare",
    "difettai": "difettare",
    "difettammo": "difettare",
    "difettan": "difettare",
    "difettando": "difettare",
    "difettano": "difettare",
    "difettante": "difettare",
    "difettanti": "difettare",
    "difettar": "difettare",
    "difettaron": "difettare",
    "difettarono": "difettare",
    "difettasse": "difettare",
    "difettasser": "difettare",
    "difettassero": "difettare",
    "difettassi": "difettare",
    "difettassimo": "difettare",
    "difettaste": "difettare",
    "difettasti": "difettare",
    "difettata": "difettare",
    "difettate": "difettare",
    "difettati": "difettare",
    "difettato": "difettare",
    "difettava": "difettare",
    "difettavamo": "difettare",
    "difettavan": "difettare",
    "difettavano": "difettare",
    "difettavate": "difettare",
    "difettavi": "difettare",
    "difettavo": "difettare",
    "difetterai": "difettare",
    "difetteran": "difettare",
    "difetteranno": "difettare",
    "difetterebbe": "difettare",
    "difetterebber": "difettare",
    "difetterebbero": "difettare",
    "difetterei": "difettare",
    "difetteremmo": "difettare",
    "difetteremo": "difettare",
    "difettereste": "difettare",
    "difetteresti": "difettare",
    "difetterete": "difettare",
    "difetterà": "difettare",
    "difetterò": "difettare",
    "difetti": "difetto",
    "difettiamo": "difettare",
    "difettiate": "difettare",
    "difettin": "difettare",
    "difettino": "difettare",
    "difetto": "difettare",
    "difettosa": "difettoso",
    "difettose": "difettoso",
    "difettosi": "difettoso",
    "difettucci": "difettuccio",
    "difettò": "difettare",
    "diffama": "diffamare",
    "diffamai": "diffamare",
    "diffamammo": "diffamare",
    "diffaman": "diffamare",
    "diffamando": "diffamare",
    "diffamano": "diffamare",
    "diffamante": "diffamare",
    "diffamanti": "diffamare",
    "diffamar": "diffamare",
    "diffamaron": "diffamare",
    "diffamarono": "diffamare",
    "diffamasse": "diffamare",
    "diffamasser": "diffamare",
    "diffamassero": "diffamare",
    "diffamassi": "diffamare",
    "diffamassimo": "diffamare",
    "diffamaste": "diffamare",
    "diffamasti": "diffamare",
    "diffamata": "diffamare",
    "diffamate": "diffamare",
    "diffamati": "diffamare",
    "diffamato": "diffamare",
    "diffamatori": "diffamatorio",
    "diffamatoria": "diffamatorio",
    "diffamatorie": "diffamatorio",
    "diffamatrice": "diffamatore",
    "diffamatrici": "diffamatore",
    "diffamava": "diffamare",
    "diffamavamo": "diffamare",
    "diffamavan": "diffamare",
    "diffamavano": "diffamare",
    "diffamavate": "diffamare",
    "diffamavi": "diffamare",
    "diffamavo": "diffamare",
    "diffamazioni": "diffamazione",
    "diffamerai": "diffamare",
    "diffameran": "diffamare",
    "diffameranno": "diffamare",
    "diffamerebbe": "diffamare",
    "diffamerebber": "diffamare",
    "diffamerebbero": "diffamare",
    "diffamerei": "diffamare",
    "diffameremmo": "diffamare",
    "diffameremo": "diffamare",
    "diffamereste": "diffamare",
    "diffameresti": "diffamare",
    "diffamerete": "diffamare",
    "diffamerà": "diffamare",
    "diffamerò": "diffamare",
    "diffami": "diffamare",
    "diffamiamo": "diffamare",
    "diffamiate": "diffamare",
    "diffamin": "diffamare",
    "diffamino": "diffamare",
    "diffamo": "diffamare",
    "diffamò": "diffamare",
    "differendo": "differire",
    "differente": "differire",
    "differenti": "differire",
    "differenze": "differenza",
    "differenzi": "differenziare",
    "differenzia": "differenziare",
    "differenziai": "differenziare",
    "differenziali": "differenziale",
    "differenziammo": "differenziare",
    "differenziamo": "differenziare",
    "differenzian": "differenziare",
    "differenziando": "differenziare",
    "differenziano": "differenziare",
    "differenziante": "differenziare",
    "differenzianti": "differenziare",
    "differenziar": "differenziare",
    "differenziaron": "differenziare",
    "differenziarono": "differenziare",
    "differenziasse": "differenziare",
    "differenziasser": "differenziare",
    "differenziassero": "differenziare",
    "differenziassi": "differenziare",
    "differenziassimo": "differenziare",
    "differenziaste": "differenziare",
    "differenziasti": "differenziare",
    "differenziata": "differenziato",
    "differenziate": "differenziato",
    "differenziati": "differenziato",
    "differenziato": "differenziare",
    "differenziava": "differenziare",
    "differenziavamo": "differenziare",
    "differenziavan": "differenziare",
    "differenziavano": "differenziare",
    "differenziavate": "differenziare",
    "differenziavi": "differenziare",
    "differenziavo": "differenziare",
    "differenziazioni": "differenziazione",
    "differenzierai": "differenziare",
    "differenzieran": "differenziare",
    "differenzieranno": "differenziare",
    "differenzierebbe": "differenziare",
    "differenzierebber": "differenziare",
    "differenzierebbero": "differenziare",
    "differenzierei": "differenziare",
    "differenzieremmo": "differenziare",
    "differenzieremo": "differenziare",
    "differenziereste": "differenziare",
    "differenzieresti": "differenziare",
    "differenzierete": "differenziare",
    "differenzierà": "differenziare",
    "differenzierò": "differenziare",
    "differenzin": "differenziare",
    "differenzino": "differenziare",
    "differenzio": "differenziare",
    "differenziò": "differenziare",
    "differiamo": "differire",
    "differiate": "differire",
    "differibili": "differibile",
    "differii": "differire",
    "differimenti": "differimento",
    "differimmo": "differire",
    "differir": "differire",
    "differirai": "differire",
    "differiran": "differire",
    "differiranno": "differire",
    "differirebbe": "differire",
    "differirebber": "differire",
    "differirebbero": "differire",
    "differirei": "differire",
    "differiremmo": "differire",
    "differiremo": "differire",
    "differireste": "differire",
    "differiresti": "differire",
    "differirete": "differire",
    "differiron": "differire",
    "differirono": "differire",
    "differirà": "differire",
    "differirò": "differire",
    "differisca": "differire",
    "differiscan": "differire",
    "differiscano": "differire",
    "differisce": "differire",
    "differisci": "differire",
    "differisco": "differire",
    "differiscon": "differire",
    "differiscono": "differire",
    "differisse": "differire",
    "differisser": "differire",
    "differissero": "differire",
    "differissi": "differire",
    "differissimo": "differire",
    "differiste": "differire",
    "differisti": "differire",
    "differita": "differire",
    "differite": "differita",
    "differiti": "differire",
    "differito": "differire",
    "differiva": "differire",
    "differivamo": "differire",
    "differivan": "differire",
    "differivano": "differire",
    "differivate": "differire",
    "differivi": "differire",
    "differivo": "differire",
    "differì": "differire",
    "difficili": "difficile",
    "difficoltosa": "difficoltoso",
    "difficoltose": "difficoltoso",
    "difficoltosi": "difficoltoso",
    "diffida": "diffidare",
    "diffidai": "diffidare",
    "diffidammo": "diffidare",
    "diffidan": "diffidare",
    "diffidando": "diffidare",
    "diffidano": "diffidare",
    "diffidante": "diffidare",
    "diffidanti": "diffidare",
    "diffidar": "diffidare",
    "diffidaron": "diffidare",
    "diffidarono": "diffidare",
    "diffidasse": "diffidare",
    "diffidasser": "diffidare",
    "diffidassero": "diffidare",
    "diffidassi": "diffidare",
    "diffidassimo": "diffidare",
    "diffidaste": "diffidare",
    "diffidasti": "diffidare",
    "diffidata": "diffidare",
    "diffidate": "diffidare",
    "diffidati": "diffidato",
    "diffidato": "diffidare",
    "diffidava": "diffidare",
    "diffidavamo": "diffidare",
    "diffidavan": "diffidare",
    "diffidavano": "diffidare",
    "diffidavate": "diffidare",
    "diffidavi": "diffidare",
    "diffidavo": "diffidare",
    "diffide": "diffida",
    "diffidenti": "diffidente",
    "diffidenze": "diffidenza",
    "diffiderai": "diffidare",
    "diffideran": "diffidare",
    "diffideranno": "diffidare",
    "diffiderebbe": "diffidare",
    "diffiderebber": "diffidare",
    "diffiderebbero": "diffidare",
    "diffiderei": "diffidare",
    "diffideremmo": "diffidare",
    "diffideremo": "diffidare",
    "diffidereste": "diffidare",
    "diffideresti": "diffidare",
    "diffiderete": "diffidare",
    "diffiderà": "diffidare",
    "diffiderò": "diffidare",
    "diffidi": "diffidare",
    "diffidiamo": "diffidare",
    "diffidiate": "diffidare",
    "diffidin": "diffidare",
    "diffidino": "diffidare",
    "diffido": "diffidare",
    "diffidò": "diffidare",
    "diffonda": "diffondere",
    "diffondan": "diffondere",
    "diffondano": "diffondere",
    "diffonde": "diffondere",
    "diffondemmo": "diffondere",
    "diffondendo": "diffondere",
    "diffondente": "diffondere",
    "diffondenti": "diffondere",
    "diffonder": "diffondere",
    "diffonderai": "diffondere",
    "diffonderan": "diffondere",
    "diffonderanno": "diffondere",
    "diffonderebbe": "diffondere",
    "diffonderebber": "diffondere",
    "diffonderebbero": "diffondere",
    "diffonderei": "diffondere",
    "diffonderemmo": "diffondere",
    "diffonderemo": "diffondere",
    "diffondereste": "diffondere",
    "diffonderesti": "diffondere",
    "diffonderete": "diffondere",
    "diffonderà": "diffondere",
    "diffonderò": "diffondere",
    "diffondesse": "diffondere",
    "diffondesser": "diffondere",
    "diffondessero": "diffondere",
    "diffondessi": "diffondere",
    "diffondessimo": "diffondere",
    "diffondeste": "diffondere",
    "diffondesti": "diffondere",
    "diffondete": "diffondere",
    "diffondeva": "diffondere",
    "diffondevamo": "diffondere",
    "diffondevan": "diffondere",
    "diffondevano": "diffondere",
    "diffondevate": "diffondere",
    "diffondevi": "diffondere",
    "diffondevo": "diffondere",
    "diffondi": "diffondere",
    "diffondiamo": "diffondere",
    "diffondiate": "diffondere",
    "diffondo": "diffondere",
    "diffondon": "diffondere",
    "diffondono": "diffondere",
    "difformi": "difforme",
    "diffusa": "diffuso",
    "diffuse": "diffuso",
    "diffuser": "diffondere",
    "diffusero": "diffondere",
    "diffusi": "diffuso",
    "diffusioni": "diffusione",
    "diffuso": "diffondere",
    "diffusori": "diffusore",
    "digerendo": "digerire",
    "digerente": "digerire",
    "digerenti": "digerire",
    "digeriamo": "digerire",
    "digeriate": "digerire",
    "digeribili": "digeribile",
    "digerii": "digerire",
    "digerimmo": "digerire",
    "digerir": "digerire",
    "digerirai": "digerire",
    "digeriran": "digerire",
    "digeriranno": "digerire",
    "digerirebbe": "digerire",
    "digerirebber": "digerire",
    "digerirebbero": "digerire",
    "digerirei": "digerire",
    "digeriremmo": "digerire",
    "digeriremo": "digerire",
    "digerireste": "digerire",
    "digeriresti": "digerire",
    "digerirete": "digerire",
    "digeriron": "digerire",
    "digerirono": "digerire",
    "digerirà": "digerire",
    "digerirò": "digerire",
    "digerisca": "digerire",
    "digeriscan": "digerire",
    "digeriscano": "digerire",
    "digerisce": "digerire",
    "digerisci": "digerire",
    "digerisco": "digerire",
    "digeriscon": "digerire",
    "digeriscono": "digerire",
    "digerisse": "digerire",
    "digerisser": "digerire",
    "digerissero": "digerire",
    "digerissi": "digerire",
    "digerissimo": "digerire",
    "digeriste": "digerire",
    "digeristi": "digerire",
    "digerita": "digerire",
    "digerite": "digerire",
    "digeriti": "digerire",
    "digerito": "digerire",
    "digeriva": "digerire",
    "digerivamo": "digerire",
    "digerivan": "digerire",
    "digerivano": "digerire",
    "digerivate": "digerire",
    "digerivi": "digerire",
    "digerivo": "digerire",
    "digerì": "digerire",
    "digestioni": "digestione",
    "digestiva": "digestivo",
    "digestive": "digestivo",
    "digestivi": "digestivo",
    "dighe": "diga",
    "digita": "digitare",
    "digitai": "digitare",
    "digitali": "digitale",
    "digitalizza": "digitalizzare",
    "digitalizzabili": "digitalizzabile",
    "digitalizzai": "digitalizzare",
    "digitalizzammo": "digitalizzare",
    "digitalizzan": "digitalizzare",
    "digitalizzando": "digitalizzare",
    "digitalizzano": "digitalizzare",
    "digitalizzante": "digitalizzare",
    "digitalizzanti": "digitalizzare",
    "digitalizzar": "digitalizzare",
    "digitalizzaron": "digitalizzare",
    "digitalizzarono": "digitalizzare",
    "digitalizzasse": "digitalizzare",
    "digitalizzasser": "digitalizzare",
    "digitalizzassero": "digitalizzare",
    "digitalizzassi": "digitalizzare",
    "digitalizzassimo": "digitalizzare",
    "digitalizzaste": "digitalizzare",
    "digitalizzasti": "digitalizzare",
    "digitalizzata": "digitalizzare",
    "digitalizzate": "digitalizzare",
    "digitalizzati": "digitalizzare",
    "digitalizzato": "digitalizzare",
    "digitalizzava": "digitalizzare",
    "digitalizzavamo": "digitalizzare",
    "digitalizzavan": "digitalizzare",
    "digitalizzavano": "digitalizzare",
    "digitalizzavate": "digitalizzare",
    "digitalizzavi": "digitalizzare",
    "digitalizzavo": "digitalizzare",
    "digitalizzerai": "digitalizzare",
    "digitalizzeran": "digitalizzare",
    "digitalizzeranno": "digitalizzare",
    "digitalizzerebbe": "digitalizzare",
    "digitalizzerebber": "digitalizzare",
    "digitalizzerebbero": "digitalizzare",
    "digitalizzerei": "digitalizzare",
    "digitalizzeremmo": "digitalizzare",
    "digitalizzeremo": "digitalizzare",
    "digitalizzereste": "digitalizzare",
    "digitalizzeresti": "digitalizzare",
    "digitalizzerete": "digitalizzare",
    "digitalizzerà": "digitalizzare",
    "digitalizzerò": "digitalizzare",
    "digitalizzi": "digitalizzare",
    "digitalizziamo": "digitalizzare",
    "digitalizziate": "digitalizzare",
    "digitalizzin": "digitalizzare",
    "digitalizzino": "digitalizzare",
    "digitalizzo": "digitalizzare",
    "digitalizzò": "digitalizzare",
    "digitammo": "digitare",
    "digitan": "digitare",
    "digitando": "digitare",
    "digitano": "digitare",
    "digitante": "digitare",
    "digitanti": "digitare",
    "digitar": "digitare",
    "digitaron": "digitare",
    "digitarono": "digitare",
    "digitasse": "digitare",
    "digitasser": "digitare",
    "digitassero": "digitare",
    "digitassi": "digitare",
    "digitassimo": "digitare",
    "digitaste": "digitare",
    "digitasti": "digitare",
    "digitata": "digitare",
    "digitate": "digitare",
    "digitati": "digitare",
    "digitato": "digitare",
    "digitava": "digitare",
    "digitavamo": "digitare",
    "digitavan": "digitare",
    "digitavano": "digitare",
    "digitavate": "digitare",
    "digitavi": "digitare",
    "digitavo": "digitare",
    "digitazioni": "digitazione",
    "digiterai": "digitare",
    "digiteran": "digitare",
    "digiteranno": "digitare",
    "digiterebbe": "digitare",
    "digiterebber": "digitare",
    "digiterebbero": "digitare",
    "digiterei": "digitare",
    "digiteremmo": "digitare",
    "digiteremo": "digitare",
    "digitereste": "digitare",
    "digiteresti": "digitare",
    "digiterete": "digitare",
    "digiterà": "digitare",
    "digiterò": "digitare",
    "digiti": "digitare",
    "digitiamo": "digitare",
    "digitiate": "digitare",
    "digitin": "digitare",
    "digitino": "digitare",
    "digito": "digitare",
    "digitò": "digitare",
    "digiuna": "digiuno",
    "digiunai": "digiunare",
    "digiunammo": "digiunare",
    "digiunan": "digiunare",
    "digiunando": "digiunare",
    "digiunano": "digiunare",
    "digiunante": "digiunare",
    "digiunanti": "digiunare",
    "digiunar": "digiunare",
    "digiunaron": "digiunare",
    "digiunarono": "digiunare",
    "digiunasse": "digiunare",
    "digiunasser": "digiunare",
    "digiunassero": "digiunare",
    "digiunassi": "digiunare",
    "digiunassimo": "digiunare",
    "digiunaste": "digiunare",
    "digiunasti": "digiunare",
    "digiunata": "digiunare",
    "digiunate": "digiunare",
    "digiunati": "digiunare",
    "digiunato": "digiunare",
    "digiunava": "digiunare",
    "digiunavamo": "digiunare",
    "digiunavan": "digiunare",
    "digiunavano": "digiunare",
    "digiunavate": "digiunare",
    "digiunavi": "digiunare",
    "digiunavo": "digiunare",
    "digiune": "digiuno",
    "digiunerai": "digiunare",
    "digiuneran": "digiunare",
    "digiuneranno": "digiunare",
    "digiunerebbe": "digiunare",
    "digiunerebber": "digiunare",
    "digiunerebbero": "digiunare",
    "digiunerei": "digiunare",
    "digiuneremmo": "digiunare",
    "digiuneremo": "digiunare",
    "digiunereste": "digiunare",
    "digiuneresti": "digiunare",
    "digiunerete": "digiunare",
    "digiunerà": "digiunare",
    "digiunerò": "digiunare",
    "digiuni": "digiuno",
    "digiuniamo": "digiunare",
    "digiuniate": "digiunare",
    "digiunin": "digiunare",
    "digiunino": "digiunare",
    "digiuno": "digiunare",
    "digiunò": "digiunare",
    "dignitari": "dignitario",
    "dignitosa": "dignitoso",
    "dignitose": "dignitoso",
    "dignitosi": "dignitoso",
    "digrada": "digradare",
    "digradai": "digradare",
    "digradammo": "digradare",
    "digradan": "digradare",
    "digradando": "digradare",
    "digradano": "digradare",
    "digradante": "digradare",
    "digradanti": "digradare",
    "digradar": "digradare",
    "digradaron": "digradare",
    "digradarono": "digradare",
    "digradasse": "digradare",
    "digradasser": "digradare",
    "digradassero": "digradare",
    "digradassi": "digradare",
    "digradassimo": "digradare",
    "digradaste": "digradare",
    "digradasti": "digradare",
    "digradata": "digradare",
    "digradate": "digradare",
    "digradati": "digradare",
    "digradato": "digradare",
    "digradava": "digradare",
    "digradavamo": "digradare",
    "digradavan": "digradare",
    "digradavano": "digradare",
    "digradavate": "digradare",
    "digradavi": "digradare",
    "digradavo": "digradare",
    "digraderai": "digradare",
    "digraderan": "digradare",
    "digraderanno": "digradare",
    "digraderebbe": "digradare",
    "digraderebber": "digradare",
    "digraderebbero": "digradare",
    "digraderei": "digradare",
    "digraderemmo": "digradare",
    "digraderemo": "digradare",
    "digradereste": "digradare",
    "digraderesti": "digradare",
    "digraderete": "digradare",
    "digraderà": "digradare",
    "digraderò": "digradare",
    "digradi": "digradare",
    "digradiamo": "digradare",
    "digradiate": "digradare",
    "digradin": "digradare",
    "digradino": "digradare",
    "digrado": "digradare",
    "digradò": "digradare",
    "digressioni": "digressione",
    "digrigna": "digrignare",
    "digrignai": "digrignare",
    "digrignammo": "digrignare",
    "digrignan": "digrignare",
    "digrignando": "digrignare",
    "digrignano": "digrignare",
    "digrignante": "digrignare",
    "digrignanti": "digrignare",
    "digrignar": "digrignare",
    "digrignaron": "digrignare",
    "digrignarono": "digrignare",
    "digrignasse": "digrignare",
    "digrignasser": "digrignare",
    "digrignassero": "digrignare",
    "digrignassi": "digrignare",
    "digrignassimo": "digrignare",
    "digrignaste": "digrignare",
    "digrignasti": "digrignare",
    "digrignata": "digrignare",
    "digrignate": "digrignare",
    "digrignati": "digrignare",
    "digrignato": "digrignare",
    "digrignava": "digrignare",
    "digrignavamo": "digrignare",
    "digrignavan": "digrignare",
    "digrignavano": "digrignare",
    "digrignavate": "digrignare",
    "digrignavi": "digrignare",
    "digrignavo": "digrignare",
    "digrignerai": "digrignare",
    "digrigneran": "digrignare",
    "digrigneranno": "digrignare",
    "digrignerebbe": "digrignare",
    "digrignerebber": "digrignare",
    "digrignerebbero": "digrignare",
    "digrignerei": "digrignare",
    "digrigneremmo": "digrignare",
    "digrigneremo": "digrignare",
    "digrignereste": "digrignare",
    "digrigneresti": "digrignare",
    "digrignerete": "digrignare",
    "digrignerà": "digrignare",
    "digrignerò": "digrignare",
    "digrigni": "digrignare",
    "digrigniamo": "digrignare",
    "digrigniate": "digrignare",
    "digrignin": "digrignare",
    "digrignino": "digrignare",
    "digrigno": "digrignare",
    "digrignò": "digrignare",
    "digrossa": "digrossare",
    "digrossai": "digrossare",
    "digrossammo": "digrossare",
    "digrossan": "digrossare",
    "digrossando": "digrossare",
    "digrossano": "digrossare",
    "digrossante": "digrossare",
    "digrossanti": "digrossare",
    "digrossar": "digrossare",
    "digrossaron": "digrossare",
    "digrossarono": "digrossare",
    "digrossasse": "digrossare",
    "digrossasser": "digrossare",
    "digrossassero": "digrossare",
    "digrossassi": "digrossare",
    "digrossassimo": "digrossare",
    "digrossaste": "digrossare",
    "digrossasti": "digrossare",
    "digrossata": "digrossare",
    "digrossate": "digrossare",
    "digrossati": "digrossare",
    "digrossato": "digrossare",
    "digrossava": "digrossare",
    "digrossavamo": "digrossare",
    "digrossavan": "digrossare",
    "digrossavano": "digrossare",
    "digrossavate": "digrossare",
    "digrossavi": "digrossare",
    "digrossavo": "digrossare",
    "digrosserai": "digrossare",
    "digrosseran": "digrossare",
    "digrosseranno": "digrossare",
    "digrosserebbe": "digrossare",
    "digrosserebber": "digrossare",
    "digrosserebbero": "digrossare",
    "digrosserei": "digrossare",
    "digrosseremmo": "digrossare",
    "digrosseremo": "digrossare",
    "digrossereste": "digrossare",
    "digrosseresti": "digrossare",
    "digrosserete": "digrossare",
    "digrosserà": "digrossare",
    "digrosserò": "digrossare",
    "digrossi": "digrossare",
    "digrossiamo": "digrossare",
    "digrossiate": "digrossare",
    "digrossin": "digrossare",
    "digrossino": "digrossare",
    "digrosso": "digrossare",
    "digrossò": "digrossare",
    "diguazza": "diguazzare",
    "diguazzai": "diguazzare",
    "diguazzammo": "diguazzare",
    "diguazzan": "diguazzare",
    "diguazzando": "diguazzare",
    "diguazzano": "diguazzare",
    "diguazzante": "diguazzare",
    "diguazzanti": "diguazzare",
    "diguazzar": "diguazzare",
    "diguazzaron": "diguazzare",
    "diguazzarono": "diguazzare",
    "diguazzasse": "diguazzare",
    "diguazzasser": "diguazzare",
    "diguazzassero": "diguazzare",
    "diguazzassi": "diguazzare",
    "diguazzassimo": "diguazzare",
    "diguazzaste": "diguazzare",
    "diguazzasti": "diguazzare",
    "diguazzata": "diguazzare",
    "diguazzate": "diguazzare",
    "diguazzati": "diguazzare",
    "diguazzato": "diguazzare",
    "diguazzava": "diguazzare",
    "diguazzavamo": "diguazzare",
    "diguazzavan": "diguazzare",
    "diguazzavano": "diguazzare",
    "diguazzavate": "diguazzare",
    "diguazzavi": "diguazzare",
    "diguazzavo": "diguazzare",
    "diguazzerai": "diguazzare",
    "diguazzeran": "diguazzare",
    "diguazzeranno": "diguazzare",
    "diguazzerebbe": "diguazzare",
    "diguazzerebber": "diguazzare",
    "diguazzerebbero": "diguazzare",
    "diguazzerei": "diguazzare",
    "diguazzeremmo": "diguazzare",
    "diguazzeremo": "diguazzare",
    "diguazzereste": "diguazzare",
    "diguazzeresti": "diguazzare",
    "diguazzerete": "diguazzare",
    "diguazzerà": "diguazzare",
    "diguazzerò": "diguazzare",
    "diguazzi": "diguazzare",
    "diguazziamo": "diguazzare",
    "diguazziate": "diguazzare",
    "diguazzin": "diguazzare",
    "diguazzino": "diguazzare",
    "diguazzo": "diguazzare",
    "diguazzò": "diguazzare",
    "dilacera": "dilacerare",
    "dilacerai": "dilacerare",
    "dilacerammo": "dilacerare",
    "dilaceran": "dilacerare",
    "dilacerando": "dilacerare",
    "dilacerano": "dilacerare",
    "dilacerante": "dilacerare",
    "dilaceranti": "dilacerare",
    "dilacerar": "dilacerare",
    "dilaceraron": "dilacerare",
    "dilacerarono": "dilacerare",
    "dilacerasse": "dilacerare",
    "dilacerasser": "dilacerare",
    "dilacerassero": "dilacerare",
    "dilacerassi": "dilacerare",
    "dilacerassimo": "dilacerare",
    "dilaceraste": "dilacerare",
    "dilacerasti": "dilacerare",
    "dilacerata": "dilacerare",
    "dilacerate": "dilacerare",
    "dilacerati": "dilacerare",
    "dilacerato": "dilacerare",
    "dilacerava": "dilacerare",
    "dilaceravamo": "dilacerare",
    "dilaceravan": "dilacerare",
    "dilaceravano": "dilacerare",
    "dilaceravate": "dilacerare",
    "dilaceravi": "dilacerare",
    "dilaceravo": "dilacerare",
    "dilacererai": "dilacerare",
    "dilacereran": "dilacerare",
    "dilacereranno": "dilacerare",
    "dilacererebbe": "dilacerare",
    "dilacererebber": "dilacerare",
    "dilacererebbero": "dilacerare",
    "dilacererei": "dilacerare",
    "dilacereremmo": "dilacerare",
    "dilacereremo": "dilacerare",
    "dilacerereste": "dilacerare",
    "dilacereresti": "dilacerare",
    "dilacererete": "dilacerare",
    "dilacererà": "dilacerare",
    "dilacererò": "dilacerare",
    "dilaceri": "dilacerare",
    "dilaceriamo": "dilacerare",
    "dilaceriate": "dilacerare",
    "dilacerin": "dilacerare",
    "dilacerino": "dilacerare",
    "dilacero": "dilacerare",
    "dilacerò": "dilacerare",
    "dilaga": "dilagare",
    "dilagai": "dilagare",
    "dilagammo": "dilagare",
    "dilagan": "dilagare",
    "dilagando": "dilagare",
    "dilagano": "dilagare",
    "dilagante": "dilagare",
    "dilaganti": "dilagare",
    "dilagar": "dilagare",
    "dilagaron": "dilagare",
    "dilagarono": "dilagare",
    "dilagasse": "dilagare",
    "dilagasser": "dilagare",
    "dilagassero": "dilagare",
    "dilagassi": "dilagare",
    "dilagassimo": "dilagare",
    "dilagaste": "dilagare",
    "dilagasti": "dilagare",
    "dilagata": "dilagare",
    "dilagate": "dilagare",
    "dilagati": "dilagare",
    "dilagato": "dilagare",
    "dilagava": "dilagare",
    "dilagavamo": "dilagare",
    "dilagavan": "dilagare",
    "dilagavano": "dilagare",
    "dilagavate": "dilagare",
    "dilagavi": "dilagare",
    "dilagavo": "dilagare",
    "dilagherai": "dilagare",
    "dilagheran": "dilagare",
    "dilagheranno": "dilagare",
    "dilagherebbe": "dilagare",
    "dilagherebber": "dilagare",
    "dilagherebbero": "dilagare",
    "dilagherei": "dilagare",
    "dilagheremmo": "dilagare",
    "dilagheremo": "dilagare",
    "dilaghereste": "dilagare",
    "dilagheresti": "dilagare",
    "dilagherete": "dilagare",
    "dilagherà": "dilagare",
    "dilagherò": "dilagare",
    "dilaghi": "dilagare",
    "dilaghiamo": "dilagare",
    "dilaghiate": "dilagare",
    "dilaghin": "dilagare",
    "dilaghino": "dilagare",
    "dilago": "dilagare",
    "dilagò": "dilagare",
    "dilani": "dilaniare",
    "dilania": "dilaniare",
    "dilaniai": "dilaniare",
    "dilaniammo": "dilaniare",
    "dilaniamo": "dilaniare",
    "dilanian": "dilaniare",
    "dilaniando": "dilaniare",
    "dilaniano": "dilaniare",
    "dilaniante": "dilaniare",
    "dilanianti": "dilaniare",
    "dilaniar": "dilaniare",
    "dilaniaron": "dilaniare",
    "dilaniarono": "dilaniare",
    "dilaniasse": "dilaniare",
    "dilaniasser": "dilaniare",
    "dilaniassero": "dilaniare",
    "dilaniassi": "dilaniare",
    "dilaniassimo": "dilaniare",
    "dilaniaste": "dilaniare",
    "dilaniasti": "dilaniare",
    "dilaniata": "dilaniare",
    "dilaniate": "dilaniare",
    "dilaniati": "dilaniare",
    "dilaniato": "dilaniare",
    "dilaniava": "dilaniare",
    "dilaniavamo": "dilaniare",
    "dilaniavan": "dilaniare",
    "dilaniavano": "dilaniare",
    "dilaniavate": "dilaniare",
    "dilaniavi": "dilaniare",
    "dilaniavo": "dilaniare",
    "dilanierai": "dilaniare",
    "dilanieran": "dilaniare",
    "dilanieranno": "dilaniare",
    "dilanierebbe": "dilaniare",
    "dilanierebber": "dilaniare",
    "dilanierebbero": "dilaniare",
    "dilanierei": "dilaniare",
    "dilanieremmo": "dilaniare",
    "dilanieremo": "dilaniare",
    "dilaniereste": "dilaniare",
    "dilanieresti": "dilaniare",
    "dilanierete": "dilaniare",
    "dilanierà": "dilaniare",
    "dilanierò": "dilaniare",
    "dilanin": "dilaniare",
    "dilanino": "dilaniare",
    "dilanio": "dilaniare",
    "dilaniò": "dilaniare",
    "dilapida": "dilapidare",
    "dilapidai": "dilapidare",
    "dilapidammo": "dilapidare",
    "dilapidan": "dilapidare",
    "dilapidando": "dilapidare",
    "dilapidano": "dilapidare",
    "dilapidante": "dilapidare",
    "dilapidanti": "dilapidare",
    "dilapidar": "dilapidare",
    "dilapidaron": "dilapidare",
    "dilapidarono": "dilapidare",
    "dilapidasse": "dilapidare",
    "dilapidasser": "dilapidare",
    "dilapidassero": "dilapidare",
    "dilapidassi": "dilapidare",
    "dilapidassimo": "dilapidare",
    "dilapidaste": "dilapidare",
    "dilapidasti": "dilapidare",
    "dilapidata": "dilapidare",
    "dilapidate": "dilapidare",
    "dilapidati": "dilapidare",
    "dilapidato": "dilapidare",
    "dilapidava": "dilapidare",
    "dilapidavamo": "dilapidare",
    "dilapidavan": "dilapidare",
    "dilapidavano": "dilapidare",
    "dilapidavate": "dilapidare",
    "dilapidavi": "dilapidare",
    "dilapidavo": "dilapidare",
    "dilapiderai": "dilapidare",
    "dilapideran": "dilapidare",
    "dilapideranno": "dilapidare",
    "dilapiderebbe": "dilapidare",
    "dilapiderebber": "dilapidare",
    "dilapiderebbero": "dilapidare",
    "dilapiderei": "dilapidare",
    "dilapideremmo": "dilapidare",
    "dilapideremo": "dilapidare",
    "dilapidereste": "dilapidare",
    "dilapideresti": "dilapidare",
    "dilapiderete": "dilapidare",
    "dilapiderà": "dilapidare",
    "dilapiderò": "dilapidare",
    "dilapidi": "dilapidare",
    "dilapidiamo": "dilapidare",
    "dilapidiate": "dilapidare",
    "dilapidin": "dilapidare",
    "dilapidino": "dilapidare",
    "dilapido": "dilapidare",
    "dilapidò": "dilapidare",
    "dilata": "dilatare",
    "dilatai": "dilatare",
    "dilatammo": "dilatare",
    "dilatan": "dilatare",
    "dilatando": "dilatare",
    "dilatano": "dilatare",
    "dilatante": "dilatare",
    "dilatanti": "dilatare",
    "dilatar": "dilatare",
    "dilataron": "dilatare",
    "dilatarono": "dilatare",
    "dilatasse": "dilatare",
    "dilatasser": "dilatare",
    "dilatassero": "dilatare",
    "dilatassi": "dilatare",
    "dilatassimo": "dilatare",
    "dilataste": "dilatare",
    "dilatasti": "dilatare",
    "dilatata": "dilatare",
    "dilatate": "dilatare",
    "dilatati": "dilatare",
    "dilatativa": "dilatativo",
    "dilatative": "dilatativo",
    "dilatativi": "dilatativo",
    "dilatato": "dilatare",
    "dilatatori": "dilatatorio",
    "dilatatoria": "dilatatorio",
    "dilatatorie": "dilatatorio",
    "dilatatrice": "dilatatore",
    "dilatatrici": "dilatatore",
    "dilatava": "dilatare",
    "dilatavamo": "dilatare",
    "dilatavan": "dilatare",
    "dilatavano": "dilatare",
    "dilatavate": "dilatare",
    "dilatavi": "dilatare",
    "dilatavo": "dilatare",
    "dilatazioni": "dilatazione",
    "dilaterai": "dilatare",
    "dilateran": "dilatare",
    "dilateranno": "dilatare",
    "dilaterebbe": "dilatare",
    "dilaterebber": "dilatare",
    "dilaterebbero": "dilatare",
    "dilaterei": "dilatare",
    "dilateremmo": "dilatare",
    "dilateremo": "dilatare",
    "dilatereste": "dilatare",
    "dilateresti": "dilatare",
    "dilaterete": "dilatare",
    "dilaterà": "dilatare",
    "dilaterò": "dilatare",
    "dilati": "dilatare",
    "dilatiamo": "dilatare",
    "dilatiate": "dilatare",
    "dilatin": "dilatare",
    "dilatino": "dilatare",
    "dilato": "dilatare",
    "dilatori": "dilatorio",
    "dilatoria": "dilatorio",
    "dilatorie": "dilatorio",
    "dilatrice": "dilatore",
    "dilatrici": "dilatore",
    "dilatò": "dilatare",
    "dilava": "dilavare",
    "dilavai": "dilavare",
    "dilavammo": "dilavare",
    "dilavan": "dilavare",
    "dilavando": "dilavare",
    "dilavano": "dilavare",
    "dilavante": "dilavare",
    "dilavanti": "dilavare",
    "dilavar": "dilavare",
    "dilavaron": "dilavare",
    "dilavarono": "dilavare",
    "dilavasse": "dilavare",
    "dilavasser": "dilavare",
    "dilavassero": "dilavare",
    "dilavassi": "dilavare",
    "dilavassimo": "dilavare",
    "dilavaste": "dilavare",
    "dilavasti": "dilavare",
    "dilavata": "dilavare",
    "dilavate": "dilavare",
    "dilavati": "dilavare",
    "dilavato": "dilavare",
    "dilavava": "dilavare",
    "dilavavamo": "dilavare",
    "dilavavan": "dilavare",
    "dilavavano": "dilavare",
    "dilavavate": "dilavare",
    "dilavavi": "dilavare",
    "dilavavo": "dilavare",
    "dilaverai": "dilavare",
    "dilaveran": "dilavare",
    "dilaveranno": "dilavare",
    "dilaverebbe": "dilavare",
    "dilaverebber": "dilavare",
    "dilaverebbero": "dilavare",
    "dilaverei": "dilavare",
    "dilaveremmo": "dilavare",
    "dilaveremo": "dilavare",
    "dilavereste": "dilavare",
    "dilaveresti": "dilavare",
    "dilaverete": "dilavare",
    "dilaverà": "dilavare",
    "dilaverò": "dilavare",
    "dilavi": "dilavare",
    "dilaviamo": "dilavare",
    "dilaviate": "dilavare",
    "dilavin": "dilavare",
    "dilavino": "dilavare",
    "dilavo": "dilavare",
    "dilavò": "dilavare",
    "dilaziona": "dilazionare",
    "dilazionabili": "dilazionabile",
    "dilazionai": "dilazionare",
    "dilazionammo": "dilazionare",
    "dilazionan": "dilazionare",
    "dilazionando": "dilazionare",
    "dilazionano": "dilazionare",
    "dilazionante": "dilazionare",
    "dilazionanti": "dilazionare",
    "dilazionar": "dilazionare",
    "dilazionaron": "dilazionare",
    "dilazionarono": "dilazionare",
    "dilazionasse": "dilazionare",
    "dilazionasser": "dilazionare",
    "dilazionassero": "dilazionare",
    "dilazionassi": "dilazionare",
    "dilazionassimo": "dilazionare",
    "dilazionaste": "dilazionare",
    "dilazionasti": "dilazionare",
    "dilazionata": "dilazionato",
    "dilazionate": "dilazionato",
    "dilazionati": "dilazionato",
    "dilazionato": "dilazionare",
    "dilazionava": "dilazionare",
    "dilazionavamo": "dilazionare",
    "dilazionavan": "dilazionare",
    "dilazionavano": "dilazionare",
    "dilazionavate": "dilazionare",
    "dilazionavi": "dilazionare",
    "dilazionavo": "dilazionare",
    "dilazionerai": "dilazionare",
    "dilazioneran": "dilazionare",
    "dilazioneranno": "dilazionare",
    "dilazionerebbe": "dilazionare",
    "dilazionerebber": "dilazionare",
    "dilazionerebbero": "dilazionare",
    "dilazionerei": "dilazionare",
    "dilazioneremmo": "dilazionare",
    "dilazioneremo": "dilazionare",
    "dilazionereste": "dilazionare",
    "dilazioneresti": "dilazionare",
    "dilazionerete": "dilazionare",
    "dilazionerà": "dilazionare",
    "dilazionerò": "dilazionare",
    "dilazioni": "dilazione",
    "dilazioniamo": "dilazionare",
    "dilazioniate": "dilazionare",
    "dilazionin": "dilazionare",
    "dilazionino": "dilazionare",
    "dilaziono": "dilazionare",
    "dilazionò": "dilazionare",
    "dileggerai": "dileggiare",
    "dileggeran": "dileggiare",
    "dileggeranno": "dileggiare",
    "dileggerebbe": "dileggiare",
    "dileggerebber": "dileggiare",
    "dileggerebbero": "dileggiare",
    "dileggerei": "dileggiare",
    "dileggeremmo": "dileggiare",
    "dileggeremo": "dileggiare",
    "dileggereste": "dileggiare",
    "dileggeresti": "dileggiare",
    "dileggerete": "dileggiare",
    "dileggerà": "dileggiare",
    "dileggerò": "dileggiare",
    "dileggi": "dileggio",
    "dileggia": "dileggiare",
    "dileggiai": "dileggiare",
    "dileggiammo": "dileggiare",
    "dileggiamo": "dileggiare",
    "dileggian": "dileggiare",
    "dileggiando": "dileggiare",
    "dileggiano": "dileggiare",
    "dileggiante": "dileggiare",
    "dileggianti": "dileggiare",
    "dileggiar": "dileggiare",
    "dileggiaron": "dileggiare",
    "dileggiarono": "dileggiare",
    "dileggiasse": "dileggiare",
    "dileggiasser": "dileggiare",
    "dileggiassero": "dileggiare",
    "dileggiassi": "dileggiare",
    "dileggiassimo": "dileggiare",
    "dileggiaste": "dileggiare",
    "dileggiasti": "dileggiare",
    "dileggiata": "dileggiare",
    "dileggiate": "dileggiare",
    "dileggiati": "dileggiare",
    "dileggiato": "dileggiare",
    "dileggiava": "dileggiare",
    "dileggiavamo": "dileggiare",
    "dileggiavan": "dileggiare",
    "dileggiavano": "dileggiare",
    "dileggiavate": "dileggiare",
    "dileggiavi": "dileggiare",
    "dileggiavo": "dileggiare",
    "dileggin": "dileggiare",
    "dileggino": "dileggiare",
    "dileggio": "dileggiare",
    "dileggiò": "dileggiare",
    "dilegua": "dileguare",
    "dileguai": "dileguare",
    "dileguammo": "dileguare",
    "dileguan": "dileguare",
    "dileguando": "dileguare",
    "dileguano": "dileguare",
    "dileguante": "dileguare",
    "dileguanti": "dileguare",
    "dileguar": "dileguare",
    "dileguaron": "dileguare",
    "dileguarono": "dileguare",
    "dileguasse": "dileguare",
    "dileguasser": "dileguare",
    "dileguassero": "dileguare",
    "dileguassi": "dileguare",
    "dileguassimo": "dileguare",
    "dileguaste": "dileguare",
    "dileguasti": "dileguare",
    "dileguata": "dileguare",
    "dileguate": "dileguare",
    "dileguati": "dileguare",
    "dileguato": "dileguare",
    "dileguava": "dileguare",
    "dileguavamo": "dileguare",
    "dileguavan": "dileguare",
    "dileguavano": "dileguare",
    "dileguavate": "dileguare",
    "dileguavi": "dileguare",
    "dileguavo": "dileguare",
    "dileguerai": "dileguare",
    "dilegueran": "dileguare",
    "dilegueranno": "dileguare",
    "dileguerebbe": "dileguare",
    "dileguerebber": "dileguare",
    "dileguerebbero": "dileguare",
    "dileguerei": "dileguare",
    "dilegueremmo": "dileguare",
    "dilegueremo": "dileguare",
    "dileguereste": "dileguare",
    "dilegueresti": "dileguare",
    "dileguerete": "dileguare",
    "dileguerà": "dileguare",
    "dileguerò": "dileguare",
    "dilegui": "dileguare",
    "dileguiamo": "dileguare",
    "dileguiate": "dileguare",
    "dileguin": "dileguare",
    "dileguino": "dileguare",
    "dileguo": "dileguare",
    "dileguò": "dileguare",
    "dilemmi": "dilemma",
    "dilesse": "diligere",
    "dilesser": "diligere",
    "dilessero": "diligere",
    "dilessi": "diligere",
    "diletta": "diligere",
    "dilettai": "dilettare",
    "dilettammo": "dilettare",
    "dilettan": "dilettare",
    "dilettando": "dilettare",
    "dilettano": "dilettare",
    "dilettante": "dilettare",
    "dilettantesca": "dilettantesco",
    "dilettantesche": "dilettantesco",
    "dilettanteschi": "dilettantesco",
    "dilettanti": "dilettare",
    "dilettantismi": "dilettantismo",
    "dilettantistica": "dilettantistico",
    "dilettantistiche": "dilettantistico",
    "dilettantistici": "dilettantistico",
    "dilettar": "dilettare",
    "dilettaron": "dilettare",
    "dilettarono": "dilettare",
    "dilettasse": "dilettare",
    "dilettasser": "dilettare",
    "dilettassero": "dilettare",
    "dilettassi": "dilettare",
    "dilettassimo": "dilettare",
    "dilettaste": "dilettare",
    "dilettasti": "dilettare",
    "dilettata": "dilettare",
    "dilettate": "dilettare",
    "dilettati": "dilettare",
    "dilettato": "dilettare",
    "dilettava": "dilettare",
    "dilettavamo": "dilettare",
    "dilettavan": "dilettare",
    "dilettavano": "dilettare",
    "dilettavate": "dilettare",
    "dilettavi": "dilettare",
    "dilettavo": "dilettare",
    "dilette": "diligere",
    "diletterai": "dilettare",
    "diletteran": "dilettare",
    "diletteranno": "dilettare",
    "diletterebbe": "dilettare",
    "diletterebber": "dilettare",
    "diletterebbero": "dilettare",
    "diletterei": "dilettare",
    "diletteremmo": "dilettare",
    "diletteremo": "dilettare",
    "dilettereste": "dilettare",
    "diletteresti": "dilettare",
    "diletterete": "dilettare",
    "diletterà": "dilettare",
    "diletterò": "dilettare",
    "dilettevoli": "dilettevole",
    "diletti": "diligere",
    "dilettiamo": "dilettare",
    "dilettiate": "dilettare",
    "dilettin": "dilettare",
    "dilettino": "dilettare",
    "diletto": "diligere",
    "dilettosa": "dilettoso",
    "dilettose": "dilettoso",
    "dilettosi": "dilettoso",
    "dilettò": "dilettare",
    "diliga": "diligere",
    "diligan": "diligere",
    "diligano": "diligere",
    "dilige": "diligere",
    "diligemmo": "diligere",
    "diligendo": "diligere",
    "diligente": "diligere",
    "diligenti": "diligere",
    "diligenze": "diligenza",
    "diliger": "diligere",
    "diligerai": "diligere",
    "diligeran": "diligere",
    "diligeranno": "diligere",
    "diligerebbe": "diligere",
    "diligerebber": "diligere",
    "diligerebbero": "diligere",
    "diligerei": "diligere",
    "diligeremmo": "diligere",
    "diligeremo": "diligere",
    "diligereste": "diligere",
    "diligeresti": "diligere",
    "diligerete": "diligere",
    "diligerà": "diligere",
    "diligerò": "diligere",
    "diligesse": "diligere",
    "diligesser": "diligere",
    "diligessero": "diligere",
    "diligessi": "diligere",
    "diligessimo": "diligere",
    "diligeste": "diligere",
    "diligesti": "diligere",
    "diligete": "diligere",
    "diligeva": "diligere",
    "diligevamo": "diligere",
    "diligevan": "diligere",
    "diligevano": "diligere",
    "diligevate": "diligere",
    "diligevi": "diligere",
    "diligevo": "diligere",
    "diligi": "diligere",
    "diligiamo": "diligere",
    "diligiate": "diligere",
    "diligo": "diligere",
    "diligon": "diligere",
    "diligono": "diligere",
    "dilisca": "diliscare",
    "diliscai": "diliscare",
    "diliscammo": "diliscare",
    "diliscan": "diliscare",
    "diliscando": "diliscare",
    "diliscano": "diliscare",
    "diliscante": "diliscare",
    "diliscanti": "diliscare",
    "diliscar": "diliscare",
    "diliscaron": "diliscare",
    "diliscarono": "diliscare",
    "diliscasse": "diliscare",
    "diliscasser": "diliscare",
    "diliscassero": "diliscare",
    "diliscassi": "diliscare",
    "diliscassimo": "diliscare",
    "diliscaste": "diliscare",
    "diliscasti": "diliscare",
    "diliscata": "diliscare",
    "diliscate": "diliscare",
    "diliscati": "diliscare",
    "diliscato": "diliscare",
    "diliscava": "diliscare",
    "diliscavamo": "diliscare",
    "diliscavan": "diliscare",
    "diliscavano": "diliscare",
    "diliscavate": "diliscare",
    "diliscavi": "diliscare",
    "diliscavo": "diliscare",
    "dilischerai": "diliscare",
    "dilischeran": "diliscare",
    "dilischeranno": "diliscare",
    "dilischerebbe": "diliscare",
    "dilischerebber": "diliscare",
    "dilischerebbero": "diliscare",
    "dilischerei": "diliscare",
    "dilischeremmo": "diliscare",
    "dilischeremo": "diliscare",
    "dilischereste": "diliscare",
    "dilischeresti": "diliscare",
    "dilischerete": "diliscare",
    "dilischerà": "diliscare",
    "dilischerò": "diliscare",
    "dilischi": "diliscare",
    "dilischiamo": "diliscare",
    "dilischiate": "diliscare",
    "dilischin": "diliscare",
    "dilischino": "diliscare",
    "dilisco": "diliscare",
    "diliscò": "diliscare",
    "diluendo": "diluire",
    "diluente": "diluire",
    "diluenti": "diluire",
    "diluiamo": "diluire",
    "diluiate": "diluire",
    "diluibili": "diluibile",
    "diluii": "diluire",
    "diluimmo": "diluire",
    "diluir": "diluire",
    "diluirai": "diluire",
    "diluiran": "diluire",
    "diluiranno": "diluire",
    "diluirebbe": "diluire",
    "diluirebber": "diluire",
    "diluirebbero": "diluire",
    "diluirei": "diluire",
    "diluiremmo": "diluire",
    "diluiremo": "diluire",
    "diluireste": "diluire",
    "diluiresti": "diluire",
    "diluirete": "diluire",
    "diluiron": "diluire",
    "diluirono": "diluire",
    "diluirà": "diluire",
    "diluirò": "diluire",
    "diluisca": "diluire",
    "diluiscan": "diluire",
    "diluiscano": "diluire",
    "diluisce": "diluire",
    "diluisci": "diluire",
    "diluisco": "diluire",
    "diluiscon": "diluire",
    "diluiscono": "diluire",
    "diluisse": "diluire",
    "diluisser": "diluire",
    "diluissero": "diluire",
    "diluissi": "diluire",
    "diluissimo": "diluire",
    "diluiste": "diluire",
    "diluisti": "diluire",
    "diluita": "diluire",
    "diluite": "diluire",
    "diluiti": "diluire",
    "diluito": "diluire",
    "diluiva": "diluire",
    "diluivamo": "diluire",
    "diluivan": "diluire",
    "diluivano": "diluire",
    "diluivate": "diluire",
    "diluivi": "diluire",
    "diluivo": "diluire",
    "diluizioni": "diluizione",
    "dilunga": "dilungare",
    "dilungai": "dilungare",
    "dilungammo": "dilungare",
    "dilungan": "dilungare",
    "dilungando": "dilungare",
    "dilungano": "dilungare",
    "dilungante": "dilungare",
    "dilunganti": "dilungare",
    "dilungar": "dilungare",
    "dilungaron": "dilungare",
    "dilungarono": "dilungare",
    "dilungasse": "dilungare",
    "dilungasser": "dilungare",
    "dilungassero": "dilungare",
    "dilungassi": "dilungare",
    "dilungassimo": "dilungare",
    "dilungaste": "dilungare",
    "dilungasti": "dilungare",
    "dilungata": "dilungare",
    "dilungate": "dilungare",
    "dilungati": "dilungare",
    "dilungato": "dilungare",
    "dilungava": "dilungare",
    "dilungavamo": "dilungare",
    "dilungavan": "dilungare",
    "dilungavano": "dilungare",
    "dilungavate": "dilungare",
    "dilungavi": "dilungare",
    "dilungavo": "dilungare",
    "dilungherai": "dilungare",
    "dilungheran": "dilungare",
    "dilungheranno": "dilungare",
    "dilungherebbe": "dilungare",
    "dilungherebber": "dilungare",
    "dilungherebbero": "dilungare",
    "dilungherei": "dilungare",
    "dilungheremmo": "dilungare",
    "dilungheremo": "dilungare",
    "dilunghereste": "dilungare",
    "dilungheresti": "dilungare",
    "dilungherete": "dilungare",
    "dilungherà": "dilungare",
    "dilungherò": "dilungare",
    "dilunghi": "dilungare",
    "dilunghiamo": "dilungare",
    "dilunghiate": "dilungare",
    "dilunghin": "dilungare",
    "dilunghino": "dilungare",
    "dilungo": "dilungare",
    "dilungò": "dilungare",
    "diluvi": "diluvio",
    "diluvia": "diluviare",
    "diluviai": "diluviare",
    "diluviammo": "diluviare",
    "diluviamo": "diluviare",
    "diluvian": "diluviare",
    "diluviando": "diluviare",
    "diluviano": "diluviare",
    "diluviante": "diluviare",
    "diluvianti": "diluviare",
    "diluviar": "diluviare",
    "diluviaron": "diluviare",
    "diluviarono": "diluviare",
    "diluviasse": "diluviare",
    "diluviasser": "diluviare",
    "diluviassero": "diluviare",
    "diluviassi": "diluviare",
    "diluviassimo": "diluviare",
    "diluviaste": "diluviare",
    "diluviasti": "diluviare",
    "diluviata": "diluviare",
    "diluviate": "diluviare",
    "diluviati": "diluviare",
    "diluviato": "diluviare",
    "diluviava": "diluviare",
    "diluviavamo": "diluviare",
    "diluviavan": "diluviare",
    "diluviavano": "diluviare",
    "diluviavate": "diluviare",
    "diluviavi": "diluviare",
    "diluviavo": "diluviare",
    "diluvierai": "diluviare",
    "diluvieran": "diluviare",
    "diluvieranno": "diluviare",
    "diluvierebbe": "diluviare",
    "diluvierebber": "diluviare",
    "diluvierebbero": "diluviare",
    "diluvierei": "diluviare",
    "diluvieremmo": "diluviare",
    "diluvieremo": "diluviare",
    "diluviereste": "diluviare",
    "diluvieresti": "diluviare",
    "diluvierete": "diluviare",
    "diluvierà": "diluviare",
    "diluvierò": "diluviare",
    "diluvin": "diluviare",
    "diluvino": "diluviare",
    "diluvio": "diluviare",
    "diluviò": "diluviare",
    "diluì": "diluire",
    "dimagra": "dimagrare",
    "dimagrai": "dimagrare",
    "dimagrammo": "dimagrare",
    "dimagran": "dimagrare",
    "dimagrando": "dimagrare",
    "dimagrano": "dimagrare",
    "dimagrante": "dimagrare",
    "dimagranti": "dimagrare",
    "dimagrar": "dimagrare",
    "dimagraron": "dimagrare",
    "dimagrarono": "dimagrare",
    "dimagrasse": "dimagrare",
    "dimagrasser": "dimagrare",
    "dimagrassero": "dimagrare",
    "dimagrassi": "dimagrare",
    "dimagrassimo": "dimagrare",
    "dimagraste": "dimagrare",
    "dimagrasti": "dimagrare",
    "dimagrata": "dimagrare",
    "dimagrate": "dimagrare",
    "dimagrati": "dimagrare",
    "dimagrato": "dimagrare",
    "dimagrava": "dimagrare",
    "dimagravamo": "dimagrare",
    "dimagravan": "dimagrare",
    "dimagravano": "dimagrare",
    "dimagravate": "dimagrare",
    "dimagravi": "dimagrare",
    "dimagravo": "dimagrare",
    "dimagrendo": "dimagrire",
    "dimagrente": "dimagrire",
    "dimagrenti": "dimagrire",
    "dimagrerai": "dimagrare",
    "dimagreran": "dimagrare",
    "dimagreranno": "dimagrare",
    "dimagrerebbe": "dimagrare",
    "dimagrerebber": "dimagrare",
    "dimagrerebbero": "dimagrare",
    "dimagrerei": "dimagrare",
    "dimagreremmo": "dimagrare",
    "dimagreremo": "dimagrare",
    "dimagrereste": "dimagrare",
    "dimagreresti": "dimagrare",
    "dimagrerete": "dimagrare",
    "dimagrerà": "dimagrare",
    "dimagrerò": "dimagrare",
    "dimagri": "dimagrare",
    "dimagriamo": "dimagrire",
    "dimagriate": "dimagrire",
    "dimagrii": "dimagrire",
    "dimagrimenti": "dimagrimento",
    "dimagrimmo": "dimagrire",
    "dimagrin": "dimagrare",
    "dimagrino": "dimagrare",
    "dimagrir": "dimagrire",
    "dimagrirai": "dimagrire",
    "dimagriran": "dimagrire",
    "dimagriranno": "dimagrire",
    "dimagrirebbe": "dimagrire",
    "dimagrirebber": "dimagrire",
    "dimagrirebbero": "dimagrire",
    "dimagrirei": "dimagrire",
    "dimagriremmo": "dimagrire",
    "dimagriremo": "dimagrire",
    "dimagrireste": "dimagrire",
    "dimagriresti": "dimagrire",
    "dimagrirete": "dimagrire",
    "dimagriron": "dimagrire",
    "dimagrirono": "dimagrire",
    "dimagrirà": "dimagrire",
    "dimagrirò": "dimagrire",
    "dimagrisca": "dimagrire",
    "dimagriscan": "dimagrire",
    "dimagriscano": "dimagrire",
    "dimagrisce": "dimagrire",
    "dimagrisci": "dimagrire",
    "dimagrisco": "dimagrire",
    "dimagriscon": "dimagrire",
    "dimagriscono": "dimagrire",
    "dimagrisse": "dimagrire",
    "dimagrisser": "dimagrire",
    "dimagrissero": "dimagrire",
    "dimagrissi": "dimagrire",
    "dimagrissimo": "dimagrire",
    "dimagriste": "dimagrire",
    "dimagristi": "dimagrire",
    "dimagrita": "dimagrire",
    "dimagrite": "dimagrire",
    "dimagriti": "dimagrire",
    "dimagrito": "dimagrire",
    "dimagriva": "dimagrire",
    "dimagrivamo": "dimagrire",
    "dimagrivan": "dimagrire",
    "dimagrivano": "dimagrire",
    "dimagrivate": "dimagrire",
    "dimagrivi": "dimagrire",
    "dimagrivo": "dimagrire",
    "dimagro": "dimagrare",
    "dimagrì": "dimagrire",
    "dimagrò": "dimagrare",
    "dimena": "dimenare",
    "dimenai": "dimenare",
    "dimenammo": "dimenare",
    "dimenan": "dimenare",
    "dimenando": "dimenare",
    "dimenano": "dimenare",
    "dimenante": "dimenare",
    "dimenanti": "dimenare",
    "dimenar": "dimenare",
    "dimenaron": "dimenare",
    "dimenarono": "dimenare",
    "dimenasse": "dimenare",
    "dimenasser": "dimenare",
    "dimenassero": "dimenare",
    "dimenassi": "dimenare",
    "dimenassimo": "dimenare",
    "dimenaste": "dimenare",
    "dimenasti": "dimenare",
    "dimenata": "dimenare",
    "dimenate": "dimenare",
    "dimenati": "dimenare",
    "dimenato": "dimenare",
    "dimenava": "dimenare",
    "dimenavamo": "dimenare",
    "dimenavan": "dimenare",
    "dimenavano": "dimenare",
    "dimenavate": "dimenare",
    "dimenavi": "dimenare",
    "dimenavo": "dimenare",
    "dimenerai": "dimenare",
    "dimeneran": "dimenare",
    "dimeneranno": "dimenare",
    "dimenerebbe": "dimenare",
    "dimenerebber": "dimenare",
    "dimenerebbero": "dimenare",
    "dimenerei": "dimenare",
    "dimeneremmo": "dimenare",
    "dimeneremo": "dimenare",
    "dimenereste": "dimenare",
    "dimeneresti": "dimenare",
    "dimenerete": "dimenare",
    "dimenerà": "dimenare",
    "dimenerò": "dimenare",
    "dimeni": "dimenare",
    "dimeniamo": "dimenare",
    "dimeniate": "dimenare",
    "dimenin": "dimenare",
    "dimenino": "dimenare",
    "dimeno": "dimenare",
    "dimensiona": "dimensionare",
    "dimensionai": "dimensionare",
    "dimensionali": "dimensionale",
    "dimensionammo": "dimensionare",
    "dimensionan": "dimensionare",
    "dimensionando": "dimensionare",
    "dimensionano": "dimensionare",
    "dimensionante": "dimensionare",
    "dimensionanti": "dimensionare",
    "dimensionar": "dimensionare",
    "dimensionaron": "dimensionare",
    "dimensionarono": "dimensionare",
    "dimensionasse": "dimensionare",
    "dimensionasser": "dimensionare",
    "dimensionassero": "dimensionare",
    "dimensionassi": "dimensionare",
    "dimensionassimo": "dimensionare",
    "dimensionaste": "dimensionare",
    "dimensionasti": "dimensionare",
    "dimensionata": "dimensionare",
    "dimensionate": "dimensionare",
    "dimensionati": "dimensionare",
    "dimensionato": "dimensionare",
    "dimensionava": "dimensionare",
    "dimensionavamo": "dimensionare",
    "dimensionavan": "dimensionare",
    "dimensionavano": "dimensionare",
    "dimensionavate": "dimensionare",
    "dimensionavi": "dimensionare",
    "dimensionavo": "dimensionare",
    "dimensionerai": "dimensionare",
    "dimensioneran": "dimensionare",
    "dimensioneranno": "dimensionare",
    "dimensionerebbe": "dimensionare",
    "dimensionerebber": "dimensionare",
    "dimensionerebbero": "dimensionare",
    "dimensionerei": "dimensionare",
    "dimensioneremmo": "dimensionare",
    "dimensioneremo": "dimensionare",
    "dimensionereste": "dimensionare",
    "dimensioneresti": "dimensionare",
    "dimensionerete": "dimensionare",
    "dimensionerà": "dimensionare",
    "dimensionerò": "dimensionare",
    "dimensioni": "dimensione",
    "dimensioniamo": "dimensionare",
    "dimensioniate": "dimensionare",
    "dimensionin": "dimensionare",
    "dimensionino": "dimensionare",
    "dimensiono": "dimensionare",
    "dimensionò": "dimensionare",
    "dimentica": "dimentico",
    "dimenticabili": "dimenticabile",
    "dimenticai": "dimenticare",
    "dimenticammo": "dimenticare",
    "dimentican": "dimenticare",
    "dimenticando": "dimenticare",
    "dimenticano": "dimenticare",
    "dimenticante": "dimenticare",
    "dimenticanti": "dimenticare",
    "dimenticanze": "dimenticanza",
    "dimenticar": "dimenticare",
    "dimenticaron": "dimenticare",
    "dimenticarono": "dimenticare",
    "dimenticasse": "dimenticare",
    "dimenticasser": "dimenticare",
    "dimenticassero": "dimenticare",
    "dimenticassi": "dimenticare",
    "dimenticassimo": "dimenticare",
    "dimenticaste": "dimenticare",
    "dimenticasti": "dimenticare",
    "dimenticata": "dimenticato",
    "dimenticate": "dimenticato",
    "dimenticati": "dimenticato",
    "dimenticato": "dimenticare",
    "dimenticatoi": "dimenticatoio",
    "dimenticava": "dimenticare",
    "dimenticavamo": "dimenticare",
    "dimenticavan": "dimenticare",
    "dimenticavano": "dimenticare",
    "dimenticavate": "dimenticare",
    "dimenticavi": "dimenticare",
    "dimenticavo": "dimenticare",
    "dimentiche": "dimentico",
    "dimenticherai": "dimenticare",
    "dimenticheran": "dimenticare",
    "dimenticheranno": "dimenticare",
    "dimenticherebbe": "dimenticare",
    "dimenticherebber": "dimenticare",
    "dimenticherebbero": "dimenticare",
    "dimenticherei": "dimenticare",
    "dimenticheremmo": "dimenticare",
    "dimenticheremo": "dimenticare",
    "dimentichereste": "dimenticare",
    "dimenticheresti": "dimenticare",
    "dimenticherete": "dimenticare",
    "dimenticherà": "dimenticare",
    "dimenticherò": "dimenticare",
    "dimentichi": "dimenticare",
    "dimentichiamo": "dimenticare",
    "dimentichiate": "dimenticare",
    "dimentichin": "dimenticare",
    "dimentichino": "dimenticare",
    "dimentici": "dimentico",
    "dimentico": "dimenticare",
    "dimenticò": "dimenticare",
    "dimenò": "dimenare",
    "dimessa": "dimettere",
    "dimesse": "dimettere",
    "dimessi": "dimettere",
    "dimesso": "dimettere",
    "dimestichezze": "dimestichezza",
    "dimetta": "dimettere",
    "dimettan": "dimettere",
    "dimettano": "dimettere",
    "dimette": "dimettere",
    "dimettemmo": "dimettere",
    "dimettendo": "dimettere",
    "dimettente": "dimettere",
    "dimettenti": "dimettere",
    "dimetter": "dimettere",
    "dimetterai": "dimettere",
    "dimetteran": "dimettere",
    "dimetteranno": "dimettere",
    "dimetterebbe": "dimettere",
    "dimetterebber": "dimettere",
    "dimetterebbero": "dimettere",
    "dimetterei": "dimettere",
    "dimetteremmo": "dimettere",
    "dimetteremo": "dimettere",
    "dimettereste": "dimettere",
    "dimetteresti": "dimettere",
    "dimetterete": "dimettere",
    "dimetterà": "dimettere",
    "dimetterò": "dimettere",
    "dimettesse": "dimettere",
    "dimettesser": "dimettere",
    "dimettessero": "dimettere",
    "dimettessi": "dimettere",
    "dimettessimo": "dimettere",
    "dimetteste": "dimettere",
    "dimettesti": "dimettere",
    "dimettete": "dimettere",
    "dimetteva": "dimettere",
    "dimettevamo": "dimettere",
    "dimettevan": "dimettere",
    "dimettevano": "dimettere",
    "dimettevate": "dimettere",
    "dimettevi": "dimettere",
    "dimettevo": "dimettere",
    "dimetti": "dimettere",
    "dimettiamo": "dimettere",
    "dimettiate": "dimettere",
    "dimetto": "dimettere",
    "dimetton": "dimettere",
    "dimettono": "dimettere",
    "dimezza": "dimezzare",
    "dimezzai": "dimezzare",
    "dimezzamenti": "dimezzamento",
    "dimezzammo": "dimezzare",
    "dimezzan": "dimezzare",
    "dimezzando": "dimezzare",
    "dimezzano": "dimezzare",
    "dimezzante": "dimezzare",
    "dimezzanti": "dimezzare",
    "dimezzar": "dimezzare",
    "dimezzaron": "dimezzare",
    "dimezzarono": "dimezzare",
    "dimezzasse": "dimezzare",
    "dimezzasser": "dimezzare",
    "dimezzassero": "dimezzare",
    "dimezzassi": "dimezzare",
    "dimezzassimo": "dimezzare",
    "dimezzaste": "dimezzare",
    "dimezzasti": "dimezzare",
    "dimezzata": "dimezzare",
    "dimezzate": "dimezzare",
    "dimezzati": "dimezzare",
    "dimezzato": "dimezzare",
    "dimezzava": "dimezzare",
    "dimezzavamo": "dimezzare",
    "dimezzavan": "dimezzare",
    "dimezzavano": "dimezzare",
    "dimezzavate": "dimezzare",
    "dimezzavi": "dimezzare",
    "dimezzavo": "dimezzare",
    "dimezzerai": "dimezzare",
    "dimezzeran": "dimezzare",
    "dimezzeranno": "dimezzare",
    "dimezzerebbe": "dimezzare",
    "dimezzerebber": "dimezzare",
    "dimezzerebbero": "dimezzare",
    "dimezzerei": "dimezzare",
    "dimezzeremmo": "dimezzare",
    "dimezzeremo": "dimezzare",
    "dimezzereste": "dimezzare",
    "dimezzeresti": "dimezzare",
    "dimezzerete": "dimezzare",
    "dimezzerà": "dimezzare",
    "dimezzerò": "dimezzare",
    "dimezzi": "dimezzare",
    "dimezziamo": "dimezzare",
    "dimezziate": "dimezzare",
    "dimezzin": "dimezzare",
    "dimezzino": "dimezzare",
    "dimezzo": "dimezzare",
    "dimezzò": "dimezzare",
    "diminuendo": "diminuire",
    "diminuente": "diminuire",
    "diminuenti": "diminuire",
    "diminuiamo": "diminuire",
    "diminuiate": "diminuire",
    "diminuii": "diminuire",
    "diminuimmo": "diminuire",
    "diminuir": "diminuire",
    "diminuirai": "diminuire",
    "diminuiran": "diminuire",
    "diminuiranno": "diminuire",
    "diminuirebbe": "diminuire",
    "diminuirebber": "diminuire",
    "diminuirebbero": "diminuire",
    "diminuirei": "diminuire",
    "diminuiremmo": "diminuire",
    "diminuiremo": "diminuire",
    "diminuireste": "diminuire",
    "diminuiresti": "diminuire",
    "diminuirete": "diminuire",
    "diminuiron": "diminuire",
    "diminuirono": "diminuire",
    "diminuirà": "diminuire",
    "diminuirò": "diminuire",
    "diminuisca": "diminuire",
    "diminuiscan": "diminuire",
    "diminuiscano": "diminuire",
    "diminuisce": "diminuire",
    "diminuisci": "diminuire",
    "diminuisco": "diminuire",
    "diminuiscon": "diminuire",
    "diminuiscono": "diminuire",
    "diminuisse": "diminuire",
    "diminuisser": "diminuire",
    "diminuissero": "diminuire",
    "diminuissi": "diminuire",
    "diminuissimo": "diminuire",
    "diminuiste": "diminuire",
    "diminuisti": "diminuire",
    "diminuita": "diminuire",
    "diminuite": "diminuire",
    "diminuiti": "diminuire",
    "diminuito": "diminuire",
    "diminuiva": "diminuire",
    "diminuivamo": "diminuire",
    "diminuivan": "diminuire",
    "diminuivano": "diminuire",
    "diminuivate": "diminuire",
    "diminuivi": "diminuire",
    "diminuivo": "diminuire",
    "diminutiva": "diminutivo",
    "diminutive": "diminutivo",
    "diminutivi": "diminutivo",
    "diminuzioni": "diminuzione",
    "diminuì": "diminuire",
    "dimise": "dimettere",
    "dimiser": "dimettere",
    "dimisero": "dimettere",
    "dimisi": "dimettere",
    "dimissiona": "dimissionare",
    "dimissionai": "dimissionare",
    "dimissionammo": "dimissionare",
    "dimissionan": "dimissionare",
    "dimissionando": "dimissionare",
    "dimissionano": "dimissionare",
    "dimissionante": "dimissionare",
    "dimissionanti": "dimissionare",
    "dimissionar": "dimissionare",
    "dimissionari": "dimissionario",
    "dimissionaria": "dimissionario",
    "dimissionarie": "dimissionario",
    "dimissionaron": "dimissionare",
    "dimissionarono": "dimissionare",
    "dimissionasse": "dimissionare",
    "dimissionasser": "dimissionare",
    "dimissionassero": "dimissionare",
    "dimissionassi": "dimissionare",
    "dimissionassimo": "dimissionare",
    "dimissionaste": "dimissionare",
    "dimissionasti": "dimissionare",
    "dimissionata": "dimissionare",
    "dimissionate": "dimissionare",
    "dimissionati": "dimissionare",
    "dimissionato": "dimissionare",
    "dimissionava": "dimissionare",
    "dimissionavamo": "dimissionare",
    "dimissionavan": "dimissionare",
    "dimissionavano": "dimissionare",
    "dimissionavate": "dimissionare",
    "dimissionavi": "dimissionare",
    "dimissionavo": "dimissionare",
    "dimissionerai": "dimissionare",
    "dimissioneran": "dimissionare",
    "dimissioneranno": "dimissionare",
    "dimissionerebbe": "dimissionare",
    "dimissionerebber": "dimissionare",
    "dimissionerebbero": "dimissionare",
    "dimissionerei": "dimissionare",
    "dimissioneremmo": "dimissionare",
    "dimissioneremo": "dimissionare",
    "dimissionereste": "dimissionare",
    "dimissioneresti": "dimissionare",
    "dimissionerete": "dimissionare",
    "dimissionerà": "dimissionare",
    "dimissionerò": "dimissionare",
    "dimissioni": "dimissione",
    "dimissioniamo": "dimissionare",
    "dimissioniate": "dimissionare",
    "dimissionin": "dimissionare",
    "dimissionino": "dimissionare",
    "dimissiono": "dimissionare",
    "dimissionò": "dimissionare",
    "dimora": "dimorare",
    "dimorai": "dimorare",
    "dimorammo": "dimorare",
    "dimoran": "dimorare",
    "dimorando": "dimorare",
    "dimorano": "dimorare",
    "dimorante": "dimorare",
    "dimoranti": "dimorare",
    "dimorar": "dimorare",
    "dimoraron": "dimorare",
    "dimorarono": "dimorare",
    "dimorasse": "dimorare",
    "dimorasser": "dimorare",
    "dimorassero": "dimorare",
    "dimorassi": "dimorare",
    "dimorassimo": "dimorare",
    "dimoraste": "dimorare",
    "dimorasti": "dimorare",
    "dimorata": "dimorare",
    "dimorate": "dimorare",
    "dimorati": "dimorare",
    "dimorato": "dimorare",
    "dimorava": "dimorare",
    "dimoravamo": "dimorare",
    "dimoravan": "dimorare",
    "dimoravano": "dimorare",
    "dimoravate": "dimorare",
    "dimoravi": "dimorare",
    "dimoravo": "dimorare",
    "dimore": "dimora",
    "dimorerai": "dimorare",
    "dimoreran": "dimorare",
    "dimoreranno": "dimorare",
    "dimorerebbe": "dimorare",
    "dimorerebber": "dimorare",
    "dimorerebbero": "dimorare",
    "dimorerei": "dimorare",
    "dimoreremmo": "dimorare",
    "dimoreremo": "dimorare",
    "dimorereste": "dimorare",
    "dimoreresti": "dimorare",
    "dimorerete": "dimorare",
    "dimorerà": "dimorare",
    "dimorerò": "dimorare",
    "dimori": "dimorare",
    "dimoriamo": "dimorare",
    "dimoriate": "dimorare",
    "dimorin": "dimorare",
    "dimorino": "dimorare",
    "dimoro": "dimorare",
    "dimorò": "dimorare",
    "dimostra": "dimostrare",
    "dimostrabili": "dimostrabile",
    "dimostrai": "dimostrare",
    "dimostrammo": "dimostrare",
    "dimostran": "dimostrare",
    "dimostrando": "dimostrare",
    "dimostrano": "dimostrare",
    "dimostrante": "dimostrare",
    "dimostranti": "dimostrare",
    "dimostrar": "dimostrare",
    "dimostraron": "dimostrare",
    "dimostrarono": "dimostrare",
    "dimostrasse": "dimostrare",
    "dimostrasser": "dimostrare",
    "dimostrassero": "dimostrare",
    "dimostrassi": "dimostrare",
    "dimostrassimo": "dimostrare",
    "dimostraste": "dimostrare",
    "dimostrasti": "dimostrare",
    "dimostrata": "dimostrare",
    "dimostrate": "dimostrare",
    "dimostrati": "dimostrare",
    "dimostrativa": "dimostrativo",
    "dimostrative": "dimostrativo",
    "dimostrativi": "dimostrativo",
    "dimostrato": "dimostrare",
    "dimostrava": "dimostrare",
    "dimostravamo": "dimostrare",
    "dimostravan": "dimostrare",
    "dimostravano": "dimostrare",
    "dimostravate": "dimostrare",
    "dimostravi": "dimostrare",
    "dimostravo": "dimostrare",
    "dimostrazioni": "dimostrazione",
    "dimostrerai": "dimostrare",
    "dimostreran": "dimostrare",
    "dimostreranno": "dimostrare",
    "dimostrerebbe": "dimostrare",
    "dimostrerebber": "dimostrare",
    "dimostrerebbero": "dimostrare",
    "dimostrerei": "dimostrare",
    "dimostreremmo": "dimostrare",
    "dimostreremo": "dimostrare",
    "dimostrereste": "dimostrare",
    "dimostreresti": "dimostrare",
    "dimostrerete": "dimostrare",
    "dimostrerà": "dimostrare",
    "dimostrerò": "dimostrare",
    "dimostri": "dimostrare",
    "dimostriamo": "dimostrare",
    "dimostriate": "dimostrare",
    "dimostrin": "dimostrare",
    "dimostrino": "dimostrare",
    "dimostro": "dimostrare",
    "dimostrò": "dimostrare",
    "dinamica": "dinamico",
    "dinamiche": "dinamico",
    "dinamici": "dinamico",
    "dinamismi": "dinamismo",
    "dinamitarda": "dinamitardo",
    "dinamitarde": "dinamitardo",
    "dinamitardi": "dinamitardo",
    "dinamiti": "dinamite",
    "dinamizza": "dinamizzare",
    "dinamizzai": "dinamizzare",
    "dinamizzammo": "dinamizzare",
    "dinamizzan": "dinamizzare",
    "dinamizzando": "dinamizzare",
    "dinamizzano": "dinamizzare",
    "dinamizzante": "dinamizzare",
    "dinamizzanti": "dinamizzare",
    "dinamizzar": "dinamizzare",
    "dinamizzaron": "dinamizzare",
    "dinamizzarono": "dinamizzare",
    "dinamizzasse": "dinamizzare",
    "dinamizzasser": "dinamizzare",
    "dinamizzassero": "dinamizzare",
    "dinamizzassi": "dinamizzare",
    "dinamizzassimo": "dinamizzare",
    "dinamizzaste": "dinamizzare",
    "dinamizzasti": "dinamizzare",
    "dinamizzata": "dinamizzare",
    "dinamizzate": "dinamizzare",
    "dinamizzati": "dinamizzare",
    "dinamizzato": "dinamizzare",
    "dinamizzava": "dinamizzare",
    "dinamizzavamo": "dinamizzare",
    "dinamizzavan": "dinamizzare",
    "dinamizzavano": "dinamizzare",
    "dinamizzavate": "dinamizzare",
    "dinamizzavi": "dinamizzare",
    "dinamizzavo": "dinamizzare",
    "dinamizzerai": "dinamizzare",
    "dinamizzeran": "dinamizzare",
    "dinamizzeranno": "dinamizzare",
    "dinamizzerebbe": "dinamizzare",
    "dinamizzerebber": "dinamizzare",
    "dinamizzerebbero": "dinamizzare",
    "dinamizzerei": "dinamizzare",
    "dinamizzeremmo": "dinamizzare",
    "dinamizzeremo": "dinamizzare",
    "dinamizzereste": "dinamizzare",
    "dinamizzeresti": "dinamizzare",
    "dinamizzerete": "dinamizzare",
    "dinamizzerà": "dinamizzare",
    "dinamizzerò": "dinamizzare",
    "dinamizzi": "dinamizzare",
    "dinamizziamo": "dinamizzare",
    "dinamizziate": "dinamizzare",
    "dinamizzin": "dinamizzare",
    "dinamizzino": "dinamizzare",
    "dinamizzo": "dinamizzare",
    "dinamizzò": "dinamizzare",
    "dinari": "dinaro",
    "dinastica": "dinastico",
    "dinastiche": "dinastico",
    "dinastici": "dinastico",
    "dinastie": "dinastia",
    "diniana": "diniano",
    "diniane": "diniano",
    "diniani": "diniano",
    "dinieghi": "diniego",
    "dinoccola": "dinoccolare",
    "dinoccolai": "dinoccolare",
    "dinoccolammo": "dinoccolare",
    "dinoccolan": "dinoccolare",
    "dinoccolando": "dinoccolare",
    "dinoccolano": "dinoccolare",
    "dinoccolante": "dinoccolare",
    "dinoccolanti": "dinoccolare",
    "dinoccolar": "dinoccolare",
    "dinoccolaron": "dinoccolare",
    "dinoccolarono": "dinoccolare",
    "dinoccolasse": "dinoccolare",
    "dinoccolasser": "dinoccolare",
    "dinoccolassero": "dinoccolare",
    "dinoccolassi": "dinoccolare",
    "dinoccolassimo": "dinoccolare",
    "dinoccolaste": "dinoccolare",
    "dinoccolasti": "dinoccolare",
    "dinoccolata": "dinoccolato",
    "dinoccolate": "dinoccolato",
    "dinoccolati": "dinoccolato",
    "dinoccolato": "dinoccolare",
    "dinoccolava": "dinoccolare",
    "dinoccolavamo": "dinoccolare",
    "dinoccolavan": "dinoccolare",
    "dinoccolavano": "dinoccolare",
    "dinoccolavate": "dinoccolare",
    "dinoccolavi": "dinoccolare",
    "dinoccolavo": "dinoccolare",
    "dinoccolerai": "dinoccolare",
    "dinoccoleran": "dinoccolare",
    "dinoccoleranno": "dinoccolare",
    "dinoccolerebbe": "dinoccolare",
    "dinoccolerebber": "dinoccolare",
    "dinoccolerebbero": "dinoccolare",
    "dinoccolerei": "dinoccolare",
    "dinoccoleremmo": "dinoccolare",
    "dinoccoleremo": "dinoccolare",
    "dinoccolereste": "dinoccolare",
    "dinoccoleresti": "dinoccolare",
    "dinoccolerete": "dinoccolare",
    "dinoccolerà": "dinoccolare",
    "dinoccolerò": "dinoccolare",
    "dinoccoli": "dinoccolare",
    "dinoccoliamo": "dinoccolare",
    "dinoccoliate": "dinoccolare",
    "dinoccolin": "dinoccolare",
    "dinoccolino": "dinoccolare",
    "dinoccolo": "dinoccolare",
    "dinoccolò": "dinoccolare",
    "dintorni": "dintorno",
    "diocesana": "diocesano",
    "diocesane": "diocesano",
    "diocesani": "diocesano",
    "dionisiaca": "dionisiaco",
    "dionisiache": "dionisiaco",
    "dionisiaci": "dionisiaco",
    "diossine": "diossina",
    "dipana": "dipanare",
    "dipanai": "dipanare",
    "dipanammo": "dipanare",
    "dipanan": "dipanare",
    "dipanando": "dipanare",
    "dipanano": "dipanare",
    "dipanante": "dipanare",
    "dipananti": "dipanare",
    "dipanar": "dipanare",
    "dipanaron": "dipanare",
    "dipanarono": "dipanare",
    "dipanasse": "dipanare",
    "dipanasser": "dipanare",
    "dipanassero": "dipanare",
    "dipanassi": "dipanare",
    "dipanassimo": "dipanare",
    "dipanaste": "dipanare",
    "dipanasti": "dipanare",
    "dipanata": "dipanare",
    "dipanate": "dipanare",
    "dipanati": "dipanare",
    "dipanato": "dipanare",
    "dipanava": "dipanare",
    "dipanavamo": "dipanare",
    "dipanavan": "dipanare",
    "dipanavano": "dipanare",
    "dipanavate": "dipanare",
    "dipanavi": "dipanare",
    "dipanavo": "dipanare",
    "dipanerai": "dipanare",
    "dipaneran": "dipanare",
    "dipaneranno": "dipanare",
    "dipanerebbe": "dipanare",
    "dipanerebber": "dipanare",
    "dipanerebbero": "dipanare",
    "dipanerei": "dipanare",
    "dipaneremmo": "dipanare",
    "dipaneremo": "dipanare",
    "dipanereste": "dipanare",
    "dipaneresti": "dipanare",
    "dipanerete": "dipanare",
    "dipanerà": "dipanare",
    "dipanerò": "dipanare",
    "dipani": "dipanare",
    "dipaniamo": "dipanare",
    "dipaniate": "dipanare",
    "dipanin": "dipanare",
    "dipanino": "dipanare",
    "dipano": "dipanare",
    "dipanò": "dipanare",
    "diparta": "dipartire",
    "dipartan": "dipartire",
    "dipartano": "dipartire",
    "diparte": "dipartire",
    "dipartendo": "dipartire",
    "dipartente": "dipartire",
    "dipartenti": "dipartire",
    "diparti": "dipartire",
    "dipartiamo": "dipartire",
    "dipartiate": "dipartire",
    "dipartii": "dipartire",
    "dipartimentali": "dipartimentale",
    "dipartimenti": "dipartimento",
    "dipartimmo": "dipartire",
    "dipartir": "dipartire",
    "dipartirai": "dipartire",
    "dipartiran": "dipartire",
    "dipartiranno": "dipartire",
    "dipartirebbe": "dipartire",
    "dipartirebber": "dipartire",
    "dipartirebbero": "dipartire",
    "dipartirei": "dipartire",
    "dipartiremmo": "dipartire",
    "dipartiremo": "dipartire",
    "dipartireste": "dipartire",
    "dipartiresti": "dipartire",
    "dipartirete": "dipartire",
    "dipartiron": "dipartire",
    "dipartirono": "dipartire",
    "dipartirà": "dipartire",
    "dipartirò": "dipartire",
    "dipartisse": "dipartire",
    "dipartisser": "dipartire",
    "dipartissero": "dipartire",
    "dipartissi": "dipartire",
    "dipartissimo": "dipartire",
    "dipartiste": "dipartire",
    "dipartisti": "dipartire",
    "dipartita": "dipartire",
    "dipartite": "dipartita",
    "dipartiti": "dipartire",
    "dipartito": "dipartire",
    "dipartiva": "dipartire",
    "dipartivamo": "dipartire",
    "dipartivan": "dipartire",
    "dipartivano": "dipartire",
    "dipartivate": "dipartire",
    "dipartivi": "dipartire",
    "dipartivo": "dipartire",
    "diparto": "dipartire",
    "diparton": "dipartire",
    "dipartono": "dipartire",
    "dipartì": "dipartire",
    "dipenda": "dipendere",
    "dipendan": "dipendere",
    "dipendano": "dipendere",
    "dipende": "dipendere",
    "dipendemmo": "dipendere",
    "dipendendo": "dipendere",
    "dipendente": "dipendere",
    "dipendenti": "dipendere",
    "dipendenze": "dipendenza",
    "dipender": "dipendere",
    "dipenderai": "dipendere",
    "dipenderan": "dipendere",
    "dipenderanno": "dipendere",
    "dipenderebbe": "dipendere",
    "dipenderebber": "dipendere",
    "dipenderebbero": "dipendere",
    "dipenderei": "dipendere",
    "dipenderemmo": "dipendere",
    "dipenderemo": "dipendere",
    "dipendereste": "dipendere",
    "dipenderesti": "dipendere",
    "dipenderete": "dipendere",
    "dipenderà": "dipendere",
    "dipenderò": "dipendere",
    "dipendesse": "dipendere",
    "dipendesser": "dipendere",
    "dipendessero": "dipendere",
    "dipendessi": "dipendere",
    "dipendessimo": "dipendere",
    "dipendeste": "dipendere",
    "dipendesti": "dipendere",
    "dipendete": "dipendere",
    "dipendeva": "dipendere",
    "dipendevamo": "dipendere",
    "dipendevan": "dipendere",
    "dipendevano": "dipendere",
    "dipendevate": "dipendere",
    "dipendevi": "dipendere",
    "dipendevo": "dipendere",
    "dipendi": "dipendere",
    "dipendiamo": "dipendere",
    "dipendiate": "dipendere",
    "dipendo": "dipendere",
    "dipendon": "dipendere",
    "dipendono": "dipendere",
    "dipesa": "dipendere",
    "dipese": "dipendere",
    "dipeser": "dipendere",
    "dipesero": "dipendere",
    "dipesi": "dipendere",
    "dipeso": "dipendere",
    "dipesè": "dipendere",
    "dipietresca": "dipietresco",
    "dipietresche": "dipietresco",
    "dipietreschi": "dipietresco",
    "dipietriste": "dipietrista",
    "dipietristi": "dipietrista",
    "dipinga": "dipingere",
    "dipingan": "dipingere",
    "dipingano": "dipingere",
    "dipinge": "dipingere",
    "dipingemmo": "dipingere",
    "dipingendo": "dipingere",
    "dipingente": "dipingere",
    "dipingenti": "dipingere",
    "dipinger": "dipingere",
    "dipingerai": "dipingere",
    "dipingeran": "dipingere",
    "dipingeranno": "dipingere",
    "dipingerebbe": "dipingere",
    "dipingerebber": "dipingere",
    "dipingerebbero": "dipingere",
    "dipingerei": "dipingere",
    "dipingeremmo": "dipingere",
    "dipingeremo": "dipingere",
    "dipingereste": "dipingere",
    "dipingeresti": "dipingere",
    "dipingerete": "dipingere",
    "dipingerà": "dipingere",
    "dipingerò": "dipingere",
    "dipingesse": "dipingere",
    "dipingesser": "dipingere",
    "dipingessero": "dipingere",
    "dipingessi": "dipingere",
    "dipingessimo": "dipingere",
    "dipingeste": "dipingere",
    "dipingesti": "dipingere",
    "dipingete": "dipingere",
    "dipingeva": "dipingere",
    "dipingevamo": "dipingere",
    "dipingevan": "dipingere",
    "dipingevano": "dipingere",
    "dipingevate": "dipingere",
    "dipingevi": "dipingere",
    "dipingevo": "dipingere",
    "dipingi": "dipingere",
    "dipingiamo": "dipingere",
    "dipingiate": "dipingere",
    "dipingo": "dipingere",
    "dipingon": "dipingere",
    "dipingono": "dipingere",
    "dipinse": "dipingere",
    "dipinser": "dipingere",
    "dipinsero": "dipingere",
    "dipinsi": "dipingere",
    "dipinta": "dipinto",
    "dipinte": "dipinto",
    "dipinti": "dipinto",
    "dipinto": "dipingere",
    "diploma": "diplomare",
    "diplomai": "diplomare",
    "diplomammo": "diplomare",
    "diploman": "diplomare",
    "diplomando": "diplomare",
    "diplomano": "diplomare",
    "diplomante": "diplomare",
    "diplomanti": "diplomare",
    "diplomar": "diplomare",
    "diplomaron": "diplomare",
    "diplomarono": "diplomare",
    "diplomasse": "diplomare",
    "diplomasser": "diplomare",
    "diplomassero": "diplomare",
    "diplomassi": "diplomare",
    "diplomassimo": "diplomare",
    "diplomaste": "diplomare",
    "diplomasti": "diplomare",
    "diplomata": "diplomare",
    "diplomate": "diplomare",
    "diplomati": "diplomato",
    "diplomatica": "diplomatico",
    "diplomatiche": "diplomatico",
    "diplomatici": "diplomatico",
    "diplomato": "diplomare",
    "diplomava": "diplomare",
    "diplomavamo": "diplomare",
    "diplomavan": "diplomare",
    "diplomavano": "diplomare",
    "diplomavate": "diplomare",
    "diplomavi": "diplomare",
    "diplomavo": "diplomare",
    "diplomazie": "diplomazia",
    "diplomerai": "diplomare",
    "diplomeran": "diplomare",
    "diplomeranno": "diplomare",
    "diplomerebbe": "diplomare",
    "diplomerebber": "diplomare",
    "diplomerebbero": "diplomare",
    "diplomerei": "diplomare",
    "diplomeremmo": "diplomare",
    "diplomeremo": "diplomare",
    "diplomereste": "diplomare",
    "diplomeresti": "diplomare",
    "diplomerete": "diplomare",
    "diplomerà": "diplomare",
    "diplomerò": "diplomare",
    "diplomi": "diplomare",
    "diplomiamo": "diplomare",
    "diplomiate": "diplomare",
    "diplomin": "diplomare",
    "diplomino": "diplomare",
    "diplomo": "diplomare",
    "diplomò": "diplomare",
    "diportisti": "diportista",
    "diposizioni": "diposizione",
    "dir": "dire",
    "dira": "diro",
    "dirada": "diradare",
    "diradai": "diradare",
    "diradammo": "diradare",
    "diradan": "diradare",
    "diradando": "diradare",
    "diradano": "diradare",
    "diradante": "diradare",
    "diradanti": "diradare",
    "diradar": "diradare",
    "diradaron": "diradare",
    "diradarono": "diradare",
    "diradasse": "diradare",
    "diradasser": "diradare",
    "diradassero": "diradare",
    "diradassi": "diradare",
    "diradassimo": "diradare",
    "diradaste": "diradare",
    "diradasti": "diradare",
    "diradata": "diradare",
    "diradate": "diradare",
    "diradati": "diradare",
    "diradato": "diradare",
    "diradava": "diradare",
    "diradavamo": "diradare",
    "diradavan": "diradare",
    "diradavano": "diradare",
    "diradavate": "diradare",
    "diradavi": "diradare",
    "diradavo": "diradare",
    "diraderai": "diradare",
    "diraderan": "diradare",
    "diraderanno": "diradare",
    "diraderebbe": "diradare",
    "diraderebber": "diradare",
    "diraderebbero": "diradare",
    "diraderei": "diradare",
    "diraderemmo": "diradare",
    "diraderemo": "diradare",
    "diradereste": "diradare",
    "diraderesti": "diradare",
    "diraderete": "diradare",
    "diraderà": "diradare",
    "diraderò": "diradare",
    "diradi": "diradare",
    "diradiamo": "diradare",
    "diradiate": "diradare",
    "diradica": "diradicare",
    "diradicai": "diradicare",
    "diradicammo": "diradicare",
    "diradican": "diradicare",
    "diradicando": "diradicare",
    "diradicano": "diradicare",
    "diradicante": "diradicare",
    "diradicanti": "diradicare",
    "diradicar": "diradicare",
    "diradicaron": "diradicare",
    "diradicarono": "diradicare",
    "diradicasse": "diradicare",
    "diradicasser": "diradicare",
    "diradicassero": "diradicare",
    "diradicassi": "diradicare",
    "diradicassimo": "diradicare",
    "diradicaste": "diradicare",
    "diradicasti": "diradicare",
    "diradicata": "diradicare",
    "diradicate": "diradicare",
    "diradicati": "diradicare",
    "diradicato": "diradicare",
    "diradicava": "diradicare",
    "diradicavamo": "diradicare",
    "diradicavan": "diradicare",
    "diradicavano": "diradicare",
    "diradicavate": "diradicare",
    "diradicavi": "diradicare",
    "diradicavo": "diradicare",
    "diradicherai": "diradicare",
    "diradicheran": "diradicare",
    "diradicheranno": "diradicare",
    "diradicherebbe": "diradicare",
    "diradicherebber": "diradicare",
    "diradicherebbero": "diradicare",
    "diradicherei": "diradicare",
    "diradicheremmo": "diradicare",
    "diradicheremo": "diradicare",
    "diradichereste": "diradicare",
    "diradicheresti": "diradicare",
    "diradicherete": "diradicare",
    "diradicherà": "diradicare",
    "diradicherò": "diradicare",
    "diradichi": "diradicare",
    "diradichiamo": "diradicare",
    "diradichiate": "diradicare",
    "diradichin": "diradicare",
    "diradichino": "diradicare",
    "diradico": "diradicare",
    "diradicò": "diradicare",
    "diradin": "diradare",
    "diradino": "diradare",
    "dirado": "diradare",
    "diradò": "diradare",
    "dirai": "dire",
    "dirama": "diramare",
    "diramai": "diramare",
    "diramammo": "diramare",
    "diraman": "diramare",
    "diramando": "diramare",
    "diramano": "diramare",
    "diramante": "diramare",
    "diramanti": "diramare",
    "diramar": "diramare",
    "diramaron": "diramare",
    "diramarono": "diramare",
    "diramasse": "diramare",
    "diramasser": "diramare",
    "diramassero": "diramare",
    "diramassi": "diramare",
    "diramassimo": "diramare",
    "diramaste": "diramare",
    "diramasti": "diramare",
    "diramata": "diramare",
    "diramate": "diramare",
    "diramati": "diramare",
    "diramato": "diramare",
    "diramava": "diramare",
    "diramavamo": "diramare",
    "diramavan": "diramare",
    "diramavano": "diramare",
    "diramavate": "diramare",
    "diramavi": "diramare",
    "diramavo": "diramare",
    "diramazioni": "diramazione",
    "diramerai": "diramare",
    "dirameran": "diramare",
    "dirameranno": "diramare",
    "diramerebbe": "diramare",
    "diramerebber": "diramare",
    "diramerebbero": "diramare",
    "diramerei": "diramare",
    "dirameremmo": "diramare",
    "dirameremo": "diramare",
    "diramereste": "diramare",
    "dirameresti": "diramare",
    "diramerete": "diramare",
    "diramerà": "diramare",
    "diramerò": "diramare",
    "dirami": "diramare",
    "diramiamo": "diramare",
    "diramiate": "diramare",
    "diramin": "diramare",
    "diramino": "diramare",
    "diramo": "diramare",
    "diramò": "diramare",
    "diran": "dire",
    "diranno": "dire",
    "dire": "diro",
    "direbbe": "dire",
    "direbber": "dire",
    "direbbero": "dire",
    "direi": "dire",
    "diremmo": "dire",
    "diremo": "dire",
    "diresse": "dirigere",
    "diresser": "dirigere",
    "diressero": "dirigere",
    "diressi": "dirigere",
    "direste": "dire",
    "diresti": "dire",
    "direte": "dire",
    "diretta": "dirigere",
    "dirette": "dirigere",
    "diretti": "dirigere",
    "direttiva": "direttivo",
    "direttive": "direttivo",
    "direttivi": "direttivo",
    "diretto": "dirigere",
    "direttori": "direttorio",
    "direttoriali": "direttoriale",
    "direttrice": "direttore",
    "direttrici": "direttrice",
    "direzionali": "direzionale",
    "direzionata": "direzionato",
    "direzionate": "direzionato",
    "direzionati": "direzionato",
    "direzioni": "direzione",
    "diri": "diro",
    "diriga": "dirigere",
    "dirigan": "dirigere",
    "dirigano": "dirigere",
    "dirige": "dirigere",
    "dirigemmo": "dirigere",
    "dirigendo": "dirigere",
    "dirigente": "dirigere",
    "dirigenti": "dirigere",
    "dirigenze": "dirigenza",
    "dirigenziali": "dirigenziale",
    "diriger": "dirigere",
    "dirigerai": "dirigere",
    "dirigeran": "dirigere",
    "dirigeranno": "dirigere",
    "dirigerebbe": "dirigere",
    "dirigerebber": "dirigere",
    "dirigerebbero": "dirigere",
    "dirigerei": "dirigere",
    "dirigeremmo": "dirigere",
    "dirigeremo": "dirigere",
    "dirigereste": "dirigere",
    "dirigeresti": "dirigere",
    "dirigerete": "dirigere",
    "dirigerà": "dirigere",
    "dirigerò": "dirigere",
    "dirigesse": "dirigere",
    "dirigesser": "dirigere",
    "dirigessero": "dirigere",
    "dirigessi": "dirigere",
    "dirigessimo": "dirigere",
    "dirigeste": "dirigere",
    "dirigesti": "dirigere",
    "dirigete": "dirigere",
    "dirigeva": "dirigere",
    "dirigevamo": "dirigere",
    "dirigevan": "dirigere",
    "dirigevano": "dirigere",
    "dirigevate": "dirigere",
    "dirigevi": "dirigere",
    "dirigevo": "dirigere",
    "dirigi": "dirigere",
    "dirigiamo": "dirigere",
    "dirigiate": "dirigere",
    "dirigibili": "dirigibile",
    "dirigismi": "dirigismo",
    "dirigiste": "dirigista",
    "dirigisti": "dirigista",
    "dirigistica": "dirigistico",
    "dirigistiche": "dirigistico",
    "dirigistici": "dirigistico",
    "dirigo": "dirigere",
    "dirigon": "dirigere",
    "dirigono": "dirigere",
    "dirima": "dirimere",
    "diriman": "dirimere",
    "dirimano": "dirimere",
    "dirime": "dirimere",
    "dirimei": "dirimere",
    "dirimemmo": "dirimere",
    "dirimendo": "dirimere",
    "dirimente": "dirimere",
    "dirimenti": "dirimere",
    "dirimer": "dirimere",
    "dirimerai": "dirimere",
    "dirimeran": "dirimere",
    "dirimeranno": "dirimere",
    "dirimerebbe": "dirimere",
    "dirimerebber": "dirimere",
    "dirimerebbero": "dirimere",
    "dirimerei": "dirimere",
    "dirimeremmo": "dirimere",
    "dirimeremo": "dirimere",
    "dirimereste": "dirimere",
    "dirimeresti": "dirimere",
    "dirimerete": "dirimere",
    "dirimeron": "dirimere",
    "dirimerono": "dirimere",
    "dirimerà": "dirimere",
    "dirimerò": "dirimere",
    "dirimesse": "dirimere",
    "dirimesser": "dirimere",
    "dirimessero": "dirimere",
    "dirimessi": "dirimere",
    "dirimessimo": "dirimere",
    "dirimeste": "dirimere",
    "dirimesti": "dirimere",
    "dirimete": "dirimere",
    "dirimeva": "dirimere",
    "dirimevamo": "dirimere",
    "dirimevan": "dirimere",
    "dirimevano": "dirimere",
    "dirimevate": "dirimere",
    "dirimevi": "dirimere",
    "dirimevo": "dirimere",
    "dirimi": "dirimere",
    "dirimiamo": "dirimere",
    "dirimiate": "dirimere",
    "dirimibili": "dirimibile",
    "dirimo": "dirimere",
    "dirimon": "dirimere",
    "dirimono": "dirimere",
    "dirimpetta": "dirimpetto",
    "dirimpettai": "dirimpettaio",
    "dirimpettaie": "dirimpettaia",
    "dirimpette": "dirimpetto",
    "dirimpetti": "dirimpetto",
    "dirimuta": "dirimere",
    "dirimute": "dirimere",
    "dirimuti": "dirimere",
    "dirimuto": "dirimere",
    "dirimè": "dirimere",
    "diritta": "diritto",
    "dirittacci": "dirittaccio",
    "diritte": "diritto",
    "diritti": "diritto",
    "diritti-doveri": "diritto-dovere",
    "diritti-tv": "diritto-tv",
    "dirittoni": "dirittone",
    "dirittti": "dirittto",
    "diritture": "dirittura",
    "dirocca": "diroccare",
    "diroccai": "diroccare",
    "diroccammo": "diroccare",
    "diroccan": "diroccare",
    "diroccando": "diroccare",
    "diroccano": "diroccare",
    "diroccante": "diroccare",
    "diroccanti": "diroccare",
    "diroccar": "diroccare",
    "diroccaron": "diroccare",
    "diroccarono": "diroccare",
    "diroccasse": "diroccare",
    "diroccasser": "diroccare",
    "diroccassero": "diroccare",
    "diroccassi": "diroccare",
    "diroccassimo": "diroccare",
    "diroccaste": "diroccare",
    "diroccasti": "diroccare",
    "diroccata": "diroccato",
    "diroccate": "diroccato",
    "diroccati": "diroccato",
    "diroccato": "diroccare",
    "diroccava": "diroccare",
    "diroccavamo": "diroccare",
    "diroccavan": "diroccare",
    "diroccavano": "diroccare",
    "diroccavate": "diroccare",
    "diroccavi": "diroccare",
    "diroccavo": "diroccare",
    "diroccherai": "diroccare",
    "diroccheran": "diroccare",
    "diroccheranno": "diroccare",
    "diroccherebbe": "diroccare",
    "diroccherebber": "diroccare",
    "diroccherebbero": "diroccare",
    "diroccherei": "diroccare",
    "diroccheremmo": "diroccare",
    "diroccheremo": "diroccare",
    "dirocchereste": "diroccare",
    "diroccheresti": "diroccare",
    "diroccherete": "diroccare",
    "diroccherà": "diroccare",
    "diroccherò": "diroccare",
    "dirocchi": "diroccare",
    "dirocchiamo": "diroccare",
    "dirocchiate": "diroccare",
    "dirocchin": "diroccare",
    "dirocchino": "diroccare",
    "dirocco": "diroccare",
    "diroccò": "diroccare",
    "dirompa": "dirompere",
    "dirompan": "dirompere",
    "dirompano": "dirompere",
    "dirompe": "dirompere",
    "dirompemmo": "dirompere",
    "dirompendo": "dirompere",
    "dirompente": "dirompere",
    "dirompenti": "dirompere",
    "diromper": "dirompere",
    "diromperai": "dirompere",
    "diromperan": "dirompere",
    "diromperanno": "dirompere",
    "diromperebbe": "dirompere",
    "diromperebber": "dirompere",
    "diromperebbero": "dirompere",
    "diromperei": "dirompere",
    "diromperemmo": "dirompere",
    "diromperemo": "dirompere",
    "dirompereste": "dirompere",
    "diromperesti": "dirompere",
    "diromperete": "dirompere",
    "diromperà": "dirompere",
    "diromperò": "dirompere",
    "dirompesse": "dirompere",
    "dirompesser": "dirompere",
    "dirompessero": "dirompere",
    "dirompessi": "dirompere",
    "dirompessimo": "dirompere",
    "dirompeste": "dirompere",
    "dirompesti": "dirompere",
    "dirompete": "dirompere",
    "dirompeva": "dirompere",
    "dirompevamo": "dirompere",
    "dirompevan": "dirompere",
    "dirompevano": "dirompere",
    "dirompevate": "dirompere",
    "dirompevi": "dirompere",
    "dirompevo": "dirompere",
    "dirompi": "dirompere",
    "dirompiamo": "dirompere",
    "dirompiate": "dirompere",
    "dirompo": "dirompere",
    "dirompon": "dirompere",
    "dirompono": "dirompere",
    "dirotta": "dirotto",
    "dirottai": "dirottare",
    "dirottamenti": "dirottamento",
    "dirottammo": "dirottare",
    "dirottan": "dirottare",
    "dirottando": "dirottare",
    "dirottano": "dirottare",
    "dirottante": "dirottare",
    "dirottanti": "dirottare",
    "dirottar": "dirottare",
    "dirottaron": "dirottare",
    "dirottarono": "dirottare",
    "dirottasse": "dirottare",
    "dirottasser": "dirottare",
    "dirottassero": "dirottare",
    "dirottassi": "dirottare",
    "dirottassimo": "dirottare",
    "dirottaste": "dirottare",
    "dirottasti": "dirottare",
    "dirottata": "dirottare",
    "dirottate": "dirottare",
    "dirottati": "dirottare",
    "dirottato": "dirottare",
    "dirottatori": "dirottatore",
    "dirottava": "dirottare",
    "dirottavamo": "dirottare",
    "dirottavan": "dirottare",
    "dirottavano": "dirottare",
    "dirottavate": "dirottare",
    "dirottavi": "dirottare",
    "dirottavo": "dirottare",
    "dirotte": "dirotto",
    "dirotterai": "dirottare",
    "dirotteran": "dirottare",
    "dirotteranno": "dirottare",
    "dirotterebbe": "dirottare",
    "dirotterebber": "dirottare",
    "dirotterebbero": "dirottare",
    "dirotterei": "dirottare",
    "dirotteremmo": "dirottare",
    "dirotteremo": "dirottare",
    "dirottereste": "dirottare",
    "dirotteresti": "dirottare",
    "dirotterete": "dirottare",
    "dirotterà": "dirottare",
    "dirotterò": "dirottare",
    "dirotti": "dirotto",
    "dirottiamo": "dirottare",
    "dirottiate": "dirottare",
    "dirottin": "dirottare",
    "dirottino": "dirottare",
    "dirotto": "dirottare",
    "dirottò": "dirottare",
    "dirozza": "dirozzare",
    "dirozzai": "dirozzare",
    "dirozzammo": "dirozzare",
    "dirozzan": "dirozzare",
    "dirozzando": "dirozzare",
    "dirozzano": "dirozzare",
    "dirozzante": "dirozzare",
    "dirozzanti": "dirozzare",
    "dirozzar": "dirozzare",
    "dirozzaron": "dirozzare",
    "dirozzarono": "dirozzare",
    "dirozzasse": "dirozzare",
    "dirozzasser": "dirozzare",
    "dirozzassero": "dirozzare",
    "dirozzassi": "dirozzare",
    "dirozzassimo": "dirozzare",
    "dirozzaste": "dirozzare",
    "dirozzasti": "dirozzare",
    "dirozzata": "dirozzare",
    "dirozzate": "dirozzare",
    "dirozzati": "dirozzare",
    "dirozzato": "dirozzare",
    "dirozzava": "dirozzare",
    "dirozzavamo": "dirozzare",
    "dirozzavan": "dirozzare",
    "dirozzavano": "dirozzare",
    "dirozzavate": "dirozzare",
    "dirozzavi": "dirozzare",
    "dirozzavo": "dirozzare",
    "dirozzerai": "dirozzare",
    "dirozzeran": "dirozzare",
    "dirozzeranno": "dirozzare",
    "dirozzerebbe": "dirozzare",
    "dirozzerebber": "dirozzare",
    "dirozzerebbero": "dirozzare",
    "dirozzerei": "dirozzare",
    "dirozzeremmo": "dirozzare",
    "dirozzeremo": "dirozzare",
    "dirozzereste": "dirozzare",
    "dirozzeresti": "dirozzare",
    "dirozzerete": "dirozzare",
    "dirozzerà": "dirozzare",
    "dirozzerò": "dirozzare",
    "dirozzi": "dirozzare",
    "dirozziamo": "dirozzare",
    "dirozziate": "dirozzare",
    "dirozzin": "dirozzare",
    "dirozzino": "dirozzare",
    "dirozzo": "dirozzare",
    "dirozzò": "dirozzare",
    "dirupa": "dirupare",
    "dirupai": "dirupare",
    "dirupammo": "dirupare",
    "dirupan": "dirupare",
    "dirupando": "dirupare",
    "dirupano": "dirupare",
    "dirupante": "dirupare",
    "dirupanti": "dirupare",
    "dirupar": "dirupare",
    "diruparon": "dirupare",
    "diruparono": "dirupare",
    "dirupasse": "dirupare",
    "dirupasser": "dirupare",
    "dirupassero": "dirupare",
    "dirupassi": "dirupare",
    "dirupassimo": "dirupare",
    "dirupaste": "dirupare",
    "dirupasti": "dirupare",
    "dirupata": "dirupare",
    "dirupate": "dirupare",
    "dirupati": "dirupare",
    "dirupato": "dirupare",
    "dirupava": "dirupare",
    "dirupavamo": "dirupare",
    "dirupavan": "dirupare",
    "dirupavano": "dirupare",
    "dirupavate": "dirupare",
    "dirupavi": "dirupare",
    "dirupavo": "dirupare",
    "diruperai": "dirupare",
    "diruperan": "dirupare",
    "diruperanno": "dirupare",
    "diruperebbe": "dirupare",
    "diruperebber": "dirupare",
    "diruperebbero": "dirupare",
    "diruperei": "dirupare",
    "diruperemmo": "dirupare",
    "diruperemo": "dirupare",
    "dirupereste": "dirupare",
    "diruperesti": "dirupare",
    "diruperete": "dirupare",
    "diruperà": "dirupare",
    "diruperò": "dirupare",
    "dirupi": "dirupo",
    "dirupiamo": "dirupare",
    "dirupiate": "dirupare",
    "dirupin": "dirupare",
    "dirupino": "dirupare",
    "dirupo": "dirupare",
    "diruppe": "dirompere",
    "dirupper": "dirompere",
    "diruppero": "dirompere",
    "diruppi": "dirompere",
    "dirupò": "dirupare",
    "dirà": "dire",
    "dirò": "dire",
    "disabili": "disabile",
    "disabitata": "disabitato",
    "disabitate": "disabitato",
    "disabitati": "disabitato",
    "disabitua": "disabituare",
    "disabituai": "disabituare",
    "disabituammo": "disabituare",
    "disabituan": "disabituare",
    "disabituando": "disabituare",
    "disabituano": "disabituare",
    "disabituante": "disabituare",
    "disabituanti": "disabituare",
    "disabituar": "disabituare",
    "disabituaron": "disabituare",
    "disabituarono": "disabituare",
    "disabituasse": "disabituare",
    "disabituasser": "disabituare",
    "disabituassero": "disabituare",
    "disabituassi": "disabituare",
    "disabituassimo": "disabituare",
    "disabituaste": "disabituare",
    "disabituasti": "disabituare",
    "disabituata": "disabituato",
    "disabituate": "disabituato",
    "disabituati": "disabituato",
    "disabituato": "disabituare",
    "disabituava": "disabituare",
    "disabituavamo": "disabituare",
    "disabituavan": "disabituare",
    "disabituavano": "disabituare",
    "disabituavate": "disabituare",
    "disabituavi": "disabituare",
    "disabituavo": "disabituare",
    "disabituerai": "disabituare",
    "disabitueran": "disabituare",
    "disabitueranno": "disabituare",
    "disabituerebbe": "disabituare",
    "disabituerebber": "disabituare",
    "disabituerebbero": "disabituare",
    "disabituerei": "disabituare",
    "disabitueremmo": "disabituare",
    "disabitueremo": "disabituare",
    "disabituereste": "disabituare",
    "disabitueresti": "disabituare",
    "disabituerete": "disabituare",
    "disabituerà": "disabituare",
    "disabituerò": "disabituare",
    "disabitui": "disabituare",
    "disabituiamo": "disabituare",
    "disabituiate": "disabituare",
    "disabituin": "disabituare",
    "disabituino": "disabituare",
    "disabituo": "disabituare",
    "disabituò": "disabituare",
    "disaccoppianti": "disaccoppiante",
    "disaccordi": "disaccordo",
    "disadattata": "disadattato",
    "disadattate": "disadattato",
    "disadattati": "disadattato",
    "disadorna": "disadorno",
    "disadorne": "disadorno",
    "disadorni": "disadorno",
    "disaffeziona": "disaffezionare",
    "disaffezionai": "disaffezionare",
    "disaffezionammo": "disaffezionare",
    "disaffezionan": "disaffezionare",
    "disaffezionando": "disaffezionare",
    "disaffezionano": "disaffezionare",
    "disaffezionante": "disaffezionare",
    "disaffezionanti": "disaffezionare",
    "disaffezionar": "disaffezionare",
    "disaffezionaron": "disaffezionare",
    "disaffezionarono": "disaffezionare",
    "disaffezionasse": "disaffezionare",
    "disaffezionasser": "disaffezionare",
    "disaffezionassero": "disaffezionare",
    "disaffezionassi": "disaffezionare",
    "disaffezionassimo": "disaffezionare",
    "disaffezionaste": "disaffezionare",
    "disaffezionasti": "disaffezionare",
    "disaffezionata": "disaffezionare",
    "disaffezionate": "disaffezionare",
    "disaffezionati": "disaffezionare",
    "disaffezionato": "disaffezionare",
    "disaffezionava": "disaffezionare",
    "disaffezionavamo": "disaffezionare",
    "disaffezionavan": "disaffezionare",
    "disaffezionavano": "disaffezionare",
    "disaffezionavate": "disaffezionare",
    "disaffezionavi": "disaffezionare",
    "disaffezionavo": "disaffezionare",
    "disaffezionerai": "disaffezionare",
    "disaffezioneran": "disaffezionare",
    "disaffezioneranno": "disaffezionare",
    "disaffezionerebbe": "disaffezionare",
    "disaffezionerebber": "disaffezionare",
    "disaffezionerebbero": "disaffezionare",
    "disaffezionerei": "disaffezionare",
    "disaffezioneremmo": "disaffezionare",
    "disaffezioneremo": "disaffezionare",
    "disaffezionereste": "disaffezionare",
    "disaffezioneresti": "disaffezionare",
    "disaffezionerete": "disaffezionare",
    "disaffezionerà": "disaffezionare",
    "disaffezionerò": "disaffezionare",
    "disaffezioni": "disaffezione",
    "disaffezioniamo": "disaffezionare",
    "disaffezioniate": "disaffezionare",
    "disaffezionin": "disaffezionare",
    "disaffezionino": "disaffezionare",
    "disaffeziono": "disaffezionare",
    "disaffezionò": "disaffezionare",
    "disagerai": "disagiare",
    "disageran": "disagiare",
    "disageranno": "disagiare",
    "disagerebbe": "disagiare",
    "disagerebber": "disagiare",
    "disagerebbero": "disagiare",
    "disagerei": "disagiare",
    "disageremmo": "disagiare",
    "disageremo": "disagiare",
    "disagereste": "disagiare",
    "disageresti": "disagiare",
    "disagerete": "disagiare",
    "disagerà": "disagiare",
    "disagerò": "disagiare",
    "disagevoli": "disagevole",
    "disaggrega": "disaggregare",
    "disaggregai": "disaggregare",
    "disaggregammo": "disaggregare",
    "disaggregan": "disaggregare",
    "disaggregando": "disaggregare",
    "disaggregano": "disaggregare",
    "disaggregante": "disaggregare",
    "disaggreganti": "disaggregare",
    "disaggregar": "disaggregare",
    "disaggregaron": "disaggregare",
    "disaggregarono": "disaggregare",
    "disaggregasse": "disaggregare",
    "disaggregasser": "disaggregare",
    "disaggregassero": "disaggregare",
    "disaggregassi": "disaggregare",
    "disaggregassimo": "disaggregare",
    "disaggregaste": "disaggregare",
    "disaggregasti": "disaggregare",
    "disaggregata": "disaggregare",
    "disaggregate": "disaggregare",
    "disaggregati": "disaggregare",
    "disaggregato": "disaggregare",
    "disaggregava": "disaggregare",
    "disaggregavamo": "disaggregare",
    "disaggregavan": "disaggregare",
    "disaggregavano": "disaggregare",
    "disaggregavate": "disaggregare",
    "disaggregavi": "disaggregare",
    "disaggregavo": "disaggregare",
    "disaggregherai": "disaggregare",
    "disaggregheran": "disaggregare",
    "disaggregheranno": "disaggregare",
    "disaggregherebbe": "disaggregare",
    "disaggregherebber": "disaggregare",
    "disaggregherebbero": "disaggregare",
    "disaggregherei": "disaggregare",
    "disaggregheremmo": "disaggregare",
    "disaggregheremo": "disaggregare",
    "disaggreghereste": "disaggregare",
    "disaggregheresti": "disaggregare",
    "disaggregherete": "disaggregare",
    "disaggregherà": "disaggregare",
    "disaggregherò": "disaggregare",
    "disaggreghi": "disaggregare",
    "disaggreghiamo": "disaggregare",
    "disaggreghiate": "disaggregare",
    "disaggreghin": "disaggregare",
    "disaggreghino": "disaggregare",
    "disaggrego": "disaggregare",
    "disaggregò": "disaggregare",
    "disagi": "disagio",
    "disagia": "disagiare",
    "disagiai": "disagiare",
    "disagiammo": "disagiare",
    "disagiamo": "disagiare",
    "disagian": "disagiare",
    "disagiando": "disagiare",
    "disagiano": "disagiare",
    "disagiante": "disagiare",
    "disagianti": "disagiare",
    "disagiar": "disagiare",
    "disagiaron": "disagiare",
    "disagiarono": "disagiare",
    "disagiasse": "disagiare",
    "disagiasser": "disagiare",
    "disagiassero": "disagiare",
    "disagiassi": "disagiare",
    "disagiassimo": "disagiare",
    "disagiaste": "disagiare",
    "disagiasti": "disagiare",
    "disagiata": "disagiato",
    "disagiate": "disagiato",
    "disagiati": "disagiato",
    "disagiato": "disagiare",
    "disagiava": "disagiare",
    "disagiavamo": "disagiare",
    "disagiavan": "disagiare",
    "disagiavano": "disagiare",
    "disagiavate": "disagiare",
    "disagiavi": "disagiare",
    "disagiavo": "disagiare",
    "disagin": "disagiare",
    "disagino": "disagiare",
    "disagio": "disagiare",
    "disagiò": "disagiare",
    "disalbera": "disalberare",
    "disalberai": "disalberare",
    "disalberammo": "disalberare",
    "disalberan": "disalberare",
    "disalberando": "disalberare",
    "disalberano": "disalberare",
    "disalberante": "disalberare",
    "disalberanti": "disalberare",
    "disalberar": "disalberare",
    "disalberaron": "disalberare",
    "disalberarono": "disalberare",
    "disalberasse": "disalberare",
    "disalberasser": "disalberare",
    "disalberassero": "disalberare",
    "disalberassi": "disalberare",
    "disalberassimo": "disalberare",
    "disalberaste": "disalberare",
    "disalberasti": "disalberare",
    "disalberata": "disalberare",
    "disalberate": "disalberare",
    "disalberati": "disalberare",
    "disalberato": "disalberare",
    "disalberava": "disalberare",
    "disalberavamo": "disalberare",
    "disalberavan": "disalberare",
    "disalberavano": "disalberare",
    "disalberavate": "disalberare",
    "disalberavi": "disalberare",
    "disalberavo": "disalberare",
    "disalbererai": "disalberare",
    "disalbereran": "disalberare",
    "disalbereranno": "disalberare",
    "disalbererebbe": "disalberare",
    "disalbererebber": "disalberare",
    "disalbererebbero": "disalberare",
    "disalbererei": "disalberare",
    "disalbereremmo": "disalberare",
    "disalbereremo": "disalberare",
    "disalberereste": "disalberare",
    "disalbereresti": "disalberare",
    "disalbererete": "disalberare",
    "disalbererà": "disalberare",
    "disalbererò": "disalberare",
    "disalberi": "disalberare",
    "disalberiamo": "disalberare",
    "disalberiate": "disalberare",
    "disalberin": "disalberare",
    "disalberino": "disalberare",
    "disalbero": "disalberare",
    "disalberò": "disalberare",
    "disamina": "disaminare",
    "disaminai": "disaminare",
    "disaminammo": "disaminare",
    "disaminan": "disaminare",
    "disaminando": "disaminare",
    "disaminano": "disaminare",
    "disaminante": "disaminare",
    "disaminanti": "disaminare",
    "disaminar": "disaminare",
    "disaminaron": "disaminare",
    "disaminarono": "disaminare",
    "disaminasse": "disaminare",
    "disaminasser": "disaminare",
    "disaminassero": "disaminare",
    "disaminassi": "disaminare",
    "disaminassimo": "disaminare",
    "disaminaste": "disaminare",
    "disaminasti": "disaminare",
    "disaminata": "disaminare",
    "disaminate": "disaminare",
    "disaminati": "disaminare",
    "disaminato": "disaminare",
    "disaminava": "disaminare",
    "disaminavamo": "disaminare",
    "disaminavan": "disaminare",
    "disaminavano": "disaminare",
    "disaminavate": "disaminare",
    "disaminavi": "disaminare",
    "disaminavo": "disaminare",
    "disamine": "disamina",
    "disaminerai": "disaminare",
    "disamineran": "disaminare",
    "disamineranno": "disaminare",
    "disaminerebbe": "disaminare",
    "disaminerebber": "disaminare",
    "disaminerebbero": "disaminare",
    "disaminerei": "disaminare",
    "disamineremmo": "disaminare",
    "disamineremo": "disaminare",
    "disaminereste": "disaminare",
    "disamineresti": "disaminare",
    "disaminerete": "disaminare",
    "disaminerà": "disaminare",
    "disaminerò": "disaminare",
    "disamini": "disaminare",
    "disaminiamo": "disaminare",
    "disaminiate": "disaminare",
    "disaminin": "disaminare",
    "disaminino": "disaminare",
    "disamino": "disaminare",
    "disaminò": "disaminare",
    "disamori": "disamore",
    "disapplica": "disapplicare",
    "disapplicai": "disapplicare",
    "disapplicammo": "disapplicare",
    "disapplican": "disapplicare",
    "disapplicando": "disapplicare",
    "disapplicano": "disapplicare",
    "disapplicante": "disapplicare",
    "disapplicanti": "disapplicare",
    "disapplicar": "disapplicare",
    "disapplicaron": "disapplicare",
    "disapplicarono": "disapplicare",
    "disapplicasse": "disapplicare",
    "disapplicasser": "disapplicare",
    "disapplicassero": "disapplicare",
    "disapplicassi": "disapplicare",
    "disapplicassimo": "disapplicare",
    "disapplicaste": "disapplicare",
    "disapplicasti": "disapplicare",
    "disapplicata": "disapplicare",
    "disapplicate": "disapplicare",
    "disapplicati": "disapplicare",
    "disapplicato": "disapplicare",
    "disapplicava": "disapplicare",
    "disapplicavamo": "disapplicare",
    "disapplicavan": "disapplicare",
    "disapplicavano": "disapplicare",
    "disapplicavate": "disapplicare",
    "disapplicavi": "disapplicare",
    "disapplicavo": "disapplicare",
    "disapplicherai": "disapplicare",
    "disapplicheran": "disapplicare",
    "disapplicheranno": "disapplicare",
    "disapplicherebbe": "disapplicare",
    "disapplicherebber": "disapplicare",
    "disapplicherebbero": "disapplicare",
    "disapplicherei": "disapplicare",
    "disapplicheremmo": "disapplicare",
    "disapplicheremo": "disapplicare",
    "disapplichereste": "disapplicare",
    "disapplicheresti": "disapplicare",
    "disapplicherete": "disapplicare",
    "disapplicherà": "disapplicare",
    "disapplicherò": "disapplicare",
    "disapplichi": "disapplicare",
    "disapplichiamo": "disapplicare",
    "disapplichiate": "disapplicare",
    "disapplichin": "disapplicare",
    "disapplichino": "disapplicare",
    "disapplico": "disapplicare",
    "disapplicò": "disapplicare",
    "disapprova": "disapprovare",
    "disapprovai": "disapprovare",
    "disapprovammo": "disapprovare",
    "disapprovan": "disapprovare",
    "disapprovando": "disapprovare",
    "disapprovano": "disapprovare",
    "disapprovante": "disapprovare",
    "disapprovanti": "disapprovare",
    "disapprovar": "disapprovare",
    "disapprovaron": "disapprovare",
    "disapprovarono": "disapprovare",
    "disapprovasse": "disapprovare",
    "disapprovasser": "disapprovare",
    "disapprovassero": "disapprovare",
    "disapprovassi": "disapprovare",
    "disapprovassimo": "disapprovare",
    "disapprovaste": "disapprovare",
    "disapprovasti": "disapprovare",
    "disapprovata": "disapprovare",
    "disapprovate": "disapprovare",
    "disapprovati": "disapprovare",
    "disapprovato": "disapprovare",
    "disapprovava": "disapprovare",
    "disapprovavamo": "disapprovare",
    "disapprovavan": "disapprovare",
    "disapprovavano": "disapprovare",
    "disapprovavate": "disapprovare",
    "disapprovavi": "disapprovare",
    "disapprovavo": "disapprovare",
    "disapprovazioni": "disapprovazione",
    "disapproverai": "disapprovare",
    "disapproveran": "disapprovare",
    "disapproveranno": "disapprovare",
    "disapproverebbe": "disapprovare",
    "disapproverebber": "disapprovare",
    "disapproverebbero": "disapprovare",
    "disapproverei": "disapprovare",
    "disapproveremmo": "disapprovare",
    "disapproveremo": "disapprovare",
    "disapprovereste": "disapprovare",
    "disapproveresti": "disapprovare",
    "disapproverete": "disapprovare",
    "disapproverà": "disapprovare",
    "disapproverò": "disapprovare",
    "disapprovi": "disapprovare",
    "disapproviamo": "disapprovare",
    "disapproviate": "disapprovare",
    "disapprovin": "disapprovare",
    "disapprovino": "disapprovare",
    "disapprovo": "disapprovare",
    "disapprovò": "disapprovare",
    "disappunti": "disappunto",
    "disarciona": "disarcionare",
    "disarcionai": "disarcionare",
    "disarcionammo": "disarcionare",
    "disarcionan": "disarcionare",
    "disarcionando": "disarcionare",
    "disarcionano": "disarcionare",
    "disarcionante": "disarcionare",
    "disarcionanti": "disarcionare",
    "disarcionar": "disarcionare",
    "disarcionaron": "disarcionare",
    "disarcionarono": "disarcionare",
    "disarcionasse": "disarcionare",
    "disarcionasser": "disarcionare",
    "disarcionassero": "disarcionare",
    "disarcionassi": "disarcionare",
    "disarcionassimo": "disarcionare",
    "disarcionaste": "disarcionare",
    "disarcionasti": "disarcionare",
    "disarcionata": "disarcionare",
    "disarcionate": "disarcionare",
    "disarcionati": "disarcionare",
    "disarcionato": "disarcionare",
    "disarcionava": "disarcionare",
    "disarcionavamo": "disarcionare",
    "disarcionavan": "disarcionare",
    "disarcionavano": "disarcionare",
    "disarcionavate": "disarcionare",
    "disarcionavi": "disarcionare",
    "disarcionavo": "disarcionare",
    "disarcionerai": "disarcionare",
    "disarcioneran": "disarcionare",
    "disarcioneranno": "disarcionare",
    "disarcionerebbe": "disarcionare",
    "disarcionerebber": "disarcionare",
    "disarcionerebbero": "disarcionare",
    "disarcionerei": "disarcionare",
    "disarcioneremmo": "disarcionare",
    "disarcioneremo": "disarcionare",
    "disarcionereste": "disarcionare",
    "disarcioneresti": "disarcionare",
    "disarcionerete": "disarcionare",
    "disarcionerà": "disarcionare",
    "disarcionerò": "disarcionare",
    "disarcioni": "disarcionare",
    "disarcioniamo": "disarcionare",
    "disarcioniate": "disarcionare",
    "disarcionin": "disarcionare",
    "disarcionino": "disarcionare",
    "disarciono": "disarcionare",
    "disarcionò": "disarcionare",
    "disarma": "disarmare",
    "disarmai": "disarmare",
    "disarmammo": "disarmare",
    "disarman": "disarmare",
    "disarmando": "disarmare",
    "disarmano": "disarmare",
    "disarmante": "disarmare",
    "disarmanti": "disarmare",
    "disarmar": "disarmare",
    "disarmaron": "disarmare",
    "disarmarono": "disarmare",
    "disarmasse": "disarmare",
    "disarmasser": "disarmare",
    "disarmassero": "disarmare",
    "disarmassi": "disarmare",
    "disarmassimo": "disarmare",
    "disarmaste": "disarmare",
    "disarmasti": "disarmare",
    "disarmata": "disarmato",
    "disarmate": "disarmato",
    "disarmati": "disarmato",
    "disarmato": "disarmare",
    "disarmava": "disarmare",
    "disarmavamo": "disarmare",
    "disarmavan": "disarmare",
    "disarmavano": "disarmare",
    "disarmavate": "disarmare",
    "disarmavi": "disarmare",
    "disarmavo": "disarmare",
    "disarmerai": "disarmare",
    "disarmeran": "disarmare",
    "disarmeranno": "disarmare",
    "disarmerebbe": "disarmare",
    "disarmerebber": "disarmare",
    "disarmerebbero": "disarmare",
    "disarmerei": "disarmare",
    "disarmeremmo": "disarmare",
    "disarmeremo": "disarmare",
    "disarmereste": "disarmare",
    "disarmeresti": "disarmare",
    "disarmerete": "disarmare",
    "disarmerà": "disarmare",
    "disarmerò": "disarmare",
    "disarmi": "disarmo",
    "disarmiamo": "disarmare",
    "disarmiate": "disarmare",
    "disarmin": "disarmare",
    "disarmino": "disarmare",
    "disarmo": "disarmare",
    "disarmonica": "disarmonico",
    "disarmoniche": "disarmonico",
    "disarmonici": "disarmonico",
    "disarmonie": "disarmonia",
    "disarmò": "disarmare",
    "disarticola": "disarticolare",
    "disarticolai": "disarticolare",
    "disarticolammo": "disarticolare",
    "disarticolan": "disarticolare",
    "disarticolando": "disarticolare",
    "disarticolano": "disarticolare",
    "disarticolante": "disarticolare",
    "disarticolanti": "disarticolare",
    "disarticolar": "disarticolare",
    "disarticolaron": "disarticolare",
    "disarticolarono": "disarticolare",
    "disarticolasse": "disarticolare",
    "disarticolasser": "disarticolare",
    "disarticolassero": "disarticolare",
    "disarticolassi": "disarticolare",
    "disarticolassimo": "disarticolare",
    "disarticolaste": "disarticolare",
    "disarticolasti": "disarticolare",
    "disarticolata": "disarticolare",
    "disarticolate": "disarticolare",
    "disarticolati": "disarticolare",
    "disarticolato": "disarticolare",
    "disarticolava": "disarticolare",
    "disarticolavamo": "disarticolare",
    "disarticolavan": "disarticolare",
    "disarticolavano": "disarticolare",
    "disarticolavate": "disarticolare",
    "disarticolavi": "disarticolare",
    "disarticolavo": "disarticolare",
    "disarticolazioni": "disarticolazione",
    "disarticolerai": "disarticolare",
    "disarticoleran": "disarticolare",
    "disarticoleranno": "disarticolare",
    "disarticolerebbe": "disarticolare",
    "disarticolerebber": "disarticolare",
    "disarticolerebbero": "disarticolare",
    "disarticolerei": "disarticolare",
    "disarticoleremmo": "disarticolare",
    "disarticoleremo": "disarticolare",
    "disarticolereste": "disarticolare",
    "disarticoleresti": "disarticolare",
    "disarticolerete": "disarticolare",
    "disarticolerà": "disarticolare",
    "disarticolerò": "disarticolare",
    "disarticoli": "disarticolare",
    "disarticoliamo": "disarticolare",
    "disarticoliate": "disarticolare",
    "disarticolin": "disarticolare",
    "disarticolino": "disarticolare",
    "disarticolo": "disarticolare",
    "disarticolò": "disarticolare",
    "disassa": "disassare",
    "disassai": "disassare",
    "disassammo": "disassare",
    "disassan": "disassare",
    "disassando": "disassare",
    "disassano": "disassare",
    "disassante": "disassare",
    "disassanti": "disassare",
    "disassar": "disassare",
    "disassaron": "disassare",
    "disassarono": "disassare",
    "disassasse": "disassare",
    "disassasser": "disassare",
    "disassassero": "disassare",
    "disassassi": "disassare",
    "disassassimo": "disassare",
    "disassaste": "disassare",
    "disassasti": "disassare",
    "disassata": "disassare",
    "disassate": "disassare",
    "disassati": "disassare",
    "disassato": "disassare",
    "disassava": "disassare",
    "disassavamo": "disassare",
    "disassavan": "disassare",
    "disassavano": "disassare",
    "disassavate": "disassare",
    "disassavi": "disassare",
    "disassavo": "disassare",
    "disasserai": "disassare",
    "disasseran": "disassare",
    "disasseranno": "disassare",
    "disasserebbe": "disassare",
    "disasserebber": "disassare",
    "disasserebbero": "disassare",
    "disasserei": "disassare",
    "disasseremmo": "disassare",
    "disasseremo": "disassare",
    "disassereste": "disassare",
    "disasseresti": "disassare",
    "disasserete": "disassare",
    "disasserà": "disassare",
    "disasserò": "disassare",
    "disassi": "disassare",
    "disassiamo": "disassare",
    "disassiate": "disassare",
    "disassin": "disassare",
    "disassino": "disassare",
    "disasso": "disassare",
    "disassò": "disassare",
    "disastra": "disastrare",
    "disastrai": "disastrare",
    "disastrammo": "disastrare",
    "disastran": "disastrare",
    "disastrando": "disastrare",
    "disastrano": "disastrare",
    "disastrante": "disastrare",
    "disastranti": "disastrare",
    "disastrar": "disastrare",
    "disastraron": "disastrare",
    "disastrarono": "disastrare",
    "disastrasse": "disastrare",
    "disastrasser": "disastrare",
    "disastrassero": "disastrare",
    "disastrassi": "disastrare",
    "disastrassimo": "disastrare",
    "disastraste": "disastrare",
    "disastrasti": "disastrare",
    "disastrata": "disastrato",
    "disastrate": "disastrato",
    "disastrati": "disastrato",
    "disastrato": "disastrare",
    "disastrava": "disastrare",
    "disastravamo": "disastrare",
    "disastravan": "disastrare",
    "disastravano": "disastrare",
    "disastravate": "disastrare",
    "disastravi": "disastrare",
    "disastravo": "disastrare",
    "disastrerai": "disastrare",
    "disastreran": "disastrare",
    "disastreranno": "disastrare",
    "disastrerebbe": "disastrare",
    "disastrerebber": "disastrare",
    "disastrerebbero": "disastrare",
    "disastrerei": "disastrare",
    "disastreremmo": "disastrare",
    "disastreremo": "disastrare",
    "disastrereste": "disastrare",
    "disastreresti": "disastrare",
    "disastrerete": "disastrare",
    "disastrerà": "disastrare",
    "disastrerò": "disastrare",
    "disastri": "disastro",
    "disastriamo": "disastrare",
    "disastriate": "disastrare",
    "disastrin": "disastrare",
    "disastrino": "disastrare",
    "disastro": "disastrare",
    "disastrosa": "disastroso",
    "disastrose": "disastroso",
    "disastrosi": "disastroso",
    "disastrò": "disastrare",
    "disattenda": "disattendere",
    "disattendan": "disattendere",
    "disattendano": "disattendere",
    "disattende": "disattendere",
    "disattendemmo": "disattendere",
    "disattendendo": "disattendere",
    "disattendente": "disattendere",
    "disattendenti": "disattendere",
    "disattender": "disattendere",
    "disattenderai": "disattendere",
    "disattenderan": "disattendere",
    "disattenderanno": "disattendere",
    "disattenderebbe": "disattendere",
    "disattenderebber": "disattendere",
    "disattenderebbero": "disattendere",
    "disattenderei": "disattendere",
    "disattenderemmo": "disattendere",
    "disattenderemo": "disattendere",
    "disattendereste": "disattendere",
    "disattenderesti": "disattendere",
    "disattenderete": "disattendere",
    "disattenderà": "disattendere",
    "disattenderò": "disattendere",
    "disattendesse": "disattendere",
    "disattendesser": "disattendere",
    "disattendessero": "disattendere",
    "disattendessi": "disattendere",
    "disattendessimo": "disattendere",
    "disattendeste": "disattendere",
    "disattendesti": "disattendere",
    "disattendete": "disattendere",
    "disattendeva": "disattendere",
    "disattendevamo": "disattendere",
    "disattendevan": "disattendere",
    "disattendevano": "disattendere",
    "disattendevate": "disattendere",
    "disattendevi": "disattendere",
    "disattendevo": "disattendere",
    "disattendi": "disattendere",
    "disattendiamo": "disattendere",
    "disattendiate": "disattendere",
    "disattendo": "disattendere",
    "disattendon": "disattendere",
    "disattendono": "disattendere",
    "disattenta": "disattento",
    "disattente": "disattento",
    "disattenti": "disattento",
    "disattenzioni": "disattenzione",
    "disattesa": "disattendere",
    "disattese": "disattendere",
    "disatteser": "disattendere",
    "disattesero": "disattendere",
    "disattesi": "disattendere",
    "disatteso": "disattendere",
    "disattesè": "disattendere",
    "disattiva": "disattivare",
    "disattivai": "disattivare",
    "disattivammo": "disattivare",
    "disattivan": "disattivare",
    "disattivando": "disattivare",
    "disattivano": "disattivare",
    "disattivante": "disattivare",
    "disattivanti": "disattivare",
    "disattivar": "disattivare",
    "disattivaron": "disattivare",
    "disattivarono": "disattivare",
    "disattivasse": "disattivare",
    "disattivasser": "disattivare",
    "disattivassero": "disattivare",
    "disattivassi": "disattivare",
    "disattivassimo": "disattivare",
    "disattivaste": "disattivare",
    "disattivasti": "disattivare",
    "disattivata": "disattivare",
    "disattivate": "disattivare",
    "disattivati": "disattivare",
    "disattivato": "disattivare",
    "disattivava": "disattivare",
    "disattivavamo": "disattivare",
    "disattivavan": "disattivare",
    "disattivavano": "disattivare",
    "disattivavate": "disattivare",
    "disattivavi": "disattivare",
    "disattivavo": "disattivare",
    "disattiverai": "disattivare",
    "disattiveran": "disattivare",
    "disattiveranno": "disattivare",
    "disattiverebbe": "disattivare",
    "disattiverebber": "disattivare",
    "disattiverebbero": "disattivare",
    "disattiverei": "disattivare",
    "disattiveremmo": "disattivare",
    "disattiveremo": "disattivare",
    "disattivereste": "disattivare",
    "disattiveresti": "disattivare",
    "disattiverete": "disattivare",
    "disattiverà": "disattivare",
    "disattiverò": "disattivare",
    "disattivi": "disattivare",
    "disattiviamo": "disattivare",
    "disattiviate": "disattivare",
    "disattivin": "disattivare",
    "disattivino": "disattivare",
    "disattivo": "disattivare",
    "disattivò": "disattivare",
    "disattrezza": "disattrezzare",
    "disattrezzai": "disattrezzare",
    "disattrezzammo": "disattrezzare",
    "disattrezzan": "disattrezzare",
    "disattrezzando": "disattrezzare",
    "disattrezzano": "disattrezzare",
    "disattrezzante": "disattrezzare",
    "disattrezzanti": "disattrezzare",
    "disattrezzar": "disattrezzare",
    "disattrezzaron": "disattrezzare",
    "disattrezzarono": "disattrezzare",
    "disattrezzasse": "disattrezzare",
    "disattrezzasser": "disattrezzare",
    "disattrezzassero": "disattrezzare",
    "disattrezzassi": "disattrezzare",
    "disattrezzassimo": "disattrezzare",
    "disattrezzaste": "disattrezzare",
    "disattrezzasti": "disattrezzare",
    "disattrezzata": "disattrezzare",
    "disattrezzate": "disattrezzare",
    "disattrezzati": "disattrezzare",
    "disattrezzato": "disattrezzare",
    "disattrezzava": "disattrezzare",
    "disattrezzavamo": "disattrezzare",
    "disattrezzavan": "disattrezzare",
    "disattrezzavano": "disattrezzare",
    "disattrezzavate": "disattrezzare",
    "disattrezzavi": "disattrezzare",
    "disattrezzavo": "disattrezzare",
    "disattrezzerai": "disattrezzare",
    "disattrezzeran": "disattrezzare",
    "disattrezzeranno": "disattrezzare",
    "disattrezzerebbe": "disattrezzare",
    "disattrezzerebber": "disattrezzare",
    "disattrezzerebbero": "disattrezzare",
    "disattrezzerei": "disattrezzare",
    "disattrezzeremmo": "disattrezzare",
    "disattrezzeremo": "disattrezzare",
    "disattrezzereste": "disattrezzare",
    "disattrezzeresti": "disattrezzare",
    "disattrezzerete": "disattrezzare",
    "disattrezzerà": "disattrezzare",
    "disattrezzerò": "disattrezzare",
    "disattrezzi": "disattrezzare",
    "disattrezziamo": "disattrezzare",
    "disattrezziate": "disattrezzare",
    "disattrezzin": "disattrezzare",
    "disattrezzino": "disattrezzare",
    "disattrezzo": "disattrezzare",
    "disattrezzò": "disattrezzare",
    "disavanzi": "disavanzo",
    "disavventure": "disavventura",
    "disavvezza": "disavvezzare",
    "disavvezzai": "disavvezzare",
    "disavvezzammo": "disavvezzare",
    "disavvezzan": "disavvezzare",
    "disavvezzando": "disavvezzare",
    "disavvezzano": "disavvezzare",
    "disavvezzante": "disavvezzare",
    "disavvezzanti": "disavvezzare",
    "disavvezzar": "disavvezzare",
    "disavvezzaron": "disavvezzare",
    "disavvezzarono": "disavvezzare",
    "disavvezzasse": "disavvezzare",
    "disavvezzasser": "disavvezzare",
    "disavvezzassero": "disavvezzare",
    "disavvezzassi": "disavvezzare",
    "disavvezzassimo": "disavvezzare",
    "disavvezzaste": "disavvezzare",
    "disavvezzasti": "disavvezzare",
    "disavvezzata": "disavvezzare",
    "disavvezzate": "disavvezzare",
    "disavvezzati": "disavvezzare",
    "disavvezzato": "disavvezzare",
    "disavvezzava": "disavvezzare",
    "disavvezzavamo": "disavvezzare",
    "disavvezzavan": "disavvezzare",
    "disavvezzavano": "disavvezzare",
    "disavvezzavate": "disavvezzare",
    "disavvezzavi": "disavvezzare",
    "disavvezzavo": "disavvezzare",
    "disavvezzerai": "disavvezzare",
    "disavvezzeran": "disavvezzare",
    "disavvezzeranno": "disavvezzare",
    "disavvezzerebbe": "disavvezzare",
    "disavvezzerebber": "disavvezzare",
    "disavvezzerebbero": "disavvezzare",
    "disavvezzerei": "disavvezzare",
    "disavvezzeremmo": "disavvezzare",
    "disavvezzeremo": "disavvezzare",
    "disavvezzereste": "disavvezzare",
    "disavvezzeresti": "disavvezzare",
    "disavvezzerete": "disavvezzare",
    "disavvezzerà": "disavvezzare",
    "disavvezzerò": "disavvezzare",
    "disavvezzi": "disavvezzare",
    "disavvezziamo": "disavvezzare",
    "disavvezziate": "disavvezzare",
    "disavvezzin": "disavvezzare",
    "disavvezzino": "disavvezzare",
    "disavvezzo": "disavvezzare",
    "disavvezzò": "disavvezzare",
    "disbosca": "disboscare",
    "disboscai": "disboscare",
    "disboscamenti": "disboscamento",
    "disboscammo": "disboscare",
    "disboscan": "disboscare",
    "disboscando": "disboscare",
    "disboscano": "disboscare",
    "disboscante": "disboscare",
    "disboscanti": "disboscare",
    "disboscar": "disboscare",
    "disboscaron": "disboscare",
    "disboscarono": "disboscare",
    "disboscasse": "disboscare",
    "disboscasser": "disboscare",
    "disboscassero": "disboscare",
    "disboscassi": "disboscare",
    "disboscassimo": "disboscare",
    "disboscaste": "disboscare",
    "disboscasti": "disboscare",
    "disboscata": "disboscare",
    "disboscate": "disboscare",
    "disboscati": "disboscare",
    "disboscato": "disboscare",
    "disboscava": "disboscare",
    "disboscavamo": "disboscare",
    "disboscavan": "disboscare",
    "disboscavano": "disboscare",
    "disboscavate": "disboscare",
    "disboscavi": "disboscare",
    "disboscavo": "disboscare",
    "disboscherai": "disboscare",
    "disboscheran": "disboscare",
    "disboscheranno": "disboscare",
    "disboscherebbe": "disboscare",
    "disboscherebber": "disboscare",
    "disboscherebbero": "disboscare",
    "disboscherei": "disboscare",
    "disboscheremmo": "disboscare",
    "disboscheremo": "disboscare",
    "disboschereste": "disboscare",
    "disboscheresti": "disboscare",
    "disboscherete": "disboscare",
    "disboscherà": "disboscare",
    "disboscherò": "disboscare",
    "disboschi": "disboscare",
    "disboschiamo": "disboscare",
    "disboschiate": "disboscare",
    "disboschin": "disboscare",
    "disboschino": "disboscare",
    "disbosco": "disboscare",
    "disboscò": "disboscare",
    "disbriga": "disbrigare",
    "disbrigai": "disbrigare",
    "disbrigammo": "disbrigare",
    "disbrigan": "disbrigare",
    "disbrigando": "disbrigare",
    "disbrigano": "disbrigare",
    "disbrigante": "disbrigare",
    "disbriganti": "disbrigare",
    "disbrigar": "disbrigare",
    "disbrigaron": "disbrigare",
    "disbrigarono": "disbrigare",
    "disbrigasse": "disbrigare",
    "disbrigasser": "disbrigare",
    "disbrigassero": "disbrigare",
    "disbrigassi": "disbrigare",
    "disbrigassimo": "disbrigare",
    "disbrigaste": "disbrigare",
    "disbrigasti": "disbrigare",
    "disbrigata": "disbrigare",
    "disbrigate": "disbrigare",
    "disbrigati": "disbrigare",
    "disbrigato": "disbrigare",
    "disbrigava": "disbrigare",
    "disbrigavamo": "disbrigare",
    "disbrigavan": "disbrigare",
    "disbrigavano": "disbrigare",
    "disbrigavate": "disbrigare",
    "disbrigavi": "disbrigare",
    "disbrigavo": "disbrigare",
    "disbrigherai": "disbrigare",
    "disbrigheran": "disbrigare",
    "disbrigheranno": "disbrigare",
    "disbrigherebbe": "disbrigare",
    "disbrigherebber": "disbrigare",
    "disbrigherebbero": "disbrigare",
    "disbrigherei": "disbrigare",
    "disbrigheremmo": "disbrigare",
    "disbrigheremo": "disbrigare",
    "disbrighereste": "disbrigare",
    "disbrigheresti": "disbrigare",
    "disbrigherete": "disbrigare",
    "disbrigherà": "disbrigare",
    "disbrigherò": "disbrigare",
    "disbrighi": "disbrigo",
    "disbrighiamo": "disbrigare",
    "disbrighiate": "disbrigare",
    "disbrighin": "disbrigare",
    "disbrighino": "disbrigare",
    "disbrigo": "disbrigare",
    "disbrigò": "disbrigare",
    "discaccerai": "discacciare",
    "discacceran": "discacciare",
    "discacceranno": "discacciare",
    "discaccerebbe": "discacciare",
    "discaccerebber": "discacciare",
    "discaccerebbero": "discacciare",
    "discaccerei": "discacciare",
    "discacceremmo": "discacciare",
    "discacceremo": "discacciare",
    "discaccereste": "discacciare",
    "discacceresti": "discacciare",
    "discaccerete": "discacciare",
    "discaccerà": "discacciare",
    "discaccerò": "discacciare",
    "discacci": "discacciare",
    "discaccia": "discacciare",
    "discacciai": "discacciare",
    "discacciammo": "discacciare",
    "discacciamo": "discacciare",
    "discaccian": "discacciare",
    "discacciando": "discacciare",
    "discacciano": "discacciare",
    "discacciante": "discacciare",
    "discaccianti": "discacciare",
    "discacciar": "discacciare",
    "discacciaron": "discacciare",
    "discacciarono": "discacciare",
    "discacciasse": "discacciare",
    "discacciasser": "discacciare",
    "discacciassero": "discacciare",
    "discacciassi": "discacciare",
    "discacciassimo": "discacciare",
    "discacciaste": "discacciare",
    "discacciasti": "discacciare",
    "discacciata": "discacciare",
    "discacciate": "discacciare",
    "discacciati": "discacciare",
    "discacciato": "discacciare",
    "discacciava": "discacciare",
    "discacciavamo": "discacciare",
    "discacciavan": "discacciare",
    "discacciavano": "discacciare",
    "discacciavate": "discacciare",
    "discacciavi": "discacciare",
    "discacciavo": "discacciare",
    "discaccin": "discacciare",
    "discaccino": "discacciare",
    "discaccio": "discacciare",
    "discacciò": "discacciare",
    "discarica": "discaricare",
    "discaricai": "discaricare",
    "discaricammo": "discaricare",
    "discarican": "discaricare",
    "discaricando": "discaricare",
    "discaricano": "discaricare",
    "discaricante": "discaricare",
    "discaricanti": "discaricare",
    "discaricar": "discaricare",
    "discaricaron": "discaricare",
    "discaricarono": "discaricare",
    "discaricasse": "discaricare",
    "discaricasser": "discaricare",
    "discaricassero": "discaricare",
    "discaricassi": "discaricare",
    "discaricassimo": "discaricare",
    "discaricaste": "discaricare",
    "discaricasti": "discaricare",
    "discaricata": "discaricare",
    "discaricate": "discaricare",
    "discaricati": "discaricare",
    "discaricato": "discaricare",
    "discaricava": "discaricare",
    "discaricavamo": "discaricare",
    "discaricavan": "discaricare",
    "discaricavano": "discaricare",
    "discaricavate": "discaricare",
    "discaricavi": "discaricare",
    "discaricavo": "discaricare",
    "discariche": "discarica",
    "discaricherai": "discaricare",
    "discaricheran": "discaricare",
    "discaricheranno": "discaricare",
    "discaricherebbe": "discaricare",
    "discaricherebber": "discaricare",
    "discaricherebbero": "discaricare",
    "discaricherei": "discaricare",
    "discaricheremmo": "discaricare",
    "discaricheremo": "discaricare",
    "discarichereste": "discaricare",
    "discaricheresti": "discaricare",
    "discaricherete": "discaricare",
    "discaricherà": "discaricare",
    "discaricherò": "discaricare",
    "discarichi": "discaricare",
    "discarichiamo": "discaricare",
    "discarichiate": "discaricare",
    "discarichin": "discaricare",
    "discarichino": "discaricare",
    "discarico": "discaricare",
    "discaricò": "discaricare",
    "discenda": "discendere",
    "discendan": "discendere",
    "discendano": "discendere",
    "discende": "discendere",
    "discendemmo": "discendere",
    "discendendo": "discendere",
    "discendente": "discendere",
    "discendenti": "discendere",
    "discendenze": "discendenza",
    "discender": "discendere",
    "discenderai": "discendere",
    "discenderan": "discendere",
    "discenderanno": "discendere",
    "discenderebbe": "discendere",
    "discenderebber": "discendere",
    "discenderebbero": "discendere",
    "discenderei": "discendere",
    "discenderemmo": "discendere",
    "discenderemo": "discendere",
    "discendereste": "discendere",
    "discenderesti": "discendere",
    "discenderete": "discendere",
    "discenderà": "discendere",
    "discenderò": "discendere",
    "discendesse": "discendere",
    "discendesser": "discendere",
    "discendessero": "discendere",
    "discendessi": "discendere",
    "discendessimo": "discendere",
    "discendeste": "discendere",
    "discendesti": "discendere",
    "discendete": "discendere",
    "discendeva": "discendere",
    "discendevamo": "discendere",
    "discendevan": "discendere",
    "discendevano": "discendere",
    "discendevate": "discendere",
    "discendevi": "discendere",
    "discendevo": "discendere",
    "discendi": "discendere",
    "discendiamo": "discendere",
    "discendiate": "discendere",
    "discendo": "discendere",
    "discendon": "discendere",
    "discendono": "discendere",
    "discenti": "discente",
    "discepole": "discepola",
    "discepoli": "discepolo",
    "discerna": "discernere",
    "discernan": "discernere",
    "discernano": "discernere",
    "discerne": "discernere",
    "discernei": "discernere",
    "discernemmo": "discernere",
    "discernendo": "discernere",
    "discernente": "discernere",
    "discernenti": "discernere",
    "discerner": "discernere",
    "discernerai": "discernere",
    "discerneran": "discernere",
    "discerneranno": "discernere",
    "discernerebbe": "discernere",
    "discernerebber": "discernere",
    "discernerebbero": "discernere",
    "discernerei": "discernere",
    "discerneremmo": "discernere",
    "discerneremo": "discernere",
    "discernereste": "discernere",
    "discerneresti": "discernere",
    "discernerete": "discernere",
    "discerneron": "discernere",
    "discernerono": "discernere",
    "discernerà": "discernere",
    "discernerò": "discernere",
    "discernesse": "discernere",
    "discernesser": "discernere",
    "discernessero": "discernere",
    "discernessi": "discernere",
    "discernessimo": "discernere",
    "discerneste": "discernere",
    "discernesti": "discernere",
    "discernete": "discernere",
    "discerneva": "discernere",
    "discernevamo": "discernere",
    "discernevan": "discernere",
    "discernevano": "discernere",
    "discernevate": "discernere",
    "discernevi": "discernere",
    "discernevo": "discernere",
    "discerni": "discernere",
    "discerniamo": "discernere",
    "discerniate": "discernere",
    "discernimenti": "discernimento",
    "discerno": "discernere",
    "discernon": "discernere",
    "discernono": "discernere",
    "discernè": "discernere",
    "discesa": "discendere",
    "discese": "discesa",
    "disceser": "discendere",
    "discesero": "discendere",
    "discesi": "discendere",
    "discesiste": "discesista",
    "discesisti": "discesista",
    "disceso": "discendere",
    "discesè": "discendere",
    "discetta": "discettare",
    "discettai": "discettare",
    "discettammo": "discettare",
    "discettan": "discettare",
    "discettando": "discettare",
    "discettano": "discettare",
    "discettante": "discettare",
    "discettanti": "discettare",
    "discettar": "discettare",
    "discettaron": "discettare",
    "discettarono": "discettare",
    "discettasse": "discettare",
    "discettasser": "discettare",
    "discettassero": "discettare",
    "discettassi": "discettare",
    "discettassimo": "discettare",
    "discettaste": "discettare",
    "discettasti": "discettare",
    "discettata": "discettare",
    "discettate": "discettare",
    "discettati": "discettare",
    "discettato": "discettare",
    "discettava": "discettare",
    "discettavamo": "discettare",
    "discettavan": "discettare",
    "discettavano": "discettare",
    "discettavate": "discettare",
    "discettavi": "discettare",
    "discettavo": "discettare",
    "discetterai": "discettare",
    "discetteran": "discettare",
    "discetteranno": "discettare",
    "discetterebbe": "discettare",
    "discetterebber": "discettare",
    "discetterebbero": "discettare",
    "discetterei": "discettare",
    "discetteremmo": "discettare",
    "discetteremo": "discettare",
    "discettereste": "discettare",
    "discetteresti": "discettare",
    "discetterete": "discettare",
    "discetterà": "discettare",
    "discetterò": "discettare",
    "discetti": "discettare",
    "discettiamo": "discettare",
    "discettiate": "discettare",
    "discettin": "discettare",
    "discettino": "discettare",
    "discetto": "discettare",
    "discettò": "discettare",
    "dischetti": "dischetto",
    "dischi": "disco",
    "dischiuda": "dischiudere",
    "dischiudan": "dischiudere",
    "dischiudano": "dischiudere",
    "dischiude": "dischiudere",
    "dischiudemmo": "dischiudere",
    "dischiudendo": "dischiudere",
    "dischiudente": "dischiudere",
    "dischiudenti": "dischiudere",
    "dischiuder": "dischiudere",
    "dischiuderai": "dischiudere",
    "dischiuderan": "dischiudere",
    "dischiuderanno": "dischiudere",
    "dischiuderebbe": "dischiudere",
    "dischiuderebber": "dischiudere",
    "dischiuderebbero": "dischiudere",
    "dischiuderei": "dischiudere",
    "dischiuderemmo": "dischiudere",
    "dischiuderemo": "dischiudere",
    "dischiudereste": "dischiudere",
    "dischiuderesti": "dischiudere",
    "dischiuderete": "dischiudere",
    "dischiuderà": "dischiudere",
    "dischiuderò": "dischiudere",
    "dischiudesse": "dischiudere",
    "dischiudesser": "dischiudere",
    "dischiudessero": "dischiudere",
    "dischiudessi": "dischiudere",
    "dischiudessimo": "dischiudere",
    "dischiudeste": "dischiudere",
    "dischiudesti": "dischiudere",
    "dischiudete": "dischiudere",
    "dischiudeva": "dischiudere",
    "dischiudevamo": "dischiudere",
    "dischiudevan": "dischiudere",
    "dischiudevano": "dischiudere",
    "dischiudevate": "dischiudere",
    "dischiudevi": "dischiudere",
    "dischiudevo": "dischiudere",
    "dischiudi": "dischiudere",
    "dischiudiamo": "dischiudere",
    "dischiudiate": "dischiudere",
    "dischiudo": "dischiudere",
    "dischiudon": "dischiudere",
    "dischiudono": "dischiudere",
    "dischiusa": "dischiudere",
    "dischiuse": "dischiudere",
    "dischiuser": "dischiudere",
    "dischiusero": "dischiudere",
    "dischiusi": "dischiudere",
    "dischiuso": "dischiudere",
    "discinga": "discingere",
    "discingan": "discingere",
    "discingano": "discingere",
    "discinge": "discingere",
    "discingemmo": "discingere",
    "discingendo": "discingere",
    "discingente": "discingere",
    "discingenti": "discingere",
    "discinger": "discingere",
    "discingerai": "discingere",
    "discingeran": "discingere",
    "discingeranno": "discingere",
    "discingerebbe": "discingere",
    "discingerebber": "discingere",
    "discingerebbero": "discingere",
    "discingerei": "discingere",
    "discingeremmo": "discingere",
    "discingeremo": "discingere",
    "discingereste": "discingere",
    "discingeresti": "discingere",
    "discingerete": "discingere",
    "discingerà": "discingere",
    "discingerò": "discingere",
    "discingesse": "discingere",
    "discingesser": "discingere",
    "discingessero": "discingere",
    "discingessi": "discingere",
    "discingessimo": "discingere",
    "discingeste": "discingere",
    "discingesti": "discingere",
    "discingete": "discingere",
    "discingeva": "discingere",
    "discingevamo": "discingere",
    "discingevan": "discingere",
    "discingevano": "discingere",
    "discingevate": "discingere",
    "discingevi": "discingere",
    "discingevo": "discingere",
    "discingi": "discingere",
    "discingiamo": "discingere",
    "discingiate": "discingere",
    "discingo": "discingere",
    "discingon": "discingere",
    "discingono": "discingere",
    "discinser": "discingere",
    "discinsero": "discingere",
    "discinsi": "discingere",
    "discinsè": "discingere",
    "discinta": "discinto",
    "discinte": "discinto",
    "discinti": "discinto",
    "discinto": "discingere",
    "disciogli": "disciogliere",
    "disciogliamo": "disciogliere",
    "disciogliate": "disciogliere",
    "discioglie": "disciogliere",
    "disciogliemmo": "disciogliere",
    "disciogliendo": "disciogliere",
    "disciogliente": "disciogliere",
    "discioglienti": "disciogliere",
    "discioglier": "disciogliere",
    "discioglierai": "disciogliere",
    "discioglieran": "disciogliere",
    "discioglieranno": "disciogliere",
    "discioglierebbe": "disciogliere",
    "discioglierebber": "disciogliere",
    "discioglierebbero": "disciogliere",
    "discioglierei": "disciogliere",
    "discioglieremmo": "disciogliere",
    "discioglieremo": "disciogliere",
    "disciogliereste": "disciogliere",
    "discioglieresti": "disciogliere",
    "discioglierete": "disciogliere",
    "discioglierà": "disciogliere",
    "discioglierò": "disciogliere",
    "disciogliesse": "disciogliere",
    "disciogliesser": "disciogliere",
    "disciogliessero": "disciogliere",
    "disciogliessi": "disciogliere",
    "disciogliessimo": "disciogliere",
    "discioglieste": "disciogliere",
    "disciogliesti": "disciogliere",
    "disciogliete": "disciogliere",
    "discioglieva": "disciogliere",
    "discioglievamo": "disciogliere",
    "discioglievan": "disciogliere",
    "discioglievano": "disciogliere",
    "discioglievate": "disciogliere",
    "discioglievi": "disciogliere",
    "discioglievo": "disciogliere",
    "disciolga": "disciogliere",
    "disciolgan": "disciogliere",
    "disciolgano": "disciogliere",
    "disciolgo": "disciogliere",
    "disciolgon": "disciogliere",
    "disciolgono": "disciogliere",
    "disciolser": "disciogliere",
    "disciolsero": "disciogliere",
    "disciolsi": "disciogliere",
    "disciolsè": "disciogliere",
    "disciolta": "disciogliere",
    "disciolte": "disciogliere",
    "disciolti": "disciogliere",
    "disciolto": "disciogliere",
    "disciplina": "disciplinare",
    "disciplinai": "disciplinare",
    "disciplinammo": "disciplinare",
    "disciplinan": "disciplinare",
    "disciplinando": "disciplinare",
    "disciplinano": "disciplinare",
    "disciplinante": "disciplinare",
    "disciplinanti": "disciplinare",
    "disciplinar": "disciplinare",
    "disciplinari": "disciplinare",
    "disciplinaron": "disciplinare",
    "disciplinarono": "disciplinare",
    "disciplinasse": "disciplinare",
    "disciplinasser": "disciplinare",
    "disciplinassero": "disciplinare",
    "disciplinassi": "disciplinare",
    "disciplinassimo": "disciplinare",
    "disciplinaste": "disciplinare",
    "disciplinasti": "disciplinare",
    "disciplinata": "disciplinato",
    "disciplinate": "disciplinato",
    "disciplinati": "disciplinato",
    "disciplinato": "disciplinare",
    "disciplinava": "disciplinare",
    "disciplinavamo": "disciplinare",
    "disciplinavan": "disciplinare",
    "disciplinavano": "disciplinare",
    "disciplinavate": "disciplinare",
    "disciplinavi": "disciplinare",
    "disciplinavo": "disciplinare",
    "discipline": "disciplina",
    "disciplinerai": "disciplinare",
    "disciplineran": "disciplinare",
    "disciplineranno": "disciplinare",
    "disciplinerebbe": "disciplinare",
    "disciplinerebber": "disciplinare",
    "disciplinerebbero": "disciplinare",
    "disciplinerei": "disciplinare",
    "disciplineremmo": "disciplinare",
    "disciplineremo": "disciplinare",
    "disciplinereste": "disciplinare",
    "disciplineresti": "disciplinare",
    "disciplinerete": "disciplinare",
    "disciplinerà": "disciplinare",
    "disciplinerò": "disciplinare",
    "disciplini": "disciplinare",
    "discipliniamo": "disciplinare",
    "discipliniate": "disciplinare",
    "disciplinin": "disciplinare",
    "disciplinino": "disciplinare",
    "disciplino": "disciplinare",
    "disciplinò": "disciplinare",
    "discoboli": "discobolo",
    "discografica": "discografico",
    "discografiche": "discografico",
    "discografici": "discografico",
    "discografie": "discografia",
    "discola": "discolo",
    "discole": "discolo",
    "discoli": "discolo",
    "discolpa": "discolpare",
    "discolpai": "discolpare",
    "discolpammo": "discolpare",
    "discolpan": "discolpare",
    "discolpando": "discolpare",
    "discolpano": "discolpare",
    "discolpante": "discolpare",
    "discolpanti": "discolpare",
    "discolpar": "discolpare",
    "discolparon": "discolpare",
    "discolparono": "discolpare",
    "discolpasse": "discolpare",
    "discolpasser": "discolpare",
    "discolpassero": "discolpare",
    "discolpassi": "discolpare",
    "discolpassimo": "discolpare",
    "discolpaste": "discolpare",
    "discolpasti": "discolpare",
    "discolpata": "discolpare",
    "discolpate": "discolpare",
    "discolpati": "discolpare",
    "discolpato": "discolpare",
    "discolpava": "discolpare",
    "discolpavamo": "discolpare",
    "discolpavan": "discolpare",
    "discolpavano": "discolpare",
    "discolpavate": "discolpare",
    "discolpavi": "discolpare",
    "discolpavo": "discolpare",
    "discolpe": "discolpa",
    "discolperai": "discolpare",
    "discolperan": "discolpare",
    "discolperanno": "discolpare",
    "discolperebbe": "discolpare",
    "discolperebber": "discolpare",
    "discolperebbero": "discolpare",
    "discolperei": "discolpare",
    "discolperemmo": "discolpare",
    "discolperemo": "discolpare",
    "discolpereste": "discolpare",
    "discolperesti": "discolpare",
    "discolperete": "discolpare",
    "discolperà": "discolpare",
    "discolperò": "discolpare",
    "discolpi": "discolpare",
    "discolpiamo": "discolpare",
    "discolpiate": "discolpare",
    "discolpin": "discolpare",
    "discolpino": "discolpare",
    "discolpo": "discolpare",
    "discolpò": "discolpare",
    "disconnetta": "disconnettere",
    "disconnettan": "disconnettere",
    "disconnettano": "disconnettere",
    "disconnette": "disconnettere",
    "disconnettei": "disconnettere",
    "disconnettemmo": "disconnettere",
    "disconnettendo": "disconnettere",
    "disconnettente": "disconnettere",
    "disconnettenti": "disconnettere",
    "disconnetter": "disconnettere",
    "disconnetterai": "disconnettere",
    "disconnetteran": "disconnettere",
    "disconnetteranno": "disconnettere",
    "disconnetterebbe": "disconnettere",
    "disconnetterebber": "disconnettere",
    "disconnetterebbero": "disconnettere",
    "disconnetterei": "disconnettere",
    "disconnetteremmo": "disconnettere",
    "disconnetteremo": "disconnettere",
    "disconnettereste": "disconnettere",
    "disconnetteresti": "disconnettere",
    "disconnetterete": "disconnettere",
    "disconnetteron": "disconnettere",
    "disconnetterono": "disconnettere",
    "disconnetterà": "disconnettere",
    "disconnetterò": "disconnettere",
    "disconnettesse": "disconnettere",
    "disconnettesser": "disconnettere",
    "disconnettessero": "disconnettere",
    "disconnettessi": "disconnettere",
    "disconnettessimo": "disconnettere",
    "disconnetteste": "disconnettere",
    "disconnettesti": "disconnettere",
    "disconnettete": "disconnettere",
    "disconnetteva": "disconnettere",
    "disconnettevamo": "disconnettere",
    "disconnettevan": "disconnettere",
    "disconnettevano": "disconnettere",
    "disconnettevate": "disconnettere",
    "disconnettevi": "disconnettere",
    "disconnettevo": "disconnettere",
    "disconnetti": "disconnettere",
    "disconnettiamo": "disconnettere",
    "disconnettiate": "disconnettere",
    "disconnetto": "disconnettere",
    "disconnetton": "disconnettere",
    "disconnettono": "disconnettere",
    "disconnettuta": "disconnettere",
    "disconnettute": "disconnettere",
    "disconnettuti": "disconnettere",
    "disconnettuto": "disconnettere",
    "disconnettè": "disconnettere",
    "disconosca": "disconoscere",
    "disconoscan": "disconoscere",
    "disconoscano": "disconoscere",
    "disconosce": "disconoscere",
    "disconoscei": "disconoscere",
    "disconoscemmo": "disconoscere",
    "disconoscendo": "disconoscere",
    "disconoscente": "disconoscere",
    "disconoscenti": "disconoscere",
    "disconoscer": "disconoscere",
    "disconoscerai": "disconoscere",
    "disconosceran": "disconoscere",
    "disconosceranno": "disconoscere",
    "disconoscerebbe": "disconoscere",
    "disconoscerebber": "disconoscere",
    "disconoscerebbero": "disconoscere",
    "disconoscerei": "disconoscere",
    "disconosceremmo": "disconoscere",
    "disconosceremo": "disconoscere",
    "disconoscereste": "disconoscere",
    "disconosceresti": "disconoscere",
    "disconoscerete": "disconoscere",
    "disconosceron": "disconoscere",
    "disconoscerono": "disconoscere",
    "disconoscerà": "disconoscere",
    "disconoscerò": "disconoscere",
    "disconoscesse": "disconoscere",
    "disconoscesser": "disconoscere",
    "disconoscessero": "disconoscere",
    "disconoscessi": "disconoscere",
    "disconoscessimo": "disconoscere",
    "disconosceste": "disconoscere",
    "disconoscesti": "disconoscere",
    "disconoscete": "disconoscere",
    "disconosceva": "disconoscere",
    "disconoscevamo": "disconoscere",
    "disconoscevan": "disconoscere",
    "disconoscevano": "disconoscere",
    "disconoscevate": "disconoscere",
    "disconoscevi": "disconoscere",
    "disconoscevo": "disconoscere",
    "disconosci": "disconoscere",
    "disconosciamo": "disconoscere",
    "disconosciate": "disconoscere",
    "disconoscimenti": "disconoscimento",
    "disconosciuta": "disconoscere",
    "disconosciute": "disconoscere",
    "disconosciuti": "disconoscere",
    "disconosciuto": "disconoscere",
    "disconosco": "disconoscere",
    "disconoscon": "disconoscere",
    "disconoscono": "disconoscere",
    "disconoscè": "disconoscere",
    "discontinua": "discontinuo",
    "discontinue": "discontinuo",
    "discontinui": "discontinuo",
    "discopra": "discoprire",
    "discopran": "discoprire",
    "discoprano": "discoprire",
    "discopre": "discoprire",
    "discoprendo": "discoprire",
    "discoprente": "discoprire",
    "discoprenti": "discoprire",
    "discopri": "discoprire",
    "discopriamo": "discoprire",
    "discopriate": "discoprire",
    "discoprii": "discoprire",
    "discoprimmo": "discoprire",
    "discoprir": "discoprire",
    "discoprirai": "discoprire",
    "discopriran": "discoprire",
    "discopriranno": "discoprire",
    "discoprirebbe": "discoprire",
    "discoprirebber": "discoprire",
    "discoprirebbero": "discoprire",
    "discoprirei": "discoprire",
    "discopriremmo": "discoprire",
    "discopriremo": "discoprire",
    "discoprireste": "discoprire",
    "discopriresti": "discoprire",
    "discoprirete": "discoprire",
    "discopriron": "discoprire",
    "discoprirono": "discoprire",
    "discoprirà": "discoprire",
    "discoprirò": "discoprire",
    "discoprisse": "discoprire",
    "discoprisser": "discoprire",
    "discoprissero": "discoprire",
    "discoprissi": "discoprire",
    "discoprissimo": "discoprire",
    "discopriste": "discoprire",
    "discopristi": "discoprire",
    "discoprita": "discoprire",
    "discoprite": "discoprire",
    "discopriti": "discoprire",
    "discoprito": "discoprire",
    "discopriva": "discoprire",
    "discoprivamo": "discoprire",
    "discoprivan": "discoprire",
    "discoprivano": "discoprire",
    "discoprivate": "discoprire",
    "discoprivi": "discoprire",
    "discoprivo": "discoprire",
    "discopro": "discoprire",
    "discopron": "discoprire",
    "discoprono": "discoprire",
    "discoprì": "discoprire",
    "discorda": "discordare",
    "discordai": "discordare",
    "discordammo": "discordare",
    "discordan": "discordare",
    "discordando": "discordare",
    "discordano": "discordare",
    "discordante": "discordare",
    "discordanti": "discordare",
    "discordanze": "discordanza",
    "discordar": "discordare",
    "discordaron": "discordare",
    "discordarono": "discordare",
    "discordasse": "discordare",
    "discordasser": "discordare",
    "discordassero": "discordare",
    "discordassi": "discordare",
    "discordassimo": "discordare",
    "discordaste": "discordare",
    "discordasti": "discordare",
    "discordata": "discordare",
    "discordate": "discordare",
    "discordati": "discordare",
    "discordato": "discordare",
    "discordava": "discordare",
    "discordavamo": "discordare",
    "discordavan": "discordare",
    "discordavano": "discordare",
    "discordavate": "discordare",
    "discordavi": "discordare",
    "discordavo": "discordare",
    "discorderai": "discordare",
    "discorderan": "discordare",
    "discorderanno": "discordare",
    "discorderebbe": "discordare",
    "discorderebber": "discordare",
    "discorderebbero": "discordare",
    "discorderei": "discordare",
    "discorderemmo": "discordare",
    "discorderemo": "discordare",
    "discordereste": "discordare",
    "discorderesti": "discordare",
    "discorderete": "discordare",
    "discorderà": "discordare",
    "discorderò": "discordare",
    "discordi": "discorde",
    "discordiamo": "discordare",
    "discordiate": "discordare",
    "discordie": "discordia",
    "discordin": "discordare",
    "discordino": "discordare",
    "discordo": "discordare",
    "discordò": "discordare",
    "discorra": "discorrere",
    "discorran": "discorrere",
    "discorrano": "discorrere",
    "discorre": "discorrere",
    "discorremmo": "discorrere",
    "discorrendo": "discorrere",
    "discorrente": "discorrere",
    "discorrenti": "discorrere",
    "discorrer": "discorrere",
    "discorrerai": "discorrere",
    "discorreran": "discorrere",
    "discorreranno": "discorrere",
    "discorrerebbe": "discorrere",
    "discorrerebber": "discorrere",
    "discorrerebbero": "discorrere",
    "discorrerei": "discorrere",
    "discorreremmo": "discorrere",
    "discorreremo": "discorrere",
    "discorrereste": "discorrere",
    "discorreresti": "discorrere",
    "discorrerete": "discorrere",
    "discorrerà": "discorrere",
    "discorrerò": "discorrere",
    "discorresse": "discorrere",
    "discorresser": "discorrere",
    "discorressero": "discorrere",
    "discorressi": "discorrere",
    "discorressimo": "discorrere",
    "discorreste": "discorrere",
    "discorresti": "discorrere",
    "discorrete": "discorrere",
    "discorreva": "discorrere",
    "discorrevamo": "discorrere",
    "discorrevan": "discorrere",
    "discorrevano": "discorrere",
    "discorrevate": "discorrere",
    "discorrevi": "discorrere",
    "discorrevo": "discorrere",
    "discorri": "discorrere",
    "discorriamo": "discorrere",
    "discorriate": "discorrere",
    "discorro": "discorrere",
    "discorron": "discorrere",
    "discorrono": "discorrere",
    "discorsa": "discorrere",
    "discorse": "discorrere",
    "discorser": "discorrere",
    "discorsero": "discorrere",
    "discorsetti": "discorsetto",
    "discorsi": "discorso",
    "discorsiva": "discorsivo",
    "discorsive": "discorsivo",
    "discorsivi": "discorsivo",
    "discorso": "discorrere",
    "discosta": "discosto",
    "discostai": "discostare",
    "discostammo": "discostare",
    "discostan": "discostare",
    "discostando": "discostare",
    "discostano": "discostare",
    "discostante": "discostare",
    "discostanti": "discostare",
    "discostar": "discostare",
    "discostaron": "discostare",
    "discostarono": "discostare",
    "discostasse": "discostare",
    "discostasser": "discostare",
    "discostassero": "discostare",
    "discostassi": "discostare",
    "discostassimo": "discostare",
    "discostaste": "discostare",
    "discostasti": "discostare",
    "discostata": "discostare",
    "discostate": "discostare",
    "discostati": "discostare",
    "discostato": "discostare",
    "discostava": "discostare",
    "discostavamo": "discostare",
    "discostavan": "discostare",
    "discostavano": "discostare",
    "discostavate": "discostare",
    "discostavi": "discostare",
    "discostavo": "discostare",
    "discoste": "discosto",
    "discosterai": "discostare",
    "discosteran": "discostare",
    "discosteranno": "discostare",
    "discosterebbe": "discostare",
    "discosterebber": "discostare",
    "discosterebbero": "discostare",
    "discosterei": "discostare",
    "discosteremmo": "discostare",
    "discosteremo": "discostare",
    "discostereste": "discostare",
    "discosteresti": "discostare",
    "discosterete": "discostare",
    "discosterà": "discostare",
    "discosterò": "discostare",
    "discosti": "discosto",
    "discostiamo": "discostare",
    "discostiate": "discostare",
    "discostin": "discostare",
    "discostino": "discostare",
    "discosto": "discostare",
    "discostò": "discostare",
    "discoteche": "discoteca",
    "discrasie": "discrasia",
    "discredita": "discreditare",
    "discreditai": "discreditare",
    "discreditammo": "discreditare",
    "discreditan": "discreditare",
    "discreditando": "discreditare",
    "discreditano": "discreditare",
    "discreditante": "discreditare",
    "discreditanti": "discreditare",
    "discreditar": "discreditare",
    "discreditaron": "discreditare",
    "discreditarono": "discreditare",
    "discreditasse": "discreditare",
    "discreditasser": "discreditare",
    "discreditassero": "discreditare",
    "discreditassi": "discreditare",
    "discreditassimo": "discreditare",
    "discreditaste": "discreditare",
    "discreditasti": "discreditare",
    "discreditata": "discreditare",
    "discreditate": "discreditare",
    "discreditati": "discreditare",
    "discreditato": "discreditare",
    "discreditava": "discreditare",
    "discreditavamo": "discreditare",
    "discreditavan": "discreditare",
    "discreditavano": "discreditare",
    "discreditavate": "discreditare",
    "discreditavi": "discreditare",
    "discreditavo": "discreditare",
    "discrediterai": "discreditare",
    "discrediteran": "discreditare",
    "discrediteranno": "discreditare",
    "discrediterebbe": "discreditare",
    "discrediterebber": "discreditare",
    "discrediterebbero": "discreditare",
    "discrediterei": "discreditare",
    "discrediteremmo": "discreditare",
    "discrediteremo": "discreditare",
    "discreditereste": "discreditare",
    "discrediteresti": "discreditare",
    "discrediterete": "discreditare",
    "discrediterà": "discreditare",
    "discrediterò": "discreditare",
    "discrediti": "discredito",
    "discreditiamo": "discreditare",
    "discreditiate": "discreditare",
    "discreditin": "discreditare",
    "discreditino": "discreditare",
    "discredito": "discreditare",
    "discreditò": "discreditare",
    "discrepa": "discrepare",
    "discrepai": "discrepare",
    "discrepammo": "discrepare",
    "discrepan": "discrepare",
    "discrepando": "discrepare",
    "discrepano": "discrepare",
    "discrepante": "discrepare",
    "discrepanti": "discrepare",
    "discrepanze": "discrepanza",
    "discrepar": "discrepare",
    "discreparon": "discrepare",
    "discreparono": "discrepare",
    "discrepasse": "discrepare",
    "discrepasser": "discrepare",
    "discrepassero": "discrepare",
    "discrepassi": "discrepare",
    "discrepassimo": "discrepare",
    "discrepaste": "discrepare",
    "discrepasti": "discrepare",
    "discrepata": "discrepare",
    "discrepate": "discrepare",
    "discrepati": "discrepare",
    "discrepato": "discrepare",
    "discrepava": "discrepare",
    "discrepavamo": "discrepare",
    "discrepavan": "discrepare",
    "discrepavano": "discrepare",
    "discrepavate": "discrepare",
    "discrepavi": "discrepare",
    "discrepavo": "discrepare",
    "discreperai": "discrepare",
    "discreperan": "discrepare",
    "discreperanno": "discrepare",
    "discreperebbe": "discrepare",
    "discreperebber": "discrepare",
    "discreperebbero": "discrepare",
    "discreperei": "discrepare",
    "discreperemmo": "discrepare",
    "discreperemo": "discrepare",
    "discrepereste": "discrepare",
    "discreperesti": "discrepare",
    "discreperete": "discrepare",
    "discreperà": "discrepare",
    "discreperò": "discrepare",
    "discrepi": "discrepare",
    "discrepiamo": "discrepare",
    "discrepiate": "discrepare",
    "discrepin": "discrepare",
    "discrepino": "discrepare",
    "discrepo": "discrepare",
    "discrepò": "discrepare",
    "discreta": "discreto",
    "discrete": "discreto",
    "discreti": "discreto",
    "discreto": "discernere",
    "discrezionali": "discrezionale",
    "discrezioni": "discrezione",
    "discrimina": "discriminare",
    "discriminabili": "discriminabile",
    "discriminai": "discriminare",
    "discriminammo": "discriminare",
    "discriminan": "discriminare",
    "discriminando": "discriminare",
    "discriminano": "discriminare",
    "discriminante": "discriminare",
    "discriminanti": "discriminare",
    "discriminar": "discriminare",
    "discriminaron": "discriminare",
    "discriminarono": "discriminare",
    "discriminasse": "discriminare",
    "discriminasser": "discriminare",
    "discriminassero": "discriminare",
    "discriminassi": "discriminare",
    "discriminassimo": "discriminare",
    "discriminaste": "discriminare",
    "discriminasti": "discriminare",
    "discriminata": "discriminare",
    "discriminate": "discriminare",
    "discriminati": "discriminare",
    "discriminato": "discriminare",
    "discriminatori": "discriminatorio",
    "discriminatoria": "discriminatorio",
    "discriminatorie": "discriminatorio",
    "discriminava": "discriminare",
    "discriminavamo": "discriminare",
    "discriminavan": "discriminare",
    "discriminavano": "discriminare",
    "discriminavate": "discriminare",
    "discriminavi": "discriminare",
    "discriminavo": "discriminare",
    "discriminazioni": "discriminazione",
    "discriminerai": "discriminare",
    "discrimineran": "discriminare",
    "discrimineranno": "discriminare",
    "discriminerebbe": "discriminare",
    "discriminerebber": "discriminare",
    "discriminerebbero": "discriminare",
    "discriminerei": "discriminare",
    "discrimineremmo": "discriminare",
    "discrimineremo": "discriminare",
    "discriminereste": "discriminare",
    "discrimineresti": "discriminare",
    "discriminerete": "discriminare",
    "discriminerà": "discriminare",
    "discriminerò": "discriminare",
    "discrimini": "discrimine",
    "discriminiamo": "discriminare",
    "discriminiate": "discriminare",
    "discriminin": "discriminare",
    "discriminino": "discriminare",
    "discrimino": "discriminare",
    "discriminò": "discriminare",
    "discussa": "discusso",
    "discusse": "discusso",
    "discussi": "discusso",
    "discussioni": "discussione",
    "discuta": "discutere",
    "discutan": "discutere",
    "discutano": "discutere",
    "discute": "discutere",
    "discutei": "discutere",
    "discutemmo": "discutere",
    "discutendo": "discutere",
    "discutente": "discutere",
    "discutenti": "discutere",
    "discuter": "discutere",
    "discuterai": "discutere",
    "discuteran": "discutere",
    "discuteranno": "discutere",
    "discuterebbe": "discutere",
    "discuterebber": "discutere",
    "discuterebbero": "discutere",
    "discuterei": "discutere",
    "discuteremmo": "discutere",
    "discuteremo": "discutere",
    "discutereste": "discutere",
    "discuteresti": "discutere",
    "discuterete": "discutere",
    "discuteron": "discutere",
    "discuterono": "discutere",
    "discuterà": "discutere",
    "discuterò": "discutere",
    "discutesse": "discutere",
    "discutesser": "discutere",
    "discutessero": "discutere",
    "discutessi": "discutere",
    "discutessimo": "discutere",
    "discuteste": "discutere",
    "discutesti": "discutere",
    "discutete": "discutere",
    "discuteva": "discutere",
    "discutevamo": "discutere",
    "discutevan": "discutere",
    "discutevano": "discutere",
    "discutevate": "discutere",
    "discutevi": "discutere",
    "discutevo": "discutere",
    "discuti": "discutere",
    "discutiamo": "discutere",
    "discutiate": "discutere",
    "discutibili": "discutibile",
    "discuto": "discutere",
    "discuton": "discutere",
    "discutono": "discutere",
    "discututa": "discutere",
    "discutute": "discutere",
    "discututi": "discutere",
    "discututo": "discutere",
    "discutè": "discutere",
    "disdegna": "disdegnare",
    "disdegnai": "disdegnare",
    "disdegnammo": "disdegnare",
    "disdegnan": "disdegnare",
    "disdegnando": "disdegnare",
    "disdegnano": "disdegnare",
    "disdegnante": "disdegnare",
    "disdegnanti": "disdegnare",
    "disdegnar": "disdegnare",
    "disdegnaron": "disdegnare",
    "disdegnarono": "disdegnare",
    "disdegnasse": "disdegnare",
    "disdegnasser": "disdegnare",
    "disdegnassero": "disdegnare",
    "disdegnassi": "disdegnare",
    "disdegnassimo": "disdegnare",
    "disdegnaste": "disdegnare",
    "disdegnasti": "disdegnare",
    "disdegnata": "disdegnare",
    "disdegnate": "disdegnare",
    "disdegnati": "disdegnare",
    "disdegnato": "disdegnare",
    "disdegnava": "disdegnare",
    "disdegnavamo": "disdegnare",
    "disdegnavan": "disdegnare",
    "disdegnavano": "disdegnare",
    "disdegnavate": "disdegnare",
    "disdegnavi": "disdegnare",
    "disdegnavo": "disdegnare",
    "disdegnerai": "disdegnare",
    "disdegneran": "disdegnare",
    "disdegneranno": "disdegnare",
    "disdegnerebbe": "disdegnare",
    "disdegnerebber": "disdegnare",
    "disdegnerebbero": "disdegnare",
    "disdegnerei": "disdegnare",
    "disdegneremmo": "disdegnare",
    "disdegneremo": "disdegnare",
    "disdegnereste": "disdegnare",
    "disdegneresti": "disdegnare",
    "disdegnerete": "disdegnare",
    "disdegnerà": "disdegnare",
    "disdegnerò": "disdegnare",
    "disdegni": "disdegnare",
    "disdegniamo": "disdegnare",
    "disdegniate": "disdegnare",
    "disdegnin": "disdegnare",
    "disdegnino": "disdegnare",
    "disdegno": "disdegnare",
    "disdegnò": "disdegnare",
    "disdetta": "disdire",
    "disdettai": "disdettare",
    "disdettammo": "disdettare",
    "disdettan": "disdettare",
    "disdettando": "disdettare",
    "disdettano": "disdettare",
    "disdettante": "disdettare",
    "disdettanti": "disdettare",
    "disdettar": "disdettare",
    "disdettaron": "disdettare",
    "disdettarono": "disdettare",
    "disdettasse": "disdettare",
    "disdettasser": "disdettare",
    "disdettassero": "disdettare",
    "disdettassi": "disdettare",
    "disdettassimo": "disdettare",
    "disdettaste": "disdettare",
    "disdettasti": "disdettare",
    "disdettata": "disdettare",
    "disdettate": "disdettare",
    "disdettati": "disdettare",
    "disdettato": "disdettare",
    "disdettava": "disdettare",
    "disdettavamo": "disdettare",
    "disdettavan": "disdettare",
    "disdettavano": "disdettare",
    "disdettavate": "disdettare",
    "disdettavi": "disdettare",
    "disdettavo": "disdettare",
    "disdette": "disdire",
    "disdetterai": "disdettare",
    "disdetteran": "disdettare",
    "disdetteranno": "disdettare",
    "disdetterebbe": "disdettare",
    "disdetterebber": "disdettare",
    "disdetterebbero": "disdettare",
    "disdetterei": "disdettare",
    "disdetteremmo": "disdettare",
    "disdetteremo": "disdettare",
    "disdettereste": "disdettare",
    "disdetteresti": "disdettare",
    "disdetterete": "disdettare",
    "disdetterà": "disdettare",
    "disdetterò": "disdettare",
    "disdetti": "disdire",
    "disdettiamo": "disdettare",
    "disdettiate": "disdettare",
    "disdettin": "disdettare",
    "disdettino": "disdettare",
    "disdetto": "disdire",
    "disdettò": "disdettare",
    "disdica": "disdire",
    "disdican": "disdire",
    "disdicano": "disdire",
    "disdice": "disdire",
    "disdicemmo": "disdire",
    "disdicesse": "disdire",
    "disdicesser": "disdire",
    "disdicessero": "disdire",
    "disdicessi": "disdire",
    "disdicessimo": "disdire",
    "disdiceste": "disdire",
    "disdicesti": "disdire",
    "disdiceva": "disdire",
    "disdicevamo": "disdire",
    "disdicevan": "disdire",
    "disdicevano": "disdire",
    "disdicevate": "disdire",
    "disdicevi": "disdire",
    "disdicevo": "disdire",
    "disdicevoli": "disdicevole",
    "disdici": "disdire",
    "disdiciamo": "disdire",
    "disdiciate": "disdire",
    "disdico": "disdire",
    "disdicon": "disdire",
    "disdicono": "disdire",
    "disdir": "disdire",
    "disdirai": "disdire",
    "disdiran": "disdire",
    "disdiranno": "disdire",
    "disdirebbe": "disdire",
    "disdirebber": "disdire",
    "disdirebbero": "disdire",
    "disdirei": "disdire",
    "disdiremmo": "disdire",
    "disdiremo": "disdire",
    "disdireste": "disdire",
    "disdiresti": "disdire",
    "disdirete": "disdire",
    "disdirà": "disdire",
    "disdirò": "disdire",
    "disdisse": "disdire",
    "disdisser": "disdire",
    "disdissero": "disdire",
    "disdissi": "disdire",
    "disdite": "disdire",
    "diseconomie": "diseconomia",
    "diseduca": "diseducare",
    "diseducai": "diseducare",
    "diseducammo": "diseducare",
    "diseducan": "diseducare",
    "diseducando": "diseducare",
    "diseducano": "diseducare",
    "diseducante": "diseducare",
    "diseducanti": "diseducare",
    "diseducar": "diseducare",
    "diseducaron": "diseducare",
    "diseducarono": "diseducare",
    "diseducasse": "diseducare",
    "diseducasser": "diseducare",
    "diseducassero": "diseducare",
    "diseducassi": "diseducare",
    "diseducassimo": "diseducare",
    "diseducaste": "diseducare",
    "diseducasti": "diseducare",
    "diseducata": "diseducare",
    "diseducate": "diseducare",
    "diseducati": "diseducare",
    "diseducativa": "diseducativo",
    "diseducative": "diseducativo",
    "diseducativi": "diseducativo",
    "diseducato": "diseducare",
    "diseducava": "diseducare",
    "diseducavamo": "diseducare",
    "diseducavan": "diseducare",
    "diseducavano": "diseducare",
    "diseducavate": "diseducare",
    "diseducavi": "diseducare",
    "diseducavo": "diseducare",
    "diseducherai": "diseducare",
    "diseducheran": "diseducare",
    "diseducheranno": "diseducare",
    "diseducherebbe": "diseducare",
    "diseducherebber": "diseducare",
    "diseducherebbero": "diseducare",
    "diseducherei": "diseducare",
    "diseducheremmo": "diseducare",
    "diseducheremo": "diseducare",
    "diseduchereste": "diseducare",
    "diseducheresti": "diseducare",
    "diseducherete": "diseducare",
    "diseducherà": "diseducare",
    "diseducherò": "diseducare",
    "diseduchi": "diseducare",
    "diseduchiamo": "diseducare",
    "diseduchiate": "diseducare",
    "diseduchin": "diseducare",
    "diseduchino": "diseducare",
    "diseduco": "diseducare",
    "diseducò": "diseducare",
    "disegna": "disegnare",
    "disegnai": "disegnare",
    "disegnammo": "disegnare",
    "disegnan": "disegnare",
    "disegnando": "disegnare",
    "disegnano": "disegnare",
    "disegnante": "disegnare",
    "disegnanti": "disegnare",
    "disegnar": "disegnare",
    "disegnaron": "disegnare",
    "disegnarono": "disegnare",
    "disegnasse": "disegnare",
    "disegnasser": "disegnare",
    "disegnassero": "disegnare",
    "disegnassi": "disegnare",
    "disegnassimo": "disegnare",
    "disegnaste": "disegnare",
    "disegnasti": "disegnare",
    "disegnata": "disegnare",
    "disegnate": "disegnare",
    "disegnati": "disegnare",
    "disegnato": "disegnare",
    "disegnatori": "disegnatore",
    "disegnava": "disegnare",
    "disegnavamo": "disegnare",
    "disegnavan": "disegnare",
    "disegnavano": "disegnare",
    "disegnavate": "disegnare",
    "disegnavi": "disegnare",
    "disegnavo": "disegnare",
    "disegnerai": "disegnare",
    "disegneran": "disegnare",
    "disegneranno": "disegnare",
    "disegnerebbe": "disegnare",
    "disegnerebber": "disegnare",
    "disegnerebbero": "disegnare",
    "disegnerei": "disegnare",
    "disegneremmo": "disegnare",
    "disegneremo": "disegnare",
    "disegnereste": "disegnare",
    "disegneresti": "disegnare",
    "disegnerete": "disegnare",
    "disegnerà": "disegnare",
    "disegnerò": "disegnare",
    "disegni": "disegno",
    "disegniamo": "disegnare",
    "disegniate": "disegnare",
    "disegnin": "disegnare",
    "disegnini": "disegnino",
    "disegnino": "disegnare",
    "disegno": "disegnare",
    "disegnò": "disegnare",
    "diseguaglianze": "diseguaglianza",
    "diseguali": "diseguale",
    "disequilibri": "disequilibrio",
    "diserba": "diserbare",
    "diserbai": "diserbare",
    "diserbammo": "diserbare",
    "diserban": "diserbare",
    "diserbando": "diserbare",
    "diserbano": "diserbare",
    "diserbante": "diserbare",
    "diserbanti": "diserbare",
    "diserbar": "diserbare",
    "diserbaron": "diserbare",
    "diserbarono": "diserbare",
    "diserbasse": "diserbare",
    "diserbasser": "diserbare",
    "diserbassero": "diserbare",
    "diserbassi": "diserbare",
    "diserbassimo": "diserbare",
    "diserbaste": "diserbare",
    "diserbasti": "diserbare",
    "diserbata": "diserbare",
    "diserbate": "diserbare",
    "diserbati": "diserbare",
    "diserbato": "diserbare",
    "diserbava": "diserbare",
    "diserbavamo": "diserbare",
    "diserbavan": "diserbare",
    "diserbavano": "diserbare",
    "diserbavate": "diserbare",
    "diserbavi": "diserbare",
    "diserbavo": "diserbare",
    "diserberai": "diserbare",
    "diserberan": "diserbare",
    "diserberanno": "diserbare",
    "diserberebbe": "diserbare",
    "diserberebber": "diserbare",
    "diserberebbero": "diserbare",
    "diserberei": "diserbare",
    "diserberemmo": "diserbare",
    "diserberemo": "diserbare",
    "diserbereste": "diserbare",
    "diserberesti": "diserbare",
    "diserberete": "diserbare",
    "diserberà": "diserbare",
    "diserberò": "diserbare",
    "diserbi": "diserbare",
    "diserbiamo": "diserbare",
    "diserbiate": "diserbare",
    "diserbin": "diserbare",
    "diserbino": "diserbare",
    "diserbo": "diserbare",
    "diserbò": "diserbare",
    "disereda": "diseredare",
    "diseredai": "diseredare",
    "diseredammo": "diseredare",
    "diseredan": "diseredare",
    "diseredando": "diseredare",
    "diseredano": "diseredare",
    "diseredante": "diseredare",
    "diseredanti": "diseredare",
    "diseredar": "diseredare",
    "diseredaron": "diseredare",
    "diseredarono": "diseredare",
    "diseredasse": "diseredare",
    "diseredasser": "diseredare",
    "diseredassero": "diseredare",
    "diseredassi": "diseredare",
    "diseredassimo": "diseredare",
    "diseredaste": "diseredare",
    "diseredasti": "diseredare",
    "diseredata": "diseredato",
    "diseredate": "diseredato",
    "diseredati": "diseredato",
    "diseredato": "diseredare",
    "diseredava": "diseredare",
    "diseredavamo": "diseredare",
    "diseredavan": "diseredare",
    "diseredavano": "diseredare",
    "diseredavate": "diseredare",
    "diseredavi": "diseredare",
    "diseredavo": "diseredare",
    "diserederai": "diseredare",
    "diserederan": "diseredare",
    "diserederanno": "diseredare",
    "diserederebbe": "diseredare",
    "diserederebber": "diseredare",
    "diserederebbero": "diseredare",
    "diserederei": "diseredare",
    "diserederemmo": "diseredare",
    "diserederemo": "diseredare",
    "diseredereste": "diseredare",
    "diserederesti": "diseredare",
    "diserederete": "diseredare",
    "diserederà": "diseredare",
    "diserederò": "diseredare",
    "diseredi": "diseredare",
    "diserediamo": "diseredare",
    "diserediate": "diseredare",
    "diseredin": "diseredare",
    "diseredino": "diseredare",
    "diseredo": "diseredare",
    "diseredò": "diseredare",
    "diserta": "disertare",
    "disertai": "disertare",
    "disertammo": "disertare",
    "disertan": "disertare",
    "disertando": "disertare",
    "disertano": "disertare",
    "disertante": "disertare",
    "disertanti": "disertare",
    "disertar": "disertare",
    "disertaron": "disertare",
    "disertarono": "disertare",
    "disertasse": "disertare",
    "disertasser": "disertare",
    "disertassero": "disertare",
    "disertassi": "disertare",
    "disertassimo": "disertare",
    "disertaste": "disertare",
    "disertasti": "disertare",
    "disertata": "disertare",
    "disertate": "disertare",
    "disertati": "disertare",
    "disertato": "disertare",
    "disertava": "disertare",
    "disertavamo": "disertare",
    "disertavan": "disertare",
    "disertavano": "disertare",
    "disertavate": "disertare",
    "disertavi": "disertare",
    "disertavo": "disertare",
    "diserterai": "disertare",
    "diserteran": "disertare",
    "diserteranno": "disertare",
    "diserterebbe": "disertare",
    "diserterebber": "disertare",
    "diserterebbero": "disertare",
    "diserterei": "disertare",
    "diserteremmo": "disertare",
    "diserteremo": "disertare",
    "disertereste": "disertare",
    "diserteresti": "disertare",
    "diserterete": "disertare",
    "diserterà": "disertare",
    "diserterò": "disertare",
    "diserti": "disertare",
    "disertiamo": "disertare",
    "disertiate": "disertare",
    "disertin": "disertare",
    "disertino": "disertare",
    "diserto": "disertare",
    "disertori": "disertore",
    "disertò": "disertare",
    "diserzioni": "diserzione",
    "disfa": "disfare",
    "disfa'": "disfare",
    "disfaccia": "disfare",
    "disfacciamo": "disfare",
    "disfaccian": "disfare",
    "disfacciano": "disfare",
    "disfacciate": "disfare",
    "disfaccio": "disfare",
    "disfacemmo": "disfare",
    "disfacendo": "disfare",
    "disfacente": "disfare",
    "disfacenti": "disfare",
    "disfacesse": "disfare",
    "disfacesser": "disfare",
    "disfacessero": "disfare",
    "disfacessi": "disfare",
    "disfacessimo": "disfare",
    "disfaceste": "disfare",
    "disfacesti": "disfare",
    "disfaceva": "disfare",
    "disfacevamo": "disfare",
    "disfacevan": "disfare",
    "disfacevano": "disfare",
    "disfacevate": "disfare",
    "disfacevi": "disfare",
    "disfacevo": "disfare",
    "disfacimenti": "disfacimento",
    "disfai": "disfare",
    "disfammo": "disfare",
    "disfan": "disfare",
    "disfando": "disfare",
    "disfanno": "disfare",
    "disfano": "disfare",
    "disfante": "disfare",
    "disfanti": "disfare",
    "disfar": "disfare",
    "disfarai": "disfare",
    "disfaran": "disfare",
    "disfaranno": "disfare",
    "disfarebbe": "disfare",
    "disfarebber": "disfare",
    "disfarebbero": "disfare",
    "disfarei": "disfare",
    "disfaremmo": "disfare",
    "disfaremo": "disfare",
    "disfareste": "disfare",
    "disfaresti": "disfare",
    "disfarete": "disfare",
    "disfaron": "disfare",
    "disfarono": "disfare",
    "disfarà": "disfare",
    "disfarò": "disfare",
    "disfasse": "disfare",
    "disfasser": "disfare",
    "disfassero": "disfare",
    "disfassi": "disfare",
    "disfassimo": "disfare",
    "disfaste": "disfare",
    "disfasti": "disfare",
    "disfata": "disfare",
    "disfate": "disfare",
    "disfati": "disfare",
    "disfato": "disfare",
    "disfatta": "disfare",
    "disfatte": "disfatta",
    "disfatti": "disfare",
    "disfattismi": "disfattismo",
    "disfattiste": "disfattista",
    "disfattisti": "disfattista",
    "disfatto": "disfare",
    "disfava": "disfare",
    "disfavamo": "disfare",
    "disfavan": "disfare",
    "disfavano": "disfare",
    "disfavate": "disfare",
    "disfavi": "disfare",
    "disfavo": "disfare",
    "disfece": "disfare",
    "disfecer": "disfare",
    "disfecero": "disfare",
    "disfeci": "disfare",
    "disferai": "disfare",
    "disferan": "disfare",
    "disferanno": "disfare",
    "disferebbe": "disfare",
    "disferebber": "disfare",
    "disferebbero": "disfare",
    "disferei": "disfare",
    "disferemmo": "disfare",
    "disferemo": "disfare",
    "disfereste": "disfare",
    "disferesti": "disfare",
    "disferete": "disfare",
    "disferà": "disfare",
    "disferò": "disfare",
    "disfi": "disfare",
    "disfiamo": "disfare",
    "disfiate": "disfare",
    "disfida": "disfidare",
    "disfidai": "disfidare",
    "disfidammo": "disfidare",
    "disfidan": "disfidare",
    "disfidando": "disfidare",
    "disfidano": "disfidare",
    "disfidante": "disfidare",
    "disfidanti": "disfidare",
    "disfidar": "disfidare",
    "disfidaron": "disfidare",
    "disfidarono": "disfidare",
    "disfidasse": "disfidare",
    "disfidasser": "disfidare",
    "disfidassero": "disfidare",
    "disfidassi": "disfidare",
    "disfidassimo": "disfidare",
    "disfidaste": "disfidare",
    "disfidasti": "disfidare",
    "disfidata": "disfidare",
    "disfidate": "disfidare",
    "disfidati": "disfidare",
    "disfidato": "disfidare",
    "disfidava": "disfidare",
    "disfidavamo": "disfidare",
    "disfidavan": "disfidare",
    "disfidavano": "disfidare",
    "disfidavate": "disfidare",
    "disfidavi": "disfidare",
    "disfidavo": "disfidare",
    "disfide": "disfida",
    "disfiderai": "disfidare",
    "disfideran": "disfidare",
    "disfideranno": "disfidare",
    "disfiderebbe": "disfidare",
    "disfiderebber": "disfidare",
    "disfiderebbero": "disfidare",
    "disfiderei": "disfidare",
    "disfideremmo": "disfidare",
    "disfideremo": "disfidare",
    "disfidereste": "disfidare",
    "disfideresti": "disfidare",
    "disfiderete": "disfidare",
    "disfiderà": "disfidare",
    "disfiderò": "disfidare",
    "disfidi": "disfidare",
    "disfidiamo": "disfidare",
    "disfidiate": "disfidare",
    "disfidin": "disfidare",
    "disfidino": "disfidare",
    "disfido": "disfidare",
    "disfidò": "disfidare",
    "disfin": "disfare",
    "disfino": "disfare",
    "disfo": "disfare",
    "disfunzionali": "disfunzionale",
    "disfunzioni": "disfunzione",
    "disfò": "disfare",
    "disgela": "disgelare",
    "disgelai": "disgelare",
    "disgelammo": "disgelare",
    "disgelan": "disgelare",
    "disgelando": "disgelare",
    "disgelano": "disgelare",
    "disgelante": "disgelare",
    "disgelanti": "disgelare",
    "disgelar": "disgelare",
    "disgelaron": "disgelare",
    "disgelarono": "disgelare",
    "disgelasse": "disgelare",
    "disgelasser": "disgelare",
    "disgelassero": "disgelare",
    "disgelassi": "disgelare",
    "disgelassimo": "disgelare",
    "disgelaste": "disgelare",
    "disgelasti": "disgelare",
    "disgelata": "disgelare",
    "disgelate": "disgelare",
    "disgelati": "disgelare",
    "disgelato": "disgelare",
    "disgelava": "disgelare",
    "disgelavamo": "disgelare",
    "disgelavan": "disgelare",
    "disgelavano": "disgelare",
    "disgelavate": "disgelare",
    "disgelavi": "disgelare",
    "disgelavo": "disgelare",
    "disgelerai": "disgelare",
    "disgeleran": "disgelare",
    "disgeleranno": "disgelare",
    "disgelerebbe": "disgelare",
    "disgelerebber": "disgelare",
    "disgelerebbero": "disgelare",
    "disgelerei": "disgelare",
    "disgeleremmo": "disgelare",
    "disgeleremo": "disgelare",
    "disgelereste": "disgelare",
    "disgeleresti": "disgelare",
    "disgelerete": "disgelare",
    "disgelerà": "disgelare",
    "disgelerò": "disgelare",
    "disgeli": "disgelo",
    "disgeliamo": "disgelare",
    "disgeliate": "disgelare",
    "disgelin": "disgelare",
    "disgelino": "disgelare",
    "disgelo": "disgelare",
    "disgelò": "disgelare",
    "disgiunga": "disgiungere",
    "disgiungan": "disgiungere",
    "disgiungano": "disgiungere",
    "disgiunge": "disgiungere",
    "disgiungemmo": "disgiungere",
    "disgiungendo": "disgiungere",
    "disgiungente": "disgiungere",
    "disgiungenti": "disgiungere",
    "disgiunger": "disgiungere",
    "disgiungerai": "disgiungere",
    "disgiungeran": "disgiungere",
    "disgiungeranno": "disgiungere",
    "disgiungerebbe": "disgiungere",
    "disgiungerebber": "disgiungere",
    "disgiungerebbero": "disgiungere",
    "disgiungerei": "disgiungere",
    "disgiungeremmo": "disgiungere",
    "disgiungeremo": "disgiungere",
    "disgiungereste": "disgiungere",
    "disgiungeresti": "disgiungere",
    "disgiungerete": "disgiungere",
    "disgiungerà": "disgiungere",
    "disgiungerò": "disgiungere",
    "disgiungesse": "disgiungere",
    "disgiungesser": "disgiungere",
    "disgiungessero": "disgiungere",
    "disgiungessi": "disgiungere",
    "disgiungessimo": "disgiungere",
    "disgiungeste": "disgiungere",
    "disgiungesti": "disgiungere",
    "disgiungete": "disgiungere",
    "disgiungeva": "disgiungere",
    "disgiungevamo": "disgiungere",
    "disgiungevan": "disgiungere",
    "disgiungevano": "disgiungere",
    "disgiungevate": "disgiungere",
    "disgiungevi": "disgiungere",
    "disgiungevo": "disgiungere",
    "disgiungi": "disgiungere",
    "disgiungiamo": "disgiungere",
    "disgiungiate": "disgiungere",
    "disgiungo": "disgiungere",
    "disgiungon": "disgiungere",
    "disgiungono": "disgiungere",
    "disgiunse": "disgiungere",
    "disgiunser": "disgiungere",
    "disgiunsero": "disgiungere",
    "disgiunsi": "disgiungere",
    "disgiunta": "disgiungere",
    "disgiunte": "disgiungere",
    "disgiunti": "disgiungere",
    "disgiunto": "disgiungere",
    "disgraziata": "disgraziato",
    "disgraziate": "disgraziato",
    "disgraziati": "disgraziato",
    "disgrazie": "disgrazia",
    "disgrega": "disgregare",
    "disgregai": "disgregare",
    "disgregammo": "disgregare",
    "disgregan": "disgregare",
    "disgregando": "disgregare",
    "disgregano": "disgregare",
    "disgregante": "disgregare",
    "disgreganti": "disgregare",
    "disgregar": "disgregare",
    "disgregaron": "disgregare",
    "disgregarono": "disgregare",
    "disgregasse": "disgregare",
    "disgregasser": "disgregare",
    "disgregassero": "disgregare",
    "disgregassi": "disgregare",
    "disgregassimo": "disgregare",
    "disgregaste": "disgregare",
    "disgregasti": "disgregare",
    "disgregata": "disgregare",
    "disgregate": "disgregare",
    "disgregati": "disgregare",
    "disgregato": "disgregare",
    "disgregatori": "disgregatore",
    "disgregatrice": "disgregatore",
    "disgregatrici": "disgregatore",
    "disgregava": "disgregare",
    "disgregavamo": "disgregare",
    "disgregavan": "disgregare",
    "disgregavano": "disgregare",
    "disgregavate": "disgregare",
    "disgregavi": "disgregare",
    "disgregavo": "disgregare",
    "disgregazioni": "disgregazione",
    "disgregherai": "disgregare",
    "disgregheran": "disgregare",
    "disgregheranno": "disgregare",
    "disgregherebbe": "disgregare",
    "disgregherebber": "disgregare",
    "disgregherebbero": "disgregare",
    "disgregherei": "disgregare",
    "disgregheremmo": "disgregare",
    "disgregheremo": "disgregare",
    "disgreghereste": "disgregare",
    "disgregheresti": "disgregare",
    "disgregherete": "disgregare",
    "disgregherà": "disgregare",
    "disgregherò": "disgregare",
    "disgreghi": "disgregare",
    "disgreghiamo": "disgregare",
    "disgreghiate": "disgregare",
    "disgreghin": "disgregare",
    "disgreghino": "disgregare",
    "disgrego": "disgregare",
    "disgregò": "disgregare",
    "disguidi": "disguido",
    "disgusta": "disgustare",
    "disgustai": "disgustare",
    "disgustammo": "disgustare",
    "disgustan": "disgustare",
    "disgustando": "disgustare",
    "disgustano": "disgustare",
    "disgustante": "disgustare",
    "disgustanti": "disgustare",
    "disgustar": "disgustare",
    "disgustaron": "disgustare",
    "disgustarono": "disgustare",
    "disgustasse": "disgustare",
    "disgustasser": "disgustare",
    "disgustassero": "disgustare",
    "disgustassi": "disgustare",
    "disgustassimo": "disgustare",
    "disgustaste": "disgustare",
    "disgustasti": "disgustare",
    "disgustata": "disgustare",
    "disgustate": "disgustare",
    "disgustati": "disgustare",
    "disgustato": "disgustare",
    "disgustava": "disgustare",
    "disgustavamo": "disgustare",
    "disgustavan": "disgustare",
    "disgustavano": "disgustare",
    "disgustavate": "disgustare",
    "disgustavi": "disgustare",
    "disgustavo": "disgustare",
    "disgusterai": "disgustare",
    "disgusteran": "disgustare",
    "disgusteranno": "disgustare",
    "disgusterebbe": "disgustare",
    "disgusterebber": "disgustare",
    "disgusterebbero": "disgustare",
    "disgusterei": "disgustare",
    "disgusteremmo": "disgustare",
    "disgusteremo": "disgustare",
    "disgustereste": "disgustare",
    "disgusteresti": "disgustare",
    "disgusterete": "disgustare",
    "disgusterà": "disgustare",
    "disgusterò": "disgustare",
    "disgusti": "disgusto",
    "disgustiamo": "disgustare",
    "disgustiate": "disgustare",
    "disgustin": "disgustare",
    "disgustino": "disgustare",
    "disgusto": "disgustare",
    "disgustosa": "disgustoso",
    "disgustose": "disgustoso",
    "disgustosi": "disgustoso",
    "disgustò": "disgustare",
    "disideologizzata": "disideologizzato",
    "disideologizzate": "disideologizzato",
    "disideologizzati": "disideologizzato",
    "disidrata": "disidratare",
    "disidratai": "disidratare",
    "disidratammo": "disidratare",
    "disidratan": "disidratare",
    "disidratando": "disidratare",
    "disidratano": "disidratare",
    "disidratante": "disidratare",
    "disidratanti": "disidratare",
    "disidratar": "disidratare",
    "disidrataron": "disidratare",
    "disidratarono": "disidratare",
    "disidratasse": "disidratare",
    "disidratasser": "disidratare",
    "disidratassero": "disidratare",
    "disidratassi": "disidratare",
    "disidratassimo": "disidratare",
    "disidrataste": "disidratare",
    "disidratasti": "disidratare",
    "disidratata": "disidratare",
    "disidratate": "disidratare",
    "disidratati": "disidratare",
    "disidratato": "disidratare",
    "disidratava": "disidratare",
    "disidratavamo": "disidratare",
    "disidratavan": "disidratare",
    "disidratavano": "disidratare",
    "disidratavate": "disidratare",
    "disidratavi": "disidratare",
    "disidratavo": "disidratare",
    "disidratazioni": "disidratazione",
    "disidraterai": "disidratare",
    "disidrateran": "disidratare",
    "disidrateranno": "disidratare",
    "disidraterebbe": "disidratare",
    "disidraterebber": "disidratare",
    "disidraterebbero": "disidratare",
    "disidraterei": "disidratare",
    "disidrateremmo": "disidratare",
    "disidrateremo": "disidratare",
    "disidratereste": "disidratare",
    "disidrateresti": "disidratare",
    "disidraterete": "disidratare",
    "disidraterà": "disidratare",
    "disidraterò": "disidratare",
    "disidrati": "disidratare",
    "disidratiamo": "disidratare",
    "disidratiate": "disidratare",
    "disidratin": "disidratare",
    "disidratino": "disidratare",
    "disidrato": "disidratare",
    "disidratò": "disidratare",
    "disilluda": "disilludere",
    "disilludan": "disilludere",
    "disilludano": "disilludere",
    "disillude": "disilludere",
    "disilludemmo": "disilludere",
    "disilludendo": "disilludere",
    "disilludente": "disilludere",
    "disilludenti": "disilludere",
    "disilluder": "disilludere",
    "disilluderai": "disilludere",
    "disilluderan": "disilludere",
    "disilluderanno": "disilludere",
    "disilluderebbe": "disilludere",
    "disilluderebber": "disilludere",
    "disilluderebbero": "disilludere",
    "disilluderei": "disilludere",
    "disilluderemmo": "disilludere",
    "disilluderemo": "disilludere",
    "disilludereste": "disilludere",
    "disilluderesti": "disilludere",
    "disilluderete": "disilludere",
    "disilluderà": "disilludere",
    "disilluderò": "disilludere",
    "disilludesse": "disilludere",
    "disilludesser": "disilludere",
    "disilludessero": "disilludere",
    "disilludessi": "disilludere",
    "disilludessimo": "disilludere",
    "disilludeste": "disilludere",
    "disilludesti": "disilludere",
    "disilludete": "disilludere",
    "disilludeva": "disilludere",
    "disilludevamo": "disilludere",
    "disilludevan": "disilludere",
    "disilludevano": "disilludere",
    "disilludevate": "disilludere",
    "disilludevi": "disilludere",
    "disilludevo": "disilludere",
    "disilludi": "disilludere",
    "disilludiamo": "disilludere",
    "disilludiate": "disilludere",
    "disilludo": "disilludere",
    "disilludon": "disilludere",
    "disilludono": "disilludere",
    "disillusa": "disilluso",
    "disilluse": "disilluso",
    "disilluser": "disilludere",
    "disillusero": "disilludere",
    "disillusi": "disilluso",
    "disillusioni": "disillusione",
    "disilluso": "disilludere",
    "disimpara": "disimparare",
    "disimparai": "disimparare",
    "disimparammo": "disimparare",
    "disimparan": "disimparare",
    "disimparando": "disimparare",
    "disimparano": "disimparare",
    "disimparante": "disimparare",
    "disimparanti": "disimparare",
    "disimparar": "disimparare",
    "disimpararon": "disimparare",
    "disimpararono": "disimparare",
    "disimparasse": "disimparare",
    "disimparasser": "disimparare",
    "disimparassero": "disimparare",
    "disimparassi": "disimparare",
    "disimparassimo": "disimparare",
    "disimparaste": "disimparare",
    "disimparasti": "disimparare",
    "disimparata": "disimparare",
    "disimparate": "disimparare",
    "disimparati": "disimparare",
    "disimparato": "disimparare",
    "disimparava": "disimparare",
    "disimparavamo": "disimparare",
    "disimparavan": "disimparare",
    "disimparavano": "disimparare",
    "disimparavate": "disimparare",
    "disimparavi": "disimparare",
    "disimparavo": "disimparare",
    "disimparerai": "disimparare",
    "disimpareran": "disimparare",
    "disimpareranno": "disimparare",
    "disimparerebbe": "disimparare",
    "disimparerebber": "disimparare",
    "disimparerebbero": "disimparare",
    "disimparerei": "disimparare",
    "disimpareremmo": "disimparare",
    "disimpareremo": "disimparare",
    "disimparereste": "disimparare",
    "disimpareresti": "disimparare",
    "disimparerete": "disimparare",
    "disimparerà": "disimparare",
    "disimparerò": "disimparare",
    "disimpari": "disimparare",
    "disimpariamo": "disimparare",
    "disimpariate": "disimparare",
    "disimparin": "disimparare",
    "disimparino": "disimparare",
    "disimparo": "disimparare",
    "disimparò": "disimparare",
    "disimpegna": "disimpegnare",
    "disimpegnai": "disimpegnare",
    "disimpegnammo": "disimpegnare",
    "disimpegnan": "disimpegnare",
    "disimpegnando": "disimpegnare",
    "disimpegnano": "disimpegnare",
    "disimpegnante": "disimpegnare",
    "disimpegnanti": "disimpegnare",
    "disimpegnar": "disimpegnare",
    "disimpegnaron": "disimpegnare",
    "disimpegnarono": "disimpegnare",
    "disimpegnasse": "disimpegnare",
    "disimpegnasser": "disimpegnare",
    "disimpegnassero": "disimpegnare",
    "disimpegnassi": "disimpegnare",
    "disimpegnassimo": "disimpegnare",
    "disimpegnaste": "disimpegnare",
    "disimpegnasti": "disimpegnare",
    "disimpegnata": "disimpegnare",
    "disimpegnate": "disimpegnare",
    "disimpegnati": "disimpegnare",
    "disimpegnato": "disimpegnare",
    "disimpegnava": "disimpegnare",
    "disimpegnavamo": "disimpegnare",
    "disimpegnavan": "disimpegnare",
    "disimpegnavano": "disimpegnare",
    "disimpegnavate": "disimpegnare",
    "disimpegnavi": "disimpegnare",
    "disimpegnavo": "disimpegnare",
    "disimpegnerai": "disimpegnare",
    "disimpegneran": "disimpegnare",
    "disimpegneranno": "disimpegnare",
    "disimpegnerebbe": "disimpegnare",
    "disimpegnerebber": "disimpegnare",
    "disimpegnerebbero": "disimpegnare",
    "disimpegnerei": "disimpegnare",
    "disimpegneremmo": "disimpegnare",
    "disimpegneremo": "disimpegnare",
    "disimpegnereste": "disimpegnare",
    "disimpegneresti": "disimpegnare",
    "disimpegnerete": "disimpegnare",
    "disimpegnerà": "disimpegnare",
    "disimpegnerò": "disimpegnare",
    "disimpegni": "disimpegno",
    "disimpegniamo": "disimpegnare",
    "disimpegniate": "disimpegnare",
    "disimpegnin": "disimpegnare",
    "disimpegnino": "disimpegnare",
    "disimpegno": "disimpegnare",
    "disimpegnò": "disimpegnare",
    "disincagli": "disincagliare",
    "disincaglia": "disincagliare",
    "disincagliai": "disincagliare",
    "disincagliammo": "disincagliare",
    "disincagliamo": "disincagliare",
    "disincaglian": "disincagliare",
    "disincagliando": "disincagliare",
    "disincagliano": "disincagliare",
    "disincagliante": "disincagliare",
    "disincaglianti": "disincagliare",
    "disincagliar": "disincagliare",
    "disincagliaron": "disincagliare",
    "disincagliarono": "disincagliare",
    "disincagliasse": "disincagliare",
    "disincagliasser": "disincagliare",
    "disincagliassero": "disincagliare",
    "disincagliassi": "disincagliare",
    "disincagliassimo": "disincagliare",
    "disincagliaste": "disincagliare",
    "disincagliasti": "disincagliare",
    "disincagliata": "disincagliare",
    "disincagliate": "disincagliare",
    "disincagliati": "disincagliare",
    "disincagliato": "disincagliare",
    "disincagliava": "disincagliare",
    "disincagliavamo": "disincagliare",
    "disincagliavan": "disincagliare",
    "disincagliavano": "disincagliare",
    "disincagliavate": "disincagliare",
    "disincagliavi": "disincagliare",
    "disincagliavo": "disincagliare",
    "disincaglierai": "disincagliare",
    "disincaglieran": "disincagliare",
    "disincaglieranno": "disincagliare",
    "disincaglierebbe": "disincagliare",
    "disincaglierebber": "disincagliare",
    "disincaglierebbero": "disincagliare",
    "disincaglierei": "disincagliare",
    "disincaglieremmo": "disincagliare",
    "disincaglieremo": "disincagliare",
    "disincagliereste": "disincagliare",
    "disincaglieresti": "disincagliare",
    "disincaglierete": "disincagliare",
    "disincaglierà": "disincagliare",
    "disincaglierò": "disincagliare",
    "disincaglin": "disincagliare",
    "disincaglino": "disincagliare",
    "disincaglio": "disincagliare",
    "disincagliò": "disincagliare",
    "disincanta": "disincantare",
    "disincantai": "disincantare",
    "disincantammo": "disincantare",
    "disincantan": "disincantare",
    "disincantando": "disincantare",
    "disincantano": "disincantare",
    "disincantante": "disincantare",
    "disincantanti": "disincantare",
    "disincantar": "disincantare",
    "disincantaron": "disincantare",
    "disincantarono": "disincantare",
    "disincantasse": "disincantare",
    "disincantasser": "disincantare",
    "disincantassero": "disincantare",
    "disincantassi": "disincantare",
    "disincantassimo": "disincantare",
    "disincantaste": "disincantare",
    "disincantasti": "disincantare",
    "disincantata": "disincantato",
    "disincantate": "disincantato",
    "disincantati": "disincantato",
    "disincantato": "disincantare",
    "disincantava": "disincantare",
    "disincantavamo": "disincantare",
    "disincantavan": "disincantare",
    "disincantavano": "disincantare",
    "disincantavate": "disincantare",
    "disincantavi": "disincantare",
    "disincantavo": "disincantare",
    "disincanterai": "disincantare",
    "disincanteran": "disincantare",
    "disincanteranno": "disincantare",
    "disincanterebbe": "disincantare",
    "disincanterebber": "disincantare",
    "disincanterebbero": "disincantare",
    "disincanterei": "disincantare",
    "disincanteremmo": "disincantare",
    "disincanteremo": "disincantare",
    "disincantereste": "disincantare",
    "disincanteresti": "disincantare",
    "disincanterete": "disincantare",
    "disincanterà": "disincantare",
    "disincanterò": "disincantare",
    "disincanti": "disincanto",
    "disincantiamo": "disincantare",
    "disincantiate": "disincantare",
    "disincantin": "disincantare",
    "disincantino": "disincantare",
    "disincanto": "disincantare",
    "disincantò": "disincantare",
    "disincentiva": "disincentivare",
    "disincentivai": "disincentivare",
    "disincentivammo": "disincentivare",
    "disincentivan": "disincentivare",
    "disincentivando": "disincentivare",
    "disincentivano": "disincentivare",
    "disincentivante": "disincentivare",
    "disincentivanti": "disincentivare",
    "disincentivar": "disincentivare",
    "disincentivaron": "disincentivare",
    "disincentivarono": "disincentivare",
    "disincentivasse": "disincentivare",
    "disincentivasser": "disincentivare",
    "disincentivassero": "disincentivare",
    "disincentivassi": "disincentivare",
    "disincentivassimo": "disincentivare",
    "disincentivaste": "disincentivare",
    "disincentivasti": "disincentivare",
    "disincentivata": "disincentivare",
    "disincentivate": "disincentivare",
    "disincentivati": "disincentivare",
    "disincentivato": "disincentivare",
    "disincentivava": "disincentivare",
    "disincentivavamo": "disincentivare",
    "disincentivavan": "disincentivare",
    "disincentivavano": "disincentivare",
    "disincentivavate": "disincentivare",
    "disincentivavi": "disincentivare",
    "disincentivavo": "disincentivare",
    "disincentiverai": "disincentivare",
    "disincentiveran": "disincentivare",
    "disincentiveranno": "disincentivare",
    "disincentiverebbe": "disincentivare",
    "disincentiverebber": "disincentivare",
    "disincentiverebbero": "disincentivare",
    "disincentiverei": "disincentivare",
    "disincentiveremmo": "disincentivare",
    "disincentiveremo": "disincentivare",
    "disincentivereste": "disincentivare",
    "disincentiveresti": "disincentivare",
    "disincentiverete": "disincentivare",
    "disincentiverà": "disincentivare",
    "disincentiverò": "disincentivare",
    "disincentivi": "disincentivo",
    "disincentiviamo": "disincentivare",
    "disincentiviate": "disincentivare",
    "disincentivin": "disincentivare",
    "disincentivino": "disincentivare",
    "disincentivo": "disincentivare",
    "disincentivò": "disincentivare",
    "disincrosta": "disincrostare",
    "disincrostai": "disincrostare",
    "disincrostammo": "disincrostare",
    "disincrostan": "disincrostare",
    "disincrostando": "disincrostare",
    "disincrostano": "disincrostare",
    "disincrostante": "disincrostare",
    "disincrostanti": "disincrostare",
    "disincrostar": "disincrostare",
    "disincrostaron": "disincrostare",
    "disincrostarono": "disincrostare",
    "disincrostasse": "disincrostare",
    "disincrostasser": "disincrostare",
    "disincrostassero": "disincrostare",
    "disincrostassi": "disincrostare",
    "disincrostassimo": "disincrostare",
    "disincrostaste": "disincrostare",
    "disincrostasti": "disincrostare",
    "disincrostata": "disincrostare",
    "disincrostate": "disincrostare",
    "disincrostati": "disincrostare",
    "disincrostato": "disincrostare",
    "disincrostava": "disincrostare",
    "disincrostavamo": "disincrostare",
    "disincrostavan": "disincrostare",
    "disincrostavano": "disincrostare",
    "disincrostavate": "disincrostare",
    "disincrostavi": "disincrostare",
    "disincrostavo": "disincrostare",
    "disincrosterai": "disincrostare",
    "disincrosteran": "disincrostare",
    "disincrosteranno": "disincrostare",
    "disincrosterebbe": "disincrostare",
    "disincrosterebber": "disincrostare",
    "disincrosterebbero": "disincrostare",
    "disincrosterei": "disincrostare",
    "disincrosteremmo": "disincrostare",
    "disincrosteremo": "disincrostare",
    "disincrostereste": "disincrostare",
    "disincrosteresti": "disincrostare",
    "disincrosterete": "disincrostare",
    "disincrosterà": "disincrostare",
    "disincrosterò": "disincrostare",
    "disincrosti": "disincrostare",
    "disincrostiamo": "disincrostare",
    "disincrostiate": "disincrostare",
    "disincrostin": "disincrostare",
    "disincrostino": "disincrostare",
    "disincrosto": "disincrostare",
    "disincrostò": "disincrostare",
    "disindustrializza": "disindustrializzare",
    "disindustrializzai": "disindustrializzare",
    "disindustrializzammo": "disindustrializzare",
    "disindustrializzan": "disindustrializzare",
    "disindustrializzando": "disindustrializzare",
    "disindustrializzano": "disindustrializzare",
    "disindustrializzante": "disindustrializzare",
    "disindustrializzanti": "disindustrializzare",
    "disindustrializzar": "disindustrializzare",
    "disindustrializzaron": "disindustrializzare",
    "disindustrializzarono": "disindustrializzare",
    "disindustrializzasse": "disindustrializzare",
    "disindustrializzasser": "disindustrializzare",
    "disindustrializzassero": "disindustrializzare",
    "disindustrializzassi": "disindustrializzare",
    "disindustrializzassimo": "disindustrializzare",
    "disindustrializzaste": "disindustrializzare",
    "disindustrializzasti": "disindustrializzare",
    "disindustrializzata": "disindustrializzare",
    "disindustrializzate": "disindustrializzare",
    "disindustrializzati": "disindustrializzare",
    "disindustrializzato": "disindustrializzare",
    "disindustrializzava": "disindustrializzare",
    "disindustrializzavamo": "disindustrializzare",
    "disindustrializzavan": "disindustrializzare",
    "disindustrializzavano": "disindustrializzare",
    "disindustrializzavate": "disindustrializzare",
    "disindustrializzavi": "disindustrializzare",
    "disindustrializzavo": "disindustrializzare",
    "disindustrializzerai": "disindustrializzare",
    "disindustrializzeran": "disindustrializzare",
    "disindustrializzeranno": "disindustrializzare",
    "disindustrializzerebbe": "disindustrializzare",
    "disindustrializzerebber": "disindustrializzare",
    "disindustrializzerebbero": "disindustrializzare",
    "disindustrializzerei": "disindustrializzare",
    "disindustrializzeremmo": "disindustrializzare",
    "disindustrializzeremo": "disindustrializzare",
    "disindustrializzereste": "disindustrializzare",
    "disindustrializzeresti": "disindustrializzare",
    "disindustrializzerete": "disindustrializzare",
    "disindustrializzerà": "disindustrializzare",
    "disindustrializzerò": "disindustrializzare",
    "disindustrializzi": "disindustrializzare",
    "disindustrializziamo": "disindustrializzare",
    "disindustrializziate": "disindustrializzare",
    "disindustrializzin": "disindustrializzare",
    "disindustrializzino": "disindustrializzare",
    "disindustrializzo": "disindustrializzare",
    "disindustrializzò": "disindustrializzare",
    "disinfesta": "disinfestare",
    "disinfestai": "disinfestare",
    "disinfestammo": "disinfestare",
    "disinfestan": "disinfestare",
    "disinfestando": "disinfestare",
    "disinfestano": "disinfestare",
    "disinfestante": "disinfestare",
    "disinfestanti": "disinfestare",
    "disinfestar": "disinfestare",
    "disinfestaron": "disinfestare",
    "disinfestarono": "disinfestare",
    "disinfestasse": "disinfestare",
    "disinfestasser": "disinfestare",
    "disinfestassero": "disinfestare",
    "disinfestassi": "disinfestare",
    "disinfestassimo": "disinfestare",
    "disinfestaste": "disinfestare",
    "disinfestasti": "disinfestare",
    "disinfestata": "disinfestare",
    "disinfestate": "disinfestare",
    "disinfestati": "disinfestare",
    "disinfestato": "disinfestare",
    "disinfestava": "disinfestare",
    "disinfestavamo": "disinfestare",
    "disinfestavan": "disinfestare",
    "disinfestavano": "disinfestare",
    "disinfestavate": "disinfestare",
    "disinfestavi": "disinfestare",
    "disinfestavo": "disinfestare",
    "disinfestazioni": "disinfestazione",
    "disinfesterai": "disinfestare",
    "disinfesteran": "disinfestare",
    "disinfesteranno": "disinfestare",
    "disinfesterebbe": "disinfestare",
    "disinfesterebber": "disinfestare",
    "disinfesterebbero": "disinfestare",
    "disinfesterei": "disinfestare",
    "disinfesteremmo": "disinfestare",
    "disinfesteremo": "disinfestare",
    "disinfestereste": "disinfestare",
    "disinfesteresti": "disinfestare",
    "disinfesterete": "disinfestare",
    "disinfesterà": "disinfestare",
    "disinfesterò": "disinfestare",
    "disinfesti": "disinfestare",
    "disinfestiamo": "disinfestare",
    "disinfestiate": "disinfestare",
    "disinfestin": "disinfestare",
    "disinfestino": "disinfestare",
    "disinfesto": "disinfestare",
    "disinfestò": "disinfestare",
    "disinfetta": "disinfettare",
    "disinfettai": "disinfettare",
    "disinfettammo": "disinfettare",
    "disinfettan": "disinfettare",
    "disinfettando": "disinfettare",
    "disinfettano": "disinfettare",
    "disinfettante": "disinfettare",
    "disinfettanti": "disinfettare",
    "disinfettar": "disinfettare",
    "disinfettaron": "disinfettare",
    "disinfettarono": "disinfettare",
    "disinfettasse": "disinfettare",
    "disinfettasser": "disinfettare",
    "disinfettassero": "disinfettare",
    "disinfettassi": "disinfettare",
    "disinfettassimo": "disinfettare",
    "disinfettaste": "disinfettare",
    "disinfettasti": "disinfettare",
    "disinfettata": "disinfettare",
    "disinfettate": "disinfettare",
    "disinfettati": "disinfettare",
    "disinfettato": "disinfettare",
    "disinfettava": "disinfettare",
    "disinfettavamo": "disinfettare",
    "disinfettavan": "disinfettare",
    "disinfettavano": "disinfettare",
    "disinfettavate": "disinfettare",
    "disinfettavi": "disinfettare",
    "disinfettavo": "disinfettare",
    "disinfetterai": "disinfettare",
    "disinfetteran": "disinfettare",
    "disinfetteranno": "disinfettare",
    "disinfetterebbe": "disinfettare",
    "disinfetterebber": "disinfettare",
    "disinfetterebbero": "disinfettare",
    "disinfetterei": "disinfettare",
    "disinfetteremmo": "disinfettare",
    "disinfetteremo": "disinfettare",
    "disinfettereste": "disinfettare",
    "disinfetteresti": "disinfettare",
    "disinfetterete": "disinfettare",
    "disinfetterà": "disinfettare",
    "disinfetterò": "disinfettare",
    "disinfetti": "disinfettare",
    "disinfettiamo": "disinfettare",
    "disinfettiate": "disinfettare",
    "disinfettin": "disinfettare",
    "disinfettino": "disinfettare",
    "disinfetto": "disinfettare",
    "disinfettò": "disinfettare",
    "disinfiamma": "disinfiammare",
    "disinfiammai": "disinfiammare",
    "disinfiammammo": "disinfiammare",
    "disinfiamman": "disinfiammare",
    "disinfiammando": "disinfiammare",
    "disinfiammano": "disinfiammare",
    "disinfiammante": "disinfiammare",
    "disinfiammanti": "disinfiammare",
    "disinfiammar": "disinfiammare",
    "disinfiammaron": "disinfiammare",
    "disinfiammarono": "disinfiammare",
    "disinfiammasse": "disinfiammare",
    "disinfiammasser": "disinfiammare",
    "disinfiammassero": "disinfiammare",
    "disinfiammassi": "disinfiammare",
    "disinfiammassimo": "disinfiammare",
    "disinfiammaste": "disinfiammare",
    "disinfiammasti": "disinfiammare",
    "disinfiammata": "disinfiammare",
    "disinfiammate": "disinfiammare",
    "disinfiammati": "disinfiammare",
    "disinfiammato": "disinfiammare",
    "disinfiammava": "disinfiammare",
    "disinfiammavamo": "disinfiammare",
    "disinfiammavan": "disinfiammare",
    "disinfiammavano": "disinfiammare",
    "disinfiammavate": "disinfiammare",
    "disinfiammavi": "disinfiammare",
    "disinfiammavo": "disinfiammare",
    "disinfiammerai": "disinfiammare",
    "disinfiammeran": "disinfiammare",
    "disinfiammeranno": "disinfiammare",
    "disinfiammerebbe": "disinfiammare",
    "disinfiammerebber": "disinfiammare",
    "disinfiammerebbero": "disinfiammare",
    "disinfiammerei": "disinfiammare",
    "disinfiammeremmo": "disinfiammare",
    "disinfiammeremo": "disinfiammare",
    "disinfiammereste": "disinfiammare",
    "disinfiammeresti": "disinfiammare",
    "disinfiammerete": "disinfiammare",
    "disinfiammerà": "disinfiammare",
    "disinfiammerò": "disinfiammare",
    "disinfiammi": "disinfiammare",
    "disinfiammiamo": "disinfiammare",
    "disinfiammiate": "disinfiammare",
    "disinfiammin": "disinfiammare",
    "disinfiammino": "disinfiammare",
    "disinfiammo": "disinfiammare",
    "disinfiammò": "disinfiammare",
    "disinflazioni": "disinflazione",
    "disinforma": "disinformare",
    "disinformai": "disinformare",
    "disinformammo": "disinformare",
    "disinforman": "disinformare",
    "disinformando": "disinformare",
    "disinformano": "disinformare",
    "disinformante": "disinformare",
    "disinformanti": "disinformare",
    "disinformar": "disinformare",
    "disinformaron": "disinformare",
    "disinformarono": "disinformare",
    "disinformasse": "disinformare",
    "disinformasser": "disinformare",
    "disinformassero": "disinformare",
    "disinformassi": "disinformare",
    "disinformassimo": "disinformare",
    "disinformaste": "disinformare",
    "disinformasti": "disinformare",
    "disinformata": "disinformato",
    "disinformate": "disinformato",
    "disinformati": "disinformato",
    "disinformato": "disinformare",
    "disinformava": "disinformare",
    "disinformavamo": "disinformare",
    "disinformavan": "disinformare",
    "disinformavano": "disinformare",
    "disinformavate": "disinformare",
    "disinformavi": "disinformare",
    "disinformavo": "disinformare",
    "disinformazioni": "disinformazione",
    "disinformerai": "disinformare",
    "disinformeran": "disinformare",
    "disinformeranno": "disinformare",
    "disinformerebbe": "disinformare",
    "disinformerebber": "disinformare",
    "disinformerebbero": "disinformare",
    "disinformerei": "disinformare",
    "disinformeremmo": "disinformare",
    "disinformeremo": "disinformare",
    "disinformereste": "disinformare",
    "disinformeresti": "disinformare",
    "disinformerete": "disinformare",
    "disinformerà": "disinformare",
    "disinformerò": "disinformare",
    "disinformi": "disinformare",
    "disinformiamo": "disinformare",
    "disinformiate": "disinformare",
    "disinformin": "disinformare",
    "disinformino": "disinformare",
    "disinformo": "disinformare",
    "disinformò": "disinformare",
    "disinganna": "disingannare",
    "disingannai": "disingannare",
    "disingannammo": "disingannare",
    "disingannan": "disingannare",
    "disingannando": "disingannare",
    "disingannano": "disingannare",
    "disingannante": "disingannare",
    "disingannanti": "disingannare",
    "disingannar": "disingannare",
    "disingannaron": "disingannare",
    "disingannarono": "disingannare",
    "disingannasse": "disingannare",
    "disingannasser": "disingannare",
    "disingannassero": "disingannare",
    "disingannassi": "disingannare",
    "disingannassimo": "disingannare",
    "disingannaste": "disingannare",
    "disingannasti": "disingannare",
    "disingannata": "disingannare",
    "disingannate": "disingannare",
    "disingannati": "disingannare",
    "disingannato": "disingannare",
    "disingannava": "disingannare",
    "disingannavamo": "disingannare",
    "disingannavan": "disingannare",
    "disingannavano": "disingannare",
    "disingannavate": "disingannare",
    "disingannavi": "disingannare",
    "disingannavo": "disingannare",
    "disingannerai": "disingannare",
    "disinganneran": "disingannare",
    "disinganneranno": "disingannare",
    "disingannerebbe": "disingannare",
    "disingannerebber": "disingannare",
    "disingannerebbero": "disingannare",
    "disingannerei": "disingannare",
    "disinganneremmo": "disingannare",
    "disinganneremo": "disingannare",
    "disingannereste": "disingannare",
    "disinganneresti": "disingannare",
    "disingannerete": "disingannare",
    "disingannerà": "disingannare",
    "disingannerò": "disingannare",
    "disinganni": "disinganno",
    "disinganniamo": "disingannare",
    "disinganniate": "disingannare",
    "disingannin": "disingannare",
    "disingannino": "disingannare",
    "disinganno": "disingannare",
    "disingannò": "disingannare",
    "disinibita": "disinibito",
    "disinibite": "disinibito",
    "disinibiti": "disinibito",
    "disinnesca": "disinnescare",
    "disinnescai": "disinnescare",
    "disinnescammo": "disinnescare",
    "disinnescan": "disinnescare",
    "disinnescando": "disinnescare",
    "disinnescano": "disinnescare",
    "disinnescante": "disinnescare",
    "disinnescanti": "disinnescare",
    "disinnescar": "disinnescare",
    "disinnescaron": "disinnescare",
    "disinnescarono": "disinnescare",
    "disinnescasse": "disinnescare",
    "disinnescasser": "disinnescare",
    "disinnescassero": "disinnescare",
    "disinnescassi": "disinnescare",
    "disinnescassimo": "disinnescare",
    "disinnescaste": "disinnescare",
    "disinnescasti": "disinnescare",
    "disinnescata": "disinnescare",
    "disinnescate": "disinnescare",
    "disinnescati": "disinnescare",
    "disinnescato": "disinnescare",
    "disinnescava": "disinnescare",
    "disinnescavamo": "disinnescare",
    "disinnescavan": "disinnescare",
    "disinnescavano": "disinnescare",
    "disinnescavate": "disinnescare",
    "disinnescavi": "disinnescare",
    "disinnescavo": "disinnescare",
    "disinnescherai": "disinnescare",
    "disinnescheran": "disinnescare",
    "disinnescheranno": "disinnescare",
    "disinnescherebbe": "disinnescare",
    "disinnescherebber": "disinnescare",
    "disinnescherebbero": "disinnescare",
    "disinnescherei": "disinnescare",
    "disinnescheremmo": "disinnescare",
    "disinnescheremo": "disinnescare",
    "disinneschereste": "disinnescare",
    "disinnescheresti": "disinnescare",
    "disinnescherete": "disinnescare",
    "disinnescherà": "disinnescare",
    "disinnescherò": "disinnescare",
    "disinneschi": "disinnescare",
    "disinneschiamo": "disinnescare",
    "disinneschiate": "disinnescare",
    "disinneschin": "disinnescare",
    "disinneschino": "disinnescare",
    "disinnesco": "disinnescare",
    "disinnescò": "disinnescare",
    "disinnesta": "disinnestare",
    "disinnestai": "disinnestare",
    "disinnestammo": "disinnestare",
    "disinnestan": "disinnestare",
    "disinnestando": "disinnestare",
    "disinnestano": "disinnestare",
    "disinnestante": "disinnestare",
    "disinnestanti": "disinnestare",
    "disinnestar": "disinnestare",
    "disinnestaron": "disinnestare",
    "disinnestarono": "disinnestare",
    "disinnestasse": "disinnestare",
    "disinnestasser": "disinnestare",
    "disinnestassero": "disinnestare",
    "disinnestassi": "disinnestare",
    "disinnestassimo": "disinnestare",
    "disinnestaste": "disinnestare",
    "disinnestasti": "disinnestare",
    "disinnestata": "disinnestare",
    "disinnestate": "disinnestare",
    "disinnestati": "disinnestare",
    "disinnestato": "disinnestare",
    "disinnestava": "disinnestare",
    "disinnestavamo": "disinnestare",
    "disinnestavan": "disinnestare",
    "disinnestavano": "disinnestare",
    "disinnestavate": "disinnestare",
    "disinnestavi": "disinnestare",
    "disinnestavo": "disinnestare",
    "disinnesterai": "disinnestare",
    "disinnesteran": "disinnestare",
    "disinnesteranno": "disinnestare",
    "disinnesterebbe": "disinnestare",
    "disinnesterebber": "disinnestare",
    "disinnesterebbero": "disinnestare",
    "disinnesterei": "disinnestare",
    "disinnesteremmo": "disinnestare",
    "disinnesteremo": "disinnestare",
    "disinnestereste": "disinnestare",
    "disinnesteresti": "disinnestare",
    "disinnesterete": "disinnestare",
    "disinnesterà": "disinnestare",
    "disinnesterò": "disinnestare",
    "disinnesti": "disinnestare",
    "disinnestiamo": "disinnestare",
    "disinnestiate": "disinnestare",
    "disinnestin": "disinnestare",
    "disinnestino": "disinnestare",
    "disinnesto": "disinnestare",
    "disinnestò": "disinnestare",
    "disinquadra": "disinquadrare",
    "disinquadrai": "disinquadrare",
    "disinquadrammo": "disinquadrare",
    "disinquadran": "disinquadrare",
    "disinquadrando": "disinquadrare",
    "disinquadrano": "disinquadrare",
    "disinquadrante": "disinquadrare",
    "disinquadranti": "disinquadrare",
    "disinquadrar": "disinquadrare",
    "disinquadraron": "disinquadrare",
    "disinquadrarono": "disinquadrare",
    "disinquadrasse": "disinquadrare",
    "disinquadrasser": "disinquadrare",
    "disinquadrassero": "disinquadrare",
    "disinquadrassi": "disinquadrare",
    "disinquadrassimo": "disinquadrare",
    "disinquadraste": "disinquadrare",
    "disinquadrasti": "disinquadrare",
    "disinquadrata": "disinquadrare",
    "disinquadrate": "disinquadrare",
    "disinquadrati": "disinquadrare",
    "disinquadrato": "disinquadrare",
    "disinquadrava": "disinquadrare",
    "disinquadravamo": "disinquadrare",
    "disinquadravan": "disinquadrare",
    "disinquadravano": "disinquadrare",
    "disinquadravate": "disinquadrare",
    "disinquadravi": "disinquadrare",
    "disinquadravo": "disinquadrare",
    "disinquadrerai": "disinquadrare",
    "disinquadreran": "disinquadrare",
    "disinquadreranno": "disinquadrare",
    "disinquadrerebbe": "disinquadrare",
    "disinquadrerebber": "disinquadrare",
    "disinquadrerebbero": "disinquadrare",
    "disinquadrerei": "disinquadrare",
    "disinquadreremmo": "disinquadrare",
    "disinquadreremo": "disinquadrare",
    "disinquadrereste": "disinquadrare",
    "disinquadreresti": "disinquadrare",
    "disinquadrerete": "disinquadrare",
    "disinquadrerà": "disinquadrare",
    "disinquadrerò": "disinquadrare",
    "disinquadri": "disinquadrare",
    "disinquadriamo": "disinquadrare",
    "disinquadriate": "disinquadrare",
    "disinquadrin": "disinquadrare",
    "disinquadrino": "disinquadrare",
    "disinquadro": "disinquadrare",
    "disinquadrò": "disinquadrare",
    "disinquina": "disinquinare",
    "disinquinai": "disinquinare",
    "disinquinamenti": "disinquinamento",
    "disinquinammo": "disinquinare",
    "disinquinan": "disinquinare",
    "disinquinando": "disinquinare",
    "disinquinano": "disinquinare",
    "disinquinante": "disinquinare",
    "disinquinanti": "disinquinare",
    "disinquinar": "disinquinare",
    "disinquinaron": "disinquinare",
    "disinquinarono": "disinquinare",
    "disinquinasse": "disinquinare",
    "disinquinasser": "disinquinare",
    "disinquinassero": "disinquinare",
    "disinquinassi": "disinquinare",
    "disinquinassimo": "disinquinare",
    "disinquinaste": "disinquinare",
    "disinquinasti": "disinquinare",
    "disinquinata": "disinquinare",
    "disinquinate": "disinquinare",
    "disinquinati": "disinquinare",
    "disinquinato": "disinquinare",
    "disinquinava": "disinquinare",
    "disinquinavamo": "disinquinare",
    "disinquinavan": "disinquinare",
    "disinquinavano": "disinquinare",
    "disinquinavate": "disinquinare",
    "disinquinavi": "disinquinare",
    "disinquinavo": "disinquinare",
    "disinquinerai": "disinquinare",
    "disinquineran": "disinquinare",
    "disinquineranno": "disinquinare",
    "disinquinerebbe": "disinquinare",
    "disinquinerebber": "disinquinare",
    "disinquinerebbero": "disinquinare",
    "disinquinerei": "disinquinare",
    "disinquineremmo": "disinquinare",
    "disinquineremo": "disinquinare",
    "disinquinereste": "disinquinare",
    "disinquineresti": "disinquinare",
    "disinquinerete": "disinquinare",
    "disinquinerà": "disinquinare",
    "disinquinerò": "disinquinare",
    "disinquini": "disinquinare",
    "disinquiniamo": "disinquinare",
    "disinquiniate": "disinquinare",
    "disinquinin": "disinquinare",
    "disinquinino": "disinquinare",
    "disinquino": "disinquinare",
    "disinquinò": "disinquinare",
    "disintasa": "disintasare",
    "disintasai": "disintasare",
    "disintasammo": "disintasare",
    "disintasan": "disintasare",
    "disintasando": "disintasare",
    "disintasano": "disintasare",
    "disintasante": "disintasare",
    "disintasanti": "disintasare",
    "disintasar": "disintasare",
    "disintasaron": "disintasare",
    "disintasarono": "disintasare",
    "disintasasse": "disintasare",
    "disintasasser": "disintasare",
    "disintasassero": "disintasare",
    "disintasassi": "disintasare",
    "disintasassimo": "disintasare",
    "disintasaste": "disintasare",
    "disintasasti": "disintasare",
    "disintasata": "disintasare",
    "disintasate": "disintasare",
    "disintasati": "disintasare",
    "disintasato": "disintasare",
    "disintasava": "disintasare",
    "disintasavamo": "disintasare",
    "disintasavan": "disintasare",
    "disintasavano": "disintasare",
    "disintasavate": "disintasare",
    "disintasavi": "disintasare",
    "disintasavo": "disintasare",
    "disintaserai": "disintasare",
    "disintaseran": "disintasare",
    "disintaseranno": "disintasare",
    "disintaserebbe": "disintasare",
    "disintaserebber": "disintasare",
    "disintaserebbero": "disintasare",
    "disintaserei": "disintasare",
    "disintaseremmo": "disintasare",
    "disintaseremo": "disintasare",
    "disintasereste": "disintasare",
    "disintaseresti": "disintasare",
    "disintaserete": "disintasare",
    "disintaserà": "disintasare",
    "disintaserò": "disintasare",
    "disintasi": "disintasare",
    "disintasiamo": "disintasare",
    "disintasiate": "disintasare",
    "disintasin": "disintasare",
    "disintasino": "disintasare",
    "disintaso": "disintasare",
    "disintasò": "disintasare",
    "disintegra": "disintegrare",
    "disintegrai": "disintegrare",
    "disintegrammo": "disintegrare",
    "disintegran": "disintegrare",
    "disintegrando": "disintegrare",
    "disintegrano": "disintegrare",
    "disintegrante": "disintegrare",
    "disintegranti": "disintegrare",
    "disintegrar": "disintegrare",
    "disintegraron": "disintegrare",
    "disintegrarono": "disintegrare",
    "disintegrasse": "disintegrare",
    "disintegrasser": "disintegrare",
    "disintegrassero": "disintegrare",
    "disintegrassi": "disintegrare",
    "disintegrassimo": "disintegrare",
    "disintegraste": "disintegrare",
    "disintegrasti": "disintegrare",
    "disintegrata": "disintegrare",
    "disintegrate": "disintegrare",
    "disintegrati": "disintegrare",
    "disintegrato": "disintegrare",
    "disintegrava": "disintegrare",
    "disintegravamo": "disintegrare",
    "disintegravan": "disintegrare",
    "disintegravano": "disintegrare",
    "disintegravate": "disintegrare",
    "disintegravi": "disintegrare",
    "disintegravo": "disintegrare",
    "disintegrazioni": "disintegrazione",
    "disintegrerai": "disintegrare",
    "disintegreran": "disintegrare",
    "disintegreranno": "disintegrare",
    "disintegrerebbe": "disintegrare",
    "disintegrerebber": "disintegrare",
    "disintegrerebbero": "disintegrare",
    "disintegrerei": "disintegrare",
    "disintegreremmo": "disintegrare",
    "disintegreremo": "disintegrare",
    "disintegrereste": "disintegrare",
    "disintegreresti": "disintegrare",
    "disintegrerete": "disintegrare",
    "disintegrerà": "disintegrare",
    "disintegrerò": "disintegrare",
    "disintegri": "disintegrare",
    "disintegriamo": "disintegrare",
    "disintegriate": "disintegrare",
    "disintegrin": "disintegrare",
    "disintegrino": "disintegrare",
    "disintegro": "disintegrare",
    "disintegrò": "disintegrare",
    "disinteressa": "disinteressare",
    "disinteressai": "disinteressare",
    "disinteressammo": "disinteressare",
    "disinteressan": "disinteressare",
    "disinteressando": "disinteressare",
    "disinteressano": "disinteressare",
    "disinteressante": "disinteressare",
    "disinteressanti": "disinteressare",
    "disinteressar": "disinteressare",
    "disinteressaron": "disinteressare",
    "disinteressarono": "disinteressare",
    "disinteressasse": "disinteressare",
    "disinteressasser": "disinteressare",
    "disinteressassero": "disinteressare",
    "disinteressassi": "disinteressare",
    "disinteressassimo": "disinteressare",
    "disinteressaste": "disinteressare",
    "disinteressasti": "disinteressare",
    "disinteressata": "disinteressato",
    "disinteressate": "disinteressato",
    "disinteressati": "disinteressato",
    "disinteressato": "disinteressare",
    "disinteressava": "disinteressare",
    "disinteressavamo": "disinteressare",
    "disinteressavan": "disinteressare",
    "disinteressavano": "disinteressare",
    "disinteressavate": "disinteressare",
    "disinteressavi": "disinteressare",
    "disinteressavo": "disinteressare",
    "disinteresserai": "disinteressare",
    "disinteresseran": "disinteressare",
    "disinteresseranno": "disinteressare",
    "disinteresserebbe": "disinteressare",
    "disinteresserebber": "disinteressare",
    "disinteresserebbero": "disinteressare",
    "disinteresserei": "disinteressare",
    "disinteresseremmo": "disinteressare",
    "disinteresseremo": "disinteressare",
    "disinteressereste": "disinteressare",
    "disinteresseresti": "disinteressare",
    "disinteresserete": "disinteressare",
    "disinteresserà": "disinteressare",
    "disinteresserò": "disinteressare",
    "disinteressi": "disinteressare",
    "disinteressiamo": "disinteressare",
    "disinteressiate": "disinteressare",
    "disinteressin": "disinteressare",
    "disinteressino": "disinteressare",
    "disinteresso": "disinteressare",
    "disinteressò": "disinteressare",
    "disintermediazioni": "disintermediazione",
    "disintossica": "disintossicare",
    "disintossicai": "disintossicare",
    "disintossicammo": "disintossicare",
    "disintossican": "disintossicare",
    "disintossicando": "disintossicare",
    "disintossicano": "disintossicare",
    "disintossicante": "disintossicare",
    "disintossicanti": "disintossicare",
    "disintossicar": "disintossicare",
    "disintossicaron": "disintossicare",
    "disintossicarono": "disintossicare",
    "disintossicasse": "disintossicare",
    "disintossicasser": "disintossicare",
    "disintossicassero": "disintossicare",
    "disintossicassi": "disintossicare",
    "disintossicassimo": "disintossicare",
    "disintossicaste": "disintossicare",
    "disintossicasti": "disintossicare",
    "disintossicata": "disintossicare",
    "disintossicate": "disintossicare",
    "disintossicati": "disintossicare",
    "disintossicato": "disintossicare",
    "disintossicava": "disintossicare",
    "disintossicavamo": "disintossicare",
    "disintossicavan": "disintossicare",
    "disintossicavano": "disintossicare",
    "disintossicavate": "disintossicare",
    "disintossicavi": "disintossicare",
    "disintossicavo": "disintossicare",
    "disintossicazioni": "disintossicazione",
    "disintossicherai": "disintossicare",
    "disintossicheran": "disintossicare",
    "disintossicheranno": "disintossicare",
    "disintossicherebbe": "disintossicare",
    "disintossicherebber": "disintossicare",
    "disintossicherebbero": "disintossicare",
    "disintossicherei": "disintossicare",
    "disintossicheremmo": "disintossicare",
    "disintossicheremo": "disintossicare",
    "disintossichereste": "disintossicare",
    "disintossicheresti": "disintossicare",
    "disintossicherete": "disintossicare",
    "disintossicherà": "disintossicare",
    "disintossicherò": "disintossicare",
    "disintossichi": "disintossicare",
    "disintossichiamo": "disintossicare",
    "disintossichiate": "disintossicare",
    "disintossichin": "disintossicare",
    "disintossichino": "disintossicare",
    "disintossico": "disintossicare",
    "disintossicò": "disintossicare",
    "disinvestimenti": "disinvestimento",
    "disinvolta": "disinvolto",
    "disinvolte": "disinvolto",
    "disinvolti": "disinvolto",
    "disinvolture": "disinvoltura",
    "disistima": "disistimare",
    "disistimai": "disistimare",
    "disistimammo": "disistimare",
    "disistiman": "disistimare",
    "disistimando": "disistimare",
    "disistimano": "disistimare",
    "disistimante": "disistimare",
    "disistimanti": "disistimare",
    "disistimar": "disistimare",
    "disistimaron": "disistimare",
    "disistimarono": "disistimare",
    "disistimasse": "disistimare",
    "disistimasser": "disistimare",
    "disistimassero": "disistimare",
    "disistimassi": "disistimare",
    "disistimassimo": "disistimare",
    "disistimaste": "disistimare",
    "disistimasti": "disistimare",
    "disistimata": "disistimare",
    "disistimate": "disistimare",
    "disistimati": "disistimare",
    "disistimato": "disistimare",
    "disistimava": "disistimare",
    "disistimavamo": "disistimare",
    "disistimavan": "disistimare",
    "disistimavano": "disistimare",
    "disistimavate": "disistimare",
    "disistimavi": "disistimare",
    "disistimavo": "disistimare",
    "disistimerai": "disistimare",
    "disistimeran": "disistimare",
    "disistimeranno": "disistimare",
    "disistimerebbe": "disistimare",
    "disistimerebber": "disistimare",
    "disistimerebbero": "disistimare",
    "disistimerei": "disistimare",
    "disistimeremmo": "disistimare",
    "disistimeremo": "disistimare",
    "disistimereste": "disistimare",
    "disistimeresti": "disistimare",
    "disistimerete": "disistimare",
    "disistimerà": "disistimare",
    "disistimerò": "disistimare",
    "disistimi": "disistimare",
    "disistimiamo": "disistimare",
    "disistimiate": "disistimare",
    "disistimin": "disistimare",
    "disistimino": "disistimare",
    "disistimo": "disistimare",
    "disistimò": "disistimare",
    "dislivelli": "dislivello",
    "disloca": "dislocare",
    "dislocai": "dislocare",
    "dislocamenti": "dislocamento",
    "dislocammo": "dislocare",
    "dislocan": "dislocare",
    "dislocando": "dislocare",
    "dislocano": "dislocare",
    "dislocante": "dislocare",
    "dislocanti": "dislocare",
    "dislocar": "dislocare",
    "dislocaron": "dislocare",
    "dislocarono": "dislocare",
    "dislocasse": "dislocare",
    "dislocasser": "dislocare",
    "dislocassero": "dislocare",
    "dislocassi": "dislocare",
    "dislocassimo": "dislocare",
    "dislocaste": "dislocare",
    "dislocasti": "dislocare",
    "dislocata": "dislocare",
    "dislocate": "dislocare",
    "dislocati": "dislocare",
    "dislocato": "dislocare",
    "dislocava": "dislocare",
    "dislocavamo": "dislocare",
    "dislocavan": "dislocare",
    "dislocavano": "dislocare",
    "dislocavate": "dislocare",
    "dislocavi": "dislocare",
    "dislocavo": "dislocare",
    "dislocazioni": "dislocazione",
    "dislocherai": "dislocare",
    "dislocheran": "dislocare",
    "dislocheranno": "dislocare",
    "dislocherebbe": "dislocare",
    "dislocherebber": "dislocare",
    "dislocherebbero": "dislocare",
    "dislocherei": "dislocare",
    "dislocheremmo": "dislocare",
    "dislocheremo": "dislocare",
    "dislochereste": "dislocare",
    "dislocheresti": "dislocare",
    "dislocherete": "dislocare",
    "dislocherà": "dislocare",
    "dislocherò": "dislocare",
    "dislochi": "dislocare",
    "dislochiamo": "dislocare",
    "dislochiate": "dislocare",
    "dislochin": "dislocare",
    "dislochino": "dislocare",
    "disloco": "dislocare",
    "dislocò": "dislocare",
    "dismetta": "dismettere",
    "dismettan": "dismettere",
    "dismettano": "dismettere",
    "dismette": "dismettere",
    "dismettei": "dismettere",
    "dismettemmo": "dismettere",
    "dismettendo": "dismettere",
    "dismettente": "dismettere",
    "dismettenti": "dismettere",
    "dismetter": "dismettere",
    "dismetterai": "dismettere",
    "dismetteran": "dismettere",
    "dismetteranno": "dismettere",
    "dismetterebbe": "dismettere",
    "dismetterebber": "dismettere",
    "dismetterebbero": "dismettere",
    "dismetterei": "dismettere",
    "dismetteremmo": "dismettere",
    "dismetteremo": "dismettere",
    "dismettereste": "dismettere",
    "dismetteresti": "dismettere",
    "dismetterete": "dismettere",
    "dismetteron": "dismettere",
    "dismetterono": "dismettere",
    "dismetterà": "dismettere",
    "dismetterò": "dismettere",
    "dismettesse": "dismettere",
    "dismettesser": "dismettere",
    "dismettessero": "dismettere",
    "dismettessi": "dismettere",
    "dismettessimo": "dismettere",
    "dismetteste": "dismettere",
    "dismettesti": "dismettere",
    "dismettete": "dismettere",
    "dismetteva": "dismettere",
    "dismettevamo": "dismettere",
    "dismettevan": "dismettere",
    "dismettevano": "dismettere",
    "dismettevate": "dismettere",
    "dismettevi": "dismettere",
    "dismettevo": "dismettere",
    "dismetti": "dismettere",
    "dismettiamo": "dismettere",
    "dismettiate": "dismettere",
    "dismetto": "dismettere",
    "dismetton": "dismettere",
    "dismettono": "dismettere",
    "dismettuta": "dismettere",
    "dismettute": "dismettere",
    "dismettuti": "dismettere",
    "dismettuto": "dismettere",
    "dismettè": "dismettere",
    "dismissioni": "dismissione",
    "dismisure": "dismisura",
    "disneiana": "disneiano",
    "disneiane": "disneiano",
    "disneiani": "disneiano",
    "disneyana": "disneyano",
    "disneyane": "disneyano",
    "disneyani": "disneyano",
    "disobbedendo": "disobbedire",
    "disobbediamo": "disobbedire",
    "disobbediate": "disobbedire",
    "disobbediente": "disobbedire",
    "disobbedienti": "disobbedire",
    "disobbedienze": "disobbedienza",
    "disobbedii": "disobbedire",
    "disobbedimmo": "disobbedire",
    "disobbedir": "disobbedire",
    "disobbedirai": "disobbedire",
    "disobbediran": "disobbedire",
    "disobbediranno": "disobbedire",
    "disobbedirebbe": "disobbedire",
    "disobbedirebber": "disobbedire",
    "disobbedirebbero": "disobbedire",
    "disobbedirei": "disobbedire",
    "disobbediremmo": "disobbedire",
    "disobbediremo": "disobbedire",
    "disobbedireste": "disobbedire",
    "disobbediresti": "disobbedire",
    "disobbedirete": "disobbedire",
    "disobbediron": "disobbedire",
    "disobbedirono": "disobbedire",
    "disobbedirà": "disobbedire",
    "disobbedirò": "disobbedire",
    "disobbedisca": "disobbedire",
    "disobbediscan": "disobbedire",
    "disobbediscano": "disobbedire",
    "disobbedisce": "disobbedire",
    "disobbedisci": "disobbedire",
    "disobbedisco": "disobbedire",
    "disobbediscon": "disobbedire",
    "disobbediscono": "disobbedire",
    "disobbedisse": "disobbedire",
    "disobbedisser": "disobbedire",
    "disobbedissero": "disobbedire",
    "disobbedissi": "disobbedire",
    "disobbedissimo": "disobbedire",
    "disobbediste": "disobbedire",
    "disobbedisti": "disobbedire",
    "disobbedita": "disobbedire",
    "disobbedite": "disobbedire",
    "disobbediti": "disobbedire",
    "disobbedito": "disobbedire",
    "disobbediva": "disobbedire",
    "disobbedivamo": "disobbedire",
    "disobbedivan": "disobbedire",
    "disobbedivano": "disobbedire",
    "disobbedivate": "disobbedire",
    "disobbedivi": "disobbedire",
    "disobbedivo": "disobbedire",
    "disobbedì": "disobbedire",
    "disobbliga": "disobbligare",
    "disobbligai": "disobbligare",
    "disobbligammo": "disobbligare",
    "disobbligan": "disobbligare",
    "disobbligando": "disobbligare",
    "disobbligano": "disobbligare",
    "disobbligante": "disobbligare",
    "disobbliganti": "disobbligare",
    "disobbligar": "disobbligare",
    "disobbligaron": "disobbligare",
    "disobbligarono": "disobbligare",
    "disobbligasse": "disobbligare",
    "disobbligasser": "disobbligare",
    "disobbligassero": "disobbligare",
    "disobbligassi": "disobbligare",
    "disobbligassimo": "disobbligare",
    "disobbligaste": "disobbligare",
    "disobbligasti": "disobbligare",
    "disobbligata": "disobbligare",
    "disobbligate": "disobbligare",
    "disobbligati": "disobbligare",
    "disobbligato": "disobbligare",
    "disobbligava": "disobbligare",
    "disobbligavamo": "disobbligare",
    "disobbligavan": "disobbligare",
    "disobbligavano": "disobbligare",
    "disobbligavate": "disobbligare",
    "disobbligavi": "disobbligare",
    "disobbligavo": "disobbligare",
    "disobbligherai": "disobbligare",
    "disobbligheran": "disobbligare",
    "disobbligheranno": "disobbligare",
    "disobbligherebbe": "disobbligare",
    "disobbligherebber": "disobbligare",
    "disobbligherebbero": "disobbligare",
    "disobbligherei": "disobbligare",
    "disobbligheremmo": "disobbligare",
    "disobbligheremo": "disobbligare",
    "disobblighereste": "disobbligare",
    "disobbligheresti": "disobbligare",
    "disobbligherete": "disobbligare",
    "disobbligherà": "disobbligare",
    "disobbligherò": "disobbligare",
    "disobblighi": "disobbligare",
    "disobblighiamo": "disobbligare",
    "disobblighiate": "disobbligare",
    "disobblighin": "disobbligare",
    "disobblighino": "disobbligare",
    "disobbligo": "disobbligare",
    "disobbligò": "disobbligare",
    "disoccupa": "disoccupare",
    "disoccupai": "disoccupare",
    "disoccupammo": "disoccupare",
    "disoccupan": "disoccupare",
    "disoccupando": "disoccupare",
    "disoccupano": "disoccupare",
    "disoccupante": "disoccupare",
    "disoccupanti": "disoccupare",
    "disoccupar": "disoccupare",
    "disoccuparon": "disoccupare",
    "disoccuparono": "disoccupare",
    "disoccupasse": "disoccupare",
    "disoccupasser": "disoccupare",
    "disoccupassero": "disoccupare",
    "disoccupassi": "disoccupare",
    "disoccupassimo": "disoccupare",
    "disoccupaste": "disoccupare",
    "disoccupasti": "disoccupare",
    "disoccupata": "disoccupato",
    "disoccupate": "disoccupato",
    "disoccupati": "disoccupato",
    "disoccupato": "disoccupare",
    "disoccupava": "disoccupare",
    "disoccupavamo": "disoccupare",
    "disoccupavan": "disoccupare",
    "disoccupavano": "disoccupare",
    "disoccupavate": "disoccupare",
    "disoccupavi": "disoccupare",
    "disoccupavo": "disoccupare",
    "disoccupazioni": "disoccupazione",
    "disoccuperai": "disoccupare",
    "disoccuperan": "disoccupare",
    "disoccuperanno": "disoccupare",
    "disoccuperebbe": "disoccupare",
    "disoccuperebber": "disoccupare",
    "disoccuperebbero": "disoccupare",
    "disoccuperei": "disoccupare",
    "disoccuperemmo": "disoccupare",
    "disoccuperemo": "disoccupare",
    "disoccupereste": "disoccupare",
    "disoccuperesti": "disoccupare",
    "disoccuperete": "disoccupare",
    "disoccuperà": "disoccupare",
    "disoccuperò": "disoccupare",
    "disoccupi": "disoccupare",
    "disoccupiamo": "disoccupare",
    "disoccupiate": "disoccupare",
    "disoccupin": "disoccupare",
    "disoccupino": "disoccupare",
    "disoccupo": "disoccupare",
    "disoccupò": "disoccupare",
    "disomogenea": "disomogeneo",
    "disomogenee": "disomogeneo",
    "disomogenei": "disomogeneo",
    "disonesta": "disonesto",
    "disoneste": "disonesto",
    "disonesti": "disonesto",
    "disonora": "disonorare",
    "disonorai": "disonorare",
    "disonorammo": "disonorare",
    "disonoran": "disonorare",
    "disonorando": "disonorare",
    "disonorano": "disonorare",
    "disonorante": "disonorare",
    "disonoranti": "disonorare",
    "disonorar": "disonorare",
    "disonoraron": "disonorare",
    "disonorarono": "disonorare",
    "disonorasse": "disonorare",
    "disonorasser": "disonorare",
    "disonorassero": "disonorare",
    "disonorassi": "disonorare",
    "disonorassimo": "disonorare",
    "disonoraste": "disonorare",
    "disonorasti": "disonorare",
    "disonorata": "disonorare",
    "disonorate": "disonorare",
    "disonorati": "disonorare",
    "disonorato": "disonorare",
    "disonorava": "disonorare",
    "disonoravamo": "disonorare",
    "disonoravan": "disonorare",
    "disonoravano": "disonorare",
    "disonoravate": "disonorare",
    "disonoravi": "disonorare",
    "disonoravo": "disonorare",
    "disonorerai": "disonorare",
    "disonoreran": "disonorare",
    "disonoreranno": "disonorare",
    "disonorerebbe": "disonorare",
    "disonorerebber": "disonorare",
    "disonorerebbero": "disonorare",
    "disonorerei": "disonorare",
    "disonoreremmo": "disonorare",
    "disonoreremo": "disonorare",
    "disonorereste": "disonorare",
    "disonoreresti": "disonorare",
    "disonorerete": "disonorare",
    "disonorerà": "disonorare",
    "disonorerò": "disonorare",
    "disonorevoli": "disonorevole",
    "disonori": "disonore",
    "disonoriamo": "disonorare",
    "disonoriate": "disonorare",
    "disonorin": "disonorare",
    "disonorino": "disonorare",
    "disonoro": "disonorare",
    "disonorò": "disonorare",
    "disordina": "disordinare",
    "disordinai": "disordinare",
    "disordinammo": "disordinare",
    "disordinan": "disordinare",
    "disordinando": "disordinare",
    "disordinano": "disordinare",
    "disordinante": "disordinare",
    "disordinanti": "disordinare",
    "disordinar": "disordinare",
    "disordinaron": "disordinare",
    "disordinarono": "disordinare",
    "disordinasse": "disordinare",
    "disordinasser": "disordinare",
    "disordinassero": "disordinare",
    "disordinassi": "disordinare",
    "disordinassimo": "disordinare",
    "disordinaste": "disordinare",
    "disordinasti": "disordinare",
    "disordinata": "disordinato",
    "disordinate": "disordinato",
    "disordinati": "disordinato",
    "disordinato": "disordinare",
    "disordinava": "disordinare",
    "disordinavamo": "disordinare",
    "disordinavan": "disordinare",
    "disordinavano": "disordinare",
    "disordinavate": "disordinare",
    "disordinavi": "disordinare",
    "disordinavo": "disordinare",
    "disordinerai": "disordinare",
    "disordineran": "disordinare",
    "disordineranno": "disordinare",
    "disordinerebbe": "disordinare",
    "disordinerebber": "disordinare",
    "disordinerebbero": "disordinare",
    "disordinerei": "disordinare",
    "disordineremmo": "disordinare",
    "disordineremo": "disordinare",
    "disordinereste": "disordinare",
    "disordineresti": "disordinare",
    "disordinerete": "disordinare",
    "disordinerà": "disordinare",
    "disordinerò": "disordinare",
    "disordini": "disordine",
    "disordiniamo": "disordinare",
    "disordiniate": "disordinare",
    "disordinin": "disordinare",
    "disordinino": "disordinare",
    "disordino": "disordinare",
    "disordinò": "disordinare",
    "disorganica": "disorganico",
    "disorganiche": "disorganico",
    "disorganici": "disorganico",
    "disorganizza": "disorganizzare",
    "disorganizzai": "disorganizzare",
    "disorganizzammo": "disorganizzare",
    "disorganizzan": "disorganizzare",
    "disorganizzando": "disorganizzare",
    "disorganizzano": "disorganizzare",
    "disorganizzante": "disorganizzare",
    "disorganizzanti": "disorganizzare",
    "disorganizzar": "disorganizzare",
    "disorganizzaron": "disorganizzare",
    "disorganizzarono": "disorganizzare",
    "disorganizzasse": "disorganizzare",
    "disorganizzasser": "disorganizzare",
    "disorganizzassero": "disorganizzare",
    "disorganizzassi": "disorganizzare",
    "disorganizzassimo": "disorganizzare",
    "disorganizzaste": "disorganizzare",
    "disorganizzasti": "disorganizzare",
    "disorganizzata": "disorganizzato",
    "disorganizzate": "disorganizzato",
    "disorganizzati": "disorganizzato",
    "disorganizzato": "disorganizzare",
    "disorganizzava": "disorganizzare",
    "disorganizzavamo": "disorganizzare",
    "disorganizzavan": "disorganizzare",
    "disorganizzavano": "disorganizzare",
    "disorganizzavate": "disorganizzare",
    "disorganizzavi": "disorganizzare",
    "disorganizzavo": "disorganizzare",
    "disorganizzazioni": "disorganizzazione",
    "disorganizzerai": "disorganizzare",
    "disorganizzeran": "disorganizzare",
    "disorganizzeranno": "disorganizzare",
    "disorganizzerebbe": "disorganizzare",
    "disorganizzerebber": "disorganizzare",
    "disorganizzerebbero": "disorganizzare",
    "disorganizzerei": "disorganizzare",
    "disorganizzeremmo": "disorganizzare",
    "disorganizzeremo": "disorganizzare",
    "disorganizzereste": "disorganizzare",
    "disorganizzeresti": "disorganizzare",
    "disorganizzerete": "disorganizzare",
    "disorganizzerà": "disorganizzare",
    "disorganizzerò": "disorganizzare",
    "disorganizzi": "disorganizzare",
    "disorganizziamo": "disorganizzare",
    "disorganizziate": "disorganizzare",
    "disorganizzin": "disorganizzare",
    "disorganizzino": "disorganizzare",
    "disorganizzo": "disorganizzare",
    "disorganizzò": "disorganizzare",
    "disorienta": "disorientare",
    "disorientai": "disorientare",
    "disorientamenti": "disorientamento",
    "disorientammo": "disorientare",
    "disorientan": "disorientare",
    "disorientando": "disorientare",
    "disorientano": "disorientare",
    "disorientante": "disorientare",
    "disorientanti": "disorientare",
    "disorientar": "disorientare",
    "disorientaron": "disorientare",
    "disorientarono": "disorientare",
    "disorientasse": "disorientare",
    "disorientasser": "disorientare",
    "disorientassero": "disorientare",
    "disorientassi": "disorientare",
    "disorientassimo": "disorientare",
    "disorientaste": "disorientare",
    "disorientasti": "disorientare",
    "disorientata": "disorientato",
    "disorientate": "disorientato",
    "disorientati": "disorientato",
    "disorientato": "disorientare",
    "disorientava": "disorientare",
    "disorientavamo": "disorientare",
    "disorientavan": "disorientare",
    "disorientavano": "disorientare",
    "disorientavate": "disorientare",
    "disorientavi": "disorientare",
    "disorientavo": "disorientare",
    "disorienterai": "disorientare",
    "disorienteran": "disorientare",
    "disorienteranno": "disorientare",
    "disorienterebbe": "disorientare",
    "disorienterebber": "disorientare",
    "disorienterebbero": "disorientare",
    "disorienterei": "disorientare",
    "disorienteremmo": "disorientare",
    "disorienteremo": "disorientare",
    "disorientereste": "disorientare",
    "disorienteresti": "disorientare",
    "disorienterete": "disorientare",
    "disorienterà": "disorientare",
    "disorienterò": "disorientare",
    "disorienti": "disorientare",
    "disorientiamo": "disorientare",
    "disorientiate": "disorientare",
    "disorientin": "disorientare",
    "disorientino": "disorientare",
    "disoriento": "disorientare",
    "disorientò": "disorientare",
    "disossa": "disossare",
    "disossai": "disossare",
    "disossammo": "disossare",
    "disossan": "disossare",
    "disossando": "disossare",
    "disossano": "disossare",
    "disossante": "disossare",
    "disossanti": "disossare",
    "disossar": "disossare",
    "disossaron": "disossare",
    "disossarono": "disossare",
    "disossasse": "disossare",
    "disossasser": "disossare",
    "disossassero": "disossare",
    "disossassi": "disossare",
    "disossassimo": "disossare",
    "disossaste": "disossare",
    "disossasti": "disossare",
    "disossata": "disossare",
    "disossate": "disossare",
    "disossati": "disossare",
    "disossato": "disossare",
    "disossava": "disossare",
    "disossavamo": "disossare",
    "disossavan": "disossare",
    "disossavano": "disossare",
    "disossavate": "disossare",
    "disossavi": "disossare",
    "disossavo": "disossare",
    "disosserai": "disossare",
    "disosseran": "disossare",
    "disosseranno": "disossare",
    "disosserebbe": "disossare",
    "disosserebber": "disossare",
    "disosserebbero": "disossare",
    "disosserei": "disossare",
    "disosseremmo": "disossare",
    "disosseremo": "disossare",
    "disossereste": "disossare",
    "disosseresti": "disossare",
    "disosserete": "disossare",
    "disosserà": "disossare",
    "disosserò": "disossare",
    "disossi": "disossare",
    "disossiamo": "disossare",
    "disossiate": "disossare",
    "disossin": "disossare",
    "disossino": "disossare",
    "disosso": "disossare",
    "disossò": "disossare",
    "dispacci": "dispaccio",
    "dispara": "disparire",
    "disparan": "disparire",
    "disparano": "disparire",
    "disparata": "disparato",
    "disparate": "disparato",
    "disparati": "disparato",
    "dispare": "disparire",
    "disparendo": "disparire",
    "disparente": "disparire",
    "disparenti": "disparire",
    "dispari": "disparire",
    "dispariamo": "disparire",
    "dispariate": "disparire",
    "disparii": "disparire",
    "disparimmo": "disparire",
    "disparir": "disparire",
    "disparirai": "disparire",
    "dispariran": "disparire",
    "dispariranno": "disparire",
    "disparirebbe": "disparire",
    "disparirebber": "disparire",
    "disparirebbero": "disparire",
    "disparirei": "disparire",
    "dispariremmo": "disparire",
    "dispariremo": "disparire",
    "disparireste": "disparire",
    "dispariresti": "disparire",
    "disparirete": "disparire",
    "dispariron": "disparire",
    "disparirono": "disparire",
    "disparirà": "disparire",
    "disparirò": "disparire",
    "disparisse": "disparire",
    "disparisser": "disparire",
    "disparissero": "disparire",
    "disparissi": "disparire",
    "disparissimo": "disparire",
    "dispariste": "disparire",
    "disparisti": "disparire",
    "disparita": "disparire",
    "disparite": "disparire",
    "dispariti": "disparire",
    "disparito": "disparire",
    "dispariva": "disparire",
    "disparivamo": "disparire",
    "disparivan": "disparire",
    "disparivano": "disparire",
    "disparivate": "disparire",
    "disparivi": "disparire",
    "disparivo": "disparire",
    "disparo": "disparire",
    "disparon": "disparire",
    "disparono": "disparire",
    "disparì": "disparire",
    "dispendi": "dispendio",
    "dispendiosa": "dispendioso",
    "dispendiose": "dispendioso",
    "dispendiosi": "dispendioso",
    "dispensa": "dispensare",
    "dispensai": "dispensare",
    "dispensammo": "dispensare",
    "dispensan": "dispensare",
    "dispensando": "dispensare",
    "dispensano": "dispensare",
    "dispensante": "dispensare",
    "dispensanti": "dispensare",
    "dispensar": "dispensare",
    "dispensari": "dispensario",
    "dispensaron": "dispensare",
    "dispensarono": "dispensare",
    "dispensasse": "dispensare",
    "dispensasser": "dispensare",
    "dispensassero": "dispensare",
    "dispensassi": "dispensare",
    "dispensassimo": "dispensare",
    "dispensaste": "dispensare",
    "dispensasti": "dispensare",
    "dispensata": "dispensare",
    "dispensate": "dispensare",
    "dispensati": "dispensare",
    "dispensato": "dispensare",
    "dispensatori": "dispensatore",
    "dispensatrice": "dispensatore",
    "dispensatrici": "dispensatore",
    "dispensava": "dispensare",
    "dispensavamo": "dispensare",
    "dispensavan": "dispensare",
    "dispensavano": "dispensare",
    "dispensavate": "dispensare",
    "dispensavi": "dispensare",
    "dispensavo": "dispensare",
    "dispense": "dispensa",
    "dispenserai": "dispensare",
    "dispenseran": "dispensare",
    "dispenseranno": "dispensare",
    "dispenserebbe": "dispensare",
    "dispenserebber": "dispensare",
    "dispenserebbero": "dispensare",
    "dispenserei": "dispensare",
    "dispenseremmo": "dispensare",
    "dispenseremo": "dispensare",
    "dispensereste": "dispensare",
    "dispenseresti": "dispensare",
    "dispenserete": "dispensare",
    "dispenserà": "dispensare",
    "dispenserò": "dispensare",
    "dispensi": "dispensare",
    "dispensiamo": "dispensare",
    "dispensiate": "dispensare",
    "dispensin": "dispensare",
    "dispensino": "dispensare",
    "dispenso": "dispensare",
    "dispensò": "dispensare",
    "dispepsie": "dispepsia",
    "dispera": "disperare",
    "disperai": "disperare",
    "disperammo": "disperare",
    "disperan": "disperare",
    "disperando": "disperare",
    "disperano": "disperare",
    "disperante": "disperare",
    "disperanti": "disperare",
    "disperar": "disperare",
    "disperaron": "disperare",
    "disperarono": "disperare",
    "disperasse": "disperare",
    "disperasser": "disperare",
    "disperassero": "disperare",
    "disperassi": "disperare",
    "disperassimo": "disperare",
    "disperaste": "disperare",
    "disperasti": "disperare",
    "disperata": "disperato",
    "disperate": "disperato",
    "disperati": "disperato",
    "disperato": "disperare",
    "disperava": "disperare",
    "disperavamo": "disperare",
    "disperavan": "disperare",
    "disperavano": "disperare",
    "disperavate": "disperare",
    "disperavi": "disperare",
    "disperavo": "disperare",
    "disperazioni": "disperazione",
    "disperda": "disperdere",
    "disperdan": "disperdere",
    "disperdano": "disperdere",
    "disperde": "disperdere",
    "disperdemmo": "disperdere",
    "disperdendo": "disperdere",
    "disperdente": "disperdere",
    "disperdenti": "disperdere",
    "disperder": "disperdere",
    "disperderai": "disperdere",
    "disperderan": "disperdere",
    "disperderanno": "disperdere",
    "disperderebbe": "disperdere",
    "disperderebber": "disperdere",
    "disperderebbero": "disperdere",
    "disperderei": "disperdere",
    "disperderemmo": "disperdere",
    "disperderemo": "disperdere",
    "disperdereste": "disperdere",
    "disperderesti": "disperdere",
    "disperderete": "disperdere",
    "disperderà": "disperdere",
    "disperderò": "disperdere",
    "disperdesse": "disperdere",
    "disperdesser": "disperdere",
    "disperdessero": "disperdere",
    "disperdessi": "disperdere",
    "disperdessimo": "disperdere",
    "disperdeste": "disperdere",
    "disperdesti": "disperdere",
    "disperdete": "disperdere",
    "disperdeva": "disperdere",
    "disperdevamo": "disperdere",
    "disperdevan": "disperdere",
    "disperdevano": "disperdere",
    "disperdevate": "disperdere",
    "disperdevi": "disperdere",
    "disperdevo": "disperdere",
    "disperdi": "disperdere",
    "disperdiamo": "disperdere",
    "disperdiate": "disperdere",
    "disperdo": "disperdere",
    "disperdon": "disperdere",
    "disperdono": "disperdere",
    "dispererai": "disperare",
    "dispereran": "disperare",
    "dispereranno": "disperare",
    "dispererebbe": "disperare",
    "dispererebber": "disperare",
    "dispererebbero": "disperare",
    "dispererei": "disperare",
    "dispereremmo": "disperare",
    "dispereremo": "disperare",
    "disperereste": "disperare",
    "dispereresti": "disperare",
    "dispererete": "disperare",
    "dispererà": "disperare",
    "dispererò": "disperare",
    "disperi": "disperare",
    "disperiamo": "disperare",
    "disperiate": "disperare",
    "disperin": "disperare",
    "disperino": "disperare",
    "dispero": "disperare",
    "dispersa": "disperso",
    "disperse": "disperso",
    "disperser": "disperdere",
    "dispersero": "disperdere",
    "dispersi": "disperso",
    "dispersioni": "dispersione",
    "dispersiva": "dispersivo",
    "dispersive": "dispersivo",
    "dispersivi": "dispersivo",
    "disperso": "disperdere",
    "dispersè": "disperdere",
    "disperò": "disperare",
    "dispetti": "dispetto",
    "dispettosa": "dispettoso",
    "dispettose": "dispettoso",
    "dispettosi": "dispettoso",
    "dispiaccia": "dispiacere",
    "dispiacciamo": "dispiacere",
    "dispiaccian": "dispiacere",
    "dispiacciano": "dispiacere",
    "dispiacciate": "dispiacere",
    "dispiaccio": "dispiacere",
    "dispiaccion": "dispiacere",
    "dispiacciono": "dispiacere",
    "dispiace": "dispiacere",
    "dispiacemmo": "dispiacere",
    "dispiacendo": "dispiacere",
    "dispiacente": "dispiacere",
    "dispiacenti": "dispiacere",
    "dispiacer": "dispiacere",
    "dispiacerai": "dispiacere",
    "dispiaceran": "dispiacere",
    "dispiaceranno": "dispiacere",
    "dispiacerebbe": "dispiacere",
    "dispiacerebber": "dispiacere",
    "dispiacerebbero": "dispiacere",
    "dispiacerei": "dispiacere",
    "dispiaceremmo": "dispiacere",
    "dispiaceremo": "dispiacere",
    "dispiacereste": "dispiacere",
    "dispiaceresti": "dispiacere",
    "dispiacerete": "dispiacere",
    "dispiaceri": "dispiacere",
    "dispiacerà": "dispiacere",
    "dispiacerò": "dispiacere",
    "dispiacesse": "dispiacere",
    "dispiacesser": "dispiacere",
    "dispiacessero": "dispiacere",
    "dispiacessi": "dispiacere",
    "dispiacessimo": "dispiacere",
    "dispiaceste": "dispiacere",
    "dispiacesti": "dispiacere",
    "dispiacete": "dispiacere",
    "dispiaceva": "dispiacere",
    "dispiacevamo": "dispiacere",
    "dispiacevan": "dispiacere",
    "dispiacevano": "dispiacere",
    "dispiacevate": "dispiacere",
    "dispiacevi": "dispiacere",
    "dispiacevo": "dispiacere",
    "dispiaci": "dispiacere",
    "dispiaciuta": "dispiaciuto",
    "dispiaciute": "dispiaciuto",
    "dispiaciuti": "dispiaciuto",
    "dispiaciuto": "dispiacere",
    "dispiacque": "dispiacere",
    "dispiacquer": "dispiacere",
    "dispiacquero": "dispiacere",
    "dispiacqui": "dispiacere",
    "dispiega": "dispiegare",
    "dispiegai": "dispiegare",
    "dispiegamenti": "dispiegamento",
    "dispiegammo": "dispiegare",
    "dispiegan": "dispiegare",
    "dispiegando": "dispiegare",
    "dispiegano": "dispiegare",
    "dispiegante": "dispiegare",
    "dispieganti": "dispiegare",
    "dispiegar": "dispiegare",
    "dispiegaron": "dispiegare",
    "dispiegarono": "dispiegare",
    "dispiegasse": "dispiegare",
    "dispiegasser": "dispiegare",
    "dispiegassero": "dispiegare",
    "dispiegassi": "dispiegare",
    "dispiegassimo": "dispiegare",
    "dispiegaste": "dispiegare",
    "dispiegasti": "dispiegare",
    "dispiegata": "dispiegare",
    "dispiegate": "dispiegare",
    "dispiegati": "dispiegare",
    "dispiegato": "dispiegare",
    "dispiegava": "dispiegare",
    "dispiegavamo": "dispiegare",
    "dispiegavan": "dispiegare",
    "dispiegavano": "dispiegare",
    "dispiegavate": "dispiegare",
    "dispiegavi": "dispiegare",
    "dispiegavo": "dispiegare",
    "dispiegherai": "dispiegare",
    "dispiegheran": "dispiegare",
    "dispiegheranno": "dispiegare",
    "dispiegherebbe": "dispiegare",
    "dispiegherebber": "dispiegare",
    "dispiegherebbero": "dispiegare",
    "dispiegherei": "dispiegare",
    "dispiegheremmo": "dispiegare",
    "dispiegheremo": "dispiegare",
    "dispieghereste": "dispiegare",
    "dispiegheresti": "dispiegare",
    "dispiegherete": "dispiegare",
    "dispiegherà": "dispiegare",
    "dispiegherò": "dispiegare",
    "dispieghi": "dispiegare",
    "dispieghiamo": "dispiegare",
    "dispieghiate": "dispiegare",
    "dispieghin": "dispiegare",
    "dispieghino": "dispiegare",
    "dispiego": "dispiegare",
    "dispiegò": "dispiegare",
    "dispone": "disporre",
    "disponemmo": "disporre",
    "disponendo": "disporre",
    "disponente": "disporre",
    "disponenti": "disporre",
    "disponesse": "disporre",
    "disponesser": "disporre",
    "disponessero": "disporre",
    "disponessi": "disporre",
    "disponessimo": "disporre",
    "disponeste": "disporre",
    "disponesti": "disporre",
    "disponete": "disporre",
    "disponeva": "disporre",
    "disponevamo": "disporre",
    "disponevan": "disporre",
    "disponevano": "disporre",
    "disponevate": "disporre",
    "disponevi": "disporre",
    "disponevo": "disporre",
    "disponga": "disporre",
    "dispongan": "disporre",
    "dispongano": "disporre",
    "dispongo": "disporre",
    "dispongon": "disporre",
    "dispongono": "disporre",
    "disponi": "disporre",
    "disponiamo": "disporre",
    "disponiate": "disporre",
    "disponibili": "disponibile",
    "disporr": "disporre",
    "disporrai": "disporre",
    "disporran": "disporre",
    "disporranno": "disporre",
    "disporrebbe": "disporre",
    "disporrebber": "disporre",
    "disporrebbero": "disporre",
    "disporrei": "disporre",
    "disporremmo": "disporre",
    "disporremo": "disporre",
    "disporreste": "disporre",
    "disporresti": "disporre",
    "disporrete": "disporre",
    "disporrà": "disporre",
    "disporrò": "disporre",
    "dispose": "disporre",
    "disposer": "disporre",
    "disposero": "disporre",
    "disposi": "disporre",
    "dispositiva": "dispositivo",
    "dispositive": "dispositivo",
    "dispositivi": "dispositivo",
    "disposizioni": "disposizione",
    "disposta": "disposto",
    "disposte": "disposto",
    "disposti": "disposto",
    "disposto": "disporre",
    "dispotica": "dispotico",
    "dispotiche": "dispotico",
    "dispotici": "dispotico",
    "dispotismi": "dispotismo",
    "dispregerai": "dispregiare",
    "dispregeran": "dispregiare",
    "dispregeranno": "dispregiare",
    "dispregerebbe": "dispregiare",
    "dispregerebber": "dispregiare",
    "dispregerebbero": "dispregiare",
    "dispregerei": "dispregiare",
    "dispregeremmo": "dispregiare",
    "dispregeremo": "dispregiare",
    "dispregereste": "dispregiare",
    "dispregeresti": "dispregiare",
    "dispregerete": "dispregiare",
    "dispregerà": "dispregiare",
    "dispregerò": "dispregiare",
    "dispregi": "dispregiare",
    "dispregia": "dispregiare",
    "dispregiai": "dispregiare",
    "dispregiammo": "dispregiare",
    "dispregiamo": "dispregiare",
    "dispregian": "dispregiare",
    "dispregiando": "dispregiare",
    "dispregiano": "dispregiare",
    "dispregiante": "dispregiare",
    "dispregianti": "dispregiare",
    "dispregiar": "dispregiare",
    "dispregiaron": "dispregiare",
    "dispregiarono": "dispregiare",
    "dispregiasse": "dispregiare",
    "dispregiasser": "dispregiare",
    "dispregiassero": "dispregiare",
    "dispregiassi": "dispregiare",
    "dispregiassimo": "dispregiare",
    "dispregiaste": "dispregiare",
    "dispregiasti": "dispregiare",
    "dispregiata": "dispregiare",
    "dispregiate": "dispregiare",
    "dispregiati": "dispregiare",
    "dispregiativa": "dispregiativo",
    "dispregiative": "dispregiativo",
    "dispregiativi": "dispregiativo",
    "dispregiato": "dispregiare",
    "dispregiava": "dispregiare",
    "dispregiavamo": "dispregiare",
    "dispregiavan": "dispregiare",
    "dispregiavano": "dispregiare",
    "dispregiavate": "dispregiare",
    "dispregiavi": "dispregiare",
    "dispregiavo": "dispregiare",
    "dispregin": "dispregiare",
    "dispregino": "dispregiare",
    "dispregio": "dispregiare",
    "dispregiò": "dispregiare",
    "disprezza": "disprezzare",
    "disprezzabili": "disprezzabile",
    "disprezzai": "disprezzare",
    "disprezzammo": "disprezzare",
    "disprezzan": "disprezzare",
    "disprezzando": "disprezzare",
    "disprezzano": "disprezzare",
    "disprezzante": "disprezzare",
    "disprezzanti": "disprezzare",
    "disprezzar": "disprezzare",
    "disprezzaron": "disprezzare",
    "disprezzarono": "disprezzare",
    "disprezzasse": "disprezzare",
    "disprezzasser": "disprezzare",
    "disprezzassero": "disprezzare",
    "disprezzassi": "disprezzare",
    "disprezzassimo": "disprezzare",
    "disprezzaste": "disprezzare",
    "disprezzasti": "disprezzare",
    "disprezzata": "disprezzare",
    "disprezzate": "disprezzare",
    "disprezzati": "disprezzare",
    "disprezzato": "disprezzare",
    "disprezzava": "disprezzare",
    "disprezzavamo": "disprezzare",
    "disprezzavan": "disprezzare",
    "disprezzavano": "disprezzare",
    "disprezzavate": "disprezzare",
    "disprezzavi": "disprezzare",
    "disprezzavo": "disprezzare",
    "disprezzerai": "disprezzare",
    "disprezzeran": "disprezzare",
    "disprezzeranno": "disprezzare",
    "disprezzerebbe": "disprezzare",
    "disprezzerebber": "disprezzare",
    "disprezzerebbero": "disprezzare",
    "disprezzerei": "disprezzare",
    "disprezzeremmo": "disprezzare",
    "disprezzeremo": "disprezzare",
    "disprezzereste": "disprezzare",
    "disprezzeresti": "disprezzare",
    "disprezzerete": "disprezzare",
    "disprezzerà": "disprezzare",
    "disprezzerò": "disprezzare",
    "disprezzi": "disprezzo",
    "disprezziamo": "disprezzare",
    "disprezziate": "disprezzare",
    "disprezzin": "disprezzare",
    "disprezzino": "disprezzare",
    "disprezzo": "disprezzare",
    "disprezzò": "disprezzare",
    "disputa": "disputare",
    "disputai": "disputare",
    "disputammo": "disputare",
    "disputan": "disputare",
    "disputando": "disputare",
    "disputano": "disputare",
    "disputante": "disputare",
    "disputanti": "disputare",
    "disputar": "disputare",
    "disputaron": "disputare",
    "disputarono": "disputare",
    "disputasse": "disputare",
    "disputasser": "disputare",
    "disputassero": "disputare",
    "disputassi": "disputare",
    "disputassimo": "disputare",
    "disputaste": "disputare",
    "disputasti": "disputare",
    "disputata": "disputare",
    "disputate": "disputare",
    "disputati": "disputare",
    "disputato": "disputare",
    "disputava": "disputare",
    "disputavamo": "disputare",
    "disputavan": "disputare",
    "disputavano": "disputare",
    "disputavate": "disputare",
    "disputavi": "disputare",
    "disputavo": "disputare",
    "dispute": "disputa",
    "disputerai": "disputare",
    "disputeran": "disputare",
    "disputeranno": "disputare",
    "disputerebbe": "disputare",
    "disputerebber": "disputare",
    "disputerebbero": "disputare",
    "disputerei": "disputare",
    "disputeremmo": "disputare",
    "disputeremo": "disputare",
    "disputereste": "disputare",
    "disputeresti": "disputare",
    "disputerete": "disputare",
    "disputerà": "disputare",
    "disputerò": "disputare",
    "disputi": "disputare",
    "disputiamo": "disputare",
    "disputiate": "disputare",
    "disputin": "disputare",
    "disputino": "disputare",
    "disputo": "disputare",
    "disputò": "disputare",
    "disquisendo": "disquisire",
    "disquisente": "disquisire",
    "disquisenti": "disquisire",
    "disquisiamo": "disquisire",
    "disquisiate": "disquisire",
    "disquisii": "disquisire",
    "disquisimmo": "disquisire",
    "disquisir": "disquisire",
    "disquisirai": "disquisire",
    "disquisiran": "disquisire",
    "disquisiranno": "disquisire",
    "disquisirebbe": "disquisire",
    "disquisirebber": "disquisire",
    "disquisirebbero": "disquisire",
    "disquisirei": "disquisire",
    "disquisiremmo": "disquisire",
    "disquisiremo": "disquisire",
    "disquisireste": "disquisire",
    "disquisiresti": "disquisire",
    "disquisirete": "disquisire",
    "disquisiron": "disquisire",
    "disquisirono": "disquisire",
    "disquisirà": "disquisire",
    "disquisirò": "disquisire",
    "disquisisca": "disquisire",
    "disquisiscan": "disquisire",
    "disquisiscano": "disquisire",
    "disquisisce": "disquisire",
    "disquisisci": "disquisire",
    "disquisisco": "disquisire",
    "disquisiscon": "disquisire",
    "disquisiscono": "disquisire",
    "disquisisse": "disquisire",
    "disquisisser": "disquisire",
    "disquisissero": "disquisire",
    "disquisissi": "disquisire",
    "disquisissimo": "disquisire",
    "disquisiste": "disquisire",
    "disquisisti": "disquisire",
    "disquisita": "disquisire",
    "disquisite": "disquisire",
    "disquisiti": "disquisire",
    "disquisito": "disquisire",
    "disquisiva": "disquisire",
    "disquisivamo": "disquisire",
    "disquisivan": "disquisire",
    "disquisivano": "disquisire",
    "disquisivate": "disquisire",
    "disquisivi": "disquisire",
    "disquisivo": "disquisire",
    "disquisizioni": "disquisizione",
    "disquisì": "disquisire",
    "dissacra": "dissacrare",
    "dissacrai": "dissacrare",
    "dissacrammo": "dissacrare",
    "dissacran": "dissacrare",
    "dissacrando": "dissacrare",
    "dissacrano": "dissacrare",
    "dissacrante": "dissacrare",
    "dissacranti": "dissacrare",
    "dissacrar": "dissacrare",
    "dissacraron": "dissacrare",
    "dissacrarono": "dissacrare",
    "dissacrasse": "dissacrare",
    "dissacrasser": "dissacrare",
    "dissacrassero": "dissacrare",
    "dissacrassi": "dissacrare",
    "dissacrassimo": "dissacrare",
    "dissacraste": "dissacrare",
    "dissacrasti": "dissacrare",
    "dissacrata": "dissacrare",
    "dissacrate": "dissacrare",
    "dissacrati": "dissacrare",
    "dissacrato": "dissacrare",
    "dissacratori": "dissacratorio",
    "dissacratoria": "dissacratorio",
    "dissacratorie": "dissacratorio",
    "dissacrava": "dissacrare",
    "dissacravamo": "dissacrare",
    "dissacravan": "dissacrare",
    "dissacravano": "dissacrare",
    "dissacravate": "dissacrare",
    "dissacravi": "dissacrare",
    "dissacravo": "dissacrare",
    "dissacrazioni": "dissacrazione",
    "dissacrerai": "dissacrare",
    "dissacreran": "dissacrare",
    "dissacreranno": "dissacrare",
    "dissacrerebbe": "dissacrare",
    "dissacrerebber": "dissacrare",
    "dissacrerebbero": "dissacrare",
    "dissacrerei": "dissacrare",
    "dissacreremmo": "dissacrare",
    "dissacreremo": "dissacrare",
    "dissacrereste": "dissacrare",
    "dissacreresti": "dissacrare",
    "dissacrerete": "dissacrare",
    "dissacrerà": "dissacrare",
    "dissacrerò": "dissacrare",
    "dissacri": "dissacrare",
    "dissacriamo": "dissacrare",
    "dissacriate": "dissacrare",
    "dissacrin": "dissacrare",
    "dissacrino": "dissacrare",
    "dissacro": "dissacrare",
    "dissacrò": "dissacrare",
    "dissala": "dissalare",
    "dissalai": "dissalare",
    "dissalammo": "dissalare",
    "dissalan": "dissalare",
    "dissalando": "dissalare",
    "dissalano": "dissalare",
    "dissalante": "dissalare",
    "dissalanti": "dissalare",
    "dissalar": "dissalare",
    "dissalaron": "dissalare",
    "dissalarono": "dissalare",
    "dissalasse": "dissalare",
    "dissalasser": "dissalare",
    "dissalassero": "dissalare",
    "dissalassi": "dissalare",
    "dissalassimo": "dissalare",
    "dissalaste": "dissalare",
    "dissalasti": "dissalare",
    "dissalata": "dissalare",
    "dissalate": "dissalare",
    "dissalati": "dissalare",
    "dissalato": "dissalare",
    "dissalatori": "dissalatore",
    "dissalava": "dissalare",
    "dissalavamo": "dissalare",
    "dissalavan": "dissalare",
    "dissalavano": "dissalare",
    "dissalavate": "dissalare",
    "dissalavi": "dissalare",
    "dissalavo": "dissalare",
    "dissalda": "dissaldare",
    "dissaldai": "dissaldare",
    "dissaldammo": "dissaldare",
    "dissaldan": "dissaldare",
    "dissaldando": "dissaldare",
    "dissaldano": "dissaldare",
    "dissaldante": "dissaldare",
    "dissaldanti": "dissaldare",
    "dissaldar": "dissaldare",
    "dissaldaron": "dissaldare",
    "dissaldarono": "dissaldare",
    "dissaldasse": "dissaldare",
    "dissaldasser": "dissaldare",
    "dissaldassero": "dissaldare",
    "dissaldassi": "dissaldare",
    "dissaldassimo": "dissaldare",
    "dissaldaste": "dissaldare",
    "dissaldasti": "dissaldare",
    "dissaldata": "dissaldare",
    "dissaldate": "dissaldare",
    "dissaldati": "dissaldare",
    "dissaldato": "dissaldare",
    "dissaldava": "dissaldare",
    "dissaldavamo": "dissaldare",
    "dissaldavan": "dissaldare",
    "dissaldavano": "dissaldare",
    "dissaldavate": "dissaldare",
    "dissaldavi": "dissaldare",
    "dissaldavo": "dissaldare",
    "dissalderai": "dissaldare",
    "dissalderan": "dissaldare",
    "dissalderanno": "dissaldare",
    "dissalderebbe": "dissaldare",
    "dissalderebber": "dissaldare",
    "dissalderebbero": "dissaldare",
    "dissalderei": "dissaldare",
    "dissalderemmo": "dissaldare",
    "dissalderemo": "dissaldare",
    "dissaldereste": "dissaldare",
    "dissalderesti": "dissaldare",
    "dissalderete": "dissaldare",
    "dissalderà": "dissaldare",
    "dissalderò": "dissaldare",
    "dissaldi": "dissaldare",
    "dissaldiamo": "dissaldare",
    "dissaldiate": "dissaldare",
    "dissaldin": "dissaldare",
    "dissaldino": "dissaldare",
    "dissaldo": "dissaldare",
    "dissaldò": "dissaldare",
    "dissalerai": "dissalare",
    "dissaleran": "dissalare",
    "dissaleranno": "dissalare",
    "dissalerebbe": "dissalare",
    "dissalerebber": "dissalare",
    "dissalerebbero": "dissalare",
    "dissalerei": "dissalare",
    "dissaleremmo": "dissalare",
    "dissaleremo": "dissalare",
    "dissalereste": "dissalare",
    "dissaleresti": "dissalare",
    "dissalerete": "dissalare",
    "dissalerà": "dissalare",
    "dissalerò": "dissalare",
    "dissali": "dissalare",
    "dissaliamo": "dissalare",
    "dissaliate": "dissalare",
    "dissalin": "dissalare",
    "dissalino": "dissalare",
    "dissalo": "dissalare",
    "dissalò": "dissalare",
    "dissangua": "dissanguare",
    "dissanguai": "dissanguare",
    "dissanguammo": "dissanguare",
    "dissanguan": "dissanguare",
    "dissanguando": "dissanguare",
    "dissanguano": "dissanguare",
    "dissanguante": "dissanguare",
    "dissanguanti": "dissanguare",
    "dissanguar": "dissanguare",
    "dissanguaron": "dissanguare",
    "dissanguarono": "dissanguare",
    "dissanguasse": "dissanguare",
    "dissanguasser": "dissanguare",
    "dissanguassero": "dissanguare",
    "dissanguassi": "dissanguare",
    "dissanguassimo": "dissanguare",
    "dissanguaste": "dissanguare",
    "dissanguasti": "dissanguare",
    "dissanguata": "dissanguare",
    "dissanguate": "dissanguare",
    "dissanguati": "dissanguare",
    "dissanguato": "dissanguare",
    "dissanguava": "dissanguare",
    "dissanguavamo": "dissanguare",
    "dissanguavan": "dissanguare",
    "dissanguavano": "dissanguare",
    "dissanguavate": "dissanguare",
    "dissanguavi": "dissanguare",
    "dissanguavo": "dissanguare",
    "dissanguerai": "dissanguare",
    "dissangueran": "dissanguare",
    "dissangueranno": "dissanguare",
    "dissanguerebbe": "dissanguare",
    "dissanguerebber": "dissanguare",
    "dissanguerebbero": "dissanguare",
    "dissanguerei": "dissanguare",
    "dissangueremmo": "dissanguare",
    "dissangueremo": "dissanguare",
    "dissanguereste": "dissanguare",
    "dissangueresti": "dissanguare",
    "dissanguerete": "dissanguare",
    "dissanguerà": "dissanguare",
    "dissanguerò": "dissanguare",
    "dissangui": "dissanguare",
    "dissanguiamo": "dissanguare",
    "dissanguiate": "dissanguare",
    "dissanguin": "dissanguare",
    "dissanguino": "dissanguare",
    "dissanguo": "dissanguare",
    "dissanguò": "dissanguare",
    "dissapori": "dissapore",
    "disse": "dire",
    "disseca": "dissecare",
    "dissecai": "dissecare",
    "dissecammo": "dissecare",
    "dissecan": "dissecare",
    "dissecando": "dissecare",
    "dissecano": "dissecare",
    "dissecante": "dissecare",
    "dissecanti": "dissecare",
    "dissecar": "dissecare",
    "dissecaron": "dissecare",
    "dissecarono": "dissecare",
    "dissecasse": "dissecare",
    "dissecasser": "dissecare",
    "dissecassero": "dissecare",
    "dissecassi": "dissecare",
    "dissecassimo": "dissecare",
    "dissecaste": "dissecare",
    "dissecasti": "dissecare",
    "dissecata": "dissecare",
    "dissecate": "dissecare",
    "dissecati": "dissecare",
    "dissecato": "dissecare",
    "dissecava": "dissecare",
    "dissecavamo": "dissecare",
    "dissecavan": "dissecare",
    "dissecavano": "dissecare",
    "dissecavate": "dissecare",
    "dissecavi": "dissecare",
    "dissecavo": "dissecare",
    "dissecca": "disseccare",
    "disseccai": "disseccare",
    "disseccammo": "disseccare",
    "disseccan": "disseccare",
    "disseccando": "disseccare",
    "disseccano": "disseccare",
    "disseccante": "disseccare",
    "disseccanti": "disseccare",
    "disseccar": "disseccare",
    "disseccaron": "disseccare",
    "disseccarono": "disseccare",
    "disseccasse": "disseccare",
    "disseccasser": "disseccare",
    "disseccassero": "disseccare",
    "disseccassi": "disseccare",
    "disseccassimo": "disseccare",
    "disseccaste": "disseccare",
    "disseccasti": "disseccare",
    "disseccata": "disseccare",
    "disseccate": "disseccare",
    "disseccati": "disseccare",
    "disseccato": "disseccare",
    "disseccava": "disseccare",
    "disseccavamo": "disseccare",
    "disseccavan": "disseccare",
    "disseccavano": "disseccare",
    "disseccavate": "disseccare",
    "disseccavi": "disseccare",
    "disseccavo": "disseccare",
    "disseccherai": "disseccare",
    "disseccheran": "disseccare",
    "disseccheranno": "disseccare",
    "disseccherebbe": "disseccare",
    "disseccherebber": "disseccare",
    "disseccherebbero": "disseccare",
    "disseccherei": "disseccare",
    "disseccheremmo": "disseccare",
    "disseccheremo": "disseccare",
    "dissecchereste": "disseccare",
    "disseccheresti": "disseccare",
    "disseccherete": "disseccare",
    "disseccherà": "disseccare",
    "disseccherò": "disseccare",
    "dissecchi": "disseccare",
    "dissecchiamo": "disseccare",
    "dissecchiate": "disseccare",
    "dissecchin": "disseccare",
    "dissecchino": "disseccare",
    "dissecco": "disseccare",
    "disseccò": "disseccare",
    "dissecherai": "dissecare",
    "dissecheran": "dissecare",
    "dissecheranno": "dissecare",
    "dissecherebbe": "dissecare",
    "dissecherebber": "dissecare",
    "dissecherebbero": "dissecare",
    "dissecherei": "dissecare",
    "dissecheremmo": "dissecare",
    "dissecheremo": "dissecare",
    "dissechereste": "dissecare",
    "dissecheresti": "dissecare",
    "dissecherete": "dissecare",
    "dissecherà": "dissecare",
    "dissecherò": "dissecare",
    "dissechi": "dissecare",
    "dissechiamo": "dissecare",
    "dissechiate": "dissecare",
    "dissechin": "dissecare",
    "dissechino": "dissecare",
    "disseco": "dissecare",
    "dissecò": "dissecare",
    "disselcerai": "disselciare",
    "disselceran": "disselciare",
    "disselceranno": "disselciare",
    "disselcerebbe": "disselciare",
    "disselcerebber": "disselciare",
    "disselcerebbero": "disselciare",
    "disselcerei": "disselciare",
    "disselceremmo": "disselciare",
    "disselceremo": "disselciare",
    "disselcereste": "disselciare",
    "disselceresti": "disselciare",
    "disselcerete": "disselciare",
    "disselcerà": "disselciare",
    "disselcerò": "disselciare",
    "disselci": "disselciare",
    "disselcia": "disselciare",
    "disselciai": "disselciare",
    "disselciammo": "disselciare",
    "disselciamo": "disselciare",
    "disselcian": "disselciare",
    "disselciando": "disselciare",
    "disselciano": "disselciare",
    "disselciante": "disselciare",
    "disselcianti": "disselciare",
    "disselciar": "disselciare",
    "disselciaron": "disselciare",
    "disselciarono": "disselciare",
    "disselciasse": "disselciare",
    "disselciasser": "disselciare",
    "disselciassero": "disselciare",
    "disselciassi": "disselciare",
    "disselciassimo": "disselciare",
    "disselciaste": "disselciare",
    "disselciasti": "disselciare",
    "disselciata": "disselciare",
    "disselciate": "disselciare",
    "disselciati": "disselciare",
    "disselciato": "disselciare",
    "disselciava": "disselciare",
    "disselciavamo": "disselciare",
    "disselciavan": "disselciare",
    "disselciavano": "disselciare",
    "disselciavate": "disselciare",
    "disselciavi": "disselciare",
    "disselciavo": "disselciare",
    "disselcin": "disselciare",
    "disselcino": "disselciare",
    "disselcio": "disselciare",
    "disselciò": "disselciare",
    "dissella": "dissellare",
    "dissellai": "dissellare",
    "dissellammo": "dissellare",
    "dissellan": "dissellare",
    "dissellando": "dissellare",
    "dissellano": "dissellare",
    "dissellante": "dissellare",
    "dissellanti": "dissellare",
    "dissellar": "dissellare",
    "dissellaron": "dissellare",
    "dissellarono": "dissellare",
    "dissellasse": "dissellare",
    "dissellasser": "dissellare",
    "dissellassero": "dissellare",
    "dissellassi": "dissellare",
    "dissellassimo": "dissellare",
    "dissellaste": "dissellare",
    "dissellasti": "dissellare",
    "dissellata": "dissellare",
    "dissellate": "dissellare",
    "dissellati": "dissellare",
    "dissellato": "dissellare",
    "dissellava": "dissellare",
    "dissellavamo": "dissellare",
    "dissellavan": "dissellare",
    "dissellavano": "dissellare",
    "dissellavate": "dissellare",
    "dissellavi": "dissellare",
    "dissellavo": "dissellare",
    "dissellerai": "dissellare",
    "disselleran": "dissellare",
    "disselleranno": "dissellare",
    "dissellerebbe": "dissellare",
    "dissellerebber": "dissellare",
    "dissellerebbero": "dissellare",
    "dissellerei": "dissellare",
    "disselleremmo": "dissellare",
    "disselleremo": "dissellare",
    "dissellereste": "dissellare",
    "disselleresti": "dissellare",
    "dissellerete": "dissellare",
    "dissellerà": "dissellare",
    "dissellerò": "dissellare",
    "disselli": "dissellare",
    "disselliamo": "dissellare",
    "disselliate": "dissellare",
    "dissellin": "dissellare",
    "dissellino": "dissellare",
    "dissello": "dissellare",
    "dissellò": "dissellare",
    "dissemina": "disseminare",
    "disseminai": "disseminare",
    "disseminammo": "disseminare",
    "disseminan": "disseminare",
    "disseminando": "disseminare",
    "disseminano": "disseminare",
    "disseminante": "disseminare",
    "disseminanti": "disseminare",
    "disseminar": "disseminare",
    "disseminaron": "disseminare",
    "disseminarono": "disseminare",
    "disseminasse": "disseminare",
    "disseminasser": "disseminare",
    "disseminassero": "disseminare",
    "disseminassi": "disseminare",
    "disseminassimo": "disseminare",
    "disseminaste": "disseminare",
    "disseminasti": "disseminare",
    "disseminata": "disseminare",
    "disseminate": "disseminare",
    "disseminati": "disseminare",
    "disseminato": "disseminare",
    "disseminava": "disseminare",
    "disseminavamo": "disseminare",
    "disseminavan": "disseminare",
    "disseminavano": "disseminare",
    "disseminavate": "disseminare",
    "disseminavi": "disseminare",
    "disseminavo": "disseminare",
    "disseminazioni": "disseminazione",
    "disseminerai": "disseminare",
    "dissemineran": "disseminare",
    "dissemineranno": "disseminare",
    "disseminerebbe": "disseminare",
    "disseminerebber": "disseminare",
    "disseminerebbero": "disseminare",
    "disseminerei": "disseminare",
    "dissemineremmo": "disseminare",
    "dissemineremo": "disseminare",
    "disseminereste": "disseminare",
    "dissemineresti": "disseminare",
    "disseminerete": "disseminare",
    "disseminerà": "disseminare",
    "disseminerò": "disseminare",
    "dissemini": "disseminare",
    "disseminiamo": "disseminare",
    "disseminiate": "disseminare",
    "disseminin": "disseminare",
    "disseminino": "disseminare",
    "dissemino": "disseminare",
    "disseminò": "disseminare",
    "dissennata": "dissennato",
    "dissennate": "dissennato",
    "dissennatezze": "dissennatezza",
    "dissennati": "dissennato",
    "dissensi": "dissenso",
    "dissenta": "dissentire",
    "dissentan": "dissentire",
    "dissentano": "dissentire",
    "dissente": "dissentire",
    "dissentendo": "dissentire",
    "dissentente": "dissentire",
    "dissententi": "dissentire",
    "dissenterie": "dissenteria",
    "dissenti": "dissentire",
    "dissentiamo": "dissentire",
    "dissentiate": "dissentire",
    "dissentii": "dissentire",
    "dissentimmo": "dissentire",
    "dissentir": "dissentire",
    "dissentirai": "dissentire",
    "dissentiran": "dissentire",
    "dissentiranno": "dissentire",
    "dissentirebbe": "dissentire",
    "dissentirebber": "dissentire",
    "dissentirebbero": "dissentire",
    "dissentirei": "dissentire",
    "dissentiremmo": "dissentire",
    "dissentiremo": "dissentire",
    "dissentireste": "dissentire",
    "dissentiresti": "dissentire",
    "dissentirete": "dissentire",
    "dissentiron": "dissentire",
    "dissentirono": "dissentire",
    "dissentirà": "dissentire",
    "dissentirò": "dissentire",
    "dissentisse": "dissentire",
    "dissentisser": "dissentire",
    "dissentissero": "dissentire",
    "dissentissi": "dissentire",
    "dissentissimo": "dissentire",
    "dissentiste": "dissentire",
    "dissentisti": "dissentire",
    "dissentita": "dissentire",
    "dissentite": "dissentire",
    "dissentiti": "dissentire",
    "dissentito": "dissentire",
    "dissentiva": "dissentire",
    "dissentivamo": "dissentire",
    "dissentivan": "dissentire",
    "dissentivano": "dissentire",
    "dissentivate": "dissentire",
    "dissentivi": "dissentire",
    "dissentivo": "dissentire",
    "dissento": "dissentire",
    "dissenton": "dissentire",
    "dissentono": "dissentire",
    "dissentì": "dissentire",
    "dissenzienti": "dissenziente",
    "dissepolta": "dissepolto",
    "dissepolte": "dissepolto",
    "dissepolti": "dissepolto",
    "disseppella": "disseppellire",
    "disseppellan": "disseppellire",
    "disseppellano": "disseppellire",
    "disseppelle": "disseppellire",
    "disseppellendo": "disseppellire",
    "disseppellente": "disseppellire",
    "disseppellenti": "disseppellire",
    "disseppelli": "disseppellire",
    "disseppelliamo": "disseppellire",
    "disseppelliate": "disseppellire",
    "disseppellii": "disseppellire",
    "disseppellimmo": "disseppellire",
    "disseppellir": "disseppellire",
    "disseppellirai": "disseppellire",
    "disseppelliran": "disseppellire",
    "disseppelliranno": "disseppellire",
    "disseppellirebbe": "disseppellire",
    "disseppellirebber": "disseppellire",
    "disseppellirebbero": "disseppellire",
    "disseppellirei": "disseppellire",
    "disseppelliremmo": "disseppellire",
    "disseppelliremo": "disseppellire",
    "disseppellireste": "disseppellire",
    "disseppelliresti": "disseppellire",
    "disseppellirete": "disseppellire",
    "disseppelliron": "disseppellire",
    "disseppellirono": "disseppellire",
    "disseppellirà": "disseppellire",
    "disseppellirò": "disseppellire",
    "disseppellisse": "disseppellire",
    "disseppellisser": "disseppellire",
    "disseppellissero": "disseppellire",
    "disseppellissi": "disseppellire",
    "disseppellissimo": "disseppellire",
    "disseppelliste": "disseppellire",
    "disseppellisti": "disseppellire",
    "disseppellita": "disseppellire",
    "disseppellite": "disseppellire",
    "disseppelliti": "disseppellire",
    "disseppellito": "disseppellire",
    "disseppelliva": "disseppellire",
    "disseppellivamo": "disseppellire",
    "disseppellivan": "disseppellire",
    "disseppellivano": "disseppellire",
    "disseppellivate": "disseppellire",
    "disseppellivi": "disseppellire",
    "disseppellivo": "disseppellire",
    "disseppello": "disseppellire",
    "disseppellon": "disseppellire",
    "disseppellono": "disseppellire",
    "disseppellì": "disseppellire",
    "dissequestra": "dissequestrare",
    "dissequestrai": "dissequestrare",
    "dissequestrammo": "dissequestrare",
    "dissequestran": "dissequestrare",
    "dissequestrando": "dissequestrare",
    "dissequestrano": "dissequestrare",
    "dissequestrante": "dissequestrare",
    "dissequestranti": "dissequestrare",
    "dissequestrar": "dissequestrare",
    "dissequestraron": "dissequestrare",
    "dissequestrarono": "dissequestrare",
    "dissequestrasse": "dissequestrare",
    "dissequestrasser": "dissequestrare",
    "dissequestrassero": "dissequestrare",
    "dissequestrassi": "dissequestrare",
    "dissequestrassimo": "dissequestrare",
    "dissequestraste": "dissequestrare",
    "dissequestrasti": "dissequestrare",
    "dissequestrata": "dissequestrare",
    "dissequestrate": "dissequestrare",
    "dissequestrati": "dissequestrare",
    "dissequestrato": "dissequestrare",
    "dissequestrava": "dissequestrare",
    "dissequestravamo": "dissequestrare",
    "dissequestravan": "dissequestrare",
    "dissequestravano": "dissequestrare",
    "dissequestravate": "dissequestrare",
    "dissequestravi": "dissequestrare",
    "dissequestravo": "dissequestrare",
    "dissequestrerai": "dissequestrare",
    "dissequestreran": "dissequestrare",
    "dissequestreranno": "dissequestrare",
    "dissequestrerebbe": "dissequestrare",
    "dissequestrerebber": "dissequestrare",
    "dissequestrerebbero": "dissequestrare",
    "dissequestrerei": "dissequestrare",
    "dissequestreremmo": "dissequestrare",
    "dissequestreremo": "dissequestrare",
    "dissequestrereste": "dissequestrare",
    "dissequestreresti": "dissequestrare",
    "dissequestrerete": "dissequestrare",
    "dissequestrerà": "dissequestrare",
    "dissequestrerò": "dissequestrare",
    "dissequestri": "dissequestro",
    "dissequestriamo": "dissequestrare",
    "dissequestriate": "dissequestrare",
    "dissequestrin": "dissequestrare",
    "dissequestrino": "dissequestrare",
    "dissequestro": "dissequestrare",
    "dissequestrò": "dissequestrare",
    "disser": "dire",
    "dissero": "dire",
    "disserra": "disserrare",
    "disserrai": "disserrare",
    "disserrammo": "disserrare",
    "disserran": "disserrare",
    "disserrando": "disserrare",
    "disserrano": "disserrare",
    "disserrante": "disserrare",
    "disserranti": "disserrare",
    "disserrar": "disserrare",
    "disserraron": "disserrare",
    "disserrarono": "disserrare",
    "disserrasse": "disserrare",
    "disserrasser": "disserrare",
    "disserrassero": "disserrare",
    "disserrassi": "disserrare",
    "disserrassimo": "disserrare",
    "disserraste": "disserrare",
    "disserrasti": "disserrare",
    "disserrata": "disserrare",
    "disserrate": "disserrare",
    "disserrati": "disserrare",
    "disserrato": "disserrare",
    "disserrava": "disserrare",
    "disserravamo": "disserrare",
    "disserravan": "disserrare",
    "disserravano": "disserrare",
    "disserravate": "disserrare",
    "disserravi": "disserrare",
    "disserravo": "disserrare",
    "disserrerai": "disserrare",
    "disserreran": "disserrare",
    "disserreranno": "disserrare",
    "disserrerebbe": "disserrare",
    "disserrerebber": "disserrare",
    "disserrerebbero": "disserrare",
    "disserrerei": "disserrare",
    "disserreremmo": "disserrare",
    "disserreremo": "disserrare",
    "disserrereste": "disserrare",
    "disserreresti": "disserrare",
    "disserrerete": "disserrare",
    "disserrerà": "disserrare",
    "disserrerò": "disserrare",
    "disserri": "disserrare",
    "disserriamo": "disserrare",
    "disserriate": "disserrare",
    "disserrin": "disserrare",
    "disserrino": "disserrare",
    "disserro": "disserrare",
    "disserrò": "disserrare",
    "disserta": "dissertare",
    "dissertai": "dissertare",
    "dissertammo": "dissertare",
    "dissertan": "dissertare",
    "dissertando": "dissertare",
    "dissertano": "dissertare",
    "dissertante": "dissertare",
    "dissertanti": "dissertare",
    "dissertar": "dissertare",
    "dissertaron": "dissertare",
    "dissertarono": "dissertare",
    "dissertasse": "dissertare",
    "dissertasser": "dissertare",
    "dissertassero": "dissertare",
    "dissertassi": "dissertare",
    "dissertassimo": "dissertare",
    "dissertaste": "dissertare",
    "dissertasti": "dissertare",
    "dissertata": "dissertare",
    "dissertate": "dissertare",
    "dissertati": "dissertare",
    "dissertato": "dissertare",
    "dissertava": "dissertare",
    "dissertavamo": "dissertare",
    "dissertavan": "dissertare",
    "dissertavano": "dissertare",
    "dissertavate": "dissertare",
    "dissertavi": "dissertare",
    "dissertavo": "dissertare",
    "dissertazioni": "dissertazione",
    "disserterai": "dissertare",
    "disserteran": "dissertare",
    "disserteranno": "dissertare",
    "disserterebbe": "dissertare",
    "disserterebber": "dissertare",
    "disserterebbero": "dissertare",
    "disserterei": "dissertare",
    "disserteremmo": "dissertare",
    "disserteremo": "dissertare",
    "dissertereste": "dissertare",
    "disserteresti": "dissertare",
    "disserterete": "dissertare",
    "disserterà": "dissertare",
    "disserterò": "dissertare",
    "disserti": "dissertare",
    "dissertiamo": "dissertare",
    "dissertiate": "dissertare",
    "dissertin": "dissertare",
    "dissertino": "dissertare",
    "disserto": "dissertare",
    "dissertò": "dissertare",
    "disservizi": "disservizio",
    "dissesta": "dissestare",
    "dissestai": "dissestare",
    "dissestammo": "dissestare",
    "dissestan": "dissestare",
    "dissestando": "dissestare",
    "dissestano": "dissestare",
    "dissestante": "dissestare",
    "dissestanti": "dissestare",
    "dissestar": "dissestare",
    "dissestaron": "dissestare",
    "dissestarono": "dissestare",
    "dissestasse": "dissestare",
    "dissestasser": "dissestare",
    "dissestassero": "dissestare",
    "dissestassi": "dissestare",
    "dissestassimo": "dissestare",
    "dissestaste": "dissestare",
    "dissestasti": "dissestare",
    "dissestata": "dissestare",
    "dissestate": "dissestata",
    "dissestati": "dissestare",
    "dissestato": "dissestare",
    "dissestava": "dissestare",
    "dissestavamo": "dissestare",
    "dissestavan": "dissestare",
    "dissestavano": "dissestare",
    "dissestavate": "dissestare",
    "dissestavi": "dissestare",
    "dissestavo": "dissestare",
    "dissesterai": "dissestare",
    "dissesteran": "dissestare",
    "dissesteranno": "dissestare",
    "dissesterebbe": "dissestare",
    "dissesterebber": "dissestare",
    "dissesterebbero": "dissestare",
    "dissesterei": "dissestare",
    "dissesteremmo": "dissestare",
    "dissesteremo": "dissestare",
    "dissestereste": "dissestare",
    "dissesteresti": "dissestare",
    "dissesterete": "dissestare",
    "dissesterà": "dissestare",
    "dissesterò": "dissestare",
    "dissesti": "dissesto",
    "dissestiamo": "dissestare",
    "dissestiate": "dissestare",
    "dissestin": "dissestare",
    "dissestino": "dissestare",
    "dissesto": "dissestare",
    "dissestò": "dissestare",
    "disseta": "dissetare",
    "dissetai": "dissetare",
    "dissetammo": "dissetare",
    "dissetan": "dissetare",
    "dissetando": "dissetare",
    "dissetano": "dissetare",
    "dissetante": "dissetare",
    "dissetanti": "dissetare",
    "dissetar": "dissetare",
    "dissetaron": "dissetare",
    "dissetarono": "dissetare",
    "dissetasse": "dissetare",
    "dissetasser": "dissetare",
    "dissetassero": "dissetare",
    "dissetassi": "dissetare",
    "dissetassimo": "dissetare",
    "dissetaste": "dissetare",
    "dissetasti": "dissetare",
    "dissetata": "dissetare",
    "dissetate": "dissetare",
    "dissetati": "dissetare",
    "dissetato": "dissetare",
    "dissetava": "dissetare",
    "dissetavamo": "dissetare",
    "dissetavan": "dissetare",
    "dissetavano": "dissetare",
    "dissetavate": "dissetare",
    "dissetavi": "dissetare",
    "dissetavo": "dissetare",
    "disseterai": "dissetare",
    "disseteran": "dissetare",
    "disseteranno": "dissetare",
    "disseterebbe": "dissetare",
    "disseterebber": "dissetare",
    "disseterebbero": "dissetare",
    "disseterei": "dissetare",
    "disseteremmo": "dissetare",
    "disseteremo": "dissetare",
    "dissetereste": "dissetare",
    "disseteresti": "dissetare",
    "disseterete": "dissetare",
    "disseterà": "dissetare",
    "disseterò": "dissetare",
    "disseti": "dissetare",
    "dissetiamo": "dissetare",
    "dissetiate": "dissetare",
    "dissetin": "dissetare",
    "dissetino": "dissetare",
    "disseto": "dissetare",
    "dissetò": "dissetare",
    "disseziona": "dissezionare",
    "dissezionai": "dissezionare",
    "dissezionammo": "dissezionare",
    "dissezionan": "dissezionare",
    "dissezionando": "dissezionare",
    "dissezionano": "dissezionare",
    "dissezionante": "dissezionare",
    "dissezionanti": "dissezionare",
    "dissezionar": "dissezionare",
    "dissezionaron": "dissezionare",
    "dissezionarono": "dissezionare",
    "dissezionasse": "dissezionare",
    "dissezionasser": "dissezionare",
    "dissezionassero": "dissezionare",
    "dissezionassi": "dissezionare",
    "dissezionassimo": "dissezionare",
    "dissezionaste": "dissezionare",
    "dissezionasti": "dissezionare",
    "dissezionata": "dissezionare",
    "dissezionate": "dissezionare",
    "dissezionati": "dissezionare",
    "dissezionato": "dissezionare",
    "dissezionava": "dissezionare",
    "dissezionavamo": "dissezionare",
    "dissezionavan": "dissezionare",
    "dissezionavano": "dissezionare",
    "dissezionavate": "dissezionare",
    "dissezionavi": "dissezionare",
    "dissezionavo": "dissezionare",
    "dissezionerai": "dissezionare",
    "dissezioneran": "dissezionare",
    "dissezioneranno": "dissezionare",
    "dissezionerebbe": "dissezionare",
    "dissezionerebber": "dissezionare",
    "dissezionerebbero": "dissezionare",
    "dissezionerei": "dissezionare",
    "dissezioneremmo": "dissezionare",
    "dissezioneremo": "dissezionare",
    "dissezionereste": "dissezionare",
    "dissezioneresti": "dissezionare",
    "dissezionerete": "dissezionare",
    "dissezionerà": "dissezionare",
    "dissezionerò": "dissezionare",
    "dissezioni": "dissezione",
    "dissezioniamo": "dissezionare",
    "dissezioniate": "dissezionare",
    "dissezionin": "dissezionare",
    "dissezionino": "dissezionare",
    "disseziono": "dissezionare",
    "dissezionò": "dissezionare",
    "dissi": "dire",
    "dissidenti": "dissidente",
    "dissidenze": "dissidenza",
    "dissidi": "dissidio",
    "dissigilla": "dissigillare",
    "dissigillai": "dissigillare",
    "dissigillammo": "dissigillare",
    "dissigillan": "dissigillare",
    "dissigillando": "dissigillare",
    "dissigillano": "dissigillare",
    "dissigillante": "dissigillare",
    "dissigillanti": "dissigillare",
    "dissigillar": "dissigillare",
    "dissigillaron": "dissigillare",
    "dissigillarono": "dissigillare",
    "dissigillasse": "dissigillare",
    "dissigillasser": "dissigillare",
    "dissigillassero": "dissigillare",
    "dissigillassi": "dissigillare",
    "dissigillassimo": "dissigillare",
    "dissigillaste": "dissigillare",
    "dissigillasti": "dissigillare",
    "dissigillata": "dissigillare",
    "dissigillate": "dissigillare",
    "dissigillati": "dissigillare",
    "dissigillato": "dissigillare",
    "dissigillava": "dissigillare",
    "dissigillavamo": "dissigillare",
    "dissigillavan": "dissigillare",
    "dissigillavano": "dissigillare",
    "dissigillavate": "dissigillare",
    "dissigillavi": "dissigillare",
    "dissigillavo": "dissigillare",
    "dissigillerai": "dissigillare",
    "dissigilleran": "dissigillare",
    "dissigilleranno": "dissigillare",
    "dissigillerebbe": "dissigillare",
    "dissigillerebber": "dissigillare",
    "dissigillerebbero": "dissigillare",
    "dissigillerei": "dissigillare",
    "dissigilleremmo": "dissigillare",
    "dissigilleremo": "dissigillare",
    "dissigillereste": "dissigillare",
    "dissigilleresti": "dissigillare",
    "dissigillerete": "dissigillare",
    "dissigillerà": "dissigillare",
    "dissigillerò": "dissigillare",
    "dissigilli": "dissigillare",
    "dissigilliamo": "dissigillare",
    "dissigilliate": "dissigillare",
    "dissigillin": "dissigillare",
    "dissigillino": "dissigillare",
    "dissigillo": "dissigillare",
    "dissigillò": "dissigillare",
    "dissimili": "dissimile",
    "dissimula": "dissimulare",
    "dissimulai": "dissimulare",
    "dissimulammo": "dissimulare",
    "dissimulan": "dissimulare",
    "dissimulando": "dissimulare",
    "dissimulano": "dissimulare",
    "dissimulante": "dissimulare",
    "dissimulanti": "dissimulare",
    "dissimular": "dissimulare",
    "dissimularon": "dissimulare",
    "dissimularono": "dissimulare",
    "dissimulasse": "dissimulare",
    "dissimulasser": "dissimulare",
    "dissimulassero": "dissimulare",
    "dissimulassi": "dissimulare",
    "dissimulassimo": "dissimulare",
    "dissimulaste": "dissimulare",
    "dissimulasti": "dissimulare",
    "dissimulata": "dissimulare",
    "dissimulate": "dissimulare",
    "dissimulati": "dissimulare",
    "dissimulato": "dissimulare",
    "dissimulava": "dissimulare",
    "dissimulavamo": "dissimulare",
    "dissimulavan": "dissimulare",
    "dissimulavano": "dissimulare",
    "dissimulavate": "dissimulare",
    "dissimulavi": "dissimulare",
    "dissimulavo": "dissimulare",
    "dissimulazioni": "dissimulazione",
    "dissimulerai": "dissimulare",
    "dissimuleran": "dissimulare",
    "dissimuleranno": "dissimulare",
    "dissimulerebbe": "dissimulare",
    "dissimulerebber": "dissimulare",
    "dissimulerebbero": "dissimulare",
    "dissimulerei": "dissimulare",
    "dissimuleremmo": "dissimulare",
    "dissimuleremo": "dissimulare",
    "dissimulereste": "dissimulare",
    "dissimuleresti": "dissimulare",
    "dissimulerete": "dissimulare",
    "dissimulerà": "dissimulare",
    "dissimulerò": "dissimulare",
    "dissimuli": "dissimulare",
    "dissimuliamo": "dissimulare",
    "dissimuliate": "dissimulare",
    "dissimulin": "dissimulare",
    "dissimulino": "dissimulare",
    "dissimulo": "dissimulare",
    "dissimulò": "dissimulare",
    "dissipa": "dissipare",
    "dissipai": "dissipare",
    "dissipammo": "dissipare",
    "dissipan": "dissipare",
    "dissipando": "dissipare",
    "dissipano": "dissipare",
    "dissipante": "dissipare",
    "dissipanti": "dissipare",
    "dissipar": "dissipare",
    "dissiparon": "dissipare",
    "dissiparono": "dissipare",
    "dissipasse": "dissipare",
    "dissipasser": "dissipare",
    "dissipassero": "dissipare",
    "dissipassi": "dissipare",
    "dissipassimo": "dissipare",
    "dissipaste": "dissipare",
    "dissipasti": "dissipare",
    "dissipata": "dissipato",
    "dissipate": "dissipato",
    "dissipatezze": "dissipatezza",
    "dissipati": "dissipato",
    "dissipato": "dissipare",
    "dissipatori": "dissipatore",
    "dissipava": "dissipare",
    "dissipavamo": "dissipare",
    "dissipavan": "dissipare",
    "dissipavano": "dissipare",
    "dissipavate": "dissipare",
    "dissipavi": "dissipare",
    "dissipavo": "dissipare",
    "dissipazioni": "dissipazione",
    "dissiperai": "dissipare",
    "dissiperan": "dissipare",
    "dissiperanno": "dissipare",
    "dissiperebbe": "dissipare",
    "dissiperebber": "dissipare",
    "dissiperebbero": "dissipare",
    "dissiperei": "dissipare",
    "dissiperemmo": "dissipare",
    "dissiperemo": "dissipare",
    "dissipereste": "dissipare",
    "dissiperesti": "dissipare",
    "dissiperete": "dissipare",
    "dissiperà": "dissipare",
    "dissiperò": "dissipare",
    "dissipi": "dissipare",
    "dissipiamo": "dissipare",
    "dissipiate": "dissipare",
    "dissipin": "dissipare",
    "dissipino": "dissipare",
    "dissipo": "dissipare",
    "dissipò": "dissipare",
    "dissocerai": "dissociare",
    "dissoceran": "dissociare",
    "dissoceranno": "dissociare",
    "dissocerebbe": "dissociare",
    "dissocerebber": "dissociare",
    "dissocerebbero": "dissociare",
    "dissocerei": "dissociare",
    "dissoceremmo": "dissociare",
    "dissoceremo": "dissociare",
    "dissocereste": "dissociare",
    "dissoceresti": "dissociare",
    "dissocerete": "dissociare",
    "dissocerà": "dissociare",
    "dissocerò": "dissociare",
    "dissoci": "dissociare",
    "dissocia": "dissociare",
    "dissociai": "dissociare",
    "dissociammo": "dissociare",
    "dissociamo": "dissociare",
    "dissocian": "dissociare",
    "dissociando": "dissociare",
    "dissociano": "dissociare",
    "dissociante": "dissociare",
    "dissocianti": "dissociare",
    "dissociar": "dissociare",
    "dissociaron": "dissociare",
    "dissociarono": "dissociare",
    "dissociasse": "dissociare",
    "dissociasser": "dissociare",
    "dissociassero": "dissociare",
    "dissociassi": "dissociare",
    "dissociassimo": "dissociare",
    "dissociaste": "dissociare",
    "dissociasti": "dissociare",
    "dissociata": "dissociato",
    "dissociate": "dissociato",
    "dissociati": "dissociato",
    "dissociato": "dissociare",
    "dissociava": "dissociare",
    "dissociavamo": "dissociare",
    "dissociavan": "dissociare",
    "dissociavano": "dissociare",
    "dissociavate": "dissociare",
    "dissociavi": "dissociare",
    "dissociavo": "dissociare",
    "dissociazioni": "dissociazione",
    "dissocin": "dissociare",
    "dissocino": "dissociare",
    "dissocio": "dissociare",
    "dissociò": "dissociare",
    "dissoda": "dissodare",
    "dissodai": "dissodare",
    "dissodammo": "dissodare",
    "dissodan": "dissodare",
    "dissodando": "dissodare",
    "dissodano": "dissodare",
    "dissodante": "dissodare",
    "dissodanti": "dissodare",
    "dissodar": "dissodare",
    "dissodaron": "dissodare",
    "dissodarono": "dissodare",
    "dissodasse": "dissodare",
    "dissodasser": "dissodare",
    "dissodassero": "dissodare",
    "dissodassi": "dissodare",
    "dissodassimo": "dissodare",
    "dissodaste": "dissodare",
    "dissodasti": "dissodare",
    "dissodata": "dissodare",
    "dissodate": "dissodare",
    "dissodati": "dissodare",
    "dissodato": "dissodare",
    "dissodava": "dissodare",
    "dissodavamo": "dissodare",
    "dissodavan": "dissodare",
    "dissodavano": "dissodare",
    "dissodavate": "dissodare",
    "dissodavi": "dissodare",
    "dissodavo": "dissodare",
    "dissoderai": "dissodare",
    "dissoderan": "dissodare",
    "dissoderanno": "dissodare",
    "dissoderebbe": "dissodare",
    "dissoderebber": "dissodare",
    "dissoderebbero": "dissodare",
    "dissoderei": "dissodare",
    "dissoderemmo": "dissodare",
    "dissoderemo": "dissodare",
    "dissodereste": "dissodare",
    "dissoderesti": "dissodare",
    "dissoderete": "dissodare",
    "dissoderà": "dissodare",
    "dissoderò": "dissodare",
    "dissodi": "dissodare",
    "dissodiamo": "dissodare",
    "dissodiate": "dissodare",
    "dissodin": "dissodare",
    "dissodino": "dissodare",
    "dissodo": "dissodare",
    "dissodò": "dissodare",
    "dissolse": "dissolvere",
    "dissolser": "dissolvere",
    "dissolsero": "dissolvere",
    "dissolsi": "dissolvere",
    "dissolta": "dissolvere",
    "dissolte": "dissolvere",
    "dissolti": "dissolvere",
    "dissolto": "dissolvere",
    "dissoluta": "dissoluto",
    "dissolute": "dissoluto",
    "dissolutezze": "dissolutezza",
    "dissoluti": "dissoluto",
    "dissoluzioni": "dissoluzione",
    "dissolva": "dissolvere",
    "dissolvan": "dissolvere",
    "dissolvano": "dissolvere",
    "dissolve": "dissolvere",
    "dissolvemmo": "dissolvere",
    "dissolvendo": "dissolvere",
    "dissolvente": "dissolvere",
    "dissolventi": "dissolvere",
    "dissolvenze": "dissolvenza",
    "dissolver": "dissolvere",
    "dissolverai": "dissolvere",
    "dissolveran": "dissolvere",
    "dissolveranno": "dissolvere",
    "dissolverebbe": "dissolvere",
    "dissolverebber": "dissolvere",
    "dissolverebbero": "dissolvere",
    "dissolverei": "dissolvere",
    "dissolveremmo": "dissolvere",
    "dissolveremo": "dissolvere",
    "dissolvereste": "dissolvere",
    "dissolveresti": "dissolvere",
    "dissolverete": "dissolvere",
    "dissolverà": "dissolvere",
    "dissolverò": "dissolvere",
    "dissolvesse": "dissolvere",
    "dissolvesser": "dissolvere",
    "dissolvessero": "dissolvere",
    "dissolvessi": "dissolvere",
    "dissolvessimo": "dissolvere",
    "dissolveste": "dissolvere",
    "dissolvesti": "dissolvere",
    "dissolvete": "dissolvere",
    "dissolveva": "dissolvere",
    "dissolvevamo": "dissolvere",
    "dissolvevan": "dissolvere",
    "dissolvevano": "dissolvere",
    "dissolvevate": "dissolvere",
    "dissolvevi": "dissolvere",
    "dissolvevo": "dissolvere",
    "dissolvi": "dissolvere",
    "dissolviamo": "dissolvere",
    "dissolviate": "dissolvere",
    "dissolvimenti": "dissolvimento",
    "dissolvo": "dissolvere",
    "dissolvon": "dissolvere",
    "dissolvono": "dissolvere",
    "dissona": "dissonare",
    "dissonai": "dissonare",
    "dissonammo": "dissonare",
    "dissonan": "dissonare",
    "dissonando": "dissonare",
    "dissonano": "dissonare",
    "dissonante": "dissonare",
    "dissonanti": "dissonare",
    "dissonanze": "dissonanza",
    "dissonar": "dissonare",
    "dissonaron": "dissonare",
    "dissonarono": "dissonare",
    "dissonasse": "dissonare",
    "dissonasser": "dissonare",
    "dissonassero": "dissonare",
    "dissonassi": "dissonare",
    "dissonassimo": "dissonare",
    "dissonaste": "dissonare",
    "dissonasti": "dissonare",
    "dissonata": "dissonare",
    "dissonate": "dissonare",
    "dissonati": "dissonare",
    "dissonato": "dissonare",
    "dissonava": "dissonare",
    "dissonavamo": "dissonare",
    "dissonavan": "dissonare",
    "dissonavano": "dissonare",
    "dissonavate": "dissonare",
    "dissonavi": "dissonare",
    "dissonavo": "dissonare",
    "dissonerai": "dissonare",
    "dissoneran": "dissonare",
    "dissoneranno": "dissonare",
    "dissonerebbe": "dissonare",
    "dissonerebber": "dissonare",
    "dissonerebbero": "dissonare",
    "dissonerei": "dissonare",
    "dissoneremmo": "dissonare",
    "dissoneremo": "dissonare",
    "dissonereste": "dissonare",
    "dissoneresti": "dissonare",
    "dissonerete": "dissonare",
    "dissonerà": "dissonare",
    "dissonerò": "dissonare",
    "dissoni": "dissonare",
    "dissoniamo": "dissonare",
    "dissoniate": "dissonare",
    "dissonin": "dissonare",
    "dissonino": "dissonare",
    "dissono": "dissonare",
    "dissonò": "dissonare",
    "dissotterra": "dissotterrare",
    "dissotterrai": "dissotterrare",
    "dissotterrammo": "dissotterrare",
    "dissotterran": "dissotterrare",
    "dissotterrando": "dissotterrare",
    "dissotterrano": "dissotterrare",
    "dissotterrante": "dissotterrare",
    "dissotterranti": "dissotterrare",
    "dissotterrar": "dissotterrare",
    "dissotterraron": "dissotterrare",
    "dissotterrarono": "dissotterrare",
    "dissotterrasse": "dissotterrare",
    "dissotterrasser": "dissotterrare",
    "dissotterrassero": "dissotterrare",
    "dissotterrassi": "dissotterrare",
    "dissotterrassimo": "dissotterrare",
    "dissotterraste": "dissotterrare",
    "dissotterrasti": "dissotterrare",
    "dissotterrata": "dissotterrare",
    "dissotterrate": "dissotterrare",
    "dissotterrati": "dissotterrare",
    "dissotterrato": "dissotterrare",
    "dissotterrava": "dissotterrare",
    "dissotterravamo": "dissotterrare",
    "dissotterravan": "dissotterrare",
    "dissotterravano": "dissotterrare",
    "dissotterravate": "dissotterrare",
    "dissotterravi": "dissotterrare",
    "dissotterravo": "dissotterrare",
    "dissotterrerai": "dissotterrare",
    "dissotterreran": "dissotterrare",
    "dissotterreranno": "dissotterrare",
    "dissotterrerebbe": "dissotterrare",
    "dissotterrerebber": "dissotterrare",
    "dissotterrerebbero": "dissotterrare",
    "dissotterrerei": "dissotterrare",
    "dissotterreremmo": "dissotterrare",
    "dissotterreremo": "dissotterrare",
    "dissotterrereste": "dissotterrare",
    "dissotterreresti": "dissotterrare",
    "dissotterrerete": "dissotterrare",
    "dissotterrerà": "dissotterrare",
    "dissotterrerò": "dissotterrare",
    "dissotterri": "dissotterrare",
    "dissotterriamo": "dissotterrare",
    "dissotterriate": "dissotterrare",
    "dissotterrin": "dissotterrare",
    "dissotterrino": "dissotterrare",
    "dissotterro": "dissotterrare",
    "dissotterrò": "dissotterrare",
    "dissuada": "dissuadere",
    "dissuadan": "dissuadere",
    "dissuadano": "dissuadere",
    "dissuade": "dissuadere",
    "dissuademmo": "dissuadere",
    "dissuadendo": "dissuadere",
    "dissuadente": "dissuadere",
    "dissuadenti": "dissuadere",
    "dissuader": "dissuadere",
    "dissuaderai": "dissuadere",
    "dissuaderan": "dissuadere",
    "dissuaderanno": "dissuadere",
    "dissuaderebbe": "dissuadere",
    "dissuaderebber": "dissuadere",
    "dissuaderebbero": "dissuadere",
    "dissuaderei": "dissuadere",
    "dissuaderemmo": "dissuadere",
    "dissuaderemo": "dissuadere",
    "dissuadereste": "dissuadere",
    "dissuaderesti": "dissuadere",
    "dissuaderete": "dissuadere",
    "dissuaderà": "dissuadere",
    "dissuaderò": "dissuadere",
    "dissuadesse": "dissuadere",
    "dissuadesser": "dissuadere",
    "dissuadessero": "dissuadere",
    "dissuadessi": "dissuadere",
    "dissuadessimo": "dissuadere",
    "dissuadeste": "dissuadere",
    "dissuadesti": "dissuadere",
    "dissuadete": "dissuadere",
    "dissuadeva": "dissuadere",
    "dissuadevamo": "dissuadere",
    "dissuadevan": "dissuadere",
    "dissuadevano": "dissuadere",
    "dissuadevate": "dissuadere",
    "dissuadevi": "dissuadere",
    "dissuadevo": "dissuadere",
    "dissuadi": "dissuadere",
    "dissuadiamo": "dissuadere",
    "dissuadiate": "dissuadere",
    "dissuado": "dissuadere",
    "dissuadon": "dissuadere",
    "dissuadono": "dissuadere",
    "dissuasa": "dissuadere",
    "dissuase": "dissuadere",
    "dissuaser": "dissuadere",
    "dissuasero": "dissuadere",
    "dissuasi": "dissuadere",
    "dissuasioni": "dissuasione",
    "dissuasiva": "dissuasivo",
    "dissuasive": "dissuasivo",
    "dissuasivi": "dissuasivo",
    "dissuaso": "dissuadere",
    "dissuggella": "dissuggellare",
    "dissuggellai": "dissuggellare",
    "dissuggellammo": "dissuggellare",
    "dissuggellan": "dissuggellare",
    "dissuggellando": "dissuggellare",
    "dissuggellano": "dissuggellare",
    "dissuggellante": "dissuggellare",
    "dissuggellanti": "dissuggellare",
    "dissuggellar": "dissuggellare",
    "dissuggellaron": "dissuggellare",
    "dissuggellarono": "dissuggellare",
    "dissuggellasse": "dissuggellare",
    "dissuggellasser": "dissuggellare",
    "dissuggellassero": "dissuggellare",
    "dissuggellassi": "dissuggellare",
    "dissuggellassimo": "dissuggellare",
    "dissuggellaste": "dissuggellare",
    "dissuggellasti": "dissuggellare",
    "dissuggellata": "dissuggellare",
    "dissuggellate": "dissuggellare",
    "dissuggellati": "dissuggellare",
    "dissuggellato": "dissuggellare",
    "dissuggellava": "dissuggellare",
    "dissuggellavamo": "dissuggellare",
    "dissuggellavan": "dissuggellare",
    "dissuggellavano": "dissuggellare",
    "dissuggellavate": "dissuggellare",
    "dissuggellavi": "dissuggellare",
    "dissuggellavo": "dissuggellare",
    "dissuggellerai": "dissuggellare",
    "dissuggelleran": "dissuggellare",
    "dissuggelleranno": "dissuggellare",
    "dissuggellerebbe": "dissuggellare",
    "dissuggellerebber": "dissuggellare",
    "dissuggellerebbero": "dissuggellare",
    "dissuggellerei": "dissuggellare",
    "dissuggelleremmo": "dissuggellare",
    "dissuggelleremo": "dissuggellare",
    "dissuggellereste": "dissuggellare",
    "dissuggelleresti": "dissuggellare",
    "dissuggellerete": "dissuggellare",
    "dissuggellerà": "dissuggellare",
    "dissuggellerò": "dissuggellare",
    "dissuggelli": "dissuggellare",
    "dissuggelliamo": "dissuggellare",
    "dissuggelliate": "dissuggellare",
    "dissuggellin": "dissuggellare",
    "dissuggellino": "dissuggellare",
    "dissuggello": "dissuggellare",
    "dissuggellò": "dissuggellare",
    "dista": "distare",
    "distacca": "distaccare",
    "distaccai": "distaccare",
    "distaccamenti": "distaccamento",
    "distaccammo": "distaccare",
    "distaccan": "distaccare",
    "distaccando": "distaccare",
    "distaccano": "distaccare",
    "distaccante": "distaccare",
    "distaccanti": "distaccare",
    "distaccar": "distaccare",
    "distaccaron": "distaccare",
    "distaccarono": "distaccare",
    "distaccasse": "distaccare",
    "distaccasser": "distaccare",
    "distaccassero": "distaccare",
    "distaccassi": "distaccare",
    "distaccassimo": "distaccare",
    "distaccaste": "distaccare",
    "distaccasti": "distaccare",
    "distaccata": "distaccato",
    "distaccate": "distaccato",
    "distaccati": "distaccato",
    "distaccato": "distaccare",
    "distaccava": "distaccare",
    "distaccavamo": "distaccare",
    "distaccavan": "distaccare",
    "distaccavano": "distaccare",
    "distaccavate": "distaccare",
    "distaccavi": "distaccare",
    "distaccavo": "distaccare",
    "distaccherai": "distaccare",
    "distaccheran": "distaccare",
    "distaccheranno": "distaccare",
    "distaccherebbe": "distaccare",
    "distaccherebber": "distaccare",
    "distaccherebbero": "distaccare",
    "distaccherei": "distaccare",
    "distaccheremmo": "distaccare",
    "distaccheremo": "distaccare",
    "distacchereste": "distaccare",
    "distaccheresti": "distaccare",
    "distaccherete": "distaccare",
    "distaccherà": "distaccare",
    "distaccherò": "distaccare",
    "distacchi": "distacco",
    "distacchiamo": "distaccare",
    "distacchiate": "distaccare",
    "distacchin": "distaccare",
    "distacchino": "distaccare",
    "distacco": "distaccare",
    "distaccò": "distaccare",
    "distai": "distare",
    "distammo": "distare",
    "distan": "distare",
    "distando": "distare",
    "distano": "distare",
    "distante": "distare",
    "distanti": "distare",
    "distanze": "distanza",
    "distanzi": "distanziare",
    "distanzia": "distanziare",
    "distanziai": "distanziare",
    "distanziammo": "distanziare",
    "distanziamo": "distanziare",
    "distanzian": "distanziare",
    "distanziando": "distanziare",
    "distanziano": "distanziare",
    "distanziante": "distanziare",
    "distanzianti": "distanziare",
    "distanziar": "distanziare",
    "distanziaron": "distanziare",
    "distanziarono": "distanziare",
    "distanziasse": "distanziare",
    "distanziasser": "distanziare",
    "distanziassero": "distanziare",
    "distanziassi": "distanziare",
    "distanziassimo": "distanziare",
    "distanziaste": "distanziare",
    "distanziasti": "distanziare",
    "distanziata": "distanziare",
    "distanziate": "distanziare",
    "distanziati": "distanziare",
    "distanziato": "distanziare",
    "distanziava": "distanziare",
    "distanziavamo": "distanziare",
    "distanziavan": "distanziare",
    "distanziavano": "distanziare",
    "distanziavate": "distanziare",
    "distanziavi": "distanziare",
    "distanziavo": "distanziare",
    "distanzierai": "distanziare",
    "distanzieran": "distanziare",
    "distanzieranno": "distanziare",
    "distanzierebbe": "distanziare",
    "distanzierebber": "distanziare",
    "distanzierebbero": "distanziare",
    "distanzierei": "distanziare",
    "distanzieremmo": "distanziare",
    "distanzieremo": "distanziare",
    "distanziereste": "distanziare",
    "distanzieresti": "distanziare",
    "distanzierete": "distanziare",
    "distanzierà": "distanziare",
    "distanzierò": "distanziare",
    "distanzin": "distanziare",
    "distanzino": "distanziare",
    "distanzio": "distanziare",
    "distanziò": "distanziare",
    "distar": "distare",
    "distaron": "distare",
    "distarono": "distare",
    "distasse": "distare",
    "distasser": "distare",
    "distassero": "distare",
    "distassi": "distare",
    "distassimo": "distare",
    "distaste": "distare",
    "distasti": "distare",
    "distata": "distare",
    "distate": "distare",
    "distati": "distare",
    "distato": "distare",
    "distava": "distare",
    "distavamo": "distare",
    "distavan": "distare",
    "distavano": "distare",
    "distavate": "distare",
    "distavi": "distare",
    "distavo": "distare",
    "distenda": "distendere",
    "distendan": "distendere",
    "distendano": "distendere",
    "distende": "distendere",
    "distendemmo": "distendere",
    "distendendo": "distendere",
    "distendente": "distendere",
    "distendenti": "distendere",
    "distender": "distendere",
    "distenderai": "distendere",
    "distenderan": "distendere",
    "distenderanno": "distendere",
    "distenderebbe": "distendere",
    "distenderebber": "distendere",
    "distenderebbero": "distendere",
    "distenderei": "distendere",
    "distenderemmo": "distendere",
    "distenderemo": "distendere",
    "distendereste": "distendere",
    "distenderesti": "distendere",
    "distenderete": "distendere",
    "distenderà": "distendere",
    "distenderò": "distendere",
    "distendesse": "distendere",
    "distendesser": "distendere",
    "distendessero": "distendere",
    "distendessi": "distendere",
    "distendessimo": "distendere",
    "distendeste": "distendere",
    "distendesti": "distendere",
    "distendete": "distendere",
    "distendeva": "distendere",
    "distendevamo": "distendere",
    "distendevan": "distendere",
    "distendevano": "distendere",
    "distendevate": "distendere",
    "distendevi": "distendere",
    "distendevo": "distendere",
    "distendi": "distendere",
    "distendiamo": "distendere",
    "distendiate": "distendere",
    "distendo": "distendere",
    "distendon": "distendere",
    "distendono": "distendere",
    "distensioni": "distensione",
    "distensiva": "distensivo",
    "distensive": "distensivo",
    "distensivi": "distensivo",
    "disterai": "distare",
    "disteran": "distare",
    "disteranno": "distare",
    "disterebbe": "distare",
    "disterebber": "distare",
    "disterebbero": "distare",
    "disterei": "distare",
    "disteremmo": "distare",
    "disteremo": "distare",
    "distereste": "distare",
    "disteresti": "distare",
    "disterete": "distare",
    "disterà": "distare",
    "disterò": "distare",
    "distesa": "disteso",
    "distese": "disteso",
    "disteser": "distendere",
    "distesero": "distendere",
    "distesi": "disteso",
    "disteso": "distendere",
    "distesè": "distendere",
    "disti": "distare",
    "distiamo": "distare",
    "distiate": "distare",
    "distilla": "distillare",
    "distillai": "distillare",
    "distillammo": "distillare",
    "distillan": "distillare",
    "distillando": "distillare",
    "distillano": "distillare",
    "distillante": "distillare",
    "distillanti": "distillare",
    "distillar": "distillare",
    "distillaron": "distillare",
    "distillarono": "distillare",
    "distillasse": "distillare",
    "distillasser": "distillare",
    "distillassero": "distillare",
    "distillassi": "distillare",
    "distillassimo": "distillare",
    "distillaste": "distillare",
    "distillasti": "distillare",
    "distillata": "distillato",
    "distillate": "distillato",
    "distillati": "distillato",
    "distillato": "distillare",
    "distillatori": "distillatore",
    "distillava": "distillare",
    "distillavamo": "distillare",
    "distillavan": "distillare",
    "distillavano": "distillare",
    "distillavate": "distillare",
    "distillavi": "distillare",
    "distillavo": "distillare",
    "distillazioni": "distillazione",
    "distillerai": "distillare",
    "distilleran": "distillare",
    "distilleranno": "distillare",
    "distillerebbe": "distillare",
    "distillerebber": "distillare",
    "distillerebbero": "distillare",
    "distillerei": "distillare",
    "distilleremmo": "distillare",
    "distilleremo": "distillare",
    "distillereste": "distillare",
    "distilleresti": "distillare",
    "distillerete": "distillare",
    "distillerie": "distilleria",
    "distillerà": "distillare",
    "distillerò": "distillare",
    "distilli": "distillare",
    "distilliamo": "distillare",
    "distilliate": "distillare",
    "distillin": "distillare",
    "distillino": "distillare",
    "distillo": "distillare",
    "distillò": "distillare",
    "distin": "distare",
    "distingua": "distinguere",
    "distinguan": "distinguere",
    "distinguano": "distinguere",
    "distingue": "distinguere",
    "distinguemmo": "distinguere",
    "distinguendo": "distinguere",
    "distinguente": "distinguere",
    "distinguenti": "distinguere",
    "distinguer": "distinguere",
    "distinguerai": "distinguere",
    "distingueran": "distinguere",
    "distingueranno": "distinguere",
    "distinguerebbe": "distinguere",
    "distinguerebber": "distinguere",
    "distinguerebbero": "distinguere",
    "distinguerei": "distinguere",
    "distingueremmo": "distinguere",
    "distingueremo": "distinguere",
    "distinguereste": "distinguere",
    "distingueresti": "distinguere",
    "distinguerete": "distinguere",
    "distinguerà": "distinguere",
    "distinguerò": "distinguere",
    "distinguesse": "distinguere",
    "distinguesser": "distinguere",
    "distinguessero": "distinguere",
    "distinguessi": "distinguere",
    "distinguessimo": "distinguere",
    "distingueste": "distinguere",
    "distinguesti": "distinguere",
    "distinguete": "distinguere",
    "distingueva": "distinguere",
    "distinguevamo": "distinguere",
    "distinguevan": "distinguere",
    "distinguevano": "distinguere",
    "distinguevate": "distinguere",
    "distinguevi": "distinguere",
    "distinguevo": "distinguere",
    "distingui": "distinguere",
    "distinguiamo": "distinguere",
    "distinguiate": "distinguere",
    "distinguibili": "distinguibile",
    "distinguo": "distinguere",
    "distinguon": "distinguere",
    "distinguono": "distinguere",
    "distino": "distare",
    "distinse": "distinguere",
    "distinser": "distinguere",
    "distinsero": "distinguere",
    "distinsi": "distinguere",
    "distinta": "distinto",
    "distinte": "distinto",
    "distinti": "distinto",
    "distintiva": "distintivo",
    "distintive": "distintivo",
    "distintivi": "distintivo",
    "distinto": "distinguere",
    "distinzioni": "distinzione",
    "disto": "distare",
    "distogli": "distogliere",
    "distogliamo": "distogliere",
    "distogliate": "distogliere",
    "distoglie": "distogliere",
    "distogliemmo": "distogliere",
    "distogliendo": "distogliere",
    "distogliente": "distogliere",
    "distoglienti": "distogliere",
    "distoglier": "distogliere",
    "distoglierai": "distogliere",
    "distoglieran": "distogliere",
    "distoglieranno": "distogliere",
    "distoglierebbe": "distogliere",
    "distoglierebber": "distogliere",
    "distoglierebbero": "distogliere",
    "distoglierei": "distogliere",
    "distoglieremmo": "distogliere",
    "distoglieremo": "distogliere",
    "distogliereste": "distogliere",
    "distoglieresti": "distogliere",
    "distoglierete": "distogliere",
    "distoglierà": "distogliere",
    "distoglierò": "distogliere",
    "distogliesse": "distogliere",
    "distogliesser": "distogliere",
    "distogliessero": "distogliere",
    "distogliessi": "distogliere",
    "distogliessimo": "distogliere",
    "distoglieste": "distogliere",
    "distogliesti": "distogliere",
    "distogliete": "distogliere",
    "distoglieva": "distogliere",
    "distoglievamo": "distogliere",
    "distoglievan": "distogliere",
    "distoglievano": "distogliere",
    "distoglievate": "distogliere",
    "distoglievi": "distogliere",
    "distoglievo": "distogliere",
    "distolga": "distogliere",
    "distolgan": "distogliere",
    "distolgano": "distogliere",
    "distolgo": "distogliere",
    "distolgon": "distogliere",
    "distolgono": "distogliere",
    "distolse": "distogliere",
    "distolser": "distogliere",
    "distolsero": "distogliere",
    "distolsi": "distogliere",
    "distolta": "distogliere",
    "distolte": "distogliere",
    "distolti": "distogliere",
    "distolto": "distogliere",
    "distorca": "distorcere",
    "distorcan": "distorcere",
    "distorcano": "distorcere",
    "distorce": "distorcere",
    "distorcemmo": "distorcere",
    "distorcendo": "distorcere",
    "distorcente": "distorcere",
    "distorcenti": "distorcere",
    "distorcer": "distorcere",
    "distorcerai": "distorcere",
    "distorceran": "distorcere",
    "distorceranno": "distorcere",
    "distorcerebbe": "distorcere",
    "distorcerebber": "distorcere",
    "distorcerebbero": "distorcere",
    "distorcerei": "distorcere",
    "distorceremmo": "distorcere",
    "distorceremo": "distorcere",
    "distorcereste": "distorcere",
    "distorceresti": "distorcere",
    "distorcerete": "distorcere",
    "distorcerà": "distorcere",
    "distorcerò": "distorcere",
    "distorcesse": "distorcere",
    "distorcesser": "distorcere",
    "distorcessero": "distorcere",
    "distorcessi": "distorcere",
    "distorcessimo": "distorcere",
    "distorceste": "distorcere",
    "distorcesti": "distorcere",
    "distorcete": "distorcere",
    "distorceva": "distorcere",
    "distorcevamo": "distorcere",
    "distorcevan": "distorcere",
    "distorcevano": "distorcere",
    "distorcevate": "distorcere",
    "distorcevi": "distorcere",
    "distorcevo": "distorcere",
    "distorci": "distorcere",
    "distorciamo": "distorcere",
    "distorciate": "distorcere",
    "distorco": "distorcere",
    "distorcon": "distorcere",
    "distorcono": "distorcere",
    "distorna": "distornare",
    "distornai": "distornare",
    "distornammo": "distornare",
    "distornan": "distornare",
    "distornando": "distornare",
    "distornano": "distornare",
    "distornante": "distornare",
    "distornanti": "distornare",
    "distornar": "distornare",
    "distornaron": "distornare",
    "distornarono": "distornare",
    "distornasse": "distornare",
    "distornasser": "distornare",
    "distornassero": "distornare",
    "distornassi": "distornare",
    "distornassimo": "distornare",
    "distornaste": "distornare",
    "distornasti": "distornare",
    "distornata": "distornare",
    "distornate": "distornare",
    "distornati": "distornare",
    "distornato": "distornare",
    "distornava": "distornare",
    "distornavamo": "distornare",
    "distornavan": "distornare",
    "distornavano": "distornare",
    "distornavate": "distornare",
    "distornavi": "distornare",
    "distornavo": "distornare",
    "distornerai": "distornare",
    "distorneran": "distornare",
    "distorneranno": "distornare",
    "distornerebbe": "distornare",
    "distornerebber": "distornare",
    "distornerebbero": "distornare",
    "distornerei": "distornare",
    "distorneremmo": "distornare",
    "distorneremo": "distornare",
    "distornereste": "distornare",
    "distorneresti": "distornare",
    "distornerete": "distornare",
    "distornerà": "distornare",
    "distornerò": "distornare",
    "distorni": "distornare",
    "distorniamo": "distornare",
    "distorniate": "distornare",
    "distornin": "distornare",
    "distornino": "distornare",
    "distorno": "distornare",
    "distornò": "distornare",
    "distorse": "distorcere",
    "distorser": "distorcere",
    "distorsero": "distorcere",
    "distorsi": "distorcere",
    "distorsioni": "distorsione",
    "distorsiva": "distorsivo",
    "distorsive": "distorsivo",
    "distorsivi": "distorsivo",
    "distorta": "distorcere",
    "distorte": "distorcere",
    "distorti": "distorcere",
    "distorto": "distorcere",
    "distrae": "distrarre",
    "distraemmo": "distrarre",
    "distraendo": "distrarre",
    "distraente": "distrarre",
    "distraenti": "distrarre",
    "distraesse": "distrarre",
    "distraesser": "distrarre",
    "distraessero": "distrarre",
    "distraessi": "distrarre",
    "distraessimo": "distrarre",
    "distraeste": "distrarre",
    "distraesti": "distrarre",
    "distraete": "distrarre",
    "distraeva": "distrarre",
    "distraevamo": "distrarre",
    "distraevan": "distrarre",
    "distraevano": "distrarre",
    "distraevate": "distrarre",
    "distraevi": "distrarre",
    "distraevo": "distrarre",
    "distragga": "distrarre",
    "distraggan": "distrarre",
    "distraggano": "distrarre",
    "distraggo": "distrarre",
    "distraggon": "distrarre",
    "distraggono": "distrarre",
    "distrai": "distrarre",
    "distraiamo": "distrarre",
    "distraiate": "distrarre",
    "distrarr": "distrarre",
    "distrarrai": "distrarre",
    "distrarran": "distrarre",
    "distrarranno": "distrarre",
    "distrarrebbe": "distrarre",
    "distrarrebber": "distrarre",
    "distrarrebbero": "distrarre",
    "distrarrei": "distrarre",
    "distrarremmo": "distrarre",
    "distrarremo": "distrarre",
    "distrarreste": "distrarre",
    "distrarresti": "distrarre",
    "distrarrete": "distrarre",
    "distrarrà": "distrarre",
    "distrarrò": "distrarre",
    "distrasse": "distrarre",
    "distrasser": "distrarre",
    "distrassero": "distrarre",
    "distrassi": "distrarre",
    "distratta": "distratto",
    "distratte": "distratto",
    "distratti": "distratto",
    "distratto": "distrarre",
    "distrazioni": "distrazione",
    "distretti": "distretto",
    "distrettuali": "distrettuale",
    "distribuendo": "distribuire",
    "distribuente": "distribuire",
    "distribuenti": "distribuire",
    "distribuiamo": "distribuire",
    "distribuiate": "distribuire",
    "distribuii": "distribuire",
    "distribuimmo": "distribuire",
    "distribuir": "distribuire",
    "distribuirai": "distribuire",
    "distribuiran": "distribuire",
    "distribuiranno": "distribuire",
    "distribuirebbe": "distribuire",
    "distribuirebber": "distribuire",
    "distribuirebbero": "distribuire",
    "distribuirei": "distribuire",
    "distribuiremmo": "distribuire",
    "distribuiremo": "distribuire",
    "distribuireste": "distribuire",
    "distribuiresti": "distribuire",
    "distribuirete": "distribuire",
    "distribuiron": "distribuire",
    "distribuirono": "distribuire",
    "distribuirà": "distribuire",
    "distribuirò": "distribuire",
    "distribuisca": "distribuire",
    "distribuiscan": "distribuire",
    "distribuiscano": "distribuire",
    "distribuisce": "distribuire",
    "distribuisci": "distribuire",
    "distribuisco": "distribuire",
    "distribuiscon": "distribuire",
    "distribuiscono": "distribuire",
    "distribuisse": "distribuire",
    "distribuisser": "distribuire",
    "distribuissero": "distribuire",
    "distribuissi": "distribuire",
    "distribuissimo": "distribuire",
    "distribuiste": "distribuire",
    "distribuisti": "distribuire",
    "distribuita": "distribuire",
    "distribuite": "distribuire",
    "distribuiti": "distribuire",
    "distribuito": "distribuire",
    "distribuiva": "distribuire",
    "distribuivamo": "distribuire",
    "distribuivan": "distribuire",
    "distribuivano": "distribuire",
    "distribuivate": "distribuire",
    "distribuivi": "distribuire",
    "distribuivo": "distribuire",
    "distributiva": "distributivo",
    "distributive": "distributivo",
    "distributivi": "distributivo",
    "distributori": "distributore",
    "distributrice": "distributore",
    "distributrici": "distributore",
    "distribuzioni": "distribuzione",
    "distribuì": "distribuire",
    "districa": "districare",
    "districai": "districare",
    "districammo": "districare",
    "districan": "districare",
    "districando": "districare",
    "districano": "districare",
    "districante": "districare",
    "districanti": "districare",
    "districar": "districare",
    "districaron": "districare",
    "districarono": "districare",
    "districasse": "districare",
    "districasser": "districare",
    "districassero": "districare",
    "districassi": "districare",
    "districassimo": "districare",
    "districaste": "districare",
    "districasti": "districare",
    "districata": "districare",
    "districate": "districare",
    "districati": "districare",
    "districato": "districare",
    "districava": "districare",
    "districavamo": "districare",
    "districavan": "districare",
    "districavano": "districare",
    "districavate": "districare",
    "districavi": "districare",
    "districavo": "districare",
    "districherai": "districare",
    "districheran": "districare",
    "districheranno": "districare",
    "districherebbe": "districare",
    "districherebber": "districare",
    "districherebbero": "districare",
    "districherei": "districare",
    "districheremmo": "districare",
    "districheremo": "districare",
    "districhereste": "districare",
    "districheresti": "districare",
    "districherete": "districare",
    "districherà": "districare",
    "districherò": "districare",
    "districhi": "districare",
    "districhiamo": "districare",
    "districhiate": "districare",
    "districhin": "districare",
    "districhino": "districare",
    "districo": "districare",
    "districò": "districare",
    "distrofie": "distrofia",
    "distrugga": "distruggere",
    "distruggan": "distruggere",
    "distruggano": "distruggere",
    "distrugge": "distruggere",
    "distruggemmo": "distruggere",
    "distruggendo": "distruggere",
    "distruggente": "distruggere",
    "distruggenti": "distruggere",
    "distrugger": "distruggere",
    "distruggerai": "distruggere",
    "distruggeran": "distruggere",
    "distruggeranno": "distruggere",
    "distruggerebbe": "distruggere",
    "distruggerebber": "distruggere",
    "distruggerebbero": "distruggere",
    "distruggerei": "distruggere",
    "distruggeremmo": "distruggere",
    "distruggeremo": "distruggere",
    "distruggereste": "distruggere",
    "distruggeresti": "distruggere",
    "distruggerete": "distruggere",
    "distruggerà": "distruggere",
    "distruggerò": "distruggere",
    "distruggesse": "distruggere",
    "distruggesser": "distruggere",
    "distruggessero": "distruggere",
    "distruggessi": "distruggere",
    "distruggessimo": "distruggere",
    "distruggeste": "distruggere",
    "distruggesti": "distruggere",
    "distruggete": "distruggere",
    "distruggeva": "distruggere",
    "distruggevamo": "distruggere",
    "distruggevan": "distruggere",
    "distruggevano": "distruggere",
    "distruggevate": "distruggere",
    "distruggevi": "distruggere",
    "distruggevo": "distruggere",
    "distruggi": "distruggere",
    "distruggiamo": "distruggere",
    "distruggiate": "distruggere",
    "distruggitrici": "distruggitrice",
    "distruggo": "distruggere",
    "distruggon": "distruggere",
    "distruggono": "distruggere",
    "distrusse": "distruggere",
    "distrusser": "distruggere",
    "distrussero": "distruggere",
    "distrussi": "distruggere",
    "distrutta": "distrutto",
    "distrutte": "distrutto",
    "distrutti": "distrutto",
    "distruttibili": "distruttibile",
    "distruttiva": "distruttivo",
    "distruttive": "distruttivo",
    "distruttivi": "distruttivo",
    "distrutto": "distruggere",
    "distruttori": "distruttore",
    "distruttrice": "distruttore",
    "distruttrici": "distruttore",
    "distruzioni": "distruzione",
    "disturba": "disturbare",
    "disturbai": "disturbare",
    "disturbammo": "disturbare",
    "disturban": "disturbare",
    "disturbando": "disturbare",
    "disturbano": "disturbare",
    "disturbante": "disturbare",
    "disturbanti": "disturbare",
    "disturbar": "disturbare",
    "disturbaron": "disturbare",
    "disturbarono": "disturbare",
    "disturbasse": "disturbare",
    "disturbasser": "disturbare",
    "disturbassero": "disturbare",
    "disturbassi": "disturbare",
    "disturbassimo": "disturbare",
    "disturbaste": "disturbare",
    "disturbasti": "disturbare",
    "disturbata": "disturbare",
    "disturbate": "disturbare",
    "disturbati": "disturbato",
    "disturbato": "disturbare",
    "disturbatori": "disturbatore",
    "disturbava": "disturbare",
    "disturbavamo": "disturbare",
    "disturbavan": "disturbare",
    "disturbavano": "disturbare",
    "disturbavate": "disturbare",
    "disturbavi": "disturbare",
    "disturbavo": "disturbare",
    "disturberai": "disturbare",
    "disturberan": "disturbare",
    "disturberanno": "disturbare",
    "disturberebbe": "disturbare",
    "disturberebber": "disturbare",
    "disturberebbero": "disturbare",
    "disturberei": "disturbare",
    "disturberemmo": "disturbare",
    "disturberemo": "disturbare",
    "disturbereste": "disturbare",
    "disturberesti": "disturbare",
    "disturberete": "disturbare",
    "disturberà": "disturbare",
    "disturberò": "disturbare",
    "disturbi": "disturbo",
    "disturbiamo": "disturbare",
    "disturbiate": "disturbare",
    "disturbin": "disturbare",
    "disturbino": "disturbare",
    "disturbo": "disturbare",
    "disturbò": "disturbare",
    "distò": "distare",
    "disubbida": "disubbidire",
    "disubbidan": "disubbidire",
    "disubbidano": "disubbidire",
    "disubbide": "disubbidire",
    "disubbidendo": "disubbidire",
    "disubbidente": "disubbidire",
    "disubbidenti": "disubbidire",
    "disubbidi": "disubbidire",
    "disubbidiamo": "disubbidire",
    "disubbidiate": "disubbidire",
    "disubbidienti": "disubbidiente",
    "disubbidienze": "disubbidienza",
    "disubbidii": "disubbidire",
    "disubbidimmo": "disubbidire",
    "disubbidir": "disubbidire",
    "disubbidirai": "disubbidire",
    "disubbidiran": "disubbidire",
    "disubbidiranno": "disubbidire",
    "disubbidirebbe": "disubbidire",
    "disubbidirebber": "disubbidire",
    "disubbidirebbero": "disubbidire",
    "disubbidirei": "disubbidire",
    "disubbidiremmo": "disubbidire",
    "disubbidiremo": "disubbidire",
    "disubbidireste": "disubbidire",
    "disubbidiresti": "disubbidire",
    "disubbidirete": "disubbidire",
    "disubbidiron": "disubbidire",
    "disubbidirono": "disubbidire",
    "disubbidirà": "disubbidire",
    "disubbidirò": "disubbidire",
    "disubbidisse": "disubbidire",
    "disubbidisser": "disubbidire",
    "disubbidissero": "disubbidire",
    "disubbidissi": "disubbidire",
    "disubbidissimo": "disubbidire",
    "disubbidiste": "disubbidire",
    "disubbidisti": "disubbidire",
    "disubbidita": "disubbidire",
    "disubbidite": "disubbidire",
    "disubbiditi": "disubbidire",
    "disubbidito": "disubbidire",
    "disubbidiva": "disubbidire",
    "disubbidivamo": "disubbidire",
    "disubbidivan": "disubbidire",
    "disubbidivano": "disubbidire",
    "disubbidivate": "disubbidire",
    "disubbidivi": "disubbidire",
    "disubbidivo": "disubbidire",
    "disubbido": "disubbidire",
    "disubbidon": "disubbidire",
    "disubbidono": "disubbidire",
    "disubbidì": "disubbidire",
    "disuguaglianze": "disuguaglianza",
    "disuguali": "disuguale",
    "disumana": "disumano",
    "disumanai": "disumanare",
    "disumanammo": "disumanare",
    "disumanan": "disumanare",
    "disumanando": "disumanare",
    "disumanano": "disumanare",
    "disumanante": "disumanare",
    "disumananti": "disumanare",
    "disumanar": "disumanare",
    "disumanaron": "disumanare",
    "disumanarono": "disumanare",
    "disumanasse": "disumanare",
    "disumanasser": "disumanare",
    "disumanassero": "disumanare",
    "disumanassi": "disumanare",
    "disumanassimo": "disumanare",
    "disumanaste": "disumanare",
    "disumanasti": "disumanare",
    "disumanata": "disumanare",
    "disumanate": "disumanare",
    "disumanati": "disumanare",
    "disumanato": "disumanare",
    "disumanava": "disumanare",
    "disumanavamo": "disumanare",
    "disumanavan": "disumanare",
    "disumanavano": "disumanare",
    "disumanavate": "disumanare",
    "disumanavi": "disumanare",
    "disumanavo": "disumanare",
    "disumane": "disumano",
    "disumanerai": "disumanare",
    "disumaneran": "disumanare",
    "disumaneranno": "disumanare",
    "disumanerebbe": "disumanare",
    "disumanerebber": "disumanare",
    "disumanerebbero": "disumanare",
    "disumanerei": "disumanare",
    "disumaneremmo": "disumanare",
    "disumaneremo": "disumanare",
    "disumanereste": "disumanare",
    "disumaneresti": "disumanare",
    "disumanerete": "disumanare",
    "disumanerà": "disumanare",
    "disumanerò": "disumanare",
    "disumani": "disumano",
    "disumaniamo": "disumanare",
    "disumaniate": "disumanare",
    "disumanin": "disumanare",
    "disumanino": "disumanare",
    "disumanizzanti": "disumanizzante",
    "disumano": "disumanare",
    "disumanò": "disumanare",
    "disunendo": "disunire",
    "disunente": "disunire",
    "disunenti": "disunire",
    "disuniamo": "disunire",
    "disuniate": "disunire",
    "disunii": "disunire",
    "disunimmo": "disunire",
    "disunioni": "disunione",
    "disunir": "disunire",
    "disunirai": "disunire",
    "disuniran": "disunire",
    "disuniranno": "disunire",
    "disunirebbe": "disunire",
    "disunirebber": "disunire",
    "disunirebbero": "disunire",
    "disunirei": "disunire",
    "disuniremmo": "disunire",
    "disuniremo": "disunire",
    "disunireste": "disunire",
    "disuniresti": "disunire",
    "disunirete": "disunire",
    "disuniron": "disunire",
    "disunirono": "disunire",
    "disunirà": "disunire",
    "disunirò": "disunire",
    "disunisca": "disunire",
    "disuniscan": "disunire",
    "disuniscano": "disunire",
    "disunisce": "disunire",
    "disunisci": "disunire",
    "disunisco": "disunire",
    "disuniscon": "disunire",
    "disuniscono": "disunire",
    "disunisse": "disunire",
    "disunisser": "disunire",
    "disunissero": "disunire",
    "disunissi": "disunire",
    "disunissimo": "disunire",
    "disuniste": "disunire",
    "disunisti": "disunire",
    "disunita": "disunito",
    "disunite": "disunito",
    "disuniti": "disunito",
    "disunito": "disunire",
    "disuniva": "disunire",
    "disunivamo": "disunire",
    "disunivan": "disunire",
    "disunivano": "disunire",
    "disunivate": "disunire",
    "disunivi": "disunire",
    "disunivo": "disunire",
    "disunì": "disunire",
    "disusa": "disusare",
    "disusai": "disusare",
    "disusammo": "disusare",
    "disusan": "disusare",
    "disusando": "disusare",
    "disusano": "disusare",
    "disusante": "disusare",
    "disusanti": "disusare",
    "disusar": "disusare",
    "disusaron": "disusare",
    "disusarono": "disusare",
    "disusasse": "disusare",
    "disusasser": "disusare",
    "disusassero": "disusare",
    "disusassi": "disusare",
    "disusassimo": "disusare",
    "disusaste": "disusare",
    "disusasti": "disusare",
    "disusata": "disusare",
    "disusate": "disusare",
    "disusati": "disusare",
    "disusato": "disusare",
    "disusava": "disusare",
    "disusavamo": "disusare",
    "disusavan": "disusare",
    "disusavano": "disusare",
    "disusavate": "disusare",
    "disusavi": "disusare",
    "disusavo": "disusare",
    "disuserai": "disusare",
    "disuseran": "disusare",
    "disuseranno": "disusare",
    "disuserebbe": "disusare",
    "disuserebber": "disusare",
    "disuserebbero": "disusare",
    "disuserei": "disusare",
    "disuseremmo": "disusare",
    "disuseremo": "disusare",
    "disusereste": "disusare",
    "disuseresti": "disusare",
    "disuserete": "disusare",
    "disuserà": "disusare",
    "disuserò": "disusare",
    "disusi": "disusare",
    "disusiamo": "disusare",
    "disusiate": "disusare",
    "disusin": "disusare",
    "disusino": "disusare",
    "disuso": "disusare",
    "disusò": "disusare",
    "disvalori": "disvalore",
    "disvela": "disvelare",
    "disvelai": "disvelare",
    "disvelamenti": "disvelamento",
    "disvelammo": "disvelare",
    "disvelan": "disvelare",
    "disvelando": "disvelare",
    "disvelano": "disvelare",
    "disvelante": "disvelare",
    "disvelanti": "disvelare",
    "disvelar": "disvelare",
    "disvelaron": "disvelare",
    "disvelarono": "disvelare",
    "disvelasse": "disvelare",
    "disvelasser": "disvelare",
    "disvelassero": "disvelare",
    "disvelassi": "disvelare",
    "disvelassimo": "disvelare",
    "disvelaste": "disvelare",
    "disvelasti": "disvelare",
    "disvelata": "disvelato",
    "disvelate": "disvelato",
    "disvelati": "disvelato",
    "disvelato": "disvelare",
    "disvelava": "disvelare",
    "disvelavamo": "disvelare",
    "disvelavan": "disvelare",
    "disvelavano": "disvelare",
    "disvelavate": "disvelare",
    "disvelavi": "disvelare",
    "disvelavo": "disvelare",
    "disvelerai": "disvelare",
    "disveleran": "disvelare",
    "disveleranno": "disvelare",
    "disvelerebbe": "disvelare",
    "disvelerebber": "disvelare",
    "disvelerebbero": "disvelare",
    "disvelerei": "disvelare",
    "disveleremmo": "disvelare",
    "disveleremo": "disvelare",
    "disvelereste": "disvelare",
    "disveleresti": "disvelare",
    "disvelerete": "disvelare",
    "disvelerà": "disvelare",
    "disvelerò": "disvelare",
    "disveli": "disvelare",
    "disveliamo": "disvelare",
    "disveliate": "disvelare",
    "disvelin": "disvelare",
    "disvelino": "disvelare",
    "disvelo": "disvelare",
    "disvelò": "disvelare",
    "disvesta": "disvestire",
    "disvestan": "disvestire",
    "disvestano": "disvestire",
    "disveste": "disvestire",
    "disvestendo": "disvestire",
    "disvestente": "disvestire",
    "disvestenti": "disvestire",
    "disvesti": "disvestire",
    "disvestiamo": "disvestire",
    "disvestiate": "disvestire",
    "disvestii": "disvestire",
    "disvestimmo": "disvestire",
    "disvestir": "disvestire",
    "disvestirai": "disvestire",
    "disvestiran": "disvestire",
    "disvestiranno": "disvestire",
    "disvestirebbe": "disvestire",
    "disvestirebber": "disvestire",
    "disvestirebbero": "disvestire",
    "disvestirei": "disvestire",
    "disvestiremmo": "disvestire",
    "disvestiremo": "disvestire",
    "disvestireste": "disvestire",
    "disvestiresti": "disvestire",
    "disvestirete": "disvestire",
    "disvestiron": "disvestire",
    "disvestirono": "disvestire",
    "disvestirà": "disvestire",
    "disvestirò": "disvestire",
    "disvestisse": "disvestire",
    "disvestisser": "disvestire",
    "disvestissero": "disvestire",
    "disvestissi": "disvestire",
    "disvestissimo": "disvestire",
    "disvestiste": "disvestire",
    "disvestisti": "disvestire",
    "disvestita": "disvestire",
    "disvestite": "disvestire",
    "disvestiti": "disvestire",
    "disvestito": "disvestire",
    "disvestiva": "disvestire",
    "disvestivamo": "disvestire",
    "disvestivan": "disvestire",
    "disvestivano": "disvestire",
    "disvestivate": "disvestire",
    "disvestivi": "disvestire",
    "disvestivo": "disvestire",
    "disvesto": "disvestire",
    "disveston": "disvestire",
    "disvestono": "disvestire",
    "disvestì": "disvestire",
    "disvola": "disvolere",
    "disvolan": "disvolere",
    "disvolano": "disvolere",
    "disvole": "disvolere",
    "disvolei": "disvolere",
    "disvolemmo": "disvolere",
    "disvolendo": "disvolere",
    "disvolente": "disvolere",
    "disvolenti": "disvolere",
    "disvoler": "disvolere",
    "disvolerai": "disvolere",
    "disvoleran": "disvolere",
    "disvoleranno": "disvolere",
    "disvolerebbe": "disvolere",
    "disvolerebber": "disvolere",
    "disvolerebbero": "disvolere",
    "disvolerei": "disvolere",
    "disvoleremmo": "disvolere",
    "disvoleremo": "disvolere",
    "disvolereste": "disvolere",
    "disvoleresti": "disvolere",
    "disvolerete": "disvolere",
    "disvoleron": "disvolere",
    "disvolerono": "disvolere",
    "disvolerà": "disvolere",
    "disvolerò": "disvolere",
    "disvolesse": "disvolere",
    "disvolesser": "disvolere",
    "disvolessero": "disvolere",
    "disvolessi": "disvolere",
    "disvolessimo": "disvolere",
    "disvoleste": "disvolere",
    "disvolesti": "disvolere",
    "disvolete": "disvolere",
    "disvoleva": "disvolere",
    "disvolevamo": "disvolere",
    "disvolevan": "disvolere",
    "disvolevano": "disvolere",
    "disvolevate": "disvolere",
    "disvolevi": "disvolere",
    "disvolevo": "disvolere",
    "disvoli": "disvolere",
    "disvoliamo": "disvolere",
    "disvoliate": "disvolere",
    "disvolo": "disvolere",
    "disvolon": "disvolere",
    "disvolono": "disvolere",
    "disvoluta": "disvolere",
    "disvolute": "disvolere",
    "disvoluti": "disvolere",
    "disvoluto": "disvolere",
    "disvolè": "disvolere",
    "dita": "dito",
    "dite": "dire",
    "diteggerai": "diteggiare",
    "diteggeran": "diteggiare",
    "diteggeranno": "diteggiare",
    "diteggerebbe": "diteggiare",
    "diteggerebber": "diteggiare",
    "diteggerebbero": "diteggiare",
    "diteggerei": "diteggiare",
    "diteggeremmo": "diteggiare",
    "diteggeremo": "diteggiare",
    "diteggereste": "diteggiare",
    "diteggeresti": "diteggiare",
    "diteggerete": "diteggiare",
    "diteggerà": "diteggiare",
    "diteggerò": "diteggiare",
    "diteggi": "diteggiare",
    "diteggia": "diteggiare",
    "diteggiai": "diteggiare",
    "diteggiammo": "diteggiare",
    "diteggiamo": "diteggiare",
    "diteggian": "diteggiare",
    "diteggiando": "diteggiare",
    "diteggiano": "diteggiare",
    "diteggiante": "diteggiare",
    "diteggianti": "diteggiare",
    "diteggiar": "diteggiare",
    "diteggiaron": "diteggiare",
    "diteggiarono": "diteggiare",
    "diteggiasse": "diteggiare",
    "diteggiasser": "diteggiare",
    "diteggiassero": "diteggiare",
    "diteggiassi": "diteggiare",
    "diteggiassimo": "diteggiare",
    "diteggiaste": "diteggiare",
    "diteggiasti": "diteggiare",
    "diteggiata": "diteggiare",
    "diteggiate": "diteggiare",
    "diteggiati": "diteggiare",
    "diteggiato": "diteggiare",
    "diteggiava": "diteggiare",
    "diteggiavamo": "diteggiare",
    "diteggiavan": "diteggiare",
    "diteggiavano": "diteggiare",
    "diteggiavate": "diteggiare",
    "diteggiavi": "diteggiare",
    "diteggiavo": "diteggiare",
    "diteggin": "diteggiare",
    "diteggino": "diteggiare",
    "diteggio": "diteggiare",
    "diteggiò": "diteggiare",
    "ditini": "ditino",
    "ditirambi": "ditirambo",
    "dittatori": "dittatorio",
    "dittatoria": "dittatorio",
    "dittatoriali": "dittatoriale",
    "dittatorie": "dittatorio",
    "dittatrice": "dittatore",
    "dittatrici": "dittatore",
    "dittature": "dittatura",
    "ditte": "ditta",
    "dittera": "dittero",
    "dittere": "dittero",
    "ditteri": "dittero",
    "diuretica": "diuretico",
    "diuretiche": "diuretico",
    "diuretici": "diuretico",
    "diurna": "diurno",
    "diurne": "diurno",
    "diurni": "diurno",
    "diuturna": "diuturno",
    "diuturne": "diuturno",
    "diuturni": "diuturno",
    "diva": "divo",
    "divaga": "divagare",
    "divagai": "divagare",
    "divagammo": "divagare",
    "divagan": "divagare",
    "divagando": "divagare",
    "divagano": "divagare",
    "divagante": "divagare",
    "divaganti": "divagare",
    "divagar": "divagare",
    "divagaron": "divagare",
    "divagarono": "divagare",
    "divagasse": "divagare",
    "divagasser": "divagare",
    "divagassero": "divagare",
    "divagassi": "divagare",
    "divagassimo": "divagare",
    "divagaste": "divagare",
    "divagasti": "divagare",
    "divagata": "divagare",
    "divagate": "divagare",
    "divagati": "divagare",
    "divagato": "divagare",
    "divagatori": "divagatorio",
    "divagatoria": "divagatorio",
    "divagatorie": "divagatorio",
    "divagava": "divagare",
    "divagavamo": "divagare",
    "divagavan": "divagare",
    "divagavano": "divagare",
    "divagavate": "divagare",
    "divagavi": "divagare",
    "divagavo": "divagare",
    "divagazioni": "divagazione",
    "divagherai": "divagare",
    "divagheran": "divagare",
    "divagheranno": "divagare",
    "divagherebbe": "divagare",
    "divagherebber": "divagare",
    "divagherebbero": "divagare",
    "divagherei": "divagare",
    "divagheremmo": "divagare",
    "divagheremo": "divagare",
    "divaghereste": "divagare",
    "divagheresti": "divagare",
    "divagherete": "divagare",
    "divagherà": "divagare",
    "divagherò": "divagare",
    "divaghi": "divagare",
    "divaghiamo": "divagare",
    "divaghiate": "divagare",
    "divaghin": "divagare",
    "divaghino": "divagare",
    "divago": "divagare",
    "divagò": "divagare",
    "divampa": "divampare",
    "divampai": "divampare",
    "divampammo": "divampare",
    "divampan": "divampare",
    "divampando": "divampare",
    "divampano": "divampare",
    "divampante": "divampare",
    "divampanti": "divampare",
    "divampar": "divampare",
    "divamparon": "divampare",
    "divamparono": "divampare",
    "divampasse": "divampare",
    "divampasser": "divampare",
    "divampassero": "divampare",
    "divampassi": "divampare",
    "divampassimo": "divampare",
    "divampaste": "divampare",
    "divampasti": "divampare",
    "divampata": "divampare",
    "divampate": "divampare",
    "divampati": "divampare",
    "divampato": "divampare",
    "divampava": "divampare",
    "divampavamo": "divampare",
    "divampavan": "divampare",
    "divampavano": "divampare",
    "divampavate": "divampare",
    "divampavi": "divampare",
    "divampavo": "divampare",
    "divamperai": "divampare",
    "divamperan": "divampare",
    "divamperanno": "divampare",
    "divamperebbe": "divampare",
    "divamperebber": "divampare",
    "divamperebbero": "divampare",
    "divamperei": "divampare",
    "divamperemmo": "divampare",
    "divamperemo": "divampare",
    "divampereste": "divampare",
    "divamperesti": "divampare",
    "divamperete": "divampare",
    "divamperà": "divampare",
    "divamperò": "divampare",
    "divampi": "divampare",
    "divampiamo": "divampare",
    "divampiate": "divampare",
    "divampin": "divampare",
    "divampino": "divampare",
    "divampo": "divampare",
    "divampò": "divampare",
    "divanetti": "divanetto",
    "divani": "divano",
    "divari": "divario",
    "divarica": "divaricare",
    "divaricai": "divaricare",
    "divaricammo": "divaricare",
    "divarican": "divaricare",
    "divaricando": "divaricare",
    "divaricano": "divaricare",
    "divaricante": "divaricare",
    "divaricanti": "divaricare",
    "divaricar": "divaricare",
    "divaricaron": "divaricare",
    "divaricarono": "divaricare",
    "divaricasse": "divaricare",
    "divaricasser": "divaricare",
    "divaricassero": "divaricare",
    "divaricassi": "divaricare",
    "divaricassimo": "divaricare",
    "divaricaste": "divaricare",
    "divaricasti": "divaricare",
    "divaricata": "divaricare",
    "divaricate": "divaricare",
    "divaricati": "divaricare",
    "divaricato": "divaricare",
    "divaricava": "divaricare",
    "divaricavamo": "divaricare",
    "divaricavan": "divaricare",
    "divaricavano": "divaricare",
    "divaricavate": "divaricare",
    "divaricavi": "divaricare",
    "divaricavo": "divaricare",
    "divaricazioni": "divaricazione",
    "divaricherai": "divaricare",
    "divaricheran": "divaricare",
    "divaricheranno": "divaricare",
    "divaricherebbe": "divaricare",
    "divaricherebber": "divaricare",
    "divaricherebbero": "divaricare",
    "divaricherei": "divaricare",
    "divaricheremmo": "divaricare",
    "divaricheremo": "divaricare",
    "divarichereste": "divaricare",
    "divaricheresti": "divaricare",
    "divaricherete": "divaricare",
    "divaricherà": "divaricare",
    "divaricherò": "divaricare",
    "divarichi": "divaricare",
    "divarichiamo": "divaricare",
    "divarichiate": "divaricare",
    "divarichin": "divaricare",
    "divarichino": "divaricare",
    "divarico": "divaricare",
    "divaricò": "divaricare",
    "dive": "divo",
    "diveda": "divedere",
    "divedan": "divedere",
    "divedano": "divedere",
    "divede": "divedere",
    "divedei": "divedere",
    "divedemmo": "divedere",
    "divedendo": "divedere",
    "divedente": "divedere",
    "divedenti": "divedere",
    "diveder": "divedere",
    "divederai": "divedere",
    "divederan": "divedere",
    "divederanno": "divedere",
    "divederebbe": "divedere",
    "divederebber": "divedere",
    "divederebbero": "divedere",
    "divederei": "divedere",
    "divederemmo": "divedere",
    "divederemo": "divedere",
    "divedereste": "divedere",
    "divederesti": "divedere",
    "divederete": "divedere",
    "divederon": "divedere",
    "divederono": "divedere",
    "divederà": "divedere",
    "divederò": "divedere",
    "divedesse": "divedere",
    "divedesser": "divedere",
    "divedessero": "divedere",
    "divedessi": "divedere",
    "divedessimo": "divedere",
    "divedeste": "divedere",
    "divedesti": "divedere",
    "divedete": "divedere",
    "divedeva": "divedere",
    "divedevamo": "divedere",
    "divedevan": "divedere",
    "divedevano": "divedere",
    "divedevate": "divedere",
    "divedevi": "divedere",
    "divedevo": "divedere",
    "divedi": "divedere",
    "divediamo": "divedere",
    "divediate": "divedere",
    "divedo": "divedere",
    "divedon": "divedere",
    "divedono": "divedere",
    "diveduta": "divedere",
    "divedute": "divedere",
    "diveduti": "divedere",
    "diveduto": "divedere",
    "divedè": "divedere",
    "divella": "divellere",
    "divellan": "divellere",
    "divellano": "divellere",
    "divelle": "divellere",
    "divellemmo": "divellere",
    "divellendo": "divellere",
    "divellente": "divellere",
    "divellenti": "divellere",
    "diveller": "divellere",
    "divellerai": "divellere",
    "divelleran": "divellere",
    "divelleranno": "divellere",
    "divellerebbe": "divellere",
    "divellerebber": "divellere",
    "divellerebbero": "divellere",
    "divellerei": "divellere",
    "divelleremmo": "divellere",
    "divelleremo": "divellere",
    "divellereste": "divellere",
    "divelleresti": "divellere",
    "divellerete": "divellere",
    "divellerà": "divellere",
    "divellerò": "divellere",
    "divellesse": "divellere",
    "divellesser": "divellere",
    "divellessero": "divellere",
    "divellessi": "divellere",
    "divellessimo": "divellere",
    "divelleste": "divellere",
    "divellesti": "divellere",
    "divellete": "divellere",
    "divelleva": "divellere",
    "divellevamo": "divellere",
    "divellevan": "divellere",
    "divellevano": "divellere",
    "divellevate": "divellere",
    "divellevi": "divellere",
    "divellevo": "divellere",
    "divelli": "divellere",
    "divelliamo": "divellere",
    "divelliate": "divellere",
    "divello": "divellere",
    "divellon": "divellere",
    "divellono": "divellere",
    "divelse": "divellere",
    "divelser": "divellere",
    "divelsero": "divellere",
    "divelsi": "divellere",
    "divelta": "divelto",
    "divelte": "divelto",
    "divelti": "divelto",
    "divelto": "divellere",
    "divenendo": "divenire",
    "divenente": "divenire",
    "divenenti": "divenire",
    "divenga": "divenire",
    "divengan": "divenire",
    "divengano": "divenire",
    "divengo": "divenire",
    "divengon": "divenire",
    "divengono": "divenire",
    "diveniamo": "divenire",
    "diveniate": "divenire",
    "divenimmo": "divenire",
    "divenir": "divenire",
    "divenisse": "divenire",
    "divenisser": "divenire",
    "divenissero": "divenire",
    "divenissi": "divenire",
    "divenissimo": "divenire",
    "diveniste": "divenire",
    "divenisti": "divenire",
    "divenite": "divenire",
    "diveniva": "divenire",
    "divenivamo": "divenire",
    "divenivan": "divenire",
    "divenivano": "divenire",
    "divenivate": "divenire",
    "divenivi": "divenire",
    "divenivo": "divenire",
    "divenne": "divenire",
    "divenner": "divenire",
    "divennero": "divenire",
    "divenni": "divenire",
    "diventa": "diventare",
    "diventai": "diventare",
    "diventammo": "diventare",
    "diventan": "diventare",
    "diventando": "diventare",
    "diventano": "diventare",
    "diventante": "diventare",
    "diventanti": "diventare",
    "diventar": "diventare",
    "diventaron": "diventare",
    "diventarono": "diventare",
    "diventasse": "diventare",
    "diventasser": "diventare",
    "diventassero": "diventare",
    "diventassi": "diventare",
    "diventassimo": "diventare",
    "diventaste": "diventare",
    "diventasti": "diventare",
    "diventata": "diventare",
    "diventate": "diventare",
    "diventati": "diventare",
    "diventato": "diventare",
    "diventava": "diventare",
    "diventavamo": "diventare",
    "diventavan": "diventare",
    "diventavano": "diventare",
    "diventavate": "diventare",
    "diventavi": "diventare",
    "diventavo": "diventare",
    "diventerai": "diventare",
    "diventeran": "diventare",
    "diventeranno": "diventare",
    "diventerebbe": "diventare",
    "diventerebber": "diventare",
    "diventerebbero": "diventare",
    "diventerei": "diventare",
    "diventeremmo": "diventare",
    "diventeremo": "diventare",
    "diventereste": "diventare",
    "diventeresti": "diventare",
    "diventerete": "diventare",
    "diventerà": "diventare",
    "diventerò": "diventare",
    "diventi": "diventare",
    "diventiamo": "diventare",
    "diventiate": "diventare",
    "diventin": "diventare",
    "diventino": "diventare",
    "divento": "diventare",
    "diventò": "diventare",
    "divenuta": "divenire",
    "divenute": "divenire",
    "divenuti": "divenire",
    "divenuto": "divenire",
    "diverbi": "diverbio",
    "diverga": "divergere",
    "divergan": "divergere",
    "divergano": "divergere",
    "diverge": "divergere",
    "divergemmo": "divergere",
    "divergendo": "divergere",
    "divergente": "divergere",
    "divergenti": "divergere",
    "divergenze": "divergenza",
    "diverger": "divergere",
    "divergerai": "divergere",
    "divergeran": "divergere",
    "divergeranno": "divergere",
    "divergerebbe": "divergere",
    "divergerebber": "divergere",
    "divergerebbero": "divergere",
    "divergerei": "divergere",
    "divergeremmo": "divergere",
    "divergeremo": "divergere",
    "divergereste": "divergere",
    "divergeresti": "divergere",
    "divergerete": "divergere",
    "divergerà": "divergere",
    "divergerò": "divergere",
    "divergesse": "divergere",
    "divergesser": "divergere",
    "divergessero": "divergere",
    "divergessi": "divergere",
    "divergessimo": "divergere",
    "divergeste": "divergere",
    "divergesti": "divergere",
    "divergete": "divergere",
    "divergeva": "divergere",
    "divergevamo": "divergere",
    "divergevan": "divergere",
    "divergevano": "divergere",
    "divergevate": "divergere",
    "divergevi": "divergere",
    "divergevo": "divergere",
    "divergi": "divergere",
    "divergiamo": "divergere",
    "divergiate": "divergere",
    "divergo": "divergere",
    "divergon": "divergere",
    "divergono": "divergere",
    "diverrai": "divenire",
    "diverran": "divenire",
    "diverranno": "divenire",
    "diverrebbe": "divenire",
    "diverrebber": "divenire",
    "diverrebbero": "divenire",
    "diverrei": "divenire",
    "diverremmo": "divenire",
    "diverremo": "divenire",
    "diverreste": "divenire",
    "diverresti": "divenire",
    "diverrete": "divenire",
    "diverrà": "divenire",
    "diverrò": "divenire",
    "diversa": "diverso",
    "diverse": "diverso",
    "diverser": "divergere",
    "diversero": "divergere",
    "diversi": "diverso",
    "diversifica": "diversificare",
    "diversificai": "diversificare",
    "diversificammo": "diversificare",
    "diversifican": "diversificare",
    "diversificando": "diversificare",
    "diversificano": "diversificare",
    "diversificante": "diversificare",
    "diversificanti": "diversificare",
    "diversificar": "diversificare",
    "diversificaron": "diversificare",
    "diversificarono": "diversificare",
    "diversificasse": "diversificare",
    "diversificasser": "diversificare",
    "diversificassero": "diversificare",
    "diversificassi": "diversificare",
    "diversificassimo": "diversificare",
    "diversificaste": "diversificare",
    "diversificasti": "diversificare",
    "diversificata": "diversificare",
    "diversificate": "diversificare",
    "diversificati": "diversificare",
    "diversificato": "diversificare",
    "diversificava": "diversificare",
    "diversificavamo": "diversificare",
    "diversificavan": "diversificare",
    "diversificavano": "diversificare",
    "diversificavate": "diversificare",
    "diversificavi": "diversificare",
    "diversificavo": "diversificare",
    "diversificazioni": "diversificazione",
    "diversificherai": "diversificare",
    "diversificheran": "diversificare",
    "diversificheranno": "diversificare",
    "diversificherebbe": "diversificare",
    "diversificherebber": "diversificare",
    "diversificherebbero": "diversificare",
    "diversificherei": "diversificare",
    "diversificheremmo": "diversificare",
    "diversificheremo": "diversificare",
    "diversifichereste": "diversificare",
    "diversificheresti": "diversificare",
    "diversificherete": "diversificare",
    "diversificherà": "diversificare",
    "diversificherò": "diversificare",
    "diversifichi": "diversificare",
    "diversifichiamo": "diversificare",
    "diversifichiate": "diversificare",
    "diversifichin": "diversificare",
    "diversifichino": "diversificare",
    "diversifico": "diversificare",
    "diversificò": "diversificare",
    "diversioni": "diversione",
    "diversiva": "diversivo",
    "diversive": "diversivo",
    "diversivi": "diversivo",
    "diversè": "divergere",
    "diverta": "divertire",
    "divertan": "divertire",
    "divertano": "divertire",
    "diverte": "divertire",
    "divertendo": "divertire",
    "divertente": "divertire",
    "divertenti": "divertire",
    "diverti": "divertire",
    "divertiamo": "divertire",
    "divertiate": "divertire",
    "divertii": "divertire",
    "divertimenti": "divertimento",
    "divertimentifici": "divertimentificio",
    "divertimmo": "divertire",
    "divertir": "divertire",
    "divertirai": "divertire",
    "divertiran": "divertire",
    "divertiranno": "divertire",
    "divertirebbe": "divertire",
    "divertirebber": "divertire",
    "divertirebbero": "divertire",
    "divertirei": "divertire",
    "divertiremmo": "divertire",
    "divertiremo": "divertire",
    "divertireste": "divertire",
    "divertiresti": "divertire",
    "divertirete": "divertire",
    "divertiron": "divertire",
    "divertirono": "divertire",
    "divertirà": "divertire",
    "divertirò": "divertire",
    "divertisse": "divertire",
    "divertisser": "divertire",
    "divertissero": "divertire",
    "divertissi": "divertire",
    "divertissimo": "divertire",
    "divertiste": "divertire",
    "divertisti": "divertire",
    "divertita": "divertito",
    "divertite": "divertito",
    "divertiti": "divertito",
    "divertito": "divertire",
    "divertiva": "divertire",
    "divertivamo": "divertire",
    "divertivan": "divertire",
    "divertivano": "divertire",
    "divertivate": "divertire",
    "divertivi": "divertire",
    "divertivo": "divertire",
    "diverto": "divertire",
    "diverton": "divertire",
    "divertono": "divertire",
    "divertì": "divertire",
    "divette": "divetta",
    "divezza": "divezzare",
    "divezzai": "divezzare",
    "divezzammo": "divezzare",
    "divezzan": "divezzare",
    "divezzando": "divezzare",
    "divezzano": "divezzare",
    "divezzante": "divezzare",
    "divezzanti": "divezzare",
    "divezzar": "divezzare",
    "divezzaron": "divezzare",
    "divezzarono": "divezzare",
    "divezzasse": "divezzare",
    "divezzasser": "divezzare",
    "divezzassero": "divezzare",
    "divezzassi": "divezzare",
    "divezzassimo": "divezzare",
    "divezzaste": "divezzare",
    "divezzasti": "divezzare",
    "divezzata": "divezzare",
    "divezzate": "divezzare",
    "divezzati": "divezzare",
    "divezzato": "divezzare",
    "divezzava": "divezzare",
    "divezzavamo": "divezzare",
    "divezzavan": "divezzare",
    "divezzavano": "divezzare",
    "divezzavate": "divezzare",
    "divezzavi": "divezzare",
    "divezzavo": "divezzare",
    "divezzerai": "divezzare",
    "divezzeran": "divezzare",
    "divezzeranno": "divezzare",
    "divezzerebbe": "divezzare",
    "divezzerebber": "divezzare",
    "divezzerebbero": "divezzare",
    "divezzerei": "divezzare",
    "divezzeremmo": "divezzare",
    "divezzeremo": "divezzare",
    "divezzereste": "divezzare",
    "divezzeresti": "divezzare",
    "divezzerete": "divezzare",
    "divezzerà": "divezzare",
    "divezzerò": "divezzare",
    "divezzi": "divezzare",
    "divezziamo": "divezzare",
    "divezziate": "divezzare",
    "divezzin": "divezzare",
    "divezzino": "divezzare",
    "divezzo": "divezzare",
    "divezzò": "divezzare",
    "divi": "divo",
    "divida": "dividere",
    "dividan": "dividere",
    "dividano": "dividere",
    "divide": "dividere",
    "dividemmo": "dividere",
    "dividendi": "dividendo",
    "dividendo": "dividere",
    "dividente": "dividere",
    "dividenti": "dividere",
    "divider": "dividere",
    "dividerai": "dividere",
    "divideran": "dividere",
    "divideranno": "dividere",
    "dividerebbe": "dividere",
    "dividerebber": "dividere",
    "dividerebbero": "dividere",
    "dividerei": "dividere",
    "divideremmo": "dividere",
    "divideremo": "dividere",
    "dividereste": "dividere",
    "divideresti": "dividere",
    "dividerete": "dividere",
    "dividerà": "dividere",
    "dividerò": "dividere",
    "dividesse": "dividere",
    "dividesser": "dividere",
    "dividessero": "dividere",
    "dividessi": "dividere",
    "dividessimo": "dividere",
    "divideste": "dividere",
    "dividesti": "dividere",
    "dividete": "dividere",
    "divideva": "dividere",
    "dividevamo": "dividere",
    "dividevan": "dividere",
    "dividevano": "dividere",
    "dividevate": "dividere",
    "dividevi": "dividere",
    "dividevo": "dividere",
    "dividi": "dividere",
    "dividiamo": "dividere",
    "dividiate": "dividere",
    "divido": "dividere",
    "dividon": "dividere",
    "dividono": "dividere",
    "diviene": "divenire",
    "divieni": "divenire",
    "divieti": "divieto",
    "divina": "divino",
    "divinai": "divinare",
    "divinammo": "divinare",
    "divinan": "divinare",
    "divinando": "divinare",
    "divinano": "divinare",
    "divinante": "divinare",
    "divinanti": "divinare",
    "divinar": "divinare",
    "divinaron": "divinare",
    "divinarono": "divinare",
    "divinasse": "divinare",
    "divinasser": "divinare",
    "divinassero": "divinare",
    "divinassi": "divinare",
    "divinassimo": "divinare",
    "divinaste": "divinare",
    "divinasti": "divinare",
    "divinata": "divinare",
    "divinate": "divinare",
    "divinati": "divinare",
    "divinato": "divinare",
    "divinatori": "divinatorio",
    "divinatoria": "divinatorio",
    "divinatorie": "divinatorio",
    "divinava": "divinare",
    "divinavamo": "divinare",
    "divinavan": "divinare",
    "divinavano": "divinare",
    "divinavate": "divinare",
    "divinavi": "divinare",
    "divinavo": "divinare",
    "divinazioni": "divinazione",
    "divincola": "divincolare",
    "divincolai": "divincolare",
    "divincolammo": "divincolare",
    "divincolan": "divincolare",
    "divincolando": "divincolare",
    "divincolano": "divincolare",
    "divincolante": "divincolare",
    "divincolanti": "divincolare",
    "divincolar": "divincolare",
    "divincolaron": "divincolare",
    "divincolarono": "divincolare",
    "divincolasse": "divincolare",
    "divincolasser": "divincolare",
    "divincolassero": "divincolare",
    "divincolassi": "divincolare",
    "divincolassimo": "divincolare",
    "divincolaste": "divincolare",
    "divincolasti": "divincolare",
    "divincolata": "divincolare",
    "divincolate": "divincolare",
    "divincolati": "divincolare",
    "divincolato": "divincolare",
    "divincolava": "divincolare",
    "divincolavamo": "divincolare",
    "divincolavan": "divincolare",
    "divincolavano": "divincolare",
    "divincolavate": "divincolare",
    "divincolavi": "divincolare",
    "divincolavo": "divincolare",
    "divincolerai": "divincolare",
    "divincoleran": "divincolare",
    "divincoleranno": "divincolare",
    "divincolerebbe": "divincolare",
    "divincolerebber": "divincolare",
    "divincolerebbero": "divincolare",
    "divincolerei": "divincolare",
    "divincoleremmo": "divincolare",
    "divincoleremo": "divincolare",
    "divincolereste": "divincolare",
    "divincoleresti": "divincolare",
    "divincolerete": "divincolare",
    "divincolerà": "divincolare",
    "divincolerò": "divincolare",
    "divincoli": "divincolare",
    "divincoliamo": "divincolare",
    "divincoliate": "divincolare",
    "divincolin": "divincolare",
    "divincolino": "divincolare",
    "divincolo": "divincolare",
    "divincolò": "divincolare",
    "divine": "divino",
    "divinerai": "divinare",
    "divineran": "divinare",
    "divineranno": "divinare",
    "divinerebbe": "divinare",
    "divinerebber": "divinare",
    "divinerebbero": "divinare",
    "divinerei": "divinare",
    "divineremmo": "divinare",
    "divineremo": "divinare",
    "divinereste": "divinare",
    "divineresti": "divinare",
    "divinerete": "divinare",
    "divinerà": "divinare",
    "divinerò": "divinare",
    "divini": "divino",
    "diviniamo": "divinare",
    "diviniate": "divinare",
    "divinin": "divinare",
    "divinino": "divinare",
    "divinizza": "divinizzare",
    "divinizzai": "divinizzare",
    "divinizzammo": "divinizzare",
    "divinizzan": "divinizzare",
    "divinizzando": "divinizzare",
    "divinizzano": "divinizzare",
    "divinizzante": "divinizzare",
    "divinizzanti": "divinizzare",
    "divinizzar": "divinizzare",
    "divinizzaron": "divinizzare",
    "divinizzarono": "divinizzare",
    "divinizzasse": "divinizzare",
    "divinizzasser": "divinizzare",
    "divinizzassero": "divinizzare",
    "divinizzassi": "divinizzare",
    "divinizzassimo": "divinizzare",
    "divinizzaste": "divinizzare",
    "divinizzasti": "divinizzare",
    "divinizzata": "divinizzare",
    "divinizzate": "divinizzare",
    "divinizzati": "divinizzare",
    "divinizzato": "divinizzare",
    "divinizzava": "divinizzare",
    "divinizzavamo": "divinizzare",
    "divinizzavan": "divinizzare",
    "divinizzavano": "divinizzare",
    "divinizzavate": "divinizzare",
    "divinizzavi": "divinizzare",
    "divinizzavo": "divinizzare",
    "divinizzerai": "divinizzare",
    "divinizzeran": "divinizzare",
    "divinizzeranno": "divinizzare",
    "divinizzerebbe": "divinizzare",
    "divinizzerebber": "divinizzare",
    "divinizzerebbero": "divinizzare",
    "divinizzerei": "divinizzare",
    "divinizzeremmo": "divinizzare",
    "divinizzeremo": "divinizzare",
    "divinizzereste": "divinizzare",
    "divinizzeresti": "divinizzare",
    "divinizzerete": "divinizzare",
    "divinizzerà": "divinizzare",
    "divinizzerò": "divinizzare",
    "divinizzi": "divinizzare",
    "divinizziamo": "divinizzare",
    "divinizziate": "divinizzare",
    "divinizzin": "divinizzare",
    "divinizzino": "divinizzare",
    "divinizzo": "divinizzare",
    "divinizzò": "divinizzare",
    "divino": "divinare",
    "divinò": "divinare",
    "divisa": "diviso",
    "divisai": "divisare",
    "divisammo": "divisare",
    "divisan": "divisare",
    "divisando": "divisare",
    "divisano": "divisare",
    "divisante": "divisare",
    "divisanti": "divisare",
    "divisar": "divisare",
    "divisaron": "divisare",
    "divisarono": "divisare",
    "divisasse": "divisare",
    "divisasser": "divisare",
    "divisassero": "divisare",
    "divisassi": "divisare",
    "divisassimo": "divisare",
    "divisaste": "divisare",
    "divisasti": "divisare",
    "divisata": "divisare",
    "divisate": "divisare",
    "divisati": "divisare",
    "divisato": "divisare",
    "divisava": "divisare",
    "divisavamo": "divisare",
    "divisavan": "divisare",
    "divisavano": "divisare",
    "divisavate": "divisare",
    "divisavi": "divisare",
    "divisavo": "divisare",
    "divise": "diviso",
    "diviser": "dividere",
    "diviserai": "divisare",
    "diviseran": "divisare",
    "diviseranno": "divisare",
    "diviserebbe": "divisare",
    "diviserebber": "divisare",
    "diviserebbero": "divisare",
    "diviserei": "divisare",
    "diviseremmo": "divisare",
    "diviseremo": "divisare",
    "divisereste": "divisare",
    "diviseresti": "divisare",
    "diviserete": "divisare",
    "divisero": "dividere",
    "diviserà": "divisare",
    "diviserò": "divisare",
    "divisi": "diviso",
    "divisiamo": "divisare",
    "divisiate": "divisare",
    "divisibili": "divisibile",
    "divisin": "divisare",
    "divisino": "divisare",
    "divisionali": "divisionale",
    "divisioni": "divisione",
    "divisionismi": "divisionismo",
    "divisionisti": "divisioniste",
    "divismi": "divismo",
    "diviso": "divisare",
    "divisori": "divisorio",
    "divisoria": "divisorio",
    "divisorie": "divisorio",
    "divistica": "divistico",
    "divistiche": "divistico",
    "divistici": "divistico",
    "divisò": "divisare",
    "divora": "divorare",
    "divorai": "divorare",
    "divorammo": "divorare",
    "divoran": "divorare",
    "divorando": "divorare",
    "divorano": "divorare",
    "divorante": "divorare",
    "divoranti": "divorare",
    "divorar": "divorare",
    "divoraron": "divorare",
    "divorarono": "divorare",
    "divorasse": "divorare",
    "divorasser": "divorare",
    "divorassero": "divorare",
    "divorassi": "divorare",
    "divorassimo": "divorare",
    "divoraste": "divorare",
    "divorasti": "divorare",
    "divorata": "divorare",
    "divorate": "divorare",
    "divorati": "divorare",
    "divorato": "divorare",
    "divoratori": "divoratore",
    "divorava": "divorare",
    "divoravamo": "divorare",
    "divoravan": "divorare",
    "divoravano": "divorare",
    "divoravate": "divorare",
    "divoravi": "divorare",
    "divoravo": "divorare",
    "divorerai": "divorare",
    "divoreran": "divorare",
    "divoreranno": "divorare",
    "divorerebbe": "divorare",
    "divorerebber": "divorare",
    "divorerebbero": "divorare",
    "divorerei": "divorare",
    "divoreremmo": "divorare",
    "divoreremo": "divorare",
    "divorereste": "divorare",
    "divoreresti": "divorare",
    "divorerete": "divorare",
    "divorerà": "divorare",
    "divorerò": "divorare",
    "divori": "divorare",
    "divoriamo": "divorare",
    "divoriate": "divorare",
    "divorin": "divorare",
    "divorino": "divorare",
    "divoro": "divorare",
    "divorzi": "divorzio",
    "divorzia": "divorziare",
    "divorziai": "divorziare",
    "divorziammo": "divorziare",
    "divorziamo": "divorziare",
    "divorzian": "divorziare",
    "divorziando": "divorziare",
    "divorziano": "divorziare",
    "divorziante": "divorziare",
    "divorzianti": "divorziare",
    "divorziar": "divorziare",
    "divorziaron": "divorziare",
    "divorziarono": "divorziare",
    "divorziasse": "divorziare",
    "divorziasser": "divorziare",
    "divorziassero": "divorziare",
    "divorziassi": "divorziare",
    "divorziassimo": "divorziare",
    "divorziaste": "divorziare",
    "divorziasti": "divorziare",
    "divorziata": "divorziato",
    "divorziate": "divorziato",
    "divorziati": "divorziato",
    "divorziato": "divorziare",
    "divorziava": "divorziare",
    "divorziavamo": "divorziare",
    "divorziavan": "divorziare",
    "divorziavano": "divorziare",
    "divorziavate": "divorziare",
    "divorziavi": "divorziare",
    "divorziavo": "divorziare",
    "divorzierai": "divorziare",
    "divorzieran": "divorziare",
    "divorzieranno": "divorziare",
    "divorzierebbe": "divorziare",
    "divorzierebber": "divorziare",
    "divorzierebbero": "divorziare",
    "divorzierei": "divorziare",
    "divorzieremmo": "divorziare",
    "divorzieremo": "divorziare",
    "divorziereste": "divorziare",
    "divorzieresti": "divorziare",
    "divorzierete": "divorziare",
    "divorzierà": "divorziare",
    "divorzierò": "divorziare",
    "divorzin": "divorziare",
    "divorzino": "divorziare",
    "divorzio": "divorziare",
    "divorziste": "divorzista",
    "divorzisti": "divorzista",
    "divorziò": "divorziare",
    "divorò": "divorare",
    "divulga": "divulgare",
    "divulgai": "divulgare",
    "divulgammo": "divulgare",
    "divulgan": "divulgare",
    "divulgando": "divulgare",
    "divulgano": "divulgare",
    "divulgante": "divulgare",
    "divulganti": "divulgare",
    "divulgar": "divulgare",
    "divulgaron": "divulgare",
    "divulgarono": "divulgare",
    "divulgasse": "divulgare",
    "divulgasser": "divulgare",
    "divulgassero": "divulgare",
    "divulgassi": "divulgare",
    "divulgassimo": "divulgare",
    "divulgaste": "divulgare",
    "divulgasti": "divulgare",
    "divulgata": "divulgare",
    "divulgate": "divulgare",
    "divulgati": "divulgare",
    "divulgativa": "divulgativo",
    "divulgative": "divulgativo",
    "divulgativi": "divulgativo",
    "divulgato": "divulgare",
    "divulgatori": "divulgatore",
    "divulgava": "divulgare",
    "divulgavamo": "divulgare",
    "divulgavan": "divulgare",
    "divulgavano": "divulgare",
    "divulgavate": "divulgare",
    "divulgavi": "divulgare",
    "divulgavo": "divulgare",
    "divulgazioni": "divulgazione",
    "divulgherai": "divulgare",
    "divulgheran": "divulgare",
    "divulgheranno": "divulgare",
    "divulgherebbe": "divulgare",
    "divulgherebber": "divulgare",
    "divulgherebbero": "divulgare",
    "divulgherei": "divulgare",
    "divulgheremmo": "divulgare",
    "divulgheremo": "divulgare",
    "divulghereste": "divulgare",
    "divulgheresti": "divulgare",
    "divulgherete": "divulgare",
    "divulgherà": "divulgare",
    "divulgherò": "divulgare",
    "divulghi": "divulgare",
    "divulghiamo": "divulgare",
    "divulghiate": "divulgare",
    "divulghin": "divulgare",
    "divulghino": "divulgare",
    "divulgo": "divulgare",
    "divulgò": "divulgare",
    "dizionari": "dizionario",
    "dizioni": "dizione",
    "do": "dare",
    "dobbiamo": "dovere",
    "dobbiate": "dovere",
    "docce": "doccia",
    "doccerai": "docciare",
    "docceran": "docciare",
    "docceranno": "docciare",
    "doccerebbe": "docciare",
    "doccerebber": "docciare",
    "doccerebbero": "docciare",
    "doccerei": "docciare",
    "docceremmo": "docciare",
    "docceremo": "docciare",
    "doccereste": "docciare",
    "docceresti": "docciare",
    "doccerete": "docciare",
    "doccerà": "docciare",
    "doccerò": "docciare",
    "docci": "docciare",
    "doccia": "docciare",
    "docciai": "docciare",
    "docciammo": "docciare",
    "docciamo": "docciare",
    "doccian": "docciare",
    "docciando": "docciare",
    "docciano": "docciare",
    "docciante": "docciare",
    "doccianti": "docciare",
    "docciar": "docciare",
    "docciaron": "docciare",
    "docciarono": "docciare",
    "docciasse": "docciare",
    "docciasser": "docciare",
    "docciassero": "docciare",
    "docciassi": "docciare",
    "docciassimo": "docciare",
    "docciaste": "docciare",
    "docciasti": "docciare",
    "docciata": "docciare",
    "docciate": "docciare",
    "docciati": "docciare",
    "docciato": "docciare",
    "docciava": "docciare",
    "docciavamo": "docciare",
    "docciavan": "docciare",
    "docciavano": "docciare",
    "docciavate": "docciare",
    "docciavi": "docciare",
    "docciavo": "docciare",
    "doccin": "docciare",
    "doccino": "docciare",
    "doccio": "docciare",
    "docciò": "docciare",
    "docenti": "docente",
    "docenze": "docenza",
    "docili": "docile",
    "documenta": "documentare",
    "documentabili": "documentabile",
    "documentai": "documentare",
    "documentali": "documentale",
    "documentammo": "documentare",
    "documentan": "documentare",
    "documentando": "documentare",
    "documentano": "documentare",
    "documentante": "documentare",
    "documentanti": "documentare",
    "documentar": "documentare",
    "documentari": "documentario",
    "documentaria": "documentario",
    "documentarie": "documentario",
    "documentaristi": "documentarista",
    "documentaristica": "documentaristico",
    "documentaristiche": "documentaristico",
    "documentaristici": "documentaristico",
    "documentaron": "documentare",
    "documentarono": "documentare",
    "documentasse": "documentare",
    "documentasser": "documentare",
    "documentassero": "documentare",
    "documentassi": "documentare",
    "documentassimo": "documentare",
    "documentaste": "documentare",
    "documentasti": "documentare",
    "documentata": "documentato",
    "documentate": "documentato",
    "documentati": "documentato",
    "documentato": "documentare",
    "documentava": "documentare",
    "documentavamo": "documentare",
    "documentavan": "documentare",
    "documentavano": "documentare",
    "documentavate": "documentare",
    "documentavi": "documentare",
    "documentavo": "documentare",
    "documentazioni": "documentazione",
    "documenterai": "documentare",
    "documenteran": "documentare",
    "documenteranno": "documentare",
    "documenterebbe": "documentare",
    "documenterebber": "documentare",
    "documenterebbero": "documentare",
    "documenterei": "documentare",
    "documenteremmo": "documentare",
    "documenteremo": "documentare",
    "documentereste": "documentare",
    "documenteresti": "documentare",
    "documenterete": "documentare",
    "documenterà": "documentare",
    "documenterò": "documentare",
    "documenti": "documento",
    "documentiamo": "documentare",
    "documentiate": "documentare",
    "documentin": "documentare",
    "documentino": "documentare",
    "documento": "documentare",
    "documentò": "documentare",
    "dodecafonica": "dodecafonico",
    "dodecafoniche": "dodecafonico",
    "dodecafonici": "dodecafonico",
    "dodicenni": "dodicenne",
    "dodicesima": "dodicesimo",
    "dodicesime": "dodicesimo",
    "dodicesimi": "dodicesimo",
    "dodicimillesima": "dodicimillesimo",
    "dodicimillesime": "dodicimillesimo",
    "dodicimillesimi": "dodicimillesimo",
    "dogali": "dogale",
    "doganali": "doganale",
    "dogane": "dogana",
    "doganieri": "doganiere",
    "dogi": "doge",
    "doglianze": "doglianza",
    "doglie": "doglia",
    "dogmatica": "dogmatico",
    "dogmatiche": "dogmatico",
    "dogmatici": "dogmatico",
    "dogmatismi": "dogmatismo",
    "dogmatizza": "dogmatizzare",
    "dogmatizzai": "dogmatizzare",
    "dogmatizzammo": "dogmatizzare",
    "dogmatizzan": "dogmatizzare",
    "dogmatizzando": "dogmatizzare",
    "dogmatizzano": "dogmatizzare",
    "dogmatizzante": "dogmatizzare",
    "dogmatizzanti": "dogmatizzare",
    "dogmatizzar": "dogmatizzare",
    "dogmatizzaron": "dogmatizzare",
    "dogmatizzarono": "dogmatizzare",
    "dogmatizzasse": "dogmatizzare",
    "dogmatizzasser": "dogmatizzare",
    "dogmatizzassero": "dogmatizzare",
    "dogmatizzassi": "dogmatizzare",
    "dogmatizzassimo": "dogmatizzare",
    "dogmatizzaste": "dogmatizzare",
    "dogmatizzasti": "dogmatizzare",
    "dogmatizzata": "dogmatizzare",
    "dogmatizzate": "dogmatizzare",
    "dogmatizzati": "dogmatizzare",
    "dogmatizzato": "dogmatizzare",
    "dogmatizzava": "dogmatizzare",
    "dogmatizzavamo": "dogmatizzare",
    "dogmatizzavan": "dogmatizzare",
    "dogmatizzavano": "dogmatizzare",
    "dogmatizzavate": "dogmatizzare",
    "dogmatizzavi": "dogmatizzare",
    "dogmatizzavo": "dogmatizzare",
    "dogmatizzerai": "dogmatizzare",
    "dogmatizzeran": "dogmatizzare",
    "dogmatizzeranno": "dogmatizzare",
    "dogmatizzerebbe": "dogmatizzare",
    "dogmatizzerebber": "dogmatizzare",
    "dogmatizzerebbero": "dogmatizzare",
    "dogmatizzerei": "dogmatizzare",
    "dogmatizzeremmo": "dogmatizzare",
    "dogmatizzeremo": "dogmatizzare",
    "dogmatizzereste": "dogmatizzare",
    "dogmatizzeresti": "dogmatizzare",
    "dogmatizzerete": "dogmatizzare",
    "dogmatizzerà": "dogmatizzare",
    "dogmatizzerò": "dogmatizzare",
    "dogmatizzi": "dogmatizzare",
    "dogmatizziamo": "dogmatizzare",
    "dogmatizziate": "dogmatizzare",
    "dogmatizzin": "dogmatizzare",
    "dogmatizzino": "dogmatizzare",
    "dogmatizzo": "dogmatizzare",
    "dogmatizzò": "dogmatizzare",
    "dogmi": "dogma",
    "dola": "dolere",
    "dolan": "dolere",
    "dolano": "dolere",
    "dolce-amara": "dolce-amaro",
    "dolce-amare": "dolce-amaro",
    "dolce-amari": "dolce-amaro",
    "dolcetti": "dolcetto",
    "dolcezze": "dolcezza",
    "dolci": "dolce",
    "dolciari": "dolciario",
    "dolciaria": "dolciario",
    "dolciarie": "dolciario",
    "dolciastra": "dolciastro",
    "dolciastre": "dolciastro",
    "dolciastri": "dolciastro",
    "dolcifica": "dolcificare",
    "dolcificai": "dolcificare",
    "dolcificammo": "dolcificare",
    "dolcifican": "dolcificare",
    "dolcificando": "dolcificare",
    "dolcificano": "dolcificare",
    "dolcificante": "dolcificare",
    "dolcificanti": "dolcificare",
    "dolcificar": "dolcificare",
    "dolcificaron": "dolcificare",
    "dolcificarono": "dolcificare",
    "dolcificasse": "dolcificare",
    "dolcificasser": "dolcificare",
    "dolcificassero": "dolcificare",
    "dolcificassi": "dolcificare",
    "dolcificassimo": "dolcificare",
    "dolcificaste": "dolcificare",
    "dolcificasti": "dolcificare",
    "dolcificata": "dolcificare",
    "dolcificate": "dolcificare",
    "dolcificati": "dolcificare",
    "dolcificato": "dolcificare",
    "dolcificava": "dolcificare",
    "dolcificavamo": "dolcificare",
    "dolcificavan": "dolcificare",
    "dolcificavano": "dolcificare",
    "dolcificavate": "dolcificare",
    "dolcificavi": "dolcificare",
    "dolcificavo": "dolcificare",
    "dolcificherai": "dolcificare",
    "dolcificheran": "dolcificare",
    "dolcificheranno": "dolcificare",
    "dolcificherebbe": "dolcificare",
    "dolcificherebber": "dolcificare",
    "dolcificherebbero": "dolcificare",
    "dolcificherei": "dolcificare",
    "dolcificheremmo": "dolcificare",
    "dolcificheremo": "dolcificare",
    "dolcifichereste": "dolcificare",
    "dolcificheresti": "dolcificare",
    "dolcificherete": "dolcificare",
    "dolcificherà": "dolcificare",
    "dolcificherò": "dolcificare",
    "dolcifichi": "dolcificare",
    "dolcifichiamo": "dolcificare",
    "dolcifichiate": "dolcificare",
    "dolcifichin": "dolcificare",
    "dolcifichino": "dolcificare",
    "dolcifico": "dolcificare",
    "dolcificò": "dolcificare",
    "dolcissime": "dolcissima",
    "dole": "dolere",
    "dolei": "dolere",
    "dolemmo": "dolere",
    "dolendo": "dolere",
    "dolente": "dolere",
    "dolenti": "dolere",
    "doler": "dolere",
    "dolerai": "dolere",
    "doleran": "dolere",
    "doleranno": "dolere",
    "dolerebbe": "dolere",
    "dolerebber": "dolere",
    "dolerebbero": "dolere",
    "dolerei": "dolere",
    "doleremmo": "dolere",
    "doleremo": "dolere",
    "dolereste": "dolere",
    "doleresti": "dolere",
    "dolerete": "dolere",
    "doleron": "dolere",
    "dolerono": "dolere",
    "dolerà": "dolere",
    "dolerò": "dolere",
    "dolesse": "dolere",
    "dolesser": "dolere",
    "dolessero": "dolere",
    "dolessi": "dolere",
    "dolessimo": "dolere",
    "doleste": "dolere",
    "dolesti": "dolere",
    "dolete": "dolere",
    "doleva": "dolere",
    "dolevamo": "dolere",
    "dolevan": "dolere",
    "dolevano": "dolere",
    "dolevate": "dolere",
    "dolevi": "dolere",
    "dolevo": "dolere",
    "doli": "dolo",
    "doliamo": "dolere",
    "doliate": "dolere",
    "dollari": "dollaro",
    "dolo": "dolere",
    "dolomitica": "dolomitico",
    "dolomitiche": "dolomitico",
    "dolomitici": "dolomitico",
    "dolon": "dolere",
    "dolono": "dolere",
    "dolora": "dolorare",
    "dolorai": "dolorare",
    "dolorammo": "dolorare",
    "doloran": "dolorare",
    "dolorando": "dolorare",
    "dolorano": "dolorare",
    "dolorante": "dolorare",
    "doloranti": "dolorare",
    "dolorar": "dolorare",
    "doloraron": "dolorare",
    "dolorarono": "dolorare",
    "dolorasse": "dolorare",
    "dolorasser": "dolorare",
    "dolorassero": "dolorare",
    "dolorassi": "dolorare",
    "dolorassimo": "dolorare",
    "doloraste": "dolorare",
    "dolorasti": "dolorare",
    "dolorata": "dolorare",
    "dolorate": "dolorare",
    "dolorati": "dolorare",
    "dolorato": "dolorare",
    "dolorava": "dolorare",
    "doloravamo": "dolorare",
    "doloravan": "dolorare",
    "doloravano": "dolorare",
    "doloravate": "dolorare",
    "doloravi": "dolorare",
    "doloravo": "dolorare",
    "dolorerai": "dolorare",
    "doloreran": "dolorare",
    "doloreranno": "dolorare",
    "dolorerebbe": "dolorare",
    "dolorerebber": "dolorare",
    "dolorerebbero": "dolorare",
    "dolorerei": "dolorare",
    "doloreremmo": "dolorare",
    "doloreremo": "dolorare",
    "dolorereste": "dolorare",
    "doloreresti": "dolorare",
    "dolorerete": "dolorare",
    "dolorerà": "dolorare",
    "dolorerò": "dolorare",
    "doloretti": "doloretto",
    "dolori": "dolore",
    "doloriamo": "dolorare",
    "doloriate": "dolorare",
    "dolorin": "dolorare",
    "dolorini": "dolorino",
    "dolorino": "dolorare",
    "doloro": "dolorare",
    "dolorosa": "doloroso",
    "dolorose": "doloroso",
    "dolorosi": "doloroso",
    "dolorò": "dolorare",
    "dolosa": "doloso",
    "dolose": "doloso",
    "dolosi": "doloso",
    "doluta": "dolere",
    "dolute": "dolere",
    "doluti": "dolere",
    "doluto": "dolere",
    "dolè": "dolere",
    "doma": "domo",
    "domai": "domare",
    "domammo": "domare",
    "doman": "domare",
    "domanda": "domandare",
    "domandai": "domandare",
    "domandammo": "domandare",
    "domandan": "domandare",
    "domandando": "domandare",
    "domandano": "domandare",
    "domandante": "domandare",
    "domandanti": "domandare",
    "domandar": "domandare",
    "domandaron": "domandare",
    "domandarono": "domandare",
    "domandasse": "domandare",
    "domandasser": "domandare",
    "domandassero": "domandare",
    "domandassi": "domandare",
    "domandassimo": "domandare",
    "domandaste": "domandare",
    "domandasti": "domandare",
    "domandata": "domandare",
    "domandate": "domandare",
    "domandati": "domandare",
    "domandato": "domandare",
    "domandava": "domandare",
    "domandavamo": "domandare",
    "domandavan": "domandare",
    "domandavano": "domandare",
    "domandavate": "domandare",
    "domandavi": "domandare",
    "domandavo": "domandare",
    "domande": "domanda",
    "domanderai": "domandare",
    "domanderan": "domandare",
    "domanderanno": "domandare",
    "domanderebbe": "domandare",
    "domanderebber": "domandare",
    "domanderebbero": "domandare",
    "domanderei": "domandare",
    "domanderemmo": "domandare",
    "domanderemo": "domandare",
    "domandereste": "domandare",
    "domanderesti": "domandare",
    "domanderete": "domandare",
    "domanderà": "domandare",
    "domanderò": "domandare",
    "domandi": "domandare",
    "domandiamo": "domandare",
    "domandiate": "domandare",
    "domandin": "domandare",
    "domandine": "domandina",
    "domandino": "domandare",
    "domando": "domare",
    "domandò": "domandare",
    "domano": "domare",
    "domante": "domare",
    "domanti": "domare",
    "domar": "domare",
    "domaron": "domare",
    "domarono": "domare",
    "domasse": "domare",
    "domasser": "domare",
    "domassero": "domare",
    "domassi": "domare",
    "domassimo": "domare",
    "domaste": "domare",
    "domasti": "domare",
    "domata": "domare",
    "domate": "domare",
    "domati": "domare",
    "domato": "domare",
    "domatori": "domatore",
    "domava": "domare",
    "domavamo": "domare",
    "domavan": "domare",
    "domavano": "domare",
    "domavate": "domare",
    "domavi": "domare",
    "domavo": "domare",
    "dome": "domo",
    "domenicali": "domenicale",
    "domenicana": "domenicano",
    "domenicane": "domenicano",
    "domenicani": "domenicano",
    "domeniche": "domenica",
    "domerai": "domare",
    "domeran": "domare",
    "domeranno": "domare",
    "domerebbe": "domare",
    "domerebber": "domare",
    "domerebbero": "domare",
    "domerei": "domare",
    "domeremmo": "domare",
    "domeremo": "domare",
    "domereste": "domare",
    "domeresti": "domare",
    "domerete": "domare",
    "domerà": "domare",
    "domerò": "domare",
    "domestica": "domestico",
    "domestiche": "domestico",
    "domestici": "domestico",
    "domi": "domo",
    "domiamo": "domare",
    "domiate": "domare",
    "domicili": "domicilio",
    "domicilia": "domiciliare",
    "domiciliai": "domiciliare",
    "domiciliammo": "domiciliare",
    "domiciliamo": "domiciliare",
    "domicilian": "domiciliare",
    "domiciliando": "domiciliare",
    "domiciliano": "domiciliare",
    "domiciliante": "domiciliare",
    "domicilianti": "domiciliare",
    "domiciliar": "domiciliare",
    "domiciliari": "domiciliare",
    "domiciliaron": "domiciliare",
    "domiciliarono": "domiciliare",
    "domiciliasse": "domiciliare",
    "domiciliasser": "domiciliare",
    "domiciliassero": "domiciliare",
    "domiciliassi": "domiciliare",
    "domiciliassimo": "domiciliare",
    "domiciliaste": "domiciliare",
    "domiciliasti": "domiciliare",
    "domiciliata": "domiciliato",
    "domiciliate": "domiciliato",
    "domiciliati": "domiciliato",
    "domiciliato": "domiciliare",
    "domiciliava": "domiciliare",
    "domiciliavamo": "domiciliare",
    "domiciliavan": "domiciliare",
    "domiciliavano": "domiciliare",
    "domiciliavate": "domiciliare",
    "domiciliavi": "domiciliare",
    "domiciliavo": "domiciliare",
    "domicilierai": "domiciliare",
    "domicilieran": "domiciliare",
    "domicilieranno": "domiciliare",
    "domicilierebbe": "domiciliare",
    "domicilierebber": "domiciliare",
    "domicilierebbero": "domiciliare",
    "domicilierei": "domiciliare",
    "domicilieremmo": "domiciliare",
    "domicilieremo": "domiciliare",
    "domiciliereste": "domiciliare",
    "domicilieresti": "domiciliare",
    "domicilierete": "domiciliare",
    "domicilierà": "domiciliare",
    "domicilierò": "domiciliare",
    "domicilin": "domiciliare",
    "domicilino": "domiciliare",
    "domicilio": "domiciliare",
    "domiciliò": "domiciliare",
    "domin": "domare",
    "domina": "dominare",
    "dominabili": "dominabile",
    "dominai": "dominare",
    "dominammo": "dominare",
    "dominan": "dominare",
    "dominando": "dominare",
    "dominano": "dominare",
    "dominante": "dominare",
    "dominanti": "dominare",
    "dominar": "dominare",
    "dominaron": "dominare",
    "dominarono": "dominare",
    "dominasse": "dominare",
    "dominasser": "dominare",
    "dominassero": "dominare",
    "dominassi": "dominare",
    "dominassimo": "dominare",
    "dominaste": "dominare",
    "dominasti": "dominare",
    "dominata": "dominare",
    "dominate": "dominare",
    "dominati": "dominare",
    "dominato": "dominare",
    "dominatori": "dominatore",
    "dominatrice": "dominatore",
    "dominatrici": "dominatore",
    "dominava": "dominare",
    "dominavamo": "dominare",
    "dominavan": "dominare",
    "dominavano": "dominare",
    "dominavate": "dominare",
    "dominavi": "dominare",
    "dominavo": "dominare",
    "dominazioni": "dominazione",
    "dominerai": "dominare",
    "domineran": "dominare",
    "domineranno": "dominare",
    "dominerebbe": "dominare",
    "dominerebber": "dominare",
    "dominerebbero": "dominare",
    "dominerei": "dominare",
    "domineremmo": "dominare",
    "domineremo": "dominare",
    "dominereste": "dominare",
    "domineresti": "dominare",
    "dominerete": "dominare",
    "dominerà": "dominare",
    "dominerò": "dominare",
    "domini": "domino",
    "dominiamo": "dominare",
    "dominiate": "dominare",
    "dominicana": "dominicano",
    "dominicane": "dominicano",
    "dominicani": "dominicano",
    "dominii": "dominio",
    "dominin": "dominare",
    "dominino": "dominare",
    "domino": "dominare",
    "dominò": "dominare",
    "domo": "domare",
    "domò": "domare",
    "dona": "donare",
    "donai": "donare",
    "donammo": "donare",
    "donan": "donare",
    "donando": "donare",
    "donano": "donare",
    "donante": "donare",
    "donanti": "donare",
    "donar": "donare",
    "donaron": "donare",
    "donarono": "donare",
    "donasse": "donare",
    "donasser": "donare",
    "donassero": "donare",
    "donassi": "donare",
    "donassimo": "donare",
    "donaste": "donare",
    "donasti": "donare",
    "donata": "donare",
    "donate": "donare",
    "donati": "donare",
    "donativa": "donativo",
    "donative": "donativo",
    "donativi": "donativo",
    "donato": "donare",
    "donatori": "donatore",
    "donatrici": "donatrice",
    "donava": "donare",
    "donavamo": "donare",
    "donavan": "donare",
    "donavano": "donare",
    "donavate": "donare",
    "donavi": "donare",
    "donavo": "donare",
    "donazioni": "donazione",
    "donchisciottesca": "donchisciottesco",
    "donchisciottesche": "donchisciottesco",
    "donchisciotteschi": "donchisciottesco",
    "dondola": "dondolare",
    "dondolai": "dondolare",
    "dondolammo": "dondolare",
    "dondolan": "dondolare",
    "dondolando": "dondolare",
    "dondolano": "dondolare",
    "dondolante": "dondolare",
    "dondolanti": "dondolare",
    "dondolar": "dondolare",
    "dondolaron": "dondolare",
    "dondolarono": "dondolare",
    "dondolasse": "dondolare",
    "dondolasser": "dondolare",
    "dondolassero": "dondolare",
    "dondolassi": "dondolare",
    "dondolassimo": "dondolare",
    "dondolaste": "dondolare",
    "dondolasti": "dondolare",
    "dondolata": "dondolare",
    "dondolate": "dondolare",
    "dondolati": "dondolare",
    "dondolato": "dondolare",
    "dondolava": "dondolare",
    "dondolavamo": "dondolare",
    "dondolavan": "dondolare",
    "dondolavano": "dondolare",
    "dondolavate": "dondolare",
    "dondolavi": "dondolare",
    "dondolavo": "dondolare",
    "dondolerai": "dondolare",
    "dondoleran": "dondolare",
    "dondoleranno": "dondolare",
    "dondolerebbe": "dondolare",
    "dondolerebber": "dondolare",
    "dondolerebbero": "dondolare",
    "dondolerei": "dondolare",
    "dondoleremmo": "dondolare",
    "dondoleremo": "dondolare",
    "dondolereste": "dondolare",
    "dondoleresti": "dondolare",
    "dondolerete": "dondolare",
    "dondolerà": "dondolare",
    "dondolerò": "dondolare",
    "dondoli": "dondolare",
    "dondoliamo": "dondolare",
    "dondoliate": "dondolare",
    "dondolin": "dondolare",
    "dondolino": "dondolare",
    "dondolo": "dondolare",
    "dondolò": "dondolare",
    "donerai": "donare",
    "doneran": "donare",
    "doneranno": "donare",
    "donerebbe": "donare",
    "donerebber": "donare",
    "donerebbero": "donare",
    "donerei": "donare",
    "doneremmo": "donare",
    "doneremo": "donare",
    "donereste": "donare",
    "doneresti": "donare",
    "donerete": "donare",
    "donerà": "donare",
    "donerò": "donare",
    "dongiovannesca": "dongiovannesco",
    "dongiovannesche": "dongiovannesco",
    "dongiovanneschi": "dongiovannesco",
    "doni": "dono",
    "doniamo": "donare",
    "doniate": "donare",
    "donin": "donare",
    "donino": "donare",
    "donnacce": "donnaccia",
    "donnaioli": "donnaiolo",
    "donne": "donna",
    "donnesca": "donnesco",
    "donnesche": "donnesco",
    "donneschi": "donnesco",
    "donnette": "donnetta",
    "donnine": "donnina",
    "donnone": "donnona",
    "donnoni": "donnone",
    "dono": "donare",
    "donzelle": "donzella",
    "donò": "donare",
    "dopa": "dopo",
    "dopamine": "dopamina",
    "dopati": "dopato",
    "dope": "dopo",
    "dopi": "dopo",
    "dopolavori": "dopolavoro",
    "dopolavoristica": "dopolavoristico",
    "dopolavoristiche": "dopolavoristico",
    "dopolavoristici": "dopolavoristico",
    "dopolistini": "dopolistino",
    "doppi": "doppio",
    "doppia": "doppio",
    "doppiaggi": "doppiaggio",
    "doppiai": "doppiare",
    "doppiammo": "doppiare",
    "doppiamo": "doppiare",
    "doppian": "doppiare",
    "doppiando": "doppiare",
    "doppiano": "doppiare",
    "doppiante": "doppiare",
    "doppianti": "doppiare",
    "doppiar": "doppiare",
    "doppiaron": "doppiare",
    "doppiarono": "doppiare",
    "doppiasse": "doppiare",
    "doppiasser": "doppiare",
    "doppiassero": "doppiare",
    "doppiassi": "doppiare",
    "doppiassimo": "doppiare",
    "doppiaste": "doppiare",
    "doppiasti": "doppiare",
    "doppiata": "doppiato",
    "doppiate": "doppiato",
    "doppiati": "doppiato",
    "doppiato": "doppiare",
    "doppiatori": "doppiatore",
    "doppiava": "doppiare",
    "doppiavamo": "doppiare",
    "doppiavan": "doppiare",
    "doppiavano": "doppiare",
    "doppiavate": "doppiare",
    "doppiavi": "doppiare",
    "doppiavo": "doppiare",
    "doppie": "doppio",
    "doppierai": "doppiare",
    "doppieran": "doppiare",
    "doppieranno": "doppiare",
    "doppierebbe": "doppiare",
    "doppierebber": "doppiare",
    "doppierebbero": "doppiare",
    "doppierei": "doppiare",
    "doppieremmo": "doppiare",
    "doppieremo": "doppiare",
    "doppiereste": "doppiare",
    "doppieresti": "doppiare",
    "doppierete": "doppiare",
    "doppierà": "doppiare",
    "doppierò": "doppiare",
    "doppiette": "doppietta",
    "doppiezze": "doppiezza",
    "doppifondo": "doppiofondo",
    "doppin": "doppiare",
    "doppino": "doppiare",
    "doppio": "doppiare",
    "doppiogiochisti": "doppiogiochista",
    "doppioni": "doppione",
    "doppiopetti": "doppiopetto",
    "doppisti": "doppista",
    "doppiò": "doppiare",
    "dora": "dorare",
    "dorai": "dorare",
    "dorammo": "dorare",
    "doran": "dorare",
    "dorando": "dorare",
    "dorano": "dorare",
    "dorante": "dorare",
    "doranti": "dorare",
    "dorar": "dorare",
    "doraron": "dorare",
    "dorarono": "dorare",
    "dorasse": "dorare",
    "dorasser": "dorare",
    "dorassero": "dorare",
    "dorassi": "dorare",
    "dorassimo": "dorare",
    "doraste": "dorare",
    "dorasti": "dorare",
    "dorata": "dorato",
    "dorate": "dorato",
    "dorati": "dorato",
    "dorato": "dorare",
    "dorature": "doratura",
    "dorava": "dorare",
    "doravamo": "dorare",
    "doravan": "dorare",
    "doravano": "dorare",
    "doravate": "dorare",
    "doravi": "dorare",
    "doravo": "dorare",
    "dorerai": "dorare",
    "doreran": "dorare",
    "doreranno": "dorare",
    "dorerebbe": "dorare",
    "dorerebber": "dorare",
    "dorerebbero": "dorare",
    "dorerei": "dorare",
    "doreremmo": "dorare",
    "doreremo": "dorare",
    "dorereste": "dorare",
    "doreresti": "dorare",
    "dorerete": "dorare",
    "dorerà": "dorare",
    "dorerò": "dorare",
    "dori": "dorare",
    "doriamo": "dorare",
    "doriana": "doriano",
    "doriane": "doriano",
    "doriani": "doriano",
    "doriate": "dorare",
    "dorica": "dorico",
    "doriche": "dorico",
    "dorici": "dorico",
    "dorin": "dorare",
    "dorino": "dorare",
    "dorma": "dormire",
    "dorman": "dormire",
    "dormano": "dormire",
    "dorme": "dormire",
    "dormendo": "dormire",
    "dormente": "dormire",
    "dormenti": "dormire",
    "dormi": "dormire",
    "dormiamo": "dormire",
    "dormiate": "dormire",
    "dormicchi": "dormicchiare",
    "dormicchia": "dormicchiare",
    "dormicchiai": "dormicchiare",
    "dormicchiammo": "dormicchiare",
    "dormicchiamo": "dormicchiare",
    "dormicchian": "dormicchiare",
    "dormicchiando": "dormicchiare",
    "dormicchiano": "dormicchiare",
    "dormicchiante": "dormicchiare",
    "dormicchianti": "dormicchiare",
    "dormicchiar": "dormicchiare",
    "dormicchiaron": "dormicchiare",
    "dormicchiarono": "dormicchiare",
    "dormicchiasse": "dormicchiare",
    "dormicchiasser": "dormicchiare",
    "dormicchiassero": "dormicchiare",
    "dormicchiassi": "dormicchiare",
    "dormicchiassimo": "dormicchiare",
    "dormicchiaste": "dormicchiare",
    "dormicchiasti": "dormicchiare",
    "dormicchiata": "dormicchiare",
    "dormicchiate": "dormicchiare",
    "dormicchiati": "dormicchiare",
    "dormicchiato": "dormicchiare",
    "dormicchiava": "dormicchiare",
    "dormicchiavamo": "dormicchiare",
    "dormicchiavan": "dormicchiare",
    "dormicchiavano": "dormicchiare",
    "dormicchiavate": "dormicchiare",
    "dormicchiavi": "dormicchiare",
    "dormicchiavo": "dormicchiare",
    "dormicchierai": "dormicchiare",
    "dormicchieran": "dormicchiare",
    "dormicchieranno": "dormicchiare",
    "dormicchierebbe": "dormicchiare",
    "dormicchierebber": "dormicchiare",
    "dormicchierebbero": "dormicchiare",
    "dormicchierei": "dormicchiare",
    "dormicchieremmo": "dormicchiare",
    "dormicchieremo": "dormicchiare",
    "dormicchiereste": "dormicchiare",
    "dormicchieresti": "dormicchiare",
    "dormicchierete": "dormicchiare",
    "dormicchierà": "dormicchiare",
    "dormicchierò": "dormicchiare",
    "dormicchin": "dormicchiare",
    "dormicchino": "dormicchiare",
    "dormicchio": "dormicchiare",
    "dormicchiò": "dormicchiare",
    "dormienti": "dormiente",
    "dormiglioni": "dormiglione",
    "dormii": "dormire",
    "dormimmo": "dormire",
    "dormir": "dormire",
    "dormirai": "dormire",
    "dormiran": "dormire",
    "dormiranno": "dormire",
    "dormirebbe": "dormire",
    "dormirebber": "dormire",
    "dormirebbero": "dormire",
    "dormirei": "dormire",
    "dormiremmo": "dormire",
    "dormiremo": "dormire",
    "dormireste": "dormire",
    "dormiresti": "dormire",
    "dormirete": "dormire",
    "dormiron": "dormire",
    "dormirono": "dormire",
    "dormirà": "dormire",
    "dormirò": "dormire",
    "dormisse": "dormire",
    "dormisser": "dormire",
    "dormissero": "dormire",
    "dormissi": "dormire",
    "dormissimo": "dormire",
    "dormiste": "dormire",
    "dormisti": "dormire",
    "dormita": "dormire",
    "dormite": "dormita",
    "dormiti": "dormire",
    "dormito": "dormire",
    "dormitori": "dormitorio",
    "dormiva": "dormire",
    "dormivamo": "dormire",
    "dormivan": "dormire",
    "dormivano": "dormire",
    "dormivate": "dormire",
    "dormivi": "dormire",
    "dormivo": "dormire",
    "dormo": "dormire",
    "dormon": "dormire",
    "dormono": "dormire",
    "dormì": "dormire",
    "doro": "dorare",
    "dorotea": "doroteo",
    "dorotee": "doroteo",
    "dorotei": "doroteo",
    "doroteismi": "doroteismo",
    "dorsali": "dorsale",
    "dorsi": "dorso",
    "dorò": "dorare",
    "dosa": "dosare",
    "dosaggi": "dosaggio",
    "dosai": "dosare",
    "dosammo": "dosare",
    "dosan": "dosare",
    "dosando": "dosare",
    "dosano": "dosare",
    "dosante": "dosare",
    "dosanti": "dosare",
    "dosar": "dosare",
    "dosaron": "dosare",
    "dosarono": "dosare",
    "dosasse": "dosare",
    "dosasser": "dosare",
    "dosassero": "dosare",
    "dosassi": "dosare",
    "dosassimo": "dosare",
    "dosaste": "dosare",
    "dosasti": "dosare",
    "dosata": "dosare",
    "dosate": "dosare",
    "dosati": "dosare",
    "dosato": "dosare",
    "dosava": "dosare",
    "dosavamo": "dosare",
    "dosavan": "dosare",
    "dosavano": "dosare",
    "dosavate": "dosare",
    "dosavi": "dosare",
    "dosavo": "dosare",
    "doserai": "dosare",
    "doseran": "dosare",
    "doseranno": "dosare",
    "doserebbe": "dosare",
    "doserebber": "dosare",
    "doserebbero": "dosare",
    "doserei": "dosare",
    "doseremmo": "dosare",
    "doseremo": "dosare",
    "dosereste": "dosare",
    "doseresti": "dosare",
    "doserete": "dosare",
    "doserà": "dosare",
    "doserò": "dosare",
    "dosi": "dose",
    "dosiamo": "dosare",
    "dosiate": "dosare",
    "dosin": "dosare",
    "dosino": "dosare",
    "doso": "dosare",
    "dossi": "dosso",
    "dosò": "dosare",
    "dota": "dotare",
    "dotai": "dotare",
    "dotammo": "dotare",
    "dotan": "dotare",
    "dotando": "dotare",
    "dotano": "dotare",
    "dotante": "dotare",
    "dotanti": "dotare",
    "dotar": "dotare",
    "dotaron": "dotare",
    "dotarono": "dotare",
    "dotasse": "dotare",
    "dotasser": "dotare",
    "dotassero": "dotare",
    "dotassi": "dotare",
    "dotassimo": "dotare",
    "dotaste": "dotare",
    "dotasti": "dotare",
    "dotata": "dotato",
    "dotate": "dotato",
    "dotati": "dotato",
    "dotato": "dotare",
    "dotava": "dotare",
    "dotavamo": "dotare",
    "dotavan": "dotare",
    "dotavano": "dotare",
    "dotavate": "dotare",
    "dotavi": "dotare",
    "dotavo": "dotare",
    "dotazioni": "dotazione",
    "doterai": "dotare",
    "doteran": "dotare",
    "doteranno": "dotare",
    "doterebbe": "dotare",
    "doterebber": "dotare",
    "doterebbero": "dotare",
    "doterei": "dotare",
    "doteremmo": "dotare",
    "doteremo": "dotare",
    "dotereste": "dotare",
    "doteresti": "dotare",
    "doterete": "dotare",
    "doterà": "dotare",
    "doterò": "dotare",
    "doti": "dote",
    "dotiamo": "dotare",
    "dotiate": "dotare",
    "dotin": "dotare",
    "dotino": "dotare",
    "doto": "dotare",
    "dotta": "dotto",
    "dotte": "dotto",
    "dotti": "dotto",
    "dottor": "dottore",
    "dottorati": "dottorato",
    "dottoreggerai": "dottoreggiare",
    "dottoreggeran": "dottoreggiare",
    "dottoreggeranno": "dottoreggiare",
    "dottoreggerebbe": "dottoreggiare",
    "dottoreggerebber": "dottoreggiare",
    "dottoreggerebbero": "dottoreggiare",
    "dottoreggerei": "dottoreggiare",
    "dottoreggeremmo": "dottoreggiare",
    "dottoreggeremo": "dottoreggiare",
    "dottoreggereste": "dottoreggiare",
    "dottoreggeresti": "dottoreggiare",
    "dottoreggerete": "dottoreggiare",
    "dottoreggerà": "dottoreggiare",
    "dottoreggerò": "dottoreggiare",
    "dottoreggi": "dottoreggiare",
    "dottoreggia": "dottoreggiare",
    "dottoreggiai": "dottoreggiare",
    "dottoreggiammo": "dottoreggiare",
    "dottoreggiamo": "dottoreggiare",
    "dottoreggian": "dottoreggiare",
    "dottoreggiando": "dottoreggiare",
    "dottoreggiano": "dottoreggiare",
    "dottoreggiante": "dottoreggiare",
    "dottoreggianti": "dottoreggiare",
    "dottoreggiar": "dottoreggiare",
    "dottoreggiaron": "dottoreggiare",
    "dottoreggiarono": "dottoreggiare",
    "dottoreggiasse": "dottoreggiare",
    "dottoreggiasser": "dottoreggiare",
    "dottoreggiassero": "dottoreggiare",
    "dottoreggiassi": "dottoreggiare",
    "dottoreggiassimo": "dottoreggiare",
    "dottoreggiaste": "dottoreggiare",
    "dottoreggiasti": "dottoreggiare",
    "dottoreggiata": "dottoreggiare",
    "dottoreggiate": "dottoreggiare",
    "dottoreggiati": "dottoreggiare",
    "dottoreggiato": "dottoreggiare",
    "dottoreggiava": "dottoreggiare",
    "dottoreggiavamo": "dottoreggiare",
    "dottoreggiavan": "dottoreggiare",
    "dottoreggiavano": "dottoreggiare",
    "dottoreggiavate": "dottoreggiare",
    "dottoreggiavi": "dottoreggiare",
    "dottoreggiavo": "dottoreggiare",
    "dottoreggin": "dottoreggiare",
    "dottoreggino": "dottoreggiare",
    "dottoreggio": "dottoreggiare",
    "dottoreggiò": "dottoreggiare",
    "dottoresse": "dottoressa",
    "dottori": "dottore",
    "dottrinali": "dottrinale",
    "dottrinari": "dottrinario",
    "dottrinaria": "dottrinario",
    "dottrinarie": "dottrinario",
    "dottrine": "dottrina",
    "dotò": "dotare",
    "dov'": "dove",
    "dovei": "dovere",
    "dovemmo": "dovere",
    "dovendo": "dovere",
    "dovente": "dovere",
    "doventi": "dovere",
    "dover": "dovere",
    "doveri": "dovere",
    "doverono": "dovere",
    "doverosa": "doveroso",
    "doverose": "doveroso",
    "doverosi": "doveroso",
    "dovesse": "dovere",
    "dovesser": "dovere",
    "dovessero": "dovere",
    "dovessi": "dovere",
    "dovessimo": "dovere",
    "doveste": "dovere",
    "dovesti": "dovere",
    "dovete": "dovere",
    "dovette": "dovere",
    "dovettero": "dovere",
    "dovetti": "dovere",
    "doveva": "dovere",
    "dovevamo": "dovere",
    "dovevan": "dovere",
    "dovevano": "dovere",
    "dovevate": "dovere",
    "dovevi": "dovere",
    "dovevo": "dovere",
    "dovizie": "dovizia",
    "dovrai": "dovere",
    "dovran": "dovere",
    "dovranno": "dovere",
    "dovrebbe": "dovere",
    "dovrebber": "dovere",
    "dovrebbero": "dovere",
    "dovrei": "dovere",
    "dovremmo": "dovere",
    "dovremo": "dovere",
    "dovreste": "dovere",
    "dovresti": "dovere",
    "dovrete": "dovere",
    "dovrà": "dovere",
    "dovrò": "dovere",
    "dovuta": "dovuto",
    "dovute": "dovuto",
    "dovuti": "dovuto",
    "dovuto": "dovere",
    "dové": "dovere",
    "dozzinali": "dozzinale",
    "dozzine": "dozzina",
    "dracme": "dracma",
    "draconiana": "draconiano",
    "draconiane": "draconiano",
    "draconiani": "draconiano",
    "draga": "dragare",
    "dragai": "dragare",
    "dragammo": "dragare",
    "dragan": "dragare",
    "dragando": "dragare",
    "dragano": "dragare",
    "dragante": "dragare",
    "draganti": "dragare",
    "dragar": "dragare",
    "dragaron": "dragare",
    "dragarono": "dragare",
    "dragasse": "dragare",
    "dragasser": "dragare",
    "dragassero": "dragare",
    "dragassi": "dragare",
    "dragassimo": "dragare",
    "dragaste": "dragare",
    "dragasti": "dragare",
    "dragata": "dragare",
    "dragate": "dragare",
    "dragati": "dragare",
    "dragato": "dragare",
    "dragava": "dragare",
    "dragavamo": "dragare",
    "dragavan": "dragare",
    "dragavano": "dragare",
    "dragavate": "dragare",
    "dragavi": "dragare",
    "dragavo": "dragare",
    "dragherai": "dragare",
    "dragheran": "dragare",
    "dragheranno": "dragare",
    "dragherebbe": "dragare",
    "dragherebber": "dragare",
    "dragherebbero": "dragare",
    "dragherei": "dragare",
    "dragheremmo": "dragare",
    "dragheremo": "dragare",
    "draghereste": "dragare",
    "dragheresti": "dragare",
    "dragherete": "dragare",
    "dragherà": "dragare",
    "dragherò": "dragare",
    "draghi": "drago",
    "draghiamo": "dragare",
    "draghiate": "dragare",
    "draghin": "dragare",
    "draghino": "dragare",
    "drago": "dragare",
    "dragoni": "dragone",
    "dragò": "dragare",
    "drammatica": "drammatico",
    "drammatiche": "drammatico",
    "drammatici": "drammatico",
    "drammatizza": "drammatizzare",
    "drammatizzai": "drammatizzare",
    "drammatizzammo": "drammatizzare",
    "drammatizzan": "drammatizzare",
    "drammatizzando": "drammatizzare",
    "drammatizzano": "drammatizzare",
    "drammatizzante": "drammatizzare",
    "drammatizzanti": "drammatizzare",
    "drammatizzar": "drammatizzare",
    "drammatizzaron": "drammatizzare",
    "drammatizzarono": "drammatizzare",
    "drammatizzasse": "drammatizzare",
    "drammatizzasser": "drammatizzare",
    "drammatizzassero": "drammatizzare",
    "drammatizzassi": "drammatizzare",
    "drammatizzassimo": "drammatizzare",
    "drammatizzaste": "drammatizzare",
    "drammatizzasti": "drammatizzare",
    "drammatizzata": "drammatizzare",
    "drammatizzate": "drammatizzare",
    "drammatizzati": "drammatizzare",
    "drammatizzato": "drammatizzare",
    "drammatizzava": "drammatizzare",
    "drammatizzavamo": "drammatizzare",
    "drammatizzavan": "drammatizzare",
    "drammatizzavano": "drammatizzare",
    "drammatizzavate": "drammatizzare",
    "drammatizzavi": "drammatizzare",
    "drammatizzavo": "drammatizzare",
    "drammatizzazioni": "drammatizzazione",
    "drammatizzerai": "drammatizzare",
    "drammatizzeran": "drammatizzare",
    "drammatizzeranno": "drammatizzare",
    "drammatizzerebbe": "drammatizzare",
    "drammatizzerebber": "drammatizzare",
    "drammatizzerebbero": "drammatizzare",
    "drammatizzerei": "drammatizzare",
    "drammatizzeremmo": "drammatizzare",
    "drammatizzeremo": "drammatizzare",
    "drammatizzereste": "drammatizzare",
    "drammatizzeresti": "drammatizzare",
    "drammatizzerete": "drammatizzare",
    "drammatizzerà": "drammatizzare",
    "drammatizzerò": "drammatizzare",
    "drammatizzi": "drammatizzare",
    "drammatizziamo": "drammatizzare",
    "drammatizziate": "drammatizzare",
    "drammatizzin": "drammatizzare",
    "drammatizzino": "drammatizzare",
    "drammatizzo": "drammatizzare",
    "drammatizzò": "drammatizzare",
    "drammaturghi": "drammaturgo",
    "drammaturgica": "drammaturgico",
    "drammaturgiche": "drammaturgico",
    "drammaturgici": "drammaturgico",
    "drammaturgie": "drammaturgia",
    "drammi": "dramma",
    "drammoni": "drammone",
    "drappeggerai": "drappeggiare",
    "drappeggeran": "drappeggiare",
    "drappeggeranno": "drappeggiare",
    "drappeggerebbe": "drappeggiare",
    "drappeggerebber": "drappeggiare",
    "drappeggerebbero": "drappeggiare",
    "drappeggerei": "drappeggiare",
    "drappeggeremmo": "drappeggiare",
    "drappeggeremo": "drappeggiare",
    "drappeggereste": "drappeggiare",
    "drappeggeresti": "drappeggiare",
    "drappeggerete": "drappeggiare",
    "drappeggerà": "drappeggiare",
    "drappeggerò": "drappeggiare",
    "drappeggi": "drappeggio",
    "drappeggia": "drappeggiare",
    "drappeggiai": "drappeggiare",
    "drappeggiammo": "drappeggiare",
    "drappeggiamo": "drappeggiare",
    "drappeggian": "drappeggiare",
    "drappeggiando": "drappeggiare",
    "drappeggiano": "drappeggiare",
    "drappeggiante": "drappeggiare",
    "drappeggianti": "drappeggiare",
    "drappeggiar": "drappeggiare",
    "drappeggiaron": "drappeggiare",
    "drappeggiarono": "drappeggiare",
    "drappeggiasse": "drappeggiare",
    "drappeggiasser": "drappeggiare",
    "drappeggiassero": "drappeggiare",
    "drappeggiassi": "drappeggiare",
    "drappeggiassimo": "drappeggiare",
    "drappeggiaste": "drappeggiare",
    "drappeggiasti": "drappeggiare",
    "drappeggiata": "drappeggiare",
    "drappeggiate": "drappeggiare",
    "drappeggiati": "drappeggiare",
    "drappeggiato": "drappeggiare",
    "drappeggiava": "drappeggiare",
    "drappeggiavamo": "drappeggiare",
    "drappeggiavan": "drappeggiare",
    "drappeggiavano": "drappeggiare",
    "drappeggiavate": "drappeggiare",
    "drappeggiavi": "drappeggiare",
    "drappeggiavo": "drappeggiare",
    "drappeggin": "drappeggiare",
    "drappeggino": "drappeggiare",
    "drappeggio": "drappeggiare",
    "drappeggiò": "drappeggiare",
    "drappelli": "drappello",
    "drappi": "drappo",
    "drastica": "drastico",
    "drastiche": "drastico",
    "drastici": "drastico",
    "drena": "drenare",
    "drenaggi": "drenaggio",
    "drenai": "drenare",
    "drenammo": "drenare",
    "drenan": "drenare",
    "drenando": "drenare",
    "drenano": "drenare",
    "drenante": "drenare",
    "drenanti": "drenare",
    "drenar": "drenare",
    "drenaron": "drenare",
    "drenarono": "drenare",
    "drenasse": "drenare",
    "drenasser": "drenare",
    "drenassero": "drenare",
    "drenassi": "drenare",
    "drenassimo": "drenare",
    "drenaste": "drenare",
    "drenasti": "drenare",
    "drenata": "drenare",
    "drenate": "drenare",
    "drenati": "drenare",
    "drenato": "drenare",
    "drenava": "drenare",
    "drenavamo": "drenare",
    "drenavan": "drenare",
    "drenavano": "drenare",
    "drenavate": "drenare",
    "drenavi": "drenare",
    "drenavo": "drenare",
    "drenerai": "drenare",
    "dreneran": "drenare",
    "dreneranno": "drenare",
    "drenerebbe": "drenare",
    "drenerebber": "drenare",
    "drenerebbero": "drenare",
    "drenerei": "drenare",
    "dreneremmo": "drenare",
    "dreneremo": "drenare",
    "drenereste": "drenare",
    "dreneresti": "drenare",
    "drenerete": "drenare",
    "drenerà": "drenare",
    "drenerò": "drenare",
    "dreni": "drenare",
    "dreniamo": "drenare",
    "dreniate": "drenare",
    "drenin": "drenare",
    "drenino": "drenare",
    "dreno": "drenare",
    "drenò": "drenare",
    "dribbla": "dribblare",
    "dribblai": "dribblare",
    "dribblammo": "dribblare",
    "dribblan": "dribblare",
    "dribblando": "dribblare",
    "dribblano": "dribblare",
    "dribblante": "dribblare",
    "dribblanti": "dribblare",
    "dribblar": "dribblare",
    "dribblaron": "dribblare",
    "dribblarono": "dribblare",
    "dribblasse": "dribblare",
    "dribblasser": "dribblare",
    "dribblassero": "dribblare",
    "dribblassi": "dribblare",
    "dribblassimo": "dribblare",
    "dribblaste": "dribblare",
    "dribblasti": "dribblare",
    "dribblata": "dribblare",
    "dribblate": "dribblare",
    "dribblati": "dribblare",
    "dribblato": "dribblare",
    "dribblava": "dribblare",
    "dribblavamo": "dribblare",
    "dribblavan": "dribblare",
    "dribblavano": "dribblare",
    "dribblavate": "dribblare",
    "dribblavi": "dribblare",
    "dribblavo": "dribblare",
    "dribblerai": "dribblare",
    "dribbleran": "dribblare",
    "dribbleranno": "dribblare",
    "dribblerebbe": "dribblare",
    "dribblerebber": "dribblare",
    "dribblerebbero": "dribblare",
    "dribblerei": "dribblare",
    "dribbleremmo": "dribblare",
    "dribbleremo": "dribblare",
    "dribblereste": "dribblare",
    "dribbleresti": "dribblare",
    "dribblerete": "dribblare",
    "dribblerà": "dribblare",
    "dribblerò": "dribblare",
    "dribbli": "dribblare",
    "dribbliamo": "dribblare",
    "dribbliate": "dribblare",
    "dribblin": "dribblare",
    "dribblino": "dribblare",
    "dribblo": "dribblare",
    "dribblò": "dribblare",
    "dritta": "dritto",
    "dritte": "dritto",
    "dritti": "dritto",
    "drizza": "drizzare",
    "drizzai": "drizzare",
    "drizzammo": "drizzare",
    "drizzan": "drizzare",
    "drizzando": "drizzare",
    "drizzano": "drizzare",
    "drizzante": "drizzare",
    "drizzanti": "drizzare",
    "drizzar": "drizzare",
    "drizzaron": "drizzare",
    "drizzarono": "drizzare",
    "drizzasse": "drizzare",
    "drizzasser": "drizzare",
    "drizzassero": "drizzare",
    "drizzassi": "drizzare",
    "drizzassimo": "drizzare",
    "drizzaste": "drizzare",
    "drizzasti": "drizzare",
    "drizzata": "drizzare",
    "drizzate": "drizzare",
    "drizzati": "drizzare",
    "drizzato": "drizzare",
    "drizzava": "drizzare",
    "drizzavamo": "drizzare",
    "drizzavan": "drizzare",
    "drizzavano": "drizzare",
    "drizzavate": "drizzare",
    "drizzavi": "drizzare",
    "drizzavo": "drizzare",
    "drizzerai": "drizzare",
    "drizzeran": "drizzare",
    "drizzeranno": "drizzare",
    "drizzerebbe": "drizzare",
    "drizzerebber": "drizzare",
    "drizzerebbero": "drizzare",
    "drizzerei": "drizzare",
    "drizzeremmo": "drizzare",
    "drizzeremo": "drizzare",
    "drizzereste": "drizzare",
    "drizzeresti": "drizzare",
    "drizzerete": "drizzare",
    "drizzerà": "drizzare",
    "drizzerò": "drizzare",
    "drizzi": "drizzare",
    "drizziamo": "drizzare",
    "drizziate": "drizzare",
    "drizzin": "drizzare",
    "drizzino": "drizzare",
    "drizzo": "drizzare",
    "drizzò": "drizzare",
    "droga": "drogare",
    "drogai": "drogare",
    "drogammo": "drogare",
    "drogan": "drogare",
    "drogando": "drogare",
    "drogano": "drogare",
    "drogante": "drogare",
    "droganti": "drogare",
    "drogar": "drogare",
    "drogaron": "drogare",
    "drogarono": "drogare",
    "drogasse": "drogare",
    "drogasser": "drogare",
    "drogassero": "drogare",
    "drogassi": "drogare",
    "drogassimo": "drogare",
    "drogaste": "drogare",
    "drogasti": "drogare",
    "drogata": "drogare",
    "drogate": "drogare",
    "drogati": "drogato",
    "drogato": "drogare",
    "drogava": "drogare",
    "drogavamo": "drogare",
    "drogavan": "drogare",
    "drogavano": "drogare",
    "drogavate": "drogare",
    "drogavi": "drogare",
    "drogavo": "drogare",
    "droghe": "droga",
    "drogherai": "drogare",
    "drogheran": "drogare",
    "drogheranno": "drogare",
    "drogherebbe": "drogare",
    "drogherebber": "drogare",
    "drogherebbero": "drogare",
    "drogherei": "drogare",
    "drogheremmo": "drogare",
    "drogheremo": "drogare",
    "droghereste": "drogare",
    "drogheresti": "drogare",
    "drogherete": "drogare",
    "drogherie": "drogheria",
    "drogherà": "drogare",
    "drogherò": "drogare",
    "droghi": "drogare",
    "droghiamo": "drogare",
    "droghiate": "drogare",
    "droghieri": "droghiere",
    "droghin": "drogare",
    "droghino": "drogare",
    "drogo": "drogare",
    "drogò": "drogare",
    "dromedari": "dromedario",
    "druidi": "druido",
    "druidica": "druidico",
    "druidiche": "druidico",
    "druidici": "druidico",
    "drusa": "druso",
    "druse": "druso",
    "drusi": "druso",
    "dualismi": "dualismo",
    "dubbi": "dubbio",
    "dubbia": "dubbio",
    "dubbie": "dubbio",
    "dubbiosa": "dubbioso",
    "dubbiose": "dubbioso",
    "dubbiosi": "dubbioso",
    "dubita": "dubitare",
    "dubitai": "dubitare",
    "dubitammo": "dubitare",
    "dubitan": "dubitare",
    "dubitando": "dubitare",
    "dubitano": "dubitare",
    "dubitante": "dubitare",
    "dubitanti": "dubitare",
    "dubitar": "dubitare",
    "dubitaron": "dubitare",
    "dubitarono": "dubitare",
    "dubitasse": "dubitare",
    "dubitasser": "dubitare",
    "dubitassero": "dubitare",
    "dubitassi": "dubitare",
    "dubitassimo": "dubitare",
    "dubitaste": "dubitare",
    "dubitasti": "dubitare",
    "dubitata": "dubitare",
    "dubitate": "dubitare",
    "dubitati": "dubitare",
    "dubitativa": "dubitativo",
    "dubitative": "dubitativo",
    "dubitativi": "dubitativo",
    "dubitato": "dubitare",
    "dubitava": "dubitare",
    "dubitavamo": "dubitare",
    "dubitavan": "dubitare",
    "dubitavano": "dubitare",
    "dubitavate": "dubitare",
    "dubitavi": "dubitare",
    "dubitavo": "dubitare",
    "dubiterai": "dubitare",
    "dubiteran": "dubitare",
    "dubiteranno": "dubitare",
    "dubiterebbe": "dubitare",
    "dubiterebber": "dubitare",
    "dubiterebbero": "dubitare",
    "dubiterei": "dubitare",
    "dubiteremmo": "dubitare",
    "dubiteremo": "dubitare",
    "dubitereste": "dubitare",
    "dubiteresti": "dubitare",
    "dubiterete": "dubitare",
    "dubiterà": "dubitare",
    "dubiterò": "dubitare",
    "dubiti": "dubitare",
    "dubitiamo": "dubitare",
    "dubitiate": "dubitare",
    "dubitin": "dubitare",
    "dubitino": "dubitare",
    "dubito": "dubitare",
    "dubitò": "dubitare",
    "ducali": "ducale",
    "ducati": "ducato",
    "ducetti": "ducetto",
    "duchesse": "duchessa",
    "duchi": "duca",
    "duecentesca": "duecentesco",
    "duecentesche": "duecentesco",
    "duecenteschi": "duecentesco",
    "duecentesima": "duecentesimo",
    "duecentesime": "duecentesimo",
    "duecentesimi": "duecentesimo",
    "duecentocinquantesima": "duecentocinquantesimo",
    "duecentocinquantesime": "duecentocinquantesimo",
    "duecentocinquantesimi": "duecentocinquantesimo",
    "duecentodecima": "duecentodecimo",
    "duecentodecime": "duecentodecimo",
    "duecentodecimi": "duecentodecimo",
    "duecentonovantesima": "duecentonovantesimo",
    "duecentonovantesime": "duecentonovantesimo",
    "duecentonovantesimi": "duecentonovantesimo",
    "duecentoquarantesima": "duecentoquarantesimo",
    "duecentoquarantesime": "duecentoquarantesimo",
    "duecentoquarantesimi": "duecentoquarantesimo",
    "duecentosessantesima": "duecentosessantesimo",
    "duecentosessantesime": "duecentosessantesimo",
    "duecentosessantesimi": "duecentosessantesimo",
    "duecentosettantesima": "duecentosettantesimo",
    "duecentosettantesime": "duecentosettantesimo",
    "duecentosettantesimi": "duecentosettantesimo",
    "duecentotrentesima": "duecentotrentesimo",
    "duecentotrentesime": "duecentotrentesimo",
    "duecentotrentesimi": "duecentotrentesimo",
    "duecentottantesima": "duecentottantesimo",
    "duecentottantesime": "duecentottantesimo",
    "duecentottantesimi": "duecentottantesimo",
    "duecentoventesima": "duecentoventesimo",
    "duecentoventesime": "duecentoventesimo",
    "duecentoventesimi": "duecentoventesimo",
    "duella": "duellare",
    "duellai": "duellare",
    "duellammo": "duellare",
    "duellan": "duellare",
    "duellando": "duellare",
    "duellano": "duellare",
    "duellante": "duellare",
    "duellanti": "duellare",
    "duellar": "duellare",
    "duellaron": "duellare",
    "duellarono": "duellare",
    "duellasse": "duellare",
    "duellasser": "duellare",
    "duellassero": "duellare",
    "duellassi": "duellare",
    "duellassimo": "duellare",
    "duellaste": "duellare",
    "duellasti": "duellare",
    "duellata": "duellare",
    "duellate": "duellare",
    "duellati": "duellare",
    "duellato": "duellare",
    "duellava": "duellare",
    "duellavamo": "duellare",
    "duellavan": "duellare",
    "duellavano": "duellare",
    "duellavate": "duellare",
    "duellavi": "duellare",
    "duellavo": "duellare",
    "duellerai": "duellare",
    "duelleran": "duellare",
    "duelleranno": "duellare",
    "duellerebbe": "duellare",
    "duellerebber": "duellare",
    "duellerebbero": "duellare",
    "duellerei": "duellare",
    "duelleremmo": "duellare",
    "duelleremo": "duellare",
    "duellereste": "duellare",
    "duelleresti": "duellare",
    "duellerete": "duellare",
    "duellerà": "duellare",
    "duellerò": "duellare",
    "duelli": "duello",
    "duelliamo": "duellare",
    "duelliate": "duellare",
    "duellin": "duellare",
    "duellino": "duellare",
    "duello": "duellare",
    "duellò": "duellare",
    "duemillesima": "duemillesimo",
    "duemillesime": "duemillesimo",
    "duemillesimi": "duemillesimo",
    "duetti": "duetto",
    "dui": "duo",
    "dune": "duna",
    "duomi": "duomo",
    "duopolii": "duopolio",
    "duplica": "duplicare",
    "duplicai": "duplicare",
    "duplicammo": "duplicare",
    "duplican": "duplicare",
    "duplicando": "duplicare",
    "duplicano": "duplicare",
    "duplicante": "duplicare",
    "duplicanti": "duplicare",
    "duplicar": "duplicare",
    "duplicaron": "duplicare",
    "duplicarono": "duplicare",
    "duplicasse": "duplicare",
    "duplicasser": "duplicare",
    "duplicassero": "duplicare",
    "duplicassi": "duplicare",
    "duplicassimo": "duplicare",
    "duplicaste": "duplicare",
    "duplicasti": "duplicare",
    "duplicata": "duplicato",
    "duplicate": "duplicato",
    "duplicati": "duplicato",
    "duplicato": "duplicare",
    "duplicava": "duplicare",
    "duplicavamo": "duplicare",
    "duplicavan": "duplicare",
    "duplicavano": "duplicare",
    "duplicavate": "duplicare",
    "duplicavi": "duplicare",
    "duplicavo": "duplicare",
    "duplicazioni": "duplicazione",
    "duplicherai": "duplicare",
    "duplicheran": "duplicare",
    "duplicheranno": "duplicare",
    "duplicherebbe": "duplicare",
    "duplicherebber": "duplicare",
    "duplicherebbero": "duplicare",
    "duplicherei": "duplicare",
    "duplicheremmo": "duplicare",
    "duplicheremo": "duplicare",
    "duplichereste": "duplicare",
    "duplicheresti": "duplicare",
    "duplicherete": "duplicare",
    "duplicherà": "duplicare",
    "duplicherò": "duplicare",
    "duplichi": "duplicare",
    "duplichiamo": "duplicare",
    "duplichiate": "duplicare",
    "duplichin": "duplicare",
    "duplichino": "duplicare",
    "duplici": "duplice",
    "duplico": "duplicare",
    "duplicò": "duplicare",
    "dura": "duro",
    "durai": "durare",
    "durammo": "durare",
    "duran": "durare",
    "durando": "durare",
    "durano": "durare",
    "durante": "durare",
    "duranti": "durare",
    "durar": "durare",
    "duraron": "durare",
    "durarono": "durare",
    "durasse": "durare",
    "durasser": "durare",
    "durassero": "durare",
    "durassi": "durare",
    "durassimo": "durare",
    "duraste": "durare",
    "durasti": "durare",
    "durata": "durare",
    "durate": "durata",
    "durati": "durare",
    "durato": "durare",
    "duratura": "duraturo",
    "durature": "duraturo",
    "duraturi": "duraturo",
    "durava": "durare",
    "duravamo": "durare",
    "duravan": "durare",
    "duravano": "durare",
    "duravate": "durare",
    "duravi": "durare",
    "duravo": "durare",
    "dure": "duro",
    "durerai": "durare",
    "dureran": "durare",
    "dureranno": "durare",
    "durerebbe": "durare",
    "durerebber": "durare",
    "durerebbero": "durare",
    "durerei": "durare",
    "dureremmo": "durare",
    "dureremo": "durare",
    "durereste": "durare",
    "dureresti": "durare",
    "durerete": "durare",
    "durerà": "durare",
    "durerò": "durare",
    "durevoli": "durevole",
    "durezze": "durezza",
    "duri": "duro",
    "duriamo": "durare",
    "duriate": "durare",
    "durin": "durare",
    "durino": "durare",
    "duro": "durare",
    "durò": "durare",
    "duttili": "duttile",
    "dà": "dare",
    "dèi": "dio",
    "dèmoni": "dèmone",
    "démoni": "démone",
    "dì": "dire",
    "ebanisti": "ebanista",
    "ebbe": "avere",
    "ebber": "avere",
    "ebbero": "avere",
    "ebbi": "avere",
    "ebbra": "ebbro",
    "ebbre": "ebbro",
    "ebbrezze": "ebbrezza",
    "ebbri": "ebbro",
    "ebeti": "ebete",
    "ebraica": "ebraico",
    "ebraiche": "ebraico",
    "ebraici": "ebraico",
    "ebrea": "ebreo",
    "ebree": "ebreo",
    "ebrei": "ebreo",
    "ecatombi": "ecatombe",
    "ecceda": "eccedere",
    "eccedan": "eccedere",
    "eccedano": "eccedere",
    "eccede": "eccedere",
    "eccedei": "eccedere",
    "eccedemmo": "eccedere",
    "eccedendo": "eccedere",
    "eccedente": "eccedere",
    "eccedenti": "eccedere",
    "eccedenze": "eccedenza",
    "ecceder": "eccedere",
    "eccederai": "eccedere",
    "eccederan": "eccedere",
    "eccederanno": "eccedere",
    "eccederebbe": "eccedere",
    "eccederebber": "eccedere",
    "eccederebbero": "eccedere",
    "eccederei": "eccedere",
    "eccederemmo": "eccedere",
    "eccederemo": "eccedere",
    "eccedereste": "eccedere",
    "eccederesti": "eccedere",
    "eccederete": "eccedere",
    "eccederon": "eccedere",
    "eccederono": "eccedere",
    "eccederà": "eccedere",
    "eccederò": "eccedere",
    "eccedesse": "eccedere",
    "eccedesser": "eccedere",
    "eccedessero": "eccedere",
    "eccedessi": "eccedere",
    "eccedessimo": "eccedere",
    "eccedeste": "eccedere",
    "eccedesti": "eccedere",
    "eccedete": "eccedere",
    "eccedeva": "eccedere",
    "eccedevamo": "eccedere",
    "eccedevan": "eccedere",
    "eccedevano": "eccedere",
    "eccedevate": "eccedere",
    "eccedevi": "eccedere",
    "eccedevo": "eccedere",
    "eccedi": "eccedere",
    "eccediamo": "eccedere",
    "eccediate": "eccedere",
    "eccedo": "eccedere",
    "eccedon": "eccedere",
    "eccedono": "eccedere",
    "ecceduta": "eccedere",
    "eccedute": "eccedere",
    "ecceduti": "eccedere",
    "ecceduto": "eccedere",
    "eccedè": "eccedere",
    "eccella": "eccellere",
    "eccellan": "eccellere",
    "eccellano": "eccellere",
    "eccelle": "eccellere",
    "eccellei": "eccellere",
    "eccellemmo": "eccellere",
    "eccellendo": "eccellere",
    "eccellente": "eccellere",
    "eccellenti": "eccellere",
    "eccellenze": "eccellenza",
    "ecceller": "eccellere",
    "eccellerai": "eccellere",
    "eccelleran": "eccellere",
    "eccelleranno": "eccellere",
    "eccellerebbe": "eccellere",
    "eccellerebber": "eccellere",
    "eccellerebbero": "eccellere",
    "eccellerei": "eccellere",
    "eccelleremmo": "eccellere",
    "eccelleremo": "eccellere",
    "eccellereste": "eccellere",
    "eccelleresti": "eccellere",
    "eccellerete": "eccellere",
    "eccelleron": "eccellere",
    "eccellerono": "eccellere",
    "eccellerà": "eccellere",
    "eccellerò": "eccellere",
    "eccellesse": "eccellere",
    "eccellesser": "eccellere",
    "eccellessero": "eccellere",
    "eccellessi": "eccellere",
    "eccellessimo": "eccellere",
    "eccelleste": "eccellere",
    "eccellesti": "eccellere",
    "eccellete": "eccellere",
    "eccelleva": "eccellere",
    "eccellevamo": "eccellere",
    "eccellevan": "eccellere",
    "eccellevano": "eccellere",
    "eccellevate": "eccellere",
    "eccellevi": "eccellere",
    "eccellevo": "eccellere",
    "eccelli": "eccellere",
    "eccelliamo": "eccellere",
    "eccelliate": "eccellere",
    "eccello": "eccellere",
    "eccellon": "eccellere",
    "eccellono": "eccellere",
    "eccelluta": "eccellere",
    "eccellute": "eccellere",
    "eccelluti": "eccellere",
    "eccelluto": "eccellere",
    "eccellè": "eccellere",
    "eccelsa": "eccelso",
    "eccelse": "eccelso",
    "eccelsi": "eccelso",
    "eccentrica": "eccentrico",
    "eccentriche": "eccentrico",
    "eccentrici": "eccentrico",
    "eccependo": "eccepire",
    "eccepente": "eccepire",
    "eccepenti": "eccepire",
    "eccepiamo": "eccepire",
    "eccepiate": "eccepire",
    "eccepibili": "eccepibile",
    "eccepii": "eccepire",
    "eccepimmo": "eccepire",
    "eccepir": "eccepire",
    "eccepirai": "eccepire",
    "eccepiran": "eccepire",
    "eccepiranno": "eccepire",
    "eccepirebbe": "eccepire",
    "eccepirebber": "eccepire",
    "eccepirebbero": "eccepire",
    "eccepirei": "eccepire",
    "eccepiremmo": "eccepire",
    "eccepiremo": "eccepire",
    "eccepireste": "eccepire",
    "eccepiresti": "eccepire",
    "eccepirete": "eccepire",
    "eccepiron": "eccepire",
    "eccepirono": "eccepire",
    "eccepirà": "eccepire",
    "eccepirò": "eccepire",
    "eccepisca": "eccepire",
    "eccepiscan": "eccepire",
    "eccepiscano": "eccepire",
    "eccepisce": "eccepire",
    "eccepisci": "eccepire",
    "eccepisco": "eccepire",
    "eccepiscon": "eccepire",
    "eccepiscono": "eccepire",
    "eccepisse": "eccepire",
    "eccepisser": "eccepire",
    "eccepissero": "eccepire",
    "eccepissi": "eccepire",
    "eccepissimo": "eccepire",
    "eccepiste": "eccepire",
    "eccepisti": "eccepire",
    "eccepita": "eccepire",
    "eccepite": "eccepire",
    "eccepiti": "eccepire",
    "eccepito": "eccepire",
    "eccepiva": "eccepire",
    "eccepivamo": "eccepire",
    "eccepivan": "eccepire",
    "eccepivano": "eccepire",
    "eccepivate": "eccepire",
    "eccepivi": "eccepire",
    "eccepivo": "eccepire",
    "eccepì": "eccepire",
    "eccessi": "eccesso",
    "eccessiva": "eccessivo",
    "eccessive": "eccessivo",
    "eccessivi": "eccessivo",
    "eccettua": "eccettuare",
    "eccettuai": "eccettuare",
    "eccettuammo": "eccettuare",
    "eccettuan": "eccettuare",
    "eccettuando": "eccettuare",
    "eccettuano": "eccettuare",
    "eccettuante": "eccettuare",
    "eccettuanti": "eccettuare",
    "eccettuar": "eccettuare",
    "eccettuaron": "eccettuare",
    "eccettuarono": "eccettuare",
    "eccettuasse": "eccettuare",
    "eccettuasser": "eccettuare",
    "eccettuassero": "eccettuare",
    "eccettuassi": "eccettuare",
    "eccettuassimo": "eccettuare",
    "eccettuaste": "eccettuare",
    "eccettuasti": "eccettuare",
    "eccettuata": "eccettuare",
    "eccettuate": "eccettuare",
    "eccettuati": "eccettuare",
    "eccettuato": "eccettuare",
    "eccettuava": "eccettuare",
    "eccettuavamo": "eccettuare",
    "eccettuavan": "eccettuare",
    "eccettuavano": "eccettuare",
    "eccettuavate": "eccettuare",
    "eccettuavi": "eccettuare",
    "eccettuavo": "eccettuare",
    "eccettuerai": "eccettuare",
    "eccettueran": "eccettuare",
    "eccettueranno": "eccettuare",
    "eccettuerebbe": "eccettuare",
    "eccettuerebber": "eccettuare",
    "eccettuerebbero": "eccettuare",
    "eccettuerei": "eccettuare",
    "eccettueremmo": "eccettuare",
    "eccettueremo": "eccettuare",
    "eccettuereste": "eccettuare",
    "eccettueresti": "eccettuare",
    "eccettuerete": "eccettuare",
    "eccettuerà": "eccettuare",
    "eccettuerò": "eccettuare",
    "eccettui": "eccettuare",
    "eccettuiamo": "eccettuare",
    "eccettuiate": "eccettuare",
    "eccettuin": "eccettuare",
    "eccettuino": "eccettuare",
    "eccettuo": "eccettuare",
    "eccettuò": "eccettuare",
    "eccezionali": "eccezionale",
    "eccezioni": "eccezione",
    "eccidi": "eccidio",
    "eccita": "eccitare",
    "eccitabili": "eccitabile",
    "eccitai": "eccitare",
    "eccitammo": "eccitare",
    "eccitan": "eccitare",
    "eccitando": "eccitare",
    "eccitano": "eccitare",
    "eccitante": "eccitare",
    "eccitanti": "eccitare",
    "eccitar": "eccitare",
    "eccitaron": "eccitare",
    "eccitarono": "eccitare",
    "eccitasse": "eccitare",
    "eccitasser": "eccitare",
    "eccitassero": "eccitare",
    "eccitassi": "eccitare",
    "eccitassimo": "eccitare",
    "eccitaste": "eccitare",
    "eccitasti": "eccitare",
    "eccitata": "eccitare",
    "eccitate": "eccitare",
    "eccitati": "eccitare",
    "eccitato": "eccitare",
    "eccitava": "eccitare",
    "eccitavamo": "eccitare",
    "eccitavan": "eccitare",
    "eccitavano": "eccitare",
    "eccitavate": "eccitare",
    "eccitavi": "eccitare",
    "eccitavo": "eccitare",
    "eccitazioni": "eccitazione",
    "ecciterai": "eccitare",
    "ecciteran": "eccitare",
    "ecciteranno": "eccitare",
    "ecciterebbe": "eccitare",
    "ecciterebber": "eccitare",
    "ecciterebbero": "eccitare",
    "ecciterei": "eccitare",
    "ecciteremmo": "eccitare",
    "ecciteremo": "eccitare",
    "eccitereste": "eccitare",
    "ecciteresti": "eccitare",
    "ecciterete": "eccitare",
    "ecciterà": "eccitare",
    "ecciterò": "eccitare",
    "ecciti": "eccitare",
    "eccitiamo": "eccitare",
    "eccitiate": "eccitare",
    "eccitin": "eccitare",
    "eccitino": "eccitare",
    "eccito": "eccitare",
    "eccitò": "eccitare",
    "ecclesiali": "ecclesiale",
    "ecclesiastica": "ecclesiastico",
    "ecclesiastiche": "ecclesiastico",
    "ecclesiastici": "ecclesiastico",
    "echeggerai": "echeggiare",
    "echeggeran": "echeggiare",
    "echeggeranno": "echeggiare",
    "echeggerebbe": "echeggiare",
    "echeggerebber": "echeggiare",
    "echeggerebbero": "echeggiare",
    "echeggerei": "echeggiare",
    "echeggeremmo": "echeggiare",
    "echeggeremo": "echeggiare",
    "echeggereste": "echeggiare",
    "echeggeresti": "echeggiare",
    "echeggerete": "echeggiare",
    "echeggerà": "echeggiare",
    "echeggerò": "echeggiare",
    "echeggi": "echeggiare",
    "echeggia": "echeggiare",
    "echeggiai": "echeggiare",
    "echeggiammo": "echeggiare",
    "echeggiamo": "echeggiare",
    "echeggian": "echeggiare",
    "echeggiando": "echeggiare",
    "echeggiano": "echeggiare",
    "echeggiante": "echeggiare",
    "echeggianti": "echeggiare",
    "echeggiar": "echeggiare",
    "echeggiaron": "echeggiare",
    "echeggiarono": "echeggiare",
    "echeggiasse": "echeggiare",
    "echeggiasser": "echeggiare",
    "echeggiassero": "echeggiare",
    "echeggiassi": "echeggiare",
    "echeggiassimo": "echeggiare",
    "echeggiaste": "echeggiare",
    "echeggiasti": "echeggiare",
    "echeggiata": "echeggiare",
    "echeggiate": "echeggiare",
    "echeggiati": "echeggiare",
    "echeggiato": "echeggiare",
    "echeggiava": "echeggiare",
    "echeggiavamo": "echeggiare",
    "echeggiavan": "echeggiare",
    "echeggiavano": "echeggiare",
    "echeggiavate": "echeggiare",
    "echeggiavi": "echeggiare",
    "echeggiavo": "echeggiare",
    "echeggin": "echeggiare",
    "echeggino": "echeggiare",
    "echeggio": "echeggiare",
    "echeggiò": "echeggiare",
    "echi": "eco",
    "eclatanti": "eclatante",
    "eclettica": "eclettico",
    "eclettiche": "eclettico",
    "eclettici": "eclettico",
    "eclettismi": "eclettismo",
    "eclissa": "eclissare",
    "eclissai": "eclissare",
    "eclissammo": "eclissare",
    "eclissan": "eclissare",
    "eclissando": "eclissare",
    "eclissano": "eclissare",
    "eclissante": "eclissare",
    "eclissanti": "eclissare",
    "eclissar": "eclissare",
    "eclissaron": "eclissare",
    "eclissarono": "eclissare",
    "eclissasse": "eclissare",
    "eclissasser": "eclissare",
    "eclissassero": "eclissare",
    "eclissassi": "eclissare",
    "eclissassimo": "eclissare",
    "eclissaste": "eclissare",
    "eclissasti": "eclissare",
    "eclissata": "eclissare",
    "eclissate": "eclissare",
    "eclissati": "eclissare",
    "eclissato": "eclissare",
    "eclissava": "eclissare",
    "eclissavamo": "eclissare",
    "eclissavan": "eclissare",
    "eclissavano": "eclissare",
    "eclissavate": "eclissare",
    "eclissavi": "eclissare",
    "eclissavo": "eclissare",
    "eclisserai": "eclissare",
    "eclisseran": "eclissare",
    "eclisseranno": "eclissare",
    "eclisserebbe": "eclissare",
    "eclisserebber": "eclissare",
    "eclisserebbero": "eclissare",
    "eclisserei": "eclissare",
    "eclisseremmo": "eclissare",
    "eclisseremo": "eclissare",
    "eclissereste": "eclissare",
    "eclisseresti": "eclissare",
    "eclisserete": "eclissare",
    "eclisserà": "eclissare",
    "eclisserò": "eclissare",
    "eclissi": "eclisse",
    "eclissiamo": "eclissare",
    "eclissiate": "eclissare",
    "eclissin": "eclissare",
    "eclissino": "eclissare",
    "eclisso": "eclissare",
    "eclissò": "eclissare",
    "ecografie": "ecografia",
    "ecologi": "ecologo",
    "ecologica": "ecologico",
    "ecologiche": "ecologico",
    "ecologici": "ecologico",
    "ecologico-ambientali": "ecologico-ambientale",
    "ecologie": "ecologia",
    "ecologiste": "ecologista",
    "ecologisti": "ecologista",
    "economa": "economo",
    "econome": "economo",
    "economi": "economo",
    "economica": "economico",
    "economiche": "economico",
    "economici": "economico",
    "economico-finanziari": "economico-finanziario",
    "economico-finanziaria": "economico-finanziario",
    "economico-finanziarie": "economico-finanziario",
    "economico-sociali": "economico-sociale",
    "economie": "economia",
    "economisti": "economista",
    "economizza": "economizzare",
    "economizzai": "economizzare",
    "economizzammo": "economizzare",
    "economizzan": "economizzare",
    "economizzando": "economizzare",
    "economizzano": "economizzare",
    "economizzante": "economizzare",
    "economizzanti": "economizzare",
    "economizzar": "economizzare",
    "economizzaron": "economizzare",
    "economizzarono": "economizzare",
    "economizzasse": "economizzare",
    "economizzasser": "economizzare",
    "economizzassero": "economizzare",
    "economizzassi": "economizzare",
    "economizzassimo": "economizzare",
    "economizzaste": "economizzare",
    "economizzasti": "economizzare",
    "economizzata": "economizzare",
    "economizzate": "economizzare",
    "economizzati": "economizzare",
    "economizzato": "economizzare",
    "economizzava": "economizzare",
    "economizzavamo": "economizzare",
    "economizzavan": "economizzare",
    "economizzavano": "economizzare",
    "economizzavate": "economizzare",
    "economizzavi": "economizzare",
    "economizzavo": "economizzare",
    "economizzerai": "economizzare",
    "economizzeran": "economizzare",
    "economizzeranno": "economizzare",
    "economizzerebbe": "economizzare",
    "economizzerebber": "economizzare",
    "economizzerebbero": "economizzare",
    "economizzerei": "economizzare",
    "economizzeremmo": "economizzare",
    "economizzeremo": "economizzare",
    "economizzereste": "economizzare",
    "economizzeresti": "economizzare",
    "economizzerete": "economizzare",
    "economizzerà": "economizzare",
    "economizzerò": "economizzare",
    "economizzi": "economizzare",
    "economizziamo": "economizzare",
    "economizziate": "economizzare",
    "economizzin": "economizzare",
    "economizzino": "economizzare",
    "economizzo": "economizzare",
    "economizzò": "economizzare",
    "ecosistemi": "ecosistema",
    "ecotasse": "ecotassa",
    "ecoterroristi": "ecoterrorista",
    "ectoplasmi": "ectoplasma",
    "ecuadoriana": "ecuadoriano",
    "ecuadoriane": "ecuadoriano",
    "ecuadoriani": "ecuadoriano",
    "ecumenica": "ecumenico",
    "ecumeniche": "ecumenico",
    "ecumenici": "ecumenico",
    "edenica": "edenico",
    "edeniche": "edenico",
    "edenici": "edenico",
    "edicolanti": "edicolante",
    "edicole": "edicola",
    "edifica": "edificare",
    "edificabili": "edificabile",
    "edificai": "edificare",
    "edificammo": "edificare",
    "edifican": "edificare",
    "edificando": "edificare",
    "edificano": "edificare",
    "edificante": "edificare",
    "edificanti": "edificare",
    "edificar": "edificare",
    "edificaron": "edificare",
    "edificarono": "edificare",
    "edificasse": "edificare",
    "edificasser": "edificare",
    "edificassero": "edificare",
    "edificassi": "edificare",
    "edificassimo": "edificare",
    "edificaste": "edificare",
    "edificasti": "edificare",
    "edificata": "edificare",
    "edificate": "edificare",
    "edificati": "edificare",
    "edificato": "edificare",
    "edificava": "edificare",
    "edificavamo": "edificare",
    "edificavan": "edificare",
    "edificavano": "edificare",
    "edificavate": "edificare",
    "edificavi": "edificare",
    "edificavo": "edificare",
    "edificazioni": "edificazione",
    "edificherai": "edificare",
    "edificheran": "edificare",
    "edificheranno": "edificare",
    "edificherebbe": "edificare",
    "edificherebber": "edificare",
    "edificherebbero": "edificare",
    "edificherei": "edificare",
    "edificheremmo": "edificare",
    "edificheremo": "edificare",
    "edifichereste": "edificare",
    "edificheresti": "edificare",
    "edificherete": "edificare",
    "edificherà": "edificare",
    "edificherò": "edificare",
    "edifichi": "edificare",
    "edifichiamo": "edificare",
    "edifichiate": "edificare",
    "edifichin": "edificare",
    "edifichino": "edificare",
    "edifici": "edificio",
    "edifico": "edificare",
    "edificò": "edificare",
    "edili": "edile",
    "edilizi": "edilizio",
    "edilizia": "edilizio",
    "edilizie": "edilizio",
    "edipica": "edipico",
    "edipiche": "edipico",
    "edipici": "edipico",
    "edita": "edito",
    "editai": "editare",
    "editammo": "editare",
    "editan": "editare",
    "editando": "editare",
    "editano": "editare",
    "editante": "editare",
    "editanti": "editare",
    "editar": "editare",
    "editaron": "editare",
    "editarono": "editare",
    "editasse": "editare",
    "editasser": "editare",
    "editassero": "editare",
    "editassi": "editare",
    "editassimo": "editare",
    "editaste": "editare",
    "editasti": "editare",
    "editata": "editare",
    "editate": "editare",
    "editati": "editare",
    "editato": "editare",
    "editava": "editare",
    "editavamo": "editare",
    "editavan": "editare",
    "editavano": "editare",
    "editavate": "editare",
    "editavi": "editare",
    "editavo": "editare",
    "edite": "edito",
    "editerai": "editare",
    "editeran": "editare",
    "editeranno": "editare",
    "editerebbe": "editare",
    "editerebber": "editare",
    "editerebbero": "editare",
    "editerei": "editare",
    "editeremmo": "editare",
    "editeremo": "editare",
    "editereste": "editare",
    "editeresti": "editare",
    "editerete": "editare",
    "editerà": "editare",
    "editerò": "editare",
    "editi": "edito",
    "editiamo": "editare",
    "editiate": "editare",
    "editin": "editare",
    "editino": "editare",
    "edito": "editare",
    "editori": "editore",
    "editoriali": "editoriale",
    "editorialisti": "editorialista",
    "editorie": "editoria",
    "editrice": "editore",
    "editrici": "editore",
    "editti": "editto",
    "editò": "editare",
    "edizioni": "edizione",
    "edonismi": "edonismo",
    "edoniste": "edonista",
    "edonisti": "edonista",
    "edonistica": "edonistico",
    "edonistiche": "edonistico",
    "edonistici": "edonistico",
    "edotta": "edotto",
    "edotte": "edotto",
    "edotti": "edotto",
    "educa": "educare",
    "educai": "educare",
    "educammo": "educare",
    "educan": "educare",
    "educande": "educanda",
    "educando": "educare",
    "educano": "educare",
    "educante": "educare",
    "educanti": "educare",
    "educar": "educare",
    "educaron": "educare",
    "educarono": "educare",
    "educasse": "educare",
    "educasser": "educare",
    "educassero": "educare",
    "educassi": "educare",
    "educassimo": "educare",
    "educaste": "educare",
    "educasti": "educare",
    "educata": "educare",
    "educate": "educare",
    "educati": "educare",
    "educativa": "educativo",
    "educative": "educativo",
    "educativi": "educativo",
    "educato": "educare",
    "educatori": "educatore",
    "educatrice": "educatore",
    "educatrici": "educatore",
    "educava": "educare",
    "educavamo": "educare",
    "educavan": "educare",
    "educavano": "educare",
    "educavate": "educare",
    "educavi": "educare",
    "educavo": "educare",
    "educazioni": "educazione",
    "educherai": "educare",
    "educheran": "educare",
    "educheranno": "educare",
    "educherebbe": "educare",
    "educherebber": "educare",
    "educherebbero": "educare",
    "educherei": "educare",
    "educheremmo": "educare",
    "educheremo": "educare",
    "educhereste": "educare",
    "educheresti": "educare",
    "educherete": "educare",
    "educherà": "educare",
    "educherò": "educare",
    "educhi": "educare",
    "educhiamo": "educare",
    "educhiate": "educare",
    "educhin": "educare",
    "educhino": "educare",
    "educo": "educare",
    "educò": "educare",
    "edulcora": "edulcorare",
    "edulcorai": "edulcorare",
    "edulcorammo": "edulcorare",
    "edulcoran": "edulcorare",
    "edulcorando": "edulcorare",
    "edulcorano": "edulcorare",
    "edulcorante": "edulcorare",
    "edulcoranti": "edulcorare",
    "edulcorar": "edulcorare",
    "edulcoraron": "edulcorare",
    "edulcorarono": "edulcorare",
    "edulcorasse": "edulcorare",
    "edulcorasser": "edulcorare",
    "edulcorassero": "edulcorare",
    "edulcorassi": "edulcorare",
    "edulcorassimo": "edulcorare",
    "edulcoraste": "edulcorare",
    "edulcorasti": "edulcorare",
    "edulcorata": "edulcorare",
    "edulcorate": "edulcorare",
    "edulcorati": "edulcorare",
    "edulcorato": "edulcorare",
    "edulcorava": "edulcorare",
    "edulcoravamo": "edulcorare",
    "edulcoravan": "edulcorare",
    "edulcoravano": "edulcorare",
    "edulcoravate": "edulcorare",
    "edulcoravi": "edulcorare",
    "edulcoravo": "edulcorare",
    "edulcorerai": "edulcorare",
    "edulcoreran": "edulcorare",
    "edulcoreranno": "edulcorare",
    "edulcorerebbe": "edulcorare",
    "edulcorerebber": "edulcorare",
    "edulcorerebbero": "edulcorare",
    "edulcorerei": "edulcorare",
    "edulcoreremmo": "edulcorare",
    "edulcoreremo": "edulcorare",
    "edulcorereste": "edulcorare",
    "edulcoreresti": "edulcorare",
    "edulcorerete": "edulcorare",
    "edulcorerà": "edulcorare",
    "edulcorerò": "edulcorare",
    "edulcori": "edulcorare",
    "edulcoriamo": "edulcorare",
    "edulcoriate": "edulcorare",
    "edulcorin": "edulcorare",
    "edulcorino": "edulcorare",
    "edulcoro": "edulcorare",
    "edulcorò": "edulcorare",
    "efebi": "efebo",
    "efebica": "efebico",
    "efebiche": "efebico",
    "efebici": "efebico",
    "effemina": "effeminare",
    "effeminai": "effeminare",
    "effeminammo": "effeminare",
    "effeminan": "effeminare",
    "effeminando": "effeminare",
    "effeminano": "effeminare",
    "effeminante": "effeminare",
    "effeminanti": "effeminare",
    "effeminar": "effeminare",
    "effeminaron": "effeminare",
    "effeminarono": "effeminare",
    "effeminasse": "effeminare",
    "effeminasser": "effeminare",
    "effeminassero": "effeminare",
    "effeminassi": "effeminare",
    "effeminassimo": "effeminare",
    "effeminaste": "effeminare",
    "effeminasti": "effeminare",
    "effeminata": "effeminato",
    "effeminate": "effeminato",
    "effeminati": "effeminato",
    "effeminato": "effeminare",
    "effeminava": "effeminare",
    "effeminavamo": "effeminare",
    "effeminavan": "effeminare",
    "effeminavano": "effeminare",
    "effeminavate": "effeminare",
    "effeminavi": "effeminare",
    "effeminavo": "effeminare",
    "effeminerai": "effeminare",
    "effemineran": "effeminare",
    "effemineranno": "effeminare",
    "effeminerebbe": "effeminare",
    "effeminerebber": "effeminare",
    "effeminerebbero": "effeminare",
    "effeminerei": "effeminare",
    "effemineremmo": "effeminare",
    "effemineremo": "effeminare",
    "effeminereste": "effeminare",
    "effemineresti": "effeminare",
    "effeminerete": "effeminare",
    "effeminerà": "effeminare",
    "effeminerò": "effeminare",
    "effemini": "effeminare",
    "effeminiamo": "effeminare",
    "effeminiate": "effeminare",
    "effeminin": "effeminare",
    "effeminino": "effeminare",
    "effemino": "effeminare",
    "effeminò": "effeminare",
    "effemmina": "effemminare",
    "effemminai": "effemminare",
    "effemminammo": "effemminare",
    "effemminan": "effemminare",
    "effemminando": "effemminare",
    "effemminano": "effemminare",
    "effemminante": "effemminare",
    "effemminanti": "effemminare",
    "effemminar": "effemminare",
    "effemminaron": "effemminare",
    "effemminarono": "effemminare",
    "effemminasse": "effemminare",
    "effemminasser": "effemminare",
    "effemminassero": "effemminare",
    "effemminassi": "effemminare",
    "effemminassimo": "effemminare",
    "effemminaste": "effemminare",
    "effemminasti": "effemminare",
    "effemminata": "effemminare",
    "effemminate": "effemminare",
    "effemminati": "effemminare",
    "effemminato": "effemminare",
    "effemminava": "effemminare",
    "effemminavamo": "effemminare",
    "effemminavan": "effemminare",
    "effemminavano": "effemminare",
    "effemminavate": "effemminare",
    "effemminavi": "effemminare",
    "effemminavo": "effemminare",
    "effemminerai": "effemminare",
    "effemmineran": "effemminare",
    "effemmineranno": "effemminare",
    "effemminerebbe": "effemminare",
    "effemminerebber": "effemminare",
    "effemminerebbero": "effemminare",
    "effemminerei": "effemminare",
    "effemmineremmo": "effemminare",
    "effemmineremo": "effemminare",
    "effemminereste": "effemminare",
    "effemmineresti": "effemminare",
    "effemminerete": "effemminare",
    "effemminerà": "effemminare",
    "effemminerò": "effemminare",
    "effemmini": "effemminare",
    "effemminiamo": "effemminare",
    "effemminiate": "effemminare",
    "effemminin": "effemminare",
    "effemminino": "effemminare",
    "effemmino": "effemminare",
    "effemminò": "effemminare",
    "efferata": "efferato",
    "efferate": "efferato",
    "efferatezze": "efferatezza",
    "efferati": "efferato",
    "effervescenti": "effervescente",
    "effervescenze": "effervescenza",
    "effettacci": "effettaccio",
    "effetti": "effetto",
    "effettiva": "effettivo",
    "effettive": "effettivo",
    "effettivi": "effettivo",
    "effettua": "effettuare",
    "effettuabili": "effettuabile",
    "effettuai": "effettuare",
    "effettuammo": "effettuare",
    "effettuan": "effettuare",
    "effettuando": "effettuare",
    "effettuano": "effettuare",
    "effettuante": "effettuare",
    "effettuanti": "effettuare",
    "effettuar": "effettuare",
    "effettuaron": "effettuare",
    "effettuarono": "effettuare",
    "effettuasse": "effettuare",
    "effettuasser": "effettuare",
    "effettuassero": "effettuare",
    "effettuassi": "effettuare",
    "effettuassimo": "effettuare",
    "effettuaste": "effettuare",
    "effettuasti": "effettuare",
    "effettuata": "effettuare",
    "effettuate": "effettuare",
    "effettuati": "effettuare",
    "effettuato": "effettuare",
    "effettuava": "effettuare",
    "effettuavamo": "effettuare",
    "effettuavan": "effettuare",
    "effettuavano": "effettuare",
    "effettuavate": "effettuare",
    "effettuavi": "effettuare",
    "effettuavo": "effettuare",
    "effettuerai": "effettuare",
    "effettueran": "effettuare",
    "effettueranno": "effettuare",
    "effettuerebbe": "effettuare",
    "effettuerebber": "effettuare",
    "effettuerebbero": "effettuare",
    "effettuerei": "effettuare",
    "effettueremmo": "effettuare",
    "effettueremo": "effettuare",
    "effettuereste": "effettuare",
    "effettueresti": "effettuare",
    "effettuerete": "effettuare",
    "effettuerà": "effettuare",
    "effettuerò": "effettuare",
    "effettui": "effettuare",
    "effettuiamo": "effettuare",
    "effettuiate": "effettuare",
    "effettuin": "effettuare",
    "effettuino": "effettuare",
    "effettuo": "effettuare",
    "effettuò": "effettuare",
    "efficaci": "efficace",
    "efficacie": "efficacia",
    "efficienti": "efficiente",
    "efficienze": "efficienza",
    "effigerai": "effigiare",
    "effigeran": "effigiare",
    "effigeranno": "effigiare",
    "effigerebbe": "effigiare",
    "effigerebber": "effigiare",
    "effigerebbero": "effigiare",
    "effigerei": "effigiare",
    "effigeremmo": "effigiare",
    "effigeremo": "effigiare",
    "effigereste": "effigiare",
    "effigeresti": "effigiare",
    "effigerete": "effigiare",
    "effigerà": "effigiare",
    "effigerò": "effigiare",
    "effigi": "effigie",
    "effigia": "effigiare",
    "effigiai": "effigiare",
    "effigiammo": "effigiare",
    "effigiamo": "effigiare",
    "effigian": "effigiare",
    "effigiando": "effigiare",
    "effigiano": "effigiare",
    "effigiante": "effigiare",
    "effigianti": "effigiare",
    "effigiar": "effigiare",
    "effigiaron": "effigiare",
    "effigiarono": "effigiare",
    "effigiasse": "effigiare",
    "effigiasser": "effigiare",
    "effigiassero": "effigiare",
    "effigiassi": "effigiare",
    "effigiassimo": "effigiare",
    "effigiaste": "effigiare",
    "effigiasti": "effigiare",
    "effigiata": "effigiare",
    "effigiate": "effigiare",
    "effigiati": "effigiare",
    "effigiato": "effigiare",
    "effigiava": "effigiare",
    "effigiavamo": "effigiare",
    "effigiavan": "effigiare",
    "effigiavano": "effigiare",
    "effigiavate": "effigiare",
    "effigiavi": "effigiare",
    "effigiavo": "effigiare",
    "effigin": "effigiare",
    "effigino": "effigiare",
    "effigio": "effigiare",
    "effigiò": "effigiare",
    "effimera": "effimero",
    "effimere": "effimero",
    "effimeri": "effimero",
    "effluvi": "effluvio",
    "effonda": "effondere",
    "effondan": "effondere",
    "effondano": "effondere",
    "effonde": "effondere",
    "effondemmo": "effondere",
    "effondendo": "effondere",
    "effondente": "effondere",
    "effondenti": "effondere",
    "effonder": "effondere",
    "effonderai": "effondere",
    "effonderan": "effondere",
    "effonderanno": "effondere",
    "effonderebbe": "effondere",
    "effonderebber": "effondere",
    "effonderebbero": "effondere",
    "effonderei": "effondere",
    "effonderemmo": "effondere",
    "effonderemo": "effondere",
    "effondereste": "effondere",
    "effonderesti": "effondere",
    "effonderete": "effondere",
    "effonderà": "effondere",
    "effonderò": "effondere",
    "effondesse": "effondere",
    "effondesser": "effondere",
    "effondessero": "effondere",
    "effondessi": "effondere",
    "effondessimo": "effondere",
    "effondeste": "effondere",
    "effondesti": "effondere",
    "effondete": "effondere",
    "effondeva": "effondere",
    "effondevamo": "effondere",
    "effondevan": "effondere",
    "effondevano": "effondere",
    "effondevate": "effondere",
    "effondevi": "effondere",
    "effondevo": "effondere",
    "effondi": "effondere",
    "effondiamo": "effondere",
    "effondiate": "effondere",
    "effondo": "effondere",
    "effondon": "effondere",
    "effondono": "effondere",
    "effrazioni": "effrazione",
    "effusa": "effondere",
    "effuse": "effondere",
    "effuser": "effondere",
    "effusero": "effondere",
    "effusi": "effondere",
    "effusioni": "effusione",
    "effuso": "effondere",
    "egalitari": "egalitario",
    "egalitaria": "egalitario",
    "egalitarie": "egalitario",
    "egemoni": "egemone",
    "egemonica": "egemonico",
    "egemoniche": "egemonico",
    "egemonici": "egemonico",
    "egemonie": "egemonia",
    "egemonizza": "egemonizzare",
    "egemonizzai": "egemonizzare",
    "egemonizzammo": "egemonizzare",
    "egemonizzan": "egemonizzare",
    "egemonizzando": "egemonizzare",
    "egemonizzano": "egemonizzare",
    "egemonizzante": "egemonizzare",
    "egemonizzanti": "egemonizzare",
    "egemonizzar": "egemonizzare",
    "egemonizzaron": "egemonizzare",
    "egemonizzarono": "egemonizzare",
    "egemonizzasse": "egemonizzare",
    "egemonizzasser": "egemonizzare",
    "egemonizzassero": "egemonizzare",
    "egemonizzassi": "egemonizzare",
    "egemonizzassimo": "egemonizzare",
    "egemonizzaste": "egemonizzare",
    "egemonizzasti": "egemonizzare",
    "egemonizzata": "egemonizzare",
    "egemonizzate": "egemonizzare",
    "egemonizzati": "egemonizzare",
    "egemonizzato": "egemonizzare",
    "egemonizzava": "egemonizzare",
    "egemonizzavamo": "egemonizzare",
    "egemonizzavan": "egemonizzare",
    "egemonizzavano": "egemonizzare",
    "egemonizzavate": "egemonizzare",
    "egemonizzavi": "egemonizzare",
    "egemonizzavo": "egemonizzare",
    "egemonizzerai": "egemonizzare",
    "egemonizzeran": "egemonizzare",
    "egemonizzeranno": "egemonizzare",
    "egemonizzerebbe": "egemonizzare",
    "egemonizzerebber": "egemonizzare",
    "egemonizzerebbero": "egemonizzare",
    "egemonizzerei": "egemonizzare",
    "egemonizzeremmo": "egemonizzare",
    "egemonizzeremo": "egemonizzare",
    "egemonizzereste": "egemonizzare",
    "egemonizzeresti": "egemonizzare",
    "egemonizzerete": "egemonizzare",
    "egemonizzerà": "egemonizzare",
    "egemonizzerò": "egemonizzare",
    "egemonizzi": "egemonizzare",
    "egemonizziamo": "egemonizzare",
    "egemonizziate": "egemonizzare",
    "egemonizzin": "egemonizzare",
    "egemonizzino": "egemonizzare",
    "egemonizzo": "egemonizzare",
    "egemonizzò": "egemonizzare",
    "egittologi": "egittologo",
    "egizi": "egizio",
    "egizia": "egizio",
    "egiziana": "egiziano",
    "egiziane": "egiziano",
    "egiziani": "egiziano",
    "egizie": "egizio",
    "egocentrica": "egocentrico",
    "egocentriche": "egocentrico",
    "egocentrici": "egocentrico",
    "egoismi": "egoismo",
    "egoiste": "egoista",
    "egoisti": "egoista",
    "egoistica": "egoistico",
    "egoistiche": "egoistico",
    "egoistici": "egoistico",
    "egra": "egro",
    "egre": "egro",
    "egregi": "egregio",
    "egregia": "egregio",
    "egregie": "egregio",
    "egri": "egro",
    "eguagli": "eguagliare",
    "eguaglia": "eguagliare",
    "eguagliai": "eguagliare",
    "eguagliammo": "eguagliare",
    "eguagliamo": "eguagliare",
    "eguaglian": "eguagliare",
    "eguagliando": "eguagliare",
    "eguagliano": "eguagliare",
    "eguagliante": "eguagliare",
    "eguaglianti": "eguagliare",
    "eguaglianze": "eguaglianza",
    "eguagliar": "eguagliare",
    "eguagliaron": "eguagliare",
    "eguagliarono": "eguagliare",
    "eguagliasse": "eguagliare",
    "eguagliasser": "eguagliare",
    "eguagliassero": "eguagliare",
    "eguagliassi": "eguagliare",
    "eguagliassimo": "eguagliare",
    "eguagliaste": "eguagliare",
    "eguagliasti": "eguagliare",
    "eguagliata": "eguagliare",
    "eguagliate": "eguagliare",
    "eguagliati": "eguagliare",
    "eguagliato": "eguagliare",
    "eguagliava": "eguagliare",
    "eguagliavamo": "eguagliare",
    "eguagliavan": "eguagliare",
    "eguagliavano": "eguagliare",
    "eguagliavate": "eguagliare",
    "eguagliavi": "eguagliare",
    "eguagliavo": "eguagliare",
    "eguaglierai": "eguagliare",
    "eguaglieran": "eguagliare",
    "eguaglieranno": "eguagliare",
    "eguaglierebbe": "eguagliare",
    "eguaglierebber": "eguagliare",
    "eguaglierebbero": "eguagliare",
    "eguaglierei": "eguagliare",
    "eguaglieremmo": "eguagliare",
    "eguaglieremo": "eguagliare",
    "eguagliereste": "eguagliare",
    "eguaglieresti": "eguagliare",
    "eguaglierete": "eguagliare",
    "eguaglierà": "eguagliare",
    "eguaglierò": "eguagliare",
    "eguaglin": "eguagliare",
    "eguaglino": "eguagliare",
    "eguaglio": "eguagliare",
    "eguagliò": "eguagliare",
    "eguali": "eguale",
    "egualitari": "egualitario",
    "egualitaria": "egualitario",
    "egualitarie": "egualitario",
    "eiaculazioni": "eiaculazione",
    "einaudiana": "einaudiano",
    "einaudiane": "einaudiano",
    "einaudiani": "einaudiano",
    "elabora": "elaborare",
    "elaborai": "elaborare",
    "elaborammo": "elaborare",
    "elaboran": "elaborare",
    "elaborando": "elaborare",
    "elaborano": "elaborare",
    "elaborante": "elaborare",
    "elaboranti": "elaborare",
    "elaborar": "elaborare",
    "elaboraron": "elaborare",
    "elaborarono": "elaborare",
    "elaborasse": "elaborare",
    "elaborasser": "elaborare",
    "elaborassero": "elaborare",
    "elaborassi": "elaborare",
    "elaborassimo": "elaborare",
    "elaboraste": "elaborare",
    "elaborasti": "elaborare",
    "elaborata": "elaborato",
    "elaborate": "elaborato",
    "elaborati": "elaborato",
    "elaborato": "elaborare",
    "elaboratori": "elaboratore",
    "elaboratrice": "elaboratore",
    "elaboratrici": "elaboratore",
    "elaborava": "elaborare",
    "elaboravamo": "elaborare",
    "elaboravan": "elaborare",
    "elaboravano": "elaborare",
    "elaboravate": "elaborare",
    "elaboravi": "elaborare",
    "elaboravo": "elaborare",
    "elaborazioni": "elaborazione",
    "elaborerai": "elaborare",
    "elaboreran": "elaborare",
    "elaboreranno": "elaborare",
    "elaborerebbe": "elaborare",
    "elaborerebber": "elaborare",
    "elaborerebbero": "elaborare",
    "elaborerei": "elaborare",
    "elaboreremmo": "elaborare",
    "elaboreremo": "elaborare",
    "elaborereste": "elaborare",
    "elaboreresti": "elaborare",
    "elaborerete": "elaborare",
    "elaborerà": "elaborare",
    "elaborerò": "elaborare",
    "elabori": "elaborare",
    "elaboriamo": "elaborare",
    "elaboriate": "elaborare",
    "elaborin": "elaborare",
    "elaborino": "elaborare",
    "elaboro": "elaborare",
    "elaborò": "elaborare",
    "elargendo": "elargire",
    "elargente": "elargire",
    "elargenti": "elargire",
    "elargiamo": "elargire",
    "elargiate": "elargire",
    "elargii": "elargire",
    "elargimmo": "elargire",
    "elargir": "elargire",
    "elargirai": "elargire",
    "elargiran": "elargire",
    "elargiranno": "elargire",
    "elargirebbe": "elargire",
    "elargirebber": "elargire",
    "elargirebbero": "elargire",
    "elargirei": "elargire",
    "elargiremmo": "elargire",
    "elargiremo": "elargire",
    "elargireste": "elargire",
    "elargiresti": "elargire",
    "elargirete": "elargire",
    "elargiron": "elargire",
    "elargirono": "elargire",
    "elargirà": "elargire",
    "elargirò": "elargire",
    "elargisca": "elargire",
    "elargiscan": "elargire",
    "elargiscano": "elargire",
    "elargisce": "elargire",
    "elargisci": "elargire",
    "elargisco": "elargire",
    "elargiscon": "elargire",
    "elargiscono": "elargire",
    "elargisse": "elargire",
    "elargisser": "elargire",
    "elargissero": "elargire",
    "elargissi": "elargire",
    "elargissimo": "elargire",
    "elargiste": "elargire",
    "elargisti": "elargire",
    "elargita": "elargire",
    "elargite": "elargire",
    "elargiti": "elargire",
    "elargito": "elargire",
    "elargiva": "elargire",
    "elargivamo": "elargire",
    "elargivan": "elargire",
    "elargivano": "elargire",
    "elargivate": "elargire",
    "elargivi": "elargire",
    "elargivo": "elargire",
    "elargizioni": "elargizione",
    "elargì": "elargire",
    "elastica": "elastico",
    "elastiche": "elastico",
    "elastici": "elastico",
    "elasticizzata": "elasticizzato",
    "elasticizzate": "elasticizzato",
    "elasticizzati": "elasticizzato",
    "elbana": "elbano",
    "elbane": "elbano",
    "elbani": "elbano",
    "elefanti": "elefante",
    "elefantiaca": "elefantiaco",
    "elefantiache": "elefantiaco",
    "elefantiaci": "elefantiaco",
    "elefantini": "elefantino",
    "eleganti": "elegante",
    "elegantoni": "elegantone",
    "eleganze": "eleganza",
    "elegga": "eleggere",
    "eleggan": "eleggere",
    "eleggano": "eleggere",
    "elegge": "eleggere",
    "eleggemmo": "eleggere",
    "eleggendo": "eleggere",
    "eleggente": "eleggere",
    "eleggenti": "eleggere",
    "elegger": "eleggere",
    "eleggerai": "eleggere",
    "eleggeran": "eleggere",
    "eleggeranno": "eleggere",
    "eleggerebbe": "eleggere",
    "eleggerebber": "eleggere",
    "eleggerebbero": "eleggere",
    "eleggerei": "eleggere",
    "eleggeremmo": "eleggere",
    "eleggeremo": "eleggere",
    "eleggereste": "eleggere",
    "eleggeresti": "eleggere",
    "eleggerete": "eleggere",
    "eleggerà": "eleggere",
    "eleggerò": "eleggere",
    "eleggesse": "eleggere",
    "eleggesser": "eleggere",
    "eleggessero": "eleggere",
    "eleggessi": "eleggere",
    "eleggessimo": "eleggere",
    "eleggeste": "eleggere",
    "eleggesti": "eleggere",
    "eleggete": "eleggere",
    "eleggeva": "eleggere",
    "eleggevamo": "eleggere",
    "eleggevan": "eleggere",
    "eleggevano": "eleggere",
    "eleggevate": "eleggere",
    "eleggevi": "eleggere",
    "eleggevo": "eleggere",
    "eleggi": "eleggere",
    "eleggiamo": "eleggere",
    "eleggiate": "eleggere",
    "eleggibili": "eleggibile",
    "eleggo": "eleggere",
    "eleggon": "eleggere",
    "eleggono": "eleggere",
    "elegiaca": "elegiaco",
    "elegiache": "elegiaco",
    "elegiaci": "elegiaco",
    "elegie": "elegia",
    "elementari": "elementare",
    "elementi": "elemento",
    "elemosina": "elemosinare",
    "elemosinai": "elemosinare",
    "elemosinammo": "elemosinare",
    "elemosinan": "elemosinare",
    "elemosinando": "elemosinare",
    "elemosinano": "elemosinare",
    "elemosinante": "elemosinare",
    "elemosinanti": "elemosinare",
    "elemosinar": "elemosinare",
    "elemosinaron": "elemosinare",
    "elemosinarono": "elemosinare",
    "elemosinasse": "elemosinare",
    "elemosinasser": "elemosinare",
    "elemosinassero": "elemosinare",
    "elemosinassi": "elemosinare",
    "elemosinassimo": "elemosinare",
    "elemosinaste": "elemosinare",
    "elemosinasti": "elemosinare",
    "elemosinata": "elemosinare",
    "elemosinate": "elemosinare",
    "elemosinati": "elemosinare",
    "elemosinato": "elemosinare",
    "elemosinava": "elemosinare",
    "elemosinavamo": "elemosinare",
    "elemosinavan": "elemosinare",
    "elemosinavano": "elemosinare",
    "elemosinavate": "elemosinare",
    "elemosinavi": "elemosinare",
    "elemosinavo": "elemosinare",
    "elemosine": "elemosina",
    "elemosinerai": "elemosinare",
    "elemosineran": "elemosinare",
    "elemosineranno": "elemosinare",
    "elemosinerebbe": "elemosinare",
    "elemosinerebber": "elemosinare",
    "elemosinerebbero": "elemosinare",
    "elemosinerei": "elemosinare",
    "elemosineremmo": "elemosinare",
    "elemosineremo": "elemosinare",
    "elemosinereste": "elemosinare",
    "elemosineresti": "elemosinare",
    "elemosinerete": "elemosinare",
    "elemosinerà": "elemosinare",
    "elemosinerò": "elemosinare",
    "elemosini": "elemosinare",
    "elemosiniamo": "elemosinare",
    "elemosiniate": "elemosinare",
    "elemosinieri": "elemosiniere",
    "elemosinin": "elemosinare",
    "elemosinino": "elemosinare",
    "elemosino": "elemosinare",
    "elemosinò": "elemosinare",
    "elenca": "elencare",
    "elencai": "elencare",
    "elencammo": "elencare",
    "elencan": "elencare",
    "elencando": "elencare",
    "elencano": "elencare",
    "elencante": "elencare",
    "elencanti": "elencare",
    "elencar": "elencare",
    "elencaron": "elencare",
    "elencarono": "elencare",
    "elencasse": "elencare",
    "elencasser": "elencare",
    "elencassero": "elencare",
    "elencassi": "elencare",
    "elencassimo": "elencare",
    "elencaste": "elencare",
    "elencasti": "elencare",
    "elencata": "elencare",
    "elencate": "elencare",
    "elencati": "elencare",
    "elencato": "elencare",
    "elencava": "elencare",
    "elencavamo": "elencare",
    "elencavan": "elencare",
    "elencavano": "elencare",
    "elencavate": "elencare",
    "elencavi": "elencare",
    "elencavo": "elencare",
    "elencazioni": "elencazione",
    "elencherai": "elencare",
    "elencheran": "elencare",
    "elencheranno": "elencare",
    "elencherebbe": "elencare",
    "elencherebber": "elencare",
    "elencherebbero": "elencare",
    "elencherei": "elencare",
    "elencheremmo": "elencare",
    "elencheremo": "elencare",
    "elenchereste": "elencare",
    "elencheresti": "elencare",
    "elencherete": "elencare",
    "elencherà": "elencare",
    "elencherò": "elencare",
    "elenchi": "elenco",
    "elenchiamo": "elencare",
    "elenchiate": "elencare",
    "elenchin": "elencare",
    "elenchino": "elencare",
    "elenco": "elencare",
    "elencò": "elencare",
    "elesse": "eleggere",
    "elesser": "eleggere",
    "elessero": "eleggere",
    "elessi": "eleggere",
    "eletta": "eletto",
    "elette": "eletto",
    "eletti": "eletto",
    "elettiva": "elettivo",
    "elettive": "elettivo",
    "elettivi": "elettivo",
    "eletto": "eleggere",
    "elettorali": "elettorale",
    "elettoralistica": "elettoralistico",
    "elettoralistiche": "elettoralistico",
    "elettoralistici": "elettoralistico",
    "elettorati": "elettorato",
    "elettori": "elettore",
    "elettrica": "elettrico",
    "elettriche": "elettrico",
    "elettrici": "elettrico",
    "elettricisti": "elettricista",
    "elettrifica": "elettrificare",
    "elettrificai": "elettrificare",
    "elettrificammo": "elettrificare",
    "elettrifican": "elettrificare",
    "elettrificando": "elettrificare",
    "elettrificano": "elettrificare",
    "elettrificante": "elettrificare",
    "elettrificanti": "elettrificare",
    "elettrificar": "elettrificare",
    "elettrificaron": "elettrificare",
    "elettrificarono": "elettrificare",
    "elettrificasse": "elettrificare",
    "elettrificasser": "elettrificare",
    "elettrificassero": "elettrificare",
    "elettrificassi": "elettrificare",
    "elettrificassimo": "elettrificare",
    "elettrificaste": "elettrificare",
    "elettrificasti": "elettrificare",
    "elettrificata": "elettrificare",
    "elettrificate": "elettrificare",
    "elettrificati": "elettrificare",
    "elettrificato": "elettrificare",
    "elettrificava": "elettrificare",
    "elettrificavamo": "elettrificare",
    "elettrificavan": "elettrificare",
    "elettrificavano": "elettrificare",
    "elettrificavate": "elettrificare",
    "elettrificavi": "elettrificare",
    "elettrificavo": "elettrificare",
    "elettrificherai": "elettrificare",
    "elettrificheran": "elettrificare",
    "elettrificheranno": "elettrificare",
    "elettrificherebbe": "elettrificare",
    "elettrificherebber": "elettrificare",
    "elettrificherebbero": "elettrificare",
    "elettrificherei": "elettrificare",
    "elettrificheremmo": "elettrificare",
    "elettrificheremo": "elettrificare",
    "elettrifichereste": "elettrificare",
    "elettrificheresti": "elettrificare",
    "elettrificherete": "elettrificare",
    "elettrificherà": "elettrificare",
    "elettrificherò": "elettrificare",
    "elettrifichi": "elettrificare",
    "elettrifichiamo": "elettrificare",
    "elettrifichiate": "elettrificare",
    "elettrifichin": "elettrificare",
    "elettrifichino": "elettrificare",
    "elettrifico": "elettrificare",
    "elettrificò": "elettrificare",
    "elettrizza": "elettrizzare",
    "elettrizzai": "elettrizzare",
    "elettrizzammo": "elettrizzare",
    "elettrizzan": "elettrizzare",
    "elettrizzando": "elettrizzare",
    "elettrizzano": "elettrizzare",
    "elettrizzante": "elettrizzare",
    "elettrizzanti": "elettrizzare",
    "elettrizzar": "elettrizzare",
    "elettrizzaron": "elettrizzare",
    "elettrizzarono": "elettrizzare",
    "elettrizzasse": "elettrizzare",
    "elettrizzasser": "elettrizzare",
    "elettrizzassero": "elettrizzare",
    "elettrizzassi": "elettrizzare",
    "elettrizzassimo": "elettrizzare",
    "elettrizzaste": "elettrizzare",
    "elettrizzasti": "elettrizzare",
    "elettrizzata": "elettrizzare",
    "elettrizzate": "elettrizzare",
    "elettrizzati": "elettrizzare",
    "elettrizzato": "elettrizzare",
    "elettrizzava": "elettrizzare",
    "elettrizzavamo": "elettrizzare",
    "elettrizzavan": "elettrizzare",
    "elettrizzavano": "elettrizzare",
    "elettrizzavate": "elettrizzare",
    "elettrizzavi": "elettrizzare",
    "elettrizzavo": "elettrizzare",
    "elettrizzerai": "elettrizzare",
    "elettrizzeran": "elettrizzare",
    "elettrizzeranno": "elettrizzare",
    "elettrizzerebbe": "elettrizzare",
    "elettrizzerebber": "elettrizzare",
    "elettrizzerebbero": "elettrizzare",
    "elettrizzerei": "elettrizzare",
    "elettrizzeremmo": "elettrizzare",
    "elettrizzeremo": "elettrizzare",
    "elettrizzereste": "elettrizzare",
    "elettrizzeresti": "elettrizzare",
    "elettrizzerete": "elettrizzare",
    "elettrizzerà": "elettrizzare",
    "elettrizzerò": "elettrizzare",
    "elettrizzi": "elettrizzare",
    "elettrizziamo": "elettrizzare",
    "elettrizziate": "elettrizzare",
    "elettrizzin": "elettrizzare",
    "elettrizzino": "elettrizzare",
    "elettrizzo": "elettrizzare",
    "elettrizzò": "elettrizzare",
    "elettroacustica": "elettroacustico",
    "elettroacustiche": "elettroacustico",
    "elettroacustici": "elettroacustico",
    "elettrocardiogrammi": "elettrocardiogramma",
    "elettrodi": "elettrodo",
    "elettrodinamica": "elettrodinamico",
    "elettrodinamiche": "elettrodinamico",
    "elettrodinamici": "elettrodinamico",
    "elettrodomestica": "elettrodomestico",
    "elettrodomestiche": "elettrodomestico",
    "elettrodomestici": "elettrodomestico",
    "elettrodotti": "elettrodotto",
    "elettrogena": "elettrogeno",
    "elettrogene": "elettrogeno",
    "elettrogeni": "elettrogeno",
    "elettrolitica": "elettrolitico",
    "elettrolitiche": "elettrolitico",
    "elettrolitici": "elettrolitico",
    "elettromagnetica": "elettromagnetico",
    "elettromagnetiche": "elettromagnetico",
    "elettromagnetici": "elettromagnetico",
    "elettromeccanica": "elettromeccanico",
    "elettromeccaniche": "elettromeccanico",
    "elettromeccanici": "elettromeccanico",
    "elettroni": "elettrone",
    "elettronica": "elettronico",
    "elettroniche": "elettronico",
    "elettronici": "elettronico",
    "elettrostatica": "elettrostatico",
    "elettrostatiche": "elettrostatico",
    "elettrostatici": "elettrostatico",
    "elettrotecnica": "elettrotecnico",
    "elettrotecniche": "elettrotecnico",
    "elettrotecnici": "elettrotecnico",
    "eleva": "elevare",
    "elevabili": "elevabile",
    "elevai": "elevare",
    "elevammo": "elevare",
    "elevan": "elevare",
    "elevando": "elevare",
    "elevano": "elevare",
    "elevante": "elevare",
    "elevanti": "elevare",
    "elevar": "elevare",
    "elevaron": "elevare",
    "elevarono": "elevare",
    "elevasse": "elevare",
    "elevasser": "elevare",
    "elevassero": "elevare",
    "elevassi": "elevare",
    "elevassimo": "elevare",
    "elevaste": "elevare",
    "elevasti": "elevare",
    "elevata": "elevato",
    "elevate": "elevato",
    "elevati": "elevato",
    "elevato": "elevare",
    "elevatori": "elevatore",
    "elevatrice": "elevatore",
    "elevatrici": "elevatore",
    "elevava": "elevare",
    "elevavamo": "elevare",
    "elevavan": "elevare",
    "elevavano": "elevare",
    "elevavate": "elevare",
    "elevavi": "elevare",
    "elevavo": "elevare",
    "elevazioni": "elevazione",
    "eleverai": "elevare",
    "eleveran": "elevare",
    "eleveranno": "elevare",
    "eleverebbe": "elevare",
    "eleverebber": "elevare",
    "eleverebbero": "elevare",
    "eleverei": "elevare",
    "eleveremmo": "elevare",
    "eleveremo": "elevare",
    "elevereste": "elevare",
    "eleveresti": "elevare",
    "eleverete": "elevare",
    "eleverà": "elevare",
    "eleverò": "elevare",
    "elevi": "elevare",
    "eleviamo": "elevare",
    "eleviate": "elevare",
    "elevin": "elevare",
    "elevino": "elevare",
    "elevo": "elevare",
    "elevò": "elevare",
    "elezioni": "elezione",
    "elfi": "elfo",
    "eliche": "elica",
    "elicoidali": "elicoidale",
    "elicotteri": "elicottero",
    "elicotteristi": "elicotterista",
    "elicotteristica": "elicotteristico",
    "elicotteristiche": "elicotteristico",
    "elicotteristici": "elicotteristico",
    "elida": "elidere",
    "elidan": "elidere",
    "elidano": "elidere",
    "elide": "elidere",
    "elidei": "elidere",
    "elidemmo": "elidere",
    "elidendo": "elidere",
    "elidente": "elidere",
    "elidenti": "elidere",
    "elider": "elidere",
    "eliderai": "elidere",
    "elideran": "elidere",
    "elideranno": "elidere",
    "eliderebbe": "elidere",
    "eliderebber": "elidere",
    "eliderebbero": "elidere",
    "eliderei": "elidere",
    "elideremmo": "elidere",
    "elideremo": "elidere",
    "elidereste": "elidere",
    "elideresti": "elidere",
    "eliderete": "elidere",
    "elideron": "elidere",
    "eliderono": "elidere",
    "eliderà": "elidere",
    "eliderò": "elidere",
    "elidesse": "elidere",
    "elidesser": "elidere",
    "elidessero": "elidere",
    "elidessi": "elidere",
    "elidessimo": "elidere",
    "elideste": "elidere",
    "elidesti": "elidere",
    "elidete": "elidere",
    "elideva": "elidere",
    "elidevamo": "elidere",
    "elidevan": "elidere",
    "elidevano": "elidere",
    "elidevate": "elidere",
    "elidevi": "elidere",
    "elidevo": "elidere",
    "elidi": "elidere",
    "elidiamo": "elidere",
    "elidiate": "elidere",
    "elido": "elidere",
    "elidon": "elidere",
    "elidono": "elidere",
    "eliduta": "elidere",
    "elidute": "elidere",
    "eliduti": "elidere",
    "eliduto": "elidere",
    "elidè": "elidere",
    "elimina": "eliminare",
    "eliminai": "eliminare",
    "eliminammo": "eliminare",
    "eliminan": "eliminare",
    "eliminando": "eliminare",
    "eliminano": "eliminare",
    "eliminante": "eliminare",
    "eliminanti": "eliminare",
    "eliminar": "eliminare",
    "eliminaron": "eliminare",
    "eliminarono": "eliminare",
    "eliminasse": "eliminare",
    "eliminasser": "eliminare",
    "eliminassero": "eliminare",
    "eliminassi": "eliminare",
    "eliminassimo": "eliminare",
    "eliminaste": "eliminare",
    "eliminasti": "eliminare",
    "eliminata": "eliminare",
    "eliminate": "eliminare",
    "eliminati": "eliminare",
    "eliminato": "eliminare",
    "eliminatori": "eliminatorio",
    "eliminatoria": "eliminatorio",
    "eliminatorie": "eliminatorio",
    "eliminatrice": "eliminatore",
    "eliminatrici": "eliminatore",
    "eliminava": "eliminare",
    "eliminavamo": "eliminare",
    "eliminavan": "eliminare",
    "eliminavano": "eliminare",
    "eliminavate": "eliminare",
    "eliminavi": "eliminare",
    "eliminavo": "eliminare",
    "eliminazioni": "eliminazione",
    "eliminerai": "eliminare",
    "elimineran": "eliminare",
    "elimineranno": "eliminare",
    "eliminerebbe": "eliminare",
    "eliminerebber": "eliminare",
    "eliminerebbero": "eliminare",
    "eliminerei": "eliminare",
    "elimineremmo": "eliminare",
    "elimineremo": "eliminare",
    "eliminereste": "eliminare",
    "elimineresti": "eliminare",
    "eliminerete": "eliminare",
    "eliminerà": "eliminare",
    "eliminerò": "eliminare",
    "elimini": "eliminare",
    "eliminiamo": "eliminare",
    "eliminiate": "eliminare",
    "eliminin": "eliminare",
    "eliminino": "eliminare",
    "elimino": "eliminare",
    "eliminò": "eliminare",
    "elisa": "eliso",
    "elisabettiana": "elisabettiano",
    "elisabettiane": "elisabettiano",
    "elisabettiani": "elisabettiano",
    "elise": "eliso",
    "elisi": "eliso",
    "elisia": "elisio",
    "elisie": "elisio",
    "elitari": "elitario",
    "elitaria": "elitario",
    "elitarie": "elitario",
    "ellenica": "ellenico",
    "elleniche": "ellenico",
    "ellenici": "ellenico",
    "ellenistica": "ellenistico",
    "ellenistiche": "ellenistico",
    "ellenistici": "ellenistico",
    "ellissi": "ellisse",
    "ellissoidali": "ellissoidale",
    "ellittica": "ellittico",
    "ellittiche": "ellittico",
    "ellittici": "ellittico",
    "elmetti": "elmetto",
    "elmi": "elmo",
    "elogerai": "elogiare",
    "elogeran": "elogiare",
    "elogeranno": "elogiare",
    "elogerebbe": "elogiare",
    "elogerebber": "elogiare",
    "elogerebbero": "elogiare",
    "elogerei": "elogiare",
    "elogeremmo": "elogiare",
    "elogeremo": "elogiare",
    "elogereste": "elogiare",
    "elogeresti": "elogiare",
    "elogerete": "elogiare",
    "elogerà": "elogiare",
    "elogerò": "elogiare",
    "elogi": "elogio",
    "elogia": "elogiare",
    "elogiai": "elogiare",
    "elogiammo": "elogiare",
    "elogiamo": "elogiare",
    "elogian": "elogiare",
    "elogiando": "elogiare",
    "elogiano": "elogiare",
    "elogiante": "elogiare",
    "elogianti": "elogiare",
    "elogiar": "elogiare",
    "elogiaron": "elogiare",
    "elogiarono": "elogiare",
    "elogiasse": "elogiare",
    "elogiasser": "elogiare",
    "elogiassero": "elogiare",
    "elogiassi": "elogiare",
    "elogiassimo": "elogiare",
    "elogiaste": "elogiare",
    "elogiasti": "elogiare",
    "elogiata": "elogiare",
    "elogiate": "elogiare",
    "elogiati": "elogiare",
    "elogiativa": "elogiativo",
    "elogiative": "elogiativo",
    "elogiativi": "elogiativo",
    "elogiato": "elogiare",
    "elogiava": "elogiare",
    "elogiavamo": "elogiare",
    "elogiavan": "elogiare",
    "elogiavano": "elogiare",
    "elogiavate": "elogiare",
    "elogiavi": "elogiare",
    "elogiavo": "elogiare",
    "elogin": "elogiare",
    "elogino": "elogiare",
    "elogio": "elogiare",
    "elogiò": "elogiare",
    "eloquenti": "eloquente",
    "eloquenze": "eloquenza",
    "eloqui": "eloquio",
    "eltsiniana": "eltsiniano",
    "eltsiniane": "eltsiniano",
    "eltsiniani": "eltsiniano",
    "elucubra": "elucubrare",
    "elucubrai": "elucubrare",
    "elucubrammo": "elucubrare",
    "elucubran": "elucubrare",
    "elucubrando": "elucubrare",
    "elucubrano": "elucubrare",
    "elucubrante": "elucubrare",
    "elucubranti": "elucubrare",
    "elucubrar": "elucubrare",
    "elucubraron": "elucubrare",
    "elucubrarono": "elucubrare",
    "elucubrasse": "elucubrare",
    "elucubrasser": "elucubrare",
    "elucubrassero": "elucubrare",
    "elucubrassi": "elucubrare",
    "elucubrassimo": "elucubrare",
    "elucubraste": "elucubrare",
    "elucubrasti": "elucubrare",
    "elucubrata": "elucubrare",
    "elucubrate": "elucubrare",
    "elucubrati": "elucubrare",
    "elucubrato": "elucubrare",
    "elucubrava": "elucubrare",
    "elucubravamo": "elucubrare",
    "elucubravan": "elucubrare",
    "elucubravano": "elucubrare",
    "elucubravate": "elucubrare",
    "elucubravi": "elucubrare",
    "elucubravo": "elucubrare",
    "elucubrazioni": "elucubrazione",
    "elucubrerai": "elucubrare",
    "elucubreran": "elucubrare",
    "elucubreranno": "elucubrare",
    "elucubrerebbe": "elucubrare",
    "elucubrerebber": "elucubrare",
    "elucubrerebbero": "elucubrare",
    "elucubrerei": "elucubrare",
    "elucubreremmo": "elucubrare",
    "elucubreremo": "elucubrare",
    "elucubrereste": "elucubrare",
    "elucubreresti": "elucubrare",
    "elucubrerete": "elucubrare",
    "elucubrerà": "elucubrare",
    "elucubrerò": "elucubrare",
    "elucubri": "elucubrare",
    "elucubriamo": "elucubrare",
    "elucubriate": "elucubrare",
    "elucubrin": "elucubrare",
    "elucubrino": "elucubrare",
    "elucubro": "elucubrare",
    "elucubrò": "elucubrare",
    "eluda": "eludere",
    "eludan": "eludere",
    "eludano": "eludere",
    "elude": "eludere",
    "eludemmo": "eludere",
    "eludendo": "eludere",
    "eludente": "eludere",
    "eludenti": "eludere",
    "eluder": "eludere",
    "eluderai": "eludere",
    "eluderan": "eludere",
    "eluderanno": "eludere",
    "eluderebbe": "eludere",
    "eluderebber": "eludere",
    "eluderebbero": "eludere",
    "eluderei": "eludere",
    "eluderemmo": "eludere",
    "eluderemo": "eludere",
    "eludereste": "eludere",
    "eluderesti": "eludere",
    "eluderete": "eludere",
    "eluderà": "eludere",
    "eluderò": "eludere",
    "eludesse": "eludere",
    "eludesser": "eludere",
    "eludessero": "eludere",
    "eludessi": "eludere",
    "eludessimo": "eludere",
    "eludeste": "eludere",
    "eludesti": "eludere",
    "eludete": "eludere",
    "eludeva": "eludere",
    "eludevamo": "eludere",
    "eludevan": "eludere",
    "eludevano": "eludere",
    "eludevate": "eludere",
    "eludevi": "eludere",
    "eludevo": "eludere",
    "eludi": "eludere",
    "eludiamo": "eludere",
    "eludiate": "eludere",
    "eludo": "eludere",
    "eludon": "eludere",
    "eludono": "eludere",
    "elusa": "eludere",
    "eluse": "eludere",
    "eluser": "eludere",
    "elusero": "eludere",
    "elusi": "eludere",
    "elusioni": "elusione",
    "elusiva": "elusivo",
    "elusive": "elusivo",
    "elusivi": "elusivo",
    "eluso": "eludere",
    "elvetica": "elvetico",
    "elvetiche": "elvetico",
    "elvetici": "elvetico",
    "elzevira": "elzeviro",
    "elzevire": "elzeviro",
    "elzeviri": "elzeviro",
    "emacerai": "emaciare",
    "emaceran": "emaciare",
    "emaceranno": "emaciare",
    "emacerebbe": "emaciare",
    "emacerebber": "emaciare",
    "emacerebbero": "emaciare",
    "emacerei": "emaciare",
    "emaceremmo": "emaciare",
    "emaceremo": "emaciare",
    "emacereste": "emaciare",
    "emaceresti": "emaciare",
    "emacerete": "emaciare",
    "emacerà": "emaciare",
    "emacerò": "emaciare",
    "emaci": "emaciare",
    "emacia": "emaciare",
    "emaciai": "emaciare",
    "emaciammo": "emaciare",
    "emaciamo": "emaciare",
    "emacian": "emaciare",
    "emaciando": "emaciare",
    "emaciano": "emaciare",
    "emaciante": "emaciare",
    "emacianti": "emaciare",
    "emaciar": "emaciare",
    "emaciaron": "emaciare",
    "emaciarono": "emaciare",
    "emaciasse": "emaciare",
    "emaciasser": "emaciare",
    "emaciassero": "emaciare",
    "emaciassi": "emaciare",
    "emaciassimo": "emaciare",
    "emaciaste": "emaciare",
    "emaciasti": "emaciare",
    "emaciata": "emaciato",
    "emaciate": "emaciato",
    "emaciati": "emaciato",
    "emaciato": "emaciare",
    "emaciava": "emaciare",
    "emaciavamo": "emaciare",
    "emaciavan": "emaciare",
    "emaciavano": "emaciare",
    "emaciavate": "emaciare",
    "emaciavi": "emaciare",
    "emaciavo": "emaciare",
    "emacin": "emaciare",
    "emacino": "emaciare",
    "emacio": "emaciare",
    "emaciò": "emaciare",
    "emana": "emanare",
    "emanai": "emanare",
    "emanammo": "emanare",
    "emanan": "emanare",
    "emanando": "emanare",
    "emanano": "emanare",
    "emanante": "emanare",
    "emananti": "emanare",
    "emanar": "emanare",
    "emanaron": "emanare",
    "emanarono": "emanare",
    "emanasse": "emanare",
    "emanasser": "emanare",
    "emanassero": "emanare",
    "emanassi": "emanare",
    "emanassimo": "emanare",
    "emanaste": "emanare",
    "emanasti": "emanare",
    "emanata": "emanare",
    "emanate": "emanare",
    "emanati": "emanare",
    "emanato": "emanare",
    "emanava": "emanare",
    "emanavamo": "emanare",
    "emanavan": "emanare",
    "emanavano": "emanare",
    "emanavate": "emanare",
    "emanavi": "emanare",
    "emanavo": "emanare",
    "emanazioni": "emanazione",
    "emancipa": "emancipare",
    "emancipai": "emancipare",
    "emancipammo": "emancipare",
    "emancipan": "emancipare",
    "emancipando": "emancipare",
    "emancipano": "emancipare",
    "emancipante": "emancipare",
    "emancipanti": "emancipare",
    "emancipar": "emancipare",
    "emanciparon": "emancipare",
    "emanciparono": "emancipare",
    "emancipasse": "emancipare",
    "emancipasser": "emancipare",
    "emancipassero": "emancipare",
    "emancipassi": "emancipare",
    "emancipassimo": "emancipare",
    "emancipaste": "emancipare",
    "emancipasti": "emancipare",
    "emancipata": "emancipato",
    "emancipate": "emancipato",
    "emancipati": "emancipato",
    "emancipato": "emancipare",
    "emancipava": "emancipare",
    "emancipavamo": "emancipare",
    "emancipavan": "emancipare",
    "emancipavano": "emancipare",
    "emancipavate": "emancipare",
    "emancipavi": "emancipare",
    "emancipavo": "emancipare",
    "emancipazioni": "emancipazione",
    "emanciperai": "emancipare",
    "emanciperan": "emancipare",
    "emanciperanno": "emancipare",
    "emanciperebbe": "emancipare",
    "emanciperebber": "emancipare",
    "emanciperebbero": "emancipare",
    "emanciperei": "emancipare",
    "emanciperemmo": "emancipare",
    "emanciperemo": "emancipare",
    "emancipereste": "emancipare",
    "emanciperesti": "emancipare",
    "emanciperete": "emancipare",
    "emanciperà": "emancipare",
    "emanciperò": "emancipare",
    "emancipi": "emancipare",
    "emancipiamo": "emancipare",
    "emancipiate": "emancipare",
    "emancipin": "emancipare",
    "emancipino": "emancipare",
    "emancipo": "emancipare",
    "emancipò": "emancipare",
    "emanerai": "emanare",
    "emaneran": "emanare",
    "emaneranno": "emanare",
    "emanerebbe": "emanare",
    "emanerebber": "emanare",
    "emanerebbero": "emanare",
    "emanerei": "emanare",
    "emaneremmo": "emanare",
    "emaneremo": "emanare",
    "emanereste": "emanare",
    "emaneresti": "emanare",
    "emanerete": "emanare",
    "emanerà": "emanare",
    "emanerò": "emanare",
    "emani": "emanare",
    "emaniamo": "emanare",
    "emaniate": "emanare",
    "emanin": "emanare",
    "emanino": "emanare",
    "emano": "emanare",
    "emanò": "emanare",
    "emargina": "emarginare",
    "emarginai": "emarginare",
    "emarginammo": "emarginare",
    "emarginan": "emarginare",
    "emarginando": "emarginare",
    "emarginano": "emarginare",
    "emarginante": "emarginare",
    "emarginanti": "emarginare",
    "emarginar": "emarginare",
    "emarginaron": "emarginare",
    "emarginarono": "emarginare",
    "emarginasse": "emarginare",
    "emarginasser": "emarginare",
    "emarginassero": "emarginare",
    "emarginassi": "emarginare",
    "emarginassimo": "emarginare",
    "emarginaste": "emarginare",
    "emarginasti": "emarginare",
    "emarginata": "emarginato",
    "emarginate": "emarginato",
    "emarginati": "emarginato",
    "emarginato": "emarginare",
    "emarginava": "emarginare",
    "emarginavamo": "emarginare",
    "emarginavan": "emarginare",
    "emarginavano": "emarginare",
    "emarginavate": "emarginare",
    "emarginavi": "emarginare",
    "emarginavo": "emarginare",
    "emarginazioni": "emarginazione",
    "emarginerai": "emarginare",
    "emargineran": "emarginare",
    "emargineranno": "emarginare",
    "emarginerebbe": "emarginare",
    "emarginerebber": "emarginare",
    "emarginerebbero": "emarginare",
    "emarginerei": "emarginare",
    "emargineremmo": "emarginare",
    "emargineremo": "emarginare",
    "emarginereste": "emarginare",
    "emargineresti": "emarginare",
    "emarginerete": "emarginare",
    "emarginerà": "emarginare",
    "emarginerò": "emarginare",
    "emargini": "emarginare",
    "emarginiamo": "emarginare",
    "emarginiate": "emarginare",
    "emarginin": "emarginare",
    "emarginino": "emarginare",
    "emargino": "emarginare",
    "emarginò": "emarginare",
    "ematica": "ematico",
    "ematiche": "ematico",
    "ematici": "ematico",
    "ematochimica": "ematochimico",
    "ematochimiche": "ematochimico",
    "ematochimici": "ematochimico",
    "ematocriti": "ematocrito",
    "ematologi": "ematologo",
    "ematologica": "ematologico",
    "ematologiche": "ematologico",
    "ematologici": "ematologico",
    "ematomi": "ematoma",
    "embarghi": "embargo",
    "emblematica": "emblematico",
    "emblematiche": "emblematico",
    "emblematici": "emblematico",
    "emblemi": "emblema",
    "embolie": "embolia",
    "embrionali": "embrionale",
    "embrioni": "embrione",
    "emedamenti": "emedamento",
    "emenda": "emendare",
    "emendai": "emendare",
    "emendamenti": "emendamento",
    "emendammo": "emendare",
    "emendan": "emendare",
    "emendando": "emendare",
    "emendano": "emendare",
    "emendante": "emendare",
    "emendanti": "emendare",
    "emendar": "emendare",
    "emendaron": "emendare",
    "emendarono": "emendare",
    "emendasse": "emendare",
    "emendasser": "emendare",
    "emendassero": "emendare",
    "emendassi": "emendare",
    "emendassimo": "emendare",
    "emendaste": "emendare",
    "emendasti": "emendare",
    "emendata": "emendare",
    "emendate": "emendare",
    "emendati": "emendare",
    "emendativa": "emendativo",
    "emendative": "emendativo",
    "emendativi": "emendativo",
    "emendato": "emendare",
    "emendava": "emendare",
    "emendavamo": "emendare",
    "emendavan": "emendare",
    "emendavano": "emendare",
    "emendavate": "emendare",
    "emendavi": "emendare",
    "emendavo": "emendare",
    "emenderai": "emendare",
    "emenderan": "emendare",
    "emenderanno": "emendare",
    "emenderebbe": "emendare",
    "emenderebber": "emendare",
    "emenderebbero": "emendare",
    "emenderei": "emendare",
    "emenderemmo": "emendare",
    "emenderemo": "emendare",
    "emendereste": "emendare",
    "emenderesti": "emendare",
    "emenderete": "emendare",
    "emenderà": "emendare",
    "emenderò": "emendare",
    "emendi": "emendare",
    "emendiamo": "emendare",
    "emendiate": "emendare",
    "emendin": "emendare",
    "emendino": "emendare",
    "emendo": "emendare",
    "emendò": "emendare",
    "emerga": "emergere",
    "emergan": "emergere",
    "emergano": "emergere",
    "emerge": "emergere",
    "emergemmo": "emergere",
    "emergendo": "emergere",
    "emergente": "emergere",
    "emergenti": "emergere",
    "emergenze": "emergenza",
    "emerger": "emergere",
    "emergerai": "emergere",
    "emergeran": "emergere",
    "emergeranno": "emergere",
    "emergerebbe": "emergere",
    "emergerebber": "emergere",
    "emergerebbero": "emergere",
    "emergerei": "emergere",
    "emergeremmo": "emergere",
    "emergeremo": "emergere",
    "emergereste": "emergere",
    "emergeresti": "emergere",
    "emergerete": "emergere",
    "emergerà": "emergere",
    "emergerò": "emergere",
    "emergesse": "emergere",
    "emergesser": "emergere",
    "emergessero": "emergere",
    "emergessi": "emergere",
    "emergessimo": "emergere",
    "emergeste": "emergere",
    "emergesti": "emergere",
    "emergete": "emergere",
    "emergeva": "emergere",
    "emergevamo": "emergere",
    "emergevan": "emergere",
    "emergevano": "emergere",
    "emergevate": "emergere",
    "emergevi": "emergere",
    "emergevo": "emergere",
    "emergi": "emergere",
    "emergiamo": "emergere",
    "emergiate": "emergere",
    "emergo": "emergere",
    "emergon": "emergere",
    "emergono": "emergere",
    "emerita": "emerito",
    "emerite": "emerito",
    "emeriti": "emerito",
    "emersa": "emerso",
    "emerse": "emerso",
    "emerser": "emergere",
    "emersero": "emergere",
    "emersi": "emerso",
    "emersioni": "emersione",
    "emerso": "emergere",
    "emessa": "emettere",
    "emesse": "emettere",
    "emessi": "emettere",
    "emesso": "emettere",
    "emetta": "emettere",
    "emettan": "emettere",
    "emettano": "emettere",
    "emette": "emettere",
    "emettemmo": "emettere",
    "emettendo": "emettere",
    "emettente": "emettere",
    "emettenti": "emettere",
    "emetter": "emettere",
    "emetterai": "emettere",
    "emetteran": "emettere",
    "emetteranno": "emettere",
    "emetterebbe": "emettere",
    "emetterebber": "emettere",
    "emetterebbero": "emettere",
    "emetterei": "emettere",
    "emetteremmo": "emettere",
    "emetteremo": "emettere",
    "emettereste": "emettere",
    "emetteresti": "emettere",
    "emetterete": "emettere",
    "emetterà": "emettere",
    "emetterò": "emettere",
    "emettesse": "emettere",
    "emettesser": "emettere",
    "emettessero": "emettere",
    "emettessi": "emettere",
    "emettessimo": "emettere",
    "emetteste": "emettere",
    "emettesti": "emettere",
    "emettete": "emettere",
    "emetteva": "emettere",
    "emettevamo": "emettere",
    "emettevan": "emettere",
    "emettevano": "emettere",
    "emettevate": "emettere",
    "emettevi": "emettere",
    "emettevo": "emettere",
    "emetti": "emettere",
    "emettiamo": "emettere",
    "emettiate": "emettere",
    "emetto": "emettere",
    "emetton": "emettere",
    "emettono": "emettere",
    "emicranie": "emicrania",
    "emigra": "emigrare",
    "emigrai": "emigrare",
    "emigrammo": "emigrare",
    "emigran": "emigrare",
    "emigrando": "emigrare",
    "emigrano": "emigrare",
    "emigrante": "emigrare",
    "emigranti": "emigrare",
    "emigrar": "emigrare",
    "emigraron": "emigrare",
    "emigrarono": "emigrare",
    "emigrasse": "emigrare",
    "emigrasser": "emigrare",
    "emigrassero": "emigrare",
    "emigrassi": "emigrare",
    "emigrassimo": "emigrare",
    "emigraste": "emigrare",
    "emigrasti": "emigrare",
    "emigrata": "emigrato",
    "emigrate": "emigrato",
    "emigrati": "emigrato",
    "emigrato": "emigrare",
    "emigratori": "emigratorio",
    "emigratoria": "emigratorio",
    "emigratorie": "emigratorio",
    "emigrava": "emigrare",
    "emigravamo": "emigrare",
    "emigravan": "emigrare",
    "emigravano": "emigrare",
    "emigravate": "emigrare",
    "emigravi": "emigrare",
    "emigravo": "emigrare",
    "emigrazioni": "emigrazione",
    "emigrerai": "emigrare",
    "emigreran": "emigrare",
    "emigreranno": "emigrare",
    "emigrerebbe": "emigrare",
    "emigrerebber": "emigrare",
    "emigrerebbero": "emigrare",
    "emigrerei": "emigrare",
    "emigreremmo": "emigrare",
    "emigreremo": "emigrare",
    "emigrereste": "emigrare",
    "emigreresti": "emigrare",
    "emigrerete": "emigrare",
    "emigrerà": "emigrare",
    "emigrerò": "emigrare",
    "emigri": "emigrare",
    "emigriamo": "emigrare",
    "emigriate": "emigrare",
    "emigrin": "emigrare",
    "emigrino": "emigrare",
    "emigro": "emigrare",
    "emigrò": "emigrare",
    "emiliana": "emiliano",
    "emiliane": "emiliano",
    "emiliani": "emiliano",
    "emiliano-romagnola": "emiliano-romagnolo",
    "emiliano-romagnole": "emiliano-romagnolo",
    "emiliano-romagnoli": "emiliano-romagnolo",
    "eminenti": "eminente",
    "eminenze": "eminenza",
    "emirati": "emirato",
    "emiri": "emiro",
    "emise": "emettere",
    "emiser": "emettere",
    "emisero": "emettere",
    "emisferi": "emisfero",
    "emisferica": "emisferico",
    "emisferiche": "emisferico",
    "emisferici": "emisferico",
    "emisi": "emettere",
    "emissari": "emissario",
    "emissaria": "emissario",
    "emissarie": "emissario",
    "emissioni": "emissione",
    "emittenti": "emittente",
    "emittenze": "emittenza",
    "emodiagnostica": "emodiagnostico",
    "emodiagnostiche": "emodiagnostico",
    "emodiagnostici": "emodiagnostico",
    "emofiliaca": "emofiliaco",
    "emofiliache": "emofiliaco",
    "emofiliaci": "emofiliaco",
    "emofilica": "emofilico",
    "emofiliche": "emofilico",
    "emofilici": "emofilico",
    "emolumenti": "emolumento",
    "emorragica": "emorragico",
    "emorragiche": "emorragico",
    "emorragici": "emorragico",
    "emorragie": "emorragia",
    "emostatica": "emostatico",
    "emostatiche": "emostatico",
    "emostatici": "emostatico",
    "emotiva": "emotivo",
    "emotive": "emotivo",
    "emotivi": "emotivo",
    "emotrasfusioni": "emotrasfusione",
    "emoziona": "emozionare",
    "emozionai": "emozionare",
    "emozionali": "emozionale",
    "emozionammo": "emozionare",
    "emozionan": "emozionare",
    "emozionando": "emozionare",
    "emozionano": "emozionare",
    "emozionante": "emozionare",
    "emozionanti": "emozionare",
    "emozionar": "emozionare",
    "emozionaron": "emozionare",
    "emozionarono": "emozionare",
    "emozionasse": "emozionare",
    "emozionasser": "emozionare",
    "emozionassero": "emozionare",
    "emozionassi": "emozionare",
    "emozionassimo": "emozionare",
    "emozionaste": "emozionare",
    "emozionasti": "emozionare",
    "emozionata": "emozionare",
    "emozionate": "emozionare",
    "emozionati": "emozionare",
    "emozionato": "emozionare",
    "emozionava": "emozionare",
    "emozionavamo": "emozionare",
    "emozionavan": "emozionare",
    "emozionavano": "emozionare",
    "emozionavate": "emozionare",
    "emozionavi": "emozionare",
    "emozionavo": "emozionare",
    "emozionerai": "emozionare",
    "emozioneran": "emozionare",
    "emozioneranno": "emozionare",
    "emozionerebbe": "emozionare",
    "emozionerebber": "emozionare",
    "emozionerebbero": "emozionare",
    "emozionerei": "emozionare",
    "emozioneremmo": "emozionare",
    "emozioneremo": "emozionare",
    "emozionereste": "emozionare",
    "emozioneresti": "emozionare",
    "emozionerete": "emozionare",
    "emozionerà": "emozionare",
    "emozionerò": "emozionare",
    "emozioni": "emozione",
    "emozioniamo": "emozionare",
    "emozioniate": "emozionare",
    "emozionin": "emozionare",
    "emozionino": "emozionare",
    "emoziono": "emozionare",
    "emozionò": "emozionare",
    "empa": "empire",
    "empan": "empire",
    "empano": "empire",
    "empe": "empire",
    "empendo": "empire",
    "empente": "empire",
    "empenti": "empire",
    "empi": "empire",
    "empia": "empio",
    "empiamo": "empire",
    "empian": "empiere",
    "empiano": "empiere",
    "empiate": "empire",
    "empie": "empio",
    "empiei": "empiere",
    "empiemmo": "empiere",
    "empiendo": "empiere",
    "empiente": "empiere",
    "empienti": "empiere",
    "empier": "empiere",
    "empierai": "empiere",
    "empieran": "empiere",
    "empieranno": "empiere",
    "empierebbe": "empiere",
    "empierebber": "empiere",
    "empierebbero": "empiere",
    "empierei": "empiere",
    "empieremmo": "empiere",
    "empieremo": "empiere",
    "empiereste": "empiere",
    "empieresti": "empiere",
    "empierete": "empiere",
    "empieron": "empiere",
    "empierono": "empiere",
    "empierà": "empiere",
    "empierò": "empiere",
    "empiesse": "empiere",
    "empiesser": "empiere",
    "empiessero": "empiere",
    "empiessi": "empiere",
    "empiessimo": "empiere",
    "empieste": "empiere",
    "empiesti": "empiere",
    "empiete": "empiere",
    "empieva": "empiere",
    "empievamo": "empiere",
    "empievan": "empiere",
    "empievano": "empiere",
    "empievate": "empiere",
    "empievi": "empiere",
    "empievo": "empiere",
    "empii": "empire",
    "empiiamo": "empiere",
    "empiiate": "empiere",
    "empimmo": "empire",
    "empio": "empiere",
    "empion": "empiere",
    "empiono": "empiere",
    "empir": "empire",
    "empirai": "empire",
    "empiran": "empire",
    "empiranno": "empire",
    "empirebbe": "empire",
    "empirebber": "empire",
    "empirebbero": "empire",
    "empirei": "empireo",
    "empiremmo": "empire",
    "empiremo": "empire",
    "empireste": "empire",
    "empiresti": "empire",
    "empirete": "empire",
    "empirica": "empirico",
    "empiriche": "empirico",
    "empirici": "empirico",
    "empiron": "empire",
    "empirono": "empire",
    "empirà": "empire",
    "empirò": "empire",
    "empisse": "empire",
    "empisser": "empire",
    "empissero": "empire",
    "empissi": "empire",
    "empissimo": "empire",
    "empiste": "empire",
    "empisti": "empire",
    "empita": "empire",
    "empite": "empire",
    "empiti": "empito",
    "empito": "empire",
    "empiuta": "empiere",
    "empiute": "empiere",
    "empiuti": "empiere",
    "empiuto": "empiere",
    "empiva": "empire",
    "empivamo": "empire",
    "empivan": "empire",
    "empivano": "empire",
    "empivate": "empire",
    "empivi": "empire",
    "empivo": "empire",
    "empiè": "empiere",
    "empo": "empire",
    "empon": "empire",
    "empono": "empire",
    "empori": "emporio",
    "empì": "empire",
    "emula": "emulare",
    "emulai": "emulare",
    "emulammo": "emulare",
    "emulan": "emulare",
    "emulando": "emulare",
    "emulano": "emulare",
    "emulante": "emulare",
    "emulanti": "emulare",
    "emular": "emulare",
    "emularon": "emulare",
    "emularono": "emulare",
    "emulasse": "emulare",
    "emulasser": "emulare",
    "emulassero": "emulare",
    "emulassi": "emulare",
    "emulassimo": "emulare",
    "emulaste": "emulare",
    "emulasti": "emulare",
    "emulata": "emulare",
    "emulate": "emulare",
    "emulati": "emulare",
    "emulativa": "emulativo",
    "emulative": "emulativo",
    "emulativi": "emulativo",
    "emulato": "emulare",
    "emulava": "emulare",
    "emulavamo": "emulare",
    "emulavan": "emulare",
    "emulavano": "emulare",
    "emulavate": "emulare",
    "emulavi": "emulare",
    "emulavo": "emulare",
    "emulazioni": "emulazione",
    "emulerai": "emulare",
    "emuleran": "emulare",
    "emuleranno": "emulare",
    "emulerebbe": "emulare",
    "emulerebber": "emulare",
    "emulerebbero": "emulare",
    "emulerei": "emulare",
    "emuleremmo": "emulare",
    "emuleremo": "emulare",
    "emulereste": "emulare",
    "emuleresti": "emulare",
    "emulerete": "emulare",
    "emulerà": "emulare",
    "emulerò": "emulare",
    "emuli": "emulo",
    "emuliamo": "emulare",
    "emuliate": "emulare",
    "emulin": "emulare",
    "emulino": "emulare",
    "emulo": "emulare",
    "emulsiona": "emulsionare",
    "emulsionai": "emulsionare",
    "emulsionammo": "emulsionare",
    "emulsionan": "emulsionare",
    "emulsionando": "emulsionare",
    "emulsionano": "emulsionare",
    "emulsionante": "emulsionare",
    "emulsionanti": "emulsionare",
    "emulsionar": "emulsionare",
    "emulsionaron": "emulsionare",
    "emulsionarono": "emulsionare",
    "emulsionasse": "emulsionare",
    "emulsionasser": "emulsionare",
    "emulsionassero": "emulsionare",
    "emulsionassi": "emulsionare",
    "emulsionassimo": "emulsionare",
    "emulsionaste": "emulsionare",
    "emulsionasti": "emulsionare",
    "emulsionata": "emulsionare",
    "emulsionate": "emulsionare",
    "emulsionati": "emulsionare",
    "emulsionato": "emulsionare",
    "emulsionava": "emulsionare",
    "emulsionavamo": "emulsionare",
    "emulsionavan": "emulsionare",
    "emulsionavano": "emulsionare",
    "emulsionavate": "emulsionare",
    "emulsionavi": "emulsionare",
    "emulsionavo": "emulsionare",
    "emulsionerai": "emulsionare",
    "emulsioneran": "emulsionare",
    "emulsioneranno": "emulsionare",
    "emulsionerebbe": "emulsionare",
    "emulsionerebber": "emulsionare",
    "emulsionerebbero": "emulsionare",
    "emulsionerei": "emulsionare",
    "emulsioneremmo": "emulsionare",
    "emulsioneremo": "emulsionare",
    "emulsionereste": "emulsionare",
    "emulsioneresti": "emulsionare",
    "emulsionerete": "emulsionare",
    "emulsionerà": "emulsionare",
    "emulsionerò": "emulsionare",
    "emulsioni": "emulsione",
    "emulsioniamo": "emulsionare",
    "emulsioniate": "emulsionare",
    "emulsionin": "emulsionare",
    "emulsionino": "emulsionare",
    "emulsiono": "emulsionare",
    "emulsionò": "emulsionare",
    "emulò": "emulare",
    "enarmonica": "enarmonico",
    "enarmoniche": "enarmonico",
    "enarmonici": "enarmonico",
    "enciclica": "enciclico",
    "encicliche": "enciclico",
    "enciclici": "enciclico",
    "enciclopedica": "enciclopedico",
    "enciclopediche": "enciclopedico",
    "enciclopedici": "enciclopedico",
    "enciclopedie": "enciclopedia",
    "encomi": "encomio",
    "encomia": "encomiare",
    "encomiabili": "encomiabile",
    "encomiai": "encomiare",
    "encomiammo": "encomiare",
    "encomiamo": "encomiare",
    "encomian": "encomiare",
    "encomiando": "encomiare",
    "encomiano": "encomiare",
    "encomiante": "encomiare",
    "encomianti": "encomiare",
    "encomiar": "encomiare",
    "encomiaron": "encomiare",
    "encomiarono": "encomiare",
    "encomiasse": "encomiare",
    "encomiasser": "encomiare",
    "encomiassero": "encomiare",
    "encomiassi": "encomiare",
    "encomiassimo": "encomiare",
    "encomiaste": "encomiare",
    "encomiasti": "encomiare",
    "encomiastica": "encomiastico",
    "encomiastiche": "encomiastico",
    "encomiastici": "encomiastico",
    "encomiata": "encomiare",
    "encomiate": "encomiare",
    "encomiati": "encomiare",
    "encomiato": "encomiare",
    "encomiava": "encomiare",
    "encomiavamo": "encomiare",
    "encomiavan": "encomiare",
    "encomiavano": "encomiare",
    "encomiavate": "encomiare",
    "encomiavi": "encomiare",
    "encomiavo": "encomiare",
    "encomierai": "encomiare",
    "encomieran": "encomiare",
    "encomieranno": "encomiare",
    "encomierebbe": "encomiare",
    "encomierebber": "encomiare",
    "encomierebbero": "encomiare",
    "encomierei": "encomiare",
    "encomieremmo": "encomiare",
    "encomieremo": "encomiare",
    "encomiereste": "encomiare",
    "encomieresti": "encomiare",
    "encomierete": "encomiare",
    "encomierà": "encomiare",
    "encomierò": "encomiare",
    "encomin": "encomiare",
    "encomino": "encomiare",
    "encomio": "encomiare",
    "encomiò": "encomiare",
    "endecasillaba": "endecasillabo",
    "endecasillabe": "endecasillabo",
    "endecasillabi": "endecasillabo",
    "endemica": "endemico",
    "endemiche": "endemico",
    "endemici": "endemico",
    "endocrina": "endocrino",
    "endocrine": "endocrino",
    "endocrini": "endocrino",
    "endogena": "endogeno",
    "endogene": "endogeno",
    "endogeni": "endogeno",
    "endovenosa": "endovenoso",
    "endovenose": "endovenoso",
    "endovenosi": "endovenoso",
    "energetica": "energetico",
    "energetiche": "energetico",
    "energetici": "energetico",
    "energica": "energico",
    "energiche": "energico",
    "energici": "energico",
    "energie": "energia",
    "energumeni": "energumeno",
    "enfatica": "enfatico",
    "enfatiche": "enfatico",
    "enfatici": "enfatico",
    "enfatizza": "enfatizzare",
    "enfatizzai": "enfatizzare",
    "enfatizzammo": "enfatizzare",
    "enfatizzan": "enfatizzare",
    "enfatizzando": "enfatizzare",
    "enfatizzano": "enfatizzare",
    "enfatizzante": "enfatizzare",
    "enfatizzanti": "enfatizzare",
    "enfatizzar": "enfatizzare",
    "enfatizzaron": "enfatizzare",
    "enfatizzarono": "enfatizzare",
    "enfatizzasse": "enfatizzare",
    "enfatizzasser": "enfatizzare",
    "enfatizzassero": "enfatizzare",
    "enfatizzassi": "enfatizzare",
    "enfatizzassimo": "enfatizzare",
    "enfatizzaste": "enfatizzare",
    "enfatizzasti": "enfatizzare",
    "enfatizzata": "enfatizzare",
    "enfatizzate": "enfatizzare",
    "enfatizzati": "enfatizzare",
    "enfatizzato": "enfatizzare",
    "enfatizzava": "enfatizzare",
    "enfatizzavamo": "enfatizzare",
    "enfatizzavan": "enfatizzare",
    "enfatizzavano": "enfatizzare",
    "enfatizzavate": "enfatizzare",
    "enfatizzavi": "enfatizzare",
    "enfatizzavo": "enfatizzare",
    "enfatizzazioni": "enfatizzazione",
    "enfatizzerai": "enfatizzare",
    "enfatizzeran": "enfatizzare",
    "enfatizzeranno": "enfatizzare",
    "enfatizzerebbe": "enfatizzare",
    "enfatizzerebber": "enfatizzare",
    "enfatizzerebbero": "enfatizzare",
    "enfatizzerei": "enfatizzare",
    "enfatizzeremmo": "enfatizzare",
    "enfatizzeremo": "enfatizzare",
    "enfatizzereste": "enfatizzare",
    "enfatizzeresti": "enfatizzare",
    "enfatizzerete": "enfatizzare",
    "enfatizzerà": "enfatizzare",
    "enfatizzerò": "enfatizzare",
    "enfatizzi": "enfatizzare",
    "enfatizziamo": "enfatizzare",
    "enfatizziate": "enfatizzare",
    "enfatizzin": "enfatizzare",
    "enfatizzino": "enfatizzare",
    "enfatizzo": "enfatizzare",
    "enfatizzò": "enfatizzare",
    "enfi": "enfiare",
    "enfia": "enfiare",
    "enfiai": "enfiare",
    "enfiammo": "enfiare",
    "enfiamo": "enfiare",
    "enfian": "enfiare",
    "enfiando": "enfiare",
    "enfiano": "enfiare",
    "enfiante": "enfiare",
    "enfianti": "enfiare",
    "enfiar": "enfiare",
    "enfiaron": "enfiare",
    "enfiarono": "enfiare",
    "enfiasse": "enfiare",
    "enfiasser": "enfiare",
    "enfiassero": "enfiare",
    "enfiassi": "enfiare",
    "enfiassimo": "enfiare",
    "enfiaste": "enfiare",
    "enfiasti": "enfiare",
    "enfiata": "enfiare",
    "enfiate": "enfiare",
    "enfiati": "enfiare",
    "enfiato": "enfiare",
    "enfiava": "enfiare",
    "enfiavamo": "enfiare",
    "enfiavan": "enfiare",
    "enfiavano": "enfiare",
    "enfiavate": "enfiare",
    "enfiavi": "enfiare",
    "enfiavo": "enfiare",
    "enfierai": "enfiare",
    "enfieran": "enfiare",
    "enfieranno": "enfiare",
    "enfierebbe": "enfiare",
    "enfierebber": "enfiare",
    "enfierebbero": "enfiare",
    "enfierei": "enfiare",
    "enfieremmo": "enfiare",
    "enfieremo": "enfiare",
    "enfiereste": "enfiare",
    "enfieresti": "enfiare",
    "enfierete": "enfiare",
    "enfierà": "enfiare",
    "enfierò": "enfiare",
    "enfin": "enfiare",
    "enfino": "enfiare",
    "enfio": "enfiare",
    "enfiò": "enfiare",
    "enigmatica": "enigmatico",
    "enigmatiche": "enigmatico",
    "enigmatici": "enigmatico",
    "enigmi": "enigma",
    "enigmistica": "enigmistico",
    "enigmistiche": "enigmistico",
    "enigmistici": "enigmistico",
    "ennesima": "ennesimo",
    "ennesime": "ennesimo",
    "ennesimi": "ennesimo",
    "enogastronomica": "enogastronomico",
    "enogastronomiche": "enogastronomico",
    "enogastronomici": "enogastronomico",
    "enologi": "enologo",
    "enologica": "enologico",
    "enologiche": "enologico",
    "enologici": "enologico",
    "enormi": "enorme",
    "enoteche": "enoteca",
    "enti": "ente",
    "entomologi": "entomologo",
    "entra": "entrare",
    "entrai": "entrare",
    "entrambe": "entrambi",
    "entrammo": "entrare",
    "entran": "entrare",
    "entrando": "entrare",
    "entrano": "entrare",
    "entrante": "entrare",
    "entranti": "entrare",
    "entrar": "entrare",
    "entraron": "entrare",
    "entrarono": "entrare",
    "entrasse": "entrare",
    "entrasser": "entrare",
    "entrassero": "entrare",
    "entrassi": "entrare",
    "entrassimo": "entrare",
    "entraste": "entrare",
    "entrasti": "entrare",
    "entrata": "entrare",
    "entrate": "entrata",
    "entrati": "entrare",
    "entrato": "entrare",
    "entrature": "entratura",
    "entrava": "entrare",
    "entravamo": "entrare",
    "entravan": "entrare",
    "entravano": "entrare",
    "entravate": "entrare",
    "entravi": "entrare",
    "entravo": "entrare",
    "entrerai": "entrare",
    "entreran": "entrare",
    "entreranno": "entrare",
    "entrerebbe": "entrare",
    "entrerebber": "entrare",
    "entrerebbero": "entrare",
    "entrerei": "entrare",
    "entreremmo": "entrare",
    "entreremo": "entrare",
    "entrereste": "entrare",
    "entreresti": "entrare",
    "entrerete": "entrare",
    "entrerà": "entrare",
    "entrerò": "entrare",
    "entri": "entrare",
    "entriamo": "entrare",
    "entriate": "entrare",
    "entrin": "entrare",
    "entrino": "entrare",
    "entro": "entrare",
    "entroborda": "entrobordo",
    "entroborde": "entrobordo",
    "entrobordi": "entrobordo",
    "entrò": "entrare",
    "entusiasma": "entusiasmare",
    "entusiasmai": "entusiasmare",
    "entusiasmammo": "entusiasmare",
    "entusiasman": "entusiasmare",
    "entusiasmando": "entusiasmare",
    "entusiasmano": "entusiasmare",
    "entusiasmante": "entusiasmare",
    "entusiasmanti": "entusiasmare",
    "entusiasmar": "entusiasmare",
    "entusiasmaron": "entusiasmare",
    "entusiasmarono": "entusiasmare",
    "entusiasmasse": "entusiasmare",
    "entusiasmasser": "entusiasmare",
    "entusiasmassero": "entusiasmare",
    "entusiasmassi": "entusiasmare",
    "entusiasmassimo": "entusiasmare",
    "entusiasmaste": "entusiasmare",
    "entusiasmasti": "entusiasmare",
    "entusiasmata": "entusiasmare",
    "entusiasmate": "entusiasmare",
    "entusiasmati": "entusiasmare",
    "entusiasmato": "entusiasmare",
    "entusiasmava": "entusiasmare",
    "entusiasmavamo": "entusiasmare",
    "entusiasmavan": "entusiasmare",
    "entusiasmavano": "entusiasmare",
    "entusiasmavate": "entusiasmare",
    "entusiasmavi": "entusiasmare",
    "entusiasmavo": "entusiasmare",
    "entusiasmerai": "entusiasmare",
    "entusiasmeran": "entusiasmare",
    "entusiasmeranno": "entusiasmare",
    "entusiasmerebbe": "entusiasmare",
    "entusiasmerebber": "entusiasmare",
    "entusiasmerebbero": "entusiasmare",
    "entusiasmerei": "entusiasmare",
    "entusiasmeremmo": "entusiasmare",
    "entusiasmeremo": "entusiasmare",
    "entusiasmereste": "entusiasmare",
    "entusiasmeresti": "entusiasmare",
    "entusiasmerete": "entusiasmare",
    "entusiasmerà": "entusiasmare",
    "entusiasmerò": "entusiasmare",
    "entusiasmi": "entusiasmo",
    "entusiasmiamo": "entusiasmare",
    "entusiasmiate": "entusiasmare",
    "entusiasmin": "entusiasmare",
    "entusiasmino": "entusiasmare",
    "entusiasmo": "entusiasmare",
    "entusiasmò": "entusiasmare",
    "entusiaste": "entusiasta",
    "entusiasti": "entusiasta",
    "entusiastica": "entusiastico",
    "entusiastiche": "entusiastico",
    "entusiastici": "entusiastico",
    "enuclea": "enucleare",
    "enucleai": "enucleare",
    "enucleammo": "enucleare",
    "enuclean": "enucleare",
    "enucleando": "enucleare",
    "enucleano": "enucleare",
    "enucleante": "enucleare",
    "enucleanti": "enucleare",
    "enuclear": "enucleare",
    "enuclearon": "enucleare",
    "enuclearono": "enucleare",
    "enucleasse": "enucleare",
    "enucleasser": "enucleare",
    "enucleassero": "enucleare",
    "enucleassi": "enucleare",
    "enucleassimo": "enucleare",
    "enucleaste": "enucleare",
    "enucleasti": "enucleare",
    "enucleata": "enucleare",
    "enucleate": "enucleare",
    "enucleati": "enucleare",
    "enucleato": "enucleare",
    "enucleava": "enucleare",
    "enucleavamo": "enucleare",
    "enucleavan": "enucleare",
    "enucleavano": "enucleare",
    "enucleavate": "enucleare",
    "enucleavi": "enucleare",
    "enucleavo": "enucleare",
    "enucleerai": "enucleare",
    "enucleeran": "enucleare",
    "enucleeranno": "enucleare",
    "enucleerebbe": "enucleare",
    "enucleerebber": "enucleare",
    "enucleerebbero": "enucleare",
    "enucleerei": "enucleare",
    "enucleeremmo": "enucleare",
    "enucleeremo": "enucleare",
    "enucleereste": "enucleare",
    "enucleeresti": "enucleare",
    "enucleerete": "enucleare",
    "enucleerà": "enucleare",
    "enucleerò": "enucleare",
    "enuclei": "enucleare",
    "enucleiamo": "enucleare",
    "enucleiate": "enucleare",
    "enuclein": "enucleare",
    "enucleino": "enucleare",
    "enucleo": "enucleare",
    "enucleò": "enucleare",
    "enumera": "enumerare",
    "enumerai": "enumerare",
    "enumerammo": "enumerare",
    "enumeran": "enumerare",
    "enumerando": "enumerare",
    "enumerano": "enumerare",
    "enumerante": "enumerare",
    "enumeranti": "enumerare",
    "enumerar": "enumerare",
    "enumeraron": "enumerare",
    "enumerarono": "enumerare",
    "enumerasse": "enumerare",
    "enumerasser": "enumerare",
    "enumerassero": "enumerare",
    "enumerassi": "enumerare",
    "enumerassimo": "enumerare",
    "enumeraste": "enumerare",
    "enumerasti": "enumerare",
    "enumerata": "enumerare",
    "enumerate": "enumerare",
    "enumerati": "enumerare",
    "enumerato": "enumerare",
    "enumerava": "enumerare",
    "enumeravamo": "enumerare",
    "enumeravan": "enumerare",
    "enumeravano": "enumerare",
    "enumeravate": "enumerare",
    "enumeravi": "enumerare",
    "enumeravo": "enumerare",
    "enumerazioni": "enumerazione",
    "enumererai": "enumerare",
    "enumereran": "enumerare",
    "enumereranno": "enumerare",
    "enumererebbe": "enumerare",
    "enumererebber": "enumerare",
    "enumererebbero": "enumerare",
    "enumererei": "enumerare",
    "enumereremmo": "enumerare",
    "enumereremo": "enumerare",
    "enumerereste": "enumerare",
    "enumereresti": "enumerare",
    "enumererete": "enumerare",
    "enumererà": "enumerare",
    "enumererò": "enumerare",
    "enumeri": "enumerare",
    "enumeriamo": "enumerare",
    "enumeriate": "enumerare",
    "enumerin": "enumerare",
    "enumerino": "enumerare",
    "enumero": "enumerare",
    "enumerò": "enumerare",
    "enuncerai": "enunciare",
    "enunceran": "enunciare",
    "enunceranno": "enunciare",
    "enuncerebbe": "enunciare",
    "enuncerebber": "enunciare",
    "enuncerebbero": "enunciare",
    "enuncerei": "enunciare",
    "enunceremmo": "enunciare",
    "enunceremo": "enunciare",
    "enuncereste": "enunciare",
    "enunceresti": "enunciare",
    "enuncerete": "enunciare",
    "enuncerà": "enunciare",
    "enuncerò": "enunciare",
    "enunci": "enunciare",
    "enuncia": "enunciare",
    "enunciai": "enunciare",
    "enunciammo": "enunciare",
    "enunciamo": "enunciare",
    "enuncian": "enunciare",
    "enunciando": "enunciare",
    "enunciano": "enunciare",
    "enunciante": "enunciare",
    "enuncianti": "enunciare",
    "enunciar": "enunciare",
    "enunciaron": "enunciare",
    "enunciarono": "enunciare",
    "enunciasse": "enunciare",
    "enunciasser": "enunciare",
    "enunciassero": "enunciare",
    "enunciassi": "enunciare",
    "enunciassimo": "enunciare",
    "enunciaste": "enunciare",
    "enunciasti": "enunciare",
    "enunciata": "enunciato",
    "enunciate": "enunciato",
    "enunciati": "enunciato",
    "enunciato": "enunciare",
    "enunciava": "enunciare",
    "enunciavamo": "enunciare",
    "enunciavan": "enunciare",
    "enunciavano": "enunciare",
    "enunciavate": "enunciare",
    "enunciavi": "enunciare",
    "enunciavo": "enunciare",
    "enunciazioni": "enunciazione",
    "enuncin": "enunciare",
    "enuncino": "enunciare",
    "enuncio": "enunciare",
    "enunciò": "enunciare",
    "enzimatica": "enzimatico",
    "enzimatiche": "enzimatico",
    "enzimatici": "enzimatico",
    "enzimi": "enzima",
    "eoliana": "eoliano",
    "eoliane": "eoliano",
    "eoliani": "eoliano",
    "eolica": "eolico",
    "eoliche": "eolico",
    "eolici": "eolico",
    "epatica": "epatico",
    "epatiche": "epatico",
    "epatici": "epatico",
    "epatiti": "epatite",
    "epatopatie": "epatopatia",
    "epica": "epico",
    "epicentri": "epicentro",
    "epiche": "epico",
    "epici": "epico",
    "epicurea": "epicureo",
    "epicuree": "epicureo",
    "epicurei": "epicureo",
    "epidemica": "epidemico",
    "epidemiche": "epidemico",
    "epidemici": "epidemico",
    "epidemie": "epidemia",
    "epidemiologi": "epidemiologo",
    "epidemiologica": "epidemiologico",
    "epidemiologiche": "epidemiologico",
    "epidemiologici": "epidemiologico",
    "epidermica": "epidermico",
    "epidermiche": "epidermico",
    "epidermici": "epidermico",
    "epifanie": "epifania",
    "epigoni": "epigono",
    "epigrafi": "epigrafe",
    "epigrammi": "epigramma",
    "epilessie": "epilessia",
    "epilettica": "epilettico",
    "epilettiche": "epilettico",
    "epilettici": "epilettico",
    "epiloghi": "epilogo",
    "epinici": "epinicio",
    "episcopali": "episcopale",
    "episcopati": "episcopato",
    "episodi": "episodio",
    "episodica": "episodico",
    "episodiche": "episodico",
    "episodici": "episodico",
    "epistemologi": "epistemologo",
    "epistola": "epistolare",
    "epistolai": "epistolare",
    "epistolammo": "epistolare",
    "epistolan": "epistolare",
    "epistolando": "epistolare",
    "epistolano": "epistolare",
    "epistolante": "epistolare",
    "epistolanti": "epistolare",
    "epistolar": "epistolare",
    "epistolari": "epistolario",
    "epistolaron": "epistolare",
    "epistolarono": "epistolare",
    "epistolasse": "epistolare",
    "epistolasser": "epistolare",
    "epistolassero": "epistolare",
    "epistolassi": "epistolare",
    "epistolassimo": "epistolare",
    "epistolaste": "epistolare",
    "epistolasti": "epistolare",
    "epistolata": "epistolare",
    "epistolate": "epistolare",
    "epistolati": "epistolare",
    "epistolato": "epistolare",
    "epistolava": "epistolare",
    "epistolavamo": "epistolare",
    "epistolavan": "epistolare",
    "epistolavano": "epistolare",
    "epistolavate": "epistolare",
    "epistolavi": "epistolare",
    "epistolavo": "epistolare",
    "epistole": "epistola",
    "epistolerai": "epistolare",
    "epistoleran": "epistolare",
    "epistoleranno": "epistolare",
    "epistolerebbe": "epistolare",
    "epistolerebber": "epistolare",
    "epistolerebbero": "epistolare",
    "epistolerei": "epistolare",
    "epistoleremmo": "epistolare",
    "epistoleremo": "epistolare",
    "epistolereste": "epistolare",
    "epistoleresti": "epistolare",
    "epistolerete": "epistolare",
    "epistolerà": "epistolare",
    "epistolerò": "epistolare",
    "epistoli": "epistolare",
    "epistoliamo": "epistolare",
    "epistoliate": "epistolare",
    "epistolin": "epistolare",
    "epistolino": "epistolare",
    "epistolo": "epistolare",
    "epistolò": "epistolare",
    "epitaffi": "epitaffio",
    "epiteli": "epitelio",
    "epiteliali": "epiteliale",
    "epiteti": "epiteto",
    "epizootica": "epizootico",
    "epizootiche": "epizootico",
    "epizootici": "epizootico",
    "epocali": "epocale",
    "epoche": "epoca",
    "eponima": "eponimo",
    "eponime": "eponimo",
    "eponimi": "eponimo",
    "epopee": "epopea",
    "epura": "epurare",
    "epurai": "epurare",
    "epurammo": "epurare",
    "epuran": "epurare",
    "epurando": "epurare",
    "epurano": "epurare",
    "epurante": "epurare",
    "epuranti": "epurare",
    "epurar": "epurare",
    "epuraron": "epurare",
    "epurarono": "epurare",
    "epurasse": "epurare",
    "epurasser": "epurare",
    "epurassero": "epurare",
    "epurassi": "epurare",
    "epurassimo": "epurare",
    "epuraste": "epurare",
    "epurasti": "epurare",
    "epurata": "epurare",
    "epurate": "epurare",
    "epurati": "epurare",
    "epurato": "epurare",
    "epurava": "epurare",
    "epuravamo": "epurare",
    "epuravan": "epurare",
    "epuravano": "epurare",
    "epuravate": "epurare",
    "epuravi": "epurare",
    "epuravo": "epurare",
    "epurazioni": "epurazione",
    "epurerai": "epurare",
    "epureran": "epurare",
    "epureranno": "epurare",
    "epurerebbe": "epurare",
    "epurerebber": "epurare",
    "epurerebbero": "epurare",
    "epurerei": "epurare",
    "epureremmo": "epurare",
    "epureremo": "epurare",
    "epurereste": "epurare",
    "epureresti": "epurare",
    "epurerete": "epurare",
    "epurerà": "epurare",
    "epurerò": "epurare",
    "epuri": "epurare",
    "epuriamo": "epurare",
    "epuriate": "epurare",
    "epurin": "epurare",
    "epurino": "epurare",
    "epuro": "epurare",
    "epurò": "epurare",
    "equa": "equo",
    "equanimi": "equanime",
    "equatoriali": "equatoriale",
    "equazioni": "equazione",
    "eque": "equo",
    "equestri": "equestre",
    "equi": "equo",
    "equidista": "equidistare",
    "equidistai": "equidistare",
    "equidistammo": "equidistare",
    "equidistan": "equidistare",
    "equidistando": "equidistare",
    "equidistano": "equidistare",
    "equidistante": "equidistare",
    "equidistanti": "equidistare",
    "equidistanze": "equidistanza",
    "equidistar": "equidistare",
    "equidistaron": "equidistare",
    "equidistarono": "equidistare",
    "equidistasse": "equidistare",
    "equidistasser": "equidistare",
    "equidistassero": "equidistare",
    "equidistassi": "equidistare",
    "equidistassimo": "equidistare",
    "equidistaste": "equidistare",
    "equidistasti": "equidistare",
    "equidistata": "equidistare",
    "equidistate": "equidistare",
    "equidistati": "equidistare",
    "equidistato": "equidistare",
    "equidistava": "equidistare",
    "equidistavamo": "equidistare",
    "equidistavan": "equidistare",
    "equidistavano": "equidistare",
    "equidistavate": "equidistare",
    "equidistavi": "equidistare",
    "equidistavo": "equidistare",
    "equidisterai": "equidistare",
    "equidisteran": "equidistare",
    "equidisteranno": "equidistare",
    "equidisterebbe": "equidistare",
    "equidisterebber": "equidistare",
    "equidisterebbero": "equidistare",
    "equidisterei": "equidistare",
    "equidisteremmo": "equidistare",
    "equidisteremo": "equidistare",
    "equidistereste": "equidistare",
    "equidisteresti": "equidistare",
    "equidisterete": "equidistare",
    "equidisterà": "equidistare",
    "equidisterò": "equidistare",
    "equidisti": "equidistare",
    "equidistiamo": "equidistare",
    "equidistiate": "equidistare",
    "equidistin": "equidistare",
    "equidistino": "equidistare",
    "equidisto": "equidistare",
    "equidistò": "equidistare",
    "equilibra": "equilibrare",
    "equilibrai": "equilibrare",
    "equilibrammo": "equilibrare",
    "equilibran": "equilibrare",
    "equilibrando": "equilibrare",
    "equilibrano": "equilibrare",
    "equilibrante": "equilibrare",
    "equilibranti": "equilibrare",
    "equilibrar": "equilibrare",
    "equilibraron": "equilibrare",
    "equilibrarono": "equilibrare",
    "equilibrasse": "equilibrare",
    "equilibrasser": "equilibrare",
    "equilibrassero": "equilibrare",
    "equilibrassi": "equilibrare",
    "equilibrassimo": "equilibrare",
    "equilibraste": "equilibrare",
    "equilibrasti": "equilibrare",
    "equilibrata": "equilibrato",
    "equilibrate": "equilibrato",
    "equilibrati": "equilibrato",
    "equilibrato": "equilibrare",
    "equilibratori": "equilibratore",
    "equilibratrice": "equilibratore",
    "equilibratrici": "equilibratore",
    "equilibrava": "equilibrare",
    "equilibravamo": "equilibrare",
    "equilibravan": "equilibrare",
    "equilibravano": "equilibrare",
    "equilibravate": "equilibrare",
    "equilibravi": "equilibrare",
    "equilibravo": "equilibrare",
    "equilibrerai": "equilibrare",
    "equilibreran": "equilibrare",
    "equilibreranno": "equilibrare",
    "equilibrerebbe": "equilibrare",
    "equilibrerebber": "equilibrare",
    "equilibrerebbero": "equilibrare",
    "equilibrerei": "equilibrare",
    "equilibreremmo": "equilibrare",
    "equilibreremo": "equilibrare",
    "equilibrereste": "equilibrare",
    "equilibreresti": "equilibrare",
    "equilibrerete": "equilibrare",
    "equilibrerà": "equilibrare",
    "equilibrerò": "equilibrare",
    "equilibri": "equilibrio",
    "equilibriamo": "equilibrare",
    "equilibriate": "equilibrare",
    "equilibrin": "equilibrare",
    "equilibrino": "equilibrare",
    "equilibrismi": "equilibrismo",
    "equilibristi": "equilibrista",
    "equilibro": "equilibrare",
    "equilibrò": "equilibrare",
    "equina": "equino",
    "equine": "equino",
    "equini": "equino",
    "equinoziali": "equinoziale",
    "equipaggerai": "equipaggiare",
    "equipaggeran": "equipaggiare",
    "equipaggeranno": "equipaggiare",
    "equipaggerebbe": "equipaggiare",
    "equipaggerebber": "equipaggiare",
    "equipaggerebbero": "equipaggiare",
    "equipaggerei": "equipaggiare",
    "equipaggeremmo": "equipaggiare",
    "equipaggeremo": "equipaggiare",
    "equipaggereste": "equipaggiare",
    "equipaggeresti": "equipaggiare",
    "equipaggerete": "equipaggiare",
    "equipaggerà": "equipaggiare",
    "equipaggerò": "equipaggiare",
    "equipaggi": "equipaggio",
    "equipaggia": "equipaggiare",
    "equipaggiai": "equipaggiare",
    "equipaggiamenti": "equipaggiamento",
    "equipaggiammo": "equipaggiare",
    "equipaggiamo": "equipaggiare",
    "equipaggian": "equipaggiare",
    "equipaggiando": "equipaggiare",
    "equipaggiano": "equipaggiare",
    "equipaggiante": "equipaggiare",
    "equipaggianti": "equipaggiare",
    "equipaggiar": "equipaggiare",
    "equipaggiaron": "equipaggiare",
    "equipaggiarono": "equipaggiare",
    "equipaggiasse": "equipaggiare",
    "equipaggiasser": "equipaggiare",
    "equipaggiassero": "equipaggiare",
    "equipaggiassi": "equipaggiare",
    "equipaggiassimo": "equipaggiare",
    "equipaggiaste": "equipaggiare",
    "equipaggiasti": "equipaggiare",
    "equipaggiata": "equipaggiato",
    "equipaggiate": "equipaggiato",
    "equipaggiati": "equipaggiato",
    "equipaggiato": "equipaggiare",
    "equipaggiava": "equipaggiare",
    "equipaggiavamo": "equipaggiare",
    "equipaggiavan": "equipaggiare",
    "equipaggiavano": "equipaggiare",
    "equipaggiavate": "equipaggiare",
    "equipaggiavi": "equipaggiare",
    "equipaggiavo": "equipaggiare",
    "equipaggin": "equipaggiare",
    "equipaggino": "equipaggiare",
    "equipaggio": "equipaggiare",
    "equipaggiò": "equipaggiare",
    "equipara": "equiparare",
    "equiparabili": "equiparabile",
    "equiparai": "equiparare",
    "equiparammo": "equiparare",
    "equiparan": "equiparare",
    "equiparando": "equiparare",
    "equiparano": "equiparare",
    "equiparante": "equiparare",
    "equiparanti": "equiparare",
    "equiparar": "equiparare",
    "equipararon": "equiparare",
    "equipararono": "equiparare",
    "equiparasse": "equiparare",
    "equiparasser": "equiparare",
    "equiparassero": "equiparare",
    "equiparassi": "equiparare",
    "equiparassimo": "equiparare",
    "equiparaste": "equiparare",
    "equiparasti": "equiparare",
    "equiparata": "equiparare",
    "equiparate": "equiparare",
    "equiparati": "equiparare",
    "equiparato": "equiparare",
    "equiparava": "equiparare",
    "equiparavamo": "equiparare",
    "equiparavan": "equiparare",
    "equiparavano": "equiparare",
    "equiparavate": "equiparare",
    "equiparavi": "equiparare",
    "equiparavo": "equiparare",
    "equiparazioni": "equiparazione",
    "equiparerai": "equiparare",
    "equipareran": "equiparare",
    "equipareranno": "equiparare",
    "equiparerebbe": "equiparare",
    "equiparerebber": "equiparare",
    "equiparerebbero": "equiparare",
    "equiparerei": "equiparare",
    "equipareremmo": "equiparare",
    "equipareremo": "equiparare",
    "equiparereste": "equiparare",
    "equipareresti": "equiparare",
    "equiparerete": "equiparare",
    "equiparerà": "equiparare",
    "equiparerò": "equiparare",
    "equipari": "equiparare",
    "equipariamo": "equiparare",
    "equipariate": "equiparare",
    "equiparin": "equiparare",
    "equiparino": "equiparare",
    "equiparo": "equiparare",
    "equiparò": "equiparare",
    "equipollenti": "equipollente",
    "equivale": "equivalere",
    "equivalemmo": "equivalere",
    "equivalendo": "equivalere",
    "equivalente": "equivalere",
    "equivalenti": "equivalere",
    "equivalenze": "equivalenza",
    "equivaler": "equivalere",
    "equivalesse": "equivalere",
    "equivalesser": "equivalere",
    "equivalessero": "equivalere",
    "equivalessi": "equivalere",
    "equivalessimo": "equivalere",
    "equivaleste": "equivalere",
    "equivalesti": "equivalere",
    "equivalete": "equivalere",
    "equivaleva": "equivalere",
    "equivalevamo": "equivalere",
    "equivalevan": "equivalere",
    "equivalevano": "equivalere",
    "equivalevate": "equivalere",
    "equivalevi": "equivalere",
    "equivalevo": "equivalere",
    "equivalga": "equivalere",
    "equivalgan": "equivalere",
    "equivalgano": "equivalere",
    "equivalgo": "equivalere",
    "equivalgon": "equivalere",
    "equivalgono": "equivalere",
    "equivali": "equivalere",
    "equivaliamo": "equivalere",
    "equivaliate": "equivalere",
    "equivalsa": "equivalere",
    "equivalse": "equivalere",
    "equivalser": "equivalere",
    "equivalsero": "equivalere",
    "equivalsi": "equivalere",
    "equivalso": "equivalere",
    "equivarrai": "equivalere",
    "equivarran": "equivalere",
    "equivarranno": "equivalere",
    "equivarrebbe": "equivalere",
    "equivarrebber": "equivalere",
    "equivarrebbero": "equivalere",
    "equivarrei": "equivalere",
    "equivarremmo": "equivalere",
    "equivarremo": "equivalere",
    "equivarreste": "equivalere",
    "equivarresti": "equivalere",
    "equivarrete": "equivalere",
    "equivarrà": "equivalere",
    "equivarrò": "equivalere",
    "equivoca": "equivoco",
    "equivocai": "equivocare",
    "equivocammo": "equivocare",
    "equivocan": "equivocare",
    "equivocando": "equivocare",
    "equivocano": "equivocare",
    "equivocante": "equivocare",
    "equivocanti": "equivocare",
    "equivocar": "equivocare",
    "equivocaron": "equivocare",
    "equivocarono": "equivocare",
    "equivocasse": "equivocare",
    "equivocasser": "equivocare",
    "equivocassero": "equivocare",
    "equivocassi": "equivocare",
    "equivocassimo": "equivocare",
    "equivocaste": "equivocare",
    "equivocasti": "equivocare",
    "equivocata": "equivocare",
    "equivocate": "equivocare",
    "equivocati": "equivocare",
    "equivocato": "equivocare",
    "equivocava": "equivocare",
    "equivocavamo": "equivocare",
    "equivocavan": "equivocare",
    "equivocavano": "equivocare",
    "equivocavate": "equivocare",
    "equivocavi": "equivocare",
    "equivocavo": "equivocare",
    "equivoche": "equivoco",
    "equivocherai": "equivocare",
    "equivocheran": "equivocare",
    "equivocheranno": "equivocare",
    "equivocherebbe": "equivocare",
    "equivocherebber": "equivocare",
    "equivocherebbero": "equivocare",
    "equivocherei": "equivocare",
    "equivocheremmo": "equivocare",
    "equivocheremo": "equivocare",
    "equivochereste": "equivocare",
    "equivocheresti": "equivocare",
    "equivocherete": "equivocare",
    "equivocherà": "equivocare",
    "equivocherò": "equivocare",
    "equivochi": "equivocare",
    "equivochiamo": "equivocare",
    "equivochiate": "equivocare",
    "equivochin": "equivocare",
    "equivochino": "equivocare",
    "equivoci": "equivoco",
    "equivoco": "equivocare",
    "equivocò": "equivocare",
    "equlibri": "equlibrio",
    "era": "essere",
    "eradica": "eradicare",
    "eradicai": "eradicare",
    "eradicammo": "eradicare",
    "eradican": "eradicare",
    "eradicando": "eradicare",
    "eradicano": "eradicare",
    "eradicante": "eradicare",
    "eradicanti": "eradicare",
    "eradicar": "eradicare",
    "eradicaron": "eradicare",
    "eradicarono": "eradicare",
    "eradicasse": "eradicare",
    "eradicasser": "eradicare",
    "eradicassero": "eradicare",
    "eradicassi": "eradicare",
    "eradicassimo": "eradicare",
    "eradicaste": "eradicare",
    "eradicasti": "eradicare",
    "eradicata": "eradicare",
    "eradicate": "eradicare",
    "eradicati": "eradicare",
    "eradicato": "eradicare",
    "eradicava": "eradicare",
    "eradicavamo": "eradicare",
    "eradicavan": "eradicare",
    "eradicavano": "eradicare",
    "eradicavate": "eradicare",
    "eradicavi": "eradicare",
    "eradicavo": "eradicare",
    "eradicherai": "eradicare",
    "eradicheran": "eradicare",
    "eradicheranno": "eradicare",
    "eradicherebbe": "eradicare",
    "eradicherebber": "eradicare",
    "eradicherebbero": "eradicare",
    "eradicherei": "eradicare",
    "eradicheremmo": "eradicare",
    "eradicheremo": "eradicare",
    "eradichereste": "eradicare",
    "eradicheresti": "eradicare",
    "eradicherete": "eradicare",
    "eradicherà": "eradicare",
    "eradicherò": "eradicare",
    "eradichi": "eradicare",
    "eradichiamo": "eradicare",
    "eradichiate": "eradicare",
    "eradichin": "eradicare",
    "eradichino": "eradicare",
    "eradico": "eradicare",
    "eradicò": "eradicare",
    "eran": "essere",
    "erano": "essere",
    "erari": "erario",
    "erariali": "erariale",
    "eravamo": "essere",
    "eravate": "essere",
    "erbacce": "erbaccia",
    "erbe": "erba",
    "erbette": "erbetta",
    "erbivora": "erbivoro",
    "erbivore": "erbivoro",
    "erbivori": "erbivoro",
    "erboristerie": "erboristeria",
    "erboristi": "erborista",
    "erbosa": "erboso",
    "erbose": "erboso",
    "erbosi": "erboso",
    "erculea": "erculeo",
    "erculee": "erculeo",
    "erculei": "erculeo",
    "ere": "era",
    "eredi": "erede",
    "eredita": "ereditare",
    "ereditai": "ereditare",
    "ereditammo": "ereditare",
    "ereditan": "ereditare",
    "ereditando": "ereditare",
    "ereditano": "ereditare",
    "ereditante": "ereditare",
    "ereditanti": "ereditare",
    "ereditar": "ereditare",
    "ereditari": "ereditario",
    "ereditaria": "ereditario",
    "ereditarie": "ereditario",
    "ereditaron": "ereditare",
    "ereditarono": "ereditare",
    "ereditasse": "ereditare",
    "ereditasser": "ereditare",
    "ereditassero": "ereditare",
    "ereditassi": "ereditare",
    "ereditassimo": "ereditare",
    "ereditaste": "ereditare",
    "ereditasti": "ereditare",
    "ereditata": "ereditare",
    "ereditate": "ereditare",
    "ereditati": "ereditare",
    "ereditato": "ereditare",
    "ereditava": "ereditare",
    "ereditavamo": "ereditare",
    "ereditavan": "ereditare",
    "ereditavano": "ereditare",
    "ereditavate": "ereditare",
    "ereditavi": "ereditare",
    "ereditavo": "ereditare",
    "erediterai": "ereditare",
    "erediteran": "ereditare",
    "erediteranno": "ereditare",
    "erediterebbe": "ereditare",
    "erediterebber": "ereditare",
    "erediterebbero": "ereditare",
    "erediterei": "ereditare",
    "erediteremmo": "ereditare",
    "erediteremo": "ereditare",
    "ereditereste": "ereditare",
    "erediteresti": "ereditare",
    "erediterete": "ereditare",
    "erediterà": "ereditare",
    "erediterò": "ereditare",
    "erediti": "ereditare",
    "ereditiamo": "ereditare",
    "ereditiate": "ereditare",
    "ereditiere": "ereditiera",
    "ereditin": "ereditare",
    "ereditino": "ereditare",
    "eredito": "ereditare",
    "ereditò": "ereditare",
    "eremiti": "eremita",
    "eresie": "eresia",
    "eretica": "eretico",
    "eretiche": "eretico",
    "eretici": "eretico",
    "eretismi": "eretismo",
    "eretta": "eretto",
    "erette": "eretto",
    "eretti": "eretto",
    "erezioni": "erezione",
    "erga": "ergere",
    "ergan": "ergere",
    "ergano": "ergere",
    "ergastolani": "ergastolano",
    "ergastoli": "ergastolo",
    "erge": "ergere",
    "ergemmo": "ergere",
    "ergendo": "ergere",
    "ergente": "ergere",
    "ergenti": "ergere",
    "erger": "ergere",
    "ergerai": "ergere",
    "ergeran": "ergere",
    "ergeranno": "ergere",
    "ergerebbe": "ergere",
    "ergerebber": "ergere",
    "ergerebbero": "ergere",
    "ergerei": "ergere",
    "ergeremmo": "ergere",
    "ergeremo": "ergere",
    "ergereste": "ergere",
    "ergeresti": "ergere",
    "ergerete": "ergere",
    "ergerà": "ergere",
    "ergerò": "ergere",
    "ergesse": "ergere",
    "ergesser": "ergere",
    "ergessero": "ergere",
    "ergessi": "ergere",
    "ergessimo": "ergere",
    "ergeste": "ergere",
    "ergesti": "ergere",
    "ergete": "ergere",
    "ergeva": "ergere",
    "ergevamo": "ergere",
    "ergevan": "ergere",
    "ergevano": "ergere",
    "ergevate": "ergere",
    "ergevi": "ergere",
    "ergevo": "ergere",
    "ergi": "ergere",
    "ergiamo": "ergere",
    "ergiate": "ergere",
    "ergo": "ergere",
    "ergon": "ergere",
    "ergono": "ergere",
    "eri": "essere",
    "eriga": "erigere",
    "erigan": "erigere",
    "erigano": "erigere",
    "erige": "erigere",
    "erigei": "erigere",
    "erigemmo": "erigere",
    "erigenda": "erigendo",
    "erigende": "erigendo",
    "erigendi": "erigendo",
    "erigendo": "erigere",
    "erigente": "erigere",
    "erigenti": "erigere",
    "eriger": "erigere",
    "erigerai": "erigere",
    "erigeran": "erigere",
    "erigeranno": "erigere",
    "erigerebbe": "erigere",
    "erigerebber": "erigere",
    "erigerebbero": "erigere",
    "erigerei": "erigere",
    "erigeremmo": "erigere",
    "erigeremo": "erigere",
    "erigereste": "erigere",
    "erigeresti": "erigere",
    "erigerete": "erigere",
    "erigeron": "erigere",
    "erigerono": "erigere",
    "erigerà": "erigere",
    "erigerò": "erigere",
    "erigesse": "erigere",
    "erigesser": "erigere",
    "erigessero": "erigere",
    "erigessi": "erigere",
    "erigessimo": "erigere",
    "erigeste": "erigere",
    "erigesti": "erigere",
    "erigete": "erigere",
    "erigeva": "erigere",
    "erigevamo": "erigere",
    "erigevan": "erigere",
    "erigevano": "erigere",
    "erigevate": "erigere",
    "erigevi": "erigere",
    "erigevo": "erigere",
    "erigi": "erigere",
    "erigiamo": "erigere",
    "erigiate": "erigere",
    "erigiuta": "erigere",
    "erigiute": "erigere",
    "erigiuti": "erigere",
    "erigiuto": "erigere",
    "erigo": "erigere",
    "erigon": "erigere",
    "erigono": "erigere",
    "erigè": "erigere",
    "eritrea": "eritreo",
    "eritree": "eritreo",
    "eritrei": "eritreo",
    "ermafrodita": "ermafrodito",
    "ermafrodite": "ermafrodito",
    "ermafroditi": "ermafrodito",
    "ermellini": "ermellino",
    "ermetica": "ermetico",
    "ermetiche": "ermetico",
    "ermetici": "ermetico",
    "ernie": "ernia",
    "ero": "essere",
    "eroda": "erodere",
    "erodan": "erodere",
    "erodano": "erodere",
    "erode": "erodere",
    "erodemmo": "erodere",
    "erodendo": "erodere",
    "erodente": "erodere",
    "erodenti": "erodere",
    "eroder": "erodere",
    "eroderai": "erodere",
    "eroderan": "erodere",
    "eroderanno": "erodere",
    "eroderebbe": "erodere",
    "eroderebber": "erodere",
    "eroderebbero": "erodere",
    "eroderei": "erodere",
    "eroderemmo": "erodere",
    "eroderemo": "erodere",
    "erodereste": "erodere",
    "eroderesti": "erodere",
    "eroderete": "erodere",
    "eroderà": "erodere",
    "eroderò": "erodere",
    "erodesse": "erodere",
    "erodesser": "erodere",
    "erodessero": "erodere",
    "erodessi": "erodere",
    "erodessimo": "erodere",
    "erodeste": "erodere",
    "erodesti": "erodere",
    "erodete": "erodere",
    "erodeva": "erodere",
    "erodevamo": "erodere",
    "erodevan": "erodere",
    "erodevano": "erodere",
    "erodevate": "erodere",
    "erodevi": "erodere",
    "erodevo": "erodere",
    "erodi": "erodere",
    "erodiamo": "erodere",
    "erodiate": "erodere",
    "erodo": "erodere",
    "erodon": "erodere",
    "erodono": "erodere",
    "eroga": "erogare",
    "erogabili": "erogabile",
    "erogai": "erogare",
    "erogammo": "erogare",
    "erogan": "erogare",
    "erogando": "erogare",
    "erogano": "erogare",
    "erogante": "erogare",
    "eroganti": "erogare",
    "erogar": "erogare",
    "erogaron": "erogare",
    "erogarono": "erogare",
    "erogasse": "erogare",
    "erogasser": "erogare",
    "erogassero": "erogare",
    "erogassi": "erogare",
    "erogassimo": "erogare",
    "erogaste": "erogare",
    "erogasti": "erogare",
    "erogata": "erogare",
    "erogate": "erogare",
    "erogati": "erogare",
    "erogato": "erogare",
    "erogatori": "erogatore",
    "erogatrice": "erogatore",
    "erogatrici": "erogatore",
    "erogava": "erogare",
    "erogavamo": "erogare",
    "erogavan": "erogare",
    "erogavano": "erogare",
    "erogavate": "erogare",
    "erogavi": "erogare",
    "erogavo": "erogare",
    "erogazioni": "erogazione",
    "erogherai": "erogare",
    "erogheran": "erogare",
    "erogheranno": "erogare",
    "erogherebbe": "erogare",
    "erogherebber": "erogare",
    "erogherebbero": "erogare",
    "erogherei": "erogare",
    "erogheremmo": "erogare",
    "erogheremo": "erogare",
    "eroghereste": "erogare",
    "erogheresti": "erogare",
    "erogherete": "erogare",
    "erogherà": "erogare",
    "erogherò": "erogare",
    "eroghi": "erogare",
    "eroghiamo": "erogare",
    "eroghiate": "erogare",
    "eroghin": "erogare",
    "eroghino": "erogare",
    "erogo": "erogare",
    "erogò": "erogare",
    "eroi": "eroe",
    "eroica": "eroico",
    "eroiche": "eroico",
    "eroici": "eroico",
    "eroicizza": "eroicizzare",
    "eroicizzai": "eroicizzare",
    "eroicizzammo": "eroicizzare",
    "eroicizzan": "eroicizzare",
    "eroicizzando": "eroicizzare",
    "eroicizzano": "eroicizzare",
    "eroicizzante": "eroicizzare",
    "eroicizzanti": "eroicizzare",
    "eroicizzar": "eroicizzare",
    "eroicizzaron": "eroicizzare",
    "eroicizzarono": "eroicizzare",
    "eroicizzasse": "eroicizzare",
    "eroicizzasser": "eroicizzare",
    "eroicizzassero": "eroicizzare",
    "eroicizzassi": "eroicizzare",
    "eroicizzassimo": "eroicizzare",
    "eroicizzaste": "eroicizzare",
    "eroicizzasti": "eroicizzare",
    "eroicizzata": "eroicizzare",
    "eroicizzate": "eroicizzare",
    "eroicizzati": "eroicizzare",
    "eroicizzato": "eroicizzare",
    "eroicizzava": "eroicizzare",
    "eroicizzavamo": "eroicizzare",
    "eroicizzavan": "eroicizzare",
    "eroicizzavano": "eroicizzare",
    "eroicizzavate": "eroicizzare",
    "eroicizzavi": "eroicizzare",
    "eroicizzavo": "eroicizzare",
    "eroicizzerai": "eroicizzare",
    "eroicizzeran": "eroicizzare",
    "eroicizzeranno": "eroicizzare",
    "eroicizzerebbe": "eroicizzare",
    "eroicizzerebber": "eroicizzare",
    "eroicizzerebbero": "eroicizzare",
    "eroicizzerei": "eroicizzare",
    "eroicizzeremmo": "eroicizzare",
    "eroicizzeremo": "eroicizzare",
    "eroicizzereste": "eroicizzare",
    "eroicizzeresti": "eroicizzare",
    "eroicizzerete": "eroicizzare",
    "eroicizzerà": "eroicizzare",
    "eroicizzerò": "eroicizzare",
    "eroicizzi": "eroicizzare",
    "eroicizziamo": "eroicizzare",
    "eroicizziate": "eroicizzare",
    "eroicizzin": "eroicizzare",
    "eroicizzino": "eroicizzare",
    "eroicizzo": "eroicizzare",
    "eroicizzò": "eroicizzare",
    "eroicomica": "eroicomico",
    "eroicomiche": "eroicomico",
    "eroicomici": "eroicomico",
    "eroine": "eroina",
    "eroinomani": "eroinomane",
    "eroismi": "eroismo",
    "erompa": "erompere",
    "erompan": "erompere",
    "erompano": "erompere",
    "erompe": "erompere",
    "erompemmo": "erompere",
    "erompendo": "erompere",
    "erompente": "erompere",
    "erompenti": "erompere",
    "eromper": "erompere",
    "eromperai": "erompere",
    "eromperan": "erompere",
    "eromperanno": "erompere",
    "eromperebbe": "erompere",
    "eromperebber": "erompere",
    "eromperebbero": "erompere",
    "eromperei": "erompere",
    "eromperemmo": "erompere",
    "eromperemo": "erompere",
    "erompereste": "erompere",
    "eromperesti": "erompere",
    "eromperete": "erompere",
    "eromperà": "erompere",
    "eromperò": "erompere",
    "erompesse": "erompere",
    "erompesser": "erompere",
    "erompessero": "erompere",
    "erompessi": "erompere",
    "erompessimo": "erompere",
    "erompeste": "erompere",
    "erompesti": "erompere",
    "erompete": "erompere",
    "erompeva": "erompere",
    "erompevamo": "erompere",
    "erompevan": "erompere",
    "erompevano": "erompere",
    "erompevate": "erompere",
    "erompevi": "erompere",
    "erompevo": "erompere",
    "erompi": "erompere",
    "erompiamo": "erompere",
    "erompiate": "erompere",
    "erompo": "erompere",
    "erompon": "erompere",
    "erompono": "erompere",
    "erosa": "erodere",
    "erose": "erodere",
    "eroser": "erodere",
    "erosero": "erodere",
    "erosi": "erodere",
    "erosioni": "erosione",
    "erosiva": "erosivo",
    "erosive": "erosivo",
    "erosivi": "erosivo",
    "eroso": "erodere",
    "erotica": "erotico",
    "erotiche": "erotico",
    "erotici": "erotico",
    "erotismi": "erotismo",
    "erotizza": "erotizzare",
    "erotizzai": "erotizzare",
    "erotizzammo": "erotizzare",
    "erotizzan": "erotizzare",
    "erotizzando": "erotizzare",
    "erotizzano": "erotizzare",
    "erotizzante": "erotizzare",
    "erotizzanti": "erotizzare",
    "erotizzar": "erotizzare",
    "erotizzaron": "erotizzare",
    "erotizzarono": "erotizzare",
    "erotizzasse": "erotizzare",
    "erotizzasser": "erotizzare",
    "erotizzassero": "erotizzare",
    "erotizzassi": "erotizzare",
    "erotizzassimo": "erotizzare",
    "erotizzaste": "erotizzare",
    "erotizzasti": "erotizzare",
    "erotizzata": "erotizzare",
    "erotizzate": "erotizzare",
    "erotizzati": "erotizzare",
    "erotizzato": "erotizzare",
    "erotizzava": "erotizzare",
    "erotizzavamo": "erotizzare",
    "erotizzavan": "erotizzare",
    "erotizzavano": "erotizzare",
    "erotizzavate": "erotizzare",
    "erotizzavi": "erotizzare",
    "erotizzavo": "erotizzare",
    "erotizzerai": "erotizzare",
    "erotizzeran": "erotizzare",
    "erotizzeranno": "erotizzare",
    "erotizzerebbe": "erotizzare",
    "erotizzerebber": "erotizzare",
    "erotizzerebbero": "erotizzare",
    "erotizzerei": "erotizzare",
    "erotizzeremmo": "erotizzare",
    "erotizzeremo": "erotizzare",
    "erotizzereste": "erotizzare",
    "erotizzeresti": "erotizzare",
    "erotizzerete": "erotizzare",
    "erotizzerà": "erotizzare",
    "erotizzerò": "erotizzare",
    "erotizzi": "erotizzare",
    "erotizziamo": "erotizzare",
    "erotizziate": "erotizzare",
    "erotizzin": "erotizzare",
    "erotizzino": "erotizzare",
    "erotizzo": "erotizzare",
    "erotizzò": "erotizzare",
    "erotomani": "erotomane",
    "erotta": "erompere",
    "erotte": "erompere",
    "erotti": "erompere",
    "erotto": "erompere",
    "erra": "errare",
    "errabonda": "errabondo",
    "errabonde": "errabondo",
    "errabondi": "errabondo",
    "errai": "errare",
    "errammo": "errare",
    "erran": "errare",
    "errando": "errare",
    "errano": "errare",
    "errante": "errare",
    "erranti": "errare",
    "errar": "errare",
    "erraron": "errare",
    "errarono": "errare",
    "errasse": "errare",
    "errasser": "errare",
    "errassero": "errare",
    "errassi": "errare",
    "errassimo": "errare",
    "erraste": "errare",
    "errasti": "errare",
    "errata": "errato",
    "errate": "errato",
    "errati": "errato",
    "erratica": "erratico",
    "erratiche": "erratico",
    "erratici": "erratico",
    "errato": "errare",
    "errava": "errare",
    "erravamo": "errare",
    "erravan": "errare",
    "erravano": "errare",
    "erravate": "errare",
    "erravi": "errare",
    "erravo": "errare",
    "errerai": "errare",
    "erreran": "errare",
    "erreranno": "errare",
    "errerebbe": "errare",
    "errerebber": "errare",
    "errerebbero": "errare",
    "errerei": "errare",
    "erreremmo": "errare",
    "erreremo": "errare",
    "errereste": "errare",
    "erreresti": "errare",
    "errerete": "errare",
    "errerà": "errare",
    "errerò": "errare",
    "erri": "errare",
    "erriamo": "errare",
    "erriate": "errare",
    "errin": "errare",
    "errino": "errare",
    "erro": "errare",
    "erronea": "erroneo",
    "erronee": "erroneo",
    "erronei": "erroneo",
    "errori": "errore",
    "errò": "errare",
    "erser": "ergere",
    "ersero": "ergere",
    "ersi": "ergere",
    "ersè": "ergere",
    "erta": "ergere",
    "erte": "ergere",
    "erti": "ergere",
    "erto": "ergere",
    "eruda": "erudire",
    "erudan": "erudire",
    "erudano": "erudire",
    "erude": "erudire",
    "erudendo": "erudire",
    "erudente": "erudire",
    "erudenti": "erudire",
    "erudi": "erudire",
    "erudiamo": "erudire",
    "erudiate": "erudire",
    "erudii": "erudire",
    "erudimmo": "erudire",
    "erudir": "erudire",
    "erudirai": "erudire",
    "erudiran": "erudire",
    "erudiranno": "erudire",
    "erudirebbe": "erudire",
    "erudirebber": "erudire",
    "erudirebbero": "erudire",
    "erudirei": "erudire",
    "erudiremmo": "erudire",
    "erudiremo": "erudire",
    "erudireste": "erudire",
    "erudiresti": "erudire",
    "erudirete": "erudire",
    "erudiron": "erudire",
    "erudirono": "erudire",
    "erudirà": "erudire",
    "erudirò": "erudire",
    "erudisse": "erudire",
    "erudisser": "erudire",
    "erudissero": "erudire",
    "erudissi": "erudire",
    "erudissimo": "erudire",
    "erudiste": "erudire",
    "erudisti": "erudire",
    "erudita": "erudito",
    "erudite": "erudito",
    "eruditi": "erudito",
    "erudito": "erudire",
    "erudiva": "erudire",
    "erudivamo": "erudire",
    "erudivan": "erudire",
    "erudivano": "erudire",
    "erudivate": "erudire",
    "erudivi": "erudire",
    "erudivo": "erudire",
    "erudizioni": "erudizione",
    "erudo": "erudire",
    "erudon": "erudire",
    "erudono": "erudire",
    "erudì": "erudire",
    "eruppe": "erompere",
    "erupper": "erompere",
    "eruppero": "erompere",
    "eruppi": "erompere",
    "erutta": "eruttare",
    "eruttai": "eruttare",
    "eruttammo": "eruttare",
    "eruttan": "eruttare",
    "eruttando": "eruttare",
    "eruttano": "eruttare",
    "eruttante": "eruttare",
    "eruttanti": "eruttare",
    "eruttar": "eruttare",
    "eruttaron": "eruttare",
    "eruttarono": "eruttare",
    "eruttasse": "eruttare",
    "eruttasser": "eruttare",
    "eruttassero": "eruttare",
    "eruttassi": "eruttare",
    "eruttassimo": "eruttare",
    "eruttaste": "eruttare",
    "eruttasti": "eruttare",
    "eruttata": "eruttare",
    "eruttate": "eruttare",
    "eruttati": "eruttare",
    "eruttato": "eruttare",
    "eruttava": "eruttare",
    "eruttavamo": "eruttare",
    "eruttavan": "eruttare",
    "eruttavano": "eruttare",
    "eruttavate": "eruttare",
    "eruttavi": "eruttare",
    "eruttavo": "eruttare",
    "erutterai": "eruttare",
    "erutteran": "eruttare",
    "erutteranno": "eruttare",
    "erutterebbe": "eruttare",
    "erutterebber": "eruttare",
    "erutterebbero": "eruttare",
    "erutterei": "eruttare",
    "erutteremmo": "eruttare",
    "erutteremo": "eruttare",
    "eruttereste": "eruttare",
    "erutteresti": "eruttare",
    "erutterete": "eruttare",
    "erutterà": "eruttare",
    "erutterò": "eruttare",
    "erutti": "eruttare",
    "eruttiamo": "eruttare",
    "eruttiate": "eruttare",
    "eruttin": "eruttare",
    "eruttino": "eruttare",
    "erutto": "eruttare",
    "eruttò": "eruttare",
    "eruzioni": "eruzione",
    "erzegovesi": "erzegovese",
    "esacerba": "esacerbare",
    "esacerbai": "esacerbare",
    "esacerbammo": "esacerbare",
    "esacerban": "esacerbare",
    "esacerbando": "esacerbare",
    "esacerbano": "esacerbare",
    "esacerbante": "esacerbare",
    "esacerbanti": "esacerbare",
    "esacerbar": "esacerbare",
    "esacerbaron": "esacerbare",
    "esacerbarono": "esacerbare",
    "esacerbasse": "esacerbare",
    "esacerbasser": "esacerbare",
    "esacerbassero": "esacerbare",
    "esacerbassi": "esacerbare",
    "esacerbassimo": "esacerbare",
    "esacerbaste": "esacerbare",
    "esacerbasti": "esacerbare",
    "esacerbata": "esacerbato",
    "esacerbate": "esacerbato",
    "esacerbati": "esacerbato",
    "esacerbato": "esacerbare",
    "esacerbava": "esacerbare",
    "esacerbavamo": "esacerbare",
    "esacerbavan": "esacerbare",
    "esacerbavano": "esacerbare",
    "esacerbavate": "esacerbare",
    "esacerbavi": "esacerbare",
    "esacerbavo": "esacerbare",
    "esacerberai": "esacerbare",
    "esacerberan": "esacerbare",
    "esacerberanno": "esacerbare",
    "esacerberebbe": "esacerbare",
    "esacerberebber": "esacerbare",
    "esacerberebbero": "esacerbare",
    "esacerberei": "esacerbare",
    "esacerberemmo": "esacerbare",
    "esacerberemo": "esacerbare",
    "esacerbereste": "esacerbare",
    "esacerberesti": "esacerbare",
    "esacerberete": "esacerbare",
    "esacerberà": "esacerbare",
    "esacerberò": "esacerbare",
    "esacerbi": "esacerbare",
    "esacerbiamo": "esacerbare",
    "esacerbiate": "esacerbare",
    "esacerbin": "esacerbare",
    "esacerbino": "esacerbare",
    "esacerbo": "esacerbare",
    "esacerbò": "esacerbare",
    "esagera": "esagerare",
    "esagerai": "esagerare",
    "esagerammo": "esagerare",
    "esageran": "esagerare",
    "esagerando": "esagerare",
    "esagerano": "esagerare",
    "esagerante": "esagerare",
    "esageranti": "esagerare",
    "esagerar": "esagerare",
    "esageraron": "esagerare",
    "esagerarono": "esagerare",
    "esagerasse": "esagerare",
    "esagerasser": "esagerare",
    "esagerassero": "esagerare",
    "esagerassi": "esagerare",
    "esagerassimo": "esagerare",
    "esageraste": "esagerare",
    "esagerasti": "esagerare",
    "esagerata": "esagerato",
    "esagerate": "esagerato",
    "esagerati": "esagerato",
    "esagerato": "esagerare",
    "esagerava": "esagerare",
    "esageravamo": "esagerare",
    "esageravan": "esagerare",
    "esageravano": "esagerare",
    "esageravate": "esagerare",
    "esageravi": "esagerare",
    "esageravo": "esagerare",
    "esagerazioni": "esagerazione",
    "esagererai": "esagerare",
    "esagereran": "esagerare",
    "esagereranno": "esagerare",
    "esagererebbe": "esagerare",
    "esagererebber": "esagerare",
    "esagererebbero": "esagerare",
    "esagererei": "esagerare",
    "esagereremmo": "esagerare",
    "esagereremo": "esagerare",
    "esagerereste": "esagerare",
    "esagereresti": "esagerare",
    "esagererete": "esagerare",
    "esagererà": "esagerare",
    "esagererò": "esagerare",
    "esageri": "esagerare",
    "esageriamo": "esagerare",
    "esageriate": "esagerare",
    "esagerin": "esagerare",
    "esagerino": "esagerare",
    "esagero": "esagerare",
    "esagerò": "esagerare",
    "esagita": "esagitare",
    "esagitai": "esagitare",
    "esagitammo": "esagitare",
    "esagitan": "esagitare",
    "esagitando": "esagitare",
    "esagitano": "esagitare",
    "esagitante": "esagitare",
    "esagitanti": "esagitare",
    "esagitar": "esagitare",
    "esagitaron": "esagitare",
    "esagitarono": "esagitare",
    "esagitasse": "esagitare",
    "esagitasser": "esagitare",
    "esagitassero": "esagitare",
    "esagitassi": "esagitare",
    "esagitassimo": "esagitare",
    "esagitaste": "esagitare",
    "esagitasti": "esagitare",
    "esagitata": "esagitato",
    "esagitate": "esagitato",
    "esagitati": "esagitato",
    "esagitato": "esagitare",
    "esagitava": "esagitare",
    "esagitavamo": "esagitare",
    "esagitavan": "esagitare",
    "esagitavano": "esagitare",
    "esagitavate": "esagitare",
    "esagitavi": "esagitare",
    "esagitavo": "esagitare",
    "esagiterai": "esagitare",
    "esagiteran": "esagitare",
    "esagiteranno": "esagitare",
    "esagiterebbe": "esagitare",
    "esagiterebber": "esagitare",
    "esagiterebbero": "esagitare",
    "esagiterei": "esagitare",
    "esagiteremmo": "esagitare",
    "esagiteremo": "esagitare",
    "esagitereste": "esagitare",
    "esagiteresti": "esagitare",
    "esagiterete": "esagitare",
    "esagiterà": "esagitare",
    "esagiterò": "esagitare",
    "esagiti": "esagitare",
    "esagitiamo": "esagitare",
    "esagitiate": "esagitare",
    "esagitin": "esagitare",
    "esagitino": "esagitare",
    "esagito": "esagitare",
    "esagitò": "esagitare",
    "esagonali": "esagonale",
    "esala": "esalare",
    "esalai": "esalare",
    "esalammo": "esalare",
    "esalan": "esalare",
    "esalando": "esalare",
    "esalano": "esalare",
    "esalante": "esalare",
    "esalanti": "esalare",
    "esalar": "esalare",
    "esalaron": "esalare",
    "esalarono": "esalare",
    "esalasse": "esalare",
    "esalasser": "esalare",
    "esalassero": "esalare",
    "esalassi": "esalare",
    "esalassimo": "esalare",
    "esalaste": "esalare",
    "esalasti": "esalare",
    "esalata": "esalare",
    "esalate": "esalare",
    "esalati": "esalare",
    "esalato": "esalare",
    "esalava": "esalare",
    "esalavamo": "esalare",
    "esalavan": "esalare",
    "esalavano": "esalare",
    "esalavate": "esalare",
    "esalavi": "esalare",
    "esalavo": "esalare",
    "esalazioni": "esalazione",
    "esalerai": "esalare",
    "esaleran": "esalare",
    "esaleranno": "esalare",
    "esalerebbe": "esalare",
    "esalerebber": "esalare",
    "esalerebbero": "esalare",
    "esalerei": "esalare",
    "esaleremmo": "esalare",
    "esaleremo": "esalare",
    "esalereste": "esalare",
    "esaleresti": "esalare",
    "esalerete": "esalare",
    "esalerà": "esalare",
    "esalerò": "esalare",
    "esali": "esalare",
    "esaliamo": "esalare",
    "esaliate": "esalare",
    "esalin": "esalare",
    "esalino": "esalare",
    "esalo": "esalare",
    "esalta": "esaltare",
    "esaltai": "esaltare",
    "esaltammo": "esaltare",
    "esaltan": "esaltare",
    "esaltando": "esaltare",
    "esaltano": "esaltare",
    "esaltante": "esaltare",
    "esaltanti": "esaltare",
    "esaltar": "esaltare",
    "esaltaron": "esaltare",
    "esaltarono": "esaltare",
    "esaltasse": "esaltare",
    "esaltasser": "esaltare",
    "esaltassero": "esaltare",
    "esaltassi": "esaltare",
    "esaltassimo": "esaltare",
    "esaltaste": "esaltare",
    "esaltasti": "esaltare",
    "esaltata": "esaltato",
    "esaltate": "esaltato",
    "esaltati": "esaltato",
    "esaltato": "esaltare",
    "esaltava": "esaltare",
    "esaltavamo": "esaltare",
    "esaltavan": "esaltare",
    "esaltavano": "esaltare",
    "esaltavate": "esaltare",
    "esaltavi": "esaltare",
    "esaltavo": "esaltare",
    "esaltazioni": "esaltazione",
    "esalterai": "esaltare",
    "esalteran": "esaltare",
    "esalteranno": "esaltare",
    "esalterebbe": "esaltare",
    "esalterebber": "esaltare",
    "esalterebbero": "esaltare",
    "esalterei": "esaltare",
    "esalteremmo": "esaltare",
    "esalteremo": "esaltare",
    "esaltereste": "esaltare",
    "esalteresti": "esaltare",
    "esalterete": "esaltare",
    "esalterà": "esaltare",
    "esalterò": "esaltare",
    "esalti": "esaltare",
    "esaltiamo": "esaltare",
    "esaltiate": "esaltare",
    "esaltin": "esaltare",
    "esaltino": "esaltare",
    "esalto": "esaltare",
    "esaltò": "esaltare",
    "esalò": "esalare",
    "esami": "esame",
    "esamina": "esaminare",
    "esaminai": "esaminare",
    "esaminammo": "esaminare",
    "esaminan": "esaminare",
    "esaminanda": "esaminando",
    "esaminande": "esaminando",
    "esaminandi": "esaminando",
    "esaminando": "esaminare",
    "esaminano": "esaminare",
    "esaminante": "esaminare",
    "esaminanti": "esaminare",
    "esaminar": "esaminare",
    "esaminaron": "esaminare",
    "esaminarono": "esaminare",
    "esaminasse": "esaminare",
    "esaminasser": "esaminare",
    "esaminassero": "esaminare",
    "esaminassi": "esaminare",
    "esaminassimo": "esaminare",
    "esaminaste": "esaminare",
    "esaminasti": "esaminare",
    "esaminata": "esaminare",
    "esaminate": "esaminare",
    "esaminati": "esaminare",
    "esaminato": "esaminare",
    "esaminatori": "esaminatore",
    "esaminava": "esaminare",
    "esaminavamo": "esaminare",
    "esaminavan": "esaminare",
    "esaminavano": "esaminare",
    "esaminavate": "esaminare",
    "esaminavi": "esaminare",
    "esaminavo": "esaminare",
    "esaminerai": "esaminare",
    "esamineran": "esaminare",
    "esamineranno": "esaminare",
    "esaminerebbe": "esaminare",
    "esaminerebber": "esaminare",
    "esaminerebbero": "esaminare",
    "esaminerei": "esaminare",
    "esamineremmo": "esaminare",
    "esamineremo": "esaminare",
    "esaminereste": "esaminare",
    "esamineresti": "esaminare",
    "esaminerete": "esaminare",
    "esaminerà": "esaminare",
    "esaminerò": "esaminare",
    "esamini": "esaminare",
    "esaminiamo": "esaminare",
    "esaminiate": "esaminare",
    "esaminin": "esaminare",
    "esaminino": "esaminare",
    "esamino": "esaminare",
    "esaminò": "esaminare",
    "esaspera": "esasperare",
    "esasperai": "esasperare",
    "esasperammo": "esasperare",
    "esasperan": "esasperare",
    "esasperando": "esasperare",
    "esasperano": "esasperare",
    "esasperante": "esasperare",
    "esasperanti": "esasperare",
    "esasperar": "esasperare",
    "esasperaron": "esasperare",
    "esasperarono": "esasperare",
    "esasperasse": "esasperare",
    "esasperasser": "esasperare",
    "esasperassero": "esasperare",
    "esasperassi": "esasperare",
    "esasperassimo": "esasperare",
    "esasperaste": "esasperare",
    "esasperasti": "esasperare",
    "esasperata": "esasperato",
    "esasperate": "esasperato",
    "esasperati": "esasperato",
    "esasperato": "esasperare",
    "esasperava": "esasperare",
    "esasperavamo": "esasperare",
    "esasperavan": "esasperare",
    "esasperavano": "esasperare",
    "esasperavate": "esasperare",
    "esasperavi": "esasperare",
    "esasperavo": "esasperare",
    "esasperazioni": "esasperazione",
    "esaspererai": "esasperare",
    "esaspereran": "esasperare",
    "esaspereranno": "esasperare",
    "esaspererebbe": "esasperare",
    "esaspererebber": "esasperare",
    "esaspererebbero": "esasperare",
    "esaspererei": "esasperare",
    "esaspereremmo": "esasperare",
    "esaspereremo": "esasperare",
    "esasperereste": "esasperare",
    "esaspereresti": "esasperare",
    "esaspererete": "esasperare",
    "esaspererà": "esasperare",
    "esaspererò": "esasperare",
    "esasperi": "esasperare",
    "esasperiamo": "esasperare",
    "esasperiate": "esasperare",
    "esasperin": "esasperare",
    "esasperino": "esasperare",
    "esaspero": "esasperare",
    "esasperò": "esasperare",
    "esatta": "esatto",
    "esatte": "esatto",
    "esattezze": "esattezza",
    "esatti": "esatto",
    "esattori": "esattore",
    "esattoriali": "esattoriale",
    "esattorie": "esattoria",
    "esaudendo": "esaudire",
    "esaudente": "esaudire",
    "esaudenti": "esaudire",
    "esaudiamo": "esaudire",
    "esaudiate": "esaudire",
    "esaudii": "esaudire",
    "esaudimmo": "esaudire",
    "esaudir": "esaudire",
    "esaudirai": "esaudire",
    "esaudiran": "esaudire",
    "esaudiranno": "esaudire",
    "esaudirebbe": "esaudire",
    "esaudirebber": "esaudire",
    "esaudirebbero": "esaudire",
    "esaudirei": "esaudire",
    "esaudiremmo": "esaudire",
    "esaudiremo": "esaudire",
    "esaudireste": "esaudire",
    "esaudiresti": "esaudire",
    "esaudirete": "esaudire",
    "esaudiron": "esaudire",
    "esaudirono": "esaudire",
    "esaudirà": "esaudire",
    "esaudirò": "esaudire",
    "esaudisca": "esaudire",
    "esaudiscan": "esaudire",
    "esaudiscano": "esaudire",
    "esaudisce": "esaudire",
    "esaudisci": "esaudire",
    "esaudisco": "esaudire",
    "esaudiscon": "esaudire",
    "esaudiscono": "esaudire",
    "esaudisse": "esaudire",
    "esaudisser": "esaudire",
    "esaudissero": "esaudire",
    "esaudissi": "esaudire",
    "esaudissimo": "esaudire",
    "esaudiste": "esaudire",
    "esaudisti": "esaudire",
    "esaudita": "esaudire",
    "esaudite": "esaudire",
    "esauditi": "esaudire",
    "esaudito": "esaudire",
    "esaudiva": "esaudire",
    "esaudivamo": "esaudire",
    "esaudivan": "esaudire",
    "esaudivano": "esaudire",
    "esaudivate": "esaudire",
    "esaudivi": "esaudire",
    "esaudivo": "esaudire",
    "esaudì": "esaudire",
    "esaurendo": "esaurire",
    "esaurente": "esaurire",
    "esaurenti": "esaurire",
    "esauriamo": "esaurire",
    "esauriate": "esaurire",
    "esauribili": "esauribile",
    "esaurienti": "esauriente",
    "esaurii": "esaurire",
    "esaurimenti": "esaurimento",
    "esaurimmo": "esaurire",
    "esaurir": "esaurire",
    "esaurirai": "esaurire",
    "esauriran": "esaurire",
    "esauriranno": "esaurire",
    "esaurirebbe": "esaurire",
    "esaurirebber": "esaurire",
    "esaurirebbero": "esaurire",
    "esaurirei": "esaurire",
    "esauriremmo": "esaurire",
    "esauriremo": "esaurire",
    "esaurireste": "esaurire",
    "esauriresti": "esaurire",
    "esaurirete": "esaurire",
    "esauriron": "esaurire",
    "esaurirono": "esaurire",
    "esaurirà": "esaurire",
    "esaurirò": "esaurire",
    "esaurisca": "esaurire",
    "esauriscan": "esaurire",
    "esauriscano": "esaurire",
    "esaurisce": "esaurire",
    "esaurisci": "esaurire",
    "esaurisco": "esaurire",
    "esauriscon": "esaurire",
    "esauriscono": "esaurire",
    "esaurisse": "esaurire",
    "esaurisser": "esaurire",
    "esaurissero": "esaurire",
    "esaurissi": "esaurire",
    "esaurissimo": "esaurire",
    "esauriste": "esaurire",
    "esauristi": "esaurire",
    "esaurita": "esaurito",
    "esaurite": "esaurito",
    "esauriti": "esaurito",
    "esaurito": "esaurire",
    "esauriva": "esaurire",
    "esaurivamo": "esaurire",
    "esaurivan": "esaurire",
    "esaurivano": "esaurire",
    "esaurivate": "esaurire",
    "esaurivi": "esaurire",
    "esaurivo": "esaurire",
    "esaurì": "esaurire",
    "esausta": "esausto",
    "esauste": "esausto",
    "esausti": "esausto",
    "esaustiva": "esaustivo",
    "esaustive": "esaustivo",
    "esaustivi": "esaustivo",
    "esautora": "esautorare",
    "esautorai": "esautorare",
    "esautorammo": "esautorare",
    "esautoran": "esautorare",
    "esautorando": "esautorare",
    "esautorano": "esautorare",
    "esautorante": "esautorare",
    "esautoranti": "esautorare",
    "esautorar": "esautorare",
    "esautoraron": "esautorare",
    "esautorarono": "esautorare",
    "esautorasse": "esautorare",
    "esautorasser": "esautorare",
    "esautorassero": "esautorare",
    "esautorassi": "esautorare",
    "esautorassimo": "esautorare",
    "esautoraste": "esautorare",
    "esautorasti": "esautorare",
    "esautorata": "esautorare",
    "esautorate": "esautorare",
    "esautorati": "esautorare",
    "esautorato": "esautorare",
    "esautorava": "esautorare",
    "esautoravamo": "esautorare",
    "esautoravan": "esautorare",
    "esautoravano": "esautorare",
    "esautoravate": "esautorare",
    "esautoravi": "esautorare",
    "esautoravo": "esautorare",
    "esautorerai": "esautorare",
    "esautoreran": "esautorare",
    "esautoreranno": "esautorare",
    "esautorerebbe": "esautorare",
    "esautorerebber": "esautorare",
    "esautorerebbero": "esautorare",
    "esautorerei": "esautorare",
    "esautoreremmo": "esautorare",
    "esautoreremo": "esautorare",
    "esautorereste": "esautorare",
    "esautoreresti": "esautorare",
    "esautorerete": "esautorare",
    "esautorerà": "esautorare",
    "esautorerò": "esautorare",
    "esautori": "esautorare",
    "esautoriamo": "esautorare",
    "esautoriate": "esautorare",
    "esautorin": "esautorare",
    "esautorino": "esautorare",
    "esautoro": "esautorare",
    "esautorò": "esautorare",
    "esavalenti": "esavalente",
    "esazioni": "esazione",
    "esborsi": "esborso",
    "esca": "uscire",
    "escan": "uscire",
    "escano": "uscire",
    "escatologica": "escatologico",
    "escatologiche": "escatologico",
    "escatologici": "escatologico",
    "escavatori": "escavatore",
    "escavatrici": "escavatrice",
    "escavazioni": "escavazione",
    "esce": "uscire",
    "esche": "esca",
    "eschimesi": "eschimese",
    "esci": "uscire",
    "esclama": "esclamare",
    "esclamai": "esclamare",
    "esclamammo": "esclamare",
    "esclaman": "esclamare",
    "esclamando": "esclamare",
    "esclamano": "esclamare",
    "esclamante": "esclamare",
    "esclamanti": "esclamare",
    "esclamar": "esclamare",
    "esclamaron": "esclamare",
    "esclamarono": "esclamare",
    "esclamasse": "esclamare",
    "esclamasser": "esclamare",
    "esclamassero": "esclamare",
    "esclamassi": "esclamare",
    "esclamassimo": "esclamare",
    "esclamaste": "esclamare",
    "esclamasti": "esclamare",
    "esclamata": "esclamare",
    "esclamate": "esclamare",
    "esclamati": "esclamare",
    "esclamativa": "esclamativo",
    "esclamative": "esclamativo",
    "esclamativi": "esclamativo",
    "esclamato": "esclamare",
    "esclamava": "esclamare",
    "esclamavamo": "esclamare",
    "esclamavan": "esclamare",
    "esclamavano": "esclamare",
    "esclamavate": "esclamare",
    "esclamavi": "esclamare",
    "esclamavo": "esclamare",
    "esclamazioni": "esclamazione",
    "esclamerai": "esclamare",
    "esclameran": "esclamare",
    "esclameranno": "esclamare",
    "esclamerebbe": "esclamare",
    "esclamerebber": "esclamare",
    "esclamerebbero": "esclamare",
    "esclamerei": "esclamare",
    "esclameremmo": "esclamare",
    "esclameremo": "esclamare",
    "esclamereste": "esclamare",
    "esclameresti": "esclamare",
    "esclamerete": "esclamare",
    "esclamerà": "esclamare",
    "esclamerò": "esclamare",
    "esclami": "esclamare",
    "esclamiamo": "esclamare",
    "esclamiate": "esclamare",
    "esclamin": "esclamare",
    "esclamino": "esclamare",
    "esclamo": "esclamare",
    "esclamò": "esclamare",
    "escluda": "escludere",
    "escludan": "escludere",
    "escludano": "escludere",
    "esclude": "escludere",
    "escludemmo": "escludere",
    "escludendo": "escludere",
    "escludente": "escludere",
    "escludenti": "escludere",
    "escluder": "escludere",
    "escluderai": "escludere",
    "escluderan": "escludere",
    "escluderanno": "escludere",
    "escluderebbe": "escludere",
    "escluderebber": "escludere",
    "escluderebbero": "escludere",
    "escluderei": "escludere",
    "escluderemmo": "escludere",
    "escluderemo": "escludere",
    "escludereste": "escludere",
    "escluderesti": "escludere",
    "escluderete": "escludere",
    "escluderà": "escludere",
    "escluderò": "escludere",
    "escludesse": "escludere",
    "escludesser": "escludere",
    "escludessero": "escludere",
    "escludessi": "escludere",
    "escludessimo": "escludere",
    "escludeste": "escludere",
    "escludesti": "escludere",
    "escludete": "escludere",
    "escludeva": "escludere",
    "escludevamo": "escludere",
    "escludevan": "escludere",
    "escludevano": "escludere",
    "escludevate": "escludere",
    "escludevi": "escludere",
    "escludevo": "escludere",
    "escludi": "escludere",
    "escludiamo": "escludere",
    "escludiate": "escludere",
    "escludo": "escludere",
    "escludon": "escludere",
    "escludono": "escludere",
    "esclusa": "escluso",
    "escluse": "escluso",
    "escluser": "escludere",
    "esclusero": "escludere",
    "esclusi": "escluso",
    "esclusioni": "esclusione",
    "esclusiva": "esclusivo",
    "esclusive": "esclusivo",
    "esclusivi": "esclusivo",
    "escluso": "escludere",
    "esco": "uscire",
    "escogita": "escogitare",
    "escogitai": "escogitare",
    "escogitammo": "escogitare",
    "escogitan": "escogitare",
    "escogitando": "escogitare",
    "escogitano": "escogitare",
    "escogitante": "escogitare",
    "escogitanti": "escogitare",
    "escogitar": "escogitare",
    "escogitaron": "escogitare",
    "escogitarono": "escogitare",
    "escogitasse": "escogitare",
    "escogitasser": "escogitare",
    "escogitassero": "escogitare",
    "escogitassi": "escogitare",
    "escogitassimo": "escogitare",
    "escogitaste": "escogitare",
    "escogitasti": "escogitare",
    "escogitata": "escogitare",
    "escogitate": "escogitare",
    "escogitati": "escogitare",
    "escogitato": "escogitare",
    "escogitava": "escogitare",
    "escogitavamo": "escogitare",
    "escogitavan": "escogitare",
    "escogitavano": "escogitare",
    "escogitavate": "escogitare",
    "escogitavi": "escogitare",
    "escogitavo": "escogitare",
    "escogitazioni": "escogitazione",
    "escogiterai": "escogitare",
    "escogiteran": "escogitare",
    "escogiteranno": "escogitare",
    "escogiterebbe": "escogitare",
    "escogiterebber": "escogitare",
    "escogiterebbero": "escogitare",
    "escogiterei": "escogitare",
    "escogiteremmo": "escogitare",
    "escogiteremo": "escogitare",
    "escogitereste": "escogitare",
    "escogiteresti": "escogitare",
    "escogiterete": "escogitare",
    "escogiterà": "escogitare",
    "escogiterò": "escogitare",
    "escogiti": "escogitare",
    "escogitiamo": "escogitare",
    "escogitiate": "escogitare",
    "escogitin": "escogitare",
    "escogitino": "escogitare",
    "escogito": "escogitare",
    "escogitò": "escogitare",
    "escon": "uscire",
    "escono": "uscire",
    "escori": "escoriare",
    "escoria": "escoriare",
    "escoriai": "escoriare",
    "escoriammo": "escoriare",
    "escoriamo": "escoriare",
    "escorian": "escoriare",
    "escoriando": "escoriare",
    "escoriano": "escoriare",
    "escoriante": "escoriare",
    "escorianti": "escoriare",
    "escoriar": "escoriare",
    "escoriaron": "escoriare",
    "escoriarono": "escoriare",
    "escoriasse": "escoriare",
    "escoriasser": "escoriare",
    "escoriassero": "escoriare",
    "escoriassi": "escoriare",
    "escoriassimo": "escoriare",
    "escoriaste": "escoriare",
    "escoriasti": "escoriare",
    "escoriata": "escoriare",
    "escoriate": "escoriare",
    "escoriati": "escoriare",
    "escoriato": "escoriare",
    "escoriava": "escoriare",
    "escoriavamo": "escoriare",
    "escoriavan": "escoriare",
    "escoriavano": "escoriare",
    "escoriavate": "escoriare",
    "escoriavi": "escoriare",
    "escoriavo": "escoriare",
    "escoriazioni": "escoriazione",
    "escorierai": "escoriare",
    "escorieran": "escoriare",
    "escorieranno": "escoriare",
    "escorierebbe": "escoriare",
    "escorierebber": "escoriare",
    "escorierebbero": "escoriare",
    "escorierei": "escoriare",
    "escorieremmo": "escoriare",
    "escorieremo": "escoriare",
    "escoriereste": "escoriare",
    "escorieresti": "escoriare",
    "escorierete": "escoriare",
    "escorierà": "escoriare",
    "escorierò": "escoriare",
    "escorin": "escoriare",
    "escorino": "escoriare",
    "escorio": "escoriare",
    "escoriò": "escoriare",
    "escrementi": "escremento",
    "escrementizi": "escrementizio",
    "escrementizia": "escrementizio",
    "escrementizie": "escrementizio",
    "escresca": "escrescere",
    "escrescan": "escrescere",
    "escrescano": "escrescere",
    "escresce": "escrescere",
    "escrescei": "escrescere",
    "escrescemmo": "escrescere",
    "escrescendo": "escrescere",
    "escrescente": "escrescere",
    "escrescenti": "escrescere",
    "escrescenze": "escrescenza",
    "escrescer": "escrescere",
    "escrescerai": "escrescere",
    "escresceran": "escrescere",
    "escresceranno": "escrescere",
    "escrescerebbe": "escrescere",
    "escrescerebber": "escrescere",
    "escrescerebbero": "escrescere",
    "escrescerei": "escrescere",
    "escresceremmo": "escrescere",
    "escresceremo": "escrescere",
    "escrescereste": "escrescere",
    "escresceresti": "escrescere",
    "escrescerete": "escrescere",
    "escresceron": "escrescere",
    "escrescerono": "escrescere",
    "escrescerà": "escrescere",
    "escrescerò": "escrescere",
    "escrescesse": "escrescere",
    "escrescesser": "escrescere",
    "escrescessero": "escrescere",
    "escrescessi": "escrescere",
    "escrescessimo": "escrescere",
    "escresceste": "escrescere",
    "escrescesti": "escrescere",
    "escrescete": "escrescere",
    "escresceva": "escrescere",
    "escrescevamo": "escrescere",
    "escrescevan": "escrescere",
    "escrescevano": "escrescere",
    "escrescevate": "escrescere",
    "escrescevi": "escrescere",
    "escrescevo": "escrescere",
    "escresci": "escrescere",
    "escresciamo": "escrescere",
    "escresciate": "escrescere",
    "escresciuta": "escrescere",
    "escresciute": "escrescere",
    "escresciuti": "escrescere",
    "escresciuto": "escrescere",
    "escresco": "escrescere",
    "escrescon": "escrescere",
    "escrescono": "escrescere",
    "escrescè": "escrescere",
    "escretori": "escretorio",
    "escretoria": "escretorio",
    "escretorie": "escretorio",
    "escretrice": "escretore",
    "escretrici": "escretore",
    "esculenta": "esculento",
    "esculente": "esculento",
    "esculenti": "esculento",
    "escursioni": "escursione",
    "escursionisti": "escursionista",
    "escuta": "escutere",
    "escutan": "escutere",
    "escutano": "escutere",
    "escute": "escutere",
    "escutei": "escutere",
    "escutemmo": "escutere",
    "escutendo": "escutere",
    "escutente": "escutere",
    "escutenti": "escutere",
    "escuter": "escutere",
    "escuterai": "escutere",
    "escuteran": "escutere",
    "escuteranno": "escutere",
    "escuterebbe": "escutere",
    "escuterebber": "escutere",
    "escuterebbero": "escutere",
    "escuterei": "escutere",
    "escuteremmo": "escutere",
    "escuteremo": "escutere",
    "escutereste": "escutere",
    "escuteresti": "escutere",
    "escuterete": "escutere",
    "escuteron": "escutere",
    "escuterono": "escutere",
    "escuterà": "escutere",
    "escuterò": "escutere",
    "escutesse": "escutere",
    "escutesser": "escutere",
    "escutessero": "escutere",
    "escutessi": "escutere",
    "escutessimo": "escutere",
    "escuteste": "escutere",
    "escutesti": "escutere",
    "escutete": "escutere",
    "escuteva": "escutere",
    "escutevamo": "escutere",
    "escutevan": "escutere",
    "escutevano": "escutere",
    "escutevate": "escutere",
    "escutevi": "escutere",
    "escutevo": "escutere",
    "escuti": "escutere",
    "escutiamo": "escutere",
    "escutiate": "escutere",
    "escuto": "escutere",
    "escuton": "escutere",
    "escutono": "escutere",
    "escututa": "escutere",
    "escutute": "escutere",
    "escututi": "escutere",
    "escututo": "escutere",
    "escutè": "escutere",
    "esecra": "esecrare",
    "esecrabili": "esecrabile",
    "esecrai": "esecrare",
    "esecrammo": "esecrare",
    "esecran": "esecrare",
    "esecranda": "esecrando",
    "esecrande": "esecrando",
    "esecrandi": "esecrando",
    "esecrando": "esecrare",
    "esecrano": "esecrare",
    "esecrante": "esecrare",
    "esecranti": "esecrare",
    "esecrar": "esecrare",
    "esecraron": "esecrare",
    "esecrarono": "esecrare",
    "esecrasse": "esecrare",
    "esecrasser": "esecrare",
    "esecrassero": "esecrare",
    "esecrassi": "esecrare",
    "esecrassimo": "esecrare",
    "esecraste": "esecrare",
    "esecrasti": "esecrare",
    "esecrata": "esecrare",
    "esecrate": "esecrare",
    "esecrati": "esecrare",
    "esecrato": "esecrare",
    "esecrava": "esecrare",
    "esecravamo": "esecrare",
    "esecravan": "esecrare",
    "esecravano": "esecrare",
    "esecravate": "esecrare",
    "esecravi": "esecrare",
    "esecravo": "esecrare",
    "esecrerai": "esecrare",
    "esecreran": "esecrare",
    "esecreranno": "esecrare",
    "esecrerebbe": "esecrare",
    "esecrerebber": "esecrare",
    "esecrerebbero": "esecrare",
    "esecrerei": "esecrare",
    "esecreremmo": "esecrare",
    "esecreremo": "esecrare",
    "esecrereste": "esecrare",
    "esecreresti": "esecrare",
    "esecrerete": "esecrare",
    "esecrerà": "esecrare",
    "esecrerò": "esecrare",
    "esecri": "esecrare",
    "esecriamo": "esecrare",
    "esecriate": "esecrare",
    "esecrin": "esecrare",
    "esecrino": "esecrare",
    "esecro": "esecrare",
    "esecrò": "esecrare",
    "esecutiva": "esecutivo",
    "esecutive": "esecutivo",
    "esecutivi": "esecutivo",
    "esecutori": "esecutorio",
    "esecutoria": "esecutorio",
    "esecutorie": "esecutorio",
    "esecutrice": "esecutore",
    "esecutrici": "esecutore",
    "esecuzioni": "esecuzione",
    "esegeti": "esegeta",
    "esegua": "eseguire",
    "eseguan": "eseguire",
    "eseguano": "eseguire",
    "esegue": "eseguire",
    "eseguendo": "eseguire",
    "eseguente": "eseguire",
    "eseguenti": "eseguire",
    "esegui": "eseguire",
    "eseguiamo": "eseguire",
    "eseguiate": "eseguire",
    "eseguibili": "eseguibile",
    "eseguii": "eseguire",
    "eseguimmo": "eseguire",
    "eseguir": "eseguire",
    "eseguirai": "eseguire",
    "eseguiran": "eseguire",
    "eseguiranno": "eseguire",
    "eseguirebbe": "eseguire",
    "eseguirebber": "eseguire",
    "eseguirebbero": "eseguire",
    "eseguirei": "eseguire",
    "eseguiremmo": "eseguire",
    "eseguiremo": "eseguire",
    "eseguireste": "eseguire",
    "eseguiresti": "eseguire",
    "eseguirete": "eseguire",
    "eseguiron": "eseguire",
    "eseguirono": "eseguire",
    "eseguirà": "eseguire",
    "eseguirò": "eseguire",
    "eseguisse": "eseguire",
    "eseguisser": "eseguire",
    "eseguissero": "eseguire",
    "eseguissi": "eseguire",
    "eseguissimo": "eseguire",
    "eseguiste": "eseguire",
    "eseguisti": "eseguire",
    "eseguita": "eseguire",
    "eseguite": "eseguire",
    "eseguiti": "eseguire",
    "eseguito": "eseguire",
    "eseguiva": "eseguire",
    "eseguivamo": "eseguire",
    "eseguivan": "eseguire",
    "eseguivano": "eseguire",
    "eseguivate": "eseguire",
    "eseguivi": "eseguire",
    "eseguivo": "eseguire",
    "eseguo": "eseguire",
    "eseguon": "eseguire",
    "eseguono": "eseguire",
    "eseguì": "eseguire",
    "esempi": "esempio",
    "esemplari": "esemplare",
    "esemplifica": "esemplificare",
    "esemplificai": "esemplificare",
    "esemplificammo": "esemplificare",
    "esemplifican": "esemplificare",
    "esemplificando": "esemplificare",
    "esemplificano": "esemplificare",
    "esemplificante": "esemplificare",
    "esemplificanti": "esemplificare",
    "esemplificar": "esemplificare",
    "esemplificaron": "esemplificare",
    "esemplificarono": "esemplificare",
    "esemplificasse": "esemplificare",
    "esemplificasser": "esemplificare",
    "esemplificassero": "esemplificare",
    "esemplificassi": "esemplificare",
    "esemplificassimo": "esemplificare",
    "esemplificaste": "esemplificare",
    "esemplificasti": "esemplificare",
    "esemplificata": "esemplificare",
    "esemplificate": "esemplificare",
    "esemplificati": "esemplificare",
    "esemplificativa": "esemplificativo",
    "esemplificative": "esemplificativo",
    "esemplificativi": "esemplificativo",
    "esemplificato": "esemplificare",
    "esemplificava": "esemplificare",
    "esemplificavamo": "esemplificare",
    "esemplificavan": "esemplificare",
    "esemplificavano": "esemplificare",
    "esemplificavate": "esemplificare",
    "esemplificavi": "esemplificare",
    "esemplificavo": "esemplificare",
    "esemplificazioni": "esemplificazione",
    "esemplificherai": "esemplificare",
    "esemplificheran": "esemplificare",
    "esemplificheranno": "esemplificare",
    "esemplificherebbe": "esemplificare",
    "esemplificherebber": "esemplificare",
    "esemplificherebbero": "esemplificare",
    "esemplificherei": "esemplificare",
    "esemplificheremmo": "esemplificare",
    "esemplificheremo": "esemplificare",
    "esemplifichereste": "esemplificare",
    "esemplificheresti": "esemplificare",
    "esemplificherete": "esemplificare",
    "esemplificherà": "esemplificare",
    "esemplificherò": "esemplificare",
    "esemplifichi": "esemplificare",
    "esemplifichiamo": "esemplificare",
    "esemplifichiate": "esemplificare",
    "esemplifichin": "esemplificare",
    "esemplifichino": "esemplificare",
    "esemplifico": "esemplificare",
    "esemplificò": "esemplificare",
    "esenta": "esentare",
    "esentai": "esentare",
    "esentammo": "esentare",
    "esentan": "esentare",
    "esentando": "esentare",
    "esentano": "esentare",
    "esentante": "esentare",
    "esentanti": "esentare",
    "esentar": "esentare",
    "esentaron": "esentare",
    "esentarono": "esentare",
    "esentasse": "esentare",
    "esentasser": "esentare",
    "esentassero": "esentare",
    "esentassi": "esentare",
    "esentassimo": "esentare",
    "esentaste": "esentare",
    "esentasti": "esentare",
    "esentata": "esentare",
    "esentate": "esentare",
    "esentati": "esentare",
    "esentato": "esentare",
    "esentava": "esentare",
    "esentavamo": "esentare",
    "esentavan": "esentare",
    "esentavano": "esentare",
    "esentavate": "esentare",
    "esentavi": "esentare",
    "esentavo": "esentare",
    "esenterai": "esentare",
    "esenteran": "esentare",
    "esenteranno": "esentare",
    "esenterebbe": "esentare",
    "esenterebber": "esentare",
    "esenterebbero": "esentare",
    "esenterei": "esentare",
    "esenteremmo": "esentare",
    "esenteremo": "esentare",
    "esentereste": "esentare",
    "esenteresti": "esentare",
    "esenterete": "esentare",
    "esenterà": "esentare",
    "esenterò": "esentare",
    "esenti": "esente",
    "esentiamo": "esentare",
    "esentiate": "esentare",
    "esentin": "esentare",
    "esentino": "esentare",
    "esento": "esentare",
    "esentò": "esentare",
    "esenzioni": "esenzione",
    "esequie": "esequia",
    "esercendo": "esercire",
    "esercente": "esercire",
    "esercenti": "esercire",
    "eserciamo": "esercire",
    "eserciate": "esercire",
    "esercii": "esercire",
    "esercimmo": "esercire",
    "esercir": "esercire",
    "esercirai": "esercire",
    "eserciran": "esercire",
    "eserciranno": "esercire",
    "esercirebbe": "esercire",
    "esercirebber": "esercire",
    "esercirebbero": "esercire",
    "esercirei": "esercire",
    "eserciremmo": "esercire",
    "eserciremo": "esercire",
    "esercireste": "esercire",
    "eserciresti": "esercire",
    "esercirete": "esercire",
    "eserciron": "esercire",
    "esercirono": "esercire",
    "esercirà": "esercire",
    "esercirò": "esercire",
    "esercisca": "esercire",
    "eserciscan": "esercire",
    "eserciscano": "esercire",
    "esercisce": "esercire",
    "esercisci": "esercire",
    "esercisco": "esercire",
    "eserciscon": "esercire",
    "eserciscono": "esercire",
    "esercisse": "esercire",
    "esercisser": "esercire",
    "esercissero": "esercire",
    "esercissi": "esercire",
    "esercissimo": "esercire",
    "eserciste": "esercire",
    "esercisti": "esercire",
    "esercita": "esercitare",
    "esercitabili": "esercitabile",
    "esercitai": "esercitare",
    "esercitammo": "esercitare",
    "esercitan": "esercitare",
    "esercitando": "esercitare",
    "esercitano": "esercitare",
    "esercitante": "esercitare",
    "esercitanti": "esercitare",
    "esercitar": "esercitare",
    "esercitaron": "esercitare",
    "esercitarono": "esercitare",
    "esercitasse": "esercitare",
    "esercitasser": "esercitare",
    "esercitassero": "esercitare",
    "esercitassi": "esercitare",
    "esercitassimo": "esercitare",
    "esercitaste": "esercitare",
    "esercitasti": "esercitare",
    "esercitata": "esercitare",
    "esercitate": "esercitare",
    "esercitati": "esercitare",
    "esercitato": "esercitare",
    "esercitava": "esercitare",
    "esercitavamo": "esercitare",
    "esercitavan": "esercitare",
    "esercitavano": "esercitare",
    "esercitavate": "esercitare",
    "esercitavi": "esercitare",
    "esercitavo": "esercitare",
    "esercitazioni": "esercitazione",
    "esercite": "esercire",
    "eserciterai": "esercitare",
    "eserciteran": "esercitare",
    "eserciteranno": "esercitare",
    "eserciterebbe": "esercitare",
    "eserciterebber": "esercitare",
    "eserciterebbero": "esercitare",
    "eserciterei": "esercitare",
    "eserciteremmo": "esercitare",
    "eserciteremo": "esercitare",
    "esercitereste": "esercitare",
    "eserciteresti": "esercitare",
    "eserciterete": "esercitare",
    "eserciterà": "esercitare",
    "eserciterò": "esercitare",
    "eserciti": "esercito",
    "esercitiamo": "esercitare",
    "esercitiate": "esercitare",
    "esercitin": "esercitare",
    "esercitino": "esercitare",
    "esercito": "esercitare",
    "esercitò": "esercitare",
    "eserciva": "esercire",
    "esercivamo": "esercire",
    "esercivan": "esercire",
    "esercivano": "esercire",
    "esercivate": "esercire",
    "esercivi": "esercire",
    "esercivo": "esercire",
    "esercizi": "esercizio",
    "esercì": "esercire",
    "esibendo": "esibire",
    "esibente": "esibire",
    "esibenti": "esibire",
    "esibiamo": "esibire",
    "esibiate": "esibire",
    "esibii": "esibire",
    "esibimmo": "esibire",
    "esibir": "esibire",
    "esibirai": "esibire",
    "esibiran": "esibire",
    "esibiranno": "esibire",
    "esibirebbe": "esibire",
    "esibirebber": "esibire",
    "esibirebbero": "esibire",
    "esibirei": "esibire",
    "esibiremmo": "esibire",
    "esibiremo": "esibire",
    "esibireste": "esibire",
    "esibiresti": "esibire",
    "esibirete": "esibire",
    "esibiron": "esibire",
    "esibirono": "esibire",
    "esibirà": "esibire",
    "esibirò": "esibire",
    "esibisca": "esibire",
    "esibiscan": "esibire",
    "esibiscano": "esibire",
    "esibisce": "esibire",
    "esibisci": "esibire",
    "esibisco": "esibire",
    "esibiscon": "esibire",
    "esibiscono": "esibire",
    "esibisse": "esibire",
    "esibisser": "esibire",
    "esibissero": "esibire",
    "esibissi": "esibire",
    "esibissimo": "esibire",
    "esibiste": "esibire",
    "esibisti": "esibire",
    "esibita": "esibire",
    "esibite": "esibire",
    "esibiti": "esibire",
    "esibito": "esibire",
    "esibiva": "esibire",
    "esibivamo": "esibire",
    "esibivan": "esibire",
    "esibivano": "esibire",
    "esibivate": "esibire",
    "esibivi": "esibire",
    "esibivo": "esibire",
    "esibizioni": "esibizione",
    "esibizionismi": "esibizionismo",
    "esibizioniste": "esibizionista",
    "esibizionisti": "esibizionista",
    "esibizionistica": "esibizionistico",
    "esibizionistiche": "esibizionistico",
    "esibizionistici": "esibizionistico",
    "esibì": "esibire",
    "esiga": "esigere",
    "esigan": "esigere",
    "esigano": "esigere",
    "esige": "esigere",
    "esigei": "esigere",
    "esigemmo": "esigere",
    "esigendo": "esigere",
    "esigente": "esigere",
    "esigenti": "esigere",
    "esigenze": "esigenza",
    "esiger": "esigere",
    "esigerai": "esigere",
    "esigeran": "esigere",
    "esigeranno": "esigere",
    "esigerebbe": "esigere",
    "esigerebber": "esigere",
    "esigerebbero": "esigere",
    "esigerei": "esigere",
    "esigeremmo": "esigere",
    "esigeremo": "esigere",
    "esigereste": "esigere",
    "esigeresti": "esigere",
    "esigerete": "esigere",
    "esigeron": "esigere",
    "esigerono": "esigere",
    "esigerà": "esigere",
    "esigerò": "esigere",
    "esigesse": "esigere",
    "esigesser": "esigere",
    "esigessero": "esigere",
    "esigessi": "esigere",
    "esigessimo": "esigere",
    "esigeste": "esigere",
    "esigesti": "esigere",
    "esigete": "esigere",
    "esigeva": "esigere",
    "esigevamo": "esigere",
    "esigevan": "esigere",
    "esigevano": "esigere",
    "esigevate": "esigere",
    "esigevi": "esigere",
    "esigevo": "esigere",
    "esigi": "esigere",
    "esigiamo": "esigere",
    "esigiate": "esigere",
    "esigibili": "esigibile",
    "esigiuta": "esigere",
    "esigiute": "esigere",
    "esigiuti": "esigere",
    "esigiuto": "esigere",
    "esigo": "esigere",
    "esigon": "esigere",
    "esigono": "esigere",
    "esigua": "esiguo",
    "esigue": "esiguo",
    "esigui": "esiguo",
    "esigè": "esigere",
    "esilara": "esilarare",
    "esilarai": "esilarare",
    "esilarammo": "esilarare",
    "esilaran": "esilarare",
    "esilarando": "esilarare",
    "esilarano": "esilarare",
    "esilarante": "esilarare",
    "esilaranti": "esilarare",
    "esilarar": "esilarare",
    "esilararon": "esilarare",
    "esilararono": "esilarare",
    "esilarasse": "esilarare",
    "esilarasser": "esilarare",
    "esilarassero": "esilarare",
    "esilarassi": "esilarare",
    "esilarassimo": "esilarare",
    "esilaraste": "esilarare",
    "esilarasti": "esilarare",
    "esilarata": "esilarare",
    "esilarate": "esilarare",
    "esilarati": "esilarare",
    "esilarato": "esilarare",
    "esilarava": "esilarare",
    "esilaravamo": "esilarare",
    "esilaravan": "esilarare",
    "esilaravano": "esilarare",
    "esilaravate": "esilarare",
    "esilaravi": "esilarare",
    "esilaravo": "esilarare",
    "esilarerai": "esilarare",
    "esilareran": "esilarare",
    "esilareranno": "esilarare",
    "esilarerebbe": "esilarare",
    "esilarerebber": "esilarare",
    "esilarerebbero": "esilarare",
    "esilarerei": "esilarare",
    "esilareremmo": "esilarare",
    "esilareremo": "esilarare",
    "esilarereste": "esilarare",
    "esilareresti": "esilarare",
    "esilarerete": "esilarare",
    "esilarerà": "esilarare",
    "esilarerò": "esilarare",
    "esilari": "esilarare",
    "esilariamo": "esilarare",
    "esilariate": "esilarare",
    "esilarin": "esilarare",
    "esilarino": "esilarare",
    "esilaro": "esilarare",
    "esilarò": "esilarare",
    "esili": "esiliare",
    "esilia": "esiliare",
    "esiliai": "esiliare",
    "esiliammo": "esiliare",
    "esiliamo": "esiliare",
    "esilian": "esiliare",
    "esiliando": "esiliare",
    "esiliano": "esiliare",
    "esiliante": "esiliare",
    "esilianti": "esiliare",
    "esiliar": "esiliare",
    "esiliaron": "esiliare",
    "esiliarono": "esiliare",
    "esiliasse": "esiliare",
    "esiliasser": "esiliare",
    "esiliassero": "esiliare",
    "esiliassi": "esiliare",
    "esiliassimo": "esiliare",
    "esiliaste": "esiliare",
    "esiliasti": "esiliare",
    "esiliata": "esiliato",
    "esiliate": "esiliato",
    "esiliati": "esiliato",
    "esiliato": "esiliare",
    "esiliava": "esiliare",
    "esiliavamo": "esiliare",
    "esiliavan": "esiliare",
    "esiliavano": "esiliare",
    "esiliavate": "esiliare",
    "esiliavi": "esiliare",
    "esiliavo": "esiliare",
    "esilierai": "esiliare",
    "esilieran": "esiliare",
    "esilieranno": "esiliare",
    "esilierebbe": "esiliare",
    "esilierebber": "esiliare",
    "esilierebbero": "esiliare",
    "esilierei": "esiliare",
    "esilieremmo": "esiliare",
    "esilieremo": "esiliare",
    "esiliereste": "esiliare",
    "esilieresti": "esiliare",
    "esilierete": "esiliare",
    "esilierà": "esiliare",
    "esilierò": "esiliare",
    "esilii": "esilio",
    "esilin": "esiliare",
    "esilino": "esiliare",
    "esilio": "esiliare",
    "esiliò": "esiliare",
    "esima": "esimere",
    "esiman": "esimere",
    "esimano": "esimere",
    "esime": "esimere",
    "esimei": "esimere",
    "esimemmo": "esimere",
    "esimendo": "esimere",
    "esimente": "esimere",
    "esimenti": "esimere",
    "esimer": "esimere",
    "esimerai": "esimere",
    "esimeran": "esimere",
    "esimeranno": "esimere",
    "esimerebbe": "esimere",
    "esimerebber": "esimere",
    "esimerebbero": "esimere",
    "esimerei": "esimere",
    "esimeremmo": "esimere",
    "esimeremo": "esimere",
    "esimereste": "esimere",
    "esimeresti": "esimere",
    "esimerete": "esimere",
    "esimeron": "esimere",
    "esimerono": "esimere",
    "esimerà": "esimere",
    "esimerò": "esimere",
    "esimesse": "esimere",
    "esimesser": "esimere",
    "esimessero": "esimere",
    "esimessi": "esimere",
    "esimessimo": "esimere",
    "esimeste": "esimere",
    "esimesti": "esimere",
    "esimete": "esimere",
    "esimeva": "esimere",
    "esimevamo": "esimere",
    "esimevan": "esimere",
    "esimevano": "esimere",
    "esimevate": "esimere",
    "esimevi": "esimere",
    "esimevo": "esimere",
    "esimi": "esimio",
    "esimia": "esimio",
    "esimiamo": "esimere",
    "esimiate": "esimere",
    "esimie": "esimio",
    "esimo": "esimere",
    "esimon": "esimere",
    "esimono": "esimere",
    "esimuta": "esimere",
    "esimute": "esimere",
    "esimuti": "esimere",
    "esimuto": "esimere",
    "esimè": "esimere",
    "esista": "esistere",
    "esistan": "esistere",
    "esistano": "esistere",
    "esiste": "esistere",
    "esistei": "esistere",
    "esistemmo": "esistere",
    "esistendo": "esistere",
    "esistente": "esistere",
    "esistenti": "esistere",
    "esistenze": "esistenza",
    "esistenziali": "esistenziale",
    "esistenzialiste": "esistenzialista",
    "esistenzialisti": "esistenzialista",
    "esister": "esistere",
    "esisterai": "esistere",
    "esisteran": "esistere",
    "esisteranno": "esistere",
    "esisterebbe": "esistere",
    "esisterebber": "esistere",
    "esisterebbero": "esistere",
    "esisterei": "esistere",
    "esisteremmo": "esistere",
    "esisteremo": "esistere",
    "esistereste": "esistere",
    "esisteresti": "esistere",
    "esisterete": "esistere",
    "esisterono": "esistere",
    "esisterà": "esistere",
    "esisterò": "esistere",
    "esistesse": "esistere",
    "esistesser": "esistere",
    "esistessero": "esistere",
    "esistessi": "esistere",
    "esistessimo": "esistere",
    "esisteste": "esistere",
    "esistesti": "esistere",
    "esistete": "esistere",
    "esisteva": "esistere",
    "esistevamo": "esistere",
    "esistevan": "esistere",
    "esistevano": "esistere",
    "esistevate": "esistere",
    "esistevi": "esistere",
    "esistevo": "esistere",
    "esisti": "esistere",
    "esistiamo": "esistere",
    "esistiate": "esistere",
    "esistita": "esistere",
    "esistite": "esistere",
    "esistiti": "esistere",
    "esistito": "esistere",
    "esisto": "esistere",
    "esiston": "esistere",
    "esistono": "esistere",
    "esistè": "esistere",
    "esita": "esitare",
    "esitai": "esitare",
    "esitammo": "esitare",
    "esitan": "esitare",
    "esitando": "esitare",
    "esitano": "esitare",
    "esitante": "esitare",
    "esitanti": "esitare",
    "esitar": "esitare",
    "esitaron": "esitare",
    "esitarono": "esitare",
    "esitasse": "esitare",
    "esitasser": "esitare",
    "esitassero": "esitare",
    "esitassi": "esitare",
    "esitassimo": "esitare",
    "esitaste": "esitare",
    "esitasti": "esitare",
    "esitata": "esitare",
    "esitate": "esitare",
    "esitati": "esitare",
    "esitato": "esitare",
    "esitava": "esitare",
    "esitavamo": "esitare",
    "esitavan": "esitare",
    "esitavano": "esitare",
    "esitavate": "esitare",
    "esitavi": "esitare",
    "esitavo": "esitare",
    "esitazioni": "esitazione",
    "esiterai": "esitare",
    "esiteran": "esitare",
    "esiteranno": "esitare",
    "esiterebbe": "esitare",
    "esiterebber": "esitare",
    "esiterebbero": "esitare",
    "esiterei": "esitare",
    "esiteremmo": "esitare",
    "esiteremo": "esitare",
    "esitereste": "esitare",
    "esiteresti": "esitare",
    "esiterete": "esitare",
    "esiterà": "esitare",
    "esiterò": "esitare",
    "esiti": "esito",
    "esitiamo": "esitare",
    "esitiate": "esitare",
    "esitin": "esitare",
    "esitino": "esitare",
    "esito": "esitare",
    "esitò": "esitare",
    "esiziali": "esiziale",
    "esodi": "esodo",
    "esogena": "esogeno",
    "esogene": "esogeno",
    "esogeni": "esogeno",
    "esonera": "esonerare",
    "esonerai": "esonerare",
    "esonerammo": "esonerare",
    "esoneran": "esonerare",
    "esonerando": "esonerare",
    "esonerano": "esonerare",
    "esonerante": "esonerare",
    "esoneranti": "esonerare",
    "esonerar": "esonerare",
    "esoneraron": "esonerare",
    "esonerarono": "esonerare",
    "esonerasse": "esonerare",
    "esonerasser": "esonerare",
    "esonerassero": "esonerare",
    "esonerassi": "esonerare",
    "esonerassimo": "esonerare",
    "esoneraste": "esonerare",
    "esonerasti": "esonerare",
    "esonerata": "esonerare",
    "esonerate": "esonerare",
    "esonerati": "esonerare",
    "esonerato": "esonerare",
    "esonerava": "esonerare",
    "esoneravamo": "esonerare",
    "esoneravan": "esonerare",
    "esoneravano": "esonerare",
    "esoneravate": "esonerare",
    "esoneravi": "esonerare",
    "esoneravo": "esonerare",
    "esonererai": "esonerare",
    "esonereran": "esonerare",
    "esonereranno": "esonerare",
    "esonererebbe": "esonerare",
    "esonererebber": "esonerare",
    "esonererebbero": "esonerare",
    "esonererei": "esonerare",
    "esonereremmo": "esonerare",
    "esonereremo": "esonerare",
    "esonerereste": "esonerare",
    "esonereresti": "esonerare",
    "esonererete": "esonerare",
    "esonererà": "esonerare",
    "esonererò": "esonerare",
    "esoneri": "esonero",
    "esoneriamo": "esonerare",
    "esoneriate": "esonerare",
    "esonerin": "esonerare",
    "esonerino": "esonerare",
    "esonero": "esonerare",
    "esonerò": "esonerare",
    "esorbita": "esorbitare",
    "esorbitai": "esorbitare",
    "esorbitammo": "esorbitare",
    "esorbitan": "esorbitare",
    "esorbitando": "esorbitare",
    "esorbitano": "esorbitare",
    "esorbitante": "esorbitare",
    "esorbitanti": "esorbitare",
    "esorbitar": "esorbitare",
    "esorbitaron": "esorbitare",
    "esorbitarono": "esorbitare",
    "esorbitasse": "esorbitare",
    "esorbitasser": "esorbitare",
    "esorbitassero": "esorbitare",
    "esorbitassi": "esorbitare",
    "esorbitassimo": "esorbitare",
    "esorbitaste": "esorbitare",
    "esorbitasti": "esorbitare",
    "esorbitata": "esorbitare",
    "esorbitate": "esorbitare",
    "esorbitati": "esorbitare",
    "esorbitato": "esorbitare",
    "esorbitava": "esorbitare",
    "esorbitavamo": "esorbitare",
    "esorbitavan": "esorbitare",
    "esorbitavano": "esorbitare",
    "esorbitavate": "esorbitare",
    "esorbitavi": "esorbitare",
    "esorbitavo": "esorbitare",
    "esorbiterai": "esorbitare",
    "esorbiteran": "esorbitare",
    "esorbiteranno": "esorbitare",
    "esorbiterebbe": "esorbitare",
    "esorbiterebber": "esorbitare",
    "esorbiterebbero": "esorbitare",
    "esorbiterei": "esorbitare",
    "esorbiteremmo": "esorbitare",
    "esorbiteremo": "esorbitare",
    "esorbitereste": "esorbitare",
    "esorbiteresti": "esorbitare",
    "esorbiterete": "esorbitare",
    "esorbiterà": "esorbitare",
    "esorbiterò": "esorbitare",
    "esorbiti": "esorbitare",
    "esorbitiamo": "esorbitare",
    "esorbitiate": "esorbitare",
    "esorbitin": "esorbitare",
    "esorbitino": "esorbitare",
    "esorbito": "esorbitare",
    "esorbitò": "esorbitare",
    "esorcismi": "esorcismo",
    "esorcisti": "esorcista",
    "esorcistica": "esorcistico",
    "esorcistiche": "esorcistico",
    "esorcistici": "esorcistico",
    "esorcizza": "esorcizzare",
    "esorcizzai": "esorcizzare",
    "esorcizzammo": "esorcizzare",
    "esorcizzan": "esorcizzare",
    "esorcizzando": "esorcizzare",
    "esorcizzano": "esorcizzare",
    "esorcizzante": "esorcizzare",
    "esorcizzanti": "esorcizzare",
    "esorcizzar": "esorcizzare",
    "esorcizzaron": "esorcizzare",
    "esorcizzarono": "esorcizzare",
    "esorcizzasse": "esorcizzare",
    "esorcizzasser": "esorcizzare",
    "esorcizzassero": "esorcizzare",
    "esorcizzassi": "esorcizzare",
    "esorcizzassimo": "esorcizzare",
    "esorcizzaste": "esorcizzare",
    "esorcizzasti": "esorcizzare",
    "esorcizzata": "esorcizzare",
    "esorcizzate": "esorcizzare",
    "esorcizzati": "esorcizzare",
    "esorcizzato": "esorcizzare",
    "esorcizzava": "esorcizzare",
    "esorcizzavamo": "esorcizzare",
    "esorcizzavan": "esorcizzare",
    "esorcizzavano": "esorcizzare",
    "esorcizzavate": "esorcizzare",
    "esorcizzavi": "esorcizzare",
    "esorcizzavo": "esorcizzare",
    "esorcizzerai": "esorcizzare",
    "esorcizzeran": "esorcizzare",
    "esorcizzeranno": "esorcizzare",
    "esorcizzerebbe": "esorcizzare",
    "esorcizzerebber": "esorcizzare",
    "esorcizzerebbero": "esorcizzare",
    "esorcizzerei": "esorcizzare",
    "esorcizzeremmo": "esorcizzare",
    "esorcizzeremo": "esorcizzare",
    "esorcizzereste": "esorcizzare",
    "esorcizzeresti": "esorcizzare",
    "esorcizzerete": "esorcizzare",
    "esorcizzerà": "esorcizzare",
    "esorcizzerò": "esorcizzare",
    "esorcizzi": "esorcizzare",
    "esorcizziamo": "esorcizzare",
    "esorcizziate": "esorcizzare",
    "esorcizzin": "esorcizzare",
    "esorcizzino": "esorcizzare",
    "esorcizzo": "esorcizzare",
    "esorcizzò": "esorcizzare",
    "esordendo": "esordire",
    "esordi": "esordio",
    "esordiamo": "esordire",
    "esordiate": "esordire",
    "esordiente": "esordire",
    "esordienti": "esordire",
    "esordii": "esordire",
    "esordimmo": "esordire",
    "esordir": "esordire",
    "esordirai": "esordire",
    "esordiran": "esordire",
    "esordiranno": "esordire",
    "esordirebbe": "esordire",
    "esordirebber": "esordire",
    "esordirebbero": "esordire",
    "esordirei": "esordire",
    "esordiremmo": "esordire",
    "esordiremo": "esordire",
    "esordireste": "esordire",
    "esordiresti": "esordire",
    "esordirete": "esordire",
    "esordiron": "esordire",
    "esordirono": "esordire",
    "esordirà": "esordire",
    "esordirò": "esordire",
    "esordisca": "esordire",
    "esordiscan": "esordire",
    "esordiscano": "esordire",
    "esordisce": "esordire",
    "esordisci": "esordire",
    "esordisco": "esordire",
    "esordiscon": "esordire",
    "esordiscono": "esordire",
    "esordisse": "esordire",
    "esordisser": "esordire",
    "esordissero": "esordire",
    "esordissi": "esordire",
    "esordissimo": "esordire",
    "esordiste": "esordire",
    "esordisti": "esordire",
    "esordita": "esordire",
    "esordite": "esordire",
    "esorditi": "esordire",
    "esordito": "esordire",
    "esordiva": "esordire",
    "esordivamo": "esordire",
    "esordivan": "esordire",
    "esordivano": "esordire",
    "esordivate": "esordire",
    "esordivi": "esordire",
    "esordivo": "esordire",
    "esordì": "esordire",
    "esorta": "esortare",
    "esortai": "esortare",
    "esortammo": "esortare",
    "esortan": "esortare",
    "esortando": "esortare",
    "esortano": "esortare",
    "esortante": "esortare",
    "esortanti": "esortare",
    "esortar": "esortare",
    "esortaron": "esortare",
    "esortarono": "esortare",
    "esortasse": "esortare",
    "esortasser": "esortare",
    "esortassero": "esortare",
    "esortassi": "esortare",
    "esortassimo": "esortare",
    "esortaste": "esortare",
    "esortasti": "esortare",
    "esortata": "esortare",
    "esortate": "esortare",
    "esortati": "esortare",
    "esortato": "esortare",
    "esortava": "esortare",
    "esortavamo": "esortare",
    "esortavan": "esortare",
    "esortavano": "esortare",
    "esortavate": "esortare",
    "esortavi": "esortare",
    "esortavo": "esortare",
    "esortazioni": "esortazione",
    "esorterai": "esortare",
    "esorteran": "esortare",
    "esorteranno": "esortare",
    "esorterebbe": "esortare",
    "esorterebber": "esortare",
    "esorterebbero": "esortare",
    "esorterei": "esortare",
    "esorteremmo": "esortare",
    "esorteremo": "esortare",
    "esortereste": "esortare",
    "esorteresti": "esortare",
    "esorterete": "esortare",
    "esorterà": "esortare",
    "esorterò": "esortare",
    "esorti": "esortare",
    "esortiamo": "esortare",
    "esortiate": "esortare",
    "esortin": "esortare",
    "esortino": "esortare",
    "esorto": "esortare",
    "esortò": "esortare",
    "esosa": "esoso",
    "esose": "esoso",
    "esosi": "esoso",
    "esoterica": "esoterico",
    "esoteriche": "esoterico",
    "esoterici": "esoterico",
    "esoterismi": "esoterismo",
    "esotica": "esotico",
    "esotiche": "esotico",
    "esotici": "esotico",
    "esotismi": "esotismo",
    "espanda": "espandere",
    "espandan": "espandere",
    "espandano": "espandere",
    "espande": "espandere",
    "espandemmo": "espandere",
    "espandendo": "espandere",
    "espandente": "espandere",
    "espandenti": "espandere",
    "espander": "espandere",
    "espanderai": "espandere",
    "espanderan": "espandere",
    "espanderanno": "espandere",
    "espanderebbe": "espandere",
    "espanderebber": "espandere",
    "espanderebbero": "espandere",
    "espanderei": "espandere",
    "espanderemmo": "espandere",
    "espanderemo": "espandere",
    "espandereste": "espandere",
    "espanderesti": "espandere",
    "espanderete": "espandere",
    "espanderà": "espandere",
    "espanderò": "espandere",
    "espandesse": "espandere",
    "espandesser": "espandere",
    "espandessero": "espandere",
    "espandessi": "espandere",
    "espandessimo": "espandere",
    "espandeste": "espandere",
    "espandesti": "espandere",
    "espandete": "espandere",
    "espandeva": "espandere",
    "espandevamo": "espandere",
    "espandevan": "espandere",
    "espandevano": "espandere",
    "espandevate": "espandere",
    "espandevi": "espandere",
    "espandevo": "espandere",
    "espandi": "espandere",
    "espandiamo": "espandere",
    "espandiate": "espandere",
    "espando": "espandere",
    "espandon": "espandere",
    "espandono": "espandere",
    "espanduta": "espandere",
    "espandute": "espandere",
    "espanduti": "espandere",
    "espanduto": "espandere",
    "espansa": "espanso",
    "espanse": "espanso",
    "espansi": "espanso",
    "espansioni": "espansione",
    "espansioniste": "espansionista",
    "espansionisti": "espansionista",
    "espansionistica": "espansionistico",
    "espansionistiche": "espansionistico",
    "espansionistici": "espansionistico",
    "espansiva": "espansivo",
    "espansive": "espansivo",
    "espansivi": "espansivo",
    "espaser": "espandere",
    "espasero": "espandere",
    "espasi": "espandere",
    "espasè": "espandere",
    "espatri": "espatrio",
    "espatria": "espatriare",
    "espatriai": "espatriare",
    "espatriammo": "espatriare",
    "espatriamo": "espatriare",
    "espatrian": "espatriare",
    "espatriando": "espatriare",
    "espatriano": "espatriare",
    "espatriante": "espatriare",
    "espatrianti": "espatriare",
    "espatriar": "espatriare",
    "espatriaron": "espatriare",
    "espatriarono": "espatriare",
    "espatriasse": "espatriare",
    "espatriasser": "espatriare",
    "espatriassero": "espatriare",
    "espatriassi": "espatriare",
    "espatriassimo": "espatriare",
    "espatriaste": "espatriare",
    "espatriasti": "espatriare",
    "espatriata": "espatriare",
    "espatriate": "espatriare",
    "espatriati": "espatriare",
    "espatriato": "espatriare",
    "espatriava": "espatriare",
    "espatriavamo": "espatriare",
    "espatriavan": "espatriare",
    "espatriavano": "espatriare",
    "espatriavate": "espatriare",
    "espatriavi": "espatriare",
    "espatriavo": "espatriare",
    "espatrierai": "espatriare",
    "espatrieran": "espatriare",
    "espatrieranno": "espatriare",
    "espatrierebbe": "espatriare",
    "espatrierebber": "espatriare",
    "espatrierebbero": "espatriare",
    "espatrierei": "espatriare",
    "espatrieremmo": "espatriare",
    "espatrieremo": "espatriare",
    "espatriereste": "espatriare",
    "espatrieresti": "espatriare",
    "espatrierete": "espatriare",
    "espatrierà": "espatriare",
    "espatrierò": "espatriare",
    "espatrin": "espatriare",
    "espatrino": "espatriare",
    "espatrio": "espatriare",
    "espatriò": "espatriare",
    "espedienti": "espediente",
    "espella": "espellere",
    "espellan": "espellere",
    "espellano": "espellere",
    "espelle": "espellere",
    "espellei": "espellere",
    "espellemmo": "espellere",
    "espellendo": "espellere",
    "espellente": "espellere",
    "espellenti": "espellere",
    "espeller": "espellere",
    "espellerai": "espellere",
    "espelleran": "espellere",
    "espelleranno": "espellere",
    "espellerebbe": "espellere",
    "espellerebber": "espellere",
    "espellerebbero": "espellere",
    "espellerei": "espellere",
    "espelleremmo": "espellere",
    "espelleremo": "espellere",
    "espellereste": "espellere",
    "espelleresti": "espellere",
    "espellerete": "espellere",
    "espelleron": "espellere",
    "espellerono": "espellere",
    "espellerà": "espellere",
    "espellerò": "espellere",
    "espellesse": "espellere",
    "espellesser": "espellere",
    "espellessero": "espellere",
    "espellessi": "espellere",
    "espellessimo": "espellere",
    "espelleste": "espellere",
    "espellesti": "espellere",
    "espellete": "espellere",
    "espelleva": "espellere",
    "espellevamo": "espellere",
    "espellevan": "espellere",
    "espellevano": "espellere",
    "espellevate": "espellere",
    "espellevi": "espellere",
    "espellevo": "espellere",
    "espelli": "espellere",
    "espelliamo": "espellere",
    "espelliate": "espellere",
    "espello": "espellere",
    "espellon": "espellere",
    "espellono": "espellere",
    "espelluta": "espellere",
    "espellute": "espellere",
    "espelluti": "espellere",
    "espelluto": "espellere",
    "espellè": "espellere",
    "esperendo": "esperire",
    "esperente": "esperire",
    "esperenti": "esperire",
    "esperiamo": "esperire",
    "esperiate": "esperire",
    "esperienze": "esperienza",
    "esperii": "esperire",
    "esperimenta": "esperimentare",
    "esperimentai": "esperimentare",
    "esperimentammo": "esperimentare",
    "esperimentan": "esperimentare",
    "esperimentando": "esperimentare",
    "esperimentano": "esperimentare",
    "esperimentante": "esperimentare",
    "esperimentanti": "esperimentare",
    "esperimentar": "esperimentare",
    "esperimentaron": "esperimentare",
    "esperimentarono": "esperimentare",
    "esperimentasse": "esperimentare",
    "esperimentasser": "esperimentare",
    "esperimentassero": "esperimentare",
    "esperimentassi": "esperimentare",
    "esperimentassimo": "esperimentare",
    "esperimentaste": "esperimentare",
    "esperimentasti": "esperimentare",
    "esperimentata": "esperimentare",
    "esperimentate": "esperimentare",
    "esperimentati": "esperimentare",
    "esperimentato": "esperimentare",
    "esperimentava": "esperimentare",
    "esperimentavamo": "esperimentare",
    "esperimentavan": "esperimentare",
    "esperimentavano": "esperimentare",
    "esperimentavate": "esperimentare",
    "esperimentavi": "esperimentare",
    "esperimentavo": "esperimentare",
    "esperimenterai": "esperimentare",
    "esperimenteran": "esperimentare",
    "esperimenteranno": "esperimentare",
    "esperimenterebbe": "esperimentare",
    "esperimenterebber": "esperimentare",
    "esperimenterebbero": "esperimentare",
    "esperimenterei": "esperimentare",
    "esperimenteremmo": "esperimentare",
    "esperimenteremo": "esperimentare",
    "esperimentereste": "esperimentare",
    "esperimenteresti": "esperimentare",
    "esperimenterete": "esperimentare",
    "esperimenterà": "esperimentare",
    "esperimenterò": "esperimentare",
    "esperimenti": "esperimento",
    "esperimentiamo": "esperimentare",
    "esperimentiate": "esperimentare",
    "esperimentin": "esperimentare",
    "esperimentino": "esperimentare",
    "esperimento": "esperimentare",
    "esperimentò": "esperimentare",
    "esperimmo": "esperire",
    "esperir": "esperire",
    "esperirai": "esperire",
    "esperiran": "esperire",
    "esperiranno": "esperire",
    "esperirebbe": "esperire",
    "esperirebber": "esperire",
    "esperirebbero": "esperire",
    "esperirei": "esperire",
    "esperiremmo": "esperire",
    "esperiremo": "esperire",
    "esperireste": "esperire",
    "esperiresti": "esperire",
    "esperirete": "esperire",
    "esperiron": "esperire",
    "esperirono": "esperire",
    "esperirà": "esperire",
    "esperirò": "esperire",
    "esperisca": "esperire",
    "esperiscan": "esperire",
    "esperiscano": "esperire",
    "esperisce": "esperire",
    "esperisci": "esperire",
    "esperisco": "esperire",
    "esperiscon": "esperire",
    "esperiscono": "esperire",
    "esperisse": "esperire",
    "esperisser": "esperire",
    "esperissero": "esperire",
    "esperissi": "esperire",
    "esperissimo": "esperire",
    "esperiste": "esperire",
    "esperisti": "esperire",
    "esperita": "esperire",
    "esperite": "esperire",
    "esperiti": "esperire",
    "esperito": "esperire",
    "esperiva": "esperire",
    "esperivamo": "esperire",
    "esperivan": "esperire",
    "esperivano": "esperire",
    "esperivate": "esperire",
    "esperivi": "esperire",
    "esperivo": "esperire",
    "esperta": "esperto",
    "esperte": "esperto",
    "esperti": "esperto",
    "esperì": "esperire",
    "espettora": "espettorare",
    "espettorai": "espettorare",
    "espettorammo": "espettorare",
    "espettoran": "espettorare",
    "espettorando": "espettorare",
    "espettorano": "espettorare",
    "espettorante": "espettorare",
    "espettoranti": "espettorare",
    "espettorar": "espettorare",
    "espettoraron": "espettorare",
    "espettorarono": "espettorare",
    "espettorasse": "espettorare",
    "espettorasser": "espettorare",
    "espettorassero": "espettorare",
    "espettorassi": "espettorare",
    "espettorassimo": "espettorare",
    "espettoraste": "espettorare",
    "espettorasti": "espettorare",
    "espettorata": "espettorare",
    "espettorate": "espettorare",
    "espettorati": "espettorare",
    "espettorato": "espettorare",
    "espettorava": "espettorare",
    "espettoravamo": "espettorare",
    "espettoravan": "espettorare",
    "espettoravano": "espettorare",
    "espettoravate": "espettorare",
    "espettoravi": "espettorare",
    "espettoravo": "espettorare",
    "espettorerai": "espettorare",
    "espettoreran": "espettorare",
    "espettoreranno": "espettorare",
    "espettorerebbe": "espettorare",
    "espettorerebber": "espettorare",
    "espettorerebbero": "espettorare",
    "espettorerei": "espettorare",
    "espettoreremmo": "espettorare",
    "espettoreremo": "espettorare",
    "espettorereste": "espettorare",
    "espettoreresti": "espettorare",
    "espettorerete": "espettorare",
    "espettorerà": "espettorare",
    "espettorerò": "espettorare",
    "espettori": "espettorare",
    "espettoriamo": "espettorare",
    "espettoriate": "espettorare",
    "espettorin": "espettorare",
    "espettorino": "espettorare",
    "espettoro": "espettorare",
    "espettorò": "espettorare",
    "espia": "espiare",
    "espiai": "espiare",
    "espiammo": "espiare",
    "espiamo": "espiare",
    "espian": "espiare",
    "espiando": "espiare",
    "espiano": "espiare",
    "espiante": "espiare",
    "espianti": "espiare",
    "espiar": "espiare",
    "espiaron": "espiare",
    "espiarono": "espiare",
    "espiasse": "espiare",
    "espiasser": "espiare",
    "espiassero": "espiare",
    "espiassi": "espiare",
    "espiassimo": "espiare",
    "espiaste": "espiare",
    "espiasti": "espiare",
    "espiata": "espiare",
    "espiate": "espiare",
    "espiati": "espiare",
    "espiato": "espiare",
    "espiatori": "espiatorio",
    "espiatoria": "espiatorio",
    "espiatorie": "espiatorio",
    "espiava": "espiare",
    "espiavamo": "espiare",
    "espiavan": "espiare",
    "espiavano": "espiare",
    "espiavate": "espiare",
    "espiavi": "espiare",
    "espiavo": "espiare",
    "espiazioni": "espiazione",
    "espierai": "espiare",
    "espieran": "espiare",
    "espieranno": "espiare",
    "espierebbe": "espiare",
    "espierebber": "espiare",
    "espierebbero": "espiare",
    "espierei": "espiare",
    "espieremmo": "espiare",
    "espieremo": "espiare",
    "espiereste": "espiare",
    "espieresti": "espiare",
    "espierete": "espiare",
    "espierà": "espiare",
    "espierò": "espiare",
    "espii": "espiare",
    "espin": "espiare",
    "espino": "espiare",
    "espio": "espiare",
    "espira": "espirare",
    "espirai": "espirare",
    "espirammo": "espirare",
    "espiran": "espirare",
    "espirando": "espirare",
    "espirano": "espirare",
    "espirante": "espirare",
    "espiranti": "espirare",
    "espirar": "espirare",
    "espiraron": "espirare",
    "espirarono": "espirare",
    "espirasse": "espirare",
    "espirasser": "espirare",
    "espirassero": "espirare",
    "espirassi": "espirare",
    "espirassimo": "espirare",
    "espiraste": "espirare",
    "espirasti": "espirare",
    "espirata": "espirare",
    "espirate": "espirare",
    "espirati": "espirare",
    "espirato": "espirare",
    "espirava": "espirare",
    "espiravamo": "espirare",
    "espiravan": "espirare",
    "espiravano": "espirare",
    "espiravate": "espirare",
    "espiravi": "espirare",
    "espiravo": "espirare",
    "espirerai": "espirare",
    "espireran": "espirare",
    "espireranno": "espirare",
    "espirerebbe": "espirare",
    "espirerebber": "espirare",
    "espirerebbero": "espirare",
    "espirerei": "espirare",
    "espireremmo": "espirare",
    "espireremo": "espirare",
    "espirereste": "espirare",
    "espireresti": "espirare",
    "espirerete": "espirare",
    "espirerà": "espirare",
    "espirerò": "espirare",
    "espiri": "espirare",
    "espiriamo": "espirare",
    "espiriate": "espirare",
    "espirin": "espirare",
    "espirino": "espirare",
    "espiro": "espirare",
    "espirò": "espirare",
    "espisodi": "espisodio",
    "espiò": "espiare",
    "espleta": "espletare",
    "espletai": "espletare",
    "espletammo": "espletare",
    "espletan": "espletare",
    "espletando": "espletare",
    "espletano": "espletare",
    "espletante": "espletare",
    "espletanti": "espletare",
    "espletar": "espletare",
    "espletaron": "espletare",
    "espletarono": "espletare",
    "espletasse": "espletare",
    "espletasser": "espletare",
    "espletassero": "espletare",
    "espletassi": "espletare",
    "espletassimo": "espletare",
    "espletaste": "espletare",
    "espletasti": "espletare",
    "espletata": "espletare",
    "espletate": "espletare",
    "espletati": "espletare",
    "espletato": "espletare",
    "espletava": "espletare",
    "espletavamo": "espletare",
    "espletavan": "espletare",
    "espletavano": "espletare",
    "espletavate": "espletare",
    "espletavi": "espletare",
    "espletavo": "espletare",
    "espleterai": "espletare",
    "espleteran": "espletare",
    "espleteranno": "espletare",
    "espleterebbe": "espletare",
    "espleterebber": "espletare",
    "espleterebbero": "espletare",
    "espleterei": "espletare",
    "espleteremmo": "espletare",
    "espleteremo": "espletare",
    "espletereste": "espletare",
    "espleteresti": "espletare",
    "espleterete": "espletare",
    "espleterà": "espletare",
    "espleterò": "espletare",
    "espleti": "espletare",
    "espletiamo": "espletare",
    "espletiate": "espletare",
    "espletin": "espletare",
    "espletino": "espletare",
    "espleto": "espletare",
    "espletò": "espletare",
    "esplica": "esplicare",
    "esplicai": "esplicare",
    "esplicammo": "esplicare",
    "esplican": "esplicare",
    "esplicando": "esplicare",
    "esplicano": "esplicare",
    "esplicante": "esplicare",
    "esplicanti": "esplicare",
    "esplicar": "esplicare",
    "esplicaron": "esplicare",
    "esplicarono": "esplicare",
    "esplicasse": "esplicare",
    "esplicasser": "esplicare",
    "esplicassero": "esplicare",
    "esplicassi": "esplicare",
    "esplicassimo": "esplicare",
    "esplicaste": "esplicare",
    "esplicasti": "esplicare",
    "esplicata": "esplicare",
    "esplicate": "esplicare",
    "esplicati": "esplicare",
    "esplicativa": "esplicativo",
    "esplicative": "esplicativo",
    "esplicativi": "esplicativo",
    "esplicato": "esplicare",
    "esplicava": "esplicare",
    "esplicavamo": "esplicare",
    "esplicavan": "esplicare",
    "esplicavano": "esplicare",
    "esplicavate": "esplicare",
    "esplicavi": "esplicare",
    "esplicavo": "esplicare",
    "esplicherai": "esplicare",
    "esplicheran": "esplicare",
    "esplicheranno": "esplicare",
    "esplicherebbe": "esplicare",
    "esplicherebber": "esplicare",
    "esplicherebbero": "esplicare",
    "esplicherei": "esplicare",
    "esplicheremmo": "esplicare",
    "esplicheremo": "esplicare",
    "esplichereste": "esplicare",
    "esplicheresti": "esplicare",
    "esplicherete": "esplicare",
    "esplicherà": "esplicare",
    "esplicherò": "esplicare",
    "esplichi": "esplicare",
    "esplichiamo": "esplicare",
    "esplichiate": "esplicare",
    "esplichin": "esplicare",
    "esplichino": "esplicare",
    "esplicita": "esplicito",
    "esplicitai": "esplicitare",
    "esplicitammo": "esplicitare",
    "esplicitan": "esplicitare",
    "esplicitando": "esplicitare",
    "esplicitano": "esplicitare",
    "esplicitante": "esplicitare",
    "esplicitanti": "esplicitare",
    "esplicitar": "esplicitare",
    "esplicitaron": "esplicitare",
    "esplicitarono": "esplicitare",
    "esplicitasse": "esplicitare",
    "esplicitasser": "esplicitare",
    "esplicitassero": "esplicitare",
    "esplicitassi": "esplicitare",
    "esplicitassimo": "esplicitare",
    "esplicitaste": "esplicitare",
    "esplicitasti": "esplicitare",
    "esplicitata": "esplicitare",
    "esplicitate": "esplicitare",
    "esplicitati": "esplicitare",
    "esplicitato": "esplicitare",
    "esplicitava": "esplicitare",
    "esplicitavamo": "esplicitare",
    "esplicitavan": "esplicitare",
    "esplicitavano": "esplicitare",
    "esplicitavate": "esplicitare",
    "esplicitavi": "esplicitare",
    "esplicitavo": "esplicitare",
    "esplicite": "esplicito",
    "espliciterai": "esplicitare",
    "espliciteran": "esplicitare",
    "espliciteranno": "esplicitare",
    "espliciterebbe": "esplicitare",
    "espliciterebber": "esplicitare",
    "espliciterebbero": "esplicitare",
    "espliciterei": "esplicitare",
    "espliciteremmo": "esplicitare",
    "espliciteremo": "esplicitare",
    "esplicitereste": "esplicitare",
    "espliciteresti": "esplicitare",
    "espliciterete": "esplicitare",
    "espliciterà": "esplicitare",
    "espliciterò": "esplicitare",
    "espliciti": "esplicito",
    "esplicitiamo": "esplicitare",
    "esplicitiate": "esplicitare",
    "esplicitin": "esplicitare",
    "esplicitino": "esplicitare",
    "esplicito": "esplicitare",
    "esplicitò": "esplicitare",
    "esplico": "esplicare",
    "esplicò": "esplicare",
    "esploda": "esplodere",
    "esplodan": "esplodere",
    "esplodano": "esplodere",
    "esplode": "esplodere",
    "esplodemmo": "esplodere",
    "esplodendo": "esplodere",
    "esplodente": "esplodere",
    "esplodenti": "esplodere",
    "esploder": "esplodere",
    "esploderai": "esplodere",
    "esploderan": "esplodere",
    "esploderanno": "esplodere",
    "esploderebbe": "esplodere",
    "esploderebber": "esplodere",
    "esploderebbero": "esplodere",
    "esploderei": "esplodere",
    "esploderemmo": "esplodere",
    "esploderemo": "esplodere",
    "esplodereste": "esplodere",
    "esploderesti": "esplodere",
    "esploderete": "esplodere",
    "esploderà": "esplodere",
    "esploderò": "esplodere",
    "esplodesse": "esplodere",
    "esplodesser": "esplodere",
    "esplodessero": "esplodere",
    "esplodessi": "esplodere",
    "esplodessimo": "esplodere",
    "esplodeste": "esplodere",
    "esplodesti": "esplodere",
    "esplodete": "esplodere",
    "esplodeva": "esplodere",
    "esplodevamo": "esplodere",
    "esplodevan": "esplodere",
    "esplodevano": "esplodere",
    "esplodevate": "esplodere",
    "esplodevi": "esplodere",
    "esplodevo": "esplodere",
    "esplodi": "esplodere",
    "esplodiamo": "esplodere",
    "esplodiate": "esplodere",
    "esplodo": "esplodere",
    "esplodon": "esplodere",
    "esplodono": "esplodere",
    "esplora": "esplorare",
    "esplorai": "esplorare",
    "esplorammo": "esplorare",
    "esploran": "esplorare",
    "esplorando": "esplorare",
    "esplorano": "esplorare",
    "esplorante": "esplorare",
    "esploranti": "esplorare",
    "esplorar": "esplorare",
    "esploraron": "esplorare",
    "esplorarono": "esplorare",
    "esplorasse": "esplorare",
    "esplorasser": "esplorare",
    "esplorassero": "esplorare",
    "esplorassi": "esplorare",
    "esplorassimo": "esplorare",
    "esploraste": "esplorare",
    "esplorasti": "esplorare",
    "esplorata": "esplorato",
    "esplorate": "esplorato",
    "esplorati": "esplorato",
    "esplorativa": "esplorativo",
    "esplorative": "esplorativo",
    "esplorativi": "esplorativo",
    "esplorato": "esplorare",
    "esploratori": "esploratore",
    "esploratrice": "esploratore",
    "esploratrici": "esploratore",
    "esplorava": "esplorare",
    "esploravamo": "esplorare",
    "esploravan": "esplorare",
    "esploravano": "esplorare",
    "esploravate": "esplorare",
    "esploravi": "esplorare",
    "esploravo": "esplorare",
    "esplorazioni": "esplorazione",
    "esplorerai": "esplorare",
    "esploreran": "esplorare",
    "esploreranno": "esplorare",
    "esplorerebbe": "esplorare",
    "esplorerebber": "esplorare",
    "esplorerebbero": "esplorare",
    "esplorerei": "esplorare",
    "esploreremmo": "esplorare",
    "esploreremo": "esplorare",
    "esplorereste": "esplorare",
    "esploreresti": "esplorare",
    "esplorerete": "esplorare",
    "esplorerà": "esplorare",
    "esplorerò": "esplorare",
    "esplori": "esplorare",
    "esploriamo": "esplorare",
    "esploriate": "esplorare",
    "esplorin": "esplorare",
    "esplorino": "esplorare",
    "esploro": "esplorare",
    "esplorò": "esplorare",
    "esplosa": "esploso",
    "esplose": "esploso",
    "esploser": "esplodere",
    "esplosero": "esplodere",
    "esplosi": "esploso",
    "esplosioni": "esplosione",
    "esplosiva": "esplosivo",
    "esplosive": "esplosivo",
    "esplosivi": "esplosivo",
    "esplosivistica": "esplosivistico",
    "esplosivistiche": "esplosivistico",
    "esplosivistici": "esplosivistico",
    "esploso": "esplodere",
    "espone": "esporre",
    "esponemmo": "esporre",
    "esponendo": "esporre",
    "esponente": "esporre",
    "esponenti": "esporre",
    "esponenziali": "esponenziale",
    "esponesse": "esporre",
    "esponesser": "esporre",
    "esponessero": "esporre",
    "esponessi": "esporre",
    "esponessimo": "esporre",
    "esponeste": "esporre",
    "esponesti": "esporre",
    "esponete": "esporre",
    "esponeva": "esporre",
    "esponevamo": "esporre",
    "esponevan": "esporre",
    "esponevano": "esporre",
    "esponevate": "esporre",
    "esponevi": "esporre",
    "esponevo": "esporre",
    "esponga": "esporre",
    "espongan": "esporre",
    "espongano": "esporre",
    "espongo": "esporre",
    "espongon": "esporre",
    "espongono": "esporre",
    "esponi": "esporre",
    "esponiamo": "esporre",
    "esponiate": "esporre",
    "esporr": "esporre",
    "esporrai": "esporre",
    "esporran": "esporre",
    "esporranno": "esporre",
    "esporrebbe": "esporre",
    "esporrebber": "esporre",
    "esporrebbero": "esporre",
    "esporrei": "esporre",
    "esporremmo": "esporre",
    "esporremo": "esporre",
    "esporreste": "esporre",
    "esporresti": "esporre",
    "esporrete": "esporre",
    "esporrà": "esporre",
    "esporrò": "esporre",
    "esporta": "esportare",
    "esportabili": "esportabile",
    "esportai": "esportare",
    "esportammo": "esportare",
    "esportan": "esportare",
    "esportando": "esportare",
    "esportano": "esportare",
    "esportante": "esportare",
    "esportanti": "esportare",
    "esportar": "esportare",
    "esportaron": "esportare",
    "esportarono": "esportare",
    "esportasse": "esportare",
    "esportasser": "esportare",
    "esportassero": "esportare",
    "esportassi": "esportare",
    "esportassimo": "esportare",
    "esportaste": "esportare",
    "esportasti": "esportare",
    "esportata": "esportare",
    "esportate": "esportare",
    "esportati": "esportare",
    "esportato": "esportare",
    "esportatori": "esportatore",
    "esportava": "esportare",
    "esportavamo": "esportare",
    "esportavan": "esportare",
    "esportavano": "esportare",
    "esportavate": "esportare",
    "esportavi": "esportare",
    "esportavo": "esportare",
    "esportazioni": "esportazione",
    "esporterai": "esportare",
    "esporteran": "esportare",
    "esporteranno": "esportare",
    "esporterebbe": "esportare",
    "esporterebber": "esportare",
    "esporterebbero": "esportare",
    "esporterei": "esportare",
    "esporteremmo": "esportare",
    "esporteremo": "esportare",
    "esportereste": "esportare",
    "esporteresti": "esportare",
    "esporterete": "esportare",
    "esporterà": "esportare",
    "esporterò": "esportare",
    "esporti": "esportare",
    "esportiamo": "esportare",
    "esportiate": "esportare",
    "esportin": "esportare",
    "esportino": "esportare",
    "esporto": "esportare",
    "esportò": "esportare",
    "espose": "esporre",
    "esposer": "esporre",
    "esposero": "esporre",
    "esposi": "esporre",
    "espositiva": "espositivo",
    "espositive": "espositivo",
    "espositivi": "espositivo",
    "espositori": "espositore",
    "espositrice": "espositore",
    "espositrici": "espositore",
    "esposizioni": "esposizione",
    "esposta": "esposto",
    "esposte": "esposto",
    "esposti": "esposto",
    "esposti-denuncia": "esposto-denuncia",
    "esposto": "esporre",
    "espressa": "esprimere",
    "espresse": "esprimere",
    "espresser": "esprimere",
    "espressero": "esprimere",
    "espressi": "esprimere",
    "espressioni": "espressione",
    "espressionismi": "espressionismo",
    "espressioniste": "espressionista",
    "espressionisti": "espressionista",
    "espressionistica": "espressionistico",
    "espressionistiche": "espressionistico",
    "espressionistici": "espressionistico",
    "espressiva": "espressivo",
    "espressive": "espressivo",
    "espressivi": "espressivo",
    "espresso": "esprimere",
    "esprima": "esprimere",
    "espriman": "esprimere",
    "esprimano": "esprimere",
    "esprime": "esprimere",
    "esprimemmo": "esprimere",
    "esprimendo": "esprimere",
    "esprimente": "esprimere",
    "esprimenti": "esprimere",
    "esprimer": "esprimere",
    "esprimerai": "esprimere",
    "esprimeran": "esprimere",
    "esprimeranno": "esprimere",
    "esprimerebbe": "esprimere",
    "esprimerebber": "esprimere",
    "esprimerebbero": "esprimere",
    "esprimerei": "esprimere",
    "esprimeremmo": "esprimere",
    "esprimeremo": "esprimere",
    "esprimereste": "esprimere",
    "esprimeresti": "esprimere",
    "esprimerete": "esprimere",
    "esprimerà": "esprimere",
    "esprimerò": "esprimere",
    "esprimesse": "esprimere",
    "esprimesser": "esprimere",
    "esprimessero": "esprimere",
    "esprimessi": "esprimere",
    "esprimessimo": "esprimere",
    "esprimeste": "esprimere",
    "esprimesti": "esprimere",
    "esprimete": "esprimere",
    "esprimeva": "esprimere",
    "esprimevamo": "esprimere",
    "esprimevan": "esprimere",
    "esprimevano": "esprimere",
    "esprimevate": "esprimere",
    "esprimevi": "esprimere",
    "esprimevo": "esprimere",
    "esprimi": "esprimere",
    "esprimiamo": "esprimere",
    "esprimiate": "esprimere",
    "esprimo": "esprimere",
    "esprimon": "esprimere",
    "esprimono": "esprimere",
    "espropri": "esproprio",
    "espropria": "espropriare",
    "espropriai": "espropriare",
    "espropriammo": "espropriare",
    "espropriamo": "espropriare",
    "esproprian": "espropriare",
    "espropriando": "espropriare",
    "espropriano": "espropriare",
    "espropriante": "espropriare",
    "esproprianti": "espropriare",
    "espropriar": "espropriare",
    "espropriaron": "espropriare",
    "espropriarono": "espropriare",
    "espropriasse": "espropriare",
    "espropriasser": "espropriare",
    "espropriassero": "espropriare",
    "espropriassi": "espropriare",
    "espropriassimo": "espropriare",
    "espropriaste": "espropriare",
    "espropriasti": "espropriare",
    "espropriata": "espropriare",
    "espropriate": "espropriare",
    "espropriati": "espropriare",
    "espropriato": "espropriare",
    "espropriava": "espropriare",
    "espropriavamo": "espropriare",
    "espropriavan": "espropriare",
    "espropriavano": "espropriare",
    "espropriavate": "espropriare",
    "espropriavi": "espropriare",
    "espropriavo": "espropriare",
    "espropriazioni": "espropriazione",
    "esproprierai": "espropriare",
    "esproprieran": "espropriare",
    "esproprieranno": "espropriare",
    "esproprierebbe": "espropriare",
    "esproprierebber": "espropriare",
    "esproprierebbero": "espropriare",
    "esproprierei": "espropriare",
    "esproprieremmo": "espropriare",
    "esproprieremo": "espropriare",
    "espropriereste": "espropriare",
    "esproprieresti": "espropriare",
    "esproprierete": "espropriare",
    "esproprierà": "espropriare",
    "esproprierò": "espropriare",
    "esproprin": "espropriare",
    "esproprino": "espropriare",
    "esproprio": "espropriare",
    "espropriò": "espropriare",
    "espugna": "espugnare",
    "espugnai": "espugnare",
    "espugnammo": "espugnare",
    "espugnan": "espugnare",
    "espugnando": "espugnare",
    "espugnano": "espugnare",
    "espugnante": "espugnare",
    "espugnanti": "espugnare",
    "espugnar": "espugnare",
    "espugnaron": "espugnare",
    "espugnarono": "espugnare",
    "espugnasse": "espugnare",
    "espugnasser": "espugnare",
    "espugnassero": "espugnare",
    "espugnassi": "espugnare",
    "espugnassimo": "espugnare",
    "espugnaste": "espugnare",
    "espugnasti": "espugnare",
    "espugnata": "espugnare",
    "espugnate": "espugnare",
    "espugnati": "espugnare",
    "espugnato": "espugnare",
    "espugnava": "espugnare",
    "espugnavamo": "espugnare",
    "espugnavan": "espugnare",
    "espugnavano": "espugnare",
    "espugnavate": "espugnare",
    "espugnavi": "espugnare",
    "espugnavo": "espugnare",
    "espugnerai": "espugnare",
    "espugneran": "espugnare",
    "espugneranno": "espugnare",
    "espugnerebbe": "espugnare",
    "espugnerebber": "espugnare",
    "espugnerebbero": "espugnare",
    "espugnerei": "espugnare",
    "espugneremmo": "espugnare",
    "espugneremo": "espugnare",
    "espugnereste": "espugnare",
    "espugneresti": "espugnare",
    "espugnerete": "espugnare",
    "espugnerà": "espugnare",
    "espugnerò": "espugnare",
    "espugni": "espugnare",
    "espugniamo": "espugnare",
    "espugniate": "espugnare",
    "espugnin": "espugnare",
    "espugnino": "espugnare",
    "espugno": "espugnare",
    "espugnò": "espugnare",
    "espulsa": "espulso",
    "espulse": "espulso",
    "espulsi": "espulso",
    "espulsioni": "espulsione",
    "espunga": "espungere",
    "espungan": "espungere",
    "espungano": "espungere",
    "espunge": "espungere",
    "espungemmo": "espungere",
    "espungendo": "espungere",
    "espungente": "espungere",
    "espungenti": "espungere",
    "espunger": "espungere",
    "espungerai": "espungere",
    "espungeran": "espungere",
    "espungeranno": "espungere",
    "espungerebbe": "espungere",
    "espungerebber": "espungere",
    "espungerebbero": "espungere",
    "espungerei": "espungere",
    "espungeremmo": "espungere",
    "espungeremo": "espungere",
    "espungereste": "espungere",
    "espungeresti": "espungere",
    "espungerete": "espungere",
    "espungerà": "espungere",
    "espungerò": "espungere",
    "espungesse": "espungere",
    "espungesser": "espungere",
    "espungessero": "espungere",
    "espungessi": "espungere",
    "espungessimo": "espungere",
    "espungeste": "espungere",
    "espungesti": "espungere",
    "espungete": "espungere",
    "espungeva": "espungere",
    "espungevamo": "espungere",
    "espungevan": "espungere",
    "espungevano": "espungere",
    "espungevate": "espungere",
    "espungevi": "espungere",
    "espungevo": "espungere",
    "espungi": "espungere",
    "espungiamo": "espungere",
    "espungiate": "espungere",
    "espungo": "espungere",
    "espungon": "espungere",
    "espungono": "espungere",
    "espunser": "espungere",
    "espunsero": "espungere",
    "espunsi": "espungere",
    "espunsè": "espungere",
    "espunta": "espungere",
    "espunte": "espungere",
    "espunti": "espungere",
    "espunto": "espungere",
    "espurga": "espurgare",
    "espurgai": "espurgare",
    "espurgammo": "espurgare",
    "espurgan": "espurgare",
    "espurgando": "espurgare",
    "espurgano": "espurgare",
    "espurgante": "espurgare",
    "espurganti": "espurgare",
    "espurgar": "espurgare",
    "espurgaron": "espurgare",
    "espurgarono": "espurgare",
    "espurgasse": "espurgare",
    "espurgasser": "espurgare",
    "espurgassero": "espurgare",
    "espurgassi": "espurgare",
    "espurgassimo": "espurgare",
    "espurgaste": "espurgare",
    "espurgasti": "espurgare",
    "espurgata": "espurgare",
    "espurgate": "espurgare",
    "espurgati": "espurgare",
    "espurgato": "espurgare",
    "espurgava": "espurgare",
    "espurgavamo": "espurgare",
    "espurgavan": "espurgare",
    "espurgavano": "espurgare",
    "espurgavate": "espurgare",
    "espurgavi": "espurgare",
    "espurgavo": "espurgare",
    "espurgherai": "espurgare",
    "espurgheran": "espurgare",
    "espurgheranno": "espurgare",
    "espurgherebbe": "espurgare",
    "espurgherebber": "espurgare",
    "espurgherebbero": "espurgare",
    "espurgherei": "espurgare",
    "espurgheremmo": "espurgare",
    "espurgheremo": "espurgare",
    "espurghereste": "espurgare",
    "espurgheresti": "espurgare",
    "espurgherete": "espurgare",
    "espurgherà": "espurgare",
    "espurgherò": "espurgare",
    "espurghi": "espurgare",
    "espurghiamo": "espurgare",
    "espurghiate": "espurgare",
    "espurghin": "espurgare",
    "espurghino": "espurgare",
    "espurgo": "espurgare",
    "espurgò": "espurgare",
    "esquimesi": "esquimese",
    "essendo": "essere",
    "essente": "essere",
    "essenti": "essere",
    "essenze": "essenza",
    "essenziali": "essenziale",
    "esser": "essere",
    "esseri": "essere",
    "esserini": "esserino",
    "essicca": "essiccare",
    "essiccai": "essiccare",
    "essiccammo": "essiccare",
    "essiccan": "essiccare",
    "essiccando": "essiccare",
    "essiccano": "essiccare",
    "essiccante": "essiccare",
    "essiccanti": "essiccare",
    "essiccar": "essiccare",
    "essiccaron": "essiccare",
    "essiccarono": "essiccare",
    "essiccasse": "essiccare",
    "essiccasser": "essiccare",
    "essiccassero": "essiccare",
    "essiccassi": "essiccare",
    "essiccassimo": "essiccare",
    "essiccaste": "essiccare",
    "essiccasti": "essiccare",
    "essiccata": "essiccare",
    "essiccate": "essiccare",
    "essiccati": "essiccare",
    "essiccato": "essiccare",
    "essiccava": "essiccare",
    "essiccavamo": "essiccare",
    "essiccavan": "essiccare",
    "essiccavano": "essiccare",
    "essiccavate": "essiccare",
    "essiccavi": "essiccare",
    "essiccavo": "essiccare",
    "essiccherai": "essiccare",
    "essiccheran": "essiccare",
    "essiccheranno": "essiccare",
    "essiccherebbe": "essiccare",
    "essiccherebber": "essiccare",
    "essiccherebbero": "essiccare",
    "essiccherei": "essiccare",
    "essiccheremmo": "essiccare",
    "essiccheremo": "essiccare",
    "essicchereste": "essiccare",
    "essiccheresti": "essiccare",
    "essiccherete": "essiccare",
    "essiccherà": "essiccare",
    "essiccherò": "essiccare",
    "essicchi": "essiccare",
    "essicchiamo": "essiccare",
    "essicchiate": "essiccare",
    "essicchin": "essiccare",
    "essicchino": "essiccare",
    "essicco": "essiccare",
    "essiccò": "essiccare",
    "estasi": "estasiare",
    "estasia": "estasiare",
    "estasiai": "estasiare",
    "estasiammo": "estasiare",
    "estasiamo": "estasiare",
    "estasian": "estasiare",
    "estasiando": "estasiare",
    "estasiano": "estasiare",
    "estasiante": "estasiare",
    "estasianti": "estasiare",
    "estasiar": "estasiare",
    "estasiaron": "estasiare",
    "estasiarono": "estasiare",
    "estasiasse": "estasiare",
    "estasiasser": "estasiare",
    "estasiassero": "estasiare",
    "estasiassi": "estasiare",
    "estasiassimo": "estasiare",
    "estasiaste": "estasiare",
    "estasiasti": "estasiare",
    "estasiata": "estasiare",
    "estasiate": "estasiare",
    "estasiati": "estasiare",
    "estasiato": "estasiare",
    "estasiava": "estasiare",
    "estasiavamo": "estasiare",
    "estasiavan": "estasiare",
    "estasiavano": "estasiare",
    "estasiavate": "estasiare",
    "estasiavi": "estasiare",
    "estasiavo": "estasiare",
    "estasierai": "estasiare",
    "estasieran": "estasiare",
    "estasieranno": "estasiare",
    "estasierebbe": "estasiare",
    "estasierebber": "estasiare",
    "estasierebbero": "estasiare",
    "estasierei": "estasiare",
    "estasieremmo": "estasiare",
    "estasieremo": "estasiare",
    "estasiereste": "estasiare",
    "estasieresti": "estasiare",
    "estasierete": "estasiare",
    "estasierà": "estasiare",
    "estasierò": "estasiare",
    "estasin": "estasiare",
    "estasino": "estasiare",
    "estasio": "estasiare",
    "estasiò": "estasiare",
    "estati": "estate",
    "estatica": "estatico",
    "estatiche": "estatico",
    "estatici": "estatico",
    "estemporanea": "estemporaneo",
    "estemporanee": "estemporaneo",
    "estemporanei": "estemporaneo",
    "estenda": "estendere",
    "estendan": "estendere",
    "estendano": "estendere",
    "estende": "estendere",
    "estendemmo": "estendere",
    "estendendo": "estendere",
    "estendente": "estendere",
    "estendenti": "estendere",
    "estender": "estendere",
    "estenderai": "estendere",
    "estenderan": "estendere",
    "estenderanno": "estendere",
    "estenderebbe": "estendere",
    "estenderebber": "estendere",
    "estenderebbero": "estendere",
    "estenderei": "estendere",
    "estenderemmo": "estendere",
    "estenderemo": "estendere",
    "estendereste": "estendere",
    "estenderesti": "estendere",
    "estenderete": "estendere",
    "estenderà": "estendere",
    "estenderò": "estendere",
    "estendesse": "estendere",
    "estendesser": "estendere",
    "estendessero": "estendere",
    "estendessi": "estendere",
    "estendessimo": "estendere",
    "estendeste": "estendere",
    "estendesti": "estendere",
    "estendete": "estendere",
    "estendeva": "estendere",
    "estendevamo": "estendere",
    "estendevan": "estendere",
    "estendevano": "estendere",
    "estendevate": "estendere",
    "estendevi": "estendere",
    "estendevo": "estendere",
    "estendi": "estendere",
    "estendiamo": "estendere",
    "estendiate": "estendere",
    "estendo": "estendere",
    "estendon": "estendere",
    "estendono": "estendere",
    "estensa": "estenso",
    "estense": "estenso",
    "estensi": "estenso",
    "estensibili": "estensibile",
    "estensioni": "estensione",
    "estensiva": "estensivo",
    "estensive": "estensivo",
    "estensivi": "estensivo",
    "estensori": "estensore",
    "estenua": "estenuare",
    "estenuai": "estenuare",
    "estenuammo": "estenuare",
    "estenuan": "estenuare",
    "estenuando": "estenuare",
    "estenuano": "estenuare",
    "estenuante": "estenuare",
    "estenuanti": "estenuare",
    "estenuar": "estenuare",
    "estenuaron": "estenuare",
    "estenuarono": "estenuare",
    "estenuasse": "estenuare",
    "estenuasser": "estenuare",
    "estenuassero": "estenuare",
    "estenuassi": "estenuare",
    "estenuassimo": "estenuare",
    "estenuaste": "estenuare",
    "estenuasti": "estenuare",
    "estenuata": "estenuare",
    "estenuate": "estenuare",
    "estenuati": "estenuare",
    "estenuato": "estenuare",
    "estenuava": "estenuare",
    "estenuavamo": "estenuare",
    "estenuavan": "estenuare",
    "estenuavano": "estenuare",
    "estenuavate": "estenuare",
    "estenuavi": "estenuare",
    "estenuavo": "estenuare",
    "estenuerai": "estenuare",
    "estenueran": "estenuare",
    "estenueranno": "estenuare",
    "estenuerebbe": "estenuare",
    "estenuerebber": "estenuare",
    "estenuerebbero": "estenuare",
    "estenuerei": "estenuare",
    "estenueremmo": "estenuare",
    "estenueremo": "estenuare",
    "estenuereste": "estenuare",
    "estenueresti": "estenuare",
    "estenuerete": "estenuare",
    "estenuerà": "estenuare",
    "estenuerò": "estenuare",
    "estenui": "estenuare",
    "estenuiamo": "estenuare",
    "estenuiate": "estenuare",
    "estenuin": "estenuare",
    "estenuino": "estenuare",
    "estenuo": "estenuare",
    "estenuò": "estenuare",
    "estera": "estero",
    "estere": "estero",
    "esteri": "estero",
    "esterifica": "esterificare",
    "esterificai": "esterificare",
    "esterificammo": "esterificare",
    "esterifican": "esterificare",
    "esterificando": "esterificare",
    "esterificano": "esterificare",
    "esterificante": "esterificare",
    "esterificanti": "esterificare",
    "esterificar": "esterificare",
    "esterificaron": "esterificare",
    "esterificarono": "esterificare",
    "esterificasse": "esterificare",
    "esterificasser": "esterificare",
    "esterificassero": "esterificare",
    "esterificassi": "esterificare",
    "esterificassimo": "esterificare",
    "esterificaste": "esterificare",
    "esterificasti": "esterificare",
    "esterificata": "esterificare",
    "esterificate": "esterificare",
    "esterificati": "esterificare",
    "esterificato": "esterificare",
    "esterificava": "esterificare",
    "esterificavamo": "esterificare",
    "esterificavan": "esterificare",
    "esterificavano": "esterificare",
    "esterificavate": "esterificare",
    "esterificavi": "esterificare",
    "esterificavo": "esterificare",
    "esterificherai": "esterificare",
    "esterificheran": "esterificare",
    "esterificheranno": "esterificare",
    "esterificherebbe": "esterificare",
    "esterificherebber": "esterificare",
    "esterificherebbero": "esterificare",
    "esterificherei": "esterificare",
    "esterificheremmo": "esterificare",
    "esterificheremo": "esterificare",
    "esterifichereste": "esterificare",
    "esterificheresti": "esterificare",
    "esterificherete": "esterificare",
    "esterificherà": "esterificare",
    "esterificherò": "esterificare",
    "esterifichi": "esterificare",
    "esterifichiamo": "esterificare",
    "esterifichiate": "esterificare",
    "esterifichin": "esterificare",
    "esterifichino": "esterificare",
    "esterifico": "esterificare",
    "esterificò": "esterificare",
    "esteriori": "esteriore",
    "esteriorizza": "esteriorizzare",
    "esteriorizzai": "esteriorizzare",
    "esteriorizzammo": "esteriorizzare",
    "esteriorizzan": "esteriorizzare",
    "esteriorizzando": "esteriorizzare",
    "esteriorizzano": "esteriorizzare",
    "esteriorizzante": "esteriorizzare",
    "esteriorizzanti": "esteriorizzare",
    "esteriorizzar": "esteriorizzare",
    "esteriorizzaron": "esteriorizzare",
    "esteriorizzarono": "esteriorizzare",
    "esteriorizzasse": "esteriorizzare",
    "esteriorizzasser": "esteriorizzare",
    "esteriorizzassero": "esteriorizzare",
    "esteriorizzassi": "esteriorizzare",
    "esteriorizzassimo": "esteriorizzare",
    "esteriorizzaste": "esteriorizzare",
    "esteriorizzasti": "esteriorizzare",
    "esteriorizzata": "esteriorizzare",
    "esteriorizzate": "esteriorizzare",
    "esteriorizzati": "esteriorizzare",
    "esteriorizzato": "esteriorizzare",
    "esteriorizzava": "esteriorizzare",
    "esteriorizzavamo": "esteriorizzare",
    "esteriorizzavan": "esteriorizzare",
    "esteriorizzavano": "esteriorizzare",
    "esteriorizzavate": "esteriorizzare",
    "esteriorizzavi": "esteriorizzare",
    "esteriorizzavo": "esteriorizzare",
    "esteriorizzerai": "esteriorizzare",
    "esteriorizzeran": "esteriorizzare",
    "esteriorizzeranno": "esteriorizzare",
    "esteriorizzerebbe": "esteriorizzare",
    "esteriorizzerebber": "esteriorizzare",
    "esteriorizzerebbero": "esteriorizzare",
    "esteriorizzerei": "esteriorizzare",
    "esteriorizzeremmo": "esteriorizzare",
    "esteriorizzeremo": "esteriorizzare",
    "esteriorizzereste": "esteriorizzare",
    "esteriorizzeresti": "esteriorizzare",
    "esteriorizzerete": "esteriorizzare",
    "esteriorizzerà": "esteriorizzare",
    "esteriorizzerò": "esteriorizzare",
    "esteriorizzi": "esteriorizzare",
    "esteriorizziamo": "esteriorizzare",
    "esteriorizziate": "esteriorizzare",
    "esteriorizzin": "esteriorizzare",
    "esteriorizzino": "esteriorizzare",
    "esteriorizzo": "esteriorizzare",
    "esteriorizzò": "esteriorizzare",
    "esterna": "esterno",
    "esternai": "esternare",
    "esternalizza": "esternalizzare",
    "esternalizzai": "esternalizzare",
    "esternalizzammo": "esternalizzare",
    "esternalizzan": "esternalizzare",
    "esternalizzando": "esternalizzare",
    "esternalizzano": "esternalizzare",
    "esternalizzante": "esternalizzare",
    "esternalizzanti": "esternalizzare",
    "esternalizzar": "esternalizzare",
    "esternalizzaron": "esternalizzare",
    "esternalizzarono": "esternalizzare",
    "esternalizzasse": "esternalizzare",
    "esternalizzasser": "esternalizzare",
    "esternalizzassero": "esternalizzare",
    "esternalizzassi": "esternalizzare",
    "esternalizzassimo": "esternalizzare",
    "esternalizzaste": "esternalizzare",
    "esternalizzasti": "esternalizzare",
    "esternalizzata": "esternalizzare",
    "esternalizzate": "esternalizzare",
    "esternalizzati": "esternalizzare",
    "esternalizzato": "esternalizzare",
    "esternalizzava": "esternalizzare",
    "esternalizzavamo": "esternalizzare",
    "esternalizzavan": "esternalizzare",
    "esternalizzavano": "esternalizzare",
    "esternalizzavate": "esternalizzare",
    "esternalizzavi": "esternalizzare",
    "esternalizzavo": "esternalizzare",
    "esternalizzerai": "esternalizzare",
    "esternalizzeran": "esternalizzare",
    "esternalizzeranno": "esternalizzare",
    "esternalizzerebbe": "esternalizzare",
    "esternalizzerebber": "esternalizzare",
    "esternalizzerebbero": "esternalizzare",
    "esternalizzerei": "esternalizzare",
    "esternalizzeremmo": "esternalizzare",
    "esternalizzeremo": "esternalizzare",
    "esternalizzereste": "esternalizzare",
    "esternalizzeresti": "esternalizzare",
    "esternalizzerete": "esternalizzare",
    "esternalizzerà": "esternalizzare",
    "esternalizzerò": "esternalizzare",
    "esternalizzi": "esternalizzare",
    "esternalizziamo": "esternalizzare",
    "esternalizziate": "esternalizzare",
    "esternalizzin": "esternalizzare",
    "esternalizzino": "esternalizzare",
    "esternalizzo": "esternalizzare",
    "esternalizzò": "esternalizzare",
    "esternammo": "esternare",
    "esternan": "esternare",
    "esternando": "esternare",
    "esternano": "esternare",
    "esternante": "esternare",
    "esternanti": "esternare",
    "esternar": "esternare",
    "esternaron": "esternare",
    "esternarono": "esternare",
    "esternasse": "esternare",
    "esternasser": "esternare",
    "esternassero": "esternare",
    "esternassi": "esternare",
    "esternassimo": "esternare",
    "esternaste": "esternare",
    "esternasti": "esternare",
    "esternata": "esternare",
    "esternate": "esternare",
    "esternati": "esternare",
    "esternato": "esternare",
    "esternatori": "esternatore",
    "esternava": "esternare",
    "esternavamo": "esternare",
    "esternavan": "esternare",
    "esternavano": "esternare",
    "esternavate": "esternare",
    "esternavi": "esternare",
    "esternavo": "esternare",
    "esternazioni": "esternazione",
    "esterne": "esterno",
    "esternerai": "esternare",
    "esterneran": "esternare",
    "esterneranno": "esternare",
    "esternerebbe": "esternare",
    "esternerebber": "esternare",
    "esternerebbero": "esternare",
    "esternerei": "esternare",
    "esterneremmo": "esternare",
    "esterneremo": "esternare",
    "esternereste": "esternare",
    "esterneresti": "esternare",
    "esternerete": "esternare",
    "esternerà": "esternare",
    "esternerò": "esternare",
    "esterni": "esterno",
    "esterniamo": "esternare",
    "esterniate": "esternare",
    "esternin": "esternare",
    "esternino": "esternare",
    "esterno": "esternare",
    "esternò": "esternare",
    "esterofila": "esterofilo",
    "esterofile": "esterofilo",
    "esterofili": "esterofilo",
    "esterofilie": "esterofilia",
    "esterrefatta": "esterrefatto",
    "esterrefatte": "esterrefatto",
    "esterrefatti": "esterrefatto",
    "estesa": "esteso",
    "estese": "esteso",
    "esteser": "estendere",
    "estesero": "estendere",
    "estesi": "esteso",
    "esteso": "estendere",
    "estesè": "estendere",
    "esteti": "esteta",
    "estetica": "estetico",
    "estetiche": "estetico",
    "estetici": "estetico",
    "estetismi": "estetismo",
    "estetiste": "estetista",
    "estetizza": "estetizzare",
    "estetizzai": "estetizzare",
    "estetizzammo": "estetizzare",
    "estetizzan": "estetizzare",
    "estetizzando": "estetizzare",
    "estetizzano": "estetizzare",
    "estetizzante": "estetizzare",
    "estetizzanti": "estetizzare",
    "estetizzar": "estetizzare",
    "estetizzaron": "estetizzare",
    "estetizzarono": "estetizzare",
    "estetizzasse": "estetizzare",
    "estetizzasser": "estetizzare",
    "estetizzassero": "estetizzare",
    "estetizzassi": "estetizzare",
    "estetizzassimo": "estetizzare",
    "estetizzaste": "estetizzare",
    "estetizzasti": "estetizzare",
    "estetizzata": "estetizzare",
    "estetizzate": "estetizzare",
    "estetizzati": "estetizzare",
    "estetizzato": "estetizzare",
    "estetizzava": "estetizzare",
    "estetizzavamo": "estetizzare",
    "estetizzavan": "estetizzare",
    "estetizzavano": "estetizzare",
    "estetizzavate": "estetizzare",
    "estetizzavi": "estetizzare",
    "estetizzavo": "estetizzare",
    "estetizzerai": "estetizzare",
    "estetizzeran": "estetizzare",
    "estetizzeranno": "estetizzare",
    "estetizzerebbe": "estetizzare",
    "estetizzerebber": "estetizzare",
    "estetizzerebbero": "estetizzare",
    "estetizzerei": "estetizzare",
    "estetizzeremmo": "estetizzare",
    "estetizzeremo": "estetizzare",
    "estetizzereste": "estetizzare",
    "estetizzeresti": "estetizzare",
    "estetizzerete": "estetizzare",
    "estetizzerà": "estetizzare",
    "estetizzerò": "estetizzare",
    "estetizzi": "estetizzare",
    "estetizziamo": "estetizzare",
    "estetizziate": "estetizzare",
    "estetizzin": "estetizzare",
    "estetizzino": "estetizzare",
    "estetizzo": "estetizzare",
    "estetizzò": "estetizzare",
    "esteuropea": "esteuropeo",
    "esteuropee": "esteuropeo",
    "esteuropei": "esteuropeo",
    "estima": "estimare",
    "estimai": "estimare",
    "estimammo": "estimare",
    "estiman": "estimare",
    "estimando": "estimare",
    "estimano": "estimare",
    "estimante": "estimare",
    "estimanti": "estimare",
    "estimar": "estimare",
    "estimaron": "estimare",
    "estimarono": "estimare",
    "estimasse": "estimare",
    "estimasser": "estimare",
    "estimassero": "estimare",
    "estimassi": "estimare",
    "estimassimo": "estimare",
    "estimaste": "estimare",
    "estimasti": "estimare",
    "estimata": "estimare",
    "estimate": "estimare",
    "estimati": "estimare",
    "estimato": "estimare",
    "estimatori": "estimatore",
    "estimava": "estimare",
    "estimavamo": "estimare",
    "estimavan": "estimare",
    "estimavano": "estimare",
    "estimavate": "estimare",
    "estimavi": "estimare",
    "estimavo": "estimare",
    "estimerai": "estimare",
    "estimeran": "estimare",
    "estimeranno": "estimare",
    "estimerebbe": "estimare",
    "estimerebber": "estimare",
    "estimerebbero": "estimare",
    "estimerei": "estimare",
    "estimeremmo": "estimare",
    "estimeremo": "estimare",
    "estimereste": "estimare",
    "estimeresti": "estimare",
    "estimerete": "estimare",
    "estimerà": "estimare",
    "estimerò": "estimare",
    "estimi": "estimo",
    "estimiamo": "estimare",
    "estimiate": "estimare",
    "estimin": "estimare",
    "estimino": "estimare",
    "estimo": "estimare",
    "estimò": "estimare",
    "estingua": "estinguere",
    "estinguan": "estinguere",
    "estinguano": "estinguere",
    "estingue": "estinguere",
    "estinguemmo": "estinguere",
    "estinguendo": "estinguere",
    "estinguente": "estinguere",
    "estinguenti": "estinguere",
    "estinguer": "estinguere",
    "estinguerai": "estinguere",
    "estingueran": "estinguere",
    "estingueranno": "estinguere",
    "estinguerebbe": "estinguere",
    "estinguerebber": "estinguere",
    "estinguerebbero": "estinguere",
    "estinguerei": "estinguere",
    "estingueremmo": "estinguere",
    "estingueremo": "estinguere",
    "estinguereste": "estinguere",
    "estingueresti": "estinguere",
    "estinguerete": "estinguere",
    "estinguerà": "estinguere",
    "estinguerò": "estinguere",
    "estinguesse": "estinguere",
    "estinguesser": "estinguere",
    "estinguessero": "estinguere",
    "estinguessi": "estinguere",
    "estinguessimo": "estinguere",
    "estingueste": "estinguere",
    "estinguesti": "estinguere",
    "estinguete": "estinguere",
    "estingueva": "estinguere",
    "estinguevamo": "estinguere",
    "estinguevan": "estinguere",
    "estinguevano": "estinguere",
    "estinguevate": "estinguere",
    "estinguevi": "estinguere",
    "estinguevo": "estinguere",
    "estingui": "estinguere",
    "estinguiamo": "estinguere",
    "estinguiate": "estinguere",
    "estinguo": "estinguere",
    "estinguon": "estinguere",
    "estinguono": "estinguere",
    "estinse": "estinguere",
    "estinser": "estinguere",
    "estinsero": "estinguere",
    "estinsi": "estinguere",
    "estinta": "estinto",
    "estinte": "estinto",
    "estinti": "estinto",
    "estinto": "estinguere",
    "estintori": "estintore",
    "estinzioni": "estinzione",
    "estirpa": "estirpare",
    "estirpai": "estirpare",
    "estirpammo": "estirpare",
    "estirpan": "estirpare",
    "estirpando": "estirpare",
    "estirpano": "estirpare",
    "estirpante": "estirpare",
    "estirpanti": "estirpare",
    "estirpar": "estirpare",
    "estirparon": "estirpare",
    "estirparono": "estirpare",
    "estirpasse": "estirpare",
    "estirpasser": "estirpare",
    "estirpassero": "estirpare",
    "estirpassi": "estirpare",
    "estirpassimo": "estirpare",
    "estirpaste": "estirpare",
    "estirpasti": "estirpare",
    "estirpata": "estirpare",
    "estirpate": "estirpare",
    "estirpati": "estirpare",
    "estirpato": "estirpare",
    "estirpava": "estirpare",
    "estirpavamo": "estirpare",
    "estirpavan": "estirpare",
    "estirpavano": "estirpare",
    "estirpavate": "estirpare",
    "estirpavi": "estirpare",
    "estirpavo": "estirpare",
    "estirperai": "estirpare",
    "estirperan": "estirpare",
    "estirperanno": "estirpare",
    "estirperebbe": "estirpare",
    "estirperebber": "estirpare",
    "estirperebbero": "estirpare",
    "estirperei": "estirpare",
    "estirperemmo": "estirpare",
    "estirperemo": "estirpare",
    "estirpereste": "estirpare",
    "estirperesti": "estirpare",
    "estirperete": "estirpare",
    "estirperà": "estirpare",
    "estirperò": "estirpare",
    "estirpi": "estirpare",
    "estirpiamo": "estirpare",
    "estirpiate": "estirpare",
    "estirpin": "estirpare",
    "estirpino": "estirpare",
    "estirpo": "estirpare",
    "estirpò": "estirpare",
    "estiva": "estivo",
    "estivai": "estivare",
    "estivammo": "estivare",
    "estivan": "estivare",
    "estivando": "estivare",
    "estivano": "estivare",
    "estivante": "estivare",
    "estivanti": "estivare",
    "estivar": "estivare",
    "estivaron": "estivare",
    "estivarono": "estivare",
    "estivasse": "estivare",
    "estivasser": "estivare",
    "estivassero": "estivare",
    "estivassi": "estivare",
    "estivassimo": "estivare",
    "estivaste": "estivare",
    "estivasti": "estivare",
    "estivata": "estivare",
    "estivate": "estivare",
    "estivati": "estivare",
    "estivato": "estivare",
    "estivava": "estivare",
    "estivavamo": "estivare",
    "estivavan": "estivare",
    "estivavano": "estivare",
    "estivavate": "estivare",
    "estivavi": "estivare",
    "estivavo": "estivare",
    "estive": "estivo",
    "estiverai": "estivare",
    "estiveran": "estivare",
    "estiveranno": "estivare",
    "estiverebbe": "estivare",
    "estiverebber": "estivare",
    "estiverebbero": "estivare",
    "estiverei": "estivare",
    "estiveremmo": "estivare",
    "estiveremo": "estivare",
    "estivereste": "estivare",
    "estiveresti": "estivare",
    "estiverete": "estivare",
    "estiverà": "estivare",
    "estiverò": "estivare",
    "estivi": "estivo",
    "estiviamo": "estivare",
    "estiviate": "estivare",
    "estivin": "estivare",
    "estivino": "estivare",
    "estivo": "estivare",
    "estivò": "estivare",
    "estoni": "estone",
    "estorca": "estorcere",
    "estorcan": "estorcere",
    "estorcano": "estorcere",
    "estorce": "estorcere",
    "estorcemmo": "estorcere",
    "estorcendo": "estorcere",
    "estorcente": "estorcere",
    "estorcenti": "estorcere",
    "estorcer": "estorcere",
    "estorcerai": "estorcere",
    "estorceran": "estorcere",
    "estorceranno": "estorcere",
    "estorcerebbe": "estorcere",
    "estorcerebber": "estorcere",
    "estorcerebbero": "estorcere",
    "estorcerei": "estorcere",
    "estorceremmo": "estorcere",
    "estorceremo": "estorcere",
    "estorcereste": "estorcere",
    "estorceresti": "estorcere",
    "estorcerete": "estorcere",
    "estorcerà": "estorcere",
    "estorcerò": "estorcere",
    "estorcesse": "estorcere",
    "estorcesser": "estorcere",
    "estorcessero": "estorcere",
    "estorcessi": "estorcere",
    "estorcessimo": "estorcere",
    "estorceste": "estorcere",
    "estorcesti": "estorcere",
    "estorcete": "estorcere",
    "estorceva": "estorcere",
    "estorcevamo": "estorcere",
    "estorcevan": "estorcere",
    "estorcevano": "estorcere",
    "estorcevate": "estorcere",
    "estorcevi": "estorcere",
    "estorcevo": "estorcere",
    "estorci": "estorcere",
    "estorciamo": "estorcere",
    "estorciate": "estorcere",
    "estorco": "estorcere",
    "estorcon": "estorcere",
    "estorcono": "estorcere",
    "estorse": "estorcere",
    "estorser": "estorcere",
    "estorsero": "estorcere",
    "estorsi": "estorcere",
    "estorsioni": "estorsione",
    "estorsiva": "estorsivo",
    "estorsive": "estorsivo",
    "estorsivi": "estorsivo",
    "estorsori": "estorsore",
    "estorta": "estorcere",
    "estorte": "estorcere",
    "estorti": "estorcere",
    "estorto": "estorcere",
    "estortori": "estortore",
    "estrada": "estradare",
    "estradai": "estradare",
    "estradammo": "estradare",
    "estradan": "estradare",
    "estradando": "estradare",
    "estradano": "estradare",
    "estradante": "estradare",
    "estradanti": "estradare",
    "estradar": "estradare",
    "estradaron": "estradare",
    "estradarono": "estradare",
    "estradasse": "estradare",
    "estradasser": "estradare",
    "estradassero": "estradare",
    "estradassi": "estradare",
    "estradassimo": "estradare",
    "estradaste": "estradare",
    "estradasti": "estradare",
    "estradata": "estradare",
    "estradate": "estradare",
    "estradati": "estradare",
    "estradato": "estradare",
    "estradava": "estradare",
    "estradavamo": "estradare",
    "estradavan": "estradare",
    "estradavano": "estradare",
    "estradavate": "estradare",
    "estradavi": "estradare",
    "estradavo": "estradare",
    "estraderai": "estradare",
    "estraderan": "estradare",
    "estraderanno": "estradare",
    "estraderebbe": "estradare",
    "estraderebber": "estradare",
    "estraderebbero": "estradare",
    "estraderei": "estradare",
    "estraderemmo": "estradare",
    "estraderemo": "estradare",
    "estradereste": "estradare",
    "estraderesti": "estradare",
    "estraderete": "estradare",
    "estraderà": "estradare",
    "estraderò": "estradare",
    "estradi": "estradare",
    "estradiamo": "estradare",
    "estradiate": "estradare",
    "estradin": "estradare",
    "estradino": "estradare",
    "estradizioni": "estradizione",
    "estrado": "estradare",
    "estradò": "estradare",
    "estrae": "estrarre",
    "estraemmo": "estrarre",
    "estraendo": "estrarre",
    "estraente": "estrarre",
    "estraenti": "estrarre",
    "estraesse": "estrarre",
    "estraesser": "estrarre",
    "estraessero": "estrarre",
    "estraessi": "estrarre",
    "estraessimo": "estrarre",
    "estraeste": "estrarre",
    "estraesti": "estrarre",
    "estraete": "estrarre",
    "estraeva": "estrarre",
    "estraevamo": "estrarre",
    "estraevan": "estrarre",
    "estraevano": "estrarre",
    "estraevate": "estrarre",
    "estraevi": "estrarre",
    "estraevo": "estrarre",
    "estragga": "estrarre",
    "estraggan": "estrarre",
    "estraggano": "estrarre",
    "estraggo": "estrarre",
    "estraggon": "estrarre",
    "estraggono": "estrarre",
    "estrai": "estrarre",
    "estraiamo": "estrarre",
    "estraiate": "estrarre",
    "estranea": "estraneo",
    "estranee": "estraneo",
    "estranei": "estraneo",
    "estrani": "estraniare",
    "estrania": "estraniare",
    "estraniai": "estraniare",
    "estraniammo": "estraniare",
    "estraniamo": "estraniare",
    "estranian": "estraniare",
    "estraniando": "estraniare",
    "estraniano": "estraniare",
    "estraniante": "estraniare",
    "estranianti": "estraniare",
    "estraniar": "estraniare",
    "estraniaron": "estraniare",
    "estraniarono": "estraniare",
    "estraniasse": "estraniare",
    "estraniasser": "estraniare",
    "estraniassero": "estraniare",
    "estraniassi": "estraniare",
    "estraniassimo": "estraniare",
    "estraniaste": "estraniare",
    "estraniasti": "estraniare",
    "estraniata": "estraniare",
    "estraniate": "estraniare",
    "estraniati": "estraniare",
    "estraniato": "estraniare",
    "estraniava": "estraniare",
    "estraniavamo": "estraniare",
    "estraniavan": "estraniare",
    "estraniavano": "estraniare",
    "estraniavate": "estraniare",
    "estraniavi": "estraniare",
    "estraniavo": "estraniare",
    "estranierai": "estraniare",
    "estranieran": "estraniare",
    "estranieranno": "estraniare",
    "estranierebbe": "estraniare",
    "estranierebber": "estraniare",
    "estranierebbero": "estraniare",
    "estranierei": "estraniare",
    "estranieremmo": "estraniare",
    "estranieremo": "estraniare",
    "estraniereste": "estraniare",
    "estranieresti": "estraniare",
    "estranierete": "estraniare",
    "estranierà": "estraniare",
    "estranierò": "estraniare",
    "estranin": "estraniare",
    "estranino": "estraniare",
    "estranio": "estraniare",
    "estraniò": "estraniare",
    "estrapola": "estrapolare",
    "estrapolai": "estrapolare",
    "estrapolammo": "estrapolare",
    "estrapolan": "estrapolare",
    "estrapolando": "estrapolare",
    "estrapolano": "estrapolare",
    "estrapolante": "estrapolare",
    "estrapolanti": "estrapolare",
    "estrapolar": "estrapolare",
    "estrapolaron": "estrapolare",
    "estrapolarono": "estrapolare",
    "estrapolasse": "estrapolare",
    "estrapolasser": "estrapolare",
    "estrapolassero": "estrapolare",
    "estrapolassi": "estrapolare",
    "estrapolassimo": "estrapolare",
    "estrapolaste": "estrapolare",
    "estrapolasti": "estrapolare",
    "estrapolata": "estrapolare",
    "estrapolate": "estrapolare",
    "estrapolati": "estrapolare",
    "estrapolato": "estrapolare",
    "estrapolava": "estrapolare",
    "estrapolavamo": "estrapolare",
    "estrapolavan": "estrapolare",
    "estrapolavano": "estrapolare",
    "estrapolavate": "estrapolare",
    "estrapolavi": "estrapolare",
    "estrapolavo": "estrapolare",
    "estrapolazioni": "estrapolazione",
    "estrapolerai": "estrapolare",
    "estrapoleran": "estrapolare",
    "estrapoleranno": "estrapolare",
    "estrapolerebbe": "estrapolare",
    "estrapolerebber": "estrapolare",
    "estrapolerebbero": "estrapolare",
    "estrapolerei": "estrapolare",
    "estrapoleremmo": "estrapolare",
    "estrapoleremo": "estrapolare",
    "estrapolereste": "estrapolare",
    "estrapoleresti": "estrapolare",
    "estrapolerete": "estrapolare",
    "estrapolerà": "estrapolare",
    "estrapolerò": "estrapolare",
    "estrapoli": "estrapolare",
    "estrapoliamo": "estrapolare",
    "estrapoliate": "estrapolare",
    "estrapolin": "estrapolare",
    "estrapolino": "estrapolare",
    "estrapolo": "estrapolare",
    "estrapolò": "estrapolare",
    "estrarr": "estrarre",
    "estrarrai": "estrarre",
    "estrarran": "estrarre",
    "estrarranno": "estrarre",
    "estrarrebbe": "estrarre",
    "estrarrebber": "estrarre",
    "estrarrebbero": "estrarre",
    "estrarrei": "estrarre",
    "estrarremmo": "estrarre",
    "estrarremo": "estrarre",
    "estrarreste": "estrarre",
    "estrarresti": "estrarre",
    "estrarrete": "estrarre",
    "estrarrà": "estrarre",
    "estrarrò": "estrarre",
    "estrasse": "estrarre",
    "estrasser": "estrarre",
    "estrassero": "estrarre",
    "estrassi": "estrarre",
    "estratta": "estratto",
    "estratte": "estratto",
    "estratti": "estratto",
    "estrattiva": "estrattivo",
    "estrattive": "estrattivo",
    "estrattivi": "estrattivo",
    "estratto": "estrarre",
    "estrazioni": "estrazione",
    "estrema": "estremo",
    "estreme": "estremo",
    "estremi": "estremo",
    "estremismi": "estremismo",
    "estremisti": "estremista",
    "estremistica": "estremistico",
    "estremistiche": "estremistico",
    "estremistici": "estremistico",
    "estremizzazioni": "estremizzazione",
    "estri": "estro",
    "estrinseca": "estrinseco",
    "estrinsecai": "estrinsecare",
    "estrinsecammo": "estrinsecare",
    "estrinsecan": "estrinsecare",
    "estrinsecando": "estrinsecare",
    "estrinsecano": "estrinsecare",
    "estrinsecante": "estrinsecare",
    "estrinsecanti": "estrinsecare",
    "estrinsecar": "estrinsecare",
    "estrinsecaron": "estrinsecare",
    "estrinsecarono": "estrinsecare",
    "estrinsecasse": "estrinsecare",
    "estrinsecasser": "estrinsecare",
    "estrinsecassero": "estrinsecare",
    "estrinsecassi": "estrinsecare",
    "estrinsecassimo": "estrinsecare",
    "estrinsecaste": "estrinsecare",
    "estrinsecasti": "estrinsecare",
    "estrinsecata": "estrinsecare",
    "estrinsecate": "estrinsecare",
    "estrinsecati": "estrinsecare",
    "estrinsecato": "estrinsecare",
    "estrinsecava": "estrinsecare",
    "estrinsecavamo": "estrinsecare",
    "estrinsecavan": "estrinsecare",
    "estrinsecavano": "estrinsecare",
    "estrinsecavate": "estrinsecare",
    "estrinsecavi": "estrinsecare",
    "estrinsecavo": "estrinsecare",
    "estrinsecazioni": "estrinsecazione",
    "estrinseche": "estrinseco",
    "estrinsecherai": "estrinsecare",
    "estrinsecheran": "estrinsecare",
    "estrinsecheranno": "estrinsecare",
    "estrinsecherebbe": "estrinsecare",
    "estrinsecherebber": "estrinsecare",
    "estrinsecherebbero": "estrinsecare",
    "estrinsecherei": "estrinsecare",
    "estrinsecheremmo": "estrinsecare",
    "estrinsecheremo": "estrinsecare",
    "estrinsechereste": "estrinsecare",
    "estrinsecheresti": "estrinsecare",
    "estrinsecherete": "estrinsecare",
    "estrinsecherà": "estrinsecare",
    "estrinsecherò": "estrinsecare",
    "estrinsechi": "estrinsecare",
    "estrinsechiamo": "estrinsecare",
    "estrinsechiate": "estrinsecare",
    "estrinsechin": "estrinsecare",
    "estrinsechino": "estrinsecare",
    "estrinseci": "estrinseco",
    "estrinseco": "estrinsecare",
    "estrinsecò": "estrinsecare",
    "estrogeni": "estrogeno",
    "estrogenica": "estrogenico",
    "estrogeniche": "estrogenico",
    "estrogenici": "estrogenico",
    "estromessa": "estromettere",
    "estromesse": "estromettere",
    "estromessi": "estromettere",
    "estromesso": "estromettere",
    "estrometta": "estromettere",
    "estromettan": "estromettere",
    "estromettano": "estromettere",
    "estromette": "estromettere",
    "estromettemmo": "estromettere",
    "estromettendo": "estromettere",
    "estromettente": "estromettere",
    "estromettenti": "estromettere",
    "estrometter": "estromettere",
    "estrometterai": "estromettere",
    "estrometteran": "estromettere",
    "estrometteranno": "estromettere",
    "estrometterebbe": "estromettere",
    "estrometterebber": "estromettere",
    "estrometterebbero": "estromettere",
    "estrometterei": "estromettere",
    "estrometteremmo": "estromettere",
    "estrometteremo": "estromettere",
    "estromettereste": "estromettere",
    "estrometteresti": "estromettere",
    "estrometterete": "estromettere",
    "estrometterà": "estromettere",
    "estrometterò": "estromettere",
    "estromettesse": "estromettere",
    "estromettesser": "estromettere",
    "estromettessero": "estromettere",
    "estromettessi": "estromettere",
    "estromettessimo": "estromettere",
    "estrometteste": "estromettere",
    "estromettesti": "estromettere",
    "estromettete": "estromettere",
    "estrometteva": "estromettere",
    "estromettevamo": "estromettere",
    "estromettevan": "estromettere",
    "estromettevano": "estromettere",
    "estromettevate": "estromettere",
    "estromettevi": "estromettere",
    "estromettevo": "estromettere",
    "estrometti": "estromettere",
    "estromettiamo": "estromettere",
    "estromettiate": "estromettere",
    "estrometto": "estromettere",
    "estrometton": "estromettere",
    "estromettono": "estromettere",
    "estromise": "estromettere",
    "estromiser": "estromettere",
    "estromisero": "estromettere",
    "estromisi": "estromettere",
    "estromissioni": "estromissione",
    "estrosa": "estroso",
    "estrose": "estroso",
    "estrosi": "estroso",
    "estroversa": "estroverso",
    "estroverse": "estroverso",
    "estroversi": "estroverso",
    "estroverta": "estrovertere",
    "estrovertan": "estrovertere",
    "estrovertano": "estrovertere",
    "estroverte": "estrovertere",
    "estrovertei": "estrovertere",
    "estrovertemmo": "estrovertere",
    "estrovertendo": "estrovertere",
    "estrovertente": "estrovertere",
    "estrovertenti": "estrovertere",
    "estroverter": "estrovertere",
    "estroverterai": "estrovertere",
    "estroverteran": "estrovertere",
    "estroverteranno": "estrovertere",
    "estroverterebbe": "estrovertere",
    "estroverterebber": "estrovertere",
    "estroverterebbero": "estrovertere",
    "estroverterei": "estrovertere",
    "estroverteremmo": "estrovertere",
    "estroverteremo": "estrovertere",
    "estrovertereste": "estrovertere",
    "estroverteresti": "estrovertere",
    "estroverterete": "estrovertere",
    "estroverteron": "estrovertere",
    "estroverterono": "estrovertere",
    "estroverterà": "estrovertere",
    "estroverterò": "estrovertere",
    "estrovertesse": "estrovertere",
    "estrovertesser": "estrovertere",
    "estrovertessero": "estrovertere",
    "estrovertessi": "estrovertere",
    "estrovertessimo": "estrovertere",
    "estroverteste": "estrovertere",
    "estrovertesti": "estrovertere",
    "estrovertete": "estrovertere",
    "estroverteva": "estrovertere",
    "estrovertevamo": "estrovertere",
    "estrovertevan": "estrovertere",
    "estrovertevano": "estrovertere",
    "estrovertevate": "estrovertere",
    "estrovertevi": "estrovertere",
    "estrovertevo": "estrovertere",
    "estroverti": "estrovertere",
    "estrovertiamo": "estrovertere",
    "estrovertiate": "estrovertere",
    "estroverto": "estrovertere",
    "estroverton": "estrovertere",
    "estrovertono": "estrovertere",
    "estrovertuta": "estrovertere",
    "estrovertute": "estrovertere",
    "estrovertuti": "estrovertere",
    "estrovertuto": "estrovertere",
    "estrovertè": "estrovertere",
    "estruda": "estrudere",
    "estrudan": "estrudere",
    "estrudano": "estrudere",
    "estrude": "estrudere",
    "estrudei": "estrudere",
    "estrudemmo": "estrudere",
    "estrudendo": "estrudere",
    "estrudente": "estrudere",
    "estrudenti": "estrudere",
    "estruder": "estrudere",
    "estruderai": "estrudere",
    "estruderan": "estrudere",
    "estruderanno": "estrudere",
    "estruderebbe": "estrudere",
    "estruderebber": "estrudere",
    "estruderebbero": "estrudere",
    "estruderei": "estrudere",
    "estruderemmo": "estrudere",
    "estruderemo": "estrudere",
    "estrudereste": "estrudere",
    "estruderesti": "estrudere",
    "estruderete": "estrudere",
    "estruderon": "estrudere",
    "estruderono": "estrudere",
    "estruderà": "estrudere",
    "estruderò": "estrudere",
    "estrudesse": "estrudere",
    "estrudesser": "estrudere",
    "estrudessero": "estrudere",
    "estrudessi": "estrudere",
    "estrudessimo": "estrudere",
    "estrudeste": "estrudere",
    "estrudesti": "estrudere",
    "estrudete": "estrudere",
    "estrudeva": "estrudere",
    "estrudevamo": "estrudere",
    "estrudevan": "estrudere",
    "estrudevano": "estrudere",
    "estrudevate": "estrudere",
    "estrudevi": "estrudere",
    "estrudevo": "estrudere",
    "estrudi": "estrudere",
    "estrudiamo": "estrudere",
    "estrudiate": "estrudere",
    "estrudo": "estrudere",
    "estrudon": "estrudere",
    "estrudono": "estrudere",
    "estruduta": "estrudere",
    "estrudute": "estrudere",
    "estruduti": "estrudere",
    "estruduto": "estrudere",
    "estrudè": "estrudere",
    "estuari": "estuario",
    "esuberanti": "esuberante",
    "esuberanze": "esuberanza",
    "esuberi": "esubero",
    "esula": "esulare",
    "esulai": "esulare",
    "esulammo": "esulare",
    "esulan": "esulare",
    "esulando": "esulare",
    "esulano": "esulare",
    "esulante": "esulare",
    "esulanti": "esulare",
    "esular": "esulare",
    "esularon": "esulare",
    "esularono": "esulare",
    "esulasse": "esulare",
    "esulasser": "esulare",
    "esulassero": "esulare",
    "esulassi": "esulare",
    "esulassimo": "esulare",
    "esulaste": "esulare",
    "esulasti": "esulare",
    "esulata": "esulare",
    "esulate": "esulare",
    "esulati": "esulare",
    "esulato": "esulare",
    "esulava": "esulare",
    "esulavamo": "esulare",
    "esulavan": "esulare",
    "esulavano": "esulare",
    "esulavate": "esulare",
    "esulavi": "esulare",
    "esulavo": "esulare",
    "esulcera": "esulcerare",
    "esulcerai": "esulcerare",
    "esulcerammo": "esulcerare",
    "esulceran": "esulcerare",
    "esulcerando": "esulcerare",
    "esulcerano": "esulcerare",
    "esulcerante": "esulcerare",
    "esulceranti": "esulcerare",
    "esulcerar": "esulcerare",
    "esulceraron": "esulcerare",
    "esulcerarono": "esulcerare",
    "esulcerasse": "esulcerare",
    "esulcerasser": "esulcerare",
    "esulcerassero": "esulcerare",
    "esulcerassi": "esulcerare",
    "esulcerassimo": "esulcerare",
    "esulceraste": "esulcerare",
    "esulcerasti": "esulcerare",
    "esulcerata": "esulcerare",
    "esulcerate": "esulcerare",
    "esulcerati": "esulcerare",
    "esulcerato": "esulcerare",
    "esulcerava": "esulcerare",
    "esulceravamo": "esulcerare",
    "esulceravan": "esulcerare",
    "esulceravano": "esulcerare",
    "esulceravate": "esulcerare",
    "esulceravi": "esulcerare",
    "esulceravo": "esulcerare",
    "esulcererai": "esulcerare",
    "esulcereran": "esulcerare",
    "esulcereranno": "esulcerare",
    "esulcererebbe": "esulcerare",
    "esulcererebber": "esulcerare",
    "esulcererebbero": "esulcerare",
    "esulcererei": "esulcerare",
    "esulcereremmo": "esulcerare",
    "esulcereremo": "esulcerare",
    "esulcerereste": "esulcerare",
    "esulcereresti": "esulcerare",
    "esulcererete": "esulcerare",
    "esulcererà": "esulcerare",
    "esulcererò": "esulcerare",
    "esulceri": "esulcerare",
    "esulceriamo": "esulcerare",
    "esulceriate": "esulcerare",
    "esulcerin": "esulcerare",
    "esulcerino": "esulcerare",
    "esulcero": "esulcerare",
    "esulcerò": "esulcerare",
    "esulerai": "esulare",
    "esuleran": "esulare",
    "esuleranno": "esulare",
    "esulerebbe": "esulare",
    "esulerebber": "esulare",
    "esulerebbero": "esulare",
    "esulerei": "esulare",
    "esuleremmo": "esulare",
    "esuleremo": "esulare",
    "esulereste": "esulare",
    "esuleresti": "esulare",
    "esulerete": "esulare",
    "esulerà": "esulare",
    "esulerò": "esulare",
    "esuli": "esule",
    "esuliamo": "esulare",
    "esuliate": "esulare",
    "esulin": "esulare",
    "esulino": "esulare",
    "esulo": "esulare",
    "esulta": "esultare",
    "esultai": "esultare",
    "esultammo": "esultare",
    "esultan": "esultare",
    "esultando": "esultare",
    "esultano": "esultare",
    "esultante": "esultare",
    "esultanti": "esultare",
    "esultanze": "esultanza",
    "esultar": "esultare",
    "esultaron": "esultare",
    "esultarono": "esultare",
    "esultasse": "esultare",
    "esultasser": "esultare",
    "esultassero": "esultare",
    "esultassi": "esultare",
    "esultassimo": "esultare",
    "esultaste": "esultare",
    "esultasti": "esultare",
    "esultata": "esultare",
    "esultate": "esultare",
    "esultati": "esultare",
    "esultato": "esultare",
    "esultava": "esultare",
    "esultavamo": "esultare",
    "esultavan": "esultare",
    "esultavano": "esultare",
    "esultavate": "esultare",
    "esultavi": "esultare",
    "esultavo": "esultare",
    "esulterai": "esultare",
    "esulteran": "esultare",
    "esulteranno": "esultare",
    "esulterebbe": "esultare",
    "esulterebber": "esultare",
    "esulterebbero": "esultare",
    "esulterei": "esultare",
    "esulteremmo": "esultare",
    "esulteremo": "esultare",
    "esultereste": "esultare",
    "esulteresti": "esultare",
    "esulterete": "esultare",
    "esulterà": "esultare",
    "esulterò": "esultare",
    "esulti": "esultare",
    "esultiamo": "esultare",
    "esultiate": "esultare",
    "esultin": "esultare",
    "esultino": "esultare",
    "esulto": "esultare",
    "esultò": "esultare",
    "esulò": "esulare",
    "esuma": "esumare",
    "esumai": "esumare",
    "esumammo": "esumare",
    "esuman": "esumare",
    "esumando": "esumare",
    "esumano": "esumare",
    "esumante": "esumare",
    "esumanti": "esumare",
    "esumar": "esumare",
    "esumaron": "esumare",
    "esumarono": "esumare",
    "esumasse": "esumare",
    "esumasser": "esumare",
    "esumassero": "esumare",
    "esumassi": "esumare",
    "esumassimo": "esumare",
    "esumaste": "esumare",
    "esumasti": "esumare",
    "esumata": "esumare",
    "esumate": "esumare",
    "esumati": "esumare",
    "esumato": "esumare",
    "esumava": "esumare",
    "esumavamo": "esumare",
    "esumavan": "esumare",
    "esumavano": "esumare",
    "esumavate": "esumare",
    "esumavi": "esumare",
    "esumavo": "esumare",
    "esumerai": "esumare",
    "esumeran": "esumare",
    "esumeranno": "esumare",
    "esumerebbe": "esumare",
    "esumerebber": "esumare",
    "esumerebbero": "esumare",
    "esumerei": "esumare",
    "esumeremmo": "esumare",
    "esumeremo": "esumare",
    "esumereste": "esumare",
    "esumeresti": "esumare",
    "esumerete": "esumare",
    "esumerà": "esumare",
    "esumerò": "esumare",
    "esumi": "esumare",
    "esumiamo": "esumare",
    "esumiate": "esumare",
    "esumin": "esumare",
    "esumino": "esumare",
    "esumo": "esumare",
    "esumò": "esumare",
    "eterea": "etereo",
    "eteree": "etereo",
    "eterei": "etereo",
    "eterna": "eterno",
    "eternai": "eternare",
    "eternammo": "eternare",
    "eternan": "eternare",
    "eternando": "eternare",
    "eternano": "eternare",
    "eternante": "eternare",
    "eternanti": "eternare",
    "eternar": "eternare",
    "eternaron": "eternare",
    "eternarono": "eternare",
    "eternasse": "eternare",
    "eternasser": "eternare",
    "eternassero": "eternare",
    "eternassi": "eternare",
    "eternassimo": "eternare",
    "eternaste": "eternare",
    "eternasti": "eternare",
    "eternata": "eternare",
    "eternate": "eternare",
    "eternati": "eternare",
    "eternato": "eternare",
    "eternava": "eternare",
    "eternavamo": "eternare",
    "eternavan": "eternare",
    "eternavano": "eternare",
    "eternavate": "eternare",
    "eternavi": "eternare",
    "eternavo": "eternare",
    "eterne": "eterno",
    "eternerai": "eternare",
    "eterneran": "eternare",
    "eterneranno": "eternare",
    "eternerebbe": "eternare",
    "eternerebber": "eternare",
    "eternerebbero": "eternare",
    "eternerei": "eternare",
    "eterneremmo": "eternare",
    "eterneremo": "eternare",
    "eternereste": "eternare",
    "eterneresti": "eternare",
    "eternerete": "eternare",
    "eternerà": "eternare",
    "eternerò": "eternare",
    "eterni": "eterno",
    "eterniamo": "eternare",
    "eterniate": "eternare",
    "eternin": "eternare",
    "eternino": "eternare",
    "eterno": "eternare",
    "eternò": "eternare",
    "eteroclita": "eteroclito",
    "eteroclite": "eteroclito",
    "eterocliti": "eteroclito",
    "eterodossa": "eterodosso",
    "eterodosse": "eterodosso",
    "eterodossi": "eterodosso",
    "eterogenea": "eterogeneo",
    "eterogenee": "eterogeneo",
    "eterogenei": "eterogeneo",
    "eterologica": "eterologico",
    "eterologiche": "eterologico",
    "eterologici": "eterologico",
    "eteronimi": "eteronimo",
    "eterosessuali": "eterosessuale",
    "etica": "etico",
    "etiche": "etico",
    "etichetta": "etichettare",
    "etichettabili": "etichettabile",
    "etichettai": "etichettare",
    "etichettammo": "etichettare",
    "etichettan": "etichettare",
    "etichettando": "etichettare",
    "etichettano": "etichettare",
    "etichettante": "etichettare",
    "etichettanti": "etichettare",
    "etichettar": "etichettare",
    "etichettaron": "etichettare",
    "etichettarono": "etichettare",
    "etichettasse": "etichettare",
    "etichettasser": "etichettare",
    "etichettassero": "etichettare",
    "etichettassi": "etichettare",
    "etichettassimo": "etichettare",
    "etichettaste": "etichettare",
    "etichettasti": "etichettare",
    "etichettata": "etichettare",
    "etichettate": "etichettare",
    "etichettati": "etichettare",
    "etichettato": "etichettare",
    "etichettature": "etichettatura",
    "etichettava": "etichettare",
    "etichettavamo": "etichettare",
    "etichettavan": "etichettare",
    "etichettavano": "etichettare",
    "etichettavate": "etichettare",
    "etichettavi": "etichettare",
    "etichettavo": "etichettare",
    "etichette": "etichetta",
    "etichetterai": "etichettare",
    "etichetteran": "etichettare",
    "etichetteranno": "etichettare",
    "etichetterebbe": "etichettare",
    "etichetterebber": "etichettare",
    "etichetterebbero": "etichettare",
    "etichetterei": "etichettare",
    "etichetteremmo": "etichettare",
    "etichetteremo": "etichettare",
    "etichettereste": "etichettare",
    "etichetteresti": "etichettare",
    "etichetterete": "etichettare",
    "etichetterà": "etichettare",
    "etichetterò": "etichettare",
    "etichetti": "etichettare",
    "etichettiamo": "etichettare",
    "etichettiate": "etichettare",
    "etichettin": "etichettare",
    "etichettino": "etichettare",
    "etichetto": "etichettare",
    "etichettò": "etichettare",
    "etici": "etico",
    "etilica": "etilico",
    "etiliche": "etilico",
    "etilici": "etilico",
    "etimologica": "etimologico",
    "etimologiche": "etimologico",
    "etimologici": "etimologico",
    "etimologie": "etimologia",
    "etiopi": "etiope",
    "etiopica": "etiopico",
    "etiopiche": "etiopico",
    "etiopici": "etiopico",
    "etnica": "etnico",
    "etniche": "etnico",
    "etnici": "etnico",
    "etnie": "etnia",
    "etnografica": "etnografico",
    "etnografiche": "etnografico",
    "etnografici": "etnografico",
    "etnologi": "etnologo",
    "etnologica": "etnologico",
    "etnologiche": "etnologico",
    "etnologici": "etnologico",
    "etnìe": "etnìa",
    "etologi": "etologo",
    "etrusca": "etrusco",
    "etrusche": "etrusco",
    "etruschi": "etrusco",
    "ettari": "ettaro",
    "etti": "etto",
    "eucaristica": "eucaristico",
    "eucaristiche": "eucaristico",
    "eucaristici": "eucaristico",
    "eufemismi": "eufemismo",
    "eufemistica": "eufemistico",
    "eufemistiche": "eufemistico",
    "eufemistici": "eufemistico",
    "euforica": "euforico",
    "euforiche": "euforico",
    "euforici": "euforico",
    "euforie": "euforia",
    "eunuchi": "eunuco",
    "eura": "euro",
    "eure": "euro",
    "euri": "euro",
    "euro-fobica": "euro-fobico",
    "euro-fobiche": "euro-fobico",
    "euro-fobici": "euro-fobico",
    "eurobbligazioni": "eurobbligazione",
    "eurocentrica": "eurocentrico",
    "eurocentriche": "eurocentrico",
    "eurocentrici": "eurocentrico",
    "eurocrati": "eurocrato",
    "eurocratica": "eurocratico",
    "eurocratiche": "eurocratico",
    "eurocratici": "eurocratico",
    "eurodeputati": "eurodeputato",
    "eurofoba": "eurofobo",
    "eurofobe": "eurofobo",
    "eurofobi": "eurofobo",
    "eurofobica": "eurofobico",
    "eurofobiche": "eurofobico",
    "eurofobici": "eurofobico",
    "europarlamentari": "europarlamentare",
    "europea": "europeo",
    "europee": "europeo",
    "europei": "europeo",
    "europeismi": "europeismo",
    "europeiste": "europeista",
    "europeisti": "europeista",
    "europeistica": "europeistico",
    "europeistiche": "europeistico",
    "europeistici": "europeistico",
    "europeizza": "europeizzare",
    "europeizzai": "europeizzare",
    "europeizzammo": "europeizzare",
    "europeizzan": "europeizzare",
    "europeizzando": "europeizzare",
    "europeizzano": "europeizzare",
    "europeizzante": "europeizzare",
    "europeizzanti": "europeizzare",
    "europeizzar": "europeizzare",
    "europeizzaron": "europeizzare",
    "europeizzarono": "europeizzare",
    "europeizzasse": "europeizzare",
    "europeizzasser": "europeizzare",
    "europeizzassero": "europeizzare",
    "europeizzassi": "europeizzare",
    "europeizzassimo": "europeizzare",
    "europeizzaste": "europeizzare",
    "europeizzasti": "europeizzare",
    "europeizzata": "europeizzare",
    "europeizzate": "europeizzare",
    "europeizzati": "europeizzare",
    "europeizzato": "europeizzare",
    "europeizzava": "europeizzare",
    "europeizzavamo": "europeizzare",
    "europeizzavan": "europeizzare",
    "europeizzavano": "europeizzare",
    "europeizzavate": "europeizzare",
    "europeizzavi": "europeizzare",
    "europeizzavo": "europeizzare",
    "europeizzerai": "europeizzare",
    "europeizzeran": "europeizzare",
    "europeizzeranno": "europeizzare",
    "europeizzerebbe": "europeizzare",
    "europeizzerebber": "europeizzare",
    "europeizzerebbero": "europeizzare",
    "europeizzerei": "europeizzare",
    "europeizzeremmo": "europeizzare",
    "europeizzeremo": "europeizzare",
    "europeizzereste": "europeizzare",
    "europeizzeresti": "europeizzare",
    "europeizzerete": "europeizzare",
    "europeizzerà": "europeizzare",
    "europeizzerò": "europeizzare",
    "europeizzi": "europeizzare",
    "europeizziamo": "europeizzare",
    "europeizziate": "europeizzare",
    "europeizzin": "europeizzare",
    "europeizzino": "europeizzare",
    "europeizzo": "europeizzare",
    "europeizzò": "europeizzare",
    "europrestiti": "europrestito",
    "euroscettica": "euroscettico",
    "euroscettiche": "euroscettico",
    "euroscettici": "euroscettico",
    "eutanasie": "eutanasia",
    "evacua": "evacuare",
    "evacuai": "evacuare",
    "evacuammo": "evacuare",
    "evacuan": "evacuare",
    "evacuando": "evacuare",
    "evacuano": "evacuare",
    "evacuante": "evacuare",
    "evacuanti": "evacuare",
    "evacuar": "evacuare",
    "evacuaron": "evacuare",
    "evacuarono": "evacuare",
    "evacuasse": "evacuare",
    "evacuasser": "evacuare",
    "evacuassero": "evacuare",
    "evacuassi": "evacuare",
    "evacuassimo": "evacuare",
    "evacuaste": "evacuare",
    "evacuasti": "evacuare",
    "evacuata": "evacuare",
    "evacuate": "evacuare",
    "evacuati": "evacuare",
    "evacuato": "evacuare",
    "evacuava": "evacuare",
    "evacuavamo": "evacuare",
    "evacuavan": "evacuare",
    "evacuavano": "evacuare",
    "evacuavate": "evacuare",
    "evacuavi": "evacuare",
    "evacuavo": "evacuare",
    "evacuazioni": "evacuazione",
    "evacuerai": "evacuare",
    "evacueran": "evacuare",
    "evacueranno": "evacuare",
    "evacuerebbe": "evacuare",
    "evacuerebber": "evacuare",
    "evacuerebbero": "evacuare",
    "evacuerei": "evacuare",
    "evacueremmo": "evacuare",
    "evacueremo": "evacuare",
    "evacuereste": "evacuare",
    "evacueresti": "evacuare",
    "evacuerete": "evacuare",
    "evacuerà": "evacuare",
    "evacuerò": "evacuare",
    "evacui": "evacuare",
    "evacuiamo": "evacuare",
    "evacuiate": "evacuare",
    "evacuin": "evacuare",
    "evacuino": "evacuare",
    "evacuo": "evacuare",
    "evacuò": "evacuare",
    "evada": "evadere",
    "evadan": "evadere",
    "evadano": "evadere",
    "evade": "evadere",
    "evademmo": "evadere",
    "evadendo": "evadere",
    "evadente": "evadere",
    "evadenti": "evadere",
    "evader": "evadere",
    "evaderai": "evadere",
    "evaderan": "evadere",
    "evaderanno": "evadere",
    "evaderebbe": "evadere",
    "evaderebber": "evadere",
    "evaderebbero": "evadere",
    "evaderei": "evadere",
    "evaderemmo": "evadere",
    "evaderemo": "evadere",
    "evadereste": "evadere",
    "evaderesti": "evadere",
    "evaderete": "evadere",
    "evaderà": "evadere",
    "evaderò": "evadere",
    "evadesse": "evadere",
    "evadesser": "evadere",
    "evadessero": "evadere",
    "evadessi": "evadere",
    "evadessimo": "evadere",
    "evadeste": "evadere",
    "evadesti": "evadere",
    "evadete": "evadere",
    "evadeva": "evadere",
    "evadevamo": "evadere",
    "evadevan": "evadere",
    "evadevano": "evadere",
    "evadevate": "evadere",
    "evadevi": "evadere",
    "evadevo": "evadere",
    "evadi": "evadere",
    "evadiamo": "evadere",
    "evadiate": "evadere",
    "evado": "evadere",
    "evadon": "evadere",
    "evadono": "evadere",
    "evanescenti": "evanescente",
    "evangelica": "evangelico",
    "evangeliche": "evangelico",
    "evangelici": "evangelico",
    "evangelisti": "evangelista",
    "evangelizza": "evangelizzare",
    "evangelizzai": "evangelizzare",
    "evangelizzammo": "evangelizzare",
    "evangelizzan": "evangelizzare",
    "evangelizzando": "evangelizzare",
    "evangelizzano": "evangelizzare",
    "evangelizzante": "evangelizzare",
    "evangelizzanti": "evangelizzare",
    "evangelizzar": "evangelizzare",
    "evangelizzaron": "evangelizzare",
    "evangelizzarono": "evangelizzare",
    "evangelizzasse": "evangelizzare",
    "evangelizzasser": "evangelizzare",
    "evangelizzassero": "evangelizzare",
    "evangelizzassi": "evangelizzare",
    "evangelizzassimo": "evangelizzare",
    "evangelizzaste": "evangelizzare",
    "evangelizzasti": "evangelizzare",
    "evangelizzata": "evangelizzare",
    "evangelizzate": "evangelizzare",
    "evangelizzati": "evangelizzare",
    "evangelizzato": "evangelizzare",
    "evangelizzava": "evangelizzare",
    "evangelizzavamo": "evangelizzare",
    "evangelizzavan": "evangelizzare",
    "evangelizzavano": "evangelizzare",
    "evangelizzavate": "evangelizzare",
    "evangelizzavi": "evangelizzare",
    "evangelizzavo": "evangelizzare",
    "evangelizzazioni": "evangelizzazione",
    "evangelizzerai": "evangelizzare",
    "evangelizzeran": "evangelizzare",
    "evangelizzeranno": "evangelizzare",
    "evangelizzerebbe": "evangelizzare",
    "evangelizzerebber": "evangelizzare",
    "evangelizzerebbero": "evangelizzare",
    "evangelizzerei": "evangelizzare",
    "evangelizzeremmo": "evangelizzare",
    "evangelizzeremo": "evangelizzare",
    "evangelizzereste": "evangelizzare",
    "evangelizzeresti": "evangelizzare",
    "evangelizzerete": "evangelizzare",
    "evangelizzerà": "evangelizzare",
    "evangelizzerò": "evangelizzare",
    "evangelizzi": "evangelizzare",
    "evangelizziamo": "evangelizzare",
    "evangelizziate": "evangelizzare",
    "evangelizzin": "evangelizzare",
    "evangelizzino": "evangelizzare",
    "evangelizzo": "evangelizzare",
    "evangelizzò": "evangelizzare",
    "evapora": "evaporare",
    "evaporai": "evaporare",
    "evaporammo": "evaporare",
    "evaporan": "evaporare",
    "evaporando": "evaporare",
    "evaporano": "evaporare",
    "evaporante": "evaporare",
    "evaporanti": "evaporare",
    "evaporar": "evaporare",
    "evaporaron": "evaporare",
    "evaporarono": "evaporare",
    "evaporasse": "evaporare",
    "evaporasser": "evaporare",
    "evaporassero": "evaporare",
    "evaporassi": "evaporare",
    "evaporassimo": "evaporare",
    "evaporaste": "evaporare",
    "evaporasti": "evaporare",
    "evaporata": "evaporare",
    "evaporate": "evaporare",
    "evaporati": "evaporare",
    "evaporato": "evaporare",
    "evaporava": "evaporare",
    "evaporavamo": "evaporare",
    "evaporavan": "evaporare",
    "evaporavano": "evaporare",
    "evaporavate": "evaporare",
    "evaporavi": "evaporare",
    "evaporavo": "evaporare",
    "evaporerai": "evaporare",
    "evaporeran": "evaporare",
    "evaporeranno": "evaporare",
    "evaporerebbe": "evaporare",
    "evaporerebber": "evaporare",
    "evaporerebbero": "evaporare",
    "evaporerei": "evaporare",
    "evaporeremmo": "evaporare",
    "evaporeremo": "evaporare",
    "evaporereste": "evaporare",
    "evaporeresti": "evaporare",
    "evaporerete": "evaporare",
    "evaporerà": "evaporare",
    "evaporerò": "evaporare",
    "evapori": "evaporare",
    "evaporiamo": "evaporare",
    "evaporiate": "evaporare",
    "evaporin": "evaporare",
    "evaporino": "evaporare",
    "evaporo": "evaporare",
    "evaporò": "evaporare",
    "evasa": "evaso",
    "evase": "evaso",
    "evaser": "evadere",
    "evasero": "evadere",
    "evasi": "evaso",
    "evasioni": "evasione",
    "evasiva": "evasivo",
    "evasive": "evasivo",
    "evasivi": "evasivo",
    "evaso": "evadere",
    "evasori": "evasore",
    "evenienze": "evenienza",
    "eventi": "evento",
    "eventuali": "eventuale",
    "eversioni": "eversione",
    "eversiva": "eversivo",
    "eversive": "eversivo",
    "eversivi": "eversivo",
    "eversori": "eversore",
    "evi": "evo",
    "evidenti": "evidente",
    "evidenze": "evidenza",
    "evidenzi": "evidenziare",
    "evidenzia": "evidenziare",
    "evidenziai": "evidenziare",
    "evidenziammo": "evidenziare",
    "evidenziamo": "evidenziare",
    "evidenzian": "evidenziare",
    "evidenziando": "evidenziare",
    "evidenziano": "evidenziare",
    "evidenziante": "evidenziare",
    "evidenzianti": "evidenziare",
    "evidenziar": "evidenziare",
    "evidenziaron": "evidenziare",
    "evidenziarono": "evidenziare",
    "evidenziasse": "evidenziare",
    "evidenziasser": "evidenziare",
    "evidenziassero": "evidenziare",
    "evidenziassi": "evidenziare",
    "evidenziassimo": "evidenziare",
    "evidenziaste": "evidenziare",
    "evidenziasti": "evidenziare",
    "evidenziata": "evidenziare",
    "evidenziate": "evidenziare",
    "evidenziati": "evidenziare",
    "evidenziato": "evidenziare",
    "evidenziava": "evidenziare",
    "evidenziavamo": "evidenziare",
    "evidenziavan": "evidenziare",
    "evidenziavano": "evidenziare",
    "evidenziavate": "evidenziare",
    "evidenziavi": "evidenziare",
    "evidenziavo": "evidenziare",
    "evidenzierai": "evidenziare",
    "evidenzieran": "evidenziare",
    "evidenzieranno": "evidenziare",
    "evidenzierebbe": "evidenziare",
    "evidenzierebber": "evidenziare",
    "evidenzierebbero": "evidenziare",
    "evidenzierei": "evidenziare",
    "evidenzieremmo": "evidenziare",
    "evidenzieremo": "evidenziare",
    "evidenziereste": "evidenziare",
    "evidenzieresti": "evidenziare",
    "evidenzierete": "evidenziare",
    "evidenzierà": "evidenziare",
    "evidenzierò": "evidenziare",
    "evidenzin": "evidenziare",
    "evidenzino": "evidenziare",
    "evidenzio": "evidenziare",
    "evidenziò": "evidenziare",
    "evinca": "evincere",
    "evincan": "evincere",
    "evincano": "evincere",
    "evince": "evincere",
    "evincemmo": "evincere",
    "evincendo": "evincere",
    "evincente": "evincere",
    "evincenti": "evincere",
    "evincer": "evincere",
    "evincerai": "evincere",
    "evinceran": "evincere",
    "evinceranno": "evincere",
    "evincerebbe": "evincere",
    "evincerebber": "evincere",
    "evincerebbero": "evincere",
    "evincerei": "evincere",
    "evinceremmo": "evincere",
    "evinceremo": "evincere",
    "evincereste": "evincere",
    "evinceresti": "evincere",
    "evincerete": "evincere",
    "evincerà": "evincere",
    "evincerò": "evincere",
    "evincesse": "evincere",
    "evincesser": "evincere",
    "evincessero": "evincere",
    "evincessi": "evincere",
    "evincessimo": "evincere",
    "evinceste": "evincere",
    "evincesti": "evincere",
    "evincete": "evincere",
    "evinceva": "evincere",
    "evincevamo": "evincere",
    "evincevan": "evincere",
    "evincevano": "evincere",
    "evincevate": "evincere",
    "evincevi": "evincere",
    "evincevo": "evincere",
    "evinci": "evincere",
    "evinciamo": "evincere",
    "evinciate": "evincere",
    "evinco": "evincere",
    "evincon": "evincere",
    "evincono": "evincere",
    "evinse": "evincere",
    "evinser": "evincere",
    "evinsero": "evincere",
    "evinsi": "evincere",
    "evinta": "evincere",
    "evinte": "evincere",
    "evinti": "evincere",
    "evinto": "evincere",
    "evira": "evirare",
    "evirai": "evirare",
    "evirammo": "evirare",
    "eviran": "evirare",
    "evirando": "evirare",
    "evirano": "evirare",
    "evirante": "evirare",
    "eviranti": "evirare",
    "evirar": "evirare",
    "eviraron": "evirare",
    "evirarono": "evirare",
    "evirasse": "evirare",
    "evirasser": "evirare",
    "evirassero": "evirare",
    "evirassi": "evirare",
    "evirassimo": "evirare",
    "eviraste": "evirare",
    "evirasti": "evirare",
    "evirata": "evirare",
    "evirate": "evirare",
    "evirati": "evirare",
    "evirato": "evirare",
    "evirava": "evirare",
    "eviravamo": "evirare",
    "eviravan": "evirare",
    "eviravano": "evirare",
    "eviravate": "evirare",
    "eviravi": "evirare",
    "eviravo": "evirare",
    "evirerai": "evirare",
    "evireran": "evirare",
    "evireranno": "evirare",
    "evirerebbe": "evirare",
    "evirerebber": "evirare",
    "evirerebbero": "evirare",
    "evirerei": "evirare",
    "evireremmo": "evirare",
    "evireremo": "evirare",
    "evirereste": "evirare",
    "evireresti": "evirare",
    "evirerete": "evirare",
    "evirerà": "evirare",
    "evirerò": "evirare",
    "eviri": "evirare",
    "eviriamo": "evirare",
    "eviriate": "evirare",
    "evirin": "evirare",
    "evirino": "evirare",
    "eviro": "evirare",
    "evirò": "evirare",
    "evita": "evitare",
    "evitabili": "evitabile",
    "evitai": "evitare",
    "evitammo": "evitare",
    "evitan": "evitare",
    "evitando": "evitare",
    "evitano": "evitare",
    "evitante": "evitare",
    "evitanti": "evitare",
    "evitar": "evitare",
    "evitaron": "evitare",
    "evitarono": "evitare",
    "evitasse": "evitare",
    "evitasser": "evitare",
    "evitassero": "evitare",
    "evitassi": "evitare",
    "evitassimo": "evitare",
    "evitaste": "evitare",
    "evitasti": "evitare",
    "evitata": "evitare",
    "evitate": "evitare",
    "evitati": "evitare",
    "evitato": "evitare",
    "evitava": "evitare",
    "evitavamo": "evitare",
    "evitavan": "evitare",
    "evitavano": "evitare",
    "evitavate": "evitare",
    "evitavi": "evitare",
    "evitavo": "evitare",
    "eviterai": "evitare",
    "eviteran": "evitare",
    "eviteranno": "evitare",
    "eviterebbe": "evitare",
    "eviterebber": "evitare",
    "eviterebbero": "evitare",
    "eviterei": "evitare",
    "eviteremmo": "evitare",
    "eviteremo": "evitare",
    "evitereste": "evitare",
    "eviteresti": "evitare",
    "eviterete": "evitare",
    "eviterà": "evitare",
    "eviterò": "evitare",
    "eviti": "evitare",
    "evitiamo": "evitare",
    "evitiate": "evitare",
    "evitin": "evitare",
    "evitino": "evitare",
    "evito": "evitare",
    "evitò": "evitare",
    "evoca": "evocare",
    "evocai": "evocare",
    "evocammo": "evocare",
    "evocan": "evocare",
    "evocando": "evocare",
    "evocano": "evocare",
    "evocante": "evocare",
    "evocanti": "evocare",
    "evocar": "evocare",
    "evocaron": "evocare",
    "evocarono": "evocare",
    "evocasse": "evocare",
    "evocasser": "evocare",
    "evocassero": "evocare",
    "evocassi": "evocare",
    "evocassimo": "evocare",
    "evocaste": "evocare",
    "evocasti": "evocare",
    "evocata": "evocare",
    "evocate": "evocare",
    "evocati": "evocare",
    "evocativa": "evocativo",
    "evocative": "evocativo",
    "evocativi": "evocativo",
    "evocato": "evocare",
    "evocava": "evocare",
    "evocavamo": "evocare",
    "evocavan": "evocare",
    "evocavano": "evocare",
    "evocavate": "evocare",
    "evocavi": "evocare",
    "evocavo": "evocare",
    "evocazioni": "evocazione",
    "evocherai": "evocare",
    "evocheran": "evocare",
    "evocheranno": "evocare",
    "evocherebbe": "evocare",
    "evocherebber": "evocare",
    "evocherebbero": "evocare",
    "evocherei": "evocare",
    "evocheremmo": "evocare",
    "evocheremo": "evocare",
    "evochereste": "evocare",
    "evocheresti": "evocare",
    "evocherete": "evocare",
    "evocherà": "evocare",
    "evocherò": "evocare",
    "evochi": "evocare",
    "evochiamo": "evocare",
    "evochiate": "evocare",
    "evochin": "evocare",
    "evochino": "evocare",
    "evoco": "evocare",
    "evocò": "evocare",
    "evolua": "evoluire",
    "evoluan": "evoluire",
    "evoluano": "evoluire",
    "evolue": "evoluire",
    "evoluendo": "evoluire",
    "evoluente": "evoluire",
    "evoluenti": "evoluire",
    "evolui": "evoluire",
    "evoluiamo": "evoluire",
    "evoluiate": "evoluire",
    "evoluii": "evoluire",
    "evoluimmo": "evoluire",
    "evoluir": "evoluire",
    "evoluirai": "evoluire",
    "evoluiran": "evoluire",
    "evoluiranno": "evoluire",
    "evoluirebbe": "evoluire",
    "evoluirebber": "evoluire",
    "evoluirebbero": "evoluire",
    "evoluirei": "evoluire",
    "evoluiremmo": "evoluire",
    "evoluiremo": "evoluire",
    "evoluireste": "evoluire",
    "evoluiresti": "evoluire",
    "evoluirete": "evoluire",
    "evoluiron": "evoluire",
    "evoluirono": "evoluire",
    "evoluirà": "evoluire",
    "evoluirò": "evoluire",
    "evoluisse": "evoluire",
    "evoluisser": "evoluire",
    "evoluissero": "evoluire",
    "evoluissi": "evoluire",
    "evoluissimo": "evoluire",
    "evoluiste": "evoluire",
    "evoluisti": "evoluire",
    "evoluita": "evoluire",
    "evoluite": "evoluire",
    "evoluiti": "evoluire",
    "evoluito": "evoluire",
    "evoluiva": "evoluire",
    "evoluivamo": "evoluire",
    "evoluivan": "evoluire",
    "evoluivano": "evoluire",
    "evoluivate": "evoluire",
    "evoluivi": "evoluire",
    "evoluivo": "evoluire",
    "evoluo": "evoluire",
    "evoluon": "evoluire",
    "evoluono": "evoluire",
    "evoluta": "evoluto",
    "evolute": "evoluto",
    "evoluti": "evoluto",
    "evolutiva": "evolutivo",
    "evolutive": "evolutivo",
    "evolutivi": "evolutivo",
    "evoluzioni": "evoluzione",
    "evoluì": "evoluire",
    "evolva": "evolvere",
    "evolvan": "evolvere",
    "evolvano": "evolvere",
    "evolve": "evolvere",
    "evolvei": "evolvere",
    "evolvemmo": "evolvere",
    "evolvendo": "evolvere",
    "evolvente": "evolvere",
    "evolventi": "evolvere",
    "evolver": "evolvere",
    "evolverai": "evolvere",
    "evolveran": "evolvere",
    "evolveranno": "evolvere",
    "evolverebbe": "evolvere",
    "evolverebber": "evolvere",
    "evolverebbero": "evolvere",
    "evolverei": "evolvere",
    "evolveremmo": "evolvere",
    "evolveremo": "evolvere",
    "evolvereste": "evolvere",
    "evolveresti": "evolvere",
    "evolverete": "evolvere",
    "evolveron": "evolvere",
    "evolverono": "evolvere",
    "evolverà": "evolvere",
    "evolverò": "evolvere",
    "evolvesse": "evolvere",
    "evolvesser": "evolvere",
    "evolvessero": "evolvere",
    "evolvessi": "evolvere",
    "evolvessimo": "evolvere",
    "evolveste": "evolvere",
    "evolvesti": "evolvere",
    "evolvete": "evolvere",
    "evolveva": "evolvere",
    "evolvevamo": "evolvere",
    "evolvevan": "evolvere",
    "evolvevano": "evolvere",
    "evolvevate": "evolvere",
    "evolvevi": "evolvere",
    "evolvevo": "evolvere",
    "evolvi": "evolvere",
    "evolviamo": "evolvere",
    "evolviate": "evolvere",
    "evolvo": "evolvere",
    "evolvon": "evolvere",
    "evolvono": "evolvere",
    "evolvuta": "evolvere",
    "evolvute": "evolvere",
    "evolvuti": "evolvere",
    "evolvuto": "evolvere",
    "evolvè": "evolvere",
    "ex-alleati": "ex-alleato",
    "ex-collaboratori": "ex-collaboratore",
    "ex-colonie": "ex-colonia",
    "ex-combattenti": "ex-combattente",
    "ex-compagni": "ex-compagno",
    "ex-comuniste": "ex-comunista",
    "ex-comunisti": "ex-comunista",
    "ex-consiglieri": "ex-consigliere",
    "ex-dipendenti": "ex-dipendente",
    "ex-dirigenti": "ex-dirigente",
    "ex-funzionari": "ex-funzionario",
    "ex-ministri": "ex-ministro",
    "ex-presidenti": "ex-presidente",
    "ex-repubbliche": "ex-repubblica",
    "exploits": "exploit",
    "extra-giudiziali": "extra-giudiziale",
    "extra-parlamentari": "extra-parlamentare",
    "extracomunitari": "extracomunitario",
    "extracomunitaria": "extracomunitario",
    "extracomunitarie": "extracomunitario",
    "extraconiugali": "extraconiugale",
    "extracontrattuali": "extracontrattuale",
    "extraeuropea": "extraeuropeo",
    "extraeuropee": "extraeuropeo",
    "extraeuropei": "extraeuropeo",
    "extragiudiziali": "extragiudiziale",
    "extralegali": "extralegale",
    "extramatrimoniali": "extramatrimoniale",
    "extraparlamentari": "extraparlamentare",
    "extrasensoriali": "extrasensoriale",
    "extraterrestri": "extraterrestre",
    "extraterritoriali": "extraterritoriale",
    "extraurbana": "extraurbano",
    "extraurbane": "extraurbano",
    "extraurbani": "extraurbano",
    "extre": "extra",
    "extri": "extra",
    "fa": "fare",
    "fa'": "fare",
    "fabbisogni": "fabbisogno",
    "fabbri": "fabbro",
    "fabbrica": "fabbricare",
    "fabbricabili": "fabbricabile",
    "fabbricai": "fabbricare",
    "fabbricammo": "fabbricare",
    "fabbrican": "fabbricare",
    "fabbricando": "fabbricare",
    "fabbricano": "fabbricare",
    "fabbricante": "fabbricare",
    "fabbricanti": "fabbricare",
    "fabbricar": "fabbricare",
    "fabbricaron": "fabbricare",
    "fabbricarono": "fabbricare",
    "fabbricasse": "fabbricare",
    "fabbricasser": "fabbricare",
    "fabbricassero": "fabbricare",
    "fabbricassi": "fabbricare",
    "fabbricassimo": "fabbricare",
    "fabbricaste": "fabbricare",
    "fabbricasti": "fabbricare",
    "fabbricata": "fabbricato",
    "fabbricate": "fabbricato",
    "fabbricati": "fabbricato",
    "fabbricato": "fabbricare",
    "fabbricatori": "fabbricatore",
    "fabbricava": "fabbricare",
    "fabbricavamo": "fabbricare",
    "fabbricavan": "fabbricare",
    "fabbricavano": "fabbricare",
    "fabbricavate": "fabbricare",
    "fabbricavi": "fabbricare",
    "fabbricavo": "fabbricare",
    "fabbricazioni": "fabbricazione",
    "fabbriche": "fabbrica",
    "fabbricherai": "fabbricare",
    "fabbricheran": "fabbricare",
    "fabbricheranno": "fabbricare",
    "fabbricherebbe": "fabbricare",
    "fabbricherebber": "fabbricare",
    "fabbricherebbero": "fabbricare",
    "fabbricherei": "fabbricare",
    "fabbricheremmo": "fabbricare",
    "fabbricheremo": "fabbricare",
    "fabbrichereste": "fabbricare",
    "fabbricheresti": "fabbricare",
    "fabbricherete": "fabbricare",
    "fabbricherà": "fabbricare",
    "fabbricherò": "fabbricare",
    "fabbrichette": "fabbrichetta",
    "fabbrichi": "fabbricare",
    "fabbrichiamo": "fabbricare",
    "fabbrichiate": "fabbricare",
    "fabbrichin": "fabbricare",
    "fabbrichino": "fabbricare",
    "fabbrico": "fabbricare",
    "fabbriconi": "fabbricone",
    "fabbricò": "fabbricare",
    "fabulazioni": "fabulazione",
    "facce": "faccia",
    "faccende": "faccenda",
    "faccendieri": "faccendiere",
    "faccette": "faccetta",
    "facchini": "facchino",
    "faccia": "fare",
    "facciali": "facciale",
    "facciamo": "fare",
    "faccian": "fare",
    "facciano": "fare",
    "facciate": "fare",
    "faccine": "faccina",
    "faccini": "faccino",
    "faccio": "fare",
    "faccioni": "faccione",
    "facemmo": "fare",
    "facendo": "fare",
    "facente": "fare",
    "facenti": "fare",
    "facesse": "fare",
    "facesser": "fare",
    "facessero": "fare",
    "facessi": "fare",
    "facessimo": "fare",
    "faceste": "fare",
    "facesti": "fare",
    "faceta": "faceto",
    "facete": "faceto",
    "faceti": "faceto",
    "faceva": "fare",
    "facevamo": "fare",
    "facevan": "fare",
    "facevano": "fare",
    "facevate": "fare",
    "facevi": "fare",
    "facevo": "fare",
    "facezie": "facezia",
    "facili": "facile",
    "facilita": "facilitare",
    "facilitai": "facilitare",
    "facilitammo": "facilitare",
    "facilitan": "facilitare",
    "facilitando": "facilitare",
    "facilitano": "facilitare",
    "facilitante": "facilitare",
    "facilitanti": "facilitare",
    "facilitar": "facilitare",
    "facilitaron": "facilitare",
    "facilitarono": "facilitare",
    "facilitasse": "facilitare",
    "facilitasser": "facilitare",
    "facilitassero": "facilitare",
    "facilitassi": "facilitare",
    "facilitassimo": "facilitare",
    "facilitaste": "facilitare",
    "facilitasti": "facilitare",
    "facilitata": "facilitato",
    "facilitate": "facilitato",
    "facilitati": "facilitato",
    "facilitato": "facilitare",
    "facilitava": "facilitare",
    "facilitavamo": "facilitare",
    "facilitavan": "facilitare",
    "facilitavano": "facilitare",
    "facilitavate": "facilitare",
    "facilitavi": "facilitare",
    "facilitavo": "facilitare",
    "facilitazioni": "facilitazione",
    "faciliterai": "facilitare",
    "faciliteran": "facilitare",
    "faciliteranno": "facilitare",
    "faciliterebbe": "facilitare",
    "faciliterebber": "facilitare",
    "faciliterebbero": "facilitare",
    "faciliterei": "facilitare",
    "faciliteremmo": "facilitare",
    "faciliteremo": "facilitare",
    "facilitereste": "facilitare",
    "faciliteresti": "facilitare",
    "faciliterete": "facilitare",
    "faciliterà": "facilitare",
    "faciliterò": "facilitare",
    "faciliti": "facilitare",
    "facilitiamo": "facilitare",
    "facilitiate": "facilitare",
    "facilitin": "facilitare",
    "facilitino": "facilitare",
    "facilito": "facilitare",
    "facilitò": "facilitare",
    "facilonerie": "faciloneria",
    "faciloni": "facilone",
    "facinorosa": "facinoroso",
    "facinorose": "facinoroso",
    "facinorosi": "facinoroso",
    "facitori": "facitore",
    "facoltativa": "facoltativo",
    "facoltative": "facoltativo",
    "facoltativi": "facoltativo",
    "facoltosa": "facoltoso",
    "facoltose": "facoltoso",
    "facoltosi": "facoltoso",
    "faconda": "facondo",
    "faconde": "facondo",
    "facondi": "facondo",
    "faggi": "faggio",
    "fagiani": "fagiano",
    "fagioli": "fagiolo",
    "faglie": "faglia",
    "fagocita": "fagocitare",
    "fagocitai": "fagocitare",
    "fagocitammo": "fagocitare",
    "fagocitan": "fagocitare",
    "fagocitando": "fagocitare",
    "fagocitano": "fagocitare",
    "fagocitante": "fagocitare",
    "fagocitanti": "fagocitare",
    "fagocitar": "fagocitare",
    "fagocitaron": "fagocitare",
    "fagocitarono": "fagocitare",
    "fagocitasse": "fagocitare",
    "fagocitasser": "fagocitare",
    "fagocitassero": "fagocitare",
    "fagocitassi": "fagocitare",
    "fagocitassimo": "fagocitare",
    "fagocitaste": "fagocitare",
    "fagocitasti": "fagocitare",
    "fagocitata": "fagocitare",
    "fagocitate": "fagocitare",
    "fagocitati": "fagocitare",
    "fagocitato": "fagocitare",
    "fagocitava": "fagocitare",
    "fagocitavamo": "fagocitare",
    "fagocitavan": "fagocitare",
    "fagocitavano": "fagocitare",
    "fagocitavate": "fagocitare",
    "fagocitavi": "fagocitare",
    "fagocitavo": "fagocitare",
    "fagociterai": "fagocitare",
    "fagociteran": "fagocitare",
    "fagociteranno": "fagocitare",
    "fagociterebbe": "fagocitare",
    "fagociterebber": "fagocitare",
    "fagociterebbero": "fagocitare",
    "fagociterei": "fagocitare",
    "fagociteremmo": "fagocitare",
    "fagociteremo": "fagocitare",
    "fagocitereste": "fagocitare",
    "fagociteresti": "fagocitare",
    "fagociterete": "fagocitare",
    "fagociterà": "fagocitare",
    "fagociterò": "fagocitare",
    "fagociti": "fagocitare",
    "fagocitiamo": "fagocitare",
    "fagocitiate": "fagocitare",
    "fagocitin": "fagocitare",
    "fagocitino": "fagocitare",
    "fagocito": "fagocitare",
    "fagocitò": "fagocitare",
    "fagotti": "fagotto",
    "fagottini": "fagottino",
    "fai": "fare",
    "faide": "faida",
    "falangisti": "falangista",
    "falansteri": "falansterio",
    "falca": "falcare",
    "falcai": "falcare",
    "falcammo": "falcare",
    "falcan": "falcare",
    "falcando": "falcare",
    "falcano": "falcare",
    "falcante": "falcare",
    "falcanti": "falcare",
    "falcar": "falcare",
    "falcaron": "falcare",
    "falcarono": "falcare",
    "falcasse": "falcare",
    "falcasser": "falcare",
    "falcassero": "falcare",
    "falcassi": "falcare",
    "falcassimo": "falcare",
    "falcaste": "falcare",
    "falcasti": "falcare",
    "falcata": "falcare",
    "falcate": "falcata",
    "falcati": "falcare",
    "falcato": "falcare",
    "falcava": "falcare",
    "falcavamo": "falcare",
    "falcavan": "falcare",
    "falcavano": "falcare",
    "falcavate": "falcare",
    "falcavi": "falcare",
    "falcavo": "falcare",
    "falcerai": "falciare",
    "falceran": "falciare",
    "falceranno": "falciare",
    "falcerebbe": "falciare",
    "falcerebber": "falciare",
    "falcerebbero": "falciare",
    "falcerei": "falciare",
    "falceremmo": "falciare",
    "falceremo": "falciare",
    "falcereste": "falciare",
    "falceresti": "falciare",
    "falcerete": "falciare",
    "falcerà": "falciare",
    "falcerò": "falciare",
    "falcherai": "falcare",
    "falcheran": "falcare",
    "falcheranno": "falcare",
    "falcherebbe": "falcare",
    "falcherebber": "falcare",
    "falcherebbero": "falcare",
    "falcherei": "falcare",
    "falcheremmo": "falcare",
    "falcheremo": "falcare",
    "falchereste": "falcare",
    "falcheresti": "falcare",
    "falcherete": "falcare",
    "falcherà": "falcare",
    "falcherò": "falcare",
    "falchi": "falco",
    "falchiamo": "falcare",
    "falchiate": "falcare",
    "falchin": "falcare",
    "falchino": "falcare",
    "falci": "falciare",
    "falcia": "falciare",
    "falciai": "falciare",
    "falciammo": "falciare",
    "falciamo": "falciare",
    "falcian": "falciare",
    "falciando": "falciare",
    "falciano": "falciare",
    "falciante": "falciare",
    "falcianti": "falciare",
    "falciar": "falciare",
    "falciaron": "falciare",
    "falciarono": "falciare",
    "falciasse": "falciare",
    "falciasser": "falciare",
    "falciassero": "falciare",
    "falciassi": "falciare",
    "falciassimo": "falciare",
    "falciaste": "falciare",
    "falciasti": "falciare",
    "falciata": "falciare",
    "falciate": "falciare",
    "falciati": "falciare",
    "falciato": "falciare",
    "falciava": "falciare",
    "falciavamo": "falciare",
    "falciavan": "falciare",
    "falciavano": "falciare",
    "falciavate": "falciare",
    "falciavi": "falciare",
    "falciavo": "falciare",
    "falcidie": "falcidia",
    "falcin": "falciare",
    "falcino": "falciare",
    "falcio": "falciare",
    "falciò": "falciare",
    "falco": "falcare",
    "falconi": "falcone",
    "falcò": "falcare",
    "faldoni": "faldone",
    "falegnamerie": "falegnameria",
    "falegnami": "falegname",
    "falene": "falena",
    "falesie": "falesia",
    "falla": "fallare",
    "fallacci": "fallaccio",
    "fallaci": "fallace",
    "fallai": "fallare",
    "fallammo": "fallare",
    "fallan": "fallare",
    "fallando": "fallare",
    "fallano": "fallare",
    "fallante": "fallare",
    "fallanti": "fallare",
    "fallar": "fallare",
    "fallaron": "fallare",
    "fallarono": "fallare",
    "fallasse": "fallare",
    "fallasser": "fallare",
    "fallassero": "fallare",
    "fallassi": "fallare",
    "fallassimo": "fallare",
    "fallaste": "fallare",
    "fallasti": "fallare",
    "fallata": "fallare",
    "fallate": "fallare",
    "fallati": "fallare",
    "fallato": "fallare",
    "fallava": "fallare",
    "fallavamo": "fallare",
    "fallavan": "fallare",
    "fallavano": "fallare",
    "fallavate": "fallare",
    "fallavi": "fallare",
    "fallavo": "fallare",
    "falle": "falla",
    "fallendo": "fallire",
    "fallente": "fallire",
    "fallenti": "fallire",
    "fallerai": "fallare",
    "falleran": "fallare",
    "falleranno": "fallare",
    "fallerebbe": "fallare",
    "fallerebber": "fallare",
    "fallerebbero": "fallare",
    "fallerei": "fallare",
    "falleremmo": "fallare",
    "falleremo": "fallare",
    "fallereste": "fallare",
    "falleresti": "fallare",
    "fallerete": "fallare",
    "fallerà": "fallare",
    "fallerò": "fallare",
    "falli": "fallo",
    "falliamo": "fallire",
    "falliate": "fallire",
    "fallii": "fallire",
    "fallimentari": "fallimentario",
    "fallimentaria": "fallimentario",
    "fallimentarie": "fallimentario",
    "fallimenti": "fallimento",
    "fallimmo": "fallire",
    "fallin": "fallare",
    "fallino": "fallare",
    "fallir": "fallire",
    "fallirai": "fallire",
    "falliran": "fallire",
    "falliranno": "fallire",
    "fallirebbe": "fallire",
    "fallirebber": "fallire",
    "fallirebbero": "fallire",
    "fallirei": "fallire",
    "falliremmo": "fallire",
    "falliremo": "fallire",
    "fallireste": "fallire",
    "falliresti": "fallire",
    "fallirete": "fallire",
    "falliron": "fallire",
    "fallirono": "fallire",
    "fallirà": "fallire",
    "fallirò": "fallire",
    "fallisca": "fallire",
    "falliscan": "fallire",
    "falliscano": "fallire",
    "fallisce": "fallire",
    "fallisci": "fallire",
    "fallisco": "fallire",
    "falliscon": "fallire",
    "falliscono": "fallire",
    "fallisse": "fallire",
    "fallisser": "fallire",
    "fallissero": "fallire",
    "fallissi": "fallire",
    "fallissimo": "fallire",
    "falliste": "fallire",
    "fallisti": "fallire",
    "fallita": "fallito",
    "fallite": "fallito",
    "falliti": "fallito",
    "fallito": "fallire",
    "falliva": "fallire",
    "fallivamo": "fallire",
    "fallivan": "fallire",
    "fallivano": "fallire",
    "fallivate": "fallire",
    "fallivi": "fallire",
    "fallivo": "fallire",
    "fallo": "fallare",
    "fallosa": "falloso",
    "fallose": "falloso",
    "fallosi": "falloso",
    "fallì": "fallire",
    "fallò": "fallare",
    "falsa": "falso",
    "falsai": "falsare",
    "falsammo": "falsare",
    "falsan": "falsare",
    "falsando": "falsare",
    "falsano": "falsare",
    "falsante": "falsare",
    "falsanti": "falsare",
    "falsar": "falsare",
    "falsari": "falsario",
    "falsarighe": "falsariga",
    "falsaron": "falsare",
    "falsarono": "falsare",
    "falsasse": "falsare",
    "falsasser": "falsare",
    "falsassero": "falsare",
    "falsassi": "falsare",
    "falsassimo": "falsare",
    "falsaste": "falsare",
    "falsasti": "falsare",
    "falsata": "falsare",
    "falsate": "falsare",
    "falsati": "falsare",
    "falsato": "falsare",
    "falsava": "falsare",
    "falsavamo": "falsare",
    "falsavan": "falsare",
    "falsavano": "falsare",
    "falsavate": "falsare",
    "falsavi": "falsare",
    "falsavo": "falsare",
    "false": "falso",
    "falserai": "falsare",
    "falseran": "falsare",
    "falseranno": "falsare",
    "falserebbe": "falsare",
    "falserebber": "falsare",
    "falserebbero": "falsare",
    "falserei": "falsare",
    "falseremmo": "falsare",
    "falseremo": "falsare",
    "falsereste": "falsare",
    "falseresti": "falsare",
    "falserete": "falsare",
    "falserà": "falsare",
    "falserò": "falsare",
    "falsetti": "falsetto",
    "falsi": "falso",
    "falsiamo": "falsare",
    "falsiate": "falsare",
    "falsifica": "falsificare",
    "falsificabili": "falsificabile",
    "falsificai": "falsificare",
    "falsificammo": "falsificare",
    "falsifican": "falsificare",
    "falsificando": "falsificare",
    "falsificano": "falsificare",
    "falsificante": "falsificare",
    "falsificanti": "falsificare",
    "falsificar": "falsificare",
    "falsificaron": "falsificare",
    "falsificarono": "falsificare",
    "falsificasse": "falsificare",
    "falsificasser": "falsificare",
    "falsificassero": "falsificare",
    "falsificassi": "falsificare",
    "falsificassimo": "falsificare",
    "falsificaste": "falsificare",
    "falsificasti": "falsificare",
    "falsificata": "falsificare",
    "falsificate": "falsificare",
    "falsificati": "falsificare",
    "falsificato": "falsificare",
    "falsificava": "falsificare",
    "falsificavamo": "falsificare",
    "falsificavan": "falsificare",
    "falsificavano": "falsificare",
    "falsificavate": "falsificare",
    "falsificavi": "falsificare",
    "falsificavo": "falsificare",
    "falsificazioni": "falsificazione",
    "falsificherai": "falsificare",
    "falsificheran": "falsificare",
    "falsificheranno": "falsificare",
    "falsificherebbe": "falsificare",
    "falsificherebber": "falsificare",
    "falsificherebbero": "falsificare",
    "falsificherei": "falsificare",
    "falsificheremmo": "falsificare",
    "falsificheremo": "falsificare",
    "falsifichereste": "falsificare",
    "falsificheresti": "falsificare",
    "falsificherete": "falsificare",
    "falsificherà": "falsificare",
    "falsificherò": "falsificare",
    "falsifichi": "falsificare",
    "falsifichiamo": "falsificare",
    "falsifichiate": "falsificare",
    "falsifichin": "falsificare",
    "falsifichino": "falsificare",
    "falsifico": "falsificare",
    "falsificò": "falsificare",
    "falsin": "falsare",
    "falsino": "falsare",
    "falso": "falsare",
    "falsopiani": "falsopiano",
    "falsò": "falsare",
    "fame": "fama",
    "famelica": "famelico",
    "fameliche": "famelico",
    "famelici": "famelico",
    "fami": "fame",
    "famigerata": "famigerato",
    "famigerate": "famigerato",
    "famigerati": "famigerato",
    "famigli": "famiglio",
    "famigliari": "famigliare",
    "famiglie": "famiglia",
    "famigliole": "famigliola",
    "famigliuole": "famigliuola",
    "familiari": "familiare",
    "familiarizza": "familiarizzare",
    "familiarizzai": "familiarizzare",
    "familiarizzammo": "familiarizzare",
    "familiarizzan": "familiarizzare",
    "familiarizzando": "familiarizzare",
    "familiarizzano": "familiarizzare",
    "familiarizzante": "familiarizzare",
    "familiarizzanti": "familiarizzare",
    "familiarizzar": "familiarizzare",
    "familiarizzaron": "familiarizzare",
    "familiarizzarono": "familiarizzare",
    "familiarizzasse": "familiarizzare",
    "familiarizzasser": "familiarizzare",
    "familiarizzassero": "familiarizzare",
    "familiarizzassi": "familiarizzare",
    "familiarizzassimo": "familiarizzare",
    "familiarizzaste": "familiarizzare",
    "familiarizzasti": "familiarizzare",
    "familiarizzata": "familiarizzare",
    "familiarizzate": "familiarizzare",
    "familiarizzati": "familiarizzare",
    "familiarizzato": "familiarizzare",
    "familiarizzava": "familiarizzare",
    "familiarizzavamo": "familiarizzare",
    "familiarizzavan": "familiarizzare",
    "familiarizzavano": "familiarizzare",
    "familiarizzavate": "familiarizzare",
    "familiarizzavi": "familiarizzare",
    "familiarizzavo": "familiarizzare",
    "familiarizzerai": "familiarizzare",
    "familiarizzeran": "familiarizzare",
    "familiarizzeranno": "familiarizzare",
    "familiarizzerebbe": "familiarizzare",
    "familiarizzerebber": "familiarizzare",
    "familiarizzerebbero": "familiarizzare",
    "familiarizzerei": "familiarizzare",
    "familiarizzeremmo": "familiarizzare",
    "familiarizzeremo": "familiarizzare",
    "familiarizzereste": "familiarizzare",
    "familiarizzeresti": "familiarizzare",
    "familiarizzerete": "familiarizzare",
    "familiarizzerà": "familiarizzare",
    "familiarizzerò": "familiarizzare",
    "familiarizzi": "familiarizzare",
    "familiarizziamo": "familiarizzare",
    "familiarizziate": "familiarizzare",
    "familiarizzin": "familiarizzare",
    "familiarizzino": "familiarizzare",
    "familiarizzo": "familiarizzare",
    "familiarizzò": "familiarizzare",
    "famosa": "famoso",
    "famose": "famoso",
    "famosi": "famoso",
    "fan": "fare",
    "fanali": "fanale",
    "fanalini": "fanalino",
    "fanatica": "fanatico",
    "fanatiche": "fanatico",
    "fanatici": "fanatico",
    "fanatismi": "fanatismo",
    "fanatizza": "fanatizzare",
    "fanatizzai": "fanatizzare",
    "fanatizzammo": "fanatizzare",
    "fanatizzan": "fanatizzare",
    "fanatizzando": "fanatizzare",
    "fanatizzano": "fanatizzare",
    "fanatizzante": "fanatizzare",
    "fanatizzanti": "fanatizzare",
    "fanatizzar": "fanatizzare",
    "fanatizzaron": "fanatizzare",
    "fanatizzarono": "fanatizzare",
    "fanatizzasse": "fanatizzare",
    "fanatizzasser": "fanatizzare",
    "fanatizzassero": "fanatizzare",
    "fanatizzassi": "fanatizzare",
    "fanatizzassimo": "fanatizzare",
    "fanatizzaste": "fanatizzare",
    "fanatizzasti": "fanatizzare",
    "fanatizzata": "fanatizzare",
    "fanatizzate": "fanatizzare",
    "fanatizzati": "fanatizzare",
    "fanatizzato": "fanatizzare",
    "fanatizzava": "fanatizzare",
    "fanatizzavamo": "fanatizzare",
    "fanatizzavan": "fanatizzare",
    "fanatizzavano": "fanatizzare",
    "fanatizzavate": "fanatizzare",
    "fanatizzavi": "fanatizzare",
    "fanatizzavo": "fanatizzare",
    "fanatizzerai": "fanatizzare",
    "fanatizzeran": "fanatizzare",
    "fanatizzeranno": "fanatizzare",
    "fanatizzerebbe": "fanatizzare",
    "fanatizzerebber": "fanatizzare",
    "fanatizzerebbero": "fanatizzare",
    "fanatizzerei": "fanatizzare",
    "fanatizzeremmo": "fanatizzare",
    "fanatizzeremo": "fanatizzare",
    "fanatizzereste": "fanatizzare",
    "fanatizzeresti": "fanatizzare",
    "fanatizzerete": "fanatizzare",
    "fanatizzerà": "fanatizzare",
    "fanatizzerò": "fanatizzare",
    "fanatizzi": "fanatizzare",
    "fanatizziamo": "fanatizzare",
    "fanatizziate": "fanatizzare",
    "fanatizzin": "fanatizzare",
    "fanatizzino": "fanatizzare",
    "fanatizzo": "fanatizzare",
    "fanatizzò": "fanatizzare",
    "fanciulla": "fanciullo",
    "fanciulle": "fanciullo",
    "fanciullezze": "fanciullezza",
    "fanciulli": "fanciullo",
    "fandonie": "fandonia",
    "fanfaniana": "fanfaniano",
    "fanfaniane": "fanfaniano",
    "fanfaniani": "fanfaniano",
    "fanfare": "fanfara",
    "fanfaronate": "fanfaronata",
    "fanghi": "fango",
    "fanghiglie": "fanghiglia",
    "fangosa": "fangoso",
    "fangose": "fangoso",
    "fangosi": "fangoso",
    "fanno": "fare",
    "fannulloni": "fannullone",
    "fans": "fan",
    "fantaccini": "fantaccino",
    "fantascientifica": "fantascientifico",
    "fantascientifiche": "fantascientifico",
    "fantascientifici": "fantascientifico",
    "fantascienze": "fantascienza",
    "fantasie": "fantasia",
    "fantasiosa": "fantasioso",
    "fantasiose": "fantasioso",
    "fantasiosi": "fantasioso",
    "fantasiste": "fantasista",
    "fantasisti": "fantasista",
    "fantasmagorica": "fantasmagorico",
    "fantasmagoriche": "fantasmagorico",
    "fantasmagorici": "fantasmagorico",
    "fantasmagorie": "fantasmagoria",
    "fantasmatica": "fantasmatico",
    "fantasmatiche": "fantasmatico",
    "fantasmatici": "fantasmatico",
    "fantasmi": "fantasma",
    "fantastica": "fantastico",
    "fantasticai": "fantasticare",
    "fantasticammo": "fantasticare",
    "fantastican": "fantasticare",
    "fantasticando": "fantasticare",
    "fantasticano": "fantasticare",
    "fantasticante": "fantasticare",
    "fantasticanti": "fantasticare",
    "fantasticar": "fantasticare",
    "fantasticaron": "fantasticare",
    "fantasticarono": "fantasticare",
    "fantasticasse": "fantasticare",
    "fantasticasser": "fantasticare",
    "fantasticassero": "fantasticare",
    "fantasticassi": "fantasticare",
    "fantasticassimo": "fantasticare",
    "fantasticaste": "fantasticare",
    "fantasticasti": "fantasticare",
    "fantasticata": "fantasticare",
    "fantasticate": "fantasticare",
    "fantasticati": "fantasticare",
    "fantasticato": "fantasticare",
    "fantasticava": "fantasticare",
    "fantasticavamo": "fantasticare",
    "fantasticavan": "fantasticare",
    "fantasticavano": "fantasticare",
    "fantasticavate": "fantasticare",
    "fantasticavi": "fantasticare",
    "fantasticavo": "fantasticare",
    "fantastiche": "fantastico",
    "fantasticherai": "fantasticare",
    "fantasticheran": "fantasticare",
    "fantasticheranno": "fantasticare",
    "fantasticherebbe": "fantasticare",
    "fantasticherebber": "fantasticare",
    "fantasticherebbero": "fantasticare",
    "fantasticherei": "fantasticare",
    "fantasticheremmo": "fantasticare",
    "fantasticheremo": "fantasticare",
    "fantastichereste": "fantasticare",
    "fantasticheresti": "fantasticare",
    "fantasticherete": "fantasticare",
    "fantasticherie": "fantasticheria",
    "fantasticherà": "fantasticare",
    "fantasticherò": "fantasticare",
    "fantastichi": "fantasticare",
    "fantastichiamo": "fantasticare",
    "fantastichiate": "fantasticare",
    "fantastichin": "fantasticare",
    "fantastichino": "fantasticare",
    "fantastici": "fantastico",
    "fantastico": "fantasticare",
    "fantasticò": "fantasticare",
    "fanterie": "fanteria",
    "fanti": "fante",
    "fantini": "fantino",
    "fantocci": "fantoccio",
    "fantomatica": "fantomatico",
    "fantomatiche": "fantomatico",
    "fantomatici": "fantomatico",
    "far": "fare",
    "farabutti": "farabutto",
    "farai": "fare",
    "faran": "fare",
    "faranno": "fare",
    "faraoni": "faraone",
    "faraonica": "faraonico",
    "faraoniche": "faraonico",
    "faraonici": "faraonico",
    "farca": "farcire",
    "farcan": "farcire",
    "farcano": "farcire",
    "farce": "farcire",
    "farcendo": "farcire",
    "farcente": "farcire",
    "farcenti": "farcire",
    "farci": "farcire",
    "farciamo": "farcire",
    "farciate": "farcire",
    "farcii": "farcire",
    "farcimmo": "farcire",
    "farcir": "farcire",
    "farcirai": "farcire",
    "farciran": "farcire",
    "farciranno": "farcire",
    "farcirebbe": "farcire",
    "farcirebber": "farcire",
    "farcirebbero": "farcire",
    "farcirei": "farcire",
    "farciremmo": "farcire",
    "farciremo": "farcire",
    "farcireste": "farcire",
    "farciresti": "farcire",
    "farcirete": "farcire",
    "farciron": "farcire",
    "farcirono": "farcire",
    "farcirà": "farcire",
    "farcirò": "farcire",
    "farcisse": "farcire",
    "farcisser": "farcire",
    "farcissero": "farcire",
    "farcissi": "farcire",
    "farcissimo": "farcire",
    "farciste": "farcire",
    "farcisti": "farcire",
    "farcita": "farcire",
    "farcite": "farcire",
    "farciti": "farcire",
    "farcito": "farcire",
    "farciva": "farcire",
    "farcivamo": "farcire",
    "farcivan": "farcire",
    "farcivano": "farcire",
    "farcivate": "farcire",
    "farcivi": "farcire",
    "farcivo": "farcire",
    "farco": "farcire",
    "farcon": "farcire",
    "farcono": "farcire",
    "farcì": "farcire",
    "fardelli": "fardello",
    "farebbe": "fare",
    "farebber": "fare",
    "farebbero": "fare",
    "farei": "fare",
    "faremmo": "fare",
    "faremo": "fare",
    "fareste": "fare",
    "faresti": "fare",
    "farete": "fare",
    "faretti": "faretto",
    "farfalle": "farfalla",
    "farfugli": "farfugliare",
    "farfuglia": "farfugliare",
    "farfugliai": "farfugliare",
    "farfugliammo": "farfugliare",
    "farfugliamo": "farfugliare",
    "farfuglian": "farfugliare",
    "farfugliando": "farfugliare",
    "farfugliano": "farfugliare",
    "farfugliante": "farfugliare",
    "farfuglianti": "farfugliare",
    "farfugliar": "farfugliare",
    "farfugliaron": "farfugliare",
    "farfugliarono": "farfugliare",
    "farfugliasse": "farfugliare",
    "farfugliasser": "farfugliare",
    "farfugliassero": "farfugliare",
    "farfugliassi": "farfugliare",
    "farfugliassimo": "farfugliare",
    "farfugliaste": "farfugliare",
    "farfugliasti": "farfugliare",
    "farfugliata": "farfugliare",
    "farfugliate": "farfugliare",
    "farfugliati": "farfugliare",
    "farfugliato": "farfugliare",
    "farfugliava": "farfugliare",
    "farfugliavamo": "farfugliare",
    "farfugliavan": "farfugliare",
    "farfugliavano": "farfugliare",
    "farfugliavate": "farfugliare",
    "farfugliavi": "farfugliare",
    "farfugliavo": "farfugliare",
    "farfuglierai": "farfugliare",
    "farfuglieran": "farfugliare",
    "farfuglieranno": "farfugliare",
    "farfuglierebbe": "farfugliare",
    "farfuglierebber": "farfugliare",
    "farfuglierebbero": "farfugliare",
    "farfuglierei": "farfugliare",
    "farfuglieremmo": "farfugliare",
    "farfuglieremo": "farfugliare",
    "farfugliereste": "farfugliare",
    "farfuglieresti": "farfugliare",
    "farfuglierete": "farfugliare",
    "farfuglierà": "farfugliare",
    "farfuglierò": "farfugliare",
    "farfuglin": "farfugliare",
    "farfuglino": "farfugliare",
    "farfuglio": "farfugliare",
    "farfugliò": "farfugliare",
    "fari": "faro",
    "farine": "farina",
    "faringea": "faringeo",
    "faringee": "faringeo",
    "faringei": "faringeo",
    "faringiti": "faringite",
    "farisei": "fariseo",
    "farmaceutica": "farmaceutico",
    "farmaceutiche": "farmaceutico",
    "farmaceutici": "farmaceutico",
    "farmaci": "farmaco",
    "farmacie": "farmacia",
    "farmaciste": "farmacista",
    "farmacisti": "farmacista",
    "farmacologi": "farmacologo",
    "farmacologica": "farmacologico",
    "farmacologiche": "farmacologico",
    "farmacologici": "farmacologico",
    "farmacologie": "farmacologia",
    "farmacopee": "farmacopea",
    "farnetica": "farneticare",
    "farneticai": "farneticare",
    "farneticammo": "farneticare",
    "farnetican": "farneticare",
    "farneticando": "farneticare",
    "farneticano": "farneticare",
    "farneticante": "farneticare",
    "farneticanti": "farneticare",
    "farneticar": "farneticare",
    "farneticaron": "farneticare",
    "farneticarono": "farneticare",
    "farneticasse": "farneticare",
    "farneticasser": "farneticare",
    "farneticassero": "farneticare",
    "farneticassi": "farneticare",
    "farneticassimo": "farneticare",
    "farneticaste": "farneticare",
    "farneticasti": "farneticare",
    "farneticata": "farneticare",
    "farneticate": "farneticare",
    "farneticati": "farneticare",
    "farneticato": "farneticare",
    "farneticava": "farneticare",
    "farneticavamo": "farneticare",
    "farneticavan": "farneticare",
    "farneticavano": "farneticare",
    "farneticavate": "farneticare",
    "farneticavi": "farneticare",
    "farneticavo": "farneticare",
    "farneticazioni": "farneticazione",
    "farneticherai": "farneticare",
    "farneticheran": "farneticare",
    "farneticheranno": "farneticare",
    "farneticherebbe": "farneticare",
    "farneticherebber": "farneticare",
    "farneticherebbero": "farneticare",
    "farneticherei": "farneticare",
    "farneticheremmo": "farneticare",
    "farneticheremo": "farneticare",
    "farnetichereste": "farneticare",
    "farneticheresti": "farneticare",
    "farneticherete": "farneticare",
    "farneticherà": "farneticare",
    "farneticherò": "farneticare",
    "farnetichi": "farneticare",
    "farnetichiamo": "farneticare",
    "farnetichiate": "farneticare",
    "farnetichin": "farneticare",
    "farnetichino": "farneticare",
    "farnetico": "farneticare",
    "farneticò": "farneticare",
    "farraginosa": "farraginoso",
    "farraginose": "farraginoso",
    "farraginosi": "farraginoso",
    "farse": "farsa",
    "farà": "fare",
    "farò": "fare",
    "fasce": "fascia",
    "fascerai": "fasciare",
    "fasceran": "fasciare",
    "fasceranno": "fasciare",
    "fascerebbe": "fasciare",
    "fascerebber": "fasciare",
    "fascerebbero": "fasciare",
    "fascerei": "fasciare",
    "fasceremmo": "fasciare",
    "fasceremo": "fasciare",
    "fascereste": "fasciare",
    "fasceresti": "fasciare",
    "fascerete": "fasciare",
    "fascerà": "fasciare",
    "fascerò": "fasciare",
    "fascette": "fascetta",
    "fasci": "fascio",
    "fascia": "fasciare",
    "fasciai": "fasciare",
    "fasciammo": "fasciare",
    "fasciamo": "fasciare",
    "fascian": "fasciare",
    "fasciando": "fasciare",
    "fasciano": "fasciare",
    "fasciante": "fasciare",
    "fascianti": "fasciare",
    "fasciar": "fasciare",
    "fasciaron": "fasciare",
    "fasciarono": "fasciare",
    "fasciasse": "fasciare",
    "fasciasser": "fasciare",
    "fasciassero": "fasciare",
    "fasciassi": "fasciare",
    "fasciassimo": "fasciare",
    "fasciaste": "fasciare",
    "fasciasti": "fasciare",
    "fasciata": "fasciato",
    "fasciate": "fasciato",
    "fasciati": "fasciato",
    "fasciato": "fasciare",
    "fasciature": "fasciatura",
    "fasciava": "fasciare",
    "fasciavamo": "fasciare",
    "fasciavan": "fasciare",
    "fasciavano": "fasciare",
    "fasciavate": "fasciare",
    "fasciavi": "fasciare",
    "fasciavo": "fasciare",
    "fascicoletti": "fascicoletto",
    "fascicoli": "fascicolo",
    "fascie": "fascia",
    "fascin": "fasciare",
    "fascina": "fascinare",
    "fascinai": "fascinare",
    "fascinammo": "fascinare",
    "fascinan": "fascinare",
    "fascinando": "fascinare",
    "fascinano": "fascinare",
    "fascinante": "fascinare",
    "fascinanti": "fascinare",
    "fascinar": "fascinare",
    "fascinaron": "fascinare",
    "fascinarono": "fascinare",
    "fascinasse": "fascinare",
    "fascinasser": "fascinare",
    "fascinassero": "fascinare",
    "fascinassi": "fascinare",
    "fascinassimo": "fascinare",
    "fascinaste": "fascinare",
    "fascinasti": "fascinare",
    "fascinata": "fascinare",
    "fascinate": "fascinare",
    "fascinati": "fascinare",
    "fascinato": "fascinare",
    "fascinava": "fascinare",
    "fascinavamo": "fascinare",
    "fascinavan": "fascinare",
    "fascinavano": "fascinare",
    "fascinavate": "fascinare",
    "fascinavi": "fascinare",
    "fascinavo": "fascinare",
    "fascinazioni": "fascinazione",
    "fascine": "fascina",
    "fascinerai": "fascinare",
    "fascineran": "fascinare",
    "fascineranno": "fascinare",
    "fascinerebbe": "fascinare",
    "fascinerebber": "fascinare",
    "fascinerebbero": "fascinare",
    "fascinerei": "fascinare",
    "fascineremmo": "fascinare",
    "fascineremo": "fascinare",
    "fascinereste": "fascinare",
    "fascineresti": "fascinare",
    "fascinerete": "fascinare",
    "fascinerà": "fascinare",
    "fascinerò": "fascinare",
    "fascini": "fascino",
    "fasciniamo": "fascinare",
    "fasciniate": "fascinare",
    "fascinin": "fascinare",
    "fascinino": "fascinare",
    "fascino": "fascinare",
    "fascinosa": "fascinoso",
    "fascinose": "fascinoso",
    "fascinosi": "fascinoso",
    "fascinò": "fascinare",
    "fascio": "fasciare",
    "fascismi": "fascismo",
    "fasciste": "fascista",
    "fascisti": "fascista",
    "fasciò": "fasciare",
    "fasi": "fase",
    "fasti": "fasto",
    "fastidi": "fastidio",
    "fastidiosa": "fastidioso",
    "fastidiose": "fastidioso",
    "fastidiosi": "fastidioso",
    "fastigi": "fastigio",
    "fastosa": "fastoso",
    "fastose": "fastoso",
    "fastosi": "fastoso",
    "fasulla": "fasullo",
    "fasulle": "fasullo",
    "fasulli": "fasullo",
    "fatali": "fatale",
    "fatalismi": "fatalismo",
    "fataliste": "fatalista",
    "fatalisti": "fatalista",
    "fatalistica": "fatalistico",
    "fatalistiche": "fatalistico",
    "fatalistici": "fatalistico",
    "fatata": "fatato",
    "fatate": "fatato",
    "fatati": "fatato",
    "fate": "fata",
    "fati": "fato",
    "fatica": "faticare",
    "faticacce": "faticaccia",
    "faticai": "faticare",
    "faticammo": "faticare",
    "fatican": "faticare",
    "faticando": "faticare",
    "faticano": "faticare",
    "faticante": "faticare",
    "faticanti": "faticare",
    "faticar": "faticare",
    "faticaron": "faticare",
    "faticarono": "faticare",
    "faticasse": "faticare",
    "faticasser": "faticare",
    "faticassero": "faticare",
    "faticassi": "faticare",
    "faticassimo": "faticare",
    "faticaste": "faticare",
    "faticasti": "faticare",
    "faticata": "faticare",
    "faticate": "faticare",
    "faticati": "faticare",
    "faticato": "faticare",
    "faticatori": "faticatore",
    "faticava": "faticare",
    "faticavamo": "faticare",
    "faticavan": "faticare",
    "faticavano": "faticare",
    "faticavate": "faticare",
    "faticavi": "faticare",
    "faticavo": "faticare",
    "fatiche": "fatica",
    "faticherai": "faticare",
    "faticheran": "faticare",
    "faticheranno": "faticare",
    "faticherebbe": "faticare",
    "faticherebber": "faticare",
    "faticherebbero": "faticare",
    "faticherei": "faticare",
    "faticheremmo": "faticare",
    "faticheremo": "faticare",
    "fatichereste": "faticare",
    "faticheresti": "faticare",
    "faticherete": "faticare",
    "faticherà": "faticare",
    "faticherò": "faticare",
    "fatichi": "faticare",
    "fatichiamo": "faticare",
    "fatichiate": "faticare",
    "fatichin": "faticare",
    "fatichino": "faticare",
    "fatico": "faticare",
    "faticosa": "faticoso",
    "faticose": "faticoso",
    "faticosi": "faticoso",
    "faticò": "faticare",
    "fatidica": "fatidico",
    "fatidiche": "fatidico",
    "fatidici": "fatidico",
    "fatine": "fatina",
    "fatta": "fare",
    "fattacci": "fattaccio",
    "fatte": "fare",
    "fatterelli": "fatterello",
    "fattezze": "fattezza",
    "fatti": "fatto",
    "fattibili": "fattibile",
    "fattiva": "fattivo",
    "fattive": "fattivo",
    "fattivi": "fattivo",
    "fatto": "fare",
    "fattori": "fattore",
    "fattorie": "fattoria",
    "fattorini": "fattorino",
    "fattrici": "fattrice",
    "fattuali": "fattuale",
    "fattucchiere": "fattucchiera",
    "fattura": "fatturare",
    "fatturai": "fatturare",
    "fatturammo": "fatturare",
    "fatturan": "fatturare",
    "fatturando": "fatturare",
    "fatturano": "fatturare",
    "fatturante": "fatturare",
    "fatturanti": "fatturare",
    "fatturar": "fatturare",
    "fatturaron": "fatturare",
    "fatturarono": "fatturare",
    "fatturasse": "fatturare",
    "fatturasser": "fatturare",
    "fatturassero": "fatturare",
    "fatturassi": "fatturare",
    "fatturassimo": "fatturare",
    "fatturaste": "fatturare",
    "fatturasti": "fatturare",
    "fatturata": "fatturato",
    "fatturate": "fatturato",
    "fatturati": "fatturato",
    "fatturato": "fatturare",
    "fatturava": "fatturare",
    "fatturavamo": "fatturare",
    "fatturavan": "fatturare",
    "fatturavano": "fatturare",
    "fatturavate": "fatturare",
    "fatturavi": "fatturare",
    "fatturavo": "fatturare",
    "fatturazioni": "fatturazione",
    "fatture": "fattura",
    "fatturerai": "fatturare",
    "fattureran": "fatturare",
    "fattureranno": "fatturare",
    "fatturerebbe": "fatturare",
    "fatturerebber": "fatturare",
    "fatturerebbero": "fatturare",
    "fatturerei": "fatturare",
    "fattureremmo": "fatturare",
    "fattureremo": "fatturare",
    "fatturereste": "fatturare",
    "fattureresti": "fatturare",
    "fatturerete": "fatturare",
    "fatturerà": "fatturare",
    "fatturerò": "fatturare",
    "fatturi": "fatturare",
    "fatturiamo": "fatturare",
    "fatturiate": "fatturare",
    "fatturin": "fatturare",
    "fatturino": "fatturare",
    "fatturo": "fatturare",
    "fatturò": "fatturare",
    "fatua": "fatuo",
    "fatue": "fatuo",
    "fatui": "fatuo",
    "fauci": "fauce",
    "faulkneriana": "faulkneriano",
    "faulkneriane": "faulkneriano",
    "faulkneriani": "faulkneriano",
    "faune": "fauna",
    "faunesca": "faunesco",
    "faunesche": "faunesco",
    "fauneschi": "faunesco",
    "fauni": "fauno",
    "fausta": "fausto",
    "fauste": "fausto",
    "fausti": "fausto",
    "faustiana": "faustiano",
    "faustiane": "faustiano",
    "faustiani": "faustiano",
    "fautori": "fautore",
    "fave": "fava",
    "favelas": "favela",
    "favella": "favellare",
    "favellai": "favellare",
    "favellammo": "favellare",
    "favellan": "favellare",
    "favellando": "favellare",
    "favellano": "favellare",
    "favellante": "favellare",
    "favellanti": "favellare",
    "favellar": "favellare",
    "favellaron": "favellare",
    "favellarono": "favellare",
    "favellasse": "favellare",
    "favellasser": "favellare",
    "favellassero": "favellare",
    "favellassi": "favellare",
    "favellassimo": "favellare",
    "favellaste": "favellare",
    "favellasti": "favellare",
    "favellata": "favellare",
    "favellate": "favellare",
    "favellati": "favellare",
    "favellato": "favellare",
    "favellava": "favellare",
    "favellavamo": "favellare",
    "favellavan": "favellare",
    "favellavano": "favellare",
    "favellavate": "favellare",
    "favellavi": "favellare",
    "favellavo": "favellare",
    "favellerai": "favellare",
    "favelleran": "favellare",
    "favelleranno": "favellare",
    "favellerebbe": "favellare",
    "favellerebber": "favellare",
    "favellerebbero": "favellare",
    "favellerei": "favellare",
    "favelleremmo": "favellare",
    "favelleremo": "favellare",
    "favellereste": "favellare",
    "favelleresti": "favellare",
    "favellerete": "favellare",
    "favellerà": "favellare",
    "favellerò": "favellare",
    "favelli": "favellare",
    "favelliamo": "favellare",
    "favelliate": "favellare",
    "favellin": "favellare",
    "favellino": "favellare",
    "favello": "favellare",
    "favellò": "favellare",
    "faville": "favilla",
    "favole": "favola",
    "favoleggerai": "favoleggiare",
    "favoleggeran": "favoleggiare",
    "favoleggeranno": "favoleggiare",
    "favoleggerebbe": "favoleggiare",
    "favoleggerebber": "favoleggiare",
    "favoleggerebbero": "favoleggiare",
    "favoleggerei": "favoleggiare",
    "favoleggeremmo": "favoleggiare",
    "favoleggeremo": "favoleggiare",
    "favoleggereste": "favoleggiare",
    "favoleggeresti": "favoleggiare",
    "favoleggerete": "favoleggiare",
    "favoleggerà": "favoleggiare",
    "favoleggerò": "favoleggiare",
    "favoleggi": "favoleggiare",
    "favoleggia": "favoleggiare",
    "favoleggiai": "favoleggiare",
    "favoleggiammo": "favoleggiare",
    "favoleggiamo": "favoleggiare",
    "favoleggian": "favoleggiare",
    "favoleggiando": "favoleggiare",
    "favoleggiano": "favoleggiare",
    "favoleggiante": "favoleggiare",
    "favoleggianti": "favoleggiare",
    "favoleggiar": "favoleggiare",
    "favoleggiaron": "favoleggiare",
    "favoleggiarono": "favoleggiare",
    "favoleggiasse": "favoleggiare",
    "favoleggiasser": "favoleggiare",
    "favoleggiassero": "favoleggiare",
    "favoleggiassi": "favoleggiare",
    "favoleggiassimo": "favoleggiare",
    "favoleggiaste": "favoleggiare",
    "favoleggiasti": "favoleggiare",
    "favoleggiata": "favoleggiare",
    "favoleggiate": "favoleggiare",
    "favoleggiati": "favoleggiare",
    "favoleggiato": "favoleggiare",
    "favoleggiava": "favoleggiare",
    "favoleggiavamo": "favoleggiare",
    "favoleggiavan": "favoleggiare",
    "favoleggiavano": "favoleggiare",
    "favoleggiavate": "favoleggiare",
    "favoleggiavi": "favoleggiare",
    "favoleggiavo": "favoleggiare",
    "favoleggin": "favoleggiare",
    "favoleggino": "favoleggiare",
    "favoleggio": "favoleggiare",
    "favoleggiò": "favoleggiare",
    "favolette": "favoletta",
    "favolistica": "favolistico",
    "favolistiche": "favolistico",
    "favolistici": "favolistico",
    "favolosa": "favoloso",
    "favolose": "favoloso",
    "favolosi": "favoloso",
    "favoreggerai": "favoreggiare",
    "favoreggeran": "favoreggiare",
    "favoreggeranno": "favoreggiare",
    "favoreggerebbe": "favoreggiare",
    "favoreggerebber": "favoreggiare",
    "favoreggerebbero": "favoreggiare",
    "favoreggerei": "favoreggiare",
    "favoreggeremmo": "favoreggiare",
    "favoreggeremo": "favoreggiare",
    "favoreggereste": "favoreggiare",
    "favoreggeresti": "favoreggiare",
    "favoreggerete": "favoreggiare",
    "favoreggerà": "favoreggiare",
    "favoreggerò": "favoreggiare",
    "favoreggi": "favoreggiare",
    "favoreggia": "favoreggiare",
    "favoreggiai": "favoreggiare",
    "favoreggiamenti": "favoreggiamento",
    "favoreggiammo": "favoreggiare",
    "favoreggiamo": "favoreggiare",
    "favoreggian": "favoreggiare",
    "favoreggiando": "favoreggiare",
    "favoreggiano": "favoreggiare",
    "favoreggiante": "favoreggiare",
    "favoreggianti": "favoreggiare",
    "favoreggiar": "favoreggiare",
    "favoreggiaron": "favoreggiare",
    "favoreggiarono": "favoreggiare",
    "favoreggiasse": "favoreggiare",
    "favoreggiasser": "favoreggiare",
    "favoreggiassero": "favoreggiare",
    "favoreggiassi": "favoreggiare",
    "favoreggiassimo": "favoreggiare",
    "favoreggiaste": "favoreggiare",
    "favoreggiasti": "favoreggiare",
    "favoreggiata": "favoreggiare",
    "favoreggiate": "favoreggiare",
    "favoreggiati": "favoreggiare",
    "favoreggiato": "favoreggiare",
    "favoreggiatori": "favoreggiatore",
    "favoreggiava": "favoreggiare",
    "favoreggiavamo": "favoreggiare",
    "favoreggiavan": "favoreggiare",
    "favoreggiavano": "favoreggiare",
    "favoreggiavate": "favoreggiare",
    "favoreggiavi": "favoreggiare",
    "favoreggiavo": "favoreggiare",
    "favoreggin": "favoreggiare",
    "favoreggino": "favoreggiare",
    "favoreggio": "favoreggiare",
    "favoreggiò": "favoreggiare",
    "favorendo": "favorire",
    "favorente": "favorire",
    "favorenti": "favorire",
    "favorevoli": "favorevole",
    "favori": "favore",
    "favoriamo": "favorire",
    "favoriate": "favorire",
    "favorii": "favorire",
    "favorimmo": "favorire",
    "favorir": "favorire",
    "favorirai": "favorire",
    "favoriran": "favorire",
    "favoriranno": "favorire",
    "favorirebbe": "favorire",
    "favorirebber": "favorire",
    "favorirebbero": "favorire",
    "favorirei": "favorire",
    "favoriremmo": "favorire",
    "favoriremo": "favorire",
    "favorireste": "favorire",
    "favoriresti": "favorire",
    "favorirete": "favorire",
    "favoriron": "favorire",
    "favorirono": "favorire",
    "favorirà": "favorire",
    "favorirò": "favorire",
    "favorisca": "favorire",
    "favoriscan": "favorire",
    "favoriscano": "favorire",
    "favorisce": "favorire",
    "favorisci": "favorire",
    "favorisco": "favorire",
    "favoriscon": "favorire",
    "favoriscono": "favorire",
    "favorisse": "favorire",
    "favorisser": "favorire",
    "favorissero": "favorire",
    "favorissi": "favorire",
    "favorissimo": "favorire",
    "favoriste": "favorire",
    "favoristi": "favorire",
    "favorita": "favorito",
    "favorite": "favorito",
    "favoriti": "favorito",
    "favoritismi": "favoritismo",
    "favorito": "favorire",
    "favoriva": "favorire",
    "favorivamo": "favorire",
    "favorivan": "favorire",
    "favorivano": "favorire",
    "favorivate": "favorire",
    "favorivi": "favorire",
    "favorivo": "favorire",
    "favorì": "favorire",
    "fazioni": "fazione",
    "faziosa": "fazioso",
    "faziose": "fazioso",
    "faziosi": "fazioso",
    "fazzoletti": "fazzoletto",
    "fazzolettini": "fazzolettino",
    "fazzolettoni": "fazzolettone",
    "febbrai": "febbraio",
    "febbri": "febbre",
    "febbricitanti": "febbricitante",
    "febbrili": "febbrile",
    "fecali": "fecale",
    "fecce": "feccia",
    "fece": "fare",
    "fecer": "fare",
    "fecero": "fare",
    "feci": "fece",
    "feconda": "fecondo",
    "fecondai": "fecondare",
    "fecondammo": "fecondare",
    "fecondan": "fecondare",
    "fecondando": "fecondare",
    "fecondano": "fecondare",
    "fecondante": "fecondare",
    "fecondanti": "fecondare",
    "fecondar": "fecondare",
    "fecondaron": "fecondare",
    "fecondarono": "fecondare",
    "fecondasse": "fecondare",
    "fecondasser": "fecondare",
    "fecondassero": "fecondare",
    "fecondassi": "fecondare",
    "fecondassimo": "fecondare",
    "fecondaste": "fecondare",
    "fecondasti": "fecondare",
    "fecondata": "fecondare",
    "fecondate": "fecondare",
    "fecondati": "fecondare",
    "fecondato": "fecondare",
    "fecondava": "fecondare",
    "fecondavamo": "fecondare",
    "fecondavan": "fecondare",
    "fecondavano": "fecondare",
    "fecondavate": "fecondare",
    "fecondavi": "fecondare",
    "fecondavo": "fecondare",
    "fecondazioni": "fecondazione",
    "feconde": "fecondo",
    "feconderai": "fecondare",
    "feconderan": "fecondare",
    "feconderanno": "fecondare",
    "feconderebbe": "fecondare",
    "feconderebber": "fecondare",
    "feconderebbero": "fecondare",
    "feconderei": "fecondare",
    "feconderemmo": "fecondare",
    "feconderemo": "fecondare",
    "fecondereste": "fecondare",
    "feconderesti": "fecondare",
    "feconderete": "fecondare",
    "feconderà": "fecondare",
    "feconderò": "fecondare",
    "fecondi": "fecondo",
    "fecondiamo": "fecondare",
    "fecondiate": "fecondare",
    "fecondin": "fecondare",
    "fecondino": "fecondare",
    "fecondo": "fecondare",
    "fecondò": "fecondare",
    "fedeli": "fedele",
    "fedelissimi": "fedelissimo",
    "federali": "federale",
    "federalismi": "federalismo",
    "federalisti": "federalista",
    "federata": "federato",
    "federate": "federato",
    "federati": "federato",
    "federativa": "federativo",
    "federative": "federativo",
    "federativi": "federativo",
    "federatletiche": "federatletica",
    "federazioni": "federazione",
    "fedi": "fede",
    "fedifraga": "fedifrago",
    "fedifraghe": "fedifrago",
    "fedifraghi": "fedifrago",
    "fedine": "fedina",
    "fegati": "fegato",
    "felici": "felice",
    "felicita": "felicitare",
    "felicitai": "felicitare",
    "felicitammo": "felicitare",
    "felicitan": "felicitare",
    "felicitando": "felicitare",
    "felicitano": "felicitare",
    "felicitante": "felicitare",
    "felicitanti": "felicitare",
    "felicitar": "felicitare",
    "felicitaron": "felicitare",
    "felicitarono": "felicitare",
    "felicitasse": "felicitare",
    "felicitasser": "felicitare",
    "felicitassero": "felicitare",
    "felicitassi": "felicitare",
    "felicitassimo": "felicitare",
    "felicitaste": "felicitare",
    "felicitasti": "felicitare",
    "felicitata": "felicitare",
    "felicitate": "felicitare",
    "felicitati": "felicitare",
    "felicitato": "felicitare",
    "felicitava": "felicitare",
    "felicitavamo": "felicitare",
    "felicitavan": "felicitare",
    "felicitavano": "felicitare",
    "felicitavate": "felicitare",
    "felicitavi": "felicitare",
    "felicitavo": "felicitare",
    "feliciterai": "felicitare",
    "feliciteran": "felicitare",
    "feliciteranno": "felicitare",
    "feliciterebbe": "felicitare",
    "feliciterebber": "felicitare",
    "feliciterebbero": "felicitare",
    "feliciterei": "felicitare",
    "feliciteremmo": "felicitare",
    "feliciteremo": "felicitare",
    "felicitereste": "felicitare",
    "feliciteresti": "felicitare",
    "feliciterete": "felicitare",
    "feliciterà": "felicitare",
    "feliciterò": "felicitare",
    "feliciti": "felicitare",
    "felicitiamo": "felicitare",
    "felicitiate": "felicitare",
    "felicitin": "felicitare",
    "felicitino": "felicitare",
    "felicito": "felicitare",
    "felicitò": "felicitare",
    "felina": "felino",
    "feline": "felino",
    "felini": "felino",
    "felloni": "fellone",
    "felpata": "felpato",
    "felpate": "felpato",
    "felpati": "felpato",
    "felpe": "felpa",
    "feltra": "feltrare",
    "feltrai": "feltrare",
    "feltrammo": "feltrare",
    "feltran": "feltrare",
    "feltrando": "feltrare",
    "feltrano": "feltrare",
    "feltrante": "feltrare",
    "feltranti": "feltrare",
    "feltrar": "feltrare",
    "feltraron": "feltrare",
    "feltrarono": "feltrare",
    "feltrasse": "feltrare",
    "feltrasser": "feltrare",
    "feltrassero": "feltrare",
    "feltrassi": "feltrare",
    "feltrassimo": "feltrare",
    "feltraste": "feltrare",
    "feltrasti": "feltrare",
    "feltrata": "feltrare",
    "feltrate": "feltrare",
    "feltrati": "feltrare",
    "feltrato": "feltrare",
    "feltrava": "feltrare",
    "feltravamo": "feltrare",
    "feltravan": "feltrare",
    "feltravano": "feltrare",
    "feltravate": "feltrare",
    "feltravi": "feltrare",
    "feltravo": "feltrare",
    "feltrerai": "feltrare",
    "feltreran": "feltrare",
    "feltreranno": "feltrare",
    "feltrerebbe": "feltrare",
    "feltrerebber": "feltrare",
    "feltrerebbero": "feltrare",
    "feltrerei": "feltrare",
    "feltreremmo": "feltrare",
    "feltreremo": "feltrare",
    "feltrereste": "feltrare",
    "feltreresti": "feltrare",
    "feltrerete": "feltrare",
    "feltrerà": "feltrare",
    "feltrerò": "feltrare",
    "feltri": "feltrare",
    "feltriamo": "feltrare",
    "feltriate": "feltrare",
    "feltrin": "feltrare",
    "feltrino": "feltrare",
    "feltro": "feltrare",
    "feltrò": "feltrare",
    "feluche": "feluca",
    "femmes": "femme",
    "femmine": "femmina",
    "femminea": "femmineo",
    "femminee": "femmineo",
    "femminei": "femmineo",
    "femminielli": "femminiello",
    "femminili": "femminile",
    "femminismi": "femminismo",
    "femministe": "femminista",
    "femministi": "femminista",
    "femminucce": "femminuccia",
    "femorali": "femorale",
    "femori": "femore",
    "fenda": "fendere",
    "fendan": "fendere",
    "fendano": "fendere",
    "fende": "fendere",
    "fendemmo": "fendere",
    "fendendo": "fendere",
    "fendente": "fendere",
    "fendenti": "fendere",
    "fender": "fendere",
    "fenderai": "fendere",
    "fenderan": "fendere",
    "fenderanno": "fendere",
    "fenderebbe": "fendere",
    "fenderebber": "fendere",
    "fenderebbero": "fendere",
    "fenderei": "fendere",
    "fenderemmo": "fendere",
    "fenderemo": "fendere",
    "fendereste": "fendere",
    "fenderesti": "fendere",
    "fenderete": "fendere",
    "fenderà": "fendere",
    "fenderò": "fendere",
    "fendesse": "fendere",
    "fendesser": "fendere",
    "fendessero": "fendere",
    "fendessi": "fendere",
    "fendessimo": "fendere",
    "fendeste": "fendere",
    "fendesti": "fendere",
    "fendete": "fendere",
    "fendeva": "fendere",
    "fendevamo": "fendere",
    "fendevan": "fendere",
    "fendevano": "fendere",
    "fendevate": "fendere",
    "fendevi": "fendere",
    "fendevo": "fendere",
    "fendi": "fendere",
    "fendiamo": "fendere",
    "fendiate": "fendere",
    "fenditure": "fenditura",
    "fendo": "fendere",
    "fendon": "fendere",
    "fendono": "fendere",
    "fenica": "fenico",
    "fenice": "fenicio",
    "feniche": "fenico",
    "fenici": "fenico",
    "fenicia": "fenicio",
    "fenicotteri": "fenicottero",
    "fenoli": "fenolo",
    "fenomenali": "fenomenale",
    "fenomeni": "fenomeno",
    "fenomenica": "fenomenico",
    "fenomeniche": "fenomenico",
    "fenomenici": "fenomenico",
    "fenomenologica": "fenomenologico",
    "fenomenologiche": "fenomenologico",
    "fenomenologici": "fenomenologico",
    "fenomenologie": "fenomenologia",
    "fera": "fero",
    "ferali": "ferale",
    "fere": "fero",
    "ferendo": "ferire",
    "ferente": "ferire",
    "ferenti": "ferire",
    "feretri": "feretro",
    "feri": "fero",
    "feriali": "feriale",
    "feriamo": "ferire",
    "feriate": "ferire",
    "ferie": "feria",
    "ferii": "ferire",
    "ferimenti": "ferimento",
    "ferimmo": "ferire",
    "ferina": "ferino",
    "ferine": "ferino",
    "ferini": "ferino",
    "ferir": "ferire",
    "ferirai": "ferire",
    "feriran": "ferire",
    "feriranno": "ferire",
    "ferirebbe": "ferire",
    "ferirebber": "ferire",
    "ferirebbero": "ferire",
    "ferirei": "ferire",
    "feriremmo": "ferire",
    "feriremo": "ferire",
    "ferireste": "ferire",
    "feriresti": "ferire",
    "ferirete": "ferire",
    "feriron": "ferire",
    "ferirono": "ferire",
    "ferirà": "ferire",
    "ferirò": "ferire",
    "ferisca": "ferire",
    "feriscan": "ferire",
    "feriscano": "ferire",
    "ferisce": "ferire",
    "ferisci": "ferire",
    "ferisco": "ferire",
    "feriscon": "ferire",
    "feriscono": "ferire",
    "ferisse": "ferire",
    "ferisser": "ferire",
    "ferissero": "ferire",
    "ferissi": "ferire",
    "ferissimo": "ferire",
    "feriste": "ferire",
    "feristi": "ferire",
    "ferita": "ferito",
    "ferite": "ferito",
    "feriti": "ferito",
    "ferito": "ferire",
    "feritoie": "feritoia",
    "feritori": "feritore",
    "feriva": "ferire",
    "ferivamo": "ferire",
    "ferivan": "ferire",
    "ferivano": "ferire",
    "ferivate": "ferire",
    "ferivi": "ferire",
    "ferivo": "ferire",
    "ferma": "fermo",
    "fermagli": "fermaglio",
    "fermai": "fermare",
    "fermammo": "fermare",
    "ferman": "fermare",
    "fermando": "fermare",
    "fermano": "fermare",
    "fermante": "fermare",
    "fermanti": "fermare",
    "fermar": "fermare",
    "fermaron": "fermare",
    "fermarono": "fermare",
    "fermasse": "fermare",
    "fermasser": "fermare",
    "fermassero": "fermare",
    "fermassi": "fermare",
    "fermassimo": "fermare",
    "fermaste": "fermare",
    "fermasti": "fermare",
    "fermata": "fermare",
    "fermate": "fermata",
    "fermati": "fermato",
    "fermato": "fermare",
    "fermava": "fermare",
    "fermavamo": "fermare",
    "fermavan": "fermare",
    "fermavano": "fermare",
    "fermavate": "fermare",
    "fermavi": "fermare",
    "fermavo": "fermare",
    "ferme": "fermo",
    "fermenta": "fermentare",
    "fermentai": "fermentare",
    "fermentammo": "fermentare",
    "fermentan": "fermentare",
    "fermentando": "fermentare",
    "fermentano": "fermentare",
    "fermentante": "fermentare",
    "fermentanti": "fermentare",
    "fermentar": "fermentare",
    "fermentaron": "fermentare",
    "fermentarono": "fermentare",
    "fermentasse": "fermentare",
    "fermentasser": "fermentare",
    "fermentassero": "fermentare",
    "fermentassi": "fermentare",
    "fermentassimo": "fermentare",
    "fermentaste": "fermentare",
    "fermentasti": "fermentare",
    "fermentata": "fermentare",
    "fermentate": "fermentare",
    "fermentati": "fermentare",
    "fermentato": "fermentare",
    "fermentava": "fermentare",
    "fermentavamo": "fermentare",
    "fermentavan": "fermentare",
    "fermentavano": "fermentare",
    "fermentavate": "fermentare",
    "fermentavi": "fermentare",
    "fermentavo": "fermentare",
    "fermentazioni": "fermentazione",
    "fermenterai": "fermentare",
    "fermenteran": "fermentare",
    "fermenteranno": "fermentare",
    "fermenterebbe": "fermentare",
    "fermenterebber": "fermentare",
    "fermenterebbero": "fermentare",
    "fermenterei": "fermentare",
    "fermenteremmo": "fermentare",
    "fermenteremo": "fermentare",
    "fermentereste": "fermentare",
    "fermenteresti": "fermentare",
    "fermenterete": "fermentare",
    "fermenterà": "fermentare",
    "fermenterò": "fermentare",
    "fermenti": "fermento",
    "fermentiamo": "fermentare",
    "fermentiate": "fermentare",
    "fermentin": "fermentare",
    "fermentino": "fermentare",
    "fermento": "fermentare",
    "fermentò": "fermentare",
    "fermerai": "fermare",
    "fermeran": "fermare",
    "fermeranno": "fermare",
    "fermerebbe": "fermare",
    "fermerebber": "fermare",
    "fermerebbero": "fermare",
    "fermerei": "fermare",
    "fermeremmo": "fermare",
    "fermeremo": "fermare",
    "fermereste": "fermare",
    "fermeresti": "fermare",
    "fermerete": "fermare",
    "fermerà": "fermare",
    "fermerò": "fermare",
    "fermezze": "fermezza",
    "fermi": "fermo",
    "fermiamo": "fermare",
    "fermiate": "fermare",
    "fermin": "fermare",
    "fermino": "fermare",
    "fermo": "fermare",
    "fermò": "fermare",
    "feroci": "feroce",
    "ferocie": "ferocia",
    "feromoni": "feromone",
    "ferra": "ferrare",
    "ferraglie": "ferraglia",
    "ferragostana": "ferragostano",
    "ferragostane": "ferragostano",
    "ferragostani": "ferragostano",
    "ferragosti": "ferragosto",
    "ferrai": "ferrare",
    "ferraia": "ferraio",
    "ferraie": "ferraio",
    "ferrammo": "ferrare",
    "ferran": "ferrare",
    "ferrando": "ferrare",
    "ferrano": "ferrare",
    "ferrante": "ferrare",
    "ferranti": "ferrare",
    "ferrar": "ferrare",
    "ferraresi": "ferrarese",
    "ferrariste": "ferrarista",
    "ferraristi": "ferrarista",
    "ferraron": "ferrare",
    "ferrarono": "ferrare",
    "ferrasse": "ferrare",
    "ferrasser": "ferrare",
    "ferrassero": "ferrare",
    "ferrassi": "ferrare",
    "ferrassimo": "ferrare",
    "ferraste": "ferrare",
    "ferrasti": "ferrare",
    "ferrata": "ferrato",
    "ferrate": "ferrato",
    "ferrati": "ferrato",
    "ferrato": "ferrare",
    "ferrava": "ferrare",
    "ferravamo": "ferrare",
    "ferravan": "ferrare",
    "ferravano": "ferrare",
    "ferravate": "ferrare",
    "ferravi": "ferrare",
    "ferravo": "ferrare",
    "ferrea": "ferreo",
    "ferree": "ferreo",
    "ferrei": "ferreo",
    "ferrerai": "ferrare",
    "ferreran": "ferrare",
    "ferreranno": "ferrare",
    "ferrerebbe": "ferrare",
    "ferrerebber": "ferrare",
    "ferrerebbero": "ferrare",
    "ferrerei": "ferrare",
    "ferreremmo": "ferrare",
    "ferreremo": "ferrare",
    "ferrereste": "ferrare",
    "ferreresti": "ferrare",
    "ferrerete": "ferrare",
    "ferrerà": "ferrare",
    "ferrerò": "ferrare",
    "ferri": "ferro",
    "ferriamo": "ferrare",
    "ferriate": "ferrare",
    "ferriere": "ferriera",
    "ferrigna": "ferrigno",
    "ferrigne": "ferrigno",
    "ferrigni": "ferrigno",
    "ferrin": "ferrare",
    "ferrino": "ferrare",
    "ferro": "ferrare",
    "ferrosa": "ferroso",
    "ferrose": "ferroso",
    "ferrosi": "ferroso",
    "ferroviari": "ferroviario",
    "ferroviaria": "ferroviario",
    "ferroviarie": "ferroviario",
    "ferrovie": "ferrovia",
    "ferrovieri": "ferroviere",
    "ferrò": "ferrare",
    "fertili": "fertile",
    "fertilizza": "fertilizzare",
    "fertilizzai": "fertilizzare",
    "fertilizzammo": "fertilizzare",
    "fertilizzan": "fertilizzare",
    "fertilizzando": "fertilizzare",
    "fertilizzano": "fertilizzare",
    "fertilizzante": "fertilizzare",
    "fertilizzanti": "fertilizzare",
    "fertilizzar": "fertilizzare",
    "fertilizzaron": "fertilizzare",
    "fertilizzarono": "fertilizzare",
    "fertilizzasse": "fertilizzare",
    "fertilizzasser": "fertilizzare",
    "fertilizzassero": "fertilizzare",
    "fertilizzassi": "fertilizzare",
    "fertilizzassimo": "fertilizzare",
    "fertilizzaste": "fertilizzare",
    "fertilizzasti": "fertilizzare",
    "fertilizzata": "fertilizzare",
    "fertilizzate": "fertilizzare",
    "fertilizzati": "fertilizzare",
    "fertilizzato": "fertilizzare",
    "fertilizzava": "fertilizzare",
    "fertilizzavamo": "fertilizzare",
    "fertilizzavan": "fertilizzare",
    "fertilizzavano": "fertilizzare",
    "fertilizzavate": "fertilizzare",
    "fertilizzavi": "fertilizzare",
    "fertilizzavo": "fertilizzare",
    "fertilizzerai": "fertilizzare",
    "fertilizzeran": "fertilizzare",
    "fertilizzeranno": "fertilizzare",
    "fertilizzerebbe": "fertilizzare",
    "fertilizzerebber": "fertilizzare",
    "fertilizzerebbero": "fertilizzare",
    "fertilizzerei": "fertilizzare",
    "fertilizzeremmo": "fertilizzare",
    "fertilizzeremo": "fertilizzare",
    "fertilizzereste": "fertilizzare",
    "fertilizzeresti": "fertilizzare",
    "fertilizzerete": "fertilizzare",
    "fertilizzerà": "fertilizzare",
    "fertilizzerò": "fertilizzare",
    "fertilizzi": "fertilizzare",
    "fertilizziamo": "fertilizzare",
    "fertilizziate": "fertilizzare",
    "fertilizzin": "fertilizzare",
    "fertilizzino": "fertilizzare",
    "fertilizzo": "fertilizzare",
    "fertilizzò": "fertilizzare",
    "ferva": "fervere",
    "fervan": "fervere",
    "fervano": "fervere",
    "ferve": "fervere",
    "fervei": "fervere",
    "fervemmo": "fervere",
    "fervendo": "fervere",
    "fervente": "fervere",
    "ferventi": "fervere",
    "ferver": "fervere",
    "ferverai": "fervere",
    "ferveran": "fervere",
    "ferveranno": "fervere",
    "ferverebbe": "fervere",
    "ferverebber": "fervere",
    "ferverebbero": "fervere",
    "ferverei": "fervere",
    "ferveremmo": "fervere",
    "ferveremo": "fervere",
    "fervereste": "fervere",
    "ferveresti": "fervere",
    "ferverete": "fervere",
    "ferveron": "fervere",
    "ferverono": "fervere",
    "ferverà": "fervere",
    "ferverò": "fervere",
    "fervesse": "fervere",
    "fervesser": "fervere",
    "fervessero": "fervere",
    "fervessi": "fervere",
    "fervessimo": "fervere",
    "ferveste": "fervere",
    "fervesti": "fervere",
    "fervete": "fervere",
    "ferveva": "fervere",
    "fervevamo": "fervere",
    "fervevan": "fervere",
    "fervevano": "fervere",
    "fervevate": "fervere",
    "fervevi": "fervere",
    "fervevo": "fervere",
    "fervi": "fervere",
    "ferviamo": "fervere",
    "ferviate": "fervere",
    "fervida": "fervido",
    "fervide": "fervido",
    "fervidi": "fervido",
    "fervo": "fervere",
    "fervon": "fervere",
    "fervono": "fervere",
    "fervori": "fervore",
    "fervuta": "fervere",
    "fervute": "fervere",
    "fervuti": "fervere",
    "fervuto": "fervere",
    "fervè": "fervere",
    "ferì": "ferire",
    "fesa": "fendere",
    "fescennina": "fescennino",
    "fescennine": "fescennino",
    "fescennini": "fescennino",
    "fese": "fendere",
    "feser": "fendere",
    "fesero": "fendere",
    "fesi": "fendere",
    "feso": "fendere",
    "fessa": "fesso",
    "fesse": "fesso",
    "fesserie": "fesseria",
    "fessi": "fesso",
    "fessure": "fessura",
    "festaiola": "festaiolo",
    "festaiole": "festaiolo",
    "festaioli": "festaiolo",
    "festanti": "festante",
    "feste": "festa",
    "festeggerai": "festeggiare",
    "festeggeran": "festeggiare",
    "festeggeranno": "festeggiare",
    "festeggerebbe": "festeggiare",
    "festeggerebber": "festeggiare",
    "festeggerebbero": "festeggiare",
    "festeggerei": "festeggiare",
    "festeggeremmo": "festeggiare",
    "festeggeremo": "festeggiare",
    "festeggereste": "festeggiare",
    "festeggeresti": "festeggiare",
    "festeggerete": "festeggiare",
    "festeggerà": "festeggiare",
    "festeggerò": "festeggiare",
    "festeggi": "festeggiare",
    "festeggia": "festeggiare",
    "festeggiai": "festeggiare",
    "festeggiamenti": "festeggiamento",
    "festeggiammo": "festeggiare",
    "festeggiamo": "festeggiare",
    "festeggian": "festeggiare",
    "festeggiando": "festeggiare",
    "festeggiano": "festeggiare",
    "festeggiante": "festeggiare",
    "festeggianti": "festeggiare",
    "festeggiar": "festeggiare",
    "festeggiaron": "festeggiare",
    "festeggiarono": "festeggiare",
    "festeggiasse": "festeggiare",
    "festeggiasser": "festeggiare",
    "festeggiassero": "festeggiare",
    "festeggiassi": "festeggiare",
    "festeggiassimo": "festeggiare",
    "festeggiaste": "festeggiare",
    "festeggiasti": "festeggiare",
    "festeggiata": "festeggiare",
    "festeggiate": "festeggiare",
    "festeggiati": "festeggiare",
    "festeggiato": "festeggiare",
    "festeggiava": "festeggiare",
    "festeggiavamo": "festeggiare",
    "festeggiavan": "festeggiare",
    "festeggiavano": "festeggiare",
    "festeggiavate": "festeggiare",
    "festeggiavi": "festeggiare",
    "festeggiavo": "festeggiare",
    "festeggin": "festeggiare",
    "festeggino": "festeggiare",
    "festeggio": "festeggiare",
    "festeggiò": "festeggiare",
    "festicciole": "festicciola",
    "festini": "festino",
    "festiva": "festivo",
    "festivalieri": "festivaliero",
    "festive": "festivo",
    "festivi": "festivo",
    "festoni": "festone",
    "festosa": "festoso",
    "festose": "festoso",
    "festosi": "festoso",
    "fesè": "fendere",
    "fetali": "fetale",
    "fetenti": "fetente",
    "feti": "feto",
    "feticci": "feticcio",
    "feticismi": "feticismo",
    "feticista": "feticisto",
    "feticiste": "feticisto",
    "feticisti": "feticisto",
    "fetida": "fetido",
    "fetide": "fetido",
    "fetidi": "fetido",
    "fetori": "fetore",
    "fette": "fetta",
    "fettine": "fettina",
    "fettucce": "fettuccia",
    "feudalesimi": "feudalesimo",
    "feudali": "feudale",
    "feudatari": "feudatario",
    "feudi": "feudo",
    "fiabe": "fiaba",
    "fiabesca": "fiabesco",
    "fiabesche": "fiabesco",
    "fiabeschi": "fiabesco",
    "fiacca": "fiacco",
    "fiaccai": "fiaccare",
    "fiaccammo": "fiaccare",
    "fiaccan": "fiaccare",
    "fiaccando": "fiaccare",
    "fiaccano": "fiaccare",
    "fiaccante": "fiaccare",
    "fiaccanti": "fiaccare",
    "fiaccar": "fiaccare",
    "fiaccaron": "fiaccare",
    "fiaccarono": "fiaccare",
    "fiaccasse": "fiaccare",
    "fiaccasser": "fiaccare",
    "fiaccassero": "fiaccare",
    "fiaccassi": "fiaccare",
    "fiaccassimo": "fiaccare",
    "fiaccaste": "fiaccare",
    "fiaccasti": "fiaccare",
    "fiaccata": "fiaccare",
    "fiaccate": "fiaccare",
    "fiaccati": "fiaccare",
    "fiaccato": "fiaccare",
    "fiaccava": "fiaccare",
    "fiaccavamo": "fiaccare",
    "fiaccavan": "fiaccare",
    "fiaccavano": "fiaccare",
    "fiaccavate": "fiaccare",
    "fiaccavi": "fiaccare",
    "fiaccavo": "fiaccare",
    "fiacche": "fiacco",
    "fiaccherai": "fiaccare",
    "fiaccheran": "fiaccare",
    "fiaccheranno": "fiaccare",
    "fiaccherebbe": "fiaccare",
    "fiaccherebber": "fiaccare",
    "fiaccherebbero": "fiaccare",
    "fiaccherei": "fiaccare",
    "fiaccheremmo": "fiaccare",
    "fiaccheremo": "fiaccare",
    "fiacchereste": "fiaccare",
    "fiaccheresti": "fiaccare",
    "fiaccherete": "fiaccare",
    "fiaccherà": "fiaccare",
    "fiaccherò": "fiaccare",
    "fiacchi": "fiacco",
    "fiacchiamo": "fiaccare",
    "fiacchiate": "fiaccare",
    "fiacchin": "fiaccare",
    "fiacchino": "fiaccare",
    "fiacco": "fiaccare",
    "fiaccolate": "fiaccolata",
    "fiaccole": "fiaccola",
    "fiaccò": "fiaccare",
    "fiale": "fiala",
    "fialette": "fialetta",
    "fiammanti": "fiammante",
    "fiammata": "fiammato",
    "fiammate": "fiammato",
    "fiammati": "fiammato",
    "fiamme": "fiamma",
    "fiammeggerai": "fiammeggiare",
    "fiammeggeran": "fiammeggiare",
    "fiammeggeranno": "fiammeggiare",
    "fiammeggerebbe": "fiammeggiare",
    "fiammeggerebber": "fiammeggiare",
    "fiammeggerebbero": "fiammeggiare",
    "fiammeggerei": "fiammeggiare",
    "fiammeggeremmo": "fiammeggiare",
    "fiammeggeremo": "fiammeggiare",
    "fiammeggereste": "fiammeggiare",
    "fiammeggeresti": "fiammeggiare",
    "fiammeggerete": "fiammeggiare",
    "fiammeggerà": "fiammeggiare",
    "fiammeggerò": "fiammeggiare",
    "fiammeggi": "fiammeggiare",
    "fiammeggia": "fiammeggiare",
    "fiammeggiai": "fiammeggiare",
    "fiammeggiammo": "fiammeggiare",
    "fiammeggiamo": "fiammeggiare",
    "fiammeggian": "fiammeggiare",
    "fiammeggiando": "fiammeggiare",
    "fiammeggiano": "fiammeggiare",
    "fiammeggiante": "fiammeggiare",
    "fiammeggianti": "fiammeggiare",
    "fiammeggiar": "fiammeggiare",
    "fiammeggiaron": "fiammeggiare",
    "fiammeggiarono": "fiammeggiare",
    "fiammeggiasse": "fiammeggiare",
    "fiammeggiasser": "fiammeggiare",
    "fiammeggiassero": "fiammeggiare",
    "fiammeggiassi": "fiammeggiare",
    "fiammeggiassimo": "fiammeggiare",
    "fiammeggiaste": "fiammeggiare",
    "fiammeggiasti": "fiammeggiare",
    "fiammeggiata": "fiammeggiare",
    "fiammeggiate": "fiammeggiare",
    "fiammeggiati": "fiammeggiare",
    "fiammeggiato": "fiammeggiare",
    "fiammeggiava": "fiammeggiare",
    "fiammeggiavamo": "fiammeggiare",
    "fiammeggiavan": "fiammeggiare",
    "fiammeggiavano": "fiammeggiare",
    "fiammeggiavate": "fiammeggiare",
    "fiammeggiavi": "fiammeggiare",
    "fiammeggiavo": "fiammeggiare",
    "fiammeggin": "fiammeggiare",
    "fiammeggino": "fiammeggiare",
    "fiammeggio": "fiammeggiare",
    "fiammeggiò": "fiammeggiare",
    "fiammelle": "fiammella",
    "fiammiferi": "fiammifero",
    "fiamminga": "fiammingo",
    "fiamminghe": "fiammingo",
    "fiamminghi": "fiammingo",
    "fianca": "fiancare",
    "fiancai": "fiancare",
    "fiancammo": "fiancare",
    "fiancan": "fiancare",
    "fiancando": "fiancare",
    "fiancano": "fiancare",
    "fiancante": "fiancare",
    "fiancanti": "fiancare",
    "fiancar": "fiancare",
    "fiancaron": "fiancare",
    "fiancarono": "fiancare",
    "fiancasse": "fiancare",
    "fiancasser": "fiancare",
    "fiancassero": "fiancare",
    "fiancassi": "fiancare",
    "fiancassimo": "fiancare",
    "fiancaste": "fiancare",
    "fiancasti": "fiancare",
    "fiancata": "fiancare",
    "fiancate": "fiancata",
    "fiancati": "fiancare",
    "fiancato": "fiancare",
    "fiancava": "fiancare",
    "fiancavamo": "fiancare",
    "fiancavan": "fiancare",
    "fiancavano": "fiancare",
    "fiancavate": "fiancare",
    "fiancavi": "fiancare",
    "fiancavo": "fiancare",
    "fiancheggerai": "fiancheggiare",
    "fiancheggeran": "fiancheggiare",
    "fiancheggeranno": "fiancheggiare",
    "fiancheggerebbe": "fiancheggiare",
    "fiancheggerebber": "fiancheggiare",
    "fiancheggerebbero": "fiancheggiare",
    "fiancheggerei": "fiancheggiare",
    "fiancheggeremmo": "fiancheggiare",
    "fiancheggeremo": "fiancheggiare",
    "fiancheggereste": "fiancheggiare",
    "fiancheggeresti": "fiancheggiare",
    "fiancheggerete": "fiancheggiare",
    "fiancheggerà": "fiancheggiare",
    "fiancheggerò": "fiancheggiare",
    "fiancheggi": "fiancheggiare",
    "fiancheggia": "fiancheggiare",
    "fiancheggiai": "fiancheggiare",
    "fiancheggiammo": "fiancheggiare",
    "fiancheggiamo": "fiancheggiare",
    "fiancheggian": "fiancheggiare",
    "fiancheggiando": "fiancheggiare",
    "fiancheggiano": "fiancheggiare",
    "fiancheggiante": "fiancheggiare",
    "fiancheggianti": "fiancheggiare",
    "fiancheggiar": "fiancheggiare",
    "fiancheggiaron": "fiancheggiare",
    "fiancheggiarono": "fiancheggiare",
    "fiancheggiasse": "fiancheggiare",
    "fiancheggiasser": "fiancheggiare",
    "fiancheggiassero": "fiancheggiare",
    "fiancheggiassi": "fiancheggiare",
    "fiancheggiassimo": "fiancheggiare",
    "fiancheggiaste": "fiancheggiare",
    "fiancheggiasti": "fiancheggiare",
    "fiancheggiata": "fiancheggiare",
    "fiancheggiate": "fiancheggiare",
    "fiancheggiati": "fiancheggiare",
    "fiancheggiato": "fiancheggiare",
    "fiancheggiatori": "fiancheggiatore",
    "fiancheggiatrice": "fiancheggiatore",
    "fiancheggiatrici": "fiancheggiatore",
    "fiancheggiava": "fiancheggiare",
    "fiancheggiavamo": "fiancheggiare",
    "fiancheggiavan": "fiancheggiare",
    "fiancheggiavano": "fiancheggiare",
    "fiancheggiavate": "fiancheggiare",
    "fiancheggiavi": "fiancheggiare",
    "fiancheggiavo": "fiancheggiare",
    "fiancheggin": "fiancheggiare",
    "fiancheggino": "fiancheggiare",
    "fiancheggio": "fiancheggiare",
    "fiancheggiò": "fiancheggiare",
    "fiancherai": "fiancare",
    "fiancheran": "fiancare",
    "fiancheranno": "fiancare",
    "fiancherebbe": "fiancare",
    "fiancherebber": "fiancare",
    "fiancherebbero": "fiancare",
    "fiancherei": "fiancare",
    "fiancheremmo": "fiancare",
    "fiancheremo": "fiancare",
    "fianchereste": "fiancare",
    "fiancheresti": "fiancare",
    "fiancherete": "fiancare",
    "fiancherà": "fiancare",
    "fiancherò": "fiancare",
    "fianchi": "fianco",
    "fianchiamo": "fiancare",
    "fianchiate": "fiancare",
    "fianchin": "fiancare",
    "fianchino": "fiancare",
    "fianco": "fiancare",
    "fiancò": "fiancare",
    "fiaschi": "fiasco",
    "fiata": "fiatare",
    "fiatai": "fiatare",
    "fiatammo": "fiatare",
    "fiatan": "fiatare",
    "fiatando": "fiatare",
    "fiatano": "fiatare",
    "fiatante": "fiatare",
    "fiatanti": "fiatare",
    "fiatar": "fiatare",
    "fiataron": "fiatare",
    "fiatarono": "fiatare",
    "fiatasse": "fiatare",
    "fiatasser": "fiatare",
    "fiatassero": "fiatare",
    "fiatassi": "fiatare",
    "fiatassimo": "fiatare",
    "fiataste": "fiatare",
    "fiatasti": "fiatare",
    "fiatata": "fiatare",
    "fiatate": "fiatare",
    "fiatati": "fiatare",
    "fiatato": "fiatare",
    "fiatava": "fiatare",
    "fiatavamo": "fiatare",
    "fiatavan": "fiatare",
    "fiatavano": "fiatare",
    "fiatavate": "fiatare",
    "fiatavi": "fiatare",
    "fiatavo": "fiatare",
    "fiaterai": "fiatare",
    "fiateran": "fiatare",
    "fiateranno": "fiatare",
    "fiaterebbe": "fiatare",
    "fiaterebber": "fiatare",
    "fiaterebbero": "fiatare",
    "fiaterei": "fiatare",
    "fiateremmo": "fiatare",
    "fiateremo": "fiatare",
    "fiatereste": "fiatare",
    "fiateresti": "fiatare",
    "fiaterete": "fiatare",
    "fiaterà": "fiatare",
    "fiaterò": "fiatare",
    "fiati": "fiato",
    "fiatiamo": "fiatare",
    "fiatiate": "fiatare",
    "fiatin": "fiatare",
    "fiatino": "fiatare",
    "fiato": "fiatare",
    "fiatoni": "fiatone",
    "fiatò": "fiatare",
    "fibre": "fibra",
    "fibrillazioni": "fibrillazione",
    "fibromi": "fibroma",
    "fibrosa": "fibroso",
    "fibrose": "fibroso",
    "fibrosi": "fibroso",
    "ficca": "ficcare",
    "ficcai": "ficcare",
    "ficcammo": "ficcare",
    "ficcan": "ficcare",
    "ficcando": "ficcare",
    "ficcano": "ficcare",
    "ficcante": "ficcare",
    "ficcanti": "ficcare",
    "ficcar": "ficcare",
    "ficcaron": "ficcare",
    "ficcarono": "ficcare",
    "ficcasse": "ficcare",
    "ficcasser": "ficcare",
    "ficcassero": "ficcare",
    "ficcassi": "ficcare",
    "ficcassimo": "ficcare",
    "ficcaste": "ficcare",
    "ficcasti": "ficcare",
    "ficcata": "ficcare",
    "ficcate": "ficcare",
    "ficcati": "ficcare",
    "ficcato": "ficcare",
    "ficcava": "ficcare",
    "ficcavamo": "ficcare",
    "ficcavan": "ficcare",
    "ficcavano": "ficcare",
    "ficcavate": "ficcare",
    "ficcavi": "ficcare",
    "ficcavo": "ficcare",
    "ficcherai": "ficcare",
    "ficcheran": "ficcare",
    "ficcheranno": "ficcare",
    "ficcherebbe": "ficcare",
    "ficcherebber": "ficcare",
    "ficcherebbero": "ficcare",
    "ficcherei": "ficcare",
    "ficcheremmo": "ficcare",
    "ficcheremo": "ficcare",
    "ficchereste": "ficcare",
    "ficcheresti": "ficcare",
    "ficcherete": "ficcare",
    "ficcherà": "ficcare",
    "ficcherò": "ficcare",
    "ficchi": "ficcare",
    "ficchiamo": "ficcare",
    "ficchiate": "ficcare",
    "ficchin": "ficcare",
    "ficchino": "ficcare",
    "ficco": "ficcare",
    "ficcò": "ficcare",
    "fichi": "fico",
    "fida": "fido",
    "fidai": "fidare",
    "fidammo": "fidare",
    "fidan": "fidare",
    "fidando": "fidare",
    "fidano": "fidare",
    "fidante": "fidare",
    "fidanti": "fidare",
    "fidanza": "fidanzare",
    "fidanzai": "fidanzare",
    "fidanzamenti": "fidanzamento",
    "fidanzammo": "fidanzare",
    "fidanzan": "fidanzare",
    "fidanzando": "fidanzare",
    "fidanzano": "fidanzare",
    "fidanzante": "fidanzare",
    "fidanzanti": "fidanzare",
    "fidanzar": "fidanzare",
    "fidanzaron": "fidanzare",
    "fidanzarono": "fidanzare",
    "fidanzasse": "fidanzare",
    "fidanzasser": "fidanzare",
    "fidanzassero": "fidanzare",
    "fidanzassi": "fidanzare",
    "fidanzassimo": "fidanzare",
    "fidanzaste": "fidanzare",
    "fidanzasti": "fidanzare",
    "fidanzata": "fidanzato",
    "fidanzate": "fidanzato",
    "fidanzati": "fidanzato",
    "fidanzatine": "fidanzatina",
    "fidanzatini": "fidanzatino",
    "fidanzato": "fidanzare",
    "fidanzava": "fidanzare",
    "fidanzavamo": "fidanzare",
    "fidanzavan": "fidanzare",
    "fidanzavano": "fidanzare",
    "fidanzavate": "fidanzare",
    "fidanzavi": "fidanzare",
    "fidanzavo": "fidanzare",
    "fidanzerai": "fidanzare",
    "fidanzeran": "fidanzare",
    "fidanzeranno": "fidanzare",
    "fidanzerebbe": "fidanzare",
    "fidanzerebber": "fidanzare",
    "fidanzerebbero": "fidanzare",
    "fidanzerei": "fidanzare",
    "fidanzeremmo": "fidanzare",
    "fidanzeremo": "fidanzare",
    "fidanzereste": "fidanzare",
    "fidanzeresti": "fidanzare",
    "fidanzerete": "fidanzare",
    "fidanzerà": "fidanzare",
    "fidanzerò": "fidanzare",
    "fidanzi": "fidanzare",
    "fidanziamo": "fidanzare",
    "fidanziate": "fidanzare",
    "fidanzin": "fidanzare",
    "fidanzino": "fidanzare",
    "fidanzo": "fidanzare",
    "fidanzò": "fidanzare",
    "fidar": "fidare",
    "fidaron": "fidare",
    "fidarono": "fidare",
    "fidasse": "fidare",
    "fidasser": "fidare",
    "fidassero": "fidare",
    "fidassi": "fidare",
    "fidassimo": "fidare",
    "fidaste": "fidare",
    "fidasti": "fidare",
    "fidata": "fidato",
    "fidate": "fidato",
    "fidati": "fidato",
    "fidato": "fidare",
    "fidava": "fidare",
    "fidavamo": "fidare",
    "fidavan": "fidare",
    "fidavano": "fidare",
    "fidavate": "fidare",
    "fidavi": "fidare",
    "fidavo": "fidare",
    "fide": "fido",
    "fideiussioni": "fideiussione",
    "fidejussioni": "fidejussione",
    "fiderai": "fidare",
    "fideran": "fidare",
    "fideranno": "fidare",
    "fiderebbe": "fidare",
    "fiderebber": "fidare",
    "fiderebbero": "fidare",
    "fiderei": "fidare",
    "fideremmo": "fidare",
    "fideremo": "fidare",
    "fidereste": "fidare",
    "fideresti": "fidare",
    "fiderete": "fidare",
    "fiderà": "fidare",
    "fiderò": "fidare",
    "fidi": "fido",
    "fidiamo": "fidare",
    "fidiate": "fidare",
    "fidin": "fidare",
    "fidino": "fidare",
    "fido": "fidare",
    "fiduce": "fiducia",
    "fiducianti": "fiduciante",
    "fiduciari": "fiduciario",
    "fiduciaria": "fiduciario",
    "fiduciarie": "fiduciario",
    "fiduciosa": "fiducioso",
    "fiduciose": "fiducioso",
    "fiduciosi": "fiducioso",
    "fidò": "fidare",
    "fieni": "fieno",
    "fiera": "fiero",
    "fiere": "fiero",
    "fierezze": "fierezza",
    "fieri": "fiero",
    "fieristica": "fieristico",
    "fieristiche": "fieristico",
    "fieristici": "fieristico",
    "fieste": "fiesta",
    "fievoli": "fievole",
    "fifoni": "fifone",
    "figga": "figgere",
    "figgan": "figgere",
    "figgano": "figgere",
    "figge": "figgere",
    "figgemmo": "figgere",
    "figgendo": "figgere",
    "figgente": "figgere",
    "figgenti": "figgere",
    "figger": "figgere",
    "figgerai": "figgere",
    "figgeran": "figgere",
    "figgeranno": "figgere",
    "figgerebbe": "figgere",
    "figgerebber": "figgere",
    "figgerebbero": "figgere",
    "figgerei": "figgere",
    "figgeremmo": "figgere",
    "figgeremo": "figgere",
    "figgereste": "figgere",
    "figgeresti": "figgere",
    "figgerete": "figgere",
    "figgerà": "figgere",
    "figgerò": "figgere",
    "figgesse": "figgere",
    "figgesser": "figgere",
    "figgessero": "figgere",
    "figgessi": "figgere",
    "figgessimo": "figgere",
    "figgeste": "figgere",
    "figgesti": "figgere",
    "figgete": "figgere",
    "figgeva": "figgere",
    "figgevamo": "figgere",
    "figgevan": "figgere",
    "figgevano": "figgere",
    "figgevate": "figgere",
    "figgevi": "figgere",
    "figgevo": "figgere",
    "figgi": "figgere",
    "figgiamo": "figgere",
    "figgiate": "figgere",
    "figgo": "figgere",
    "figgon": "figgere",
    "figgono": "figgere",
    "fighetti": "fighetto",
    "figiana": "figiano",
    "figiane": "figiano",
    "figiani": "figiano",
    "figli": "figlio",
    "figlia": "figliare",
    "figliai": "figliare",
    "figliammo": "figliare",
    "figliamo": "figliare",
    "figlian": "figliare",
    "figliando": "figliare",
    "figliano": "figliare",
    "figliante": "figliare",
    "figlianti": "figliare",
    "figliar": "figliare",
    "figliaron": "figliare",
    "figliarono": "figliare",
    "figliasse": "figliare",
    "figliasser": "figliare",
    "figliassero": "figliare",
    "figliassi": "figliare",
    "figliassimo": "figliare",
    "figliaste": "figliare",
    "figliasti": "figliare",
    "figliastre": "figliastra",
    "figliastri": "figliastro",
    "figliata": "figliare",
    "figliate": "figliare",
    "figliati": "figliare",
    "figliato": "figliare",
    "figliava": "figliare",
    "figliavamo": "figliare",
    "figliavan": "figliare",
    "figliavano": "figliare",
    "figliavate": "figliare",
    "figliavi": "figliare",
    "figliavo": "figliare",
    "figlie": "figlia",
    "figlierai": "figliare",
    "figlieran": "figliare",
    "figlieranno": "figliare",
    "figlierebbe": "figliare",
    "figlierebber": "figliare",
    "figlierebbero": "figliare",
    "figlierei": "figliare",
    "figlieremmo": "figliare",
    "figlieremo": "figliare",
    "figliereste": "figliare",
    "figlieresti": "figliare",
    "figlierete": "figliare",
    "figlierà": "figliare",
    "figlierò": "figliare",
    "figlin": "figliare",
    "figlino": "figliare",
    "figlio": "figliare",
    "figliocci": "figlioccio",
    "figliol": "figliolo",
    "figliole": "figliola",
    "figliolette": "figlioletta",
    "figlioletti": "figlioletto",
    "figlioli": "figliolo",
    "figliuoli": "figliuolo",
    "figliò": "figliare",
    "figura": "figurare",
    "figuracce": "figuraccia",
    "figurai": "figurare",
    "figurammo": "figurare",
    "figuran": "figurare",
    "figurando": "figurare",
    "figurano": "figurare",
    "figurante": "figurare",
    "figuranti": "figurare",
    "figurar": "figurare",
    "figuraron": "figurare",
    "figurarono": "figurare",
    "figurasse": "figurare",
    "figurasser": "figurare",
    "figurassero": "figurare",
    "figurassi": "figurare",
    "figurassimo": "figurare",
    "figuraste": "figurare",
    "figurasti": "figurare",
    "figurata": "figurato",
    "figurate": "figurato",
    "figurati": "figurato",
    "figurativa": "figurativo",
    "figurative": "figurativo",
    "figurativi": "figurativo",
    "figurato": "figurare",
    "figurava": "figurare",
    "figuravamo": "figurare",
    "figuravan": "figurare",
    "figuravano": "figurare",
    "figuravate": "figurare",
    "figuravi": "figurare",
    "figuravo": "figurare",
    "figurazioni": "figurazione",
    "figure": "figura",
    "figurerai": "figurare",
    "figureran": "figurare",
    "figureranno": "figurare",
    "figurerebbe": "figurare",
    "figurerebber": "figurare",
    "figurerebbero": "figurare",
    "figurerei": "figurare",
    "figureremmo": "figurare",
    "figureremo": "figurare",
    "figurereste": "figurare",
    "figureresti": "figurare",
    "figurerete": "figurare",
    "figurerà": "figurare",
    "figurerò": "figurare",
    "figurette": "figuretta",
    "figuri": "figurare",
    "figuriamo": "figurare",
    "figuriate": "figurare",
    "figurin": "figurare",
    "figurine": "figurina",
    "figurini": "figurino",
    "figurino": "figurare",
    "figuro": "figurare",
    "figurò": "figurare",
    "fil": "filo",
    "fila": "filo",
    "filai": "filare",
    "filamenti": "filamento",
    "filamentosa": "filamentoso",
    "filamentose": "filamentoso",
    "filamentosi": "filamentoso",
    "filammo": "filare",
    "filan": "filare",
    "filande": "filanda",
    "filando": "filare",
    "filano": "filare",
    "filante": "filare",
    "filanti": "filare",
    "filantropi": "filantropo",
    "filantropica": "filantropico",
    "filantropiche": "filantropico",
    "filantropici": "filantropico",
    "filantropie": "filantropia",
    "filar": "filare",
    "filarmonica": "filarmonico",
    "filarmoniche": "filarmonico",
    "filarmonici": "filarmonico",
    "filaron": "filare",
    "filarono": "filare",
    "filasse": "filare",
    "filasser": "filare",
    "filassero": "filare",
    "filassi": "filare",
    "filassimo": "filare",
    "filaste": "filare",
    "filasti": "filare",
    "filastrocche": "filastrocca",
    "filata": "filato",
    "filate": "filato",
    "filatelica": "filatelico",
    "filateliche": "filatelico",
    "filatelici": "filatelico",
    "filati": "filato",
    "filato": "filare",
    "filatrici": "filatrice",
    "filature": "filatura",
    "filava": "filare",
    "filavamo": "filare",
    "filavan": "filare",
    "filavano": "filare",
    "filavate": "filare",
    "filavi": "filare",
    "filavo": "filare",
    "file": "fila",
    "filerai": "filare",
    "fileran": "filare",
    "fileranno": "filare",
    "filerebbe": "filare",
    "filerebber": "filare",
    "filerebbero": "filare",
    "filerei": "filare",
    "fileremmo": "filare",
    "fileremo": "filare",
    "filereste": "filare",
    "fileresti": "filare",
    "filerete": "filare",
    "filerà": "filare",
    "filerò": "filare",
    "filetta": "filettare",
    "filettai": "filettare",
    "filettammo": "filettare",
    "filettan": "filettare",
    "filettando": "filettare",
    "filettano": "filettare",
    "filettante": "filettare",
    "filettanti": "filettare",
    "filettar": "filettare",
    "filettaron": "filettare",
    "filettarono": "filettare",
    "filettasse": "filettare",
    "filettasser": "filettare",
    "filettassero": "filettare",
    "filettassi": "filettare",
    "filettassimo": "filettare",
    "filettaste": "filettare",
    "filettasti": "filettare",
    "filettata": "filettare",
    "filettate": "filettare",
    "filettati": "filettare",
    "filettato": "filettare",
    "filettava": "filettare",
    "filettavamo": "filettare",
    "filettavan": "filettare",
    "filettavano": "filettare",
    "filettavate": "filettare",
    "filettavi": "filettare",
    "filettavo": "filettare",
    "filetterai": "filettare",
    "filetteran": "filettare",
    "filetteranno": "filettare",
    "filetterebbe": "filettare",
    "filetterebber": "filettare",
    "filetterebbero": "filettare",
    "filetterei": "filettare",
    "filetteremmo": "filettare",
    "filetteremo": "filettare",
    "filettereste": "filettare",
    "filetteresti": "filettare",
    "filetterete": "filettare",
    "filetterà": "filettare",
    "filetterò": "filettare",
    "filetti": "filetto",
    "filettiamo": "filettare",
    "filettiate": "filettare",
    "filettin": "filettare",
    "filettino": "filettare",
    "filetto": "filettare",
    "filettò": "filettare",
    "fili": "filo",
    "filiali": "filiale",
    "filiamo": "filare",
    "filiate": "filare",
    "filiazioni": "filiazione",
    "filiere": "filiera",
    "filiformi": "filiforme",
    "filigrane": "filigrana",
    "filin": "filare",
    "filini": "filino",
    "filino": "filare",
    "filippiche": "filippica",
    "filippina": "filippino",
    "filippine": "filippino",
    "filippini": "filippino",
    "filistea": "filisteo",
    "filistee": "filisteo",
    "filistei": "filisteo",
    "filma": "filmare",
    "filmacci": "filmaccio",
    "filmai": "filmare",
    "filmammo": "filmare",
    "filman": "filmare",
    "filmando": "filmare",
    "filmano": "filmare",
    "filmante": "filmare",
    "filmanti": "filmare",
    "filmar": "filmare",
    "filmaron": "filmare",
    "filmarono": "filmare",
    "filmasse": "filmare",
    "filmasser": "filmare",
    "filmassero": "filmare",
    "filmassi": "filmare",
    "filmassimo": "filmare",
    "filmaste": "filmare",
    "filmasti": "filmare",
    "filmata": "filmato",
    "filmate": "filmato",
    "filmati": "filmato",
    "filmato": "filmare",
    "filmava": "filmare",
    "filmavamo": "filmare",
    "filmavan": "filmare",
    "filmavano": "filmare",
    "filmavate": "filmare",
    "filmavi": "filmare",
    "filmavo": "filmare",
    "filmerai": "filmare",
    "filmeran": "filmare",
    "filmeranno": "filmare",
    "filmerebbe": "filmare",
    "filmerebber": "filmare",
    "filmerebbero": "filmare",
    "filmerei": "filmare",
    "filmeremmo": "filmare",
    "filmeremo": "filmare",
    "filmereste": "filmare",
    "filmeresti": "filmare",
    "filmerete": "filmare",
    "filmerà": "filmare",
    "filmerò": "filmare",
    "filmetti": "filmetto",
    "filmi": "filmare",
    "filmiamo": "filmare",
    "filmiate": "filmare",
    "filmica": "filmico",
    "filmiche": "filmico",
    "filmici": "filmico",
    "filmin": "filmare",
    "filmini": "filmino",
    "filmino": "filmare",
    "filmo": "filmare",
    "filmografie": "filmografia",
    "filmoni": "filmone",
    "films": "film",
    "filmò": "filmare",
    "filo": "filare",
    "filo-castriste": "filo-castrista",
    "filo-castristi": "filo-castrista",
    "filo-cinesi": "filo-cinese",
    "filo-curda": "filo-curdo",
    "filo-curde": "filo-curdo",
    "filo-curdi": "filo-curdo",
    "filo-egiziana": "filo-egiziano",
    "filo-egiziane": "filo-egiziano",
    "filo-egiziani": "filo-egiziano",
    "filo-governativa": "filo-governativo",
    "filo-governative": "filo-governativo",
    "filo-governativi": "filo-governativo",
    "filo-irachena": "filo-iracheno",
    "filo-irachene": "filo-iracheno",
    "filo-iracheni": "filo-iracheno",
    "filo-iraniana": "filo-iraniano",
    "filo-iraniane": "filo-iraniano",
    "filo-iraniani": "filo-iraniano",
    "filo-occidentali": "filo-occidentale",
    "filodrammatica": "filodrammatico",
    "filodrammatiche": "filodrammatico",
    "filodrammatici": "filodrammatico",
    "filogovernativi": "filogovernativo",
    "filoiraniana": "filoiraniano",
    "filoiraniane": "filoiraniano",
    "filoiraniani": "filoiraniano",
    "filologi": "filologo",
    "filologica": "filologico",
    "filologiche": "filologico",
    "filologici": "filologico",
    "filologie": "filologia",
    "filonaziste": "filonazista",
    "filonazisti": "filonazista",
    "filoni": "filone",
    "filosiriana": "filosiriano",
    "filosiriane": "filosiriano",
    "filosiriani": "filosiriano",
    "filosofa": "filosofare",
    "filosofai": "filosofare",
    "filosofali": "filosofale",
    "filosofammo": "filosofare",
    "filosofan": "filosofare",
    "filosofando": "filosofare",
    "filosofano": "filosofare",
    "filosofante": "filosofare",
    "filosofanti": "filosofare",
    "filosofar": "filosofare",
    "filosofaron": "filosofare",
    "filosofarono": "filosofare",
    "filosofasse": "filosofare",
    "filosofasser": "filosofare",
    "filosofassero": "filosofare",
    "filosofassi": "filosofare",
    "filosofassimo": "filosofare",
    "filosofaste": "filosofare",
    "filosofasti": "filosofare",
    "filosofata": "filosofare",
    "filosofate": "filosofare",
    "filosofati": "filosofare",
    "filosofato": "filosofare",
    "filosofava": "filosofare",
    "filosofavamo": "filosofare",
    "filosofavan": "filosofare",
    "filosofavano": "filosofare",
    "filosofavate": "filosofare",
    "filosofavi": "filosofare",
    "filosofavo": "filosofare",
    "filosofeggerai": "filosofeggiare",
    "filosofeggeran": "filosofeggiare",
    "filosofeggeranno": "filosofeggiare",
    "filosofeggerebbe": "filosofeggiare",
    "filosofeggerebber": "filosofeggiare",
    "filosofeggerebbero": "filosofeggiare",
    "filosofeggerei": "filosofeggiare",
    "filosofeggeremmo": "filosofeggiare",
    "filosofeggeremo": "filosofeggiare",
    "filosofeggereste": "filosofeggiare",
    "filosofeggeresti": "filosofeggiare",
    "filosofeggerete": "filosofeggiare",
    "filosofeggerà": "filosofeggiare",
    "filosofeggerò": "filosofeggiare",
    "filosofeggi": "filosofeggiare",
    "filosofeggia": "filosofeggiare",
    "filosofeggiai": "filosofeggiare",
    "filosofeggiammo": "filosofeggiare",
    "filosofeggiamo": "filosofeggiare",
    "filosofeggian": "filosofeggiare",
    "filosofeggiando": "filosofeggiare",
    "filosofeggiano": "filosofeggiare",
    "filosofeggiante": "filosofeggiare",
    "filosofeggianti": "filosofeggiare",
    "filosofeggiar": "filosofeggiare",
    "filosofeggiaron": "filosofeggiare",
    "filosofeggiarono": "filosofeggiare",
    "filosofeggiasse": "filosofeggiare",
    "filosofeggiasser": "filosofeggiare",
    "filosofeggiassero": "filosofeggiare",
    "filosofeggiassi": "filosofeggiare",
    "filosofeggiassimo": "filosofeggiare",
    "filosofeggiaste": "filosofeggiare",
    "filosofeggiasti": "filosofeggiare",
    "filosofeggiata": "filosofeggiare",
    "filosofeggiate": "filosofeggiare",
    "filosofeggiati": "filosofeggiare",
    "filosofeggiato": "filosofeggiare",
    "filosofeggiava": "filosofeggiare",
    "filosofeggiavamo": "filosofeggiare",
    "filosofeggiavan": "filosofeggiare",
    "filosofeggiavano": "filosofeggiare",
    "filosofeggiavate": "filosofeggiare",
    "filosofeggiavi": "filosofeggiare",
    "filosofeggiavo": "filosofeggiare",
    "filosofeggin": "filosofeggiare",
    "filosofeggino": "filosofeggiare",
    "filosofeggio": "filosofeggiare",
    "filosofeggiò": "filosofeggiare",
    "filosoferai": "filosofare",
    "filosoferan": "filosofare",
    "filosoferanno": "filosofare",
    "filosoferebbe": "filosofare",
    "filosoferebber": "filosofare",
    "filosoferebbero": "filosofare",
    "filosoferei": "filosofare",
    "filosoferemmo": "filosofare",
    "filosoferemo": "filosofare",
    "filosofereste": "filosofare",
    "filosoferesti": "filosofare",
    "filosoferete": "filosofare",
    "filosoferà": "filosofare",
    "filosoferò": "filosofare",
    "filosofi": "filosofo",
    "filosofiamo": "filosofare",
    "filosofiate": "filosofare",
    "filosofica": "filosofico",
    "filosofiche": "filosofico",
    "filosofici": "filosofico",
    "filosofie": "filosofia",
    "filosofin": "filosofare",
    "filosofino": "filosofare",
    "filosofo": "filosofare",
    "filosofò": "filosofare",
    "filosovietica": "filosovietico",
    "filosovietiche": "filosovietico",
    "filosovietici": "filosovietico",
    "filtra": "filtrare",
    "filtrai": "filtrare",
    "filtrammo": "filtrare",
    "filtran": "filtrare",
    "filtrando": "filtrare",
    "filtrano": "filtrare",
    "filtrante": "filtrare",
    "filtranti": "filtrare",
    "filtrar": "filtrare",
    "filtraron": "filtrare",
    "filtrarono": "filtrare",
    "filtrasse": "filtrare",
    "filtrasser": "filtrare",
    "filtrassero": "filtrare",
    "filtrassi": "filtrare",
    "filtrassimo": "filtrare",
    "filtraste": "filtrare",
    "filtrasti": "filtrare",
    "filtrata": "filtrare",
    "filtrate": "filtrare",
    "filtrati": "filtrare",
    "filtrato": "filtrare",
    "filtrava": "filtrare",
    "filtravamo": "filtrare",
    "filtravan": "filtrare",
    "filtravano": "filtrare",
    "filtravate": "filtrare",
    "filtravi": "filtrare",
    "filtravo": "filtrare",
    "filtrerai": "filtrare",
    "filtreran": "filtrare",
    "filtreranno": "filtrare",
    "filtrerebbe": "filtrare",
    "filtrerebber": "filtrare",
    "filtrerebbero": "filtrare",
    "filtrerei": "filtrare",
    "filtreremmo": "filtrare",
    "filtreremo": "filtrare",
    "filtrereste": "filtrare",
    "filtreresti": "filtrare",
    "filtrerete": "filtrare",
    "filtrerà": "filtrare",
    "filtrerò": "filtrare",
    "filtri": "filtro",
    "filtriamo": "filtrare",
    "filtriate": "filtrare",
    "filtrin": "filtrare",
    "filtrino": "filtrare",
    "filtro": "filtrare",
    "filtrò": "filtrare",
    "filò": "filare",
    "fina": "fino",
    "finali": "finale",
    "finaliste": "finalista",
    "finalisti": "finalista",
    "finalizza": "finalizzare",
    "finalizzai": "finalizzare",
    "finalizzammo": "finalizzare",
    "finalizzan": "finalizzare",
    "finalizzando": "finalizzare",
    "finalizzano": "finalizzare",
    "finalizzante": "finalizzare",
    "finalizzanti": "finalizzare",
    "finalizzar": "finalizzare",
    "finalizzaron": "finalizzare",
    "finalizzarono": "finalizzare",
    "finalizzasse": "finalizzare",
    "finalizzasser": "finalizzare",
    "finalizzassero": "finalizzare",
    "finalizzassi": "finalizzare",
    "finalizzassimo": "finalizzare",
    "finalizzaste": "finalizzare",
    "finalizzasti": "finalizzare",
    "finalizzata": "finalizzare",
    "finalizzate": "finalizzare",
    "finalizzati": "finalizzare",
    "finalizzato": "finalizzare",
    "finalizzava": "finalizzare",
    "finalizzavamo": "finalizzare",
    "finalizzavan": "finalizzare",
    "finalizzavano": "finalizzare",
    "finalizzavate": "finalizzare",
    "finalizzavi": "finalizzare",
    "finalizzavo": "finalizzare",
    "finalizzazioni": "finalizzazione",
    "finalizzerai": "finalizzare",
    "finalizzeran": "finalizzare",
    "finalizzeranno": "finalizzare",
    "finalizzerebbe": "finalizzare",
    "finalizzerebber": "finalizzare",
    "finalizzerebbero": "finalizzare",
    "finalizzerei": "finalizzare",
    "finalizzeremmo": "finalizzare",
    "finalizzeremo": "finalizzare",
    "finalizzereste": "finalizzare",
    "finalizzeresti": "finalizzare",
    "finalizzerete": "finalizzare",
    "finalizzerà": "finalizzare",
    "finalizzerò": "finalizzare",
    "finalizzi": "finalizzare",
    "finalizziamo": "finalizzare",
    "finalizziate": "finalizzare",
    "finalizzin": "finalizzare",
    "finalizzino": "finalizzare",
    "finalizzo": "finalizzare",
    "finalizzò": "finalizzare",
    "finanze": "finanza",
    "finanzi": "finanziare",
    "finanzia": "finanziare",
    "finanziabili": "finanziabile",
    "finanziai": "finanziare",
    "finanziamenti": "finanziamento",
    "finanziammo": "finanziare",
    "finanziamo": "finanziare",
    "finanzian": "finanziare",
    "finanziando": "finanziare",
    "finanziano": "finanziare",
    "finanziante": "finanziare",
    "finanzianti": "finanziare",
    "finanziar": "finanziare",
    "finanziari": "finanziario",
    "finanziaria": "finanziario",
    "finanziarie": "finanziario",
    "finanziaron": "finanziare",
    "finanziarono": "finanziare",
    "finanziasse": "finanziare",
    "finanziasser": "finanziare",
    "finanziassero": "finanziare",
    "finanziassi": "finanziare",
    "finanziassimo": "finanziare",
    "finanziaste": "finanziare",
    "finanziasti": "finanziare",
    "finanziata": "finanziare",
    "finanziate": "finanziare",
    "finanziati": "finanziare",
    "finanziato": "finanziare",
    "finanziatori": "finanziatore",
    "finanziava": "finanziare",
    "finanziavamo": "finanziare",
    "finanziavan": "finanziare",
    "finanziavano": "finanziare",
    "finanziavate": "finanziare",
    "finanziavi": "finanziare",
    "finanziavo": "finanziare",
    "finanzierai": "finanziare",
    "finanzieran": "finanziare",
    "finanzieranno": "finanziare",
    "finanzierebbe": "finanziare",
    "finanzierebber": "finanziare",
    "finanzierebbero": "finanziare",
    "finanzierei": "finanziare",
    "finanzieremmo": "finanziare",
    "finanzieremo": "finanziare",
    "finanziereste": "finanziare",
    "finanzieresti": "finanziare",
    "finanzierete": "finanziare",
    "finanzieri": "finanziere",
    "finanzierà": "finanziare",
    "finanzierò": "finanziare",
    "finanzin": "finanziare",
    "finanzino": "finanziare",
    "finanzio": "finanziare",
    "finanziò": "finanziare",
    "finaziamenti": "finaziamento",
    "fine": "fino",
    "finendo": "finire",
    "finente": "finire",
    "finenti": "finire",
    "finestre": "finestra",
    "finestrelle": "finestrella",
    "finestrini": "finestrino",
    "finestroni": "finestrone",
    "finezze": "finezza",
    "finga": "fingere",
    "fingan": "fingere",
    "fingano": "fingere",
    "finge": "fingere",
    "fingemmo": "fingere",
    "fingendo": "fingere",
    "fingente": "fingere",
    "fingenti": "fingere",
    "finger": "fingere",
    "fingerai": "fingere",
    "fingeran": "fingere",
    "fingeranno": "fingere",
    "fingerebbe": "fingere",
    "fingerebber": "fingere",
    "fingerebbero": "fingere",
    "fingerei": "fingere",
    "fingeremmo": "fingere",
    "fingeremo": "fingere",
    "fingereste": "fingere",
    "fingeresti": "fingere",
    "fingerete": "fingere",
    "fingerà": "fingere",
    "fingerò": "fingere",
    "fingesse": "fingere",
    "fingesser": "fingere",
    "fingessero": "fingere",
    "fingessi": "fingere",
    "fingessimo": "fingere",
    "fingeste": "fingere",
    "fingesti": "fingere",
    "fingete": "fingere",
    "fingeva": "fingere",
    "fingevamo": "fingere",
    "fingevan": "fingere",
    "fingevano": "fingere",
    "fingevate": "fingere",
    "fingevi": "fingere",
    "fingevo": "fingere",
    "fingi": "fingere",
    "fingiamo": "fingere",
    "fingiate": "fingere",
    "fingo": "fingere",
    "fingon": "fingere",
    "fingono": "fingere",
    "fini": "fino",
    "finiamo": "finire",
    "finiana": "finiano",
    "finiane": "finiano",
    "finiani": "finiano",
    "finiate": "finire",
    "finii": "finire",
    "finimmo": "finire",
    "finimondi": "finimondo",
    "finir": "finire",
    "finirai": "finire",
    "finiran": "finire",
    "finiranno": "finire",
    "finirebbe": "finire",
    "finirebber": "finire",
    "finirebbero": "finire",
    "finirei": "finire",
    "finiremmo": "finire",
    "finiremo": "finire",
    "finireste": "finire",
    "finiresti": "finire",
    "finirete": "finire",
    "finiron": "finire",
    "finirono": "finire",
    "finirà": "finire",
    "finirò": "finire",
    "finisca": "finire",
    "finiscan": "finire",
    "finiscano": "finire",
    "finisce": "finire",
    "finisci": "finire",
    "finisco": "finire",
    "finiscon": "finire",
    "finiscono": "finire",
    "finisse": "finire",
    "finisser": "finire",
    "finissero": "finire",
    "finissi": "finire",
    "finissimo": "finire",
    "finiste": "finire",
    "finisti": "finire",
    "finita": "finito",
    "finite": "finito",
    "finitezze": "finitezza",
    "finiti": "finito",
    "finito": "finire",
    "finiture": "finitura",
    "finiva": "finire",
    "finivamo": "finire",
    "finivan": "finire",
    "finivano": "finire",
    "finivate": "finire",
    "finivi": "finire",
    "finivo": "finire",
    "finlandesi": "finlandese",
    "finmeccaniche": "finmeccanica",
    "finnica": "finnico",
    "finniche": "finnico",
    "finnici": "finnico",
    "finocchi": "finocchio",
    "finser": "fingere",
    "finsero": "fingere",
    "finsi": "fingere",
    "finsè": "fingere",
    "finta": "finto",
    "fintai": "fintare",
    "fintammo": "fintare",
    "fintan": "fintare",
    "fintando": "fintare",
    "fintano": "fintare",
    "fintante": "fintare",
    "fintanti": "fintare",
    "fintar": "fintare",
    "fintaron": "fintare",
    "fintarono": "fintare",
    "fintasse": "fintare",
    "fintasser": "fintare",
    "fintassero": "fintare",
    "fintassi": "fintare",
    "fintassimo": "fintare",
    "fintaste": "fintare",
    "fintasti": "fintare",
    "fintata": "fintare",
    "fintate": "fintare",
    "fintati": "fintare",
    "fintato": "fintare",
    "fintava": "fintare",
    "fintavamo": "fintare",
    "fintavan": "fintare",
    "fintavano": "fintare",
    "fintavate": "fintare",
    "fintavi": "fintare",
    "fintavo": "fintare",
    "finte": "finto",
    "finterai": "fintare",
    "finteran": "fintare",
    "finteranno": "fintare",
    "finterebbe": "fintare",
    "finterebber": "fintare",
    "finterebbero": "fintare",
    "finterei": "fintare",
    "finteremmo": "fintare",
    "finteremo": "fintare",
    "fintereste": "fintare",
    "finteresti": "fintare",
    "finterete": "fintare",
    "finterà": "fintare",
    "finterò": "fintare",
    "finti": "finto",
    "fintiamo": "fintare",
    "fintiate": "fintare",
    "fintin": "fintare",
    "fintino": "fintare",
    "finto": "fintare",
    "fintò": "fintare",
    "finzioni": "finzione",
    "finì": "finire",
    "fioca": "fioco",
    "fiocca": "fioccare",
    "fioccai": "fioccare",
    "fioccammo": "fioccare",
    "fioccan": "fioccare",
    "fioccando": "fioccare",
    "fioccano": "fioccare",
    "fioccante": "fioccare",
    "fioccanti": "fioccare",
    "fioccar": "fioccare",
    "fioccaron": "fioccare",
    "fioccarono": "fioccare",
    "fioccasse": "fioccare",
    "fioccasser": "fioccare",
    "fioccassero": "fioccare",
    "fioccassi": "fioccare",
    "fioccassimo": "fioccare",
    "fioccaste": "fioccare",
    "fioccasti": "fioccare",
    "fioccata": "fioccare",
    "fioccate": "fioccare",
    "fioccati": "fioccare",
    "fioccato": "fioccare",
    "fioccava": "fioccare",
    "fioccavamo": "fioccare",
    "fioccavan": "fioccare",
    "fioccavano": "fioccare",
    "fioccavate": "fioccare",
    "fioccavi": "fioccare",
    "fioccavo": "fioccare",
    "fioccherai": "fioccare",
    "fioccheran": "fioccare",
    "fioccheranno": "fioccare",
    "fioccherebbe": "fioccare",
    "fioccherebber": "fioccare",
    "fioccherebbero": "fioccare",
    "fioccherei": "fioccare",
    "fioccheremmo": "fioccare",
    "fioccheremo": "fioccare",
    "fiocchereste": "fioccare",
    "fioccheresti": "fioccare",
    "fioccherete": "fioccare",
    "fioccherà": "fioccare",
    "fioccherò": "fioccare",
    "fiocchetti": "fiocchetto",
    "fiocchi": "fiocco",
    "fiocchiamo": "fioccare",
    "fiocchiate": "fioccare",
    "fiocchin": "fioccare",
    "fiocchino": "fioccare",
    "fiocco": "fioccare",
    "fioccò": "fioccare",
    "fioche": "fioco",
    "fiochi": "fioco",
    "fiocina": "fiocinare",
    "fiocinai": "fiocinare",
    "fiocinammo": "fiocinare",
    "fiocinan": "fiocinare",
    "fiocinando": "fiocinare",
    "fiocinano": "fiocinare",
    "fiocinante": "fiocinare",
    "fiocinanti": "fiocinare",
    "fiocinar": "fiocinare",
    "fiocinaron": "fiocinare",
    "fiocinarono": "fiocinare",
    "fiocinasse": "fiocinare",
    "fiocinasser": "fiocinare",
    "fiocinassero": "fiocinare",
    "fiocinassi": "fiocinare",
    "fiocinassimo": "fiocinare",
    "fiocinaste": "fiocinare",
    "fiocinasti": "fiocinare",
    "fiocinata": "fiocinare",
    "fiocinate": "fiocinare",
    "fiocinati": "fiocinare",
    "fiocinato": "fiocinare",
    "fiocinava": "fiocinare",
    "fiocinavamo": "fiocinare",
    "fiocinavan": "fiocinare",
    "fiocinavano": "fiocinare",
    "fiocinavate": "fiocinare",
    "fiocinavi": "fiocinare",
    "fiocinavo": "fiocinare",
    "fiocinerai": "fiocinare",
    "fiocineran": "fiocinare",
    "fiocineranno": "fiocinare",
    "fiocinerebbe": "fiocinare",
    "fiocinerebber": "fiocinare",
    "fiocinerebbero": "fiocinare",
    "fiocinerei": "fiocinare",
    "fiocineremmo": "fiocinare",
    "fiocineremo": "fiocinare",
    "fiocinereste": "fiocinare",
    "fiocineresti": "fiocinare",
    "fiocinerete": "fiocinare",
    "fiocinerà": "fiocinare",
    "fiocinerò": "fiocinare",
    "fiocini": "fiocinare",
    "fiociniamo": "fiocinare",
    "fiociniate": "fiocinare",
    "fiocinin": "fiocinare",
    "fiocinino": "fiocinare",
    "fiocino": "fiocinare",
    "fiocinò": "fiocinare",
    "fiondate": "fiondata",
    "fionde": "fionda",
    "fiorai": "fioraio",
    "fioraie": "fioraia",
    "fiordi": "fiordo",
    "fiorellini": "fiorellino",
    "fiorendo": "fiorire",
    "fiorente": "fiorire",
    "fiorenti": "fiorire",
    "fiorentina": "fiorentino",
    "fiorentine": "fiorentino",
    "fiorentini": "fiorentino",
    "fioretta": "fiorettare",
    "fiorettai": "fiorettare",
    "fiorettammo": "fiorettare",
    "fiorettan": "fiorettare",
    "fiorettando": "fiorettare",
    "fiorettano": "fiorettare",
    "fiorettante": "fiorettare",
    "fiorettanti": "fiorettare",
    "fiorettar": "fiorettare",
    "fiorettaron": "fiorettare",
    "fiorettarono": "fiorettare",
    "fiorettasse": "fiorettare",
    "fiorettasser": "fiorettare",
    "fiorettassero": "fiorettare",
    "fiorettassi": "fiorettare",
    "fiorettassimo": "fiorettare",
    "fiorettaste": "fiorettare",
    "fiorettasti": "fiorettare",
    "fiorettata": "fiorettare",
    "fiorettate": "fiorettare",
    "fiorettati": "fiorettare",
    "fiorettato": "fiorettare",
    "fiorettava": "fiorettare",
    "fiorettavamo": "fiorettare",
    "fiorettavan": "fiorettare",
    "fiorettavano": "fiorettare",
    "fiorettavate": "fiorettare",
    "fiorettavi": "fiorettare",
    "fiorettavo": "fiorettare",
    "fioretterai": "fiorettare",
    "fioretteran": "fiorettare",
    "fioretteranno": "fiorettare",
    "fioretterebbe": "fiorettare",
    "fioretterebber": "fiorettare",
    "fioretterebbero": "fiorettare",
    "fioretterei": "fiorettare",
    "fioretteremmo": "fiorettare",
    "fioretteremo": "fiorettare",
    "fiorettereste": "fiorettare",
    "fioretteresti": "fiorettare",
    "fioretterete": "fiorettare",
    "fioretterà": "fiorettare",
    "fioretterò": "fiorettare",
    "fioretti": "fioretto",
    "fiorettiamo": "fiorettare",
    "fiorettiate": "fiorettare",
    "fiorettin": "fiorettare",
    "fiorettino": "fiorettare",
    "fiorettiste": "fiorettista",
    "fiorettisti": "fiorettista",
    "fioretto": "fiorettare",
    "fiorettò": "fiorettare",
    "fiori": "fiore",
    "fioriamo": "fiorire",
    "fioriate": "fiorire",
    "fioriere": "fioriera",
    "fiorii": "fiorire",
    "fiorimmo": "fiorire",
    "fiorini": "fiorino",
    "fiorir": "fiorire",
    "fiorirai": "fiorire",
    "fioriran": "fiorire",
    "fioriranno": "fiorire",
    "fiorirebbe": "fiorire",
    "fiorirebber": "fiorire",
    "fiorirebbero": "fiorire",
    "fiorirei": "fiorire",
    "fioriremmo": "fiorire",
    "fioriremo": "fiorire",
    "fiorireste": "fiorire",
    "fioriresti": "fiorire",
    "fiorirete": "fiorire",
    "fioriron": "fiorire",
    "fiorirono": "fiorire",
    "fiorirà": "fiorire",
    "fiorirò": "fiorire",
    "fiorisca": "fiorire",
    "fioriscan": "fiorire",
    "fioriscano": "fiorire",
    "fiorisce": "fiorire",
    "fiorisci": "fiorire",
    "fiorisco": "fiorire",
    "fioriscon": "fiorire",
    "fioriscono": "fiorire",
    "fiorisse": "fiorire",
    "fiorisser": "fiorire",
    "fiorissero": "fiorire",
    "fiorissi": "fiorire",
    "fiorissimo": "fiorire",
    "fioriste": "fiorire",
    "fioristi": "fiorista",
    "fiorita": "fiorito",
    "fiorite": "fiorito",
    "fioriti": "fiorito",
    "fiorito": "fiorire",
    "fioriture": "fioritura",
    "fioriva": "fiorire",
    "fiorivamo": "fiorire",
    "fiorivan": "fiorire",
    "fiorivano": "fiorire",
    "fiorivate": "fiorire",
    "fiorivi": "fiorire",
    "fiorivo": "fiorire",
    "fiorì": "fiorire",
    "fiotti": "fiotto",
    "firma": "firmare",
    "firmai": "firmare",
    "firmamenti": "firmamento",
    "firmammo": "firmare",
    "firman": "firmare",
    "firmando": "firmare",
    "firmano": "firmare",
    "firmante": "firmare",
    "firmanti": "firmare",
    "firmar": "firmare",
    "firmaron": "firmare",
    "firmarono": "firmare",
    "firmasse": "firmare",
    "firmasser": "firmare",
    "firmassero": "firmare",
    "firmassi": "firmare",
    "firmassimo": "firmare",
    "firmaste": "firmare",
    "firmasti": "firmare",
    "firmata": "firmato",
    "firmatari": "firmatario",
    "firmataria": "firmatario",
    "firmatarie": "firmatario",
    "firmate": "firmato",
    "firmati": "firmato",
    "firmato": "firmare",
    "firmava": "firmare",
    "firmavamo": "firmare",
    "firmavan": "firmare",
    "firmavano": "firmare",
    "firmavate": "firmare",
    "firmavi": "firmare",
    "firmavo": "firmare",
    "firme": "firma",
    "firmerai": "firmare",
    "firmeran": "firmare",
    "firmeranno": "firmare",
    "firmerebbe": "firmare",
    "firmerebber": "firmare",
    "firmerebbero": "firmare",
    "firmerei": "firmare",
    "firmeremmo": "firmare",
    "firmeremo": "firmare",
    "firmereste": "firmare",
    "firmeresti": "firmare",
    "firmerete": "firmare",
    "firmerà": "firmare",
    "firmerò": "firmare",
    "firmi": "firmare",
    "firmiamo": "firmare",
    "firmiate": "firmare",
    "firmin": "firmare",
    "firmino": "firmare",
    "firmo": "firmare",
    "firmò": "firmare",
    "fisa": "fiso",
    "fisarmoniche": "fisarmonica",
    "fiscali": "fiscale",
    "fiscalisti": "fiscalista",
    "fiscalizza": "fiscalizzare",
    "fiscalizzai": "fiscalizzare",
    "fiscalizzammo": "fiscalizzare",
    "fiscalizzan": "fiscalizzare",
    "fiscalizzando": "fiscalizzare",
    "fiscalizzano": "fiscalizzare",
    "fiscalizzante": "fiscalizzare",
    "fiscalizzanti": "fiscalizzare",
    "fiscalizzar": "fiscalizzare",
    "fiscalizzaron": "fiscalizzare",
    "fiscalizzarono": "fiscalizzare",
    "fiscalizzasse": "fiscalizzare",
    "fiscalizzasser": "fiscalizzare",
    "fiscalizzassero": "fiscalizzare",
    "fiscalizzassi": "fiscalizzare",
    "fiscalizzassimo": "fiscalizzare",
    "fiscalizzaste": "fiscalizzare",
    "fiscalizzasti": "fiscalizzare",
    "fiscalizzata": "fiscalizzare",
    "fiscalizzate": "fiscalizzare",
    "fiscalizzati": "fiscalizzare",
    "fiscalizzato": "fiscalizzare",
    "fiscalizzava": "fiscalizzare",
    "fiscalizzavamo": "fiscalizzare",
    "fiscalizzavan": "fiscalizzare",
    "fiscalizzavano": "fiscalizzare",
    "fiscalizzavate": "fiscalizzare",
    "fiscalizzavi": "fiscalizzare",
    "fiscalizzavo": "fiscalizzare",
    "fiscalizzazioni": "fiscalizzazione",
    "fiscalizzerai": "fiscalizzare",
    "fiscalizzeran": "fiscalizzare",
    "fiscalizzeranno": "fiscalizzare",
    "fiscalizzerebbe": "fiscalizzare",
    "fiscalizzerebber": "fiscalizzare",
    "fiscalizzerebbero": "fiscalizzare",
    "fiscalizzerei": "fiscalizzare",
    "fiscalizzeremmo": "fiscalizzare",
    "fiscalizzeremo": "fiscalizzare",
    "fiscalizzereste": "fiscalizzare",
    "fiscalizzeresti": "fiscalizzare",
    "fiscalizzerete": "fiscalizzare",
    "fiscalizzerà": "fiscalizzare",
    "fiscalizzerò": "fiscalizzare",
    "fiscalizzi": "fiscalizzare",
    "fiscalizziamo": "fiscalizzare",
    "fiscalizziate": "fiscalizzare",
    "fiscalizzin": "fiscalizzare",
    "fiscalizzino": "fiscalizzare",
    "fiscalizzo": "fiscalizzare",
    "fiscalizzò": "fiscalizzare",
    "fischi": "fisco",
    "fischia": "fischiare",
    "fischiai": "fischiare",
    "fischiammo": "fischiare",
    "fischiamo": "fischiare",
    "fischian": "fischiare",
    "fischiando": "fischiare",
    "fischiano": "fischiare",
    "fischiante": "fischiare",
    "fischianti": "fischiare",
    "fischiar": "fischiare",
    "fischiaron": "fischiare",
    "fischiarono": "fischiare",
    "fischiasse": "fischiare",
    "fischiasser": "fischiare",
    "fischiassero": "fischiare",
    "fischiassi": "fischiare",
    "fischiassimo": "fischiare",
    "fischiaste": "fischiare",
    "fischiasti": "fischiare",
    "fischiata": "fischiare",
    "fischiate": "fischiata",
    "fischiati": "fischiare",
    "fischiato": "fischiare",
    "fischiava": "fischiare",
    "fischiavamo": "fischiare",
    "fischiavan": "fischiare",
    "fischiavano": "fischiare",
    "fischiavate": "fischiare",
    "fischiavi": "fischiare",
    "fischiavo": "fischiare",
    "fischierai": "fischiare",
    "fischieran": "fischiare",
    "fischieranno": "fischiare",
    "fischierebbe": "fischiare",
    "fischierebber": "fischiare",
    "fischierebbero": "fischiare",
    "fischierei": "fischiare",
    "fischieremmo": "fischiare",
    "fischieremo": "fischiare",
    "fischiereste": "fischiare",
    "fischieresti": "fischiare",
    "fischierete": "fischiare",
    "fischierà": "fischiare",
    "fischierò": "fischiare",
    "fischietta": "fischiettare",
    "fischiettai": "fischiettare",
    "fischiettammo": "fischiettare",
    "fischiettan": "fischiettare",
    "fischiettando": "fischiettare",
    "fischiettano": "fischiettare",
    "fischiettante": "fischiettare",
    "fischiettanti": "fischiettare",
    "fischiettar": "fischiettare",
    "fischiettaron": "fischiettare",
    "fischiettarono": "fischiettare",
    "fischiettasse": "fischiettare",
    "fischiettasser": "fischiettare",
    "fischiettassero": "fischiettare",
    "fischiettassi": "fischiettare",
    "fischiettassimo": "fischiettare",
    "fischiettaste": "fischiettare",
    "fischiettasti": "fischiettare",
    "fischiettata": "fischiettare",
    "fischiettate": "fischiettare",
    "fischiettati": "fischiettare",
    "fischiettato": "fischiettare",
    "fischiettava": "fischiettare",
    "fischiettavamo": "fischiettare",
    "fischiettavan": "fischiettare",
    "fischiettavano": "fischiettare",
    "fischiettavate": "fischiettare",
    "fischiettavi": "fischiettare",
    "fischiettavo": "fischiettare",
    "fischietterai": "fischiettare",
    "fischietteran": "fischiettare",
    "fischietteranno": "fischiettare",
    "fischietterebbe": "fischiettare",
    "fischietterebber": "fischiettare",
    "fischietterebbero": "fischiettare",
    "fischietterei": "fischiettare",
    "fischietteremmo": "fischiettare",
    "fischietteremo": "fischiettare",
    "fischiettereste": "fischiettare",
    "fischietteresti": "fischiettare",
    "fischietterete": "fischiettare",
    "fischietterà": "fischiettare",
    "fischietterò": "fischiettare",
    "fischietti": "fischietto",
    "fischiettiamo": "fischiettare",
    "fischiettiate": "fischiettare",
    "fischiettin": "fischiettare",
    "fischiettino": "fischiettare",
    "fischietto": "fischiettare",
    "fischiettò": "fischiettare",
    "fischin": "fischiare",
    "fischino": "fischiare",
    "fischio": "fischiare",
    "fischiò": "fischiare",
    "fise": "fiso",
    "fisi": "fiso",
    "fisica": "fisico",
    "fisiche": "fisico",
    "fisici": "fisico",
    "fisiocratica": "fisiocratico",
    "fisiocratiche": "fisiocratico",
    "fisiocratici": "fisiocratico",
    "fisiognomiche": "fisiognomica",
    "fisiologi": "fisiologo",
    "fisiologica": "fisiologico",
    "fisiologiche": "fisiologico",
    "fisiologici": "fisiologico",
    "fisiologie": "fisiologia",
    "fisionomica": "fisionomico",
    "fisionomiche": "fisionomico",
    "fisionomici": "fisionomico",
    "fisionomie": "fisionomia",
    "fisioterapica": "fisioterapico",
    "fisioterapiche": "fisioterapico",
    "fisioterapici": "fisioterapico",
    "fisioterapie": "fisioterapia",
    "fisioterapisti": "fisioterapista",
    "fissa": "fisso",
    "fissai": "fissare",
    "fissammo": "fissare",
    "fissan": "fissare",
    "fissando": "fissare",
    "fissano": "fissare",
    "fissante": "fissare",
    "fissanti": "fissare",
    "fissar": "fissare",
    "fissaron": "fissare",
    "fissarono": "fissare",
    "fissasse": "fissare",
    "fissasser": "fissare",
    "fissassero": "fissare",
    "fissassi": "fissare",
    "fissassimo": "fissare",
    "fissaste": "fissare",
    "fissasti": "fissare",
    "fissata": "fissato",
    "fissate": "fissato",
    "fissati": "fissato",
    "fissato": "fissare",
    "fissava": "fissare",
    "fissavamo": "fissare",
    "fissavan": "fissare",
    "fissavano": "fissare",
    "fissavate": "fissare",
    "fissavi": "fissare",
    "fissavo": "fissare",
    "fissazioni": "fissazione",
    "fisse": "fisso",
    "fisser": "figgere",
    "fisserai": "fissare",
    "fisseran": "fissare",
    "fisseranno": "fissare",
    "fisserebbe": "fissare",
    "fisserebber": "fissare",
    "fisserebbero": "fissare",
    "fisserei": "fissare",
    "fisseremmo": "fissare",
    "fisseremo": "fissare",
    "fissereste": "fissare",
    "fisseresti": "fissare",
    "fisserete": "fissare",
    "fissero": "figgere",
    "fisserà": "fissare",
    "fisserò": "fissare",
    "fissi": "fisso",
    "fissiamo": "fissare",
    "fissiate": "fissare",
    "fissili": "fissile",
    "fissin": "fissare",
    "fissino": "fissare",
    "fissioni": "fissione",
    "fisso": "fissare",
    "fissè": "figgere",
    "fissò": "fissare",
    "fistole": "fistola",
    "fitofarmaci": "fitofarmaco",
    "fitta": "fitto",
    "fitte": "fitto",
    "fitti": "fitto",
    "fittili": "fittile",
    "fittizi": "fittizio",
    "fittizia": "fittizio",
    "fittizie": "fittizio",
    "fitto": "figgere",
    "fiumane": "fiumana",
    "fiumi": "fiume",
    "fiumiciattoli": "fiumiciattolo",
    "fiuta": "fiutare",
    "fiutai": "fiutare",
    "fiutammo": "fiutare",
    "fiutan": "fiutare",
    "fiutando": "fiutare",
    "fiutano": "fiutare",
    "fiutante": "fiutare",
    "fiutanti": "fiutare",
    "fiutar": "fiutare",
    "fiutaron": "fiutare",
    "fiutarono": "fiutare",
    "fiutasse": "fiutare",
    "fiutasser": "fiutare",
    "fiutassero": "fiutare",
    "fiutassi": "fiutare",
    "fiutassimo": "fiutare",
    "fiutaste": "fiutare",
    "fiutasti": "fiutare",
    "fiutata": "fiutare",
    "fiutate": "fiutare",
    "fiutati": "fiutare",
    "fiutato": "fiutare",
    "fiutava": "fiutare",
    "fiutavamo": "fiutare",
    "fiutavan": "fiutare",
    "fiutavano": "fiutare",
    "fiutavate": "fiutare",
    "fiutavi": "fiutare",
    "fiutavo": "fiutare",
    "fiuterai": "fiutare",
    "fiuteran": "fiutare",
    "fiuteranno": "fiutare",
    "fiuterebbe": "fiutare",
    "fiuterebber": "fiutare",
    "fiuterebbero": "fiutare",
    "fiuterei": "fiutare",
    "fiuteremmo": "fiutare",
    "fiuteremo": "fiutare",
    "fiutereste": "fiutare",
    "fiuteresti": "fiutare",
    "fiuterete": "fiutare",
    "fiuterà": "fiutare",
    "fiuterò": "fiutare",
    "fiuti": "fiuto",
    "fiutiamo": "fiutare",
    "fiutiate": "fiutare",
    "fiutin": "fiutare",
    "fiutino": "fiutare",
    "fiuto": "fiutare",
    "fiutò": "fiutare",
    "flaconcini": "flaconcino",
    "flaconi": "flacone",
    "flagella": "flagellare",
    "flagellai": "flagellare",
    "flagellammo": "flagellare",
    "flagellan": "flagellare",
    "flagellando": "flagellare",
    "flagellano": "flagellare",
    "flagellante": "flagellare",
    "flagellanti": "flagellare",
    "flagellar": "flagellare",
    "flagellaron": "flagellare",
    "flagellarono": "flagellare",
    "flagellasse": "flagellare",
    "flagellasser": "flagellare",
    "flagellassero": "flagellare",
    "flagellassi": "flagellare",
    "flagellassimo": "flagellare",
    "flagellaste": "flagellare",
    "flagellasti": "flagellare",
    "flagellata": "flagellare",
    "flagellate": "flagellare",
    "flagellati": "flagellare",
    "flagellato": "flagellare",
    "flagellava": "flagellare",
    "flagellavamo": "flagellare",
    "flagellavan": "flagellare",
    "flagellavano": "flagellare",
    "flagellavate": "flagellare",
    "flagellavi": "flagellare",
    "flagellavo": "flagellare",
    "flagellerai": "flagellare",
    "flagelleran": "flagellare",
    "flagelleranno": "flagellare",
    "flagellerebbe": "flagellare",
    "flagellerebber": "flagellare",
    "flagellerebbero": "flagellare",
    "flagellerei": "flagellare",
    "flagelleremmo": "flagellare",
    "flagelleremo": "flagellare",
    "flagellereste": "flagellare",
    "flagelleresti": "flagellare",
    "flagellerete": "flagellare",
    "flagellerà": "flagellare",
    "flagellerò": "flagellare",
    "flagelli": "flagello",
    "flagelliamo": "flagellare",
    "flagelliate": "flagellare",
    "flagellin": "flagellare",
    "flagellino": "flagellare",
    "flagello": "flagellare",
    "flagellò": "flagellare",
    "flagranti": "flagrante",
    "flamencos": "flamenco",
    "flanelle": "flanella",
    "flatulenze": "flatulenza",
    "flautata": "flautato",
    "flautate": "flautato",
    "flautati": "flautato",
    "flauti": "flauto",
    "flautisti": "flautista",
    "flebili": "flebile",
    "flemmatica": "flemmatico",
    "flemmatiche": "flemmatico",
    "flemmatici": "flemmatico",
    "flemme": "flemma",
    "flessibili": "flessibile",
    "flessibilizza": "flessibilizzare",
    "flessibilizzai": "flessibilizzare",
    "flessibilizzammo": "flessibilizzare",
    "flessibilizzan": "flessibilizzare",
    "flessibilizzando": "flessibilizzare",
    "flessibilizzano": "flessibilizzare",
    "flessibilizzante": "flessibilizzare",
    "flessibilizzanti": "flessibilizzare",
    "flessibilizzar": "flessibilizzare",
    "flessibilizzaron": "flessibilizzare",
    "flessibilizzarono": "flessibilizzare",
    "flessibilizzasse": "flessibilizzare",
    "flessibilizzasser": "flessibilizzare",
    "flessibilizzassero": "flessibilizzare",
    "flessibilizzassi": "flessibilizzare",
    "flessibilizzassimo": "flessibilizzare",
    "flessibilizzaste": "flessibilizzare",
    "flessibilizzasti": "flessibilizzare",
    "flessibilizzata": "flessibilizzare",
    "flessibilizzate": "flessibilizzare",
    "flessibilizzati": "flessibilizzare",
    "flessibilizzato": "flessibilizzare",
    "flessibilizzava": "flessibilizzare",
    "flessibilizzavamo": "flessibilizzare",
    "flessibilizzavan": "flessibilizzare",
    "flessibilizzavano": "flessibilizzare",
    "flessibilizzavate": "flessibilizzare",
    "flessibilizzavi": "flessibilizzare",
    "flessibilizzavo": "flessibilizzare",
    "flessibilizzerai": "flessibilizzare",
    "flessibilizzeran": "flessibilizzare",
    "flessibilizzeranno": "flessibilizzare",
    "flessibilizzerebbe": "flessibilizzare",
    "flessibilizzerebber": "flessibilizzare",
    "flessibilizzerebbero": "flessibilizzare",
    "flessibilizzerei": "flessibilizzare",
    "flessibilizzeremmo": "flessibilizzare",
    "flessibilizzeremo": "flessibilizzare",
    "flessibilizzereste": "flessibilizzare",
    "flessibilizzeresti": "flessibilizzare",
    "flessibilizzerete": "flessibilizzare",
    "flessibilizzerà": "flessibilizzare",
    "flessibilizzerò": "flessibilizzare",
    "flessibilizzi": "flessibilizzare",
    "flessibilizziamo": "flessibilizzare",
    "flessibilizziate": "flessibilizzare",
    "flessibilizzin": "flessibilizzare",
    "flessibilizzino": "flessibilizzare",
    "flessibilizzo": "flessibilizzare",
    "flessibilizzò": "flessibilizzare",
    "flessioni": "flessione",
    "flessori": "flessore",
    "flessuosa": "flessuoso",
    "flessuose": "flessuoso",
    "flessuosi": "flessuoso",
    "fletta": "flettere",
    "flettan": "flettere",
    "flettano": "flettere",
    "flette": "flettere",
    "flettei": "flettere",
    "flettemmo": "flettere",
    "flettendo": "flettere",
    "flettente": "flettere",
    "flettenti": "flettere",
    "fletter": "flettere",
    "fletterai": "flettere",
    "fletteran": "flettere",
    "fletteranno": "flettere",
    "fletterebbe": "flettere",
    "fletterebber": "flettere",
    "fletterebbero": "flettere",
    "fletterei": "flettere",
    "fletteremmo": "flettere",
    "fletteremo": "flettere",
    "flettereste": "flettere",
    "fletteresti": "flettere",
    "fletterete": "flettere",
    "fletteron": "flettere",
    "fletterono": "flettere",
    "fletterà": "flettere",
    "fletterò": "flettere",
    "flettesse": "flettere",
    "flettesser": "flettere",
    "flettessero": "flettere",
    "flettessi": "flettere",
    "flettessimo": "flettere",
    "fletteste": "flettere",
    "flettesti": "flettere",
    "flettete": "flettere",
    "fletteva": "flettere",
    "flettevamo": "flettere",
    "flettevan": "flettere",
    "flettevano": "flettere",
    "flettevate": "flettere",
    "flettevi": "flettere",
    "flettevo": "flettere",
    "fletti": "flettere",
    "flettiamo": "flettere",
    "flettiate": "flettere",
    "fletto": "flettere",
    "fletton": "flettere",
    "flettono": "flettere",
    "flettuta": "flettere",
    "flettute": "flettere",
    "flettuti": "flettere",
    "flettuto": "flettere",
    "flettè": "flettere",
    "flirta": "flirtare",
    "flirtai": "flirtare",
    "flirtammo": "flirtare",
    "flirtan": "flirtare",
    "flirtando": "flirtare",
    "flirtano": "flirtare",
    "flirtante": "flirtare",
    "flirtanti": "flirtare",
    "flirtar": "flirtare",
    "flirtaron": "flirtare",
    "flirtarono": "flirtare",
    "flirtasse": "flirtare",
    "flirtasser": "flirtare",
    "flirtassero": "flirtare",
    "flirtassi": "flirtare",
    "flirtassimo": "flirtare",
    "flirtaste": "flirtare",
    "flirtasti": "flirtare",
    "flirtata": "flirtare",
    "flirtate": "flirtare",
    "flirtati": "flirtare",
    "flirtato": "flirtare",
    "flirtava": "flirtare",
    "flirtavamo": "flirtare",
    "flirtavan": "flirtare",
    "flirtavano": "flirtare",
    "flirtavate": "flirtare",
    "flirtavi": "flirtare",
    "flirtavo": "flirtare",
    "flirterai": "flirtare",
    "flirteran": "flirtare",
    "flirteranno": "flirtare",
    "flirterebbe": "flirtare",
    "flirterebber": "flirtare",
    "flirterebbero": "flirtare",
    "flirterei": "flirtare",
    "flirteremmo": "flirtare",
    "flirteremo": "flirtare",
    "flirtereste": "flirtare",
    "flirteresti": "flirtare",
    "flirterete": "flirtare",
    "flirterà": "flirtare",
    "flirterò": "flirtare",
    "flirti": "flirtare",
    "flirtiamo": "flirtare",
    "flirtiate": "flirtare",
    "flirtin": "flirtare",
    "flirtino": "flirtare",
    "flirto": "flirtare",
    "flirtò": "flirtare",
    "flore": "flora",
    "floreali": "floreale",
    "florida": "florido",
    "floride": "florido",
    "floridi": "florido",
    "florilegi": "florilegio",
    "flosce": "floscio",
    "flosci": "floscio",
    "floscia": "floscio",
    "flotta": "flottare",
    "flottai": "flottare",
    "flottammo": "flottare",
    "flottan": "flottare",
    "flottando": "flottare",
    "flottano": "flottare",
    "flottante": "flottare",
    "flottanti": "flottare",
    "flottar": "flottare",
    "flottaron": "flottare",
    "flottarono": "flottare",
    "flottasse": "flottare",
    "flottasser": "flottare",
    "flottassero": "flottare",
    "flottassi": "flottare",
    "flottassimo": "flottare",
    "flottaste": "flottare",
    "flottasti": "flottare",
    "flottata": "flottare",
    "flottate": "flottare",
    "flottati": "flottare",
    "flottato": "flottare",
    "flottava": "flottare",
    "flottavamo": "flottare",
    "flottavan": "flottare",
    "flottavano": "flottare",
    "flottavate": "flottare",
    "flottavi": "flottare",
    "flottavo": "flottare",
    "flotte": "flotta",
    "flotterai": "flottare",
    "flotteran": "flottare",
    "flotteranno": "flottare",
    "flotterebbe": "flottare",
    "flotterebber": "flottare",
    "flotterebbero": "flottare",
    "flotterei": "flottare",
    "flotteremmo": "flottare",
    "flotteremo": "flottare",
    "flottereste": "flottare",
    "flotteresti": "flottare",
    "flotterete": "flottare",
    "flotterà": "flottare",
    "flotterò": "flottare",
    "flotti": "flottare",
    "flottiamo": "flottare",
    "flottiate": "flottare",
    "flottiglie": "flottiglia",
    "flottin": "flottare",
    "flottino": "flottare",
    "flotto": "flottare",
    "flottò": "flottare",
    "fluendo": "fluire",
    "fluente": "fluire",
    "fluenti": "fluire",
    "fluiamo": "fluire",
    "fluiate": "fluire",
    "fluida": "fluido",
    "fluide": "fluido",
    "fluidi": "fluido",
    "fluidifica": "fluidificare",
    "fluidificai": "fluidificare",
    "fluidificammo": "fluidificare",
    "fluidifican": "fluidificare",
    "fluidificando": "fluidificare",
    "fluidificano": "fluidificare",
    "fluidificante": "fluidificare",
    "fluidificanti": "fluidificare",
    "fluidificar": "fluidificare",
    "fluidificaron": "fluidificare",
    "fluidificarono": "fluidificare",
    "fluidificasse": "fluidificare",
    "fluidificasser": "fluidificare",
    "fluidificassero": "fluidificare",
    "fluidificassi": "fluidificare",
    "fluidificassimo": "fluidificare",
    "fluidificaste": "fluidificare",
    "fluidificasti": "fluidificare",
    "fluidificata": "fluidificare",
    "fluidificate": "fluidificare",
    "fluidificati": "fluidificare",
    "fluidificato": "fluidificare",
    "fluidificava": "fluidificare",
    "fluidificavamo": "fluidificare",
    "fluidificavan": "fluidificare",
    "fluidificavano": "fluidificare",
    "fluidificavate": "fluidificare",
    "fluidificavi": "fluidificare",
    "fluidificavo": "fluidificare",
    "fluidificherai": "fluidificare",
    "fluidificheran": "fluidificare",
    "fluidificheranno": "fluidificare",
    "fluidificherebbe": "fluidificare",
    "fluidificherebber": "fluidificare",
    "fluidificherebbero": "fluidificare",
    "fluidificherei": "fluidificare",
    "fluidificheremmo": "fluidificare",
    "fluidificheremo": "fluidificare",
    "fluidifichereste": "fluidificare",
    "fluidificheresti": "fluidificare",
    "fluidificherete": "fluidificare",
    "fluidificherà": "fluidificare",
    "fluidificherò": "fluidificare",
    "fluidifichi": "fluidificare",
    "fluidifichiamo": "fluidificare",
    "fluidifichiate": "fluidificare",
    "fluidifichin": "fluidificare",
    "fluidifichino": "fluidificare",
    "fluidifico": "fluidificare",
    "fluidificò": "fluidificare",
    "fluii": "fluire",
    "fluimmo": "fluire",
    "fluir": "fluire",
    "fluirai": "fluire",
    "fluiran": "fluire",
    "fluiranno": "fluire",
    "fluirebbe": "fluire",
    "fluirebber": "fluire",
    "fluirebbero": "fluire",
    "fluirei": "fluire",
    "fluiremmo": "fluire",
    "fluiremo": "fluire",
    "fluireste": "fluire",
    "fluiresti": "fluire",
    "fluirete": "fluire",
    "fluiron": "fluire",
    "fluirono": "fluire",
    "fluirà": "fluire",
    "fluirò": "fluire",
    "fluisca": "fluire",
    "fluiscan": "fluire",
    "fluiscano": "fluire",
    "fluisce": "fluire",
    "fluisci": "fluire",
    "fluisco": "fluire",
    "fluiscon": "fluire",
    "fluiscono": "fluire",
    "fluisse": "fluire",
    "fluisser": "fluire",
    "fluissero": "fluire",
    "fluissi": "fluire",
    "fluissimo": "fluire",
    "fluiste": "fluire",
    "fluisti": "fluire",
    "fluita": "fluire",
    "fluite": "fluire",
    "fluiti": "fluire",
    "fluito": "fluire",
    "fluiva": "fluire",
    "fluivamo": "fluire",
    "fluivan": "fluire",
    "fluivano": "fluire",
    "fluivate": "fluire",
    "fluivi": "fluire",
    "fluivo": "fluire",
    "fluorescenti": "fluorescente",
    "fluori": "fluoro",
    "fluoridrica": "fluoridrico",
    "fluoridriche": "fluoridrico",
    "fluoridrici": "fluoridrico",
    "flussi": "flusso",
    "flutti": "flutto",
    "fluttua": "fluttuare",
    "fluttuai": "fluttuare",
    "fluttuammo": "fluttuare",
    "fluttuan": "fluttuare",
    "fluttuando": "fluttuare",
    "fluttuano": "fluttuare",
    "fluttuante": "fluttuare",
    "fluttuanti": "fluttuare",
    "fluttuar": "fluttuare",
    "fluttuaron": "fluttuare",
    "fluttuarono": "fluttuare",
    "fluttuasse": "fluttuare",
    "fluttuasser": "fluttuare",
    "fluttuassero": "fluttuare",
    "fluttuassi": "fluttuare",
    "fluttuassimo": "fluttuare",
    "fluttuaste": "fluttuare",
    "fluttuasti": "fluttuare",
    "fluttuata": "fluttuare",
    "fluttuate": "fluttuare",
    "fluttuati": "fluttuare",
    "fluttuato": "fluttuare",
    "fluttuava": "fluttuare",
    "fluttuavamo": "fluttuare",
    "fluttuavan": "fluttuare",
    "fluttuavano": "fluttuare",
    "fluttuavate": "fluttuare",
    "fluttuavi": "fluttuare",
    "fluttuavo": "fluttuare",
    "fluttuazioni": "fluttuazione",
    "fluttuerai": "fluttuare",
    "fluttueran": "fluttuare",
    "fluttueranno": "fluttuare",
    "fluttuerebbe": "fluttuare",
    "fluttuerebber": "fluttuare",
    "fluttuerebbero": "fluttuare",
    "fluttuerei": "fluttuare",
    "fluttueremmo": "fluttuare",
    "fluttueremo": "fluttuare",
    "fluttuereste": "fluttuare",
    "fluttueresti": "fluttuare",
    "fluttuerete": "fluttuare",
    "fluttuerà": "fluttuare",
    "fluttuerò": "fluttuare",
    "fluttui": "fluttuare",
    "fluttuiamo": "fluttuare",
    "fluttuiate": "fluttuare",
    "fluttuin": "fluttuare",
    "fluttuino": "fluttuare",
    "fluttuo": "fluttuare",
    "fluttuò": "fluttuare",
    "fluviali": "fluviale",
    "fluì": "fluire",
    "fobica": "fobico",
    "fobiche": "fobico",
    "fobici": "fobico",
    "fobie": "fobia",
    "focacce": "focaccia",
    "focali": "focale",
    "focalizza": "focalizzare",
    "focalizzai": "focalizzare",
    "focalizzammo": "focalizzare",
    "focalizzan": "focalizzare",
    "focalizzando": "focalizzare",
    "focalizzano": "focalizzare",
    "focalizzante": "focalizzare",
    "focalizzanti": "focalizzare",
    "focalizzar": "focalizzare",
    "focalizzaron": "focalizzare",
    "focalizzarono": "focalizzare",
    "focalizzasse": "focalizzare",
    "focalizzasser": "focalizzare",
    "focalizzassero": "focalizzare",
    "focalizzassi": "focalizzare",
    "focalizzassimo": "focalizzare",
    "focalizzaste": "focalizzare",
    "focalizzasti": "focalizzare",
    "focalizzata": "focalizzare",
    "focalizzate": "focalizzare",
    "focalizzati": "focalizzare",
    "focalizzato": "focalizzare",
    "focalizzava": "focalizzare",
    "focalizzavamo": "focalizzare",
    "focalizzavan": "focalizzare",
    "focalizzavano": "focalizzare",
    "focalizzavate": "focalizzare",
    "focalizzavi": "focalizzare",
    "focalizzavo": "focalizzare",
    "focalizzerai": "focalizzare",
    "focalizzeran": "focalizzare",
    "focalizzeranno": "focalizzare",
    "focalizzerebbe": "focalizzare",
    "focalizzerebber": "focalizzare",
    "focalizzerebbero": "focalizzare",
    "focalizzerei": "focalizzare",
    "focalizzeremmo": "focalizzare",
    "focalizzeremo": "focalizzare",
    "focalizzereste": "focalizzare",
    "focalizzeresti": "focalizzare",
    "focalizzerete": "focalizzare",
    "focalizzerà": "focalizzare",
    "focalizzerò": "focalizzare",
    "focalizzi": "focalizzare",
    "focalizziamo": "focalizzare",
    "focalizziate": "focalizzare",
    "focalizzin": "focalizzare",
    "focalizzino": "focalizzare",
    "focalizzo": "focalizzare",
    "focalizzò": "focalizzare",
    "foche": "foca",
    "foci": "foce",
    "focolai": "focolaio",
    "focolari": "focolare",
    "focomelica": "focomelico",
    "focomeliche": "focomelico",
    "focomelici": "focomelico",
    "focosa": "focoso",
    "focose": "focoso",
    "focosi": "focoso",
    "fodera": "foderare",
    "foderai": "foderare",
    "foderammo": "foderare",
    "foderan": "foderare",
    "foderando": "foderare",
    "foderano": "foderare",
    "foderante": "foderare",
    "foderanti": "foderare",
    "foderar": "foderare",
    "foderaron": "foderare",
    "foderarono": "foderare",
    "foderasse": "foderare",
    "foderasser": "foderare",
    "foderassero": "foderare",
    "foderassi": "foderare",
    "foderassimo": "foderare",
    "foderaste": "foderare",
    "foderasti": "foderare",
    "foderata": "foderare",
    "foderate": "foderare",
    "foderati": "foderare",
    "foderato": "foderare",
    "foderava": "foderare",
    "foderavamo": "foderare",
    "foderavan": "foderare",
    "foderavano": "foderare",
    "foderavate": "foderare",
    "foderavi": "foderare",
    "foderavo": "foderare",
    "fodere": "fodera",
    "fodererai": "foderare",
    "fodereran": "foderare",
    "fodereranno": "foderare",
    "fodererebbe": "foderare",
    "fodererebber": "foderare",
    "fodererebbero": "foderare",
    "fodererei": "foderare",
    "fodereremmo": "foderare",
    "fodereremo": "foderare",
    "foderereste": "foderare",
    "fodereresti": "foderare",
    "fodererete": "foderare",
    "fodererà": "foderare",
    "fodererò": "foderare",
    "foderi": "fodero",
    "foderiamo": "foderare",
    "foderiate": "foderare",
    "foderin": "foderare",
    "foderino": "foderare",
    "fodero": "foderare",
    "foderò": "foderare",
    "fogge": "foggia",
    "foggerai": "foggiare",
    "foggeran": "foggiare",
    "foggeranno": "foggiare",
    "foggerebbe": "foggiare",
    "foggerebber": "foggiare",
    "foggerebbero": "foggiare",
    "foggerei": "foggiare",
    "foggeremmo": "foggiare",
    "foggeremo": "foggiare",
    "foggereste": "foggiare",
    "foggeresti": "foggiare",
    "foggerete": "foggiare",
    "foggerà": "foggiare",
    "foggerò": "foggiare",
    "foggi": "foggiare",
    "foggia": "foggiare",
    "foggiai": "foggiare",
    "foggiammo": "foggiare",
    "foggiamo": "foggiare",
    "foggian": "foggiare",
    "foggiando": "foggiare",
    "foggiani": "foggiano",
    "foggiano": "foggiare",
    "foggiante": "foggiare",
    "foggianti": "foggiare",
    "foggiar": "foggiare",
    "foggiaron": "foggiare",
    "foggiarono": "foggiare",
    "foggiasse": "foggiare",
    "foggiasser": "foggiare",
    "foggiassero": "foggiare",
    "foggiassi": "foggiare",
    "foggiassimo": "foggiare",
    "foggiaste": "foggiare",
    "foggiasti": "foggiare",
    "foggiata": "foggiare",
    "foggiate": "foggiare",
    "foggiati": "foggiare",
    "foggiato": "foggiare",
    "foggiava": "foggiare",
    "foggiavamo": "foggiare",
    "foggiavan": "foggiare",
    "foggiavano": "foggiare",
    "foggiavate": "foggiare",
    "foggiavi": "foggiare",
    "foggiavo": "foggiare",
    "foggin": "foggiare",
    "foggino": "foggiare",
    "foggio": "foggiare",
    "foggiò": "foggiare",
    "foghe": "foga",
    "fogli": "foglio",
    "foglia": "fogliare",
    "fogliacci": "fogliaccio",
    "fogliai": "fogliare",
    "fogliami": "fogliame",
    "fogliammo": "fogliare",
    "fogliamo": "fogliare",
    "foglian": "fogliare",
    "fogliando": "fogliare",
    "fogliano": "fogliare",
    "fogliante": "fogliare",
    "foglianti": "fogliare",
    "fogliar": "fogliare",
    "fogliaron": "fogliare",
    "fogliarono": "fogliare",
    "fogliasse": "fogliare",
    "fogliasser": "fogliare",
    "fogliassero": "fogliare",
    "fogliassi": "fogliare",
    "fogliassimo": "fogliare",
    "fogliaste": "fogliare",
    "fogliasti": "fogliare",
    "fogliata": "fogliare",
    "fogliate": "fogliare",
    "fogliati": "fogliare",
    "fogliato": "fogliare",
    "fogliava": "fogliare",
    "fogliavamo": "fogliare",
    "fogliavan": "fogliare",
    "fogliavano": "fogliare",
    "fogliavate": "fogliare",
    "fogliavi": "fogliare",
    "fogliavo": "fogliare",
    "foglie": "foglia",
    "foglierai": "fogliare",
    "foglieran": "fogliare",
    "foglieranno": "fogliare",
    "foglierebbe": "fogliare",
    "foglierebber": "fogliare",
    "foglierebbero": "fogliare",
    "foglierei": "fogliare",
    "foglieremmo": "fogliare",
    "foglieremo": "fogliare",
    "fogliereste": "fogliare",
    "foglieresti": "fogliare",
    "foglierete": "fogliare",
    "foglierà": "fogliare",
    "foglierò": "fogliare",
    "foglietti": "foglietto",
    "fogliettini": "fogliettino",
    "foglin": "fogliare",
    "foglino": "fogliare",
    "foglio": "fogliare",
    "foglioline": "fogliolina",
    "fogliò": "fogliare",
    "fogna": "fognare",
    "fognai": "fognare",
    "fognammo": "fognare",
    "fognan": "fognare",
    "fognando": "fognare",
    "fognano": "fognare",
    "fognante": "fognare",
    "fognanti": "fognare",
    "fognar": "fognare",
    "fognari": "fognario",
    "fognaria": "fognario",
    "fognarie": "fognario",
    "fognaron": "fognare",
    "fognarono": "fognare",
    "fognasse": "fognare",
    "fognasser": "fognare",
    "fognassero": "fognare",
    "fognassi": "fognare",
    "fognassimo": "fognare",
    "fognaste": "fognare",
    "fognasti": "fognare",
    "fognata": "fognare",
    "fognate": "fognare",
    "fognati": "fognare",
    "fognato": "fognare",
    "fognature": "fognatura",
    "fognava": "fognare",
    "fognavamo": "fognare",
    "fognavan": "fognare",
    "fognavano": "fognare",
    "fognavate": "fognare",
    "fognavi": "fognare",
    "fognavo": "fognare",
    "fogne": "fogna",
    "fognerai": "fognare",
    "fogneran": "fognare",
    "fogneranno": "fognare",
    "fognerebbe": "fognare",
    "fognerebber": "fognare",
    "fognerebbero": "fognare",
    "fognerei": "fognare",
    "fogneremmo": "fognare",
    "fogneremo": "fognare",
    "fognereste": "fognare",
    "fogneresti": "fognare",
    "fognerete": "fognare",
    "fognerà": "fognare",
    "fognerò": "fognare",
    "fogni": "fognare",
    "fogniamo": "fognare",
    "fogniate": "fognare",
    "fognin": "fognare",
    "fognino": "fognare",
    "fogno": "fognare",
    "fognò": "fognare",
    "foibe": "foiba",
    "folate": "folata",
    "folclori": "folclore",
    "folcloristica": "folcloristico",
    "folcloristiche": "folcloristico",
    "folcloristici": "folcloristico",
    "fole": "fola",
    "folgora": "folgorare",
    "folgorai": "folgorare",
    "folgorammo": "folgorare",
    "folgoran": "folgorare",
    "folgorando": "folgorare",
    "folgorano": "folgorare",
    "folgorante": "folgorare",
    "folgoranti": "folgorare",
    "folgorar": "folgorare",
    "folgoraron": "folgorare",
    "folgorarono": "folgorare",
    "folgorasse": "folgorare",
    "folgorasser": "folgorare",
    "folgorassero": "folgorare",
    "folgorassi": "folgorare",
    "folgorassimo": "folgorare",
    "folgoraste": "folgorare",
    "folgorasti": "folgorare",
    "folgorata": "folgorare",
    "folgorate": "folgorare",
    "folgorati": "folgorare",
    "folgorato": "folgorare",
    "folgorava": "folgorare",
    "folgoravamo": "folgorare",
    "folgoravan": "folgorare",
    "folgoravano": "folgorare",
    "folgoravate": "folgorare",
    "folgoravi": "folgorare",
    "folgoravo": "folgorare",
    "folgorazioni": "folgorazione",
    "folgorerai": "folgorare",
    "folgoreran": "folgorare",
    "folgoreranno": "folgorare",
    "folgorerebbe": "folgorare",
    "folgorerebber": "folgorare",
    "folgorerebbero": "folgorare",
    "folgorerei": "folgorare",
    "folgoreremmo": "folgorare",
    "folgoreremo": "folgorare",
    "folgorereste": "folgorare",
    "folgoreresti": "folgorare",
    "folgorerete": "folgorare",
    "folgorerà": "folgorare",
    "folgorerò": "folgorare",
    "folgori": "folgore",
    "folgoriamo": "folgorare",
    "folgoriate": "folgorare",
    "folgorin": "folgorare",
    "folgorino": "folgorare",
    "folgoro": "folgorare",
    "folgorò": "folgorare",
    "folklori": "folklore",
    "folla": "follare",
    "follai": "follare",
    "follammo": "follare",
    "follan": "follare",
    "follando": "follare",
    "follano": "follare",
    "follante": "follare",
    "follanti": "follare",
    "follar": "follare",
    "follaron": "follare",
    "follarono": "follare",
    "follasse": "follare",
    "follasser": "follare",
    "follassero": "follare",
    "follassi": "follare",
    "follassimo": "follare",
    "follaste": "follare",
    "follasti": "follare",
    "follata": "follare",
    "follate": "follare",
    "follati": "follare",
    "follato": "follare",
    "follava": "follare",
    "follavamo": "follare",
    "follavan": "follare",
    "follavano": "follare",
    "follavate": "follare",
    "follavi": "follare",
    "follavo": "follare",
    "folle": "folla",
    "folleggerai": "folleggiare",
    "folleggeran": "folleggiare",
    "folleggeranno": "folleggiare",
    "folleggerebbe": "folleggiare",
    "folleggerebber": "folleggiare",
    "folleggerebbero": "folleggiare",
    "folleggerei": "folleggiare",
    "folleggeremmo": "folleggiare",
    "folleggeremo": "folleggiare",
    "folleggereste": "folleggiare",
    "folleggeresti": "folleggiare",
    "folleggerete": "folleggiare",
    "folleggerà": "folleggiare",
    "folleggerò": "folleggiare",
    "folleggi": "folleggiare",
    "folleggia": "folleggiare",
    "folleggiai": "folleggiare",
    "folleggiammo": "folleggiare",
    "folleggiamo": "folleggiare",
    "folleggian": "folleggiare",
    "folleggiando": "folleggiare",
    "folleggiano": "folleggiare",
    "folleggiante": "folleggiare",
    "folleggianti": "folleggiare",
    "folleggiar": "folleggiare",
    "folleggiaron": "folleggiare",
    "folleggiarono": "folleggiare",
    "folleggiasse": "folleggiare",
    "folleggiasser": "folleggiare",
    "folleggiassero": "folleggiare",
    "folleggiassi": "folleggiare",
    "folleggiassimo": "folleggiare",
    "folleggiaste": "folleggiare",
    "folleggiasti": "folleggiare",
    "folleggiata": "folleggiare",
    "folleggiate": "folleggiare",
    "folleggiati": "folleggiare",
    "folleggiato": "folleggiare",
    "folleggiava": "folleggiare",
    "folleggiavamo": "folleggiare",
    "folleggiavan": "folleggiare",
    "folleggiavano": "folleggiare",
    "folleggiavate": "folleggiare",
    "folleggiavi": "folleggiare",
    "folleggiavo": "folleggiare",
    "folleggin": "folleggiare",
    "folleggino": "folleggiare",
    "folleggio": "folleggiare",
    "folleggiò": "folleggiare",
    "follerai": "follare",
    "folleran": "follare",
    "folleranno": "follare",
    "follerebbe": "follare",
    "follerebber": "follare",
    "follerebbero": "follare",
    "follerei": "follare",
    "folleremmo": "follare",
    "folleremo": "follare",
    "follereste": "follare",
    "folleresti": "follare",
    "follerete": "follare",
    "follerà": "follare",
    "follerò": "follare",
    "folletti": "folletto",
    "folli": "folle",
    "folliamo": "follare",
    "folliate": "follare",
    "follicoli": "follicolo",
    "follie": "follia",
    "follin": "follare",
    "follino": "follare",
    "follo": "follare",
    "follìe": "follìa",
    "follò": "follare",
    "folta": "folto",
    "folte": "folto",
    "folti": "folto",
    "fomenta": "fomentare",
    "fomentai": "fomentare",
    "fomentammo": "fomentare",
    "fomentan": "fomentare",
    "fomentando": "fomentare",
    "fomentano": "fomentare",
    "fomentante": "fomentare",
    "fomentanti": "fomentare",
    "fomentar": "fomentare",
    "fomentaron": "fomentare",
    "fomentarono": "fomentare",
    "fomentasse": "fomentare",
    "fomentasser": "fomentare",
    "fomentassero": "fomentare",
    "fomentassi": "fomentare",
    "fomentassimo": "fomentare",
    "fomentaste": "fomentare",
    "fomentasti": "fomentare",
    "fomentata": "fomentare",
    "fomentate": "fomentare",
    "fomentati": "fomentare",
    "fomentato": "fomentare",
    "fomentatori": "fomentatore",
    "fomentava": "fomentare",
    "fomentavamo": "fomentare",
    "fomentavan": "fomentare",
    "fomentavano": "fomentare",
    "fomentavate": "fomentare",
    "fomentavi": "fomentare",
    "fomentavo": "fomentare",
    "fomenterai": "fomentare",
    "fomenteran": "fomentare",
    "fomenteranno": "fomentare",
    "fomenterebbe": "fomentare",
    "fomenterebber": "fomentare",
    "fomenterebbero": "fomentare",
    "fomenterei": "fomentare",
    "fomenteremmo": "fomentare",
    "fomenteremo": "fomentare",
    "fomentereste": "fomentare",
    "fomenteresti": "fomentare",
    "fomenterete": "fomentare",
    "fomenterà": "fomentare",
    "fomenterò": "fomentare",
    "fomenti": "fomentare",
    "fomentiamo": "fomentare",
    "fomentiate": "fomentare",
    "fomentin": "fomentare",
    "fomentino": "fomentare",
    "fomento": "fomentare",
    "fomentò": "fomentare",
    "fonda": "fondere",
    "fondai": "fondare",
    "fondali": "fondale",
    "fondalini": "fondalino",
    "fondamenta": "fondamento",
    "fondamentali": "fondamentale",
    "fondamentalismi": "fondamentalismo",
    "fondamentalisti": "fondamentalista",
    "fondamenti": "fondamento",
    "fondammo": "fondare",
    "fondan": "fondere",
    "fondando": "fondare",
    "fondano": "fondere",
    "fondante": "fondare",
    "fondanti": "fondare",
    "fondar": "fondare",
    "fondaron": "fondare",
    "fondarono": "fondare",
    "fondasse": "fondare",
    "fondasser": "fondare",
    "fondassero": "fondare",
    "fondassi": "fondare",
    "fondassimo": "fondare",
    "fondaste": "fondare",
    "fondasti": "fondare",
    "fondata": "fondato",
    "fondate": "fondato",
    "fondati": "fondato",
    "fondato": "fondare",
    "fondatori": "fondatore",
    "fondatrici": "fondatrice",
    "fondava": "fondare",
    "fondavamo": "fondare",
    "fondavan": "fondare",
    "fondavano": "fondare",
    "fondavate": "fondare",
    "fondavi": "fondare",
    "fondavo": "fondare",
    "fondazioni": "fondazione",
    "fonde": "fondere",
    "fondelli": "fondello",
    "fondemmo": "fondere",
    "fondendo": "fondere",
    "fondente": "fondere",
    "fondenti": "fondere",
    "fonder": "fondere",
    "fonderai": "fondere",
    "fonderan": "fondere",
    "fonderanno": "fondere",
    "fonderebbe": "fondere",
    "fonderebber": "fondere",
    "fonderebbero": "fondere",
    "fonderei": "fondere",
    "fonderemmo": "fondere",
    "fonderemo": "fondere",
    "fondereste": "fondere",
    "fonderesti": "fondere",
    "fonderete": "fondere",
    "fonderie": "fonderia",
    "fonderà": "fondere",
    "fonderò": "fondere",
    "fondesse": "fondere",
    "fondesser": "fondere",
    "fondessero": "fondere",
    "fondessi": "fondere",
    "fondessimo": "fondere",
    "fondeste": "fondere",
    "fondesti": "fondere",
    "fondete": "fondere",
    "fondeva": "fondere",
    "fondevamo": "fondere",
    "fondevan": "fondere",
    "fondevano": "fondere",
    "fondevate": "fondere",
    "fondevi": "fondere",
    "fondevo": "fondere",
    "fondi": "fondo",
    "fondiamo": "fondere",
    "fondiari": "fondiario",
    "fondiaria": "fondiario",
    "fondiarie": "fondiario",
    "fondiate": "fondere",
    "fondin": "fondare",
    "fondine": "fondina",
    "fondino": "fondare",
    "fondiste": "fondista",
    "fondisti": "fondista",
    "fondo": "fondere",
    "fondon": "fondere",
    "fondono": "fondere",
    "fondò": "fondare",
    "fonetica": "fonetico",
    "fonetiche": "fonetico",
    "fonetici": "fonetico",
    "fonica": "fonico",
    "foniche": "fonico",
    "fonici": "fonico",
    "fonografica": "fonografico",
    "fonografiche": "fonografico",
    "fonografici": "fonografico",
    "fonogrammi": "fonogramma",
    "fontane": "fontana",
    "fontanelle": "fontanella",
    "fonti": "fonte",
    "fora": "forare",
    "foracchi": "foracchiare",
    "foracchia": "foracchiare",
    "foracchiai": "foracchiare",
    "foracchiammo": "foracchiare",
    "foracchiamo": "foracchiare",
    "foracchian": "foracchiare",
    "foracchiando": "foracchiare",
    "foracchiano": "foracchiare",
    "foracchiante": "foracchiare",
    "foracchianti": "foracchiare",
    "foracchiar": "foracchiare",
    "foracchiaron": "foracchiare",
    "foracchiarono": "foracchiare",
    "foracchiasse": "foracchiare",
    "foracchiasser": "foracchiare",
    "foracchiassero": "foracchiare",
    "foracchiassi": "foracchiare",
    "foracchiassimo": "foracchiare",
    "foracchiaste": "foracchiare",
    "foracchiasti": "foracchiare",
    "foracchiata": "foracchiare",
    "foracchiate": "foracchiare",
    "foracchiati": "foracchiare",
    "foracchiato": "foracchiare",
    "foracchiava": "foracchiare",
    "foracchiavamo": "foracchiare",
    "foracchiavan": "foracchiare",
    "foracchiavano": "foracchiare",
    "foracchiavate": "foracchiare",
    "foracchiavi": "foracchiare",
    "foracchiavo": "foracchiare",
    "foracchierai": "foracchiare",
    "foracchieran": "foracchiare",
    "foracchieranno": "foracchiare",
    "foracchierebbe": "foracchiare",
    "foracchierebber": "foracchiare",
    "foracchierebbero": "foracchiare",
    "foracchierei": "foracchiare",
    "foracchieremmo": "foracchiare",
    "foracchieremo": "foracchiare",
    "foracchiereste": "foracchiare",
    "foracchieresti": "foracchiare",
    "foracchierete": "foracchiare",
    "foracchierà": "foracchiare",
    "foracchierò": "foracchiare",
    "foracchin": "foracchiare",
    "foracchino": "foracchiare",
    "foracchio": "foracchiare",
    "foracchiò": "foracchiare",
    "foraggerai": "foraggiare",
    "foraggeran": "foraggiare",
    "foraggeranno": "foraggiare",
    "foraggerebbe": "foraggiare",
    "foraggerebber": "foraggiare",
    "foraggerebbero": "foraggiare",
    "foraggerei": "foraggiare",
    "foraggeremmo": "foraggiare",
    "foraggeremo": "foraggiare",
    "foraggereste": "foraggiare",
    "foraggeresti": "foraggiare",
    "foraggerete": "foraggiare",
    "foraggerà": "foraggiare",
    "foraggerò": "foraggiare",
    "foraggi": "foraggio",
    "foraggia": "foraggiare",
    "foraggiai": "foraggiare",
    "foraggiammo": "foraggiare",
    "foraggiamo": "foraggiare",
    "foraggian": "foraggiare",
    "foraggiando": "foraggiare",
    "foraggiano": "foraggiare",
    "foraggiante": "foraggiare",
    "foraggianti": "foraggiare",
    "foraggiar": "foraggiare",
    "foraggiaron": "foraggiare",
    "foraggiarono": "foraggiare",
    "foraggiasse": "foraggiare",
    "foraggiasser": "foraggiare",
    "foraggiassero": "foraggiare",
    "foraggiassi": "foraggiare",
    "foraggiassimo": "foraggiare",
    "foraggiaste": "foraggiare",
    "foraggiasti": "foraggiare",
    "foraggiata": "foraggiare",
    "foraggiate": "foraggiare",
    "foraggiati": "foraggiare",
    "foraggiato": "foraggiare",
    "foraggiava": "foraggiare",
    "foraggiavamo": "foraggiare",
    "foraggiavan": "foraggiare",
    "foraggiavano": "foraggiare",
    "foraggiavate": "foraggiare",
    "foraggiavi": "foraggiare",
    "foraggiavo": "foraggiare",
    "foraggin": "foraggiare",
    "foraggino": "foraggiare",
    "foraggio": "foraggiare",
    "foraggiò": "foraggiare",
    "forai": "forare",
    "forammo": "forare",
    "foran": "forare",
    "forando": "forare",
    "forano": "forare",
    "forante": "forare",
    "foranti": "forare",
    "forar": "forare",
    "foraron": "forare",
    "forarono": "forare",
    "forasse": "forare",
    "forasser": "forare",
    "forassero": "forare",
    "forassi": "forare",
    "forassimo": "forare",
    "foraste": "forare",
    "forasti": "forare",
    "forata": "forare",
    "forate": "forare",
    "forati": "forare",
    "forato": "forare",
    "forature": "foratura",
    "forava": "forare",
    "foravamo": "forare",
    "foravan": "forare",
    "foravano": "forare",
    "foravate": "forare",
    "foravi": "forare",
    "foravo": "forare",
    "forba": "forbire",
    "forban": "forbire",
    "forbano": "forbire",
    "forbe": "forbire",
    "forbendo": "forbire",
    "forbente": "forbire",
    "forbenti": "forbire",
    "forbi": "forbire",
    "forbiamo": "forbire",
    "forbiate": "forbire",
    "forbici": "forbice",
    "forbii": "forbire",
    "forbimmo": "forbire",
    "forbir": "forbire",
    "forbirai": "forbire",
    "forbiran": "forbire",
    "forbiranno": "forbire",
    "forbirebbe": "forbire",
    "forbirebber": "forbire",
    "forbirebbero": "forbire",
    "forbirei": "forbire",
    "forbiremmo": "forbire",
    "forbiremo": "forbire",
    "forbireste": "forbire",
    "forbiresti": "forbire",
    "forbirete": "forbire",
    "forbiron": "forbire",
    "forbirono": "forbire",
    "forbirà": "forbire",
    "forbirò": "forbire",
    "forbisse": "forbire",
    "forbisser": "forbire",
    "forbissero": "forbire",
    "forbissi": "forbire",
    "forbissimo": "forbire",
    "forbiste": "forbire",
    "forbisti": "forbire",
    "forbita": "forbito",
    "forbite": "forbito",
    "forbiti": "forbito",
    "forbito": "forbire",
    "forbiva": "forbire",
    "forbivamo": "forbire",
    "forbivan": "forbire",
    "forbivano": "forbire",
    "forbivate": "forbire",
    "forbivi": "forbire",
    "forbivo": "forbire",
    "forbo": "forbire",
    "forbon": "forbire",
    "forbono": "forbire",
    "forbì": "forbire",
    "forcaioli": "forcaiolo",
    "forcelle": "forcella",
    "forche": "forca",
    "forchette": "forchetta",
    "forchettoni": "forchettone",
    "forconi": "forcone",
    "forellini": "forellino",
    "forensi": "forense",
    "forerai": "forare",
    "foreran": "forare",
    "foreranno": "forare",
    "forerebbe": "forare",
    "forerebber": "forare",
    "forerebbero": "forare",
    "forerei": "forare",
    "foreremmo": "forare",
    "foreremo": "forare",
    "forereste": "forare",
    "foreresti": "forare",
    "forerete": "forare",
    "forerà": "forare",
    "forerò": "forare",
    "forestali": "forestale",
    "forestazioni": "forestazione",
    "foreste": "foresta",
    "foresterie": "foresteria",
    "forestieri": "forestiero",
    "forfettari": "forfettario",
    "forfettaria": "forfettario",
    "forfettarie": "forfettario",
    "forgerai": "forgiare",
    "forgeran": "forgiare",
    "forgeranno": "forgiare",
    "forgerebbe": "forgiare",
    "forgerebber": "forgiare",
    "forgerebbero": "forgiare",
    "forgerei": "forgiare",
    "forgeremmo": "forgiare",
    "forgeremo": "forgiare",
    "forgereste": "forgiare",
    "forgeresti": "forgiare",
    "forgerete": "forgiare",
    "forgerà": "forgiare",
    "forgerò": "forgiare",
    "forgi": "forgiare",
    "forgia": "forgiare",
    "forgiai": "forgiare",
    "forgiammo": "forgiare",
    "forgiamo": "forgiare",
    "forgian": "forgiare",
    "forgiando": "forgiare",
    "forgiano": "forgiare",
    "forgiante": "forgiare",
    "forgianti": "forgiare",
    "forgiar": "forgiare",
    "forgiaron": "forgiare",
    "forgiarono": "forgiare",
    "forgiasse": "forgiare",
    "forgiasser": "forgiare",
    "forgiassero": "forgiare",
    "forgiassi": "forgiare",
    "forgiassimo": "forgiare",
    "forgiaste": "forgiare",
    "forgiasti": "forgiare",
    "forgiata": "forgiare",
    "forgiate": "forgiare",
    "forgiati": "forgiare",
    "forgiato": "forgiare",
    "forgiava": "forgiare",
    "forgiavamo": "forgiare",
    "forgiavan": "forgiare",
    "forgiavano": "forgiare",
    "forgiavate": "forgiare",
    "forgiavi": "forgiare",
    "forgiavo": "forgiare",
    "forgin": "forgiare",
    "forgino": "forgiare",
    "forgio": "forgiare",
    "forgiò": "forgiare",
    "fori": "foro",
    "foriamo": "forare",
    "foriate": "forare",
    "foriera": "foriero",
    "foriere": "foriero",
    "forieri": "foriero",
    "forin": "forare",
    "forino": "forare",
    "forlaniana": "forlaniano",
    "forlaniane": "forlaniano",
    "forlaniani": "forlaniano",
    "forma": "formare",
    "formaggi": "formaggio",
    "formaggini": "formaggino",
    "formai": "formare",
    "formali": "formale",
    "formalismi": "formalismo",
    "formalisti": "formalista",
    "formalistica": "formalistico",
    "formalistiche": "formalistico",
    "formalistici": "formalistico",
    "formalizza": "formalizzare",
    "formalizzai": "formalizzare",
    "formalizzammo": "formalizzare",
    "formalizzan": "formalizzare",
    "formalizzando": "formalizzare",
    "formalizzano": "formalizzare",
    "formalizzante": "formalizzare",
    "formalizzanti": "formalizzare",
    "formalizzar": "formalizzare",
    "formalizzaron": "formalizzare",
    "formalizzarono": "formalizzare",
    "formalizzasse": "formalizzare",
    "formalizzasser": "formalizzare",
    "formalizzassero": "formalizzare",
    "formalizzassi": "formalizzare",
    "formalizzassimo": "formalizzare",
    "formalizzaste": "formalizzare",
    "formalizzasti": "formalizzare",
    "formalizzata": "formalizzare",
    "formalizzate": "formalizzare",
    "formalizzati": "formalizzare",
    "formalizzato": "formalizzare",
    "formalizzava": "formalizzare",
    "formalizzavamo": "formalizzare",
    "formalizzavan": "formalizzare",
    "formalizzavano": "formalizzare",
    "formalizzavate": "formalizzare",
    "formalizzavi": "formalizzare",
    "formalizzavo": "formalizzare",
    "formalizzazioni": "formalizzazione",
    "formalizzerai": "formalizzare",
    "formalizzeran": "formalizzare",
    "formalizzeranno": "formalizzare",
    "formalizzerebbe": "formalizzare",
    "formalizzerebber": "formalizzare",
    "formalizzerebbero": "formalizzare",
    "formalizzerei": "formalizzare",
    "formalizzeremmo": "formalizzare",
    "formalizzeremo": "formalizzare",
    "formalizzereste": "formalizzare",
    "formalizzeresti": "formalizzare",
    "formalizzerete": "formalizzare",
    "formalizzerà": "formalizzare",
    "formalizzerò": "formalizzare",
    "formalizzi": "formalizzare",
    "formalizziamo": "formalizzare",
    "formalizziate": "formalizzare",
    "formalizzin": "formalizzare",
    "formalizzino": "formalizzare",
    "formalizzo": "formalizzare",
    "formalizzò": "formalizzare",
    "formammo": "formare",
    "forman": "formare",
    "formando": "formare",
    "formano": "formare",
    "formante": "formare",
    "formanti": "formare",
    "formar": "formare",
    "formaron": "formare",
    "formarono": "formare",
    "formasse": "formare",
    "formasser": "formare",
    "formassero": "formare",
    "formassi": "formare",
    "formassimo": "formare",
    "formaste": "formare",
    "formasti": "formare",
    "formata": "formato",
    "formate": "formato",
    "formati": "formato",
    "formativa": "formativo",
    "formative": "formativo",
    "formativi": "formativo",
    "formato": "formare",
    "formatori": "formatore",
    "formava": "formare",
    "formavamo": "formare",
    "formavan": "formare",
    "formavano": "formare",
    "formavate": "formare",
    "formavi": "formare",
    "formavo": "formare",
    "formazioni": "formazione",
    "forme": "forma",
    "forme-partito": "forma-partito",
    "formelle": "formella",
    "formerai": "formare",
    "formeran": "formare",
    "formeranno": "formare",
    "formerebbe": "formare",
    "formerebber": "formare",
    "formerebbero": "formare",
    "formerei": "formare",
    "formeremmo": "formare",
    "formeremo": "formare",
    "formereste": "formare",
    "formeresti": "formare",
    "formerete": "formare",
    "formerà": "formare",
    "formerò": "formare",
    "formi": "formare",
    "formiamo": "formare",
    "formiate": "formare",
    "formica": "formico",
    "formicai": "formicaio",
    "formiche": "formico",
    "formichine": "formichina",
    "formici": "formico",
    "formicola": "formicolare",
    "formicolai": "formicolare",
    "formicolammo": "formicolare",
    "formicolan": "formicolare",
    "formicolando": "formicolare",
    "formicolano": "formicolare",
    "formicolante": "formicolare",
    "formicolanti": "formicolare",
    "formicolar": "formicolare",
    "formicolaron": "formicolare",
    "formicolarono": "formicolare",
    "formicolasse": "formicolare",
    "formicolasser": "formicolare",
    "formicolassero": "formicolare",
    "formicolassi": "formicolare",
    "formicolassimo": "formicolare",
    "formicolaste": "formicolare",
    "formicolasti": "formicolare",
    "formicolata": "formicolare",
    "formicolate": "formicolare",
    "formicolati": "formicolare",
    "formicolato": "formicolare",
    "formicolava": "formicolare",
    "formicolavamo": "formicolare",
    "formicolavan": "formicolare",
    "formicolavano": "formicolare",
    "formicolavate": "formicolare",
    "formicolavi": "formicolare",
    "formicolavo": "formicolare",
    "formicolerai": "formicolare",
    "formicoleran": "formicolare",
    "formicoleranno": "formicolare",
    "formicolerebbe": "formicolare",
    "formicolerebber": "formicolare",
    "formicolerebbero": "formicolare",
    "formicolerei": "formicolare",
    "formicoleremmo": "formicolare",
    "formicoleremo": "formicolare",
    "formicolereste": "formicolare",
    "formicoleresti": "formicolare",
    "formicolerete": "formicolare",
    "formicolerà": "formicolare",
    "formicolerò": "formicolare",
    "formicoli": "formicolare",
    "formicoliamo": "formicolare",
    "formicoliate": "formicolare",
    "formicolin": "formicolare",
    "formicolino": "formicolare",
    "formicolo": "formicolare",
    "formicolò": "formicolare",
    "formidabili": "formidabile",
    "formin": "formare",
    "formino": "formare",
    "formo": "formare",
    "formosa": "formoso",
    "formose": "formoso",
    "formosi": "formoso",
    "formula": "formulare",
    "formulai": "formulare",
    "formulammo": "formulare",
    "formulan": "formulare",
    "formulando": "formulare",
    "formulano": "formulare",
    "formulante": "formulare",
    "formulanti": "formulare",
    "formular": "formulare",
    "formulari": "formulario",
    "formularon": "formulare",
    "formularono": "formulare",
    "formulasse": "formulare",
    "formulasser": "formulare",
    "formulassero": "formulare",
    "formulassi": "formulare",
    "formulassimo": "formulare",
    "formulaste": "formulare",
    "formulasti": "formulare",
    "formulata": "formulare",
    "formulate": "formulare",
    "formulati": "formulare",
    "formulato": "formulare",
    "formulava": "formulare",
    "formulavamo": "formulare",
    "formulavan": "formulare",
    "formulavano": "formulare",
    "formulavate": "formulare",
    "formulavi": "formulare",
    "formulavo": "formulare",
    "formulazioni": "formulazione",
    "formule": "formula",
    "formulerai": "formulare",
    "formuleran": "formulare",
    "formuleranno": "formulare",
    "formulerebbe": "formulare",
    "formulerebber": "formulare",
    "formulerebbero": "formulare",
    "formulerei": "formulare",
    "formuleremmo": "formulare",
    "formuleremo": "formulare",
    "formulereste": "formulare",
    "formuleresti": "formulare",
    "formulerete": "formulare",
    "formulerà": "formulare",
    "formulerò": "formulare",
    "formulette": "formuletta",
    "formuli": "formulare",
    "formuliamo": "formulare",
    "formuliate": "formulare",
    "formulin": "formulare",
    "formulino": "formulare",
    "formulo": "formulare",
    "formulò": "formulare",
    "formò": "formare",
    "fornaci": "fornace",
    "fornai": "fornaio",
    "fornelli": "fornello",
    "fornendo": "fornire",
    "fornente": "fornire",
    "fornenti": "fornire",
    "forni": "forno",
    "forniamo": "fornire",
    "forniate": "fornire",
    "fornica": "fornicare",
    "fornicai": "fornicare",
    "fornicammo": "fornicare",
    "fornican": "fornicare",
    "fornicando": "fornicare",
    "fornicano": "fornicare",
    "fornicante": "fornicare",
    "fornicanti": "fornicare",
    "fornicar": "fornicare",
    "fornicaron": "fornicare",
    "fornicarono": "fornicare",
    "fornicasse": "fornicare",
    "fornicasser": "fornicare",
    "fornicassero": "fornicare",
    "fornicassi": "fornicare",
    "fornicassimo": "fornicare",
    "fornicaste": "fornicare",
    "fornicasti": "fornicare",
    "fornicata": "fornicare",
    "fornicate": "fornicare",
    "fornicati": "fornicare",
    "fornicato": "fornicare",
    "fornicava": "fornicare",
    "fornicavamo": "fornicare",
    "fornicavan": "fornicare",
    "fornicavano": "fornicare",
    "fornicavate": "fornicare",
    "fornicavi": "fornicare",
    "fornicavo": "fornicare",
    "fornicazioni": "fornicazione",
    "fornicherai": "fornicare",
    "fornicheran": "fornicare",
    "fornicheranno": "fornicare",
    "fornicherebbe": "fornicare",
    "fornicherebber": "fornicare",
    "fornicherebbero": "fornicare",
    "fornicherei": "fornicare",
    "fornicheremmo": "fornicare",
    "fornicheremo": "fornicare",
    "fornichereste": "fornicare",
    "fornicheresti": "fornicare",
    "fornicherete": "fornicare",
    "fornicherà": "fornicare",
    "fornicherò": "fornicare",
    "fornichi": "fornicare",
    "fornichiamo": "fornicare",
    "fornichiate": "fornicare",
    "fornichin": "fornicare",
    "fornichino": "fornicare",
    "fornico": "fornicare",
    "fornicò": "fornicare",
    "fornii": "fornire",
    "fornimmo": "fornire",
    "fornir": "fornire",
    "fornirai": "fornire",
    "forniran": "fornire",
    "forniranno": "fornire",
    "fornirebbe": "fornire",
    "fornirebber": "fornire",
    "fornirebbero": "fornire",
    "fornirei": "fornire",
    "forniremmo": "fornire",
    "forniremo": "fornire",
    "fornireste": "fornire",
    "forniresti": "fornire",
    "fornirete": "fornire",
    "forniron": "fornire",
    "fornirono": "fornire",
    "fornirà": "fornire",
    "fornirò": "fornire",
    "fornisca": "fornire",
    "forniscan": "fornire",
    "forniscano": "fornire",
    "fornisce": "fornire",
    "fornisci": "fornire",
    "fornisco": "fornire",
    "forniscon": "fornire",
    "forniscono": "fornire",
    "fornisse": "fornire",
    "fornisser": "fornire",
    "fornissero": "fornire",
    "fornissi": "fornire",
    "fornissimo": "fornire",
    "forniste": "fornire",
    "fornisti": "fornire",
    "fornita": "fornito",
    "fornite": "fornito",
    "forniti": "fornito",
    "fornito": "fornire",
    "fornitori": "fornitore",
    "fornitrice": "fornitore",
    "fornitrici": "fornitrice",
    "forniture": "fornitura",
    "forniva": "fornire",
    "fornivamo": "fornire",
    "fornivan": "fornire",
    "fornivano": "fornire",
    "fornivate": "fornire",
    "fornivi": "fornire",
    "fornivo": "fornire",
    "fornì": "fornire",
    "foro": "forare",
    "forsennata": "forsennato",
    "forsennate": "forsennato",
    "forsennati": "forsennato",
    "fortezze": "fortezza",
    "forti": "forte",
    "fortifica": "fortificare",
    "fortificai": "fortificare",
    "fortificammo": "fortificare",
    "fortifican": "fortificare",
    "fortificando": "fortificare",
    "fortificano": "fortificare",
    "fortificante": "fortificare",
    "fortificanti": "fortificare",
    "fortificar": "fortificare",
    "fortificaron": "fortificare",
    "fortificarono": "fortificare",
    "fortificasse": "fortificare",
    "fortificasser": "fortificare",
    "fortificassero": "fortificare",
    "fortificassi": "fortificare",
    "fortificassimo": "fortificare",
    "fortificaste": "fortificare",
    "fortificasti": "fortificare",
    "fortificata": "fortificare",
    "fortificate": "fortificare",
    "fortificati": "fortificare",
    "fortificato": "fortificare",
    "fortificava": "fortificare",
    "fortificavamo": "fortificare",
    "fortificavan": "fortificare",
    "fortificavano": "fortificare",
    "fortificavate": "fortificare",
    "fortificavi": "fortificare",
    "fortificavo": "fortificare",
    "fortificazioni": "fortificazione",
    "fortificherai": "fortificare",
    "fortificheran": "fortificare",
    "fortificheranno": "fortificare",
    "fortificherebbe": "fortificare",
    "fortificherebber": "fortificare",
    "fortificherebbero": "fortificare",
    "fortificherei": "fortificare",
    "fortificheremmo": "fortificare",
    "fortificheremo": "fortificare",
    "fortifichereste": "fortificare",
    "fortificheresti": "fortificare",
    "fortificherete": "fortificare",
    "fortificherà": "fortificare",
    "fortificherò": "fortificare",
    "fortifichi": "fortificare",
    "fortifichiamo": "fortificare",
    "fortifichiate": "fortificare",
    "fortifichin": "fortificare",
    "fortifichino": "fortificare",
    "fortifico": "fortificare",
    "fortificò": "fortificare",
    "fortilizi": "fortilizio",
    "fortini": "fortino",
    "fortuita": "fortuito",
    "fortuite": "fortuito",
    "fortuiti": "fortuito",
    "fortunali": "fortunale",
    "fortunata": "fortunato",
    "fortunate": "fortunato",
    "fortunati": "fortunato",
    "fortune": "fortuna",
    "fortunosa": "fortunoso",
    "fortunose": "fortunoso",
    "fortunosi": "fortunoso",
    "foruncoli": "foruncolo",
    "forvi": "forviare",
    "forvia": "forviare",
    "forviai": "forviare",
    "forviammo": "forviare",
    "forviamo": "forviare",
    "forvian": "forviare",
    "forviando": "forviare",
    "forviano": "forviare",
    "forviante": "forviare",
    "forvianti": "forviare",
    "forviar": "forviare",
    "forviaron": "forviare",
    "forviarono": "forviare",
    "forviasse": "forviare",
    "forviasser": "forviare",
    "forviassero": "forviare",
    "forviassi": "forviare",
    "forviassimo": "forviare",
    "forviaste": "forviare",
    "forviasti": "forviare",
    "forviata": "forviare",
    "forviate": "forviare",
    "forviati": "forviare",
    "forviato": "forviare",
    "forviava": "forviare",
    "forviavamo": "forviare",
    "forviavan": "forviare",
    "forviavano": "forviare",
    "forviavate": "forviare",
    "forviavi": "forviare",
    "forviavo": "forviare",
    "forvierai": "forviare",
    "forvieran": "forviare",
    "forvieranno": "forviare",
    "forvierebbe": "forviare",
    "forvierebber": "forviare",
    "forvierebbero": "forviare",
    "forvierei": "forviare",
    "forvieremmo": "forviare",
    "forvieremo": "forviare",
    "forviereste": "forviare",
    "forvieresti": "forviare",
    "forvierete": "forviare",
    "forvierà": "forviare",
    "forvierò": "forviare",
    "forvin": "forviare",
    "forvino": "forviare",
    "forvio": "forviare",
    "forviò": "forviare",
    "forza": "forzare",
    "forzai": "forzare",
    "forzammo": "forzare",
    "forzan": "forzare",
    "forzando": "forzare",
    "forzano": "forzare",
    "forzanovisti": "forzanovista",
    "forzante": "forzare",
    "forzanti": "forzare",
    "forzar": "forzare",
    "forzaron": "forzare",
    "forzarono": "forzare",
    "forzasse": "forzare",
    "forzasser": "forzare",
    "forzassero": "forzare",
    "forzassi": "forzare",
    "forzassimo": "forzare",
    "forzaste": "forzare",
    "forzasti": "forzare",
    "forzata": "forzato",
    "forzate": "forzato",
    "forzati": "forzato",
    "forzato": "forzare",
    "forzature": "forzatura",
    "forzava": "forzare",
    "forzavamo": "forzare",
    "forzavan": "forzare",
    "forzavano": "forzare",
    "forzavate": "forzare",
    "forzavi": "forzare",
    "forzavo": "forzare",
    "forze": "forza",
    "forze-lavoro": "forza-lavoro",
    "forzerai": "forzare",
    "forzeran": "forzare",
    "forzeranno": "forzare",
    "forzerebbe": "forzare",
    "forzerebber": "forzare",
    "forzerebbero": "forzare",
    "forzerei": "forzare",
    "forzeremmo": "forzare",
    "forzeremo": "forzare",
    "forzereste": "forzare",
    "forzeresti": "forzare",
    "forzerete": "forzare",
    "forzerà": "forzare",
    "forzerò": "forzare",
    "forzi": "forzare",
    "forziamo": "forzare",
    "forziate": "forzare",
    "forzieri": "forziere",
    "forzin": "forzare",
    "forzino": "forzare",
    "forzisti": "forzista",
    "forzo": "forzare",
    "forzosa": "forzoso",
    "forzose": "forzoso",
    "forzosi": "forzoso",
    "forzuta": "forzuto",
    "forzute": "forzuto",
    "forzuti": "forzuto",
    "forzò": "forzare",
    "forò": "forare",
    "fosca": "fosco",
    "fosche": "fosco",
    "foschi": "fosco",
    "foschie": "foschia",
    "fosforescenti": "fosforescente",
    "fosfori": "fosforo",
    "fossati": "fossato",
    "fosse": "fossa",
    "fosser": "essere",
    "fossero": "essere",
    "fossette": "fossetta",
    "fossi": "fosso",
    "fossili": "fossile",
    "fossilizza": "fossilizzare",
    "fossilizzai": "fossilizzare",
    "fossilizzammo": "fossilizzare",
    "fossilizzan": "fossilizzare",
    "fossilizzando": "fossilizzare",
    "fossilizzano": "fossilizzare",
    "fossilizzante": "fossilizzare",
    "fossilizzanti": "fossilizzare",
    "fossilizzar": "fossilizzare",
    "fossilizzaron": "fossilizzare",
    "fossilizzarono": "fossilizzare",
    "fossilizzasse": "fossilizzare",
    "fossilizzasser": "fossilizzare",
    "fossilizzassero": "fossilizzare",
    "fossilizzassi": "fossilizzare",
    "fossilizzassimo": "fossilizzare",
    "fossilizzaste": "fossilizzare",
    "fossilizzasti": "fossilizzare",
    "fossilizzata": "fossilizzare",
    "fossilizzate": "fossilizzare",
    "fossilizzati": "fossilizzare",
    "fossilizzato": "fossilizzare",
    "fossilizzava": "fossilizzare",
    "fossilizzavamo": "fossilizzare",
    "fossilizzavan": "fossilizzare",
    "fossilizzavano": "fossilizzare",
    "fossilizzavate": "fossilizzare",
    "fossilizzavi": "fossilizzare",
    "fossilizzavo": "fossilizzare",
    "fossilizzerai": "fossilizzare",
    "fossilizzeran": "fossilizzare",
    "fossilizzeranno": "fossilizzare",
    "fossilizzerebbe": "fossilizzare",
    "fossilizzerebber": "fossilizzare",
    "fossilizzerebbero": "fossilizzare",
    "fossilizzerei": "fossilizzare",
    "fossilizzeremmo": "fossilizzare",
    "fossilizzeremo": "fossilizzare",
    "fossilizzereste": "fossilizzare",
    "fossilizzeresti": "fossilizzare",
    "fossilizzerete": "fossilizzare",
    "fossilizzerà": "fossilizzare",
    "fossilizzerò": "fossilizzare",
    "fossilizzi": "fossilizzare",
    "fossilizziamo": "fossilizzare",
    "fossilizziate": "fossilizzare",
    "fossilizzin": "fossilizzare",
    "fossilizzino": "fossilizzare",
    "fossilizzo": "fossilizzare",
    "fossilizzò": "fossilizzare",
    "fossimo": "essere",
    "foste": "essere",
    "fosti": "essere",
    "fotocellule": "fotocellula",
    "fotocopi": "fotocopiare",
    "fotocopia": "fotocopiare",
    "fotocopiai": "fotocopiare",
    "fotocopiammo": "fotocopiare",
    "fotocopiamo": "fotocopiare",
    "fotocopian": "fotocopiare",
    "fotocopiando": "fotocopiare",
    "fotocopiano": "fotocopiare",
    "fotocopiante": "fotocopiare",
    "fotocopianti": "fotocopiare",
    "fotocopiar": "fotocopiare",
    "fotocopiaron": "fotocopiare",
    "fotocopiarono": "fotocopiare",
    "fotocopiasse": "fotocopiare",
    "fotocopiasser": "fotocopiare",
    "fotocopiassero": "fotocopiare",
    "fotocopiassi": "fotocopiare",
    "fotocopiassimo": "fotocopiare",
    "fotocopiaste": "fotocopiare",
    "fotocopiasti": "fotocopiare",
    "fotocopiata": "fotocopiare",
    "fotocopiate": "fotocopiare",
    "fotocopiati": "fotocopiare",
    "fotocopiato": "fotocopiare",
    "fotocopiatrici": "fotocopiatrice",
    "fotocopiava": "fotocopiare",
    "fotocopiavamo": "fotocopiare",
    "fotocopiavan": "fotocopiare",
    "fotocopiavano": "fotocopiare",
    "fotocopiavate": "fotocopiare",
    "fotocopiavi": "fotocopiare",
    "fotocopiavo": "fotocopiare",
    "fotocopie": "fotocopia",
    "fotocopierai": "fotocopiare",
    "fotocopieran": "fotocopiare",
    "fotocopieranno": "fotocopiare",
    "fotocopierebbe": "fotocopiare",
    "fotocopierebber": "fotocopiare",
    "fotocopierebbero": "fotocopiare",
    "fotocopierei": "fotocopiare",
    "fotocopieremmo": "fotocopiare",
    "fotocopieremo": "fotocopiare",
    "fotocopiereste": "fotocopiare",
    "fotocopieresti": "fotocopiare",
    "fotocopierete": "fotocopiare",
    "fotocopierà": "fotocopiare",
    "fotocopierò": "fotocopiare",
    "fotocopin": "fotocopiare",
    "fotocopino": "fotocopiare",
    "fotocopio": "fotocopiare",
    "fotocopiò": "fotocopiare",
    "fotoelettrica": "fotoelettrico",
    "fotoelettriche": "fotoelettrico",
    "fotoelettrici": "fotoelettrico",
    "fotogenica": "fotogenico",
    "fotogeniche": "fotogenico",
    "fotogenici": "fotogenico",
    "fotografa": "fotografare",
    "fotografai": "fotografare",
    "fotografammo": "fotografare",
    "fotografan": "fotografare",
    "fotografando": "fotografare",
    "fotografano": "fotografare",
    "fotografante": "fotografare",
    "fotografanti": "fotografare",
    "fotografar": "fotografare",
    "fotografaron": "fotografare",
    "fotografarono": "fotografare",
    "fotografasse": "fotografare",
    "fotografasser": "fotografare",
    "fotografassero": "fotografare",
    "fotografassi": "fotografare",
    "fotografassimo": "fotografare",
    "fotografaste": "fotografare",
    "fotografasti": "fotografare",
    "fotografata": "fotografare",
    "fotografate": "fotografare",
    "fotografati": "fotografare",
    "fotografato": "fotografare",
    "fotografava": "fotografare",
    "fotografavamo": "fotografare",
    "fotografavan": "fotografare",
    "fotografavano": "fotografare",
    "fotografavate": "fotografare",
    "fotografavi": "fotografare",
    "fotografavo": "fotografare",
    "fotografe": "fotografa",
    "fotograferai": "fotografare",
    "fotograferan": "fotografare",
    "fotograferanno": "fotografare",
    "fotograferebbe": "fotografare",
    "fotograferebber": "fotografare",
    "fotograferebbero": "fotografare",
    "fotograferei": "fotografare",
    "fotograferemmo": "fotografare",
    "fotograferemo": "fotografare",
    "fotografereste": "fotografare",
    "fotograferesti": "fotografare",
    "fotograferete": "fotografare",
    "fotograferà": "fotografare",
    "fotograferò": "fotografare",
    "fotografi": "fotografo",
    "fotografiamo": "fotografare",
    "fotografiate": "fotografare",
    "fotografica": "fotografico",
    "fotografiche": "fotografico",
    "fotografici": "fotografico",
    "fotografie": "fotografia",
    "fotografin": "fotografare",
    "fotografino": "fotografare",
    "fotografo": "fotografare",
    "fotografò": "fotografare",
    "fotogrammetrica": "fotogrammetrico",
    "fotogrammetriche": "fotogrammetrico",
    "fotogrammetrici": "fotogrammetrico",
    "fotogrammi": "fotogramma",
    "fotomodelle": "fotomodella",
    "fotomontaggi": "fotomontaggio",
    "fotoni": "fotone",
    "fotoromanzi": "fotoromanzo",
    "fotostatica": "fotostatico",
    "fotostatiche": "fotostatico",
    "fotostatici": "fotostatico",
    "fotovoltaica": "fotovoltaico",
    "fotovoltaiche": "fotovoltaico",
    "fotovoltaici": "fotovoltaico",
    "fotta": "fottere",
    "fottan": "fottere",
    "fottano": "fottere",
    "fotte": "fottere",
    "fottei": "fottere",
    "fottemmo": "fottere",
    "fottendo": "fottere",
    "fottente": "fottere",
    "fottenti": "fottere",
    "fotter": "fottere",
    "fotterai": "fottere",
    "fotteran": "fottere",
    "fotteranno": "fottere",
    "fotterebbe": "fottere",
    "fotterebber": "fottere",
    "fotterebbero": "fottere",
    "fotterei": "fottere",
    "fotteremmo": "fottere",
    "fotteremo": "fottere",
    "fottereste": "fottere",
    "fotteresti": "fottere",
    "fotterete": "fottere",
    "fotteron": "fottere",
    "fotterono": "fottere",
    "fotterà": "fottere",
    "fotterò": "fottere",
    "fottesse": "fottere",
    "fottesser": "fottere",
    "fottessero": "fottere",
    "fottessi": "fottere",
    "fottessimo": "fottere",
    "fotteste": "fottere",
    "fottesti": "fottere",
    "fottete": "fottere",
    "fotteva": "fottere",
    "fottevamo": "fottere",
    "fottevan": "fottere",
    "fottevano": "fottere",
    "fottevate": "fottere",
    "fottevi": "fottere",
    "fottevo": "fottere",
    "fotti": "fottere",
    "fottiamo": "fottere",
    "fottiate": "fottere",
    "fotto": "fottere",
    "fotton": "fottere",
    "fottono": "fottere",
    "fottuta": "fottere",
    "fottute": "fottere",
    "fottuti": "fottere",
    "fottuto": "fottere",
    "fottè": "fottere",
    "fracassa": "fracassare",
    "fracassai": "fracassare",
    "fracassammo": "fracassare",
    "fracassan": "fracassare",
    "fracassando": "fracassare",
    "fracassano": "fracassare",
    "fracassante": "fracassare",
    "fracassanti": "fracassare",
    "fracassar": "fracassare",
    "fracassaron": "fracassare",
    "fracassarono": "fracassare",
    "fracassasse": "fracassare",
    "fracassasser": "fracassare",
    "fracassassero": "fracassare",
    "fracassassi": "fracassare",
    "fracassassimo": "fracassare",
    "fracassaste": "fracassare",
    "fracassasti": "fracassare",
    "fracassata": "fracassare",
    "fracassate": "fracassare",
    "fracassati": "fracassare",
    "fracassato": "fracassare",
    "fracassava": "fracassare",
    "fracassavamo": "fracassare",
    "fracassavan": "fracassare",
    "fracassavano": "fracassare",
    "fracassavate": "fracassare",
    "fracassavi": "fracassare",
    "fracassavo": "fracassare",
    "fracasserai": "fracassare",
    "fracasseran": "fracassare",
    "fracasseranno": "fracassare",
    "fracasserebbe": "fracassare",
    "fracasserebber": "fracassare",
    "fracasserebbero": "fracassare",
    "fracasserei": "fracassare",
    "fracasseremmo": "fracassare",
    "fracasseremo": "fracassare",
    "fracassereste": "fracassare",
    "fracasseresti": "fracassare",
    "fracasserete": "fracassare",
    "fracasserà": "fracassare",
    "fracasserò": "fracassare",
    "fracassi": "fracasso",
    "fracassiamo": "fracassare",
    "fracassiate": "fracassare",
    "fracassin": "fracassare",
    "fracassino": "fracassare",
    "fracasso": "fracassare",
    "fracassò": "fracassare",
    "fradice": "fradicio",
    "fradici": "fradicio",
    "fradicia": "fradicio",
    "fragili": "fragile",
    "fragole": "fragola",
    "fragori": "fragore",
    "fragorosa": "fragoroso",
    "fragorose": "fragoroso",
    "fragorosi": "fragoroso",
    "fragranti": "fragrante",
    "fragranze": "fragranza",
    "fraintenda": "fraintendere",
    "fraintendan": "fraintendere",
    "fraintendano": "fraintendere",
    "fraintende": "fraintendere",
    "fraintendemmo": "fraintendere",
    "fraintendendo": "fraintendere",
    "fraintendente": "fraintendere",
    "fraintendenti": "fraintendere",
    "fraintender": "fraintendere",
    "fraintenderai": "fraintendere",
    "fraintenderan": "fraintendere",
    "fraintenderanno": "fraintendere",
    "fraintenderebbe": "fraintendere",
    "fraintenderebber": "fraintendere",
    "fraintenderebbero": "fraintendere",
    "fraintenderei": "fraintendere",
    "fraintenderemmo": "fraintendere",
    "fraintenderemo": "fraintendere",
    "fraintendereste": "fraintendere",
    "fraintenderesti": "fraintendere",
    "fraintenderete": "fraintendere",
    "fraintenderà": "fraintendere",
    "fraintenderò": "fraintendere",
    "fraintendesse": "fraintendere",
    "fraintendesser": "fraintendere",
    "fraintendessero": "fraintendere",
    "fraintendessi": "fraintendere",
    "fraintendessimo": "fraintendere",
    "fraintendeste": "fraintendere",
    "fraintendesti": "fraintendere",
    "fraintendete": "fraintendere",
    "fraintendeva": "fraintendere",
    "fraintendevamo": "fraintendere",
    "fraintendevan": "fraintendere",
    "fraintendevano": "fraintendere",
    "fraintendevate": "fraintendere",
    "fraintendevi": "fraintendere",
    "fraintendevo": "fraintendere",
    "fraintendi": "fraintendere",
    "fraintendiamo": "fraintendere",
    "fraintendiate": "fraintendere",
    "fraintendimenti": "fraintendimento",
    "fraintendo": "fraintendere",
    "fraintendon": "fraintendere",
    "fraintendono": "fraintendere",
    "fraintesa": "fraintendere",
    "fraintese": "fraintendere",
    "frainteser": "fraintendere",
    "fraintesero": "fraintendere",
    "fraintesi": "fraintendere",
    "frainteso": "fraintendere",
    "fraintesè": "fraintendere",
    "frammenta": "frammentare",
    "frammentai": "frammentare",
    "frammentammo": "frammentare",
    "frammentan": "frammentare",
    "frammentando": "frammentare",
    "frammentano": "frammentare",
    "frammentante": "frammentare",
    "frammentanti": "frammentare",
    "frammentar": "frammentare",
    "frammentari": "frammentario",
    "frammentaria": "frammentario",
    "frammentarie": "frammentario",
    "frammentaron": "frammentare",
    "frammentarono": "frammentare",
    "frammentasse": "frammentare",
    "frammentasser": "frammentare",
    "frammentassero": "frammentare",
    "frammentassi": "frammentare",
    "frammentassimo": "frammentare",
    "frammentaste": "frammentare",
    "frammentasti": "frammentare",
    "frammentata": "frammentare",
    "frammentate": "frammentare",
    "frammentati": "frammentare",
    "frammentato": "frammentare",
    "frammentava": "frammentare",
    "frammentavamo": "frammentare",
    "frammentavan": "frammentare",
    "frammentavano": "frammentare",
    "frammentavate": "frammentare",
    "frammentavi": "frammentare",
    "frammentavo": "frammentare",
    "frammentazioni": "frammentazione",
    "frammenterai": "frammentare",
    "frammenteran": "frammentare",
    "frammenteranno": "frammentare",
    "frammenterebbe": "frammentare",
    "frammenterebber": "frammentare",
    "frammenterebbero": "frammentare",
    "frammenterei": "frammentare",
    "frammenteremmo": "frammentare",
    "frammenteremo": "frammentare",
    "frammentereste": "frammentare",
    "frammenteresti": "frammentare",
    "frammenterete": "frammentare",
    "frammenterà": "frammentare",
    "frammenterò": "frammentare",
    "frammenti": "frammento",
    "frammentiamo": "frammentare",
    "frammentiate": "frammentare",
    "frammentin": "frammentare",
    "frammentino": "frammentare",
    "frammento": "frammentare",
    "frammentò": "frammentare",
    "frammetta": "frammettere",
    "frammettan": "frammettere",
    "frammettano": "frammettere",
    "frammette": "frammettere",
    "frammettei": "frammettere",
    "frammettemmo": "frammettere",
    "frammettendo": "frammettere",
    "frammettente": "frammettere",
    "frammettenti": "frammettere",
    "frammetter": "frammettere",
    "frammetterai": "frammettere",
    "frammetteran": "frammettere",
    "frammetteranno": "frammettere",
    "frammetterebbe": "frammettere",
    "frammetterebber": "frammettere",
    "frammetterebbero": "frammettere",
    "frammetterei": "frammettere",
    "frammetteremmo": "frammettere",
    "frammetteremo": "frammettere",
    "frammettereste": "frammettere",
    "frammetteresti": "frammettere",
    "frammetterete": "frammettere",
    "frammetteron": "frammettere",
    "frammetterono": "frammettere",
    "frammetterà": "frammettere",
    "frammetterò": "frammettere",
    "frammettesse": "frammettere",
    "frammettesser": "frammettere",
    "frammettessero": "frammettere",
    "frammettessi": "frammettere",
    "frammettessimo": "frammettere",
    "frammetteste": "frammettere",
    "frammettesti": "frammettere",
    "frammettete": "frammettere",
    "frammetteva": "frammettere",
    "frammettevamo": "frammettere",
    "frammettevan": "frammettere",
    "frammettevano": "frammettere",
    "frammettevate": "frammettere",
    "frammettevi": "frammettere",
    "frammettevo": "frammettere",
    "frammetti": "frammettere",
    "frammettiamo": "frammettere",
    "frammettiate": "frammettere",
    "frammetto": "frammettere",
    "frammetton": "frammettere",
    "frammettono": "frammettere",
    "frammettuta": "frammettere",
    "frammettute": "frammettere",
    "frammettuti": "frammettere",
    "frammettuto": "frammettere",
    "frammettè": "frammettere",
    "frammezza": "frammezzare",
    "frammezzai": "frammezzare",
    "frammezzammo": "frammezzare",
    "frammezzan": "frammezzare",
    "frammezzando": "frammezzare",
    "frammezzano": "frammezzare",
    "frammezzante": "frammezzare",
    "frammezzanti": "frammezzare",
    "frammezzar": "frammezzare",
    "frammezzaron": "frammezzare",
    "frammezzarono": "frammezzare",
    "frammezzasse": "frammezzare",
    "frammezzasser": "frammezzare",
    "frammezzassero": "frammezzare",
    "frammezzassi": "frammezzare",
    "frammezzassimo": "frammezzare",
    "frammezzaste": "frammezzare",
    "frammezzasti": "frammezzare",
    "frammezzata": "frammezzare",
    "frammezzate": "frammezzare",
    "frammezzati": "frammezzare",
    "frammezzato": "frammezzare",
    "frammezzava": "frammezzare",
    "frammezzavamo": "frammezzare",
    "frammezzavan": "frammezzare",
    "frammezzavano": "frammezzare",
    "frammezzavate": "frammezzare",
    "frammezzavi": "frammezzare",
    "frammezzavo": "frammezzare",
    "frammezzerai": "frammezzare",
    "frammezzeran": "frammezzare",
    "frammezzeranno": "frammezzare",
    "frammezzerebbe": "frammezzare",
    "frammezzerebber": "frammezzare",
    "frammezzerebbero": "frammezzare",
    "frammezzerei": "frammezzare",
    "frammezzeremmo": "frammezzare",
    "frammezzeremo": "frammezzare",
    "frammezzereste": "frammezzare",
    "frammezzeresti": "frammezzare",
    "frammezzerete": "frammezzare",
    "frammezzerà": "frammezzare",
    "frammezzerò": "frammezzare",
    "frammezzi": "frammezzare",
    "frammezziamo": "frammezzare",
    "frammezziate": "frammezzare",
    "frammezzin": "frammezzare",
    "frammezzino": "frammezzare",
    "frammezzo": "frammezzare",
    "frammezzò": "frammezzare",
    "frammischi": "frammischiare",
    "frammischia": "frammischiare",
    "frammischiai": "frammischiare",
    "frammischiammo": "frammischiare",
    "frammischiamo": "frammischiare",
    "frammischian": "frammischiare",
    "frammischiando": "frammischiare",
    "frammischiano": "frammischiare",
    "frammischiante": "frammischiare",
    "frammischianti": "frammischiare",
    "frammischiar": "frammischiare",
    "frammischiaron": "frammischiare",
    "frammischiarono": "frammischiare",
    "frammischiasse": "frammischiare",
    "frammischiasser": "frammischiare",
    "frammischiassero": "frammischiare",
    "frammischiassi": "frammischiare",
    "frammischiassimo": "frammischiare",
    "frammischiaste": "frammischiare",
    "frammischiasti": "frammischiare",
    "frammischiata": "frammischiare",
    "frammischiate": "frammischiare",
    "frammischiati": "frammischiare",
    "frammischiato": "frammischiare",
    "frammischiava": "frammischiare",
    "frammischiavamo": "frammischiare",
    "frammischiavan": "frammischiare",
    "frammischiavano": "frammischiare",
    "frammischiavate": "frammischiare",
    "frammischiavi": "frammischiare",
    "frammischiavo": "frammischiare",
    "frammischierai": "frammischiare",
    "frammischieran": "frammischiare",
    "frammischieranno": "frammischiare",
    "frammischierebbe": "frammischiare",
    "frammischierebber": "frammischiare",
    "frammischierebbero": "frammischiare",
    "frammischierei": "frammischiare",
    "frammischieremmo": "frammischiare",
    "frammischieremo": "frammischiare",
    "frammischiereste": "frammischiare",
    "frammischieresti": "frammischiare",
    "frammischierete": "frammischiare",
    "frammischierà": "frammischiare",
    "frammischierò": "frammischiare",
    "frammischin": "frammischiare",
    "frammischino": "frammischiare",
    "frammischio": "frammischiare",
    "frammischiò": "frammischiare",
    "frammista": "frammisto",
    "frammiste": "frammisto",
    "frammisti": "frammisto",
    "frana": "franare",
    "franai": "franare",
    "franammo": "franare",
    "franan": "franare",
    "franando": "franare",
    "franano": "franare",
    "franante": "franare",
    "frananti": "franare",
    "franar": "franare",
    "franaron": "franare",
    "franarono": "franare",
    "franasse": "franare",
    "franasser": "franare",
    "franassero": "franare",
    "franassi": "franare",
    "franassimo": "franare",
    "franaste": "franare",
    "franasti": "franare",
    "franata": "franare",
    "franate": "franare",
    "franati": "franare",
    "franato": "franare",
    "franava": "franare",
    "franavamo": "franare",
    "franavan": "franare",
    "franavano": "franare",
    "franavate": "franare",
    "franavi": "franare",
    "franavo": "franare",
    "franca": "franco",
    "francai": "francare",
    "francammo": "francare",
    "francan": "francare",
    "francando": "francare",
    "francano": "francare",
    "francante": "francare",
    "francanti": "francare",
    "francar": "francare",
    "francaron": "francare",
    "francarono": "francare",
    "francasse": "francare",
    "francasser": "francare",
    "francassero": "francare",
    "francassi": "francare",
    "francassimo": "francare",
    "francaste": "francare",
    "francasti": "francare",
    "francata": "francare",
    "francate": "francare",
    "francati": "francare",
    "francato": "francare",
    "francava": "francare",
    "francavamo": "francare",
    "francavan": "francare",
    "francavano": "francare",
    "francavate": "francare",
    "francavi": "francare",
    "francavo": "francare",
    "francescana": "francescano",
    "francescane": "francescano",
    "francescani": "francescano",
    "francesi": "francese",
    "franche": "franco",
    "francherai": "francare",
    "francheran": "francare",
    "francheranno": "francare",
    "francherebbe": "francare",
    "francherebber": "francare",
    "francherebbero": "francare",
    "francherei": "francare",
    "francheremmo": "francare",
    "francheremo": "francare",
    "franchereste": "francare",
    "francheresti": "francare",
    "francherete": "francare",
    "francherà": "francare",
    "francherò": "francare",
    "franchezze": "franchezza",
    "franchi": "franco",
    "franchiamo": "francare",
    "franchiate": "francare",
    "franchigie": "franchigia",
    "franchin": "francare",
    "franchino": "francare",
    "franchismi": "franchismo",
    "franchisti": "franchista",
    "franco": "francare",
    "franco-britannica": "franco-britannico",
    "franco-britanniche": "franco-britannico",
    "franco-britannici": "franco-britannico",
    "franco-iraniana": "franco-iraniano",
    "franco-iraniane": "franco-iraniano",
    "franco-iraniani": "franco-iraniano",
    "franco-tedesca": "franco-tedesco",
    "franco-tedesche": "franco-tedesco",
    "franco-tedeschi": "franco-tedesco",
    "francobolli": "francobollo",
    "francofona": "francofono",
    "francofone": "francofono",
    "francofoni": "francofono",
    "francofortesi": "francofortese",
    "francò": "francare",
    "frane": "frana",
    "franerai": "franare",
    "franeran": "franare",
    "franeranno": "franare",
    "franerebbe": "franare",
    "franerebber": "franare",
    "franerebbero": "franare",
    "franerei": "franare",
    "franeremmo": "franare",
    "franeremo": "franare",
    "franereste": "franare",
    "franeresti": "franare",
    "franerete": "franare",
    "franerà": "franare",
    "franerò": "franare",
    "franga": "frangere",
    "frangan": "frangere",
    "frangano": "frangere",
    "frange": "frangia",
    "frangemmo": "frangere",
    "frangendo": "frangere",
    "frangente": "frangere",
    "frangenti": "frangere",
    "franger": "frangere",
    "frangerai": "frangiare",
    "frangeran": "frangiare",
    "frangeranno": "frangiare",
    "frangerebbe": "frangiare",
    "frangerebber": "frangiare",
    "frangerebbero": "frangiare",
    "frangerei": "frangiare",
    "frangeremmo": "frangiare",
    "frangeremo": "frangiare",
    "frangereste": "frangiare",
    "frangeresti": "frangiare",
    "frangerete": "frangiare",
    "frangerà": "frangiare",
    "frangerò": "frangiare",
    "frangesse": "frangere",
    "frangesser": "frangere",
    "frangessero": "frangere",
    "frangessi": "frangere",
    "frangessimo": "frangere",
    "frangeste": "frangere",
    "frangesti": "frangere",
    "frangete": "frangere",
    "frangette": "frangetta",
    "frangeva": "frangere",
    "frangevamo": "frangere",
    "frangevan": "frangere",
    "frangevano": "frangere",
    "frangevate": "frangere",
    "frangevi": "frangere",
    "frangevo": "frangere",
    "frangi": "frangiare",
    "frangia": "frangiare",
    "frangiai": "frangiare",
    "frangiammo": "frangiare",
    "frangiamo": "frangiare",
    "frangian": "frangiare",
    "frangiando": "frangiare",
    "frangiano": "frangiare",
    "frangiante": "frangiare",
    "frangianti": "frangiare",
    "frangiar": "frangiare",
    "frangiaron": "frangiare",
    "frangiarono": "frangiare",
    "frangiasse": "frangiare",
    "frangiasser": "frangiare",
    "frangiassero": "frangiare",
    "frangiassi": "frangiare",
    "frangiassimo": "frangiare",
    "frangiaste": "frangiare",
    "frangiasti": "frangiare",
    "frangiata": "frangiare",
    "frangiate": "frangiare",
    "frangiati": "frangiare",
    "frangiato": "frangiare",
    "frangiava": "frangiare",
    "frangiavamo": "frangiare",
    "frangiavan": "frangiare",
    "frangiavano": "frangiare",
    "frangiavate": "frangiare",
    "frangiavi": "frangiare",
    "frangiavo": "frangiare",
    "frangin": "frangiare",
    "frangino": "frangiare",
    "frangio": "frangiare",
    "frangiò": "frangiare",
    "frango": "frangere",
    "frangon": "frangere",
    "frangono": "frangere",
    "frani": "franare",
    "franiamo": "franare",
    "franiate": "franare",
    "franin": "franare",
    "franino": "franare",
    "frano": "franare",
    "franosa": "franoso",
    "franose": "franoso",
    "franosi": "franoso",
    "franser": "frangere",
    "fransero": "frangere",
    "fransi": "frangere",
    "fransè": "frangere",
    "franta": "frangere",
    "frante": "frangere",
    "franti": "frangere",
    "franto": "frangere",
    "frantoi": "frantoio",
    "frantuma": "frantumare",
    "frantumai": "frantumare",
    "frantumammo": "frantumare",
    "frantuman": "frantumare",
    "frantumando": "frantumare",
    "frantumano": "frantumare",
    "frantumante": "frantumare",
    "frantumanti": "frantumare",
    "frantumar": "frantumare",
    "frantumaron": "frantumare",
    "frantumarono": "frantumare",
    "frantumasse": "frantumare",
    "frantumasser": "frantumare",
    "frantumassero": "frantumare",
    "frantumassi": "frantumare",
    "frantumassimo": "frantumare",
    "frantumaste": "frantumare",
    "frantumasti": "frantumare",
    "frantumata": "frantumare",
    "frantumate": "frantumare",
    "frantumati": "frantumare",
    "frantumato": "frantumare",
    "frantumava": "frantumare",
    "frantumavamo": "frantumare",
    "frantumavan": "frantumare",
    "frantumavano": "frantumare",
    "frantumavate": "frantumare",
    "frantumavi": "frantumare",
    "frantumavo": "frantumare",
    "frantumazioni": "frantumazione",
    "frantumerai": "frantumare",
    "frantumeran": "frantumare",
    "frantumeranno": "frantumare",
    "frantumerebbe": "frantumare",
    "frantumerebber": "frantumare",
    "frantumerebbero": "frantumare",
    "frantumerei": "frantumare",
    "frantumeremmo": "frantumare",
    "frantumeremo": "frantumare",
    "frantumereste": "frantumare",
    "frantumeresti": "frantumare",
    "frantumerete": "frantumare",
    "frantumerà": "frantumare",
    "frantumerò": "frantumare",
    "frantumi": "frantumare",
    "frantumiamo": "frantumare",
    "frantumiate": "frantumare",
    "frantumin": "frantumare",
    "frantumino": "frantumare",
    "frantumo": "frantumare",
    "frantumò": "frantumare",
    "franò": "franare",
    "frappone": "frapporre",
    "frapponemmo": "frapporre",
    "frapponendo": "frapporre",
    "frapponente": "frapporre",
    "frapponenti": "frapporre",
    "frapponesse": "frapporre",
    "frapponesser": "frapporre",
    "frapponessero": "frapporre",
    "frapponessi": "frapporre",
    "frapponessimo": "frapporre",
    "frapponeste": "frapporre",
    "frapponesti": "frapporre",
    "frapponete": "frapporre",
    "frapponeva": "frapporre",
    "frapponevamo": "frapporre",
    "frapponevan": "frapporre",
    "frapponevano": "frapporre",
    "frapponevate": "frapporre",
    "frapponevi": "frapporre",
    "frapponevo": "frapporre",
    "frapponga": "frapporre",
    "frappongan": "frapporre",
    "frappongano": "frapporre",
    "frappongo": "frapporre",
    "frappongon": "frapporre",
    "frappongono": "frapporre",
    "frapponi": "frapporre",
    "frapponiamo": "frapporre",
    "frapponiate": "frapporre",
    "frapporr": "frapporre",
    "frapporrai": "frapporre",
    "frapporran": "frapporre",
    "frapporranno": "frapporre",
    "frapporrebbe": "frapporre",
    "frapporrebber": "frapporre",
    "frapporrebbero": "frapporre",
    "frapporrei": "frapporre",
    "frapporremmo": "frapporre",
    "frapporremo": "frapporre",
    "frapporreste": "frapporre",
    "frapporresti": "frapporre",
    "frapporrete": "frapporre",
    "frapporrà": "frapporre",
    "frapporrò": "frapporre",
    "frappose": "frapporre",
    "frapposer": "frapporre",
    "frapposero": "frapporre",
    "frapposi": "frapporre",
    "frapposta": "frapporre",
    "frapposte": "frapporre",
    "frapposti": "frapporre",
    "frapposto": "frapporre",
    "frasari": "frasario",
    "frasche": "frasca",
    "fraseggerai": "fraseggiare",
    "fraseggeran": "fraseggiare",
    "fraseggeranno": "fraseggiare",
    "fraseggerebbe": "fraseggiare",
    "fraseggerebber": "fraseggiare",
    "fraseggerebbero": "fraseggiare",
    "fraseggerei": "fraseggiare",
    "fraseggeremmo": "fraseggiare",
    "fraseggeremo": "fraseggiare",
    "fraseggereste": "fraseggiare",
    "fraseggeresti": "fraseggiare",
    "fraseggerete": "fraseggiare",
    "fraseggerà": "fraseggiare",
    "fraseggerò": "fraseggiare",
    "fraseggi": "fraseggio",
    "fraseggia": "fraseggiare",
    "fraseggiai": "fraseggiare",
    "fraseggiammo": "fraseggiare",
    "fraseggiamo": "fraseggiare",
    "fraseggian": "fraseggiare",
    "fraseggiando": "fraseggiare",
    "fraseggiano": "fraseggiare",
    "fraseggiante": "fraseggiare",
    "fraseggianti": "fraseggiare",
    "fraseggiar": "fraseggiare",
    "fraseggiaron": "fraseggiare",
    "fraseggiarono": "fraseggiare",
    "fraseggiasse": "fraseggiare",
    "fraseggiasser": "fraseggiare",
    "fraseggiassero": "fraseggiare",
    "fraseggiassi": "fraseggiare",
    "fraseggiassimo": "fraseggiare",
    "fraseggiaste": "fraseggiare",
    "fraseggiasti": "fraseggiare",
    "fraseggiata": "fraseggiare",
    "fraseggiate": "fraseggiare",
    "fraseggiati": "fraseggiare",
    "fraseggiato": "fraseggiare",
    "fraseggiava": "fraseggiare",
    "fraseggiavamo": "fraseggiare",
    "fraseggiavan": "fraseggiare",
    "fraseggiavano": "fraseggiare",
    "fraseggiavate": "fraseggiare",
    "fraseggiavi": "fraseggiare",
    "fraseggiavo": "fraseggiare",
    "fraseggin": "fraseggiare",
    "fraseggino": "fraseggiare",
    "fraseggio": "fraseggiare",
    "fraseggiò": "fraseggiare",
    "fraseologie": "fraseologia",
    "frasette": "frasetta",
    "frasi": "frase",
    "frastagli": "frastagliare",
    "frastaglia": "frastagliare",
    "frastagliai": "frastagliare",
    "frastagliammo": "frastagliare",
    "frastagliamo": "frastagliare",
    "frastaglian": "frastagliare",
    "frastagliando": "frastagliare",
    "frastagliano": "frastagliare",
    "frastagliante": "frastagliare",
    "frastaglianti": "frastagliare",
    "frastagliar": "frastagliare",
    "frastagliaron": "frastagliare",
    "frastagliarono": "frastagliare",
    "frastagliasse": "frastagliare",
    "frastagliasser": "frastagliare",
    "frastagliassero": "frastagliare",
    "frastagliassi": "frastagliare",
    "frastagliassimo": "frastagliare",
    "frastagliaste": "frastagliare",
    "frastagliasti": "frastagliare",
    "frastagliata": "frastagliare",
    "frastagliate": "frastagliare",
    "frastagliati": "frastagliare",
    "frastagliato": "frastagliare",
    "frastagliava": "frastagliare",
    "frastagliavamo": "frastagliare",
    "frastagliavan": "frastagliare",
    "frastagliavano": "frastagliare",
    "frastagliavate": "frastagliare",
    "frastagliavi": "frastagliare",
    "frastagliavo": "frastagliare",
    "frastaglierai": "frastagliare",
    "frastaglieran": "frastagliare",
    "frastaglieranno": "frastagliare",
    "frastaglierebbe": "frastagliare",
    "frastaglierebber": "frastagliare",
    "frastaglierebbero": "frastagliare",
    "frastaglierei": "frastagliare",
    "frastaglieremmo": "frastagliare",
    "frastaglieremo": "frastagliare",
    "frastagliereste": "frastagliare",
    "frastaglieresti": "frastagliare",
    "frastaglierete": "frastagliare",
    "frastaglierà": "frastagliare",
    "frastaglierò": "frastagliare",
    "frastaglin": "frastagliare",
    "frastaglino": "frastagliare",
    "frastaglio": "frastagliare",
    "frastagliò": "frastagliare",
    "frastorna": "frastornare",
    "frastornai": "frastornare",
    "frastornammo": "frastornare",
    "frastornan": "frastornare",
    "frastornando": "frastornare",
    "frastornano": "frastornare",
    "frastornante": "frastornare",
    "frastornanti": "frastornare",
    "frastornar": "frastornare",
    "frastornaron": "frastornare",
    "frastornarono": "frastornare",
    "frastornasse": "frastornare",
    "frastornasser": "frastornare",
    "frastornassero": "frastornare",
    "frastornassi": "frastornare",
    "frastornassimo": "frastornare",
    "frastornaste": "frastornare",
    "frastornasti": "frastornare",
    "frastornata": "frastornato",
    "frastornate": "frastornato",
    "frastornati": "frastornato",
    "frastornato": "frastornare",
    "frastornava": "frastornare",
    "frastornavamo": "frastornare",
    "frastornavan": "frastornare",
    "frastornavano": "frastornare",
    "frastornavate": "frastornare",
    "frastornavi": "frastornare",
    "frastornavo": "frastornare",
    "frastornerai": "frastornare",
    "frastorneran": "frastornare",
    "frastorneranno": "frastornare",
    "frastornerebbe": "frastornare",
    "frastornerebber": "frastornare",
    "frastornerebbero": "frastornare",
    "frastornerei": "frastornare",
    "frastorneremmo": "frastornare",
    "frastorneremo": "frastornare",
    "frastornereste": "frastornare",
    "frastorneresti": "frastornare",
    "frastornerete": "frastornare",
    "frastornerà": "frastornare",
    "frastornerò": "frastornare",
    "frastorni": "frastornare",
    "frastorniamo": "frastornare",
    "frastorniate": "frastornare",
    "frastornin": "frastornare",
    "frastornino": "frastornare",
    "frastorno": "frastornare",
    "frastornò": "frastornare",
    "frastuoni": "frastuono",
    "fratellanze": "fratellanza",
    "fratellastri": "fratellastro",
    "fratelli": "fratello",
    "fratellini": "fratellino",
    "fratelloni": "fratellone",
    "fraterna": "fraterno",
    "fraterne": "fraterno",
    "fraterni": "fraterno",
    "fraternizza": "fraternizzare",
    "fraternizzai": "fraternizzare",
    "fraternizzammo": "fraternizzare",
    "fraternizzan": "fraternizzare",
    "fraternizzando": "fraternizzare",
    "fraternizzano": "fraternizzare",
    "fraternizzante": "fraternizzare",
    "fraternizzanti": "fraternizzare",
    "fraternizzar": "fraternizzare",
    "fraternizzaron": "fraternizzare",
    "fraternizzarono": "fraternizzare",
    "fraternizzasse": "fraternizzare",
    "fraternizzasser": "fraternizzare",
    "fraternizzassero": "fraternizzare",
    "fraternizzassi": "fraternizzare",
    "fraternizzassimo": "fraternizzare",
    "fraternizzaste": "fraternizzare",
    "fraternizzasti": "fraternizzare",
    "fraternizzata": "fraternizzare",
    "fraternizzate": "fraternizzare",
    "fraternizzati": "fraternizzare",
    "fraternizzato": "fraternizzare",
    "fraternizzava": "fraternizzare",
    "fraternizzavamo": "fraternizzare",
    "fraternizzavan": "fraternizzare",
    "fraternizzavano": "fraternizzare",
    "fraternizzavate": "fraternizzare",
    "fraternizzavi": "fraternizzare",
    "fraternizzavo": "fraternizzare",
    "fraternizzerai": "fraternizzare",
    "fraternizzeran": "fraternizzare",
    "fraternizzeranno": "fraternizzare",
    "fraternizzerebbe": "fraternizzare",
    "fraternizzerebber": "fraternizzare",
    "fraternizzerebbero": "fraternizzare",
    "fraternizzerei": "fraternizzare",
    "fraternizzeremmo": "fraternizzare",
    "fraternizzeremo": "fraternizzare",
    "fraternizzereste": "fraternizzare",
    "fraternizzeresti": "fraternizzare",
    "fraternizzerete": "fraternizzare",
    "fraternizzerà": "fraternizzare",
    "fraternizzerò": "fraternizzare",
    "fraternizzi": "fraternizzare",
    "fraternizziamo": "fraternizzare",
    "fraternizziate": "fraternizzare",
    "fraternizzin": "fraternizzare",
    "fraternizzino": "fraternizzare",
    "fraternizzo": "fraternizzare",
    "fraternizzò": "fraternizzare",
    "fratesca": "fratesco",
    "fratesche": "fratesco",
    "frateschi": "fratesco",
    "frati": "frate",
    "fraticelli": "fraticello",
    "fratricide": "fratricida",
    "fratricidi": "fratricida",
    "fratta": "fratto",
    "fratte": "fratto",
    "fratti": "fratto",
    "frattura": "fratturare",
    "fratturai": "fratturare",
    "fratturammo": "fratturare",
    "fratturan": "fratturare",
    "fratturando": "fratturare",
    "fratturano": "fratturare",
    "fratturante": "fratturare",
    "fratturanti": "fratturare",
    "fratturar": "fratturare",
    "fratturaron": "fratturare",
    "fratturarono": "fratturare",
    "fratturasse": "fratturare",
    "fratturasser": "fratturare",
    "fratturassero": "fratturare",
    "fratturassi": "fratturare",
    "fratturassimo": "fratturare",
    "fratturaste": "fratturare",
    "fratturasti": "fratturare",
    "fratturata": "fratturare",
    "fratturate": "fratturare",
    "fratturati": "fratturare",
    "fratturato": "fratturare",
    "fratturava": "fratturare",
    "fratturavamo": "fratturare",
    "fratturavan": "fratturare",
    "fratturavano": "fratturare",
    "fratturavate": "fratturare",
    "fratturavi": "fratturare",
    "fratturavo": "fratturare",
    "fratture": "frattura",
    "fratturerai": "fratturare",
    "frattureran": "fratturare",
    "frattureranno": "fratturare",
    "fratturerebbe": "fratturare",
    "fratturerebber": "fratturare",
    "fratturerebbero": "fratturare",
    "fratturerei": "fratturare",
    "frattureremmo": "fratturare",
    "frattureremo": "fratturare",
    "fratturereste": "fratturare",
    "frattureresti": "fratturare",
    "fratturerete": "fratturare",
    "fratturerà": "fratturare",
    "fratturerò": "fratturare",
    "fratturi": "fratturare",
    "fratturiamo": "fratturare",
    "fratturiate": "fratturare",
    "fratturin": "fratturare",
    "fratturino": "fratturare",
    "fratturo": "fratturare",
    "fratturò": "fratturare",
    "fraudolenta": "fraudolento",
    "fraudolente": "fraudolento",
    "fraudolenti": "fraudolento",
    "fraziona": "frazionare",
    "frazionabili": "frazionabile",
    "frazionai": "frazionare",
    "frazionamenti": "frazionamento",
    "frazionammo": "frazionare",
    "frazionan": "frazionare",
    "frazionando": "frazionare",
    "frazionano": "frazionare",
    "frazionante": "frazionare",
    "frazionanti": "frazionare",
    "frazionar": "frazionare",
    "frazionaron": "frazionare",
    "frazionarono": "frazionare",
    "frazionasse": "frazionare",
    "frazionasser": "frazionare",
    "frazionassero": "frazionare",
    "frazionassi": "frazionare",
    "frazionassimo": "frazionare",
    "frazionaste": "frazionare",
    "frazionasti": "frazionare",
    "frazionata": "frazionato",
    "frazionate": "frazionato",
    "frazionati": "frazionato",
    "frazionato": "frazionare",
    "frazionava": "frazionare",
    "frazionavamo": "frazionare",
    "frazionavan": "frazionare",
    "frazionavano": "frazionare",
    "frazionavate": "frazionare",
    "frazionavi": "frazionare",
    "frazionavo": "frazionare",
    "frazionerai": "frazionare",
    "frazioneran": "frazionare",
    "frazioneranno": "frazionare",
    "frazionerebbe": "frazionare",
    "frazionerebber": "frazionare",
    "frazionerebbero": "frazionare",
    "frazionerei": "frazionare",
    "frazioneremmo": "frazionare",
    "frazioneremo": "frazionare",
    "frazionereste": "frazionare",
    "frazioneresti": "frazionare",
    "frazionerete": "frazionare",
    "frazionerà": "frazionare",
    "frazionerò": "frazionare",
    "frazioni": "frazione",
    "frazioniamo": "frazionare",
    "frazioniate": "frazionare",
    "frazionin": "frazionare",
    "frazionino": "frazionare",
    "fraziono": "frazionare",
    "frazionò": "frazionare",
    "freatica": "freatico",
    "freatiche": "freatico",
    "freatici": "freatico",
    "frecce": "freccia",
    "freccette": "freccetta",
    "frecciate": "frecciata",
    "frecciatine": "frecciatina",
    "fredda": "freddo",
    "freddai": "freddare",
    "freddammo": "freddare",
    "freddan": "freddare",
    "freddando": "freddare",
    "freddano": "freddare",
    "freddante": "freddare",
    "freddanti": "freddare",
    "freddar": "freddare",
    "freddaron": "freddare",
    "freddarono": "freddare",
    "freddasse": "freddare",
    "freddasser": "freddare",
    "freddassero": "freddare",
    "freddassi": "freddare",
    "freddassimo": "freddare",
    "freddaste": "freddare",
    "freddasti": "freddare",
    "freddata": "freddare",
    "freddate": "freddare",
    "freddati": "freddare",
    "freddato": "freddare",
    "freddava": "freddare",
    "freddavamo": "freddare",
    "freddavan": "freddare",
    "freddavano": "freddare",
    "freddavate": "freddare",
    "freddavi": "freddare",
    "freddavo": "freddare",
    "fredde": "freddo",
    "fredderai": "freddare",
    "fredderan": "freddare",
    "fredderanno": "freddare",
    "fredderebbe": "freddare",
    "fredderebber": "freddare",
    "fredderebbero": "freddare",
    "fredderei": "freddare",
    "fredderemmo": "freddare",
    "fredderemo": "freddare",
    "freddereste": "freddare",
    "fredderesti": "freddare",
    "fredderete": "freddare",
    "fredderà": "freddare",
    "fredderò": "freddare",
    "freddezze": "freddezza",
    "freddi": "freddo",
    "freddiamo": "freddare",
    "freddiate": "freddare",
    "freddin": "freddare",
    "freddino": "freddare",
    "freddo": "freddare",
    "freddolosa": "freddoloso",
    "freddolose": "freddoloso",
    "freddolosi": "freddoloso",
    "freddure": "freddura",
    "freddò": "freddare",
    "frega": "fregare",
    "fregai": "fregare",
    "fregammo": "fregare",
    "fregan": "fregare",
    "fregando": "fregare",
    "fregano": "fregare",
    "fregante": "fregare",
    "freganti": "fregare",
    "fregar": "fregare",
    "fregaron": "fregare",
    "fregarono": "fregare",
    "fregasse": "fregare",
    "fregasser": "fregare",
    "fregassero": "fregare",
    "fregassi": "fregare",
    "fregassimo": "fregare",
    "fregaste": "fregare",
    "fregasti": "fregare",
    "fregata": "fregare",
    "fregate": "fregata",
    "fregati": "fregare",
    "fregato": "fregare",
    "fregature": "fregatura",
    "fregava": "fregare",
    "fregavamo": "fregare",
    "fregavan": "fregare",
    "fregavano": "fregare",
    "fregavate": "fregare",
    "fregavi": "fregare",
    "fregavo": "fregare",
    "fregerai": "fregiare",
    "fregeran": "fregiare",
    "fregeranno": "fregiare",
    "fregerebbe": "fregiare",
    "fregerebber": "fregiare",
    "fregerebbero": "fregiare",
    "fregerei": "fregiare",
    "fregeremmo": "fregiare",
    "fregeremo": "fregiare",
    "fregereste": "fregiare",
    "fregeresti": "fregiare",
    "fregerete": "fregiare",
    "fregerà": "fregiare",
    "fregerò": "fregiare",
    "fregherai": "fregare",
    "fregheran": "fregare",
    "fregheranno": "fregare",
    "fregherebbe": "fregare",
    "fregherebber": "fregare",
    "fregherebbero": "fregare",
    "fregherei": "fregare",
    "fregheremmo": "fregare",
    "fregheremo": "fregare",
    "freghereste": "fregare",
    "fregheresti": "fregare",
    "fregherete": "fregare",
    "fregherà": "fregare",
    "fregherò": "fregare",
    "freghi": "fregare",
    "freghiamo": "fregare",
    "freghiate": "fregare",
    "freghin": "fregare",
    "freghino": "fregare",
    "fregi": "fregio",
    "fregia": "fregiare",
    "fregiai": "fregiare",
    "fregiammo": "fregiare",
    "fregiamo": "fregiare",
    "fregian": "fregiare",
    "fregiando": "fregiare",
    "fregiano": "fregiare",
    "fregiante": "fregiare",
    "fregianti": "fregiare",
    "fregiar": "fregiare",
    "fregiaron": "fregiare",
    "fregiarono": "fregiare",
    "fregiasse": "fregiare",
    "fregiasser": "fregiare",
    "fregiassero": "fregiare",
    "fregiassi": "fregiare",
    "fregiassimo": "fregiare",
    "fregiaste": "fregiare",
    "fregiasti": "fregiare",
    "fregiata": "fregiare",
    "fregiate": "fregiare",
    "fregiati": "fregiare",
    "fregiato": "fregiare",
    "fregiava": "fregiare",
    "fregiavamo": "fregiare",
    "fregiavan": "fregiare",
    "fregiavano": "fregiare",
    "fregiavate": "fregiare",
    "fregiavi": "fregiare",
    "fregiavo": "fregiare",
    "fregin": "fregiare",
    "fregino": "fregiare",
    "fregio": "fregiare",
    "fregiò": "fregiare",
    "fregnacce": "fregnaccia",
    "frego": "fregare",
    "fregole": "fregola",
    "fregò": "fregare",
    "frema": "fremere",
    "freman": "fremere",
    "fremano": "fremere",
    "freme": "fremere",
    "fremei": "fremere",
    "frememmo": "fremere",
    "fremendo": "fremere",
    "fremente": "fremere",
    "frementi": "fremere",
    "fremer": "fremere",
    "fremerai": "fremere",
    "fremeran": "fremere",
    "fremeranno": "fremere",
    "fremerebbe": "fremere",
    "fremerebber": "fremere",
    "fremerebbero": "fremere",
    "fremerei": "fremere",
    "fremeremmo": "fremere",
    "fremeremo": "fremere",
    "fremereste": "fremere",
    "fremeresti": "fremere",
    "fremerete": "fremere",
    "fremeron": "fremere",
    "fremerono": "fremere",
    "fremerà": "fremere",
    "fremerò": "fremere",
    "fremesse": "fremere",
    "fremesser": "fremere",
    "fremessero": "fremere",
    "fremessi": "fremere",
    "fremessimo": "fremere",
    "fremeste": "fremere",
    "fremesti": "fremere",
    "fremete": "fremere",
    "fremeva": "fremere",
    "fremevamo": "fremere",
    "fremevan": "fremere",
    "fremevano": "fremere",
    "fremevate": "fremere",
    "fremevi": "fremere",
    "fremevo": "fremere",
    "fremi": "fremere",
    "fremiamo": "fremere",
    "fremiate": "fremere",
    "fremiti": "fremito",
    "fremo": "fremere",
    "fremon": "fremere",
    "fremono": "fremere",
    "fremuta": "fremere",
    "fremute": "fremere",
    "fremuti": "fremere",
    "fremuto": "fremere",
    "fremè": "fremere",
    "frena": "frenare",
    "frenai": "frenare",
    "frenammo": "frenare",
    "frenan": "frenare",
    "frenando": "frenare",
    "frenano": "frenare",
    "frenante": "frenare",
    "frenanti": "frenare",
    "frenar": "frenare",
    "frenaron": "frenare",
    "frenarono": "frenare",
    "frenasse": "frenare",
    "frenasser": "frenare",
    "frenassero": "frenare",
    "frenassi": "frenare",
    "frenassimo": "frenare",
    "frenaste": "frenare",
    "frenasti": "frenare",
    "frenata": "frenato",
    "frenate": "frenato",
    "frenati": "frenato",
    "frenato": "frenare",
    "frenatori": "frenatore",
    "frenatrice": "frenatore",
    "frenatrici": "frenatore",
    "frenava": "frenare",
    "frenavamo": "frenare",
    "frenavan": "frenare",
    "frenavano": "frenare",
    "frenavate": "frenare",
    "frenavi": "frenare",
    "frenavo": "frenare",
    "frenerai": "frenare",
    "freneran": "frenare",
    "freneranno": "frenare",
    "frenerebbe": "frenare",
    "frenerebber": "frenare",
    "frenerebbero": "frenare",
    "frenerei": "frenare",
    "freneremmo": "frenare",
    "freneremo": "frenare",
    "frenereste": "frenare",
    "freneresti": "frenare",
    "frenerete": "frenare",
    "frenerà": "frenare",
    "frenerò": "frenare",
    "frenesie": "frenesia",
    "frenetica": "frenetico",
    "frenetiche": "frenetico",
    "frenetici": "frenetico",
    "freni": "freno",
    "freniamo": "frenare",
    "freniate": "frenare",
    "frenin": "frenare",
    "frenino": "frenare",
    "freno": "frenare",
    "frenò": "frenare",
    "frequenta": "frequentare",
    "frequentai": "frequentare",
    "frequentammo": "frequentare",
    "frequentan": "frequentare",
    "frequentando": "frequentare",
    "frequentano": "frequentare",
    "frequentante": "frequentare",
    "frequentanti": "frequentare",
    "frequentar": "frequentare",
    "frequentaron": "frequentare",
    "frequentarono": "frequentare",
    "frequentasse": "frequentare",
    "frequentasser": "frequentare",
    "frequentassero": "frequentare",
    "frequentassi": "frequentare",
    "frequentassimo": "frequentare",
    "frequentaste": "frequentare",
    "frequentasti": "frequentare",
    "frequentata": "frequentato",
    "frequentate": "frequentato",
    "frequentati": "frequentato",
    "frequentato": "frequentare",
    "frequentatori": "frequentatore",
    "frequentava": "frequentare",
    "frequentavamo": "frequentare",
    "frequentavan": "frequentare",
    "frequentavano": "frequentare",
    "frequentavate": "frequentare",
    "frequentavi": "frequentare",
    "frequentavo": "frequentare",
    "frequentazioni": "frequentazione",
    "frequenterai": "frequentare",
    "frequenteran": "frequentare",
    "frequenteranno": "frequentare",
    "frequenterebbe": "frequentare",
    "frequenterebber": "frequentare",
    "frequenterebbero": "frequentare",
    "frequenterei": "frequentare",
    "frequenteremmo": "frequentare",
    "frequenteremo": "frequentare",
    "frequentereste": "frequentare",
    "frequenteresti": "frequentare",
    "frequenterete": "frequentare",
    "frequenterà": "frequentare",
    "frequenterò": "frequentare",
    "frequenti": "frequente",
    "frequentiamo": "frequentare",
    "frequentiate": "frequentare",
    "frequentin": "frequentare",
    "frequentino": "frequentare",
    "frequento": "frequentare",
    "frequentò": "frequentare",
    "frequenze": "frequenza",
    "fresa": "fresare",
    "fresai": "fresare",
    "fresammo": "fresare",
    "fresan": "fresare",
    "fresando": "fresare",
    "fresano": "fresare",
    "fresante": "fresare",
    "fresanti": "fresare",
    "fresar": "fresare",
    "fresaron": "fresare",
    "fresarono": "fresare",
    "fresasse": "fresare",
    "fresasser": "fresare",
    "fresassero": "fresare",
    "fresassi": "fresare",
    "fresassimo": "fresare",
    "fresaste": "fresare",
    "fresasti": "fresare",
    "fresata": "fresare",
    "fresate": "fresare",
    "fresati": "fresare",
    "fresato": "fresare",
    "fresava": "fresare",
    "fresavamo": "fresare",
    "fresavan": "fresare",
    "fresavano": "fresare",
    "fresavate": "fresare",
    "fresavi": "fresare",
    "fresavo": "fresare",
    "fresca": "fresco",
    "fresche": "fresco",
    "freschezze": "freschezza",
    "freschi": "fresco",
    "frescure": "frescura",
    "frese": "fresa",
    "freserai": "fresare",
    "freseran": "fresare",
    "freseranno": "fresare",
    "freserebbe": "fresare",
    "freserebber": "fresare",
    "freserebbero": "fresare",
    "freserei": "fresare",
    "freseremmo": "fresare",
    "freseremo": "fresare",
    "fresereste": "fresare",
    "freseresti": "fresare",
    "freserete": "fresare",
    "freserà": "fresare",
    "freserò": "fresare",
    "fresi": "fresare",
    "fresiamo": "fresare",
    "fresiate": "fresare",
    "fresin": "fresare",
    "fresino": "fresare",
    "freso": "fresare",
    "fresò": "fresare",
    "frette": "fretta",
    "frettolosa": "frettoloso",
    "frettolose": "frettoloso",
    "frettolosi": "frettoloso",
    "freudiana": "freudiano",
    "freudiane": "freudiano",
    "freudiani": "freudiano",
    "friabili": "friabile",
    "fricchettoni": "fricchettone",
    "frigga": "friggere",
    "friggan": "friggere",
    "friggano": "friggere",
    "frigge": "friggere",
    "friggemmo": "friggere",
    "friggendo": "friggere",
    "friggente": "friggere",
    "friggenti": "friggere",
    "frigger": "friggere",
    "friggerai": "friggere",
    "friggeran": "friggere",
    "friggeranno": "friggere",
    "friggerebbe": "friggere",
    "friggerebber": "friggere",
    "friggerebbero": "friggere",
    "friggerei": "friggere",
    "friggeremmo": "friggere",
    "friggeremo": "friggere",
    "friggereste": "friggere",
    "friggeresti": "friggere",
    "friggerete": "friggere",
    "friggerà": "friggere",
    "friggerò": "friggere",
    "friggesse": "friggere",
    "friggesser": "friggere",
    "friggessero": "friggere",
    "friggessi": "friggere",
    "friggessimo": "friggere",
    "friggeste": "friggere",
    "friggesti": "friggere",
    "friggete": "friggere",
    "friggeva": "friggere",
    "friggevamo": "friggere",
    "friggevan": "friggere",
    "friggevano": "friggere",
    "friggevate": "friggere",
    "friggevi": "friggere",
    "friggevo": "friggere",
    "friggi": "friggere",
    "friggiamo": "friggere",
    "friggiate": "friggere",
    "friggo": "friggere",
    "friggon": "friggere",
    "friggono": "friggere",
    "frigi": "frigio",
    "frigia": "frigio",
    "frigida": "frigido",
    "frigide": "frigido",
    "frigidi": "frigido",
    "frigie": "frigio",
    "frigna": "frignare",
    "frignai": "frignare",
    "frignammo": "frignare",
    "frignan": "frignare",
    "frignando": "frignare",
    "frignano": "frignare",
    "frignante": "frignare",
    "frignanti": "frignare",
    "frignar": "frignare",
    "frignaron": "frignare",
    "frignarono": "frignare",
    "frignasse": "frignare",
    "frignasser": "frignare",
    "frignassero": "frignare",
    "frignassi": "frignare",
    "frignassimo": "frignare",
    "frignaste": "frignare",
    "frignasti": "frignare",
    "frignata": "frignare",
    "frignate": "frignare",
    "frignati": "frignare",
    "frignato": "frignare",
    "frignava": "frignare",
    "frignavamo": "frignare",
    "frignavan": "frignare",
    "frignavano": "frignare",
    "frignavate": "frignare",
    "frignavi": "frignare",
    "frignavo": "frignare",
    "frignerai": "frignare",
    "frigneran": "frignare",
    "frigneranno": "frignare",
    "frignerebbe": "frignare",
    "frignerebber": "frignare",
    "frignerebbero": "frignare",
    "frignerei": "frignare",
    "frigneremmo": "frignare",
    "frigneremo": "frignare",
    "frignereste": "frignare",
    "frigneresti": "frignare",
    "frignerete": "frignare",
    "frignerà": "frignare",
    "frignerò": "frignare",
    "frigni": "frignare",
    "frigniamo": "frignare",
    "frigniate": "frignare",
    "frignin": "frignare",
    "frignino": "frignare",
    "frigno": "frignare",
    "frignò": "frignare",
    "frigorifera": "frigorifero",
    "frigorifere": "frigorifero",
    "frigoriferi": "frigorifero",
    "frilli": "frillo",
    "frinendo": "frinire",
    "frinente": "frinire",
    "frinenti": "frinire",
    "fringuelli": "fringuello",
    "friniamo": "frinire",
    "friniate": "frinire",
    "frinii": "frinire",
    "frinimmo": "frinire",
    "frinir": "frinire",
    "frinirai": "frinire",
    "friniran": "frinire",
    "friniranno": "frinire",
    "frinirebbe": "frinire",
    "frinirebber": "frinire",
    "frinirebbero": "frinire",
    "frinirei": "frinire",
    "friniremmo": "frinire",
    "friniremo": "frinire",
    "frinireste": "frinire",
    "friniresti": "frinire",
    "frinirete": "frinire",
    "friniron": "frinire",
    "frinirono": "frinire",
    "frinirà": "frinire",
    "frinirò": "frinire",
    "frinisca": "frinire",
    "friniscan": "frinire",
    "friniscano": "frinire",
    "frinisce": "frinire",
    "frinisci": "frinire",
    "frinisco": "frinire",
    "friniscon": "frinire",
    "friniscono": "frinire",
    "frinisse": "frinire",
    "frinisser": "frinire",
    "frinissero": "frinire",
    "frinissi": "frinire",
    "frinissimo": "frinire",
    "friniste": "frinire",
    "frinisti": "frinire",
    "frinita": "frinire",
    "frinite": "frinire",
    "friniti": "frinire",
    "frinito": "frinire",
    "friniva": "frinire",
    "frinivamo": "frinire",
    "frinivan": "frinire",
    "frinivano": "frinire",
    "frinivate": "frinire",
    "frinivi": "frinire",
    "frinivo": "frinire",
    "frinì": "frinire",
    "frisa": "frisare",
    "frisai": "frisare",
    "frisammo": "frisare",
    "frisan": "frisare",
    "frisando": "frisare",
    "frisano": "frisare",
    "frisante": "frisare",
    "frisanti": "frisare",
    "frisar": "frisare",
    "frisaron": "frisare",
    "frisarono": "frisare",
    "frisasse": "frisare",
    "frisasser": "frisare",
    "frisassero": "frisare",
    "frisassi": "frisare",
    "frisassimo": "frisare",
    "frisaste": "frisare",
    "frisasti": "frisare",
    "frisata": "frisare",
    "frisate": "frisare",
    "frisati": "frisare",
    "frisato": "frisare",
    "frisava": "frisare",
    "frisavamo": "frisare",
    "frisavan": "frisare",
    "frisavano": "frisare",
    "frisavate": "frisare",
    "frisavi": "frisare",
    "frisavo": "frisare",
    "friserai": "frisare",
    "friseran": "frisare",
    "friseranno": "frisare",
    "friserebbe": "frisare",
    "friserebber": "frisare",
    "friserebbero": "frisare",
    "friserei": "frisare",
    "friseremmo": "frisare",
    "friseremo": "frisare",
    "frisereste": "frisare",
    "friseresti": "frisare",
    "friserete": "frisare",
    "friserà": "frisare",
    "friserò": "frisare",
    "frisi": "frisare",
    "frisiamo": "frisare",
    "frisiate": "frisare",
    "frisin": "frisare",
    "frisino": "frisare",
    "friso": "frisare",
    "frisser": "friggere",
    "frissero": "friggere",
    "frissi": "friggere",
    "frissè": "friggere",
    "frisò": "frisare",
    "fritta": "fritto",
    "frittate": "frittata",
    "fritte": "fritto",
    "frittelle": "frittella",
    "fritti": "fritto",
    "fritto": "friggere",
    "fritture": "frittura",
    "friulana": "friulano",
    "friulane": "friulano",
    "friulani": "friulano",
    "frivola": "frivolo",
    "frivole": "frivolo",
    "frivolezze": "frivolezza",
    "frivoli": "frivolo",
    "friziona": "frizionare",
    "frizionai": "frizionare",
    "frizionammo": "frizionare",
    "frizionan": "frizionare",
    "frizionando": "frizionare",
    "frizionano": "frizionare",
    "frizionante": "frizionare",
    "frizionanti": "frizionare",
    "frizionar": "frizionare",
    "frizionaron": "frizionare",
    "frizionarono": "frizionare",
    "frizionasse": "frizionare",
    "frizionasser": "frizionare",
    "frizionassero": "frizionare",
    "frizionassi": "frizionare",
    "frizionassimo": "frizionare",
    "frizionaste": "frizionare",
    "frizionasti": "frizionare",
    "frizionata": "frizionare",
    "frizionate": "frizionare",
    "frizionati": "frizionare",
    "frizionato": "frizionare",
    "frizionava": "frizionare",
    "frizionavamo": "frizionare",
    "frizionavan": "frizionare",
    "frizionavano": "frizionare",
    "frizionavate": "frizionare",
    "frizionavi": "frizionare",
    "frizionavo": "frizionare",
    "frizionerai": "frizionare",
    "frizioneran": "frizionare",
    "frizioneranno": "frizionare",
    "frizionerebbe": "frizionare",
    "frizionerebber": "frizionare",
    "frizionerebbero": "frizionare",
    "frizionerei": "frizionare",
    "frizioneremmo": "frizionare",
    "frizioneremo": "frizionare",
    "frizionereste": "frizionare",
    "frizioneresti": "frizionare",
    "frizionerete": "frizionare",
    "frizionerà": "frizionare",
    "frizionerò": "frizionare",
    "frizioni": "frizione",
    "frizioniamo": "frizionare",
    "frizioniate": "frizionare",
    "frizionin": "frizionare",
    "frizionino": "frizionare",
    "friziono": "frizionare",
    "frizionò": "frizionare",
    "frizza": "frizzare",
    "frizzai": "frizzare",
    "frizzammo": "frizzare",
    "frizzan": "frizzare",
    "frizzando": "frizzare",
    "frizzano": "frizzare",
    "frizzante": "frizzare",
    "frizzanti": "frizzare",
    "frizzar": "frizzare",
    "frizzaron": "frizzare",
    "frizzarono": "frizzare",
    "frizzasse": "frizzare",
    "frizzasser": "frizzare",
    "frizzassero": "frizzare",
    "frizzassi": "frizzare",
    "frizzassimo": "frizzare",
    "frizzaste": "frizzare",
    "frizzasti": "frizzare",
    "frizzata": "frizzare",
    "frizzate": "frizzare",
    "frizzati": "frizzare",
    "frizzato": "frizzare",
    "frizzava": "frizzare",
    "frizzavamo": "frizzare",
    "frizzavan": "frizzare",
    "frizzavano": "frizzare",
    "frizzavate": "frizzare",
    "frizzavi": "frizzare",
    "frizzavo": "frizzare",
    "frizzerai": "frizzare",
    "frizzeran": "frizzare",
    "frizzeranno": "frizzare",
    "frizzerebbe": "frizzare",
    "frizzerebber": "frizzare",
    "frizzerebbero": "frizzare",
    "frizzerei": "frizzare",
    "frizzeremmo": "frizzare",
    "frizzeremo": "frizzare",
    "frizzereste": "frizzare",
    "frizzeresti": "frizzare",
    "frizzerete": "frizzare",
    "frizzerà": "frizzare",
    "frizzerò": "frizzare",
    "frizzi": "frizzo",
    "frizziamo": "frizzare",
    "frizziate": "frizzare",
    "frizzin": "frizzare",
    "frizzino": "frizzare",
    "frizzo": "frizzare",
    "frizzò": "frizzare",
    "froci": "frocio",
    "froda": "frodare",
    "frodai": "frodare",
    "frodammo": "frodare",
    "frodan": "frodare",
    "frodando": "frodare",
    "frodano": "frodare",
    "frodante": "frodare",
    "frodanti": "frodare",
    "frodar": "frodare",
    "frodaron": "frodare",
    "frodarono": "frodare",
    "frodasse": "frodare",
    "frodasser": "frodare",
    "frodassero": "frodare",
    "frodassi": "frodare",
    "frodassimo": "frodare",
    "frodaste": "frodare",
    "frodasti": "frodare",
    "frodata": "frodare",
    "frodate": "frodare",
    "frodati": "frodare",
    "frodato": "frodare",
    "frodava": "frodare",
    "frodavamo": "frodare",
    "frodavan": "frodare",
    "frodavano": "frodare",
    "frodavate": "frodare",
    "frodavi": "frodare",
    "frodavo": "frodare",
    "froderai": "frodare",
    "froderan": "frodare",
    "froderanno": "frodare",
    "froderebbe": "frodare",
    "froderebber": "frodare",
    "froderebbero": "frodare",
    "froderei": "frodare",
    "froderemmo": "frodare",
    "froderemo": "frodare",
    "frodereste": "frodare",
    "froderesti": "frodare",
    "froderete": "frodare",
    "froderà": "frodare",
    "froderò": "frodare",
    "frodi": "frode",
    "frodiamo": "frodare",
    "frodiate": "frodare",
    "frodin": "frodare",
    "frodino": "frodare",
    "frodo": "frodare",
    "frodò": "frodare",
    "frolla": "frollare",
    "frollai": "frollare",
    "frollammo": "frollare",
    "frollan": "frollare",
    "frollando": "frollare",
    "frollano": "frollare",
    "frollante": "frollare",
    "frollanti": "frollare",
    "frollar": "frollare",
    "frollaron": "frollare",
    "frollarono": "frollare",
    "frollasse": "frollare",
    "frollasser": "frollare",
    "frollassero": "frollare",
    "frollassi": "frollare",
    "frollassimo": "frollare",
    "frollaste": "frollare",
    "frollasti": "frollare",
    "frollata": "frollare",
    "frollate": "frollare",
    "frollati": "frollare",
    "frollato": "frollare",
    "frollava": "frollare",
    "frollavamo": "frollare",
    "frollavan": "frollare",
    "frollavano": "frollare",
    "frollavate": "frollare",
    "frollavi": "frollare",
    "frollavo": "frollare",
    "frollerai": "frollare",
    "frolleran": "frollare",
    "frolleranno": "frollare",
    "frollerebbe": "frollare",
    "frollerebber": "frollare",
    "frollerebbero": "frollare",
    "frollerei": "frollare",
    "frolleremmo": "frollare",
    "frolleremo": "frollare",
    "frollereste": "frollare",
    "frolleresti": "frollare",
    "frollerete": "frollare",
    "frollerà": "frollare",
    "frollerò": "frollare",
    "frolli": "frollare",
    "frolliamo": "frollare",
    "frolliate": "frollare",
    "frollin": "frollare",
    "frollino": "frollare",
    "frollo": "frollare",
    "frollò": "frollare",
    "frombolieri": "fromboliere",
    "fronde": "fronda",
    "frontali": "frontale",
    "frontalieri": "frontaliere",
    "fronteggerai": "fronteggiare",
    "fronteggeran": "fronteggiare",
    "fronteggeranno": "fronteggiare",
    "fronteggerebbe": "fronteggiare",
    "fronteggerebber": "fronteggiare",
    "fronteggerebbero": "fronteggiare",
    "fronteggerei": "fronteggiare",
    "fronteggeremmo": "fronteggiare",
    "fronteggeremo": "fronteggiare",
    "fronteggereste": "fronteggiare",
    "fronteggeresti": "fronteggiare",
    "fronteggerete": "fronteggiare",
    "fronteggerà": "fronteggiare",
    "fronteggerò": "fronteggiare",
    "fronteggi": "fronteggiare",
    "fronteggia": "fronteggiare",
    "fronteggiai": "fronteggiare",
    "fronteggiammo": "fronteggiare",
    "fronteggiamo": "fronteggiare",
    "fronteggian": "fronteggiare",
    "fronteggiando": "fronteggiare",
    "fronteggiano": "fronteggiare",
    "fronteggiante": "fronteggiare",
    "fronteggianti": "fronteggiare",
    "fronteggiar": "fronteggiare",
    "fronteggiaron": "fronteggiare",
    "fronteggiarono": "fronteggiare",
    "fronteggiasse": "fronteggiare",
    "fronteggiasser": "fronteggiare",
    "fronteggiassero": "fronteggiare",
    "fronteggiassi": "fronteggiare",
    "fronteggiassimo": "fronteggiare",
    "fronteggiaste": "fronteggiare",
    "fronteggiasti": "fronteggiare",
    "fronteggiata": "fronteggiare",
    "fronteggiate": "fronteggiare",
    "fronteggiati": "fronteggiare",
    "fronteggiato": "fronteggiare",
    "fronteggiava": "fronteggiare",
    "fronteggiavamo": "fronteggiare",
    "fronteggiavan": "fronteggiare",
    "fronteggiavano": "fronteggiare",
    "fronteggiavate": "fronteggiare",
    "fronteggiavi": "fronteggiare",
    "fronteggiavo": "fronteggiare",
    "fronteggin": "fronteggiare",
    "fronteggino": "fronteggiare",
    "fronteggio": "fronteggiare",
    "fronteggiò": "fronteggiare",
    "frontespizi": "frontespizio",
    "fronti": "fronte",
    "frontiere": "frontiera",
    "frontoni": "frontone",
    "fronzoli": "fronzolo",
    "fronzuta": "fronzuto",
    "fronzute": "fronzuto",
    "fronzuti": "fronzuto",
    "frotte": "frotta",
    "frottole": "frottola",
    "fruendo": "fruire",
    "fruente": "fruire",
    "fruenti": "fruire",
    "fruga": "frugare",
    "frugai": "frugare",
    "frugali": "frugale",
    "frugammo": "frugare",
    "frugan": "frugare",
    "frugando": "frugare",
    "frugano": "frugare",
    "frugante": "frugare",
    "fruganti": "frugare",
    "frugar": "frugare",
    "frugaron": "frugare",
    "frugarono": "frugare",
    "frugasse": "frugare",
    "frugasser": "frugare",
    "frugassero": "frugare",
    "frugassi": "frugare",
    "frugassimo": "frugare",
    "frugaste": "frugare",
    "frugasti": "frugare",
    "frugata": "frugare",
    "frugate": "frugare",
    "frugati": "frugare",
    "frugato": "frugare",
    "frugava": "frugare",
    "frugavamo": "frugare",
    "frugavan": "frugare",
    "frugavano": "frugare",
    "frugavate": "frugare",
    "frugavi": "frugare",
    "frugavo": "frugare",
    "frugherai": "frugare",
    "frugheran": "frugare",
    "frugheranno": "frugare",
    "frugherebbe": "frugare",
    "frugherebber": "frugare",
    "frugherebbero": "frugare",
    "frugherei": "frugare",
    "frugheremmo": "frugare",
    "frugheremo": "frugare",
    "frughereste": "frugare",
    "frugheresti": "frugare",
    "frugherete": "frugare",
    "frugherà": "frugare",
    "frugherò": "frugare",
    "frughi": "frugare",
    "frughiamo": "frugare",
    "frughiate": "frugare",
    "frughin": "frugare",
    "frughino": "frugare",
    "frugo": "frugare",
    "frugò": "frugare",
    "fruiamo": "fruire",
    "fruiate": "fruire",
    "fruibili": "fruibile",
    "fruii": "fruire",
    "fruimmo": "fruire",
    "fruir": "fruire",
    "fruirai": "fruire",
    "fruiran": "fruire",
    "fruiranno": "fruire",
    "fruirebbe": "fruire",
    "fruirebber": "fruire",
    "fruirebbero": "fruire",
    "fruirei": "fruire",
    "fruiremmo": "fruire",
    "fruiremo": "fruire",
    "fruireste": "fruire",
    "fruiresti": "fruire",
    "fruirete": "fruire",
    "fruiron": "fruire",
    "fruirono": "fruire",
    "fruirà": "fruire",
    "fruirò": "fruire",
    "fruisca": "fruire",
    "fruiscan": "fruire",
    "fruiscano": "fruire",
    "fruisce": "fruire",
    "fruisci": "fruire",
    "fruisco": "fruire",
    "fruiscon": "fruire",
    "fruiscono": "fruire",
    "fruisse": "fruire",
    "fruisser": "fruire",
    "fruissero": "fruire",
    "fruissi": "fruire",
    "fruissimo": "fruire",
    "fruiste": "fruire",
    "fruisti": "fruire",
    "fruita": "fruire",
    "fruite": "fruire",
    "fruiti": "fruire",
    "fruito": "fruire",
    "fruitori": "fruitore",
    "fruiva": "fruire",
    "fruivamo": "fruire",
    "fruivan": "fruire",
    "fruivano": "fruire",
    "fruivate": "fruire",
    "fruivi": "fruire",
    "fruivo": "fruire",
    "fruizioni": "fruizione",
    "frulla": "frullare",
    "frullai": "frullare",
    "frullammo": "frullare",
    "frullan": "frullare",
    "frullando": "frullare",
    "frullano": "frullare",
    "frullante": "frullare",
    "frullanti": "frullare",
    "frullar": "frullare",
    "frullaron": "frullare",
    "frullarono": "frullare",
    "frullasse": "frullare",
    "frullasser": "frullare",
    "frullassero": "frullare",
    "frullassi": "frullare",
    "frullassimo": "frullare",
    "frullaste": "frullare",
    "frullasti": "frullare",
    "frullata": "frullare",
    "frullate": "frullare",
    "frullati": "frullato",
    "frullato": "frullare",
    "frullatori": "frullatore",
    "frullava": "frullare",
    "frullavamo": "frullare",
    "frullavan": "frullare",
    "frullavano": "frullare",
    "frullavate": "frullare",
    "frullavi": "frullare",
    "frullavo": "frullare",
    "frullerai": "frullare",
    "frulleran": "frullare",
    "frulleranno": "frullare",
    "frullerebbe": "frullare",
    "frullerebber": "frullare",
    "frullerebbero": "frullare",
    "frullerei": "frullare",
    "frulleremmo": "frullare",
    "frulleremo": "frullare",
    "frullereste": "frullare",
    "frulleresti": "frullare",
    "frullerete": "frullare",
    "frullerà": "frullare",
    "frullerò": "frullare",
    "frulli": "frullare",
    "frulliamo": "frullare",
    "frulliate": "frullare",
    "frullin": "frullare",
    "frullino": "frullare",
    "frullo": "frullare",
    "frullò": "frullare",
    "frumenti": "frumento",
    "fruscerai": "frusciare",
    "frusceran": "frusciare",
    "frusceranno": "frusciare",
    "fruscerebbe": "frusciare",
    "fruscerebber": "frusciare",
    "fruscerebbero": "frusciare",
    "fruscerei": "frusciare",
    "frusceremmo": "frusciare",
    "frusceremo": "frusciare",
    "fruscereste": "frusciare",
    "frusceresti": "frusciare",
    "fruscerete": "frusciare",
    "fruscerà": "frusciare",
    "fruscerò": "frusciare",
    "frusci": "frusciare",
    "fruscia": "frusciare",
    "frusciai": "frusciare",
    "frusciammo": "frusciare",
    "frusciamo": "frusciare",
    "fruscian": "frusciare",
    "frusciando": "frusciare",
    "frusciano": "frusciare",
    "frusciante": "frusciare",
    "fruscianti": "frusciare",
    "frusciar": "frusciare",
    "frusciaron": "frusciare",
    "frusciarono": "frusciare",
    "frusciasse": "frusciare",
    "frusciasser": "frusciare",
    "frusciassero": "frusciare",
    "frusciassi": "frusciare",
    "frusciassimo": "frusciare",
    "frusciaste": "frusciare",
    "frusciasti": "frusciare",
    "frusciata": "frusciare",
    "frusciate": "frusciare",
    "frusciati": "frusciare",
    "frusciato": "frusciare",
    "frusciava": "frusciare",
    "frusciavamo": "frusciare",
    "frusciavan": "frusciare",
    "frusciavano": "frusciare",
    "frusciavate": "frusciare",
    "frusciavi": "frusciare",
    "frusciavo": "frusciare",
    "fruscii": "fruscio",
    "fruscin": "frusciare",
    "fruscino": "frusciare",
    "fruscio": "frusciare",
    "frusciò": "frusciare",
    "frusta": "frusto",
    "frustai": "frustare",
    "frustammo": "frustare",
    "frustan": "frustare",
    "frustando": "frustare",
    "frustano": "frustare",
    "frustante": "frustare",
    "frustanti": "frustare",
    "frustar": "frustare",
    "frustaron": "frustare",
    "frustarono": "frustare",
    "frustasse": "frustare",
    "frustasser": "frustare",
    "frustassero": "frustare",
    "frustassi": "frustare",
    "frustassimo": "frustare",
    "frustaste": "frustare",
    "frustasti": "frustare",
    "frustata": "frustare",
    "frustate": "frustata",
    "frustati": "frustare",
    "frustato": "frustare",
    "frustava": "frustare",
    "frustavamo": "frustare",
    "frustavan": "frustare",
    "frustavano": "frustare",
    "frustavate": "frustare",
    "frustavi": "frustare",
    "frustavo": "frustare",
    "frustazioni": "frustazione",
    "fruste": "frusto",
    "frusterai": "frustare",
    "frusteran": "frustare",
    "frusteranno": "frustare",
    "frusterebbe": "frustare",
    "frusterebber": "frustare",
    "frusterebbero": "frustare",
    "frusterei": "frustare",
    "frusteremmo": "frustare",
    "frusteremo": "frustare",
    "frustereste": "frustare",
    "frusteresti": "frustare",
    "frusterete": "frustare",
    "frusterà": "frustare",
    "frusterò": "frustare",
    "frusti": "frusto",
    "frustiamo": "frustare",
    "frustiate": "frustare",
    "frustin": "frustare",
    "frustini": "frustino",
    "frustino": "frustare",
    "frusto": "frustare",
    "frustra": "frustrare",
    "frustrai": "frustrare",
    "frustrammo": "frustrare",
    "frustran": "frustrare",
    "frustrando": "frustrare",
    "frustrano": "frustrare",
    "frustrante": "frustrare",
    "frustranti": "frustrare",
    "frustrar": "frustrare",
    "frustraron": "frustrare",
    "frustrarono": "frustrare",
    "frustrasse": "frustrare",
    "frustrasser": "frustrare",
    "frustrassero": "frustrare",
    "frustrassi": "frustrare",
    "frustrassimo": "frustrare",
    "frustraste": "frustrare",
    "frustrasti": "frustrare",
    "frustrata": "frustrato",
    "frustrate": "frustrato",
    "frustrati": "frustrato",
    "frustrato": "frustrare",
    "frustrava": "frustrare",
    "frustravamo": "frustrare",
    "frustravan": "frustrare",
    "frustravano": "frustrare",
    "frustravate": "frustrare",
    "frustravi": "frustrare",
    "frustravo": "frustrare",
    "frustrazioni": "frustrazione",
    "frustrerai": "frustrare",
    "frustreran": "frustrare",
    "frustreranno": "frustrare",
    "frustrerebbe": "frustrare",
    "frustrerebber": "frustrare",
    "frustrerebbero": "frustrare",
    "frustrerei": "frustrare",
    "frustreremmo": "frustrare",
    "frustreremo": "frustrare",
    "frustrereste": "frustrare",
    "frustreresti": "frustrare",
    "frustrerete": "frustrare",
    "frustrerà": "frustrare",
    "frustrerò": "frustrare",
    "frustri": "frustrare",
    "frustriamo": "frustrare",
    "frustriate": "frustrare",
    "frustrin": "frustrare",
    "frustrino": "frustrare",
    "frustro": "frustrare",
    "frustrò": "frustrare",
    "frustò": "frustare",
    "frutta": "fruttare",
    "fruttai": "fruttare",
    "fruttammo": "fruttare",
    "fruttan": "fruttare",
    "fruttando": "fruttare",
    "fruttano": "fruttare",
    "fruttante": "fruttare",
    "fruttanti": "fruttare",
    "fruttar": "fruttare",
    "fruttaron": "fruttare",
    "fruttarono": "fruttare",
    "fruttasse": "fruttare",
    "fruttasser": "fruttare",
    "fruttassero": "fruttare",
    "fruttassi": "fruttare",
    "fruttassimo": "fruttare",
    "fruttaste": "fruttare",
    "fruttasti": "fruttare",
    "fruttata": "fruttare",
    "fruttate": "fruttare",
    "fruttati": "fruttare",
    "fruttato": "fruttare",
    "fruttava": "fruttare",
    "fruttavamo": "fruttare",
    "fruttavan": "fruttare",
    "fruttavano": "fruttare",
    "fruttavate": "fruttare",
    "fruttavi": "fruttare",
    "fruttavo": "fruttare",
    "frutte": "frutta",
    "frutterai": "fruttare",
    "frutteran": "fruttare",
    "frutteranno": "fruttare",
    "frutterebbe": "fruttare",
    "frutterebber": "fruttare",
    "frutterebbero": "fruttare",
    "frutterei": "fruttare",
    "frutteremmo": "fruttare",
    "frutteremo": "fruttare",
    "fruttereste": "fruttare",
    "frutteresti": "fruttare",
    "frutterete": "fruttare",
    "frutterà": "fruttare",
    "frutterò": "fruttare",
    "frutteti": "frutteto",
    "frutti": "frutto",
    "fruttiamo": "fruttare",
    "fruttiate": "fruttare",
    "fruttifera": "fruttifero",
    "fruttifere": "fruttifero",
    "fruttiferi": "fruttifero",
    "fruttifica": "fruttificare",
    "fruttificai": "fruttificare",
    "fruttificammo": "fruttificare",
    "fruttifican": "fruttificare",
    "fruttificando": "fruttificare",
    "fruttificano": "fruttificare",
    "fruttificante": "fruttificare",
    "fruttificanti": "fruttificare",
    "fruttificar": "fruttificare",
    "fruttificaron": "fruttificare",
    "fruttificarono": "fruttificare",
    "fruttificasse": "fruttificare",
    "fruttificasser": "fruttificare",
    "fruttificassero": "fruttificare",
    "fruttificassi": "fruttificare",
    "fruttificassimo": "fruttificare",
    "fruttificaste": "fruttificare",
    "fruttificasti": "fruttificare",
    "fruttificata": "fruttificare",
    "fruttificate": "fruttificare",
    "fruttificati": "fruttificare",
    "fruttificato": "fruttificare",
    "fruttificava": "fruttificare",
    "fruttificavamo": "fruttificare",
    "fruttificavan": "fruttificare",
    "fruttificavano": "fruttificare",
    "fruttificavate": "fruttificare",
    "fruttificavi": "fruttificare",
    "fruttificavo": "fruttificare",
    "fruttificherai": "fruttificare",
    "fruttificheran": "fruttificare",
    "fruttificheranno": "fruttificare",
    "fruttificherebbe": "fruttificare",
    "fruttificherebber": "fruttificare",
    "fruttificherebbero": "fruttificare",
    "fruttificherei": "fruttificare",
    "fruttificheremmo": "fruttificare",
    "fruttificheremo": "fruttificare",
    "fruttifichereste": "fruttificare",
    "fruttificheresti": "fruttificare",
    "fruttificherete": "fruttificare",
    "fruttificherà": "fruttificare",
    "fruttificherò": "fruttificare",
    "fruttifichi": "fruttificare",
    "fruttifichiamo": "fruttificare",
    "fruttifichiate": "fruttificare",
    "fruttifichin": "fruttificare",
    "fruttifichino": "fruttificare",
    "fruttifico": "fruttificare",
    "fruttificò": "fruttificare",
    "fruttin": "fruttare",
    "fruttino": "fruttare",
    "fruttivendoli": "fruttivendolo",
    "frutto": "fruttare",
    "fruttuosa": "fruttuoso",
    "fruttuose": "fruttuoso",
    "fruttuosi": "fruttuoso",
    "fruttò": "fruttare",
    "fruì": "fruire",
    "fu": "essere",
    "fucila": "fucilare",
    "fucilai": "fucilare",
    "fucilammo": "fucilare",
    "fucilan": "fucilare",
    "fucilando": "fucilare",
    "fucilano": "fucilare",
    "fucilante": "fucilare",
    "fucilanti": "fucilare",
    "fucilar": "fucilare",
    "fucilaron": "fucilare",
    "fucilarono": "fucilare",
    "fucilasse": "fucilare",
    "fucilasser": "fucilare",
    "fucilassero": "fucilare",
    "fucilassi": "fucilare",
    "fucilassimo": "fucilare",
    "fucilaste": "fucilare",
    "fucilasti": "fucilare",
    "fucilata": "fucilare",
    "fucilate": "fucilata",
    "fucilati": "fucilare",
    "fucilato": "fucilare",
    "fucilava": "fucilare",
    "fucilavamo": "fucilare",
    "fucilavan": "fucilare",
    "fucilavano": "fucilare",
    "fucilavate": "fucilare",
    "fucilavi": "fucilare",
    "fucilavo": "fucilare",
    "fucilazioni": "fucilazione",
    "fucilerai": "fucilare",
    "fucileran": "fucilare",
    "fucileranno": "fucilare",
    "fucilerebbe": "fucilare",
    "fucilerebber": "fucilare",
    "fucilerebbero": "fucilare",
    "fucilerei": "fucilare",
    "fucileremmo": "fucilare",
    "fucileremo": "fucilare",
    "fucilereste": "fucilare",
    "fucileresti": "fucilare",
    "fucilerete": "fucilare",
    "fucilerà": "fucilare",
    "fucilerò": "fucilare",
    "fucili": "fucile",
    "fuciliamo": "fucilare",
    "fuciliate": "fucilare",
    "fucilieri": "fuciliere",
    "fucilin": "fucilare",
    "fucilino": "fucilare",
    "fucilo": "fucilare",
    "fucilò": "fucilare",
    "fucina": "fucinare",
    "fucinai": "fucinare",
    "fucinammo": "fucinare",
    "fucinan": "fucinare",
    "fucinando": "fucinare",
    "fucinano": "fucinare",
    "fucinante": "fucinare",
    "fucinanti": "fucinare",
    "fucinar": "fucinare",
    "fucinaron": "fucinare",
    "fucinarono": "fucinare",
    "fucinasse": "fucinare",
    "fucinasser": "fucinare",
    "fucinassero": "fucinare",
    "fucinassi": "fucinare",
    "fucinassimo": "fucinare",
    "fucinaste": "fucinare",
    "fucinasti": "fucinare",
    "fucinata": "fucinare",
    "fucinate": "fucinare",
    "fucinati": "fucinare",
    "fucinato": "fucinare",
    "fucinava": "fucinare",
    "fucinavamo": "fucinare",
    "fucinavan": "fucinare",
    "fucinavano": "fucinare",
    "fucinavate": "fucinare",
    "fucinavi": "fucinare",
    "fucinavo": "fucinare",
    "fucine": "fucina",
    "fucinerai": "fucinare",
    "fucineran": "fucinare",
    "fucineranno": "fucinare",
    "fucinerebbe": "fucinare",
    "fucinerebber": "fucinare",
    "fucinerebbero": "fucinare",
    "fucinerei": "fucinare",
    "fucineremmo": "fucinare",
    "fucineremo": "fucinare",
    "fucinereste": "fucinare",
    "fucineresti": "fucinare",
    "fucinerete": "fucinare",
    "fucinerà": "fucinare",
    "fucinerò": "fucinare",
    "fucini": "fucinare",
    "fuciniamo": "fucinare",
    "fuciniate": "fucinare",
    "fucinin": "fucinare",
    "fucinino": "fucinare",
    "fucino": "fucinare",
    "fucinò": "fucinare",
    "fuga": "fugare",
    "fugaci": "fugace",
    "fugai": "fugare",
    "fugammo": "fugare",
    "fugan": "fugare",
    "fugando": "fugare",
    "fugano": "fugare",
    "fugante": "fugare",
    "fuganti": "fugare",
    "fugar": "fugare",
    "fugaron": "fugare",
    "fugarono": "fugare",
    "fugasse": "fugare",
    "fugasser": "fugare",
    "fugassero": "fugare",
    "fugassi": "fugare",
    "fugassimo": "fugare",
    "fugaste": "fugare",
    "fugasti": "fugare",
    "fugata": "fugato",
    "fugate": "fugato",
    "fugati": "fugato",
    "fugato": "fugare",
    "fugava": "fugare",
    "fugavamo": "fugare",
    "fugavan": "fugare",
    "fugavano": "fugare",
    "fugavate": "fugare",
    "fugavi": "fugare",
    "fugavo": "fugare",
    "fugga": "fuggire",
    "fuggan": "fuggire",
    "fuggano": "fuggire",
    "fugge": "fuggire",
    "fuggendo": "fuggire",
    "fuggente": "fuggire",
    "fuggenti": "fuggire",
    "fuggevoli": "fuggevole",
    "fuggi": "fuggire",
    "fuggiamo": "fuggire",
    "fuggiasca": "fuggiasco",
    "fuggiasche": "fuggiasco",
    "fuggiaschi": "fuggiasco",
    "fuggiate": "fuggire",
    "fuggii": "fuggire",
    "fuggimmo": "fuggire",
    "fuggir": "fuggire",
    "fuggirai": "fuggire",
    "fuggiran": "fuggire",
    "fuggiranno": "fuggire",
    "fuggirebbe": "fuggire",
    "fuggirebber": "fuggire",
    "fuggirebbero": "fuggire",
    "fuggirei": "fuggire",
    "fuggiremmo": "fuggire",
    "fuggiremo": "fuggire",
    "fuggireste": "fuggire",
    "fuggiresti": "fuggire",
    "fuggirete": "fuggire",
    "fuggiron": "fuggire",
    "fuggirono": "fuggire",
    "fuggirà": "fuggire",
    "fuggirò": "fuggire",
    "fuggisse": "fuggire",
    "fuggisser": "fuggire",
    "fuggissero": "fuggire",
    "fuggissi": "fuggire",
    "fuggissimo": "fuggire",
    "fuggiste": "fuggire",
    "fuggisti": "fuggire",
    "fuggita": "fuggire",
    "fuggite": "fuggire",
    "fuggiti": "fuggire",
    "fuggitiva": "fuggitivo",
    "fuggitive": "fuggitivo",
    "fuggitivi": "fuggitivo",
    "fuggito": "fuggire",
    "fuggiva": "fuggire",
    "fuggivamo": "fuggire",
    "fuggivan": "fuggire",
    "fuggivano": "fuggire",
    "fuggivate": "fuggire",
    "fuggivi": "fuggire",
    "fuggivo": "fuggire",
    "fuggo": "fuggire",
    "fuggon": "fuggire",
    "fuggono": "fuggire",
    "fuggì": "fuggire",
    "fughe": "fuga",
    "fugherai": "fugare",
    "fugheran": "fugare",
    "fugheranno": "fugare",
    "fugherebbe": "fugare",
    "fugherebber": "fugare",
    "fugherebbero": "fugare",
    "fugherei": "fugare",
    "fugheremmo": "fugare",
    "fugheremo": "fugare",
    "fughereste": "fugare",
    "fugheresti": "fugare",
    "fugherete": "fugare",
    "fugherà": "fugare",
    "fugherò": "fugare",
    "fughi": "fugare",
    "fughiamo": "fugare",
    "fughiate": "fugare",
    "fughin": "fugare",
    "fughino": "fugare",
    "fugo": "fugare",
    "fugò": "fugare",
    "fui": "essere",
    "fujimoriana": "fujimoriano",
    "fujimoriane": "fujimoriano",
    "fujimoriani": "fujimoriano",
    "fulcri": "fulcro",
    "fulga": "fulgere",
    "fulgan": "fulgere",
    "fulgano": "fulgere",
    "fulge": "fulgere",
    "fulgei": "fulgere",
    "fulgemmo": "fulgere",
    "fulgendo": "fulgere",
    "fulgente": "fulgere",
    "fulgenti": "fulgere",
    "fulger": "fulgere",
    "fulgerai": "fulgere",
    "fulgeran": "fulgere",
    "fulgeranno": "fulgere",
    "fulgerebbe": "fulgere",
    "fulgerebber": "fulgere",
    "fulgerebbero": "fulgere",
    "fulgerei": "fulgere",
    "fulgeremmo": "fulgere",
    "fulgeremo": "fulgere",
    "fulgereste": "fulgere",
    "fulgeresti": "fulgere",
    "fulgerete": "fulgere",
    "fulgeron": "fulgere",
    "fulgerono": "fulgere",
    "fulgerà": "fulgere",
    "fulgerò": "fulgere",
    "fulgesse": "fulgere",
    "fulgesser": "fulgere",
    "fulgessero": "fulgere",
    "fulgessi": "fulgere",
    "fulgessimo": "fulgere",
    "fulgeste": "fulgere",
    "fulgesti": "fulgere",
    "fulgete": "fulgere",
    "fulgeva": "fulgere",
    "fulgevamo": "fulgere",
    "fulgevan": "fulgere",
    "fulgevano": "fulgere",
    "fulgevate": "fulgere",
    "fulgevi": "fulgere",
    "fulgevo": "fulgere",
    "fulgi": "fulgere",
    "fulgiamo": "fulgere",
    "fulgiate": "fulgere",
    "fulgida": "fulgido",
    "fulgide": "fulgido",
    "fulgidi": "fulgido",
    "fulgo": "fulgere",
    "fulgon": "fulgere",
    "fulgono": "fulgere",
    "fulgori": "fulgore",
    "fulgè": "fulgere",
    "fulmina": "fulminare",
    "fulminai": "fulminare",
    "fulminammo": "fulminare",
    "fulminan": "fulminare",
    "fulminando": "fulminare",
    "fulminano": "fulminare",
    "fulminante": "fulminare",
    "fulminanti": "fulminare",
    "fulminar": "fulminare",
    "fulminaron": "fulminare",
    "fulminarono": "fulminare",
    "fulminasse": "fulminare",
    "fulminasser": "fulminare",
    "fulminassero": "fulminare",
    "fulminassi": "fulminare",
    "fulminassimo": "fulminare",
    "fulminaste": "fulminare",
    "fulminasti": "fulminare",
    "fulminata": "fulminato",
    "fulminate": "fulminato",
    "fulminati": "fulminato",
    "fulminato": "fulminare",
    "fulminava": "fulminare",
    "fulminavamo": "fulminare",
    "fulminavan": "fulminare",
    "fulminavano": "fulminare",
    "fulminavate": "fulminare",
    "fulminavi": "fulminare",
    "fulminavo": "fulminare",
    "fulminea": "fulmineo",
    "fulminee": "fulmineo",
    "fulminei": "fulmineo",
    "fulminerai": "fulminare",
    "fulmineran": "fulminare",
    "fulmineranno": "fulminare",
    "fulminerebbe": "fulminare",
    "fulminerebber": "fulminare",
    "fulminerebbero": "fulminare",
    "fulminerei": "fulminare",
    "fulmineremmo": "fulminare",
    "fulmineremo": "fulminare",
    "fulminereste": "fulminare",
    "fulmineresti": "fulminare",
    "fulminerete": "fulminare",
    "fulminerà": "fulminare",
    "fulminerò": "fulminare",
    "fulmini": "fulmine",
    "fulminiamo": "fulminare",
    "fulminiate": "fulminare",
    "fulminin": "fulminare",
    "fulminino": "fulminare",
    "fulmino": "fulminare",
    "fulminò": "fulminare",
    "fulta": "fulgere",
    "fulte": "fulgere",
    "fulti": "fulgere",
    "fulto": "fulgere",
    "fulva": "fulvo",
    "fulve": "fulvo",
    "fulvi": "fulvo",
    "fuma": "fumare",
    "fumai": "fumare",
    "fumaioli": "fumaiolo",
    "fumammo": "fumare",
    "fuman": "fumare",
    "fumando": "fumare",
    "fumano": "fumare",
    "fumante": "fumare",
    "fumanti": "fumare",
    "fumar": "fumare",
    "fumaron": "fumare",
    "fumarono": "fumare",
    "fumasse": "fumare",
    "fumasser": "fumare",
    "fumassero": "fumare",
    "fumassi": "fumare",
    "fumassimo": "fumare",
    "fumaste": "fumare",
    "fumasti": "fumare",
    "fumata": "fumare",
    "fumate": "fumata",
    "fumati": "fumare",
    "fumato": "fumare",
    "fumatori": "fumatore",
    "fumatrici": "fumatrice",
    "fumava": "fumare",
    "fumavamo": "fumare",
    "fumavan": "fumare",
    "fumavano": "fumare",
    "fumavate": "fumare",
    "fumavi": "fumare",
    "fumavo": "fumare",
    "fumerai": "fumare",
    "fumeran": "fumare",
    "fumeranno": "fumare",
    "fumerebbe": "fumare",
    "fumerebber": "fumare",
    "fumerebbero": "fumare",
    "fumerei": "fumare",
    "fumeremmo": "fumare",
    "fumeremo": "fumare",
    "fumereste": "fumare",
    "fumeresti": "fumare",
    "fumerete": "fumare",
    "fumerie": "fumeria",
    "fumerà": "fumare",
    "fumerò": "fumare",
    "fumettari": "fumettaro",
    "fumetti": "fumetto",
    "fumettoni": "fumettone",
    "fumi": "fumo",
    "fumiamo": "fumare",
    "fumiate": "fumare",
    "fumiga": "fumigare",
    "fumigai": "fumigare",
    "fumigammo": "fumigare",
    "fumigan": "fumigare",
    "fumigando": "fumigare",
    "fumigano": "fumigare",
    "fumigante": "fumigare",
    "fumiganti": "fumigare",
    "fumigar": "fumigare",
    "fumigaron": "fumigare",
    "fumigarono": "fumigare",
    "fumigasse": "fumigare",
    "fumigasser": "fumigare",
    "fumigassero": "fumigare",
    "fumigassi": "fumigare",
    "fumigassimo": "fumigare",
    "fumigaste": "fumigare",
    "fumigasti": "fumigare",
    "fumigata": "fumigare",
    "fumigate": "fumigare",
    "fumigati": "fumigare",
    "fumigato": "fumigare",
    "fumigava": "fumigare",
    "fumigavamo": "fumigare",
    "fumigavan": "fumigare",
    "fumigavano": "fumigare",
    "fumigavate": "fumigare",
    "fumigavi": "fumigare",
    "fumigavo": "fumigare",
    "fumigherai": "fumigare",
    "fumigheran": "fumigare",
    "fumigheranno": "fumigare",
    "fumigherebbe": "fumigare",
    "fumigherebber": "fumigare",
    "fumigherebbero": "fumigare",
    "fumigherei": "fumigare",
    "fumigheremmo": "fumigare",
    "fumigheremo": "fumigare",
    "fumighereste": "fumigare",
    "fumigheresti": "fumigare",
    "fumigherete": "fumigare",
    "fumigherà": "fumigare",
    "fumigherò": "fumigare",
    "fumighi": "fumigare",
    "fumighiamo": "fumigare",
    "fumighiate": "fumigare",
    "fumighin": "fumigare",
    "fumighino": "fumigare",
    "fumigo": "fumigare",
    "fumigò": "fumigare",
    "fumin": "fumare",
    "fumino": "fumare",
    "fumisterie": "fumisteria",
    "fummo": "essere",
    "fumo": "fumare",
    "fumogena": "fumogeno",
    "fumogene": "fumogeno",
    "fumogeni": "fumogeno",
    "fumosa": "fumoso",
    "fumose": "fumoso",
    "fumosi": "fumoso",
    "fumò": "fumare",
    "funamboli": "funambolo",
    "funambolismi": "funambolismo",
    "funebri": "funebre",
    "funerali": "funerale",
    "funerari": "funerario",
    "funeraria": "funerario",
    "funerarie": "funerario",
    "funerea": "funereo",
    "funeree": "funereo",
    "funerei": "funereo",
    "funesta": "funesto",
    "funestai": "funestare",
    "funestammo": "funestare",
    "funestan": "funestare",
    "funestando": "funestare",
    "funestano": "funestare",
    "funestante": "funestare",
    "funestanti": "funestare",
    "funestar": "funestare",
    "funestaron": "funestare",
    "funestarono": "funestare",
    "funestasse": "funestare",
    "funestasser": "funestare",
    "funestassero": "funestare",
    "funestassi": "funestare",
    "funestassimo": "funestare",
    "funestaste": "funestare",
    "funestasti": "funestare",
    "funestata": "funestare",
    "funestate": "funestare",
    "funestati": "funestare",
    "funestato": "funestare",
    "funestava": "funestare",
    "funestavamo": "funestare",
    "funestavan": "funestare",
    "funestavano": "funestare",
    "funestavate": "funestare",
    "funestavi": "funestare",
    "funestavo": "funestare",
    "funeste": "funesto",
    "funesterai": "funestare",
    "funesteran": "funestare",
    "funesteranno": "funestare",
    "funesterebbe": "funestare",
    "funesterebber": "funestare",
    "funesterebbero": "funestare",
    "funesterei": "funestare",
    "funesteremmo": "funestare",
    "funesteremo": "funestare",
    "funestereste": "funestare",
    "funesteresti": "funestare",
    "funesterete": "funestare",
    "funesterà": "funestare",
    "funesterò": "funestare",
    "funesti": "funesto",
    "funestiamo": "funestare",
    "funestiate": "funestare",
    "funestin": "funestare",
    "funestino": "funestare",
    "funesto": "funestare",
    "funestò": "funestare",
    "funga": "fungere",
    "fungan": "fungere",
    "fungano": "fungere",
    "funge": "fungere",
    "fungemmo": "fungere",
    "fungendo": "fungere",
    "fungente": "fungere",
    "fungenti": "fungere",
    "funger": "fungere",
    "fungerai": "fungere",
    "fungeran": "fungere",
    "fungeranno": "fungere",
    "fungerebbe": "fungere",
    "fungerebber": "fungere",
    "fungerebbero": "fungere",
    "fungerei": "fungere",
    "fungeremmo": "fungere",
    "fungeremo": "fungere",
    "fungereste": "fungere",
    "fungeresti": "fungere",
    "fungerete": "fungere",
    "fungerà": "fungere",
    "fungerò": "fungere",
    "fungesse": "fungere",
    "fungesser": "fungere",
    "fungessero": "fungere",
    "fungessi": "fungere",
    "fungessimo": "fungere",
    "fungeste": "fungere",
    "fungesti": "fungere",
    "fungete": "fungere",
    "fungeva": "fungere",
    "fungevamo": "fungere",
    "fungevan": "fungere",
    "fungevano": "fungere",
    "fungevate": "fungere",
    "fungevi": "fungere",
    "fungevo": "fungere",
    "funghi": "fungo",
    "fungi": "fungere",
    "fungiamo": "fungere",
    "fungiate": "fungere",
    "fungo": "fungere",
    "fungon": "fungere",
    "fungono": "fungere",
    "funi": "fune",
    "funicola": "funicolare",
    "funicolai": "funicolare",
    "funicolammo": "funicolare",
    "funicolan": "funicolare",
    "funicolando": "funicolare",
    "funicolano": "funicolare",
    "funicolante": "funicolare",
    "funicolanti": "funicolare",
    "funicolar": "funicolare",
    "funicolari": "funicolare",
    "funicolaron": "funicolare",
    "funicolarono": "funicolare",
    "funicolasse": "funicolare",
    "funicolasser": "funicolare",
    "funicolassero": "funicolare",
    "funicolassi": "funicolare",
    "funicolassimo": "funicolare",
    "funicolaste": "funicolare",
    "funicolasti": "funicolare",
    "funicolata": "funicolare",
    "funicolate": "funicolare",
    "funicolati": "funicolare",
    "funicolato": "funicolare",
    "funicolava": "funicolare",
    "funicolavamo": "funicolare",
    "funicolavan": "funicolare",
    "funicolavano": "funicolare",
    "funicolavate": "funicolare",
    "funicolavi": "funicolare",
    "funicolavo": "funicolare",
    "funicolerai": "funicolare",
    "funicoleran": "funicolare",
    "funicoleranno": "funicolare",
    "funicolerebbe": "funicolare",
    "funicolerebber": "funicolare",
    "funicolerebbero": "funicolare",
    "funicolerei": "funicolare",
    "funicoleremmo": "funicolare",
    "funicoleremo": "funicolare",
    "funicolereste": "funicolare",
    "funicoleresti": "funicolare",
    "funicolerete": "funicolare",
    "funicolerà": "funicolare",
    "funicolerò": "funicolare",
    "funicoli": "funicolare",
    "funicoliamo": "funicolare",
    "funicoliate": "funicolare",
    "funicolin": "funicolare",
    "funicolino": "funicolare",
    "funicolo": "funicolare",
    "funicolò": "funicolare",
    "funivie": "funivia",
    "funser": "fungere",
    "funsero": "fungere",
    "funsi": "fungere",
    "funsè": "fungere",
    "funta": "fungere",
    "funte": "fungere",
    "funti": "fungere",
    "funto": "fungere",
    "funziona": "funzionare",
    "funzionai": "funzionare",
    "funzionali": "funzionale",
    "funzionamenti": "funzionamento",
    "funzionammo": "funzionare",
    "funzionan": "funzionare",
    "funzionando": "funzionare",
    "funzionano": "funzionare",
    "funzionante": "funzionare",
    "funzionanti": "funzionare",
    "funzionar": "funzionare",
    "funzionari": "funzionario",
    "funzionarie": "funzionaria",
    "funzionaron": "funzionare",
    "funzionarono": "funzionare",
    "funzionasse": "funzionare",
    "funzionasser": "funzionare",
    "funzionassero": "funzionare",
    "funzionassi": "funzionare",
    "funzionassimo": "funzionare",
    "funzionaste": "funzionare",
    "funzionasti": "funzionare",
    "funzionata": "funzionare",
    "funzionate": "funzionare",
    "funzionati": "funzionare",
    "funzionato": "funzionare",
    "funzionava": "funzionare",
    "funzionavamo": "funzionare",
    "funzionavan": "funzionare",
    "funzionavano": "funzionare",
    "funzionavate": "funzionare",
    "funzionavi": "funzionare",
    "funzionavo": "funzionare",
    "funzionerai": "funzionare",
    "funzioneran": "funzionare",
    "funzioneranno": "funzionare",
    "funzionerebbe": "funzionare",
    "funzionerebber": "funzionare",
    "funzionerebbero": "funzionare",
    "funzionerei": "funzionare",
    "funzioneremmo": "funzionare",
    "funzioneremo": "funzionare",
    "funzionereste": "funzionare",
    "funzioneresti": "funzionare",
    "funzionerete": "funzionare",
    "funzionerà": "funzionare",
    "funzionerò": "funzionare",
    "funzioni": "funzione",
    "funzioniamo": "funzionare",
    "funzioniate": "funzionare",
    "funzionin": "funzionare",
    "funzionino": "funzionare",
    "funziono": "funzionare",
    "funzionò": "funzionare",
    "fuocherelli": "fuocherello",
    "fuochi": "fuoco",
    "fuochisti": "fuochista",
    "fuoriesca": "fuoriuscire",
    "fuoriescan": "fuoriuscire",
    "fuoriescano": "fuoriuscire",
    "fuoriesce": "fuoriuscire",
    "fuoriesci": "fuoriuscire",
    "fuoriesco": "fuoriuscire",
    "fuoriescon": "fuoriuscire",
    "fuoriescono": "fuoriuscire",
    "fuoriserii": "fuoriserie",
    "fuoriuscendo": "fuoriuscire",
    "fuoriuscente": "fuoriuscire",
    "fuoriuscenti": "fuoriuscire",
    "fuoriusciamo": "fuoriuscire",
    "fuoriusciate": "fuoriuscire",
    "fuoriuscii": "fuoriuscire",
    "fuoriuscimmo": "fuoriuscire",
    "fuoriuscir": "fuoriuscire",
    "fuoriuscirai": "fuoriuscire",
    "fuoriusciran": "fuoriuscire",
    "fuoriusciranno": "fuoriuscire",
    "fuoriuscirebbe": "fuoriuscire",
    "fuoriuscirebber": "fuoriuscire",
    "fuoriuscirebbero": "fuoriuscire",
    "fuoriuscirei": "fuoriuscire",
    "fuoriusciremmo": "fuoriuscire",
    "fuoriusciremo": "fuoriuscire",
    "fuoriuscireste": "fuoriuscire",
    "fuoriusciresti": "fuoriuscire",
    "fuoriuscirete": "fuoriuscire",
    "fuoriusciron": "fuoriuscire",
    "fuoriuscirono": "fuoriuscire",
    "fuoriuscirà": "fuoriuscire",
    "fuoriuscirò": "fuoriuscire",
    "fuoriuscisse": "fuoriuscire",
    "fuoriuscisser": "fuoriuscire",
    "fuoriuscissero": "fuoriuscire",
    "fuoriuscissi": "fuoriuscire",
    "fuoriuscissimo": "fuoriuscire",
    "fuoriusciste": "fuoriuscire",
    "fuoriuscisti": "fuoriuscire",
    "fuoriuscita": "fuoriuscito",
    "fuoriuscite": "fuoriuscito",
    "fuoriusciti": "fuoriuscito",
    "fuoriuscito": "fuoriuscire",
    "fuoriusciva": "fuoriuscire",
    "fuoriuscivamo": "fuoriuscire",
    "fuoriuscivan": "fuoriuscire",
    "fuoriuscivano": "fuoriuscire",
    "fuoriuscivate": "fuoriuscire",
    "fuoriuscivi": "fuoriuscire",
    "fuoriuscivo": "fuoriuscire",
    "fuoriuscì": "fuoriuscire",
    "fuorusca": "fuoruscire",
    "fuoruscan": "fuoruscire",
    "fuoruscano": "fuoruscire",
    "fuorusce": "fuoruscire",
    "fuoruscendo": "fuoruscire",
    "fuoruscente": "fuoruscire",
    "fuoruscenti": "fuoruscire",
    "fuorusci": "fuoruscire",
    "fuorusciamo": "fuoruscire",
    "fuorusciate": "fuoruscire",
    "fuoruscii": "fuoruscire",
    "fuoruscimmo": "fuoruscire",
    "fuoruscir": "fuoruscire",
    "fuoruscirai": "fuoruscire",
    "fuorusciran": "fuoruscire",
    "fuorusciranno": "fuoruscire",
    "fuoruscirebbe": "fuoruscire",
    "fuoruscirebber": "fuoruscire",
    "fuoruscirebbero": "fuoruscire",
    "fuoruscirei": "fuoruscire",
    "fuorusciremmo": "fuoruscire",
    "fuorusciremo": "fuoruscire",
    "fuoruscireste": "fuoruscire",
    "fuorusciresti": "fuoruscire",
    "fuoruscirete": "fuoruscire",
    "fuorusciron": "fuoruscire",
    "fuoruscirono": "fuoruscire",
    "fuoruscirà": "fuoruscire",
    "fuoruscirò": "fuoruscire",
    "fuoruscisse": "fuoruscire",
    "fuoruscisser": "fuoruscire",
    "fuoruscissero": "fuoruscire",
    "fuoruscissi": "fuoruscire",
    "fuoruscissimo": "fuoruscire",
    "fuorusciste": "fuoruscire",
    "fuoruscisti": "fuoruscire",
    "fuoruscita": "fuoruscire",
    "fuoruscite": "fuoruscita",
    "fuorusciti": "fuoruscito",
    "fuoruscito": "fuoruscire",
    "fuorusciva": "fuoruscire",
    "fuoruscivamo": "fuoruscire",
    "fuoruscivan": "fuoruscire",
    "fuoruscivano": "fuoruscire",
    "fuoruscivate": "fuoruscire",
    "fuoruscivi": "fuoruscire",
    "fuoruscivo": "fuoruscire",
    "fuorusco": "fuoruscire",
    "fuoruscon": "fuoruscire",
    "fuoruscono": "fuoruscire",
    "fuoruscì": "fuoruscire",
    "fuorvi": "fuorviare",
    "fuorvia": "fuorviare",
    "fuorviai": "fuorviare",
    "fuorviammo": "fuorviare",
    "fuorviamo": "fuorviare",
    "fuorvian": "fuorviare",
    "fuorviando": "fuorviare",
    "fuorviano": "fuorviare",
    "fuorviante": "fuorviare",
    "fuorvianti": "fuorviare",
    "fuorviar": "fuorviare",
    "fuorviaron": "fuorviare",
    "fuorviarono": "fuorviare",
    "fuorviasse": "fuorviare",
    "fuorviasser": "fuorviare",
    "fuorviassero": "fuorviare",
    "fuorviassi": "fuorviare",
    "fuorviassimo": "fuorviare",
    "fuorviaste": "fuorviare",
    "fuorviasti": "fuorviare",
    "fuorviata": "fuorviare",
    "fuorviate": "fuorviare",
    "fuorviati": "fuorviare",
    "fuorviato": "fuorviare",
    "fuorviava": "fuorviare",
    "fuorviavamo": "fuorviare",
    "fuorviavan": "fuorviare",
    "fuorviavano": "fuorviare",
    "fuorviavate": "fuorviare",
    "fuorviavi": "fuorviare",
    "fuorviavo": "fuorviare",
    "fuorvierai": "fuorviare",
    "fuorvieran": "fuorviare",
    "fuorvieranno": "fuorviare",
    "fuorvierebbe": "fuorviare",
    "fuorvierebber": "fuorviare",
    "fuorvierebbero": "fuorviare",
    "fuorvierei": "fuorviare",
    "fuorvieremmo": "fuorviare",
    "fuorvieremo": "fuorviare",
    "fuorviereste": "fuorviare",
    "fuorvieresti": "fuorviare",
    "fuorvierete": "fuorviare",
    "fuorvierà": "fuorviare",
    "fuorvierò": "fuorviare",
    "fuorvin": "fuorviare",
    "fuorvino": "fuorviare",
    "fuorvio": "fuorviare",
    "fuorviò": "fuorviare",
    "furba": "furbo",
    "furbacchioni": "furbacchione",
    "furbastri": "furbastro",
    "furbate": "furbata",
    "furbe": "furbo",
    "furberie": "furberia",
    "furbesca": "furbesco",
    "furbesche": "furbesco",
    "furbeschi": "furbesco",
    "furbi": "furbo",
    "furbizie": "furbizia",
    "furboni": "furbone",
    "furenti": "furente",
    "furerie": "fureria",
    "furetti": "furetto",
    "furfanti": "furfante",
    "furgoncini": "furgoncino",
    "furgoni": "furgone",
    "furibonda": "furibondo",
    "furibonde": "furibondo",
    "furibondi": "furibondo",
    "furie": "furia",
    "furiosa": "furioso",
    "furiose": "furioso",
    "furiosi": "furioso",
    "furlani": "furlano",
    "furon": "essere",
    "furono": "essere",
    "furoreggerai": "furoreggiare",
    "furoreggeran": "furoreggiare",
    "furoreggeranno": "furoreggiare",
    "furoreggerebbe": "furoreggiare",
    "furoreggerebber": "furoreggiare",
    "furoreggerebbero": "furoreggiare",
    "furoreggerei": "furoreggiare",
    "furoreggeremmo": "furoreggiare",
    "furoreggeremo": "furoreggiare",
    "furoreggereste": "furoreggiare",
    "furoreggeresti": "furoreggiare",
    "furoreggerete": "furoreggiare",
    "furoreggerà": "furoreggiare",
    "furoreggerò": "furoreggiare",
    "furoreggi": "furoreggiare",
    "furoreggia": "furoreggiare",
    "furoreggiai": "furoreggiare",
    "furoreggiammo": "furoreggiare",
    "furoreggiamo": "furoreggiare",
    "furoreggian": "furoreggiare",
    "furoreggiando": "furoreggiare",
    "furoreggiano": "furoreggiare",
    "furoreggiante": "furoreggiare",
    "furoreggianti": "furoreggiare",
    "furoreggiar": "furoreggiare",
    "furoreggiaron": "furoreggiare",
    "furoreggiarono": "furoreggiare",
    "furoreggiasse": "furoreggiare",
    "furoreggiasser": "furoreggiare",
    "furoreggiassero": "furoreggiare",
    "furoreggiassi": "furoreggiare",
    "furoreggiassimo": "furoreggiare",
    "furoreggiaste": "furoreggiare",
    "furoreggiasti": "furoreggiare",
    "furoreggiata": "furoreggiare",
    "furoreggiate": "furoreggiare",
    "furoreggiati": "furoreggiare",
    "furoreggiato": "furoreggiare",
    "furoreggiava": "furoreggiare",
    "furoreggiavamo": "furoreggiare",
    "furoreggiavan": "furoreggiare",
    "furoreggiavano": "furoreggiare",
    "furoreggiavate": "furoreggiare",
    "furoreggiavi": "furoreggiare",
    "furoreggiavo": "furoreggiare",
    "furoreggin": "furoreggiare",
    "furoreggino": "furoreggiare",
    "furoreggio": "furoreggiare",
    "furoreggiò": "furoreggiare",
    "furori": "furore",
    "furtarelli": "furtarello",
    "furti": "furto",
    "furtiva": "furtivo",
    "furtive": "furtivo",
    "furtivi": "furtivo",
    "fusa": "fuso",
    "fuscelli": "fuscello",
    "fuse": "fuso",
    "fuser": "fondere",
    "fusero": "fondere",
    "fusi": "fuso",
    "fusilli": "fusillo",
    "fusioni": "fusione",
    "fuso": "fondere",
    "fusoliere": "fusoliera",
    "fustella": "fustellare",
    "fustellai": "fustellare",
    "fustellammo": "fustellare",
    "fustellan": "fustellare",
    "fustellando": "fustellare",
    "fustellano": "fustellare",
    "fustellante": "fustellare",
    "fustellanti": "fustellare",
    "fustellar": "fustellare",
    "fustellaron": "fustellare",
    "fustellarono": "fustellare",
    "fustellasse": "fustellare",
    "fustellasser": "fustellare",
    "fustellassero": "fustellare",
    "fustellassi": "fustellare",
    "fustellassimo": "fustellare",
    "fustellaste": "fustellare",
    "fustellasti": "fustellare",
    "fustellata": "fustellare",
    "fustellate": "fustellare",
    "fustellati": "fustellare",
    "fustellato": "fustellare",
    "fustellava": "fustellare",
    "fustellavamo": "fustellare",
    "fustellavan": "fustellare",
    "fustellavano": "fustellare",
    "fustellavate": "fustellare",
    "fustellavi": "fustellare",
    "fustellavo": "fustellare",
    "fustelle": "fustella",
    "fustellerai": "fustellare",
    "fustelleran": "fustellare",
    "fustelleranno": "fustellare",
    "fustellerebbe": "fustellare",
    "fustellerebber": "fustellare",
    "fustellerebbero": "fustellare",
    "fustellerei": "fustellare",
    "fustelleremmo": "fustellare",
    "fustelleremo": "fustellare",
    "fustellereste": "fustellare",
    "fustelleresti": "fustellare",
    "fustellerete": "fustellare",
    "fustellerà": "fustellare",
    "fustellerò": "fustellare",
    "fustelli": "fustellare",
    "fustelliamo": "fustellare",
    "fustelliate": "fustellare",
    "fustellin": "fustellare",
    "fustellino": "fustellare",
    "fustello": "fustellare",
    "fustellò": "fustellare",
    "fusti": "fusto",
    "fustiga": "fustigare",
    "fustigai": "fustigare",
    "fustigammo": "fustigare",
    "fustigan": "fustigare",
    "fustigando": "fustigare",
    "fustigano": "fustigare",
    "fustigante": "fustigare",
    "fustiganti": "fustigare",
    "fustigar": "fustigare",
    "fustigaron": "fustigare",
    "fustigarono": "fustigare",
    "fustigasse": "fustigare",
    "fustigasser": "fustigare",
    "fustigassero": "fustigare",
    "fustigassi": "fustigare",
    "fustigassimo": "fustigare",
    "fustigaste": "fustigare",
    "fustigasti": "fustigare",
    "fustigata": "fustigare",
    "fustigate": "fustigare",
    "fustigati": "fustigare",
    "fustigato": "fustigare",
    "fustigatori": "fustigatore",
    "fustigatrice": "fustigatore",
    "fustigatrici": "fustigatore",
    "fustigava": "fustigare",
    "fustigavamo": "fustigare",
    "fustigavan": "fustigare",
    "fustigavano": "fustigare",
    "fustigavate": "fustigare",
    "fustigavi": "fustigare",
    "fustigavo": "fustigare",
    "fustigherai": "fustigare",
    "fustigheran": "fustigare",
    "fustigheranno": "fustigare",
    "fustigherebbe": "fustigare",
    "fustigherebber": "fustigare",
    "fustigherebbero": "fustigare",
    "fustigherei": "fustigare",
    "fustigheremmo": "fustigare",
    "fustigheremo": "fustigare",
    "fustighereste": "fustigare",
    "fustigheresti": "fustigare",
    "fustigherete": "fustigare",
    "fustigherà": "fustigare",
    "fustigherò": "fustigare",
    "fustighi": "fustigare",
    "fustighiamo": "fustigare",
    "fustighiate": "fustigare",
    "fustighin": "fustigare",
    "fustighino": "fustigare",
    "fustigo": "fustigare",
    "fustigò": "fustigare",
    "fustini": "fustino",
    "futili": "futile",
    "futura": "futuro",
    "future": "futuro",
    "futuri": "futuro",
    "futuribili": "futuribile",
    "futurismi": "futurismo",
    "futuriste": "futurista",
    "futuristi": "futurista",
    "futurologi": "futurologo",
    "gabba": "gabbare",
    "gabbai": "gabbare",
    "gabbammo": "gabbare",
    "gabban": "gabbare",
    "gabbando": "gabbare",
    "gabbano": "gabbare",
    "gabbante": "gabbare",
    "gabbanti": "gabbare",
    "gabbar": "gabbare",
    "gabbaron": "gabbare",
    "gabbarono": "gabbare",
    "gabbasse": "gabbare",
    "gabbasser": "gabbare",
    "gabbassero": "gabbare",
    "gabbassi": "gabbare",
    "gabbassimo": "gabbare",
    "gabbaste": "gabbare",
    "gabbasti": "gabbare",
    "gabbata": "gabbare",
    "gabbate": "gabbare",
    "gabbati": "gabbare",
    "gabbato": "gabbare",
    "gabbava": "gabbare",
    "gabbavamo": "gabbare",
    "gabbavan": "gabbare",
    "gabbavano": "gabbare",
    "gabbavate": "gabbare",
    "gabbavi": "gabbare",
    "gabbavo": "gabbare",
    "gabberai": "gabbare",
    "gabberan": "gabbare",
    "gabberanno": "gabbare",
    "gabberebbe": "gabbare",
    "gabberebber": "gabbare",
    "gabberebbero": "gabbare",
    "gabberei": "gabbare",
    "gabberemmo": "gabbare",
    "gabberemo": "gabbare",
    "gabbereste": "gabbare",
    "gabberesti": "gabbare",
    "gabberete": "gabbare",
    "gabberà": "gabbare",
    "gabberò": "gabbare",
    "gabbi": "gabbare",
    "gabbiamo": "gabbare",
    "gabbianelle": "gabbianella",
    "gabbiani": "gabbiano",
    "gabbiate": "gabbare",
    "gabbie": "gabbia",
    "gabbiette": "gabbietta",
    "gabbin": "gabbare",
    "gabbino": "gabbare",
    "gabbioni": "gabbione",
    "gabbiotti": "gabbiotto",
    "gabbo": "gabbare",
    "gabbò": "gabbare",
    "gabella": "gabellare",
    "gabellai": "gabellare",
    "gabellammo": "gabellare",
    "gabellan": "gabellare",
    "gabellando": "gabellare",
    "gabellano": "gabellare",
    "gabellante": "gabellare",
    "gabellanti": "gabellare",
    "gabellar": "gabellare",
    "gabellaron": "gabellare",
    "gabellarono": "gabellare",
    "gabellasse": "gabellare",
    "gabellasser": "gabellare",
    "gabellassero": "gabellare",
    "gabellassi": "gabellare",
    "gabellassimo": "gabellare",
    "gabellaste": "gabellare",
    "gabellasti": "gabellare",
    "gabellata": "gabellare",
    "gabellate": "gabellare",
    "gabellati": "gabellare",
    "gabellato": "gabellare",
    "gabellava": "gabellare",
    "gabellavamo": "gabellare",
    "gabellavan": "gabellare",
    "gabellavano": "gabellare",
    "gabellavate": "gabellare",
    "gabellavi": "gabellare",
    "gabellavo": "gabellare",
    "gabelle": "gabella",
    "gabellerai": "gabellare",
    "gabelleran": "gabellare",
    "gabelleranno": "gabellare",
    "gabellerebbe": "gabellare",
    "gabellerebber": "gabellare",
    "gabellerebbero": "gabellare",
    "gabellerei": "gabellare",
    "gabelleremmo": "gabellare",
    "gabelleremo": "gabellare",
    "gabellereste": "gabellare",
    "gabelleresti": "gabellare",
    "gabellerete": "gabellare",
    "gabellerà": "gabellare",
    "gabellerò": "gabellare",
    "gabelli": "gabellare",
    "gabelliamo": "gabellare",
    "gabelliate": "gabellare",
    "gabellieri": "gabelliere",
    "gabellin": "gabellare",
    "gabellino": "gabellare",
    "gabello": "gabellare",
    "gabellò": "gabellare",
    "gabinetti": "gabinetto",
    "gabonesi": "gabonese",
    "gadgets": "gadget",
    "gaffes": "gaffe",
    "gagliarda": "gagliardo",
    "gagliarde": "gagliardo",
    "gagliardetti": "gagliardetto",
    "gagliardi": "gagliardo",
    "gaglioffa": "gaglioffo",
    "gaglioffe": "gaglioffo",
    "gaglioffi": "gaglioffo",
    "gai": "gaio",
    "gaia": "gaio",
    "gaie": "gaio",
    "gaiezze": "gaiezza",
    "galanterie": "galanteria",
    "galanti": "galante",
    "galantuoma": "galantuomo",
    "galantuome": "galantuomo",
    "galantuomi": "galantuomo",
    "galantuomini": "galantuomo",
    "galassie": "galassia",
    "galatei": "galateo",
    "galattica": "galattico",
    "galattiche": "galattico",
    "galattici": "galattico",
    "galeoni": "galeone",
    "galeotta": "galeotto",
    "galeotte": "galeotto",
    "galeotti": "galeotto",
    "galere": "galera",
    "galla": "gallare",
    "gallai": "gallare",
    "gallammo": "gallare",
    "gallan": "gallare",
    "gallando": "gallare",
    "gallano": "gallare",
    "gallante": "gallare",
    "gallanti": "gallare",
    "gallar": "gallare",
    "gallaron": "gallare",
    "gallarono": "gallare",
    "gallasse": "gallare",
    "gallasser": "gallare",
    "gallassero": "gallare",
    "gallassi": "gallare",
    "gallassimo": "gallare",
    "gallaste": "gallare",
    "gallasti": "gallare",
    "gallata": "gallare",
    "gallate": "gallare",
    "gallati": "gallare",
    "gallato": "gallare",
    "gallava": "gallare",
    "gallavamo": "gallare",
    "gallavan": "gallare",
    "gallavano": "gallare",
    "gallavate": "gallare",
    "gallavi": "gallare",
    "gallavo": "gallare",
    "galleggerai": "galleggiare",
    "galleggeran": "galleggiare",
    "galleggeranno": "galleggiare",
    "galleggerebbe": "galleggiare",
    "galleggerebber": "galleggiare",
    "galleggerebbero": "galleggiare",
    "galleggerei": "galleggiare",
    "galleggeremmo": "galleggiare",
    "galleggeremo": "galleggiare",
    "galleggereste": "galleggiare",
    "galleggeresti": "galleggiare",
    "galleggerete": "galleggiare",
    "galleggerà": "galleggiare",
    "galleggerò": "galleggiare",
    "galleggi": "galleggiare",
    "galleggia": "galleggiare",
    "galleggiai": "galleggiare",
    "galleggiamenti": "galleggiamento",
    "galleggiammo": "galleggiare",
    "galleggiamo": "galleggiare",
    "galleggian": "galleggiare",
    "galleggiando": "galleggiare",
    "galleggiano": "galleggiare",
    "galleggiante": "galleggiare",
    "galleggianti": "galleggiare",
    "galleggiar": "galleggiare",
    "galleggiaron": "galleggiare",
    "galleggiarono": "galleggiare",
    "galleggiasse": "galleggiare",
    "galleggiasser": "galleggiare",
    "galleggiassero": "galleggiare",
    "galleggiassi": "galleggiare",
    "galleggiassimo": "galleggiare",
    "galleggiaste": "galleggiare",
    "galleggiasti": "galleggiare",
    "galleggiata": "galleggiare",
    "galleggiate": "galleggiare",
    "galleggiati": "galleggiare",
    "galleggiato": "galleggiare",
    "galleggiava": "galleggiare",
    "galleggiavamo": "galleggiare",
    "galleggiavan": "galleggiare",
    "galleggiavano": "galleggiare",
    "galleggiavate": "galleggiare",
    "galleggiavi": "galleggiare",
    "galleggiavo": "galleggiare",
    "galleggin": "galleggiare",
    "galleggino": "galleggiare",
    "galleggio": "galleggiare",
    "galleggiò": "galleggiare",
    "gallerai": "gallare",
    "galleran": "gallare",
    "galleranno": "gallare",
    "gallerebbe": "gallare",
    "gallerebber": "gallare",
    "gallerebbero": "gallare",
    "gallerei": "gallare",
    "galleremmo": "gallare",
    "galleremo": "gallare",
    "gallereste": "gallare",
    "galleresti": "gallare",
    "gallerete": "gallare",
    "gallerie": "galleria",
    "galleristi": "gallerista",
    "gallerà": "gallare",
    "gallerò": "gallare",
    "gallesi": "gallese",
    "galletti": "galletto",
    "galli": "gallo",
    "galliamo": "gallare",
    "galliate": "gallare",
    "gallica": "gallico",
    "galliche": "gallico",
    "gallici": "gallico",
    "gallin": "gallare",
    "galline": "gallina",
    "gallino": "gallare",
    "gallo": "gallare",
    "gallona": "gallonare",
    "gallonai": "gallonare",
    "gallonammo": "gallonare",
    "gallonan": "gallonare",
    "gallonando": "gallonare",
    "gallonano": "gallonare",
    "gallonante": "gallonare",
    "gallonanti": "gallonare",
    "gallonar": "gallonare",
    "gallonaron": "gallonare",
    "gallonarono": "gallonare",
    "gallonasse": "gallonare",
    "gallonasser": "gallonare",
    "gallonassero": "gallonare",
    "gallonassi": "gallonare",
    "gallonassimo": "gallonare",
    "gallonaste": "gallonare",
    "gallonasti": "gallonare",
    "gallonata": "gallonare",
    "gallonate": "gallonare",
    "gallonati": "gallonare",
    "gallonato": "gallonare",
    "gallonava": "gallonare",
    "gallonavamo": "gallonare",
    "gallonavan": "gallonare",
    "gallonavano": "gallonare",
    "gallonavate": "gallonare",
    "gallonavi": "gallonare",
    "gallonavo": "gallonare",
    "gallonerai": "gallonare",
    "galloneran": "gallonare",
    "galloneranno": "gallonare",
    "gallonerebbe": "gallonare",
    "gallonerebber": "gallonare",
    "gallonerebbero": "gallonare",
    "gallonerei": "gallonare",
    "galloneremmo": "gallonare",
    "galloneremo": "gallonare",
    "gallonereste": "gallonare",
    "galloneresti": "gallonare",
    "gallonerete": "gallonare",
    "gallonerà": "gallonare",
    "gallonerò": "gallonare",
    "galloni": "gallone",
    "galloniamo": "gallonare",
    "galloniate": "gallonare",
    "gallonin": "gallonare",
    "gallonino": "gallonare",
    "gallono": "gallonare",
    "gallonò": "gallonare",
    "gallò": "gallare",
    "galoppa": "galoppare",
    "galoppai": "galoppare",
    "galoppammo": "galoppare",
    "galoppan": "galoppare",
    "galoppando": "galoppare",
    "galoppano": "galoppare",
    "galoppante": "galoppare",
    "galoppanti": "galoppare",
    "galoppar": "galoppare",
    "galopparon": "galoppare",
    "galopparono": "galoppare",
    "galoppasse": "galoppare",
    "galoppasser": "galoppare",
    "galoppassero": "galoppare",
    "galoppassi": "galoppare",
    "galoppassimo": "galoppare",
    "galoppaste": "galoppare",
    "galoppasti": "galoppare",
    "galoppata": "galoppare",
    "galoppate": "galoppata",
    "galoppati": "galoppare",
    "galoppato": "galoppare",
    "galoppava": "galoppare",
    "galoppavamo": "galoppare",
    "galoppavan": "galoppare",
    "galoppavano": "galoppare",
    "galoppavate": "galoppare",
    "galoppavi": "galoppare",
    "galoppavo": "galoppare",
    "galopperai": "galoppare",
    "galopperan": "galoppare",
    "galopperanno": "galoppare",
    "galopperebbe": "galoppare",
    "galopperebber": "galoppare",
    "galopperebbero": "galoppare",
    "galopperei": "galoppare",
    "galopperemmo": "galoppare",
    "galopperemo": "galoppare",
    "galoppereste": "galoppare",
    "galopperesti": "galoppare",
    "galopperete": "galoppare",
    "galopperà": "galoppare",
    "galopperò": "galoppare",
    "galoppi": "galoppo",
    "galoppiamo": "galoppare",
    "galoppiate": "galoppare",
    "galoppin": "galoppare",
    "galoppini": "galoppino",
    "galoppino": "galoppare",
    "galoppo": "galoppare",
    "galoppò": "galoppare",
    "galvanica": "galvanico",
    "galvaniche": "galvanico",
    "galvanici": "galvanico",
    "galvanizza": "galvanizzare",
    "galvanizzai": "galvanizzare",
    "galvanizzammo": "galvanizzare",
    "galvanizzan": "galvanizzare",
    "galvanizzando": "galvanizzare",
    "galvanizzano": "galvanizzare",
    "galvanizzante": "galvanizzare",
    "galvanizzanti": "galvanizzare",
    "galvanizzar": "galvanizzare",
    "galvanizzaron": "galvanizzare",
    "galvanizzarono": "galvanizzare",
    "galvanizzasse": "galvanizzare",
    "galvanizzasser": "galvanizzare",
    "galvanizzassero": "galvanizzare",
    "galvanizzassi": "galvanizzare",
    "galvanizzassimo": "galvanizzare",
    "galvanizzaste": "galvanizzare",
    "galvanizzasti": "galvanizzare",
    "galvanizzata": "galvanizzare",
    "galvanizzate": "galvanizzare",
    "galvanizzati": "galvanizzare",
    "galvanizzato": "galvanizzare",
    "galvanizzava": "galvanizzare",
    "galvanizzavamo": "galvanizzare",
    "galvanizzavan": "galvanizzare",
    "galvanizzavano": "galvanizzare",
    "galvanizzavate": "galvanizzare",
    "galvanizzavi": "galvanizzare",
    "galvanizzavo": "galvanizzare",
    "galvanizzerai": "galvanizzare",
    "galvanizzeran": "galvanizzare",
    "galvanizzeranno": "galvanizzare",
    "galvanizzerebbe": "galvanizzare",
    "galvanizzerebber": "galvanizzare",
    "galvanizzerebbero": "galvanizzare",
    "galvanizzerei": "galvanizzare",
    "galvanizzeremmo": "galvanizzare",
    "galvanizzeremo": "galvanizzare",
    "galvanizzereste": "galvanizzare",
    "galvanizzeresti": "galvanizzare",
    "galvanizzerete": "galvanizzare",
    "galvanizzerà": "galvanizzare",
    "galvanizzerò": "galvanizzare",
    "galvanizzi": "galvanizzare",
    "galvanizziamo": "galvanizzare",
    "galvanizziate": "galvanizzare",
    "galvanizzin": "galvanizzare",
    "galvanizzino": "galvanizzare",
    "galvanizzo": "galvanizzare",
    "galvanizzò": "galvanizzare",
    "gambe": "gamba",
    "gamberetti": "gamberetto",
    "gamberi": "gambero",
    "gambette": "gambetta",
    "gambi": "gambo",
    "gambizzazioni": "gambizzazione",
    "gambone": "gambona",
    "games": "game",
    "gamme": "gamma",
    "ganci": "gancio",
    "gangli": "ganglio",
    "gangsterismi": "gangsterismo",
    "gangsters": "gangster",
    "garantendo": "garantire",
    "garantente": "garantire",
    "garantenti": "garantire",
    "garanti": "garante",
    "garantiamo": "garantire",
    "garantiate": "garantire",
    "garantii": "garantire",
    "garantimmo": "garantire",
    "garantir": "garantire",
    "garantirai": "garantire",
    "garantiran": "garantire",
    "garantiranno": "garantire",
    "garantirebbe": "garantire",
    "garantirebber": "garantire",
    "garantirebbero": "garantire",
    "garantirei": "garantire",
    "garantiremmo": "garantire",
    "garantiremo": "garantire",
    "garantireste": "garantire",
    "garantiresti": "garantire",
    "garantirete": "garantire",
    "garantiron": "garantire",
    "garantirono": "garantire",
    "garantirà": "garantire",
    "garantirò": "garantire",
    "garantisca": "garantire",
    "garantiscan": "garantire",
    "garantiscano": "garantire",
    "garantisce": "garantire",
    "garantisci": "garantire",
    "garantisco": "garantire",
    "garantiscon": "garantire",
    "garantiscono": "garantire",
    "garantismi": "garantismo",
    "garantisse": "garantire",
    "garantisser": "garantire",
    "garantissero": "garantire",
    "garantissi": "garantire",
    "garantissimo": "garantire",
    "garantiste": "garantire",
    "garantisti": "garantista",
    "garantita": "garantito",
    "garantite": "garantito",
    "garantiti": "garantito",
    "garantito": "garantire",
    "garantiva": "garantire",
    "garantivamo": "garantire",
    "garantivan": "garantire",
    "garantivano": "garantire",
    "garantivate": "garantire",
    "garantivi": "garantire",
    "garantivo": "garantire",
    "garantì": "garantire",
    "garanzie": "garanzia",
    "garba": "garbare",
    "garbai": "garbare",
    "garbammo": "garbare",
    "garban": "garbare",
    "garbando": "garbare",
    "garbano": "garbare",
    "garbante": "garbare",
    "garbanti": "garbare",
    "garbar": "garbare",
    "garbaron": "garbare",
    "garbarono": "garbare",
    "garbasse": "garbare",
    "garbasser": "garbare",
    "garbassero": "garbare",
    "garbassi": "garbare",
    "garbassimo": "garbare",
    "garbaste": "garbare",
    "garbasti": "garbare",
    "garbata": "garbato",
    "garbate": "garbato",
    "garbati": "garbato",
    "garbato": "garbare",
    "garbava": "garbare",
    "garbavamo": "garbare",
    "garbavan": "garbare",
    "garbavano": "garbare",
    "garbavate": "garbare",
    "garbavi": "garbare",
    "garbavo": "garbare",
    "garberai": "garbare",
    "garberan": "garbare",
    "garberanno": "garbare",
    "garberebbe": "garbare",
    "garberebber": "garbare",
    "garberebbero": "garbare",
    "garberei": "garbare",
    "garberemmo": "garbare",
    "garberemo": "garbare",
    "garbereste": "garbare",
    "garberesti": "garbare",
    "garberete": "garbare",
    "garberà": "garbare",
    "garberò": "garbare",
    "garbi": "garbo",
    "garbiamo": "garbare",
    "garbiate": "garbare",
    "garbin": "garbare",
    "garbino": "garbare",
    "garbo": "garbare",
    "garbugli": "garbuglio",
    "garbò": "garbare",
    "gardenie": "gardenia",
    "gardesana": "gardesano",
    "gardesane": "gardesano",
    "gardesani": "gardesano",
    "gare": "gara",
    "gareggerai": "gareggiare",
    "gareggeran": "gareggiare",
    "gareggeranno": "gareggiare",
    "gareggerebbe": "gareggiare",
    "gareggerebber": "gareggiare",
    "gareggerebbero": "gareggiare",
    "gareggerei": "gareggiare",
    "gareggeremmo": "gareggiare",
    "gareggeremo": "gareggiare",
    "gareggereste": "gareggiare",
    "gareggeresti": "gareggiare",
    "gareggerete": "gareggiare",
    "gareggerà": "gareggiare",
    "gareggerò": "gareggiare",
    "gareggi": "gareggiare",
    "gareggia": "gareggiare",
    "gareggiai": "gareggiare",
    "gareggiammo": "gareggiare",
    "gareggiamo": "gareggiare",
    "gareggian": "gareggiare",
    "gareggiando": "gareggiare",
    "gareggiano": "gareggiare",
    "gareggiante": "gareggiare",
    "gareggianti": "gareggiare",
    "gareggiar": "gareggiare",
    "gareggiaron": "gareggiare",
    "gareggiarono": "gareggiare",
    "gareggiasse": "gareggiare",
    "gareggiasser": "gareggiare",
    "gareggiassero": "gareggiare",
    "gareggiassi": "gareggiare",
    "gareggiassimo": "gareggiare",
    "gareggiaste": "gareggiare",
    "gareggiasti": "gareggiare",
    "gareggiata": "gareggiare",
    "gareggiate": "gareggiare",
    "gareggiati": "gareggiare",
    "gareggiato": "gareggiare",
    "gareggiava": "gareggiare",
    "gareggiavamo": "gareggiare",
    "gareggiavan": "gareggiare",
    "gareggiavano": "gareggiare",
    "gareggiavate": "gareggiare",
    "gareggiavi": "gareggiare",
    "gareggiavo": "gareggiare",
    "gareggin": "gareggiare",
    "gareggino": "gareggiare",
    "gareggio": "gareggiare",
    "gareggiò": "gareggiare",
    "gargarizza": "gargarizzare",
    "gargarizzai": "gargarizzare",
    "gargarizzammo": "gargarizzare",
    "gargarizzan": "gargarizzare",
    "gargarizzando": "gargarizzare",
    "gargarizzano": "gargarizzare",
    "gargarizzante": "gargarizzare",
    "gargarizzanti": "gargarizzare",
    "gargarizzar": "gargarizzare",
    "gargarizzaron": "gargarizzare",
    "gargarizzarono": "gargarizzare",
    "gargarizzasse": "gargarizzare",
    "gargarizzasser": "gargarizzare",
    "gargarizzassero": "gargarizzare",
    "gargarizzassi": "gargarizzare",
    "gargarizzassimo": "gargarizzare",
    "gargarizzaste": "gargarizzare",
    "gargarizzasti": "gargarizzare",
    "gargarizzata": "gargarizzare",
    "gargarizzate": "gargarizzare",
    "gargarizzati": "gargarizzare",
    "gargarizzato": "gargarizzare",
    "gargarizzava": "gargarizzare",
    "gargarizzavamo": "gargarizzare",
    "gargarizzavan": "gargarizzare",
    "gargarizzavano": "gargarizzare",
    "gargarizzavate": "gargarizzare",
    "gargarizzavi": "gargarizzare",
    "gargarizzavo": "gargarizzare",
    "gargarizzerai": "gargarizzare",
    "gargarizzeran": "gargarizzare",
    "gargarizzeranno": "gargarizzare",
    "gargarizzerebbe": "gargarizzare",
    "gargarizzerebber": "gargarizzare",
    "gargarizzerebbero": "gargarizzare",
    "gargarizzerei": "gargarizzare",
    "gargarizzeremmo": "gargarizzare",
    "gargarizzeremo": "gargarizzare",
    "gargarizzereste": "gargarizzare",
    "gargarizzeresti": "gargarizzare",
    "gargarizzerete": "gargarizzare",
    "gargarizzerà": "gargarizzare",
    "gargarizzerò": "gargarizzare",
    "gargarizzi": "gargarizzare",
    "gargarizziamo": "gargarizzare",
    "gargarizziate": "gargarizzare",
    "gargarizzin": "gargarizzare",
    "gargarizzino": "gargarizzare",
    "gargarizzo": "gargarizzare",
    "gargarizzò": "gargarizzare",
    "garibaldina": "garibaldino",
    "garibaldine": "garibaldino",
    "garibaldini": "garibaldino",
    "garitte": "garitta",
    "garofani": "garofano",
    "garrendo": "garrire",
    "garrente": "garrire",
    "garrenti": "garrire",
    "garretti": "garretto",
    "garriamo": "garrire",
    "garriate": "garrire",
    "garrii": "garrire",
    "garrimmo": "garrire",
    "garrir": "garrire",
    "garrirai": "garrire",
    "garriran": "garrire",
    "garriranno": "garrire",
    "garrirebbe": "garrire",
    "garrirebber": "garrire",
    "garrirebbero": "garrire",
    "garrirei": "garrire",
    "garriremmo": "garrire",
    "garriremo": "garrire",
    "garrireste": "garrire",
    "garriresti": "garrire",
    "garrirete": "garrire",
    "garriron": "garrire",
    "garrirono": "garrire",
    "garrirà": "garrire",
    "garrirò": "garrire",
    "garrisca": "garrire",
    "garriscan": "garrire",
    "garriscano": "garrire",
    "garrisce": "garrire",
    "garrisci": "garrire",
    "garrisco": "garrire",
    "garriscon": "garrire",
    "garriscono": "garrire",
    "garrisse": "garrire",
    "garrisser": "garrire",
    "garrissero": "garrire",
    "garrissi": "garrire",
    "garrissimo": "garrire",
    "garriste": "garrire",
    "garristi": "garrire",
    "garrita": "garrire",
    "garrite": "garrire",
    "garriti": "garrire",
    "garrito": "garrire",
    "garritte": "garritta",
    "garriva": "garrire",
    "garrivamo": "garrire",
    "garrivan": "garrire",
    "garrivano": "garrire",
    "garrivate": "garrire",
    "garrivi": "garrire",
    "garrivo": "garrire",
    "garrula": "garrulo",
    "garrule": "garrulo",
    "garruli": "garrulo",
    "garrì": "garrire",
    "garza": "garzare",
    "garzai": "garzare",
    "garzammo": "garzare",
    "garzan": "garzare",
    "garzando": "garzare",
    "garzano": "garzare",
    "garzante": "garzare",
    "garzanti": "garzare",
    "garzar": "garzare",
    "garzaron": "garzare",
    "garzarono": "garzare",
    "garzasse": "garzare",
    "garzasser": "garzare",
    "garzassero": "garzare",
    "garzassi": "garzare",
    "garzassimo": "garzare",
    "garzaste": "garzare",
    "garzasti": "garzare",
    "garzata": "garzare",
    "garzate": "garzare",
    "garzati": "garzare",
    "garzato": "garzare",
    "garzava": "garzare",
    "garzavamo": "garzare",
    "garzavan": "garzare",
    "garzavano": "garzare",
    "garzavate": "garzare",
    "garzavi": "garzare",
    "garzavo": "garzare",
    "garze": "garza",
    "garzerai": "garzare",
    "garzeran": "garzare",
    "garzeranno": "garzare",
    "garzerebbe": "garzare",
    "garzerebber": "garzare",
    "garzerebbero": "garzare",
    "garzerei": "garzare",
    "garzeremmo": "garzare",
    "garzeremo": "garzare",
    "garzereste": "garzare",
    "garzeresti": "garzare",
    "garzerete": "garzare",
    "garzerà": "garzare",
    "garzerò": "garzare",
    "garzi": "garzare",
    "garziamo": "garzare",
    "garziate": "garzare",
    "garzin": "garzare",
    "garzino": "garzare",
    "garzo": "garzare",
    "garzoni": "garzone",
    "garzò": "garzare",
    "gasa": "gasare",
    "gasai": "gasare",
    "gasammo": "gasare",
    "gasan": "gasare",
    "gasando": "gasare",
    "gasano": "gasare",
    "gasante": "gasare",
    "gasanti": "gasare",
    "gasar": "gasare",
    "gasaron": "gasare",
    "gasarono": "gasare",
    "gasasse": "gasare",
    "gasasser": "gasare",
    "gasassero": "gasare",
    "gasassi": "gasare",
    "gasassimo": "gasare",
    "gasaste": "gasare",
    "gasasti": "gasare",
    "gasata": "gasato",
    "gasate": "gasato",
    "gasati": "gasato",
    "gasato": "gasare",
    "gasava": "gasare",
    "gasavamo": "gasare",
    "gasavan": "gasare",
    "gasavano": "gasare",
    "gasavate": "gasare",
    "gasavi": "gasare",
    "gasavo": "gasare",
    "gasdotti": "gasdotto",
    "gaserai": "gasare",
    "gaseran": "gasare",
    "gaseranno": "gasare",
    "gaserebbe": "gasare",
    "gaserebber": "gasare",
    "gaserebbero": "gasare",
    "gaserei": "gasare",
    "gaseremmo": "gasare",
    "gaseremo": "gasare",
    "gasereste": "gasare",
    "gaseresti": "gasare",
    "gaserete": "gasare",
    "gaserà": "gasare",
    "gaserò": "gasare",
    "gasi": "gasare",
    "gasiamo": "gasare",
    "gasiate": "gasare",
    "gasin": "gasare",
    "gasino": "gasare",
    "gaso": "gasare",
    "gasoli": "gasolio",
    "gassifica": "gassificare",
    "gassificai": "gassificare",
    "gassificammo": "gassificare",
    "gassifican": "gassificare",
    "gassificando": "gassificare",
    "gassificano": "gassificare",
    "gassificante": "gassificare",
    "gassificanti": "gassificare",
    "gassificar": "gassificare",
    "gassificaron": "gassificare",
    "gassificarono": "gassificare",
    "gassificasse": "gassificare",
    "gassificasser": "gassificare",
    "gassificassero": "gassificare",
    "gassificassi": "gassificare",
    "gassificassimo": "gassificare",
    "gassificaste": "gassificare",
    "gassificasti": "gassificare",
    "gassificata": "gassificare",
    "gassificate": "gassificare",
    "gassificati": "gassificare",
    "gassificato": "gassificare",
    "gassificava": "gassificare",
    "gassificavamo": "gassificare",
    "gassificavan": "gassificare",
    "gassificavano": "gassificare",
    "gassificavate": "gassificare",
    "gassificavi": "gassificare",
    "gassificavo": "gassificare",
    "gassificherai": "gassificare",
    "gassificheran": "gassificare",
    "gassificheranno": "gassificare",
    "gassificherebbe": "gassificare",
    "gassificherebber": "gassificare",
    "gassificherebbero": "gassificare",
    "gassificherei": "gassificare",
    "gassificheremmo": "gassificare",
    "gassificheremo": "gassificare",
    "gassifichereste": "gassificare",
    "gassificheresti": "gassificare",
    "gassificherete": "gassificare",
    "gassificherà": "gassificare",
    "gassificherò": "gassificare",
    "gassifichi": "gassificare",
    "gassifichiamo": "gassificare",
    "gassifichiate": "gassificare",
    "gassifichin": "gassificare",
    "gassifichino": "gassificare",
    "gassifico": "gassificare",
    "gassificò": "gassificare",
    "gassosa": "gassoso",
    "gassose": "gassoso",
    "gassosi": "gassoso",
    "gastrica": "gastrico",
    "gastriche": "gastrico",
    "gastrici": "gastrico",
    "gastriti": "gastrite",
    "gastroenterica": "gastroenterico",
    "gastroenteriche": "gastroenterico",
    "gastroenterici": "gastroenterico",
    "gastroenterologi": "gastroenterologo",
    "gastrointestinali": "gastrointestinale",
    "gastronomi": "gastronomo",
    "gastronomica": "gastronomico",
    "gastronomiche": "gastronomico",
    "gastronomici": "gastronomico",
    "gastronomie": "gastronomia",
    "gasò": "gasare",
    "gatte": "gatta",
    "gatteggerai": "gatteggiare",
    "gatteggeran": "gatteggiare",
    "gatteggeranno": "gatteggiare",
    "gatteggerebbe": "gatteggiare",
    "gatteggerebber": "gatteggiare",
    "gatteggerebbero": "gatteggiare",
    "gatteggerei": "gatteggiare",
    "gatteggeremmo": "gatteggiare",
    "gatteggeremo": "gatteggiare",
    "gatteggereste": "gatteggiare",
    "gatteggeresti": "gatteggiare",
    "gatteggerete": "gatteggiare",
    "gatteggerà": "gatteggiare",
    "gatteggerò": "gatteggiare",
    "gatteggi": "gatteggiare",
    "gatteggia": "gatteggiare",
    "gatteggiai": "gatteggiare",
    "gatteggiammo": "gatteggiare",
    "gatteggiamo": "gatteggiare",
    "gatteggian": "gatteggiare",
    "gatteggiando": "gatteggiare",
    "gatteggiano": "gatteggiare",
    "gatteggiante": "gatteggiare",
    "gatteggianti": "gatteggiare",
    "gatteggiar": "gatteggiare",
    "gatteggiaron": "gatteggiare",
    "gatteggiarono": "gatteggiare",
    "gatteggiasse": "gatteggiare",
    "gatteggiasser": "gatteggiare",
    "gatteggiassero": "gatteggiare",
    "gatteggiassi": "gatteggiare",
    "gatteggiassimo": "gatteggiare",
    "gatteggiaste": "gatteggiare",
    "gatteggiasti": "gatteggiare",
    "gatteggiata": "gatteggiare",
    "gatteggiate": "gatteggiare",
    "gatteggiati": "gatteggiare",
    "gatteggiato": "gatteggiare",
    "gatteggiava": "gatteggiare",
    "gatteggiavamo": "gatteggiare",
    "gatteggiavan": "gatteggiare",
    "gatteggiavano": "gatteggiare",
    "gatteggiavate": "gatteggiare",
    "gatteggiavi": "gatteggiare",
    "gatteggiavo": "gatteggiare",
    "gatteggin": "gatteggiare",
    "gatteggino": "gatteggiare",
    "gatteggio": "gatteggiare",
    "gatteggiò": "gatteggiare",
    "gatti": "gatto",
    "gattine": "gattina",
    "gattini": "gattino",
    "gattona": "gattonare",
    "gattonai": "gattonare",
    "gattonammo": "gattonare",
    "gattonan": "gattonare",
    "gattonando": "gattonare",
    "gattonano": "gattonare",
    "gattonante": "gattonare",
    "gattonanti": "gattonare",
    "gattonar": "gattonare",
    "gattonaron": "gattonare",
    "gattonarono": "gattonare",
    "gattonasse": "gattonare",
    "gattonasser": "gattonare",
    "gattonassero": "gattonare",
    "gattonassi": "gattonare",
    "gattonassimo": "gattonare",
    "gattonaste": "gattonare",
    "gattonasti": "gattonare",
    "gattonata": "gattonare",
    "gattonate": "gattonare",
    "gattonati": "gattonare",
    "gattonato": "gattonare",
    "gattonava": "gattonare",
    "gattonavamo": "gattonare",
    "gattonavan": "gattonare",
    "gattonavano": "gattonare",
    "gattonavate": "gattonare",
    "gattonavi": "gattonare",
    "gattonavo": "gattonare",
    "gattoneggerai": "gattoneggiare",
    "gattoneggeran": "gattoneggiare",
    "gattoneggeranno": "gattoneggiare",
    "gattoneggerebbe": "gattoneggiare",
    "gattoneggerebber": "gattoneggiare",
    "gattoneggerebbero": "gattoneggiare",
    "gattoneggerei": "gattoneggiare",
    "gattoneggeremmo": "gattoneggiare",
    "gattoneggeremo": "gattoneggiare",
    "gattoneggereste": "gattoneggiare",
    "gattoneggeresti": "gattoneggiare",
    "gattoneggerete": "gattoneggiare",
    "gattoneggerà": "gattoneggiare",
    "gattoneggerò": "gattoneggiare",
    "gattoneggi": "gattoneggiare",
    "gattoneggia": "gattoneggiare",
    "gattoneggiai": "gattoneggiare",
    "gattoneggiammo": "gattoneggiare",
    "gattoneggiamo": "gattoneggiare",
    "gattoneggian": "gattoneggiare",
    "gattoneggiando": "gattoneggiare",
    "gattoneggiano": "gattoneggiare",
    "gattoneggiante": "gattoneggiare",
    "gattoneggianti": "gattoneggiare",
    "gattoneggiar": "gattoneggiare",
    "gattoneggiaron": "gattoneggiare",
    "gattoneggiarono": "gattoneggiare",
    "gattoneggiasse": "gattoneggiare",
    "gattoneggiasser": "gattoneggiare",
    "gattoneggiassero": "gattoneggiare",
    "gattoneggiassi": "gattoneggiare",
    "gattoneggiassimo": "gattoneggiare",
    "gattoneggiaste": "gattoneggiare",
    "gattoneggiasti": "gattoneggiare",
    "gattoneggiata": "gattoneggiare",
    "gattoneggiate": "gattoneggiare",
    "gattoneggiati": "gattoneggiare",
    "gattoneggiato": "gattoneggiare",
    "gattoneggiava": "gattoneggiare",
    "gattoneggiavamo": "gattoneggiare",
    "gattoneggiavan": "gattoneggiare",
    "gattoneggiavano": "gattoneggiare",
    "gattoneggiavate": "gattoneggiare",
    "gattoneggiavi": "gattoneggiare",
    "gattoneggiavo": "gattoneggiare",
    "gattoneggin": "gattoneggiare",
    "gattoneggino": "gattoneggiare",
    "gattoneggio": "gattoneggiare",
    "gattoneggiò": "gattoneggiare",
    "gattonerai": "gattonare",
    "gattoneran": "gattonare",
    "gattoneranno": "gattonare",
    "gattonerebbe": "gattonare",
    "gattonerebber": "gattonare",
    "gattonerebbero": "gattonare",
    "gattonerei": "gattonare",
    "gattoneremmo": "gattonare",
    "gattoneremo": "gattonare",
    "gattonereste": "gattonare",
    "gattoneresti": "gattonare",
    "gattonerete": "gattonare",
    "gattonerà": "gattonare",
    "gattonerò": "gattonare",
    "gattoni": "gattone",
    "gattoniamo": "gattonare",
    "gattoniate": "gattonare",
    "gattonin": "gattonare",
    "gattonino": "gattonare",
    "gattono": "gattonare",
    "gattonò": "gattonare",
    "gattopardesca": "gattopardesco",
    "gattopardesche": "gattopardesco",
    "gattopardeschi": "gattopardesco",
    "gattopardi": "gattopardo",
    "gaudenti": "gaudente",
    "gaudiosa": "gaudioso",
    "gaudiose": "gaudioso",
    "gaudiosi": "gaudioso",
    "gavazza": "gavazzare",
    "gavazzai": "gavazzare",
    "gavazzammo": "gavazzare",
    "gavazzan": "gavazzare",
    "gavazzando": "gavazzare",
    "gavazzano": "gavazzare",
    "gavazzante": "gavazzare",
    "gavazzanti": "gavazzare",
    "gavazzar": "gavazzare",
    "gavazzaron": "gavazzare",
    "gavazzarono": "gavazzare",
    "gavazzasse": "gavazzare",
    "gavazzasser": "gavazzare",
    "gavazzassero": "gavazzare",
    "gavazzassi": "gavazzare",
    "gavazzassimo": "gavazzare",
    "gavazzaste": "gavazzare",
    "gavazzasti": "gavazzare",
    "gavazzata": "gavazzare",
    "gavazzate": "gavazzare",
    "gavazzati": "gavazzare",
    "gavazzato": "gavazzare",
    "gavazzava": "gavazzare",
    "gavazzavamo": "gavazzare",
    "gavazzavan": "gavazzare",
    "gavazzavano": "gavazzare",
    "gavazzavate": "gavazzare",
    "gavazzavi": "gavazzare",
    "gavazzavo": "gavazzare",
    "gavazzerai": "gavazzare",
    "gavazzeran": "gavazzare",
    "gavazzeranno": "gavazzare",
    "gavazzerebbe": "gavazzare",
    "gavazzerebber": "gavazzare",
    "gavazzerebbero": "gavazzare",
    "gavazzerei": "gavazzare",
    "gavazzeremmo": "gavazzare",
    "gavazzeremo": "gavazzare",
    "gavazzereste": "gavazzare",
    "gavazzeresti": "gavazzare",
    "gavazzerete": "gavazzare",
    "gavazzerà": "gavazzare",
    "gavazzerò": "gavazzare",
    "gavazzi": "gavazzare",
    "gavazziamo": "gavazzare",
    "gavazziate": "gavazzare",
    "gavazzin": "gavazzare",
    "gavazzino": "gavazzare",
    "gavazzo": "gavazzare",
    "gavazzò": "gavazzare",
    "gavette": "gavetta",
    "gavettoni": "gavettone",
    "gavianei": "gavianeo",
    "gazzarre": "gazzarra",
    "gazze": "gazza",
    "gazzelle": "gazzella",
    "gazzette": "gazzetta",
    "geishe": "geisha",
    "gela": "gelare",
    "gelai": "gelare",
    "gelammo": "gelare",
    "gelan": "gelare",
    "gelando": "gelare",
    "gelano": "gelare",
    "gelante": "gelare",
    "gelanti": "gelare",
    "gelar": "gelare",
    "gelaron": "gelare",
    "gelarono": "gelare",
    "gelasse": "gelare",
    "gelasser": "gelare",
    "gelassero": "gelare",
    "gelassi": "gelare",
    "gelassimo": "gelare",
    "gelaste": "gelare",
    "gelasti": "gelare",
    "gelata": "gelato",
    "gelatai": "gelataio",
    "gelate": "gelato",
    "gelaterie": "gelateria",
    "gelati": "gelato",
    "gelatine": "gelatina",
    "gelatinizza": "gelatinizzare",
    "gelatinizzai": "gelatinizzare",
    "gelatinizzammo": "gelatinizzare",
    "gelatinizzan": "gelatinizzare",
    "gelatinizzando": "gelatinizzare",
    "gelatinizzano": "gelatinizzare",
    "gelatinizzante": "gelatinizzare",
    "gelatinizzanti": "gelatinizzare",
    "gelatinizzar": "gelatinizzare",
    "gelatinizzaron": "gelatinizzare",
    "gelatinizzarono": "gelatinizzare",
    "gelatinizzasse": "gelatinizzare",
    "gelatinizzasser": "gelatinizzare",
    "gelatinizzassero": "gelatinizzare",
    "gelatinizzassi": "gelatinizzare",
    "gelatinizzassimo": "gelatinizzare",
    "gelatinizzaste": "gelatinizzare",
    "gelatinizzasti": "gelatinizzare",
    "gelatinizzata": "gelatinizzare",
    "gelatinizzate": "gelatinizzare",
    "gelatinizzati": "gelatinizzare",
    "gelatinizzato": "gelatinizzare",
    "gelatinizzava": "gelatinizzare",
    "gelatinizzavamo": "gelatinizzare",
    "gelatinizzavan": "gelatinizzare",
    "gelatinizzavano": "gelatinizzare",
    "gelatinizzavate": "gelatinizzare",
    "gelatinizzavi": "gelatinizzare",
    "gelatinizzavo": "gelatinizzare",
    "gelatinizzerai": "gelatinizzare",
    "gelatinizzeran": "gelatinizzare",
    "gelatinizzeranno": "gelatinizzare",
    "gelatinizzerebbe": "gelatinizzare",
    "gelatinizzerebber": "gelatinizzare",
    "gelatinizzerebbero": "gelatinizzare",
    "gelatinizzerei": "gelatinizzare",
    "gelatinizzeremmo": "gelatinizzare",
    "gelatinizzeremo": "gelatinizzare",
    "gelatinizzereste": "gelatinizzare",
    "gelatinizzeresti": "gelatinizzare",
    "gelatinizzerete": "gelatinizzare",
    "gelatinizzerà": "gelatinizzare",
    "gelatinizzerò": "gelatinizzare",
    "gelatinizzi": "gelatinizzare",
    "gelatinizziamo": "gelatinizzare",
    "gelatinizziate": "gelatinizzare",
    "gelatinizzin": "gelatinizzare",
    "gelatinizzino": "gelatinizzare",
    "gelatinizzo": "gelatinizzare",
    "gelatinizzò": "gelatinizzare",
    "gelatinosa": "gelatinoso",
    "gelatinose": "gelatinoso",
    "gelatinosi": "gelatinoso",
    "gelato": "gelare",
    "gelava": "gelare",
    "gelavamo": "gelare",
    "gelavan": "gelare",
    "gelavano": "gelare",
    "gelavate": "gelare",
    "gelavi": "gelare",
    "gelavo": "gelare",
    "gelerai": "gelare",
    "geleran": "gelare",
    "geleranno": "gelare",
    "gelerebbe": "gelare",
    "gelerebber": "gelare",
    "gelerebbero": "gelare",
    "gelerei": "gelare",
    "geleremmo": "gelare",
    "geleremo": "gelare",
    "gelereste": "gelare",
    "geleresti": "gelare",
    "gelerete": "gelare",
    "gelerà": "gelare",
    "gelerò": "gelare",
    "gelesi": "gelese",
    "geli": "gelo",
    "geliamo": "gelare",
    "geliate": "gelare",
    "gelida": "gelido",
    "gelide": "gelido",
    "gelidi": "gelido",
    "gelifica": "gelificare",
    "gelificai": "gelificare",
    "gelificammo": "gelificare",
    "gelifican": "gelificare",
    "gelificando": "gelificare",
    "gelificano": "gelificare",
    "gelificante": "gelificare",
    "gelificanti": "gelificare",
    "gelificar": "gelificare",
    "gelificaron": "gelificare",
    "gelificarono": "gelificare",
    "gelificasse": "gelificare",
    "gelificasser": "gelificare",
    "gelificassero": "gelificare",
    "gelificassi": "gelificare",
    "gelificassimo": "gelificare",
    "gelificaste": "gelificare",
    "gelificasti": "gelificare",
    "gelificata": "gelificare",
    "gelificate": "gelificare",
    "gelificati": "gelificare",
    "gelificato": "gelificare",
    "gelificava": "gelificare",
    "gelificavamo": "gelificare",
    "gelificavan": "gelificare",
    "gelificavano": "gelificare",
    "gelificavate": "gelificare",
    "gelificavi": "gelificare",
    "gelificavo": "gelificare",
    "gelificherai": "gelificare",
    "gelificheran": "gelificare",
    "gelificheranno": "gelificare",
    "gelificherebbe": "gelificare",
    "gelificherebber": "gelificare",
    "gelificherebbero": "gelificare",
    "gelificherei": "gelificare",
    "gelificheremmo": "gelificare",
    "gelificheremo": "gelificare",
    "gelifichereste": "gelificare",
    "gelificheresti": "gelificare",
    "gelificherete": "gelificare",
    "gelificherà": "gelificare",
    "gelificherò": "gelificare",
    "gelifichi": "gelificare",
    "gelifichiamo": "gelificare",
    "gelifichiate": "gelificare",
    "gelifichin": "gelificare",
    "gelifichino": "gelificare",
    "gelifico": "gelificare",
    "gelificò": "gelificare",
    "gelin": "gelare",
    "gelino": "gelare",
    "gelo": "gelare",
    "gelosa": "geloso",
    "gelose": "geloso",
    "gelosi": "geloso",
    "gelosie": "gelosia",
    "gelsomini": "gelsomino",
    "gelò": "gelare",
    "gema": "gemere",
    "geman": "gemere",
    "gemano": "gemere",
    "geme": "gemere",
    "gemei": "gemere",
    "gemella": "gemello",
    "gemellaggi": "gemellaggio",
    "gemellai": "gemellare",
    "gemellammo": "gemellare",
    "gemellan": "gemellare",
    "gemellando": "gemellare",
    "gemellano": "gemellare",
    "gemellante": "gemellare",
    "gemellanti": "gemellare",
    "gemellar": "gemellare",
    "gemellari": "gemellare",
    "gemellaron": "gemellare",
    "gemellarono": "gemellare",
    "gemellasse": "gemellare",
    "gemellasser": "gemellare",
    "gemellassero": "gemellare",
    "gemellassi": "gemellare",
    "gemellassimo": "gemellare",
    "gemellaste": "gemellare",
    "gemellasti": "gemellare",
    "gemellata": "gemellare",
    "gemellate": "gemellare",
    "gemellati": "gemellare",
    "gemellato": "gemellare",
    "gemellava": "gemellare",
    "gemellavamo": "gemellare",
    "gemellavan": "gemellare",
    "gemellavano": "gemellare",
    "gemellavate": "gemellare",
    "gemellavi": "gemellare",
    "gemellavo": "gemellare",
    "gemelle": "gemello",
    "gemellerai": "gemellare",
    "gemelleran": "gemellare",
    "gemelleranno": "gemellare",
    "gemellerebbe": "gemellare",
    "gemellerebber": "gemellare",
    "gemellerebbero": "gemellare",
    "gemellerei": "gemellare",
    "gemelleremmo": "gemellare",
    "gemelleremo": "gemellare",
    "gemellereste": "gemellare",
    "gemelleresti": "gemellare",
    "gemellerete": "gemellare",
    "gemellerà": "gemellare",
    "gemellerò": "gemellare",
    "gemelli": "gemello",
    "gemelliamo": "gemellare",
    "gemelliate": "gemellare",
    "gemellin": "gemellare",
    "gemelline": "gemellina",
    "gemellini": "gemellino",
    "gemellino": "gemellare",
    "gemello": "gemellare",
    "gemellò": "gemellare",
    "gememmo": "gemere",
    "gemendo": "gemere",
    "gemente": "gemere",
    "gementi": "gemere",
    "gemer": "gemere",
    "gemerai": "gemere",
    "gemeran": "gemere",
    "gemeranno": "gemere",
    "gemerebbe": "gemere",
    "gemerebber": "gemere",
    "gemerebbero": "gemere",
    "gemerei": "gemere",
    "gemeremmo": "gemere",
    "gemeremo": "gemere",
    "gemereste": "gemere",
    "gemeresti": "gemere",
    "gemerete": "gemere",
    "gemeron": "gemere",
    "gemerono": "gemere",
    "gemerà": "gemere",
    "gemerò": "gemere",
    "gemesse": "gemere",
    "gemesser": "gemere",
    "gemessero": "gemere",
    "gemessi": "gemere",
    "gemessimo": "gemere",
    "gemeste": "gemere",
    "gemesti": "gemere",
    "gemete": "gemere",
    "gemeva": "gemere",
    "gemevamo": "gemere",
    "gemevan": "gemere",
    "gemevano": "gemere",
    "gemevate": "gemere",
    "gemevi": "gemere",
    "gemevo": "gemere",
    "gemi": "gemere",
    "gemiamo": "gemere",
    "gemiate": "gemere",
    "gemina": "gemino",
    "geminai": "geminare",
    "geminammo": "geminare",
    "geminan": "geminare",
    "geminando": "geminare",
    "geminano": "geminare",
    "geminante": "geminare",
    "geminanti": "geminare",
    "geminar": "geminare",
    "geminaron": "geminare",
    "geminarono": "geminare",
    "geminasse": "geminare",
    "geminasser": "geminare",
    "geminassero": "geminare",
    "geminassi": "geminare",
    "geminassimo": "geminare",
    "geminaste": "geminare",
    "geminasti": "geminare",
    "geminata": "geminare",
    "geminate": "geminare",
    "geminati": "geminare",
    "geminato": "geminare",
    "geminava": "geminare",
    "geminavamo": "geminare",
    "geminavan": "geminare",
    "geminavano": "geminare",
    "geminavate": "geminare",
    "geminavi": "geminare",
    "geminavo": "geminare",
    "gemine": "gemino",
    "geminerai": "geminare",
    "gemineran": "geminare",
    "gemineranno": "geminare",
    "geminerebbe": "geminare",
    "geminerebber": "geminare",
    "geminerebbero": "geminare",
    "geminerei": "geminare",
    "gemineremmo": "geminare",
    "gemineremo": "geminare",
    "geminereste": "geminare",
    "gemineresti": "geminare",
    "geminerete": "geminare",
    "geminerà": "geminare",
    "geminerò": "geminare",
    "gemini": "gemino",
    "geminiamo": "geminare",
    "geminiate": "geminare",
    "geminin": "geminare",
    "geminino": "geminare",
    "gemino": "geminare",
    "geminò": "geminare",
    "gemiti": "gemito",
    "gemma": "gemmare",
    "gemmai": "gemmare",
    "gemmammo": "gemmare",
    "gemman": "gemmare",
    "gemmando": "gemmare",
    "gemmano": "gemmare",
    "gemmante": "gemmare",
    "gemmanti": "gemmare",
    "gemmar": "gemmare",
    "gemmaron": "gemmare",
    "gemmarono": "gemmare",
    "gemmasse": "gemmare",
    "gemmasser": "gemmare",
    "gemmassero": "gemmare",
    "gemmassi": "gemmare",
    "gemmassimo": "gemmare",
    "gemmaste": "gemmare",
    "gemmasti": "gemmare",
    "gemmata": "gemmare",
    "gemmate": "gemmare",
    "gemmati": "gemmare",
    "gemmato": "gemmare",
    "gemmava": "gemmare",
    "gemmavamo": "gemmare",
    "gemmavan": "gemmare",
    "gemmavano": "gemmare",
    "gemmavate": "gemmare",
    "gemmavi": "gemmare",
    "gemmavo": "gemmare",
    "gemme": "gemma",
    "gemmerai": "gemmare",
    "gemmeran": "gemmare",
    "gemmeranno": "gemmare",
    "gemmerebbe": "gemmare",
    "gemmerebber": "gemmare",
    "gemmerebbero": "gemmare",
    "gemmerei": "gemmare",
    "gemmeremmo": "gemmare",
    "gemmeremo": "gemmare",
    "gemmereste": "gemmare",
    "gemmeresti": "gemmare",
    "gemmerete": "gemmare",
    "gemmerà": "gemmare",
    "gemmerò": "gemmare",
    "gemmi": "gemmare",
    "gemmiamo": "gemmare",
    "gemmiate": "gemmare",
    "gemmin": "gemmare",
    "gemmino": "gemmare",
    "gemmo": "gemmare",
    "gemmò": "gemmare",
    "gemo": "gemere",
    "gemon": "gemere",
    "gemono": "gemere",
    "gemuta": "gemere",
    "gemute": "gemere",
    "gemuti": "gemere",
    "gemuto": "gemere",
    "gemè": "gemere",
    "gena": "genare",
    "genai": "genare",
    "genammo": "genare",
    "genan": "genare",
    "genando": "genare",
    "genano": "genare",
    "genante": "genare",
    "genanti": "genare",
    "genar": "genare",
    "genaron": "genare",
    "genarono": "genare",
    "genasse": "genare",
    "genasser": "genare",
    "genassero": "genare",
    "genassi": "genare",
    "genassimo": "genare",
    "genaste": "genare",
    "genasti": "genare",
    "genata": "genare",
    "genate": "genare",
    "genati": "genare",
    "genato": "genare",
    "genava": "genare",
    "genavamo": "genare",
    "genavan": "genare",
    "genavano": "genare",
    "genavate": "genare",
    "genavi": "genare",
    "genavo": "genare",
    "gendarmerie": "gendarmeria",
    "gendarmi": "gendarme",
    "genealogica": "genealogico",
    "genealogiche": "genealogico",
    "genealogici": "genealogico",
    "genealogie": "genealogia",
    "genera": "generare",
    "generai": "generare",
    "general": "generale",
    "generali": "generale",
    "generali-presidenti": "generale-presidente",
    "generaliste": "generalista",
    "generalisti": "generalista",
    "generalizi": "generalizio",
    "generalizia": "generalizio",
    "generalizie": "generalizio",
    "generalizza": "generalizzare",
    "generalizzai": "generalizzare",
    "generalizzammo": "generalizzare",
    "generalizzan": "generalizzare",
    "generalizzando": "generalizzare",
    "generalizzano": "generalizzare",
    "generalizzante": "generalizzare",
    "generalizzanti": "generalizzare",
    "generalizzar": "generalizzare",
    "generalizzaron": "generalizzare",
    "generalizzarono": "generalizzare",
    "generalizzasse": "generalizzare",
    "generalizzasser": "generalizzare",
    "generalizzassero": "generalizzare",
    "generalizzassi": "generalizzare",
    "generalizzassimo": "generalizzare",
    "generalizzaste": "generalizzare",
    "generalizzasti": "generalizzare",
    "generalizzata": "generalizzato",
    "generalizzate": "generalizzato",
    "generalizzati": "generalizzato",
    "generalizzato": "generalizzare",
    "generalizzava": "generalizzare",
    "generalizzavamo": "generalizzare",
    "generalizzavan": "generalizzare",
    "generalizzavano": "generalizzare",
    "generalizzavate": "generalizzare",
    "generalizzavi": "generalizzare",
    "generalizzavo": "generalizzare",
    "generalizzazioni": "generalizzazione",
    "generalizzerai": "generalizzare",
    "generalizzeran": "generalizzare",
    "generalizzeranno": "generalizzare",
    "generalizzerebbe": "generalizzare",
    "generalizzerebber": "generalizzare",
    "generalizzerebbero": "generalizzare",
    "generalizzerei": "generalizzare",
    "generalizzeremmo": "generalizzare",
    "generalizzeremo": "generalizzare",
    "generalizzereste": "generalizzare",
    "generalizzeresti": "generalizzare",
    "generalizzerete": "generalizzare",
    "generalizzerà": "generalizzare",
    "generalizzerò": "generalizzare",
    "generalizzi": "generalizzare",
    "generalizziamo": "generalizzare",
    "generalizziate": "generalizzare",
    "generalizzin": "generalizzare",
    "generalizzino": "generalizzare",
    "generalizzo": "generalizzare",
    "generalizzò": "generalizzare",
    "generaloni": "generalone",
    "generammo": "generare",
    "generan": "generare",
    "generando": "generare",
    "generanno": "genare",
    "generano": "generare",
    "generante": "generare",
    "generanti": "generare",
    "generar": "generare",
    "generaron": "generare",
    "generarono": "generare",
    "generasse": "generare",
    "generasser": "generare",
    "generassero": "generare",
    "generassi": "generare",
    "generassimo": "generare",
    "generaste": "generare",
    "generasti": "generare",
    "generata": "generare",
    "generate": "generare",
    "generati": "generare",
    "generato": "generare",
    "generatori": "generatore",
    "generatrice": "generatore",
    "generatrici": "generatore",
    "generava": "generare",
    "generavamo": "generare",
    "generavan": "generare",
    "generavano": "generare",
    "generavate": "generare",
    "generavi": "generare",
    "generavo": "generare",
    "generazionali": "generazionale",
    "generazioni": "generazione",
    "genere": "genera",
    "generebbe": "genare",
    "generebber": "genare",
    "generebbero": "genare",
    "generei": "genare",
    "generemmo": "genare",
    "generemo": "genare",
    "genererai": "generare",
    "genereran": "generare",
    "genereranno": "generare",
    "genererebbe": "generare",
    "genererebber": "generare",
    "genererebbero": "generare",
    "genererei": "generare",
    "genereremmo": "generare",
    "genereremo": "generare",
    "generereste": "generare",
    "genereresti": "generare",
    "genererete": "generare",
    "genererà": "generare",
    "genererò": "generare",
    "genereste": "genare",
    "generesti": "genare",
    "generete": "genare",
    "generi": "genero",
    "generiamo": "generare",
    "generiate": "generare",
    "generica": "generico",
    "generiche": "generico",
    "generici": "generico",
    "generin": "generare",
    "generino": "generare",
    "genero": "generare",
    "generoni": "generone",
    "generosa": "generoso",
    "generose": "generoso",
    "generosi": "generoso",
    "generà": "genare",
    "generò": "generare",
    "genetica": "genetico",
    "genetiche": "genetico",
    "genetici": "genetico",
    "genetico-morali": "genetico-morale",
    "genetisti": "genetista",
    "genetliaca": "genetliaco",
    "genetliache": "genetliaco",
    "genetliaci": "genetliaco",
    "gengive": "gengiva",
    "gengiviti": "gengivite",
    "geni": "genio",
    "geniacci": "geniaccio",
    "geniali": "geniale",
    "geniamo": "genare",
    "geniate": "genare",
    "genica": "genico",
    "geniche": "genico",
    "genici": "genico",
    "genie": "genia",
    "genieri": "geniere",
    "genietti": "genietto",
    "genii": "genio",
    "genin": "genare",
    "genino": "genare",
    "genitali": "genitale",
    "genitori": "genitore",
    "gennai": "gennaio",
    "geno": "genare",
    "genoana": "genoano",
    "genoane": "genoano",
    "genoani": "genoano",
    "genocidi": "genocidio",
    "genomi": "genoma",
    "genomica": "genomico",
    "genomiche": "genomico",
    "genomici": "genomico",
    "genotossica": "genotossico",
    "genotossiche": "genotossico",
    "genotossici": "genotossico",
    "genovesi": "genovese",
    "genti": "gente",
    "gentildonne": "gentildonna",
    "gentilezze": "gentilezza",
    "gentili": "gentile",
    "gentiliana": "gentiliano",
    "gentiliane": "gentiliano",
    "gentiliani": "gentiliano",
    "gentilizi": "gentilizio",
    "gentilizia": "gentilizio",
    "gentilizie": "gentilizio",
    "gentiluomini": "gentiluomo",
    "gentlemen": "gentleman",
    "genuflessioni": "genuflessione",
    "genufletta": "genuflettere",
    "genuflettan": "genuflettere",
    "genuflettano": "genuflettere",
    "genuflette": "genuflettere",
    "genuflettei": "genuflettere",
    "genuflettemmo": "genuflettere",
    "genuflettendo": "genuflettere",
    "genufletter": "genuflettere",
    "genufletterai": "genuflettere",
    "genufletteran": "genuflettere",
    "genufletteranno": "genuflettere",
    "genufletterebbe": "genuflettere",
    "genufletterebber": "genuflettere",
    "genufletterebbero": "genuflettere",
    "genufletterei": "genuflettere",
    "genufletteremmo": "genuflettere",
    "genufletteremo": "genuflettere",
    "genuflettereste": "genuflettere",
    "genufletteresti": "genuflettere",
    "genufletterete": "genuflettere",
    "genufletteron": "genuflettere",
    "genufletterono": "genuflettere",
    "genufletterà": "genuflettere",
    "genufletterò": "genuflettere",
    "genuflettesse": "genuflettere",
    "genuflettesser": "genuflettere",
    "genuflettessero": "genuflettere",
    "genuflettessi": "genuflettere",
    "genuflettessimo": "genuflettere",
    "genufletteste": "genuflettere",
    "genuflettesti": "genuflettere",
    "genuflettete": "genuflettere",
    "genufletteva": "genuflettere",
    "genuflettevamo": "genuflettere",
    "genuflettevan": "genuflettere",
    "genuflettevano": "genuflettere",
    "genuflettevate": "genuflettere",
    "genuflettevi": "genuflettere",
    "genuflettevo": "genuflettere",
    "genufletti": "genuflettere",
    "genuflettiamo": "genuflettere",
    "genuflettiate": "genuflettere",
    "genufletto": "genuflettere",
    "genufletton": "genuflettere",
    "genuflettono": "genuflettere",
    "genuflettuta": "genuflettere",
    "genuflettute": "genuflettere",
    "genuflettuti": "genuflettere",
    "genuflettuto": "genuflettere",
    "genuflettè": "genuflettere",
    "genuina": "genuino",
    "genuine": "genuino",
    "genuini": "genuino",
    "genìe": "genìa",
    "genò": "genare",
    "geo-economica": "geo-economico",
    "geo-economiche": "geo-economico",
    "geo-economici": "geo-economico",
    "geo-politica": "geo-politico",
    "geo-politiche": "geo-politico",
    "geo-politici": "geo-politico",
    "geodetica": "geodetico",
    "geodetiche": "geodetico",
    "geodetici": "geodetico",
    "geofisica": "geofisico",
    "geofisiche": "geofisico",
    "geofisici": "geofisico",
    "geofoni": "geofono",
    "geognostica": "geognostico",
    "geognostiche": "geognostico",
    "geognostici": "geognostico",
    "geografi": "geografo",
    "geografica": "geografico",
    "geografiche": "geografico",
    "geografici": "geografico",
    "geografie": "geografia",
    "geolinguistica": "geolinguistico",
    "geolinguistiche": "geolinguistico",
    "geolinguistici": "geolinguistico",
    "geologi": "geologo",
    "geologica": "geologico",
    "geologiche": "geologico",
    "geologici": "geologico",
    "geologie": "geologia",
    "geometri": "geometra",
    "geometrica": "geometrico",
    "geometriche": "geometrico",
    "geometrici": "geometrico",
    "geometrie": "geometria",
    "geopolitica": "geopolitico",
    "geopolitiche": "geopolitico",
    "geopolitici": "geopolitico",
    "georgiana": "georgiano",
    "georgiane": "georgiano",
    "georgiani": "georgiano",
    "georgica": "georgico",
    "georgiche": "georgico",
    "georgici": "georgico",
    "geostazionari": "geostazionario",
    "geostazionaria": "geostazionario",
    "geostazionarie": "geostazionario",
    "geostrategica": "geostrategico",
    "geostrategiche": "geostrategico",
    "geostrategici": "geostrategico",
    "geotermica": "geotermico",
    "geotermiche": "geotermico",
    "geotermici": "geotermico",
    "geotermoelettrica": "geotermoelettrico",
    "geotermoelettriche": "geotermoelettrico",
    "geotermoelettrici": "geotermoelettrico",
    "gerani": "geranio",
    "gerarchi": "gerarca",
    "gerarchica": "gerarchico",
    "gerarchiche": "gerarchico",
    "gerarchici": "gerarchico",
    "gerarchie": "gerarchia",
    "gerarchizza": "gerarchizzare",
    "gerarchizzai": "gerarchizzare",
    "gerarchizzammo": "gerarchizzare",
    "gerarchizzan": "gerarchizzare",
    "gerarchizzando": "gerarchizzare",
    "gerarchizzano": "gerarchizzare",
    "gerarchizzante": "gerarchizzare",
    "gerarchizzanti": "gerarchizzare",
    "gerarchizzar": "gerarchizzare",
    "gerarchizzaron": "gerarchizzare",
    "gerarchizzarono": "gerarchizzare",
    "gerarchizzasse": "gerarchizzare",
    "gerarchizzasser": "gerarchizzare",
    "gerarchizzassero": "gerarchizzare",
    "gerarchizzassi": "gerarchizzare",
    "gerarchizzassimo": "gerarchizzare",
    "gerarchizzaste": "gerarchizzare",
    "gerarchizzasti": "gerarchizzare",
    "gerarchizzata": "gerarchizzare",
    "gerarchizzate": "gerarchizzare",
    "gerarchizzati": "gerarchizzare",
    "gerarchizzato": "gerarchizzare",
    "gerarchizzava": "gerarchizzare",
    "gerarchizzavamo": "gerarchizzare",
    "gerarchizzavan": "gerarchizzare",
    "gerarchizzavano": "gerarchizzare",
    "gerarchizzavate": "gerarchizzare",
    "gerarchizzavi": "gerarchizzare",
    "gerarchizzavo": "gerarchizzare",
    "gerarchizzerai": "gerarchizzare",
    "gerarchizzeran": "gerarchizzare",
    "gerarchizzeranno": "gerarchizzare",
    "gerarchizzerebbe": "gerarchizzare",
    "gerarchizzerebber": "gerarchizzare",
    "gerarchizzerebbero": "gerarchizzare",
    "gerarchizzerei": "gerarchizzare",
    "gerarchizzeremmo": "gerarchizzare",
    "gerarchizzeremo": "gerarchizzare",
    "gerarchizzereste": "gerarchizzare",
    "gerarchizzeresti": "gerarchizzare",
    "gerarchizzerete": "gerarchizzare",
    "gerarchizzerà": "gerarchizzare",
    "gerarchizzerò": "gerarchizzare",
    "gerarchizzi": "gerarchizzare",
    "gerarchizziamo": "gerarchizzare",
    "gerarchizziate": "gerarchizzare",
    "gerarchizzin": "gerarchizzare",
    "gerarchizzino": "gerarchizzare",
    "gerarchizzo": "gerarchizzare",
    "gerarchizzò": "gerarchizzare",
    "geremiadi": "geremiade",
    "gergali": "gergale",
    "gerghi": "gergo",
    "germana": "germano",
    "germane": "germano",
    "germani": "germano",
    "germanica": "germanico",
    "germaniche": "germanico",
    "germanici": "germanico",
    "germanisti": "germanista",
    "germi": "germe",
    "germina": "germinare",
    "germinai": "germinare",
    "germinali": "germinale",
    "germinammo": "germinare",
    "germinan": "germinare",
    "germinando": "germinare",
    "germinano": "germinare",
    "germinante": "germinare",
    "germinanti": "germinare",
    "germinar": "germinare",
    "germinaron": "germinare",
    "germinarono": "germinare",
    "germinasse": "germinare",
    "germinasser": "germinare",
    "germinassero": "germinare",
    "germinassi": "germinare",
    "germinassimo": "germinare",
    "germinaste": "germinare",
    "germinasti": "germinare",
    "germinata": "germinare",
    "germinate": "germinare",
    "germinati": "germinare",
    "germinato": "germinare",
    "germinava": "germinare",
    "germinavamo": "germinare",
    "germinavan": "germinare",
    "germinavano": "germinare",
    "germinavate": "germinare",
    "germinavi": "germinare",
    "germinavo": "germinare",
    "germinerai": "germinare",
    "germineran": "germinare",
    "germineranno": "germinare",
    "germinerebbe": "germinare",
    "germinerebber": "germinare",
    "germinerebbero": "germinare",
    "germinerei": "germinare",
    "germineremmo": "germinare",
    "germineremo": "germinare",
    "germinereste": "germinare",
    "germineresti": "germinare",
    "germinerete": "germinare",
    "germinerà": "germinare",
    "germinerò": "germinare",
    "germini": "germinare",
    "germiniamo": "germinare",
    "germiniate": "germinare",
    "germinin": "germinare",
    "germinino": "germinare",
    "germino": "germinare",
    "germinò": "germinare",
    "germogli": "germoglio",
    "germoglia": "germogliare",
    "germogliai": "germogliare",
    "germogliammo": "germogliare",
    "germogliamo": "germogliare",
    "germoglian": "germogliare",
    "germogliando": "germogliare",
    "germogliano": "germogliare",
    "germogliante": "germogliare",
    "germoglianti": "germogliare",
    "germogliar": "germogliare",
    "germogliaron": "germogliare",
    "germogliarono": "germogliare",
    "germogliasse": "germogliare",
    "germogliasser": "germogliare",
    "germogliassero": "germogliare",
    "germogliassi": "germogliare",
    "germogliassimo": "germogliare",
    "germogliaste": "germogliare",
    "germogliasti": "germogliare",
    "germogliata": "germogliare",
    "germogliate": "germogliare",
    "germogliati": "germogliare",
    "germogliato": "germogliare",
    "germogliava": "germogliare",
    "germogliavamo": "germogliare",
    "germogliavan": "germogliare",
    "germogliavano": "germogliare",
    "germogliavate": "germogliare",
    "germogliavi": "germogliare",
    "germogliavo": "germogliare",
    "germoglierai": "germogliare",
    "germoglieran": "germogliare",
    "germoglieranno": "germogliare",
    "germoglierebbe": "germogliare",
    "germoglierebber": "germogliare",
    "germoglierebbero": "germogliare",
    "germoglierei": "germogliare",
    "germoglieremmo": "germogliare",
    "germoglieremo": "germogliare",
    "germogliereste": "germogliare",
    "germoglieresti": "germogliare",
    "germoglierete": "germogliare",
    "germoglierà": "germogliare",
    "germoglierò": "germogliare",
    "germoglin": "germogliare",
    "germoglino": "germogliare",
    "germoglio": "germogliare",
    "germogliò": "germogliare",
    "geroglifica": "geroglifico",
    "geroglifiche": "geroglifico",
    "geroglifici": "geroglifico",
    "gerontocrazie": "gerontocrazia",
    "gerontologi": "gerontologo",
    "gessa": "gessare",
    "gessai": "gessare",
    "gessammo": "gessare",
    "gessan": "gessare",
    "gessando": "gessare",
    "gessano": "gessare",
    "gessante": "gessare",
    "gessanti": "gessare",
    "gessar": "gessare",
    "gessaron": "gessare",
    "gessarono": "gessare",
    "gessasse": "gessare",
    "gessasser": "gessare",
    "gessassero": "gessare",
    "gessassi": "gessare",
    "gessassimo": "gessare",
    "gessaste": "gessare",
    "gessasti": "gessare",
    "gessata": "gessato",
    "gessate": "gessato",
    "gessati": "gessato",
    "gessato": "gessare",
    "gessava": "gessare",
    "gessavamo": "gessare",
    "gessavan": "gessare",
    "gessavano": "gessare",
    "gessavate": "gessare",
    "gessavi": "gessare",
    "gessavo": "gessare",
    "gesserai": "gessare",
    "gesseran": "gessare",
    "gesseranno": "gessare",
    "gesserebbe": "gessare",
    "gesserebber": "gessare",
    "gesserebbero": "gessare",
    "gesserei": "gessare",
    "gesseremmo": "gessare",
    "gesseremo": "gessare",
    "gessereste": "gessare",
    "gesseresti": "gessare",
    "gesserete": "gessare",
    "gesserà": "gessare",
    "gesserò": "gessare",
    "gessetti": "gessetto",
    "gessi": "gesso",
    "gessiamo": "gessare",
    "gessiate": "gessare",
    "gessin": "gessare",
    "gessino": "gessare",
    "gesso": "gessare",
    "gessosa": "gessoso",
    "gessose": "gessoso",
    "gessosi": "gessoso",
    "gessò": "gessare",
    "gesta": "gesto",
    "gestacci": "gestaccio",
    "gestanti": "gestante",
    "gestazioni": "gestazione",
    "gestendo": "gestire",
    "gestente": "gestire",
    "gestenti": "gestire",
    "gesti": "gesto",
    "gestiamo": "gestire",
    "gestiate": "gestire",
    "gesticola": "gesticolare",
    "gesticolai": "gesticolare",
    "gesticolammo": "gesticolare",
    "gesticolan": "gesticolare",
    "gesticolando": "gesticolare",
    "gesticolano": "gesticolare",
    "gesticolante": "gesticolare",
    "gesticolanti": "gesticolare",
    "gesticolar": "gesticolare",
    "gesticolaron": "gesticolare",
    "gesticolarono": "gesticolare",
    "gesticolasse": "gesticolare",
    "gesticolasser": "gesticolare",
    "gesticolassero": "gesticolare",
    "gesticolassi": "gesticolare",
    "gesticolassimo": "gesticolare",
    "gesticolaste": "gesticolare",
    "gesticolasti": "gesticolare",
    "gesticolata": "gesticolare",
    "gesticolate": "gesticolare",
    "gesticolati": "gesticolare",
    "gesticolato": "gesticolare",
    "gesticolava": "gesticolare",
    "gesticolavamo": "gesticolare",
    "gesticolavan": "gesticolare",
    "gesticolavano": "gesticolare",
    "gesticolavate": "gesticolare",
    "gesticolavi": "gesticolare",
    "gesticolavo": "gesticolare",
    "gesticolazioni": "gesticolazione",
    "gesticolerai": "gesticolare",
    "gesticoleran": "gesticolare",
    "gesticoleranno": "gesticolare",
    "gesticolerebbe": "gesticolare",
    "gesticolerebber": "gesticolare",
    "gesticolerebbero": "gesticolare",
    "gesticolerei": "gesticolare",
    "gesticoleremmo": "gesticolare",
    "gesticoleremo": "gesticolare",
    "gesticolereste": "gesticolare",
    "gesticoleresti": "gesticolare",
    "gesticolerete": "gesticolare",
    "gesticolerà": "gesticolare",
    "gesticolerò": "gesticolare",
    "gesticoli": "gesticolare",
    "gesticoliamo": "gesticolare",
    "gesticoliate": "gesticolare",
    "gesticolin": "gesticolare",
    "gesticolino": "gesticolare",
    "gesticolo": "gesticolare",
    "gesticolò": "gesticolare",
    "gestii": "gestire",
    "gestimmo": "gestire",
    "gestionali": "gestionale",
    "gestioni": "gestione",
    "gestir": "gestire",
    "gestirai": "gestire",
    "gestiran": "gestire",
    "gestiranno": "gestire",
    "gestirebbe": "gestire",
    "gestirebber": "gestire",
    "gestirebbero": "gestire",
    "gestirei": "gestire",
    "gestiremmo": "gestire",
    "gestiremo": "gestire",
    "gestireste": "gestire",
    "gestiresti": "gestire",
    "gestirete": "gestire",
    "gestiron": "gestire",
    "gestirono": "gestire",
    "gestirà": "gestire",
    "gestirò": "gestire",
    "gestisca": "gestire",
    "gestiscan": "gestire",
    "gestiscano": "gestire",
    "gestisce": "gestire",
    "gestisci": "gestire",
    "gestisco": "gestire",
    "gestiscon": "gestire",
    "gestiscono": "gestire",
    "gestisse": "gestire",
    "gestisser": "gestire",
    "gestissero": "gestire",
    "gestissi": "gestire",
    "gestissimo": "gestire",
    "gestiste": "gestire",
    "gestisti": "gestire",
    "gestita": "gestire",
    "gestite": "gestire",
    "gestiti": "gestire",
    "gestito": "gestire",
    "gestiva": "gestire",
    "gestivamo": "gestire",
    "gestivan": "gestire",
    "gestivano": "gestire",
    "gestivate": "gestire",
    "gestivi": "gestire",
    "gestivo": "gestire",
    "gestori": "gestore",
    "gestuali": "gestuale",
    "gestì": "gestire",
    "gesuite": "gesuita",
    "gesuiti": "gesuita",
    "gesuitica": "gesuitico",
    "gesuitiche": "gesuitico",
    "gesuitici": "gesuitico",
    "getta": "gettare",
    "gettai": "gettare",
    "gettammo": "gettare",
    "gettan": "gettare",
    "gettando": "gettare",
    "gettano": "gettare",
    "gettante": "gettare",
    "gettanti": "gettare",
    "gettar": "gettare",
    "gettaron": "gettare",
    "gettarono": "gettare",
    "gettasse": "gettare",
    "gettasser": "gettare",
    "gettassero": "gettare",
    "gettassi": "gettare",
    "gettassimo": "gettare",
    "gettaste": "gettare",
    "gettasti": "gettare",
    "gettata": "gettare",
    "gettate": "gettare",
    "gettati": "gettare",
    "gettato": "gettare",
    "gettava": "gettare",
    "gettavamo": "gettare",
    "gettavan": "gettare",
    "gettavano": "gettare",
    "gettavate": "gettare",
    "gettavi": "gettare",
    "gettavo": "gettare",
    "getterai": "gettare",
    "getteran": "gettare",
    "getteranno": "gettare",
    "getterebbe": "gettare",
    "getterebber": "gettare",
    "getterebbero": "gettare",
    "getterei": "gettare",
    "getteremmo": "gettare",
    "getteremo": "gettare",
    "gettereste": "gettare",
    "getteresti": "gettare",
    "getterete": "gettare",
    "getterà": "gettare",
    "getterò": "gettare",
    "getti": "getto",
    "gettiamo": "gettare",
    "gettiate": "gettare",
    "gettin": "gettare",
    "gettino": "gettare",
    "gettiti": "gettito",
    "getto": "gettare",
    "gettona": "gettonare",
    "gettonai": "gettonare",
    "gettonammo": "gettonare",
    "gettonan": "gettonare",
    "gettonando": "gettonare",
    "gettonano": "gettonare",
    "gettonante": "gettonare",
    "gettonanti": "gettonare",
    "gettonar": "gettonare",
    "gettonaron": "gettonare",
    "gettonarono": "gettonare",
    "gettonasse": "gettonare",
    "gettonasser": "gettonare",
    "gettonassero": "gettonare",
    "gettonassi": "gettonare",
    "gettonassimo": "gettonare",
    "gettonaste": "gettonare",
    "gettonasti": "gettonare",
    "gettonata": "gettonato",
    "gettonate": "gettonato",
    "gettonati": "gettonato",
    "gettonato": "gettonare",
    "gettonava": "gettonare",
    "gettonavamo": "gettonare",
    "gettonavan": "gettonare",
    "gettonavano": "gettonare",
    "gettonavate": "gettonare",
    "gettonavi": "gettonare",
    "gettonavo": "gettonare",
    "gettonerai": "gettonare",
    "gettoneran": "gettonare",
    "gettoneranno": "gettonare",
    "gettonerebbe": "gettonare",
    "gettonerebber": "gettonare",
    "gettonerebbero": "gettonare",
    "gettonerei": "gettonare",
    "gettoneremmo": "gettonare",
    "gettoneremo": "gettonare",
    "gettonereste": "gettonare",
    "gettoneresti": "gettonare",
    "gettonerete": "gettonare",
    "gettonerà": "gettonare",
    "gettonerò": "gettonare",
    "gettoni": "gettone",
    "gettoniamo": "gettonare",
    "gettoniate": "gettonare",
    "gettonin": "gettonare",
    "gettonino": "gettonare",
    "gettono": "gettonare",
    "gettonò": "gettonare",
    "gettò": "gettare",
    "ghanesi": "ghanese",
    "ghepardi": "ghepardo",
    "ghermendo": "ghermire",
    "ghermente": "ghermire",
    "ghermenti": "ghermire",
    "ghermiamo": "ghermire",
    "ghermiate": "ghermire",
    "ghermii": "ghermire",
    "ghermimmo": "ghermire",
    "gherminelle": "gherminella",
    "ghermir": "ghermire",
    "ghermirai": "ghermire",
    "ghermiran": "ghermire",
    "ghermiranno": "ghermire",
    "ghermirebbe": "ghermire",
    "ghermirebber": "ghermire",
    "ghermirebbero": "ghermire",
    "ghermirei": "ghermire",
    "ghermiremmo": "ghermire",
    "ghermiremo": "ghermire",
    "ghermireste": "ghermire",
    "ghermiresti": "ghermire",
    "ghermirete": "ghermire",
    "ghermiron": "ghermire",
    "ghermirono": "ghermire",
    "ghermirà": "ghermire",
    "ghermirò": "ghermire",
    "ghermisca": "ghermire",
    "ghermiscan": "ghermire",
    "ghermiscano": "ghermire",
    "ghermisce": "ghermire",
    "ghermisci": "ghermire",
    "ghermisco": "ghermire",
    "ghermiscon": "ghermire",
    "ghermiscono": "ghermire",
    "ghermisse": "ghermire",
    "ghermisser": "ghermire",
    "ghermissero": "ghermire",
    "ghermissi": "ghermire",
    "ghermissimo": "ghermire",
    "ghermiste": "ghermire",
    "ghermisti": "ghermire",
    "ghermita": "ghermire",
    "ghermite": "ghermire",
    "ghermiti": "ghermire",
    "ghermito": "ghermire",
    "ghermiva": "ghermire",
    "ghermivamo": "ghermire",
    "ghermivan": "ghermire",
    "ghermivano": "ghermire",
    "ghermivate": "ghermire",
    "ghermivi": "ghermire",
    "ghermivo": "ghermire",
    "ghermì": "ghermire",
    "ghetti": "ghetto",
    "ghettizza": "ghettizzare",
    "ghettizzai": "ghettizzare",
    "ghettizzammo": "ghettizzare",
    "ghettizzan": "ghettizzare",
    "ghettizzando": "ghettizzare",
    "ghettizzano": "ghettizzare",
    "ghettizzante": "ghettizzare",
    "ghettizzanti": "ghettizzare",
    "ghettizzar": "ghettizzare",
    "ghettizzaron": "ghettizzare",
    "ghettizzarono": "ghettizzare",
    "ghettizzasse": "ghettizzare",
    "ghettizzasser": "ghettizzare",
    "ghettizzassero": "ghettizzare",
    "ghettizzassi": "ghettizzare",
    "ghettizzassimo": "ghettizzare",
    "ghettizzaste": "ghettizzare",
    "ghettizzasti": "ghettizzare",
    "ghettizzata": "ghettizzare",
    "ghettizzate": "ghettizzare",
    "ghettizzati": "ghettizzare",
    "ghettizzato": "ghettizzare",
    "ghettizzava": "ghettizzare",
    "ghettizzavamo": "ghettizzare",
    "ghettizzavan": "ghettizzare",
    "ghettizzavano": "ghettizzare",
    "ghettizzavate": "ghettizzare",
    "ghettizzavi": "ghettizzare",
    "ghettizzavo": "ghettizzare",
    "ghettizzazioni": "ghettizzazione",
    "ghettizzerai": "ghettizzare",
    "ghettizzeran": "ghettizzare",
    "ghettizzeranno": "ghettizzare",
    "ghettizzerebbe": "ghettizzare",
    "ghettizzerebber": "ghettizzare",
    "ghettizzerebbero": "ghettizzare",
    "ghettizzerei": "ghettizzare",
    "ghettizzeremmo": "ghettizzare",
    "ghettizzeremo": "ghettizzare",
    "ghettizzereste": "ghettizzare",
    "ghettizzeresti": "ghettizzare",
    "ghettizzerete": "ghettizzare",
    "ghettizzerà": "ghettizzare",
    "ghettizzerò": "ghettizzare",
    "ghettizzi": "ghettizzare",
    "ghettizziamo": "ghettizzare",
    "ghettizziate": "ghettizzare",
    "ghettizzin": "ghettizzare",
    "ghettizzino": "ghettizzare",
    "ghettizzo": "ghettizzare",
    "ghettizzò": "ghettizzare",
    "ghiaccerai": "ghiacciare",
    "ghiacceran": "ghiacciare",
    "ghiacceranno": "ghiacciare",
    "ghiaccerebbe": "ghiacciare",
    "ghiaccerebber": "ghiacciare",
    "ghiaccerebbero": "ghiacciare",
    "ghiaccerei": "ghiacciare",
    "ghiacceremmo": "ghiacciare",
    "ghiacceremo": "ghiacciare",
    "ghiaccereste": "ghiacciare",
    "ghiacceresti": "ghiacciare",
    "ghiaccerete": "ghiacciare",
    "ghiaccerà": "ghiacciare",
    "ghiaccerò": "ghiacciare",
    "ghiacci": "ghiaccio",
    "ghiaccia": "ghiacciare",
    "ghiacciai": "ghiacciare",
    "ghiacciammo": "ghiacciare",
    "ghiacciamo": "ghiacciare",
    "ghiaccian": "ghiacciare",
    "ghiacciando": "ghiacciare",
    "ghiacciano": "ghiacciare",
    "ghiacciante": "ghiacciare",
    "ghiaccianti": "ghiacciare",
    "ghiacciar": "ghiacciare",
    "ghiacciaron": "ghiacciare",
    "ghiacciarono": "ghiacciare",
    "ghiacciasse": "ghiacciare",
    "ghiacciasser": "ghiacciare",
    "ghiacciassero": "ghiacciare",
    "ghiacciassi": "ghiacciare",
    "ghiacciassimo": "ghiacciare",
    "ghiacciaste": "ghiacciare",
    "ghiacciasti": "ghiacciare",
    "ghiacciata": "ghiacciato",
    "ghiacciate": "ghiacciato",
    "ghiacciati": "ghiacciato",
    "ghiacciato": "ghiacciare",
    "ghiacciava": "ghiacciare",
    "ghiacciavamo": "ghiacciare",
    "ghiacciavan": "ghiacciare",
    "ghiacciavano": "ghiacciare",
    "ghiacciavate": "ghiacciare",
    "ghiacciavi": "ghiacciare",
    "ghiacciavo": "ghiacciare",
    "ghiaccin": "ghiacciare",
    "ghiaccino": "ghiacciare",
    "ghiaccio": "ghiacciare",
    "ghiaccioli": "ghiacciolo",
    "ghiacciò": "ghiacciare",
    "ghiaie": "ghiaia",
    "ghiaioni": "ghiaione",
    "ghiaiosa": "ghiaioso",
    "ghiaiose": "ghiaioso",
    "ghiaiosi": "ghiaioso",
    "ghiandole": "ghiandola",
    "ghibellina": "ghibellino",
    "ghibelline": "ghibellino",
    "ghibellini": "ghibellino",
    "ghigliottina": "ghigliottinare",
    "ghigliottinai": "ghigliottinare",
    "ghigliottinammo": "ghigliottinare",
    "ghigliottinan": "ghigliottinare",
    "ghigliottinando": "ghigliottinare",
    "ghigliottinano": "ghigliottinare",
    "ghigliottinante": "ghigliottinare",
    "ghigliottinanti": "ghigliottinare",
    "ghigliottinar": "ghigliottinare",
    "ghigliottinaron": "ghigliottinare",
    "ghigliottinarono": "ghigliottinare",
    "ghigliottinasse": "ghigliottinare",
    "ghigliottinasser": "ghigliottinare",
    "ghigliottinassero": "ghigliottinare",
    "ghigliottinassi": "ghigliottinare",
    "ghigliottinassimo": "ghigliottinare",
    "ghigliottinaste": "ghigliottinare",
    "ghigliottinasti": "ghigliottinare",
    "ghigliottinata": "ghigliottinare",
    "ghigliottinate": "ghigliottinare",
    "ghigliottinati": "ghigliottinare",
    "ghigliottinato": "ghigliottinare",
    "ghigliottinava": "ghigliottinare",
    "ghigliottinavamo": "ghigliottinare",
    "ghigliottinavan": "ghigliottinare",
    "ghigliottinavano": "ghigliottinare",
    "ghigliottinavate": "ghigliottinare",
    "ghigliottinavi": "ghigliottinare",
    "ghigliottinavo": "ghigliottinare",
    "ghigliottine": "ghigliottina",
    "ghigliottinerai": "ghigliottinare",
    "ghigliottineran": "ghigliottinare",
    "ghigliottineranno": "ghigliottinare",
    "ghigliottinerebbe": "ghigliottinare",
    "ghigliottinerebber": "ghigliottinare",
    "ghigliottinerebbero": "ghigliottinare",
    "ghigliottinerei": "ghigliottinare",
    "ghigliottineremmo": "ghigliottinare",
    "ghigliottineremo": "ghigliottinare",
    "ghigliottinereste": "ghigliottinare",
    "ghigliottineresti": "ghigliottinare",
    "ghigliottinerete": "ghigliottinare",
    "ghigliottinerà": "ghigliottinare",
    "ghigliottinerò": "ghigliottinare",
    "ghigliottini": "ghigliottinare",
    "ghigliottiniamo": "ghigliottinare",
    "ghigliottiniate": "ghigliottinare",
    "ghigliottinin": "ghigliottinare",
    "ghigliottinino": "ghigliottinare",
    "ghigliottino": "ghigliottinare",
    "ghigliottinò": "ghigliottinare",
    "ghigna": "ghignare",
    "ghignai": "ghignare",
    "ghignammo": "ghignare",
    "ghignan": "ghignare",
    "ghignando": "ghignare",
    "ghignano": "ghignare",
    "ghignante": "ghignare",
    "ghignanti": "ghignare",
    "ghignar": "ghignare",
    "ghignaron": "ghignare",
    "ghignarono": "ghignare",
    "ghignasse": "ghignare",
    "ghignasser": "ghignare",
    "ghignassero": "ghignare",
    "ghignassi": "ghignare",
    "ghignassimo": "ghignare",
    "ghignaste": "ghignare",
    "ghignasti": "ghignare",
    "ghignata": "ghignare",
    "ghignate": "ghignare",
    "ghignati": "ghignare",
    "ghignato": "ghignare",
    "ghignava": "ghignare",
    "ghignavamo": "ghignare",
    "ghignavan": "ghignare",
    "ghignavano": "ghignare",
    "ghignavate": "ghignare",
    "ghignavi": "ghignare",
    "ghignavo": "ghignare",
    "ghignerai": "ghignare",
    "ghigneran": "ghignare",
    "ghigneranno": "ghignare",
    "ghignerebbe": "ghignare",
    "ghignerebber": "ghignare",
    "ghignerebbero": "ghignare",
    "ghignerei": "ghignare",
    "ghigneremmo": "ghignare",
    "ghigneremo": "ghignare",
    "ghignereste": "ghignare",
    "ghigneresti": "ghignare",
    "ghignerete": "ghignare",
    "ghignerà": "ghignare",
    "ghignerò": "ghignare",
    "ghigni": "ghigno",
    "ghigniamo": "ghignare",
    "ghigniate": "ghignare",
    "ghignin": "ghignare",
    "ghignino": "ghignare",
    "ghigno": "ghignare",
    "ghignò": "ghignare",
    "ghiotta": "ghiotto",
    "ghiotte": "ghiotto",
    "ghiotti": "ghiotto",
    "ghiottonerie": "ghiottoneria",
    "ghiottoni": "ghiottone",
    "ghiribizzi": "ghiribizzo",
    "ghirigori": "ghirigoro",
    "ghirlande": "ghirlanda",
    "giacche": "giacca",
    "giacchette": "giacchetta",
    "giacchine": "giacchina",
    "giacchini": "giacchino",
    "giaccia": "giacere",
    "giaccian": "giacere",
    "giacciano": "giacere",
    "giaccio": "giacere",
    "giaccion": "giacere",
    "giacciono": "giacere",
    "giacconi": "giaccone",
    "giace": "giacere",
    "giacemmo": "giacere",
    "giacendo": "giacere",
    "giacente": "giacere",
    "giacenti": "giacere",
    "giacenze": "giacenza",
    "giacer": "giacere",
    "giacerai": "giacere",
    "giaceran": "giacere",
    "giaceranno": "giacere",
    "giacerebbe": "giacere",
    "giacerebber": "giacere",
    "giacerebbero": "giacere",
    "giacerei": "giacere",
    "giaceremmo": "giacere",
    "giaceremo": "giacere",
    "giacereste": "giacere",
    "giaceresti": "giacere",
    "giacerete": "giacere",
    "giacerà": "giacere",
    "giacerò": "giacere",
    "giacesse": "giacere",
    "giacesser": "giacere",
    "giacessero": "giacere",
    "giacessi": "giacere",
    "giacessimo": "giacere",
    "giaceste": "giacere",
    "giacesti": "giacere",
    "giacete": "giacere",
    "giaceva": "giacere",
    "giacevamo": "giacere",
    "giacevan": "giacere",
    "giacevano": "giacere",
    "giacevate": "giacere",
    "giacevi": "giacere",
    "giacevo": "giacere",
    "giaci": "giacere",
    "giaciamo": "giacere",
    "giaciate": "giacere",
    "giacigli": "giaciglio",
    "giacimenti": "giacimento",
    "giaciuta": "giacere",
    "giaciute": "giacere",
    "giaciuti": "giacere",
    "giaciuto": "giacere",
    "giacobina": "giacobino",
    "giacobine": "giacobino",
    "giacobini": "giacobino",
    "giacobinismi": "giacobinismo",
    "giacque": "giacere",
    "giacquer": "giacere",
    "giacquero": "giacere",
    "giacqui": "giacere",
    "giaculatorie": "giaculatoria",
    "giade": "giada",
    "giaguari": "giaguaro",
    "gialla": "giallo",
    "giallastra": "giallastro",
    "giallastre": "giallastro",
    "giallastri": "giallastro",
    "gialle": "giallo",
    "gialli": "giallo",
    "giallisti": "giallista",
    "giallognola": "giallognolo",
    "giallognole": "giallognolo",
    "giallognoli": "giallognolo",
    "giallorossa": "giallorosso",
    "giallorosse": "giallorosso",
    "giallorossi": "giallorosso",
    "gialloverdi": "gialloverde",
    "giamaicana": "giamaicano",
    "giamaicane": "giamaicano",
    "giamaicani": "giamaicano",
    "gianduiotti": "gianduiotto",
    "giansenisti": "giansenista",
    "giapponesi": "giapponese",
    "giapponesini": "giapponesino",
    "giardinaggi": "giardinaggio",
    "giardinette": "giardinetta",
    "giardinetti": "giardinetto",
    "giardini": "giardino",
    "giardinieri": "giardiniere",
    "giarrettiere": "giarrettiera",
    "giavellotti": "giavellotto",
    "gibbosa": "gibboso",
    "gibbose": "gibboso",
    "gibbosi": "gibboso",
    "giganteggerai": "giganteggiare",
    "giganteggeran": "giganteggiare",
    "giganteggeranno": "giganteggiare",
    "giganteggerebbe": "giganteggiare",
    "giganteggerebber": "giganteggiare",
    "giganteggerebbero": "giganteggiare",
    "giganteggerei": "giganteggiare",
    "giganteggeremmo": "giganteggiare",
    "giganteggeremo": "giganteggiare",
    "giganteggereste": "giganteggiare",
    "giganteggeresti": "giganteggiare",
    "giganteggerete": "giganteggiare",
    "giganteggerà": "giganteggiare",
    "giganteggerò": "giganteggiare",
    "giganteggi": "giganteggiare",
    "giganteggia": "giganteggiare",
    "giganteggiai": "giganteggiare",
    "giganteggiammo": "giganteggiare",
    "giganteggiamo": "giganteggiare",
    "giganteggian": "giganteggiare",
    "giganteggiando": "giganteggiare",
    "giganteggiano": "giganteggiare",
    "giganteggiante": "giganteggiare",
    "giganteggianti": "giganteggiare",
    "giganteggiar": "giganteggiare",
    "giganteggiaron": "giganteggiare",
    "giganteggiarono": "giganteggiare",
    "giganteggiasse": "giganteggiare",
    "giganteggiasser": "giganteggiare",
    "giganteggiassero": "giganteggiare",
    "giganteggiassi": "giganteggiare",
    "giganteggiassimo": "giganteggiare",
    "giganteggiaste": "giganteggiare",
    "giganteggiasti": "giganteggiare",
    "giganteggiata": "giganteggiare",
    "giganteggiate": "giganteggiare",
    "giganteggiati": "giganteggiare",
    "giganteggiato": "giganteggiare",
    "giganteggiava": "giganteggiare",
    "giganteggiavamo": "giganteggiare",
    "giganteggiavan": "giganteggiare",
    "giganteggiavano": "giganteggiare",
    "giganteggiavate": "giganteggiare",
    "giganteggiavi": "giganteggiare",
    "giganteggiavo": "giganteggiare",
    "giganteggin": "giganteggiare",
    "giganteggino": "giganteggiare",
    "giganteggio": "giganteggiare",
    "giganteggiò": "giganteggiare",
    "gigantesca": "gigantesco",
    "gigantesche": "gigantesco",
    "giganteschi": "gigantesco",
    "giganti": "gigante",
    "gigantismi": "gigantismo",
    "gigantografie": "gigantografia",
    "gigantoni": "gigantone",
    "gigionismi": "gigionismo",
    "gigli": "giglio",
    "gigliata": "gigliato",
    "gigliate": "gigliato",
    "gigliati": "gigliato",
    "gimkane": "gimkana",
    "ginecologhe": "ginecologa",
    "ginecologi": "ginecologo",
    "ginecologica": "ginecologico",
    "ginecologiche": "ginecologico",
    "ginecologici": "ginecologico",
    "gineprai": "ginepraio",
    "ginevrina": "ginevrino",
    "ginevrine": "ginevrino",
    "ginevrini": "ginevrino",
    "gingilla": "gingillare",
    "gingillai": "gingillare",
    "gingillammo": "gingillare",
    "gingillan": "gingillare",
    "gingillando": "gingillare",
    "gingillano": "gingillare",
    "gingillante": "gingillare",
    "gingillanti": "gingillare",
    "gingillar": "gingillare",
    "gingillaron": "gingillare",
    "gingillarono": "gingillare",
    "gingillasse": "gingillare",
    "gingillasser": "gingillare",
    "gingillassero": "gingillare",
    "gingillassi": "gingillare",
    "gingillassimo": "gingillare",
    "gingillaste": "gingillare",
    "gingillasti": "gingillare",
    "gingillata": "gingillare",
    "gingillate": "gingillare",
    "gingillati": "gingillare",
    "gingillato": "gingillare",
    "gingillava": "gingillare",
    "gingillavamo": "gingillare",
    "gingillavan": "gingillare",
    "gingillavano": "gingillare",
    "gingillavate": "gingillare",
    "gingillavi": "gingillare",
    "gingillavo": "gingillare",
    "gingillerai": "gingillare",
    "gingilleran": "gingillare",
    "gingilleranno": "gingillare",
    "gingillerebbe": "gingillare",
    "gingillerebber": "gingillare",
    "gingillerebbero": "gingillare",
    "gingillerei": "gingillare",
    "gingilleremmo": "gingillare",
    "gingilleremo": "gingillare",
    "gingillereste": "gingillare",
    "gingilleresti": "gingillare",
    "gingillerete": "gingillare",
    "gingillerà": "gingillare",
    "gingillerò": "gingillare",
    "gingilli": "gingillo",
    "gingilliamo": "gingillare",
    "gingilliate": "gingillare",
    "gingillin": "gingillare",
    "gingillino": "gingillare",
    "gingillo": "gingillare",
    "gingillò": "gingillare",
    "ginnasi": "ginnasio",
    "ginnasiali": "ginnasiale",
    "ginnaste": "ginnasta",
    "ginnasti": "ginnasta",
    "ginnastica": "ginnastico",
    "ginnastiche": "ginnastico",
    "ginnastici": "ginnastico",
    "ginnica": "ginnico",
    "ginniche": "ginnico",
    "ginnici": "ginnico",
    "ginocchi": "ginocchio",
    "ginocchia": "ginocchio",
    "gioca": "giocare",
    "giocai": "giocare",
    "giocammo": "giocare",
    "giocan": "giocare",
    "giocando": "giocare",
    "giocano": "giocare",
    "giocante": "giocare",
    "giocanti": "giocare",
    "giocar": "giocare",
    "giocaron": "giocare",
    "giocarono": "giocare",
    "giocasse": "giocare",
    "giocasser": "giocare",
    "giocassero": "giocare",
    "giocassi": "giocare",
    "giocassimo": "giocare",
    "giocaste": "giocare",
    "giocasti": "giocare",
    "giocata": "giocare",
    "giocate": "giocata",
    "giocati": "giocare",
    "giocato": "giocare",
    "giocatori": "giocatore",
    "giocatrici": "giocatrice",
    "giocattolai": "giocattolaio",
    "giocattoli": "giocattolo",
    "giocattolini": "giocattolino",
    "giocava": "giocare",
    "giocavamo": "giocare",
    "giocavan": "giocare",
    "giocavano": "giocare",
    "giocavate": "giocare",
    "giocavi": "giocare",
    "giocavo": "giocare",
    "giocherai": "giocare",
    "giocheran": "giocare",
    "giocheranno": "giocare",
    "giocherebbe": "giocare",
    "giocherebber": "giocare",
    "giocherebbero": "giocare",
    "giocherei": "giocare",
    "giocherella": "giocherellare",
    "giocherellai": "giocherellare",
    "giocherellammo": "giocherellare",
    "giocherellan": "giocherellare",
    "giocherellando": "giocherellare",
    "giocherellano": "giocherellare",
    "giocherellante": "giocherellare",
    "giocherellanti": "giocherellare",
    "giocherellar": "giocherellare",
    "giocherellaron": "giocherellare",
    "giocherellarono": "giocherellare",
    "giocherellasse": "giocherellare",
    "giocherellasser": "giocherellare",
    "giocherellassero": "giocherellare",
    "giocherellassi": "giocherellare",
    "giocherellassimo": "giocherellare",
    "giocherellaste": "giocherellare",
    "giocherellasti": "giocherellare",
    "giocherellata": "giocherellare",
    "giocherellate": "giocherellare",
    "giocherellati": "giocherellare",
    "giocherellato": "giocherellare",
    "giocherellava": "giocherellare",
    "giocherellavamo": "giocherellare",
    "giocherellavan": "giocherellare",
    "giocherellavano": "giocherellare",
    "giocherellavate": "giocherellare",
    "giocherellavi": "giocherellare",
    "giocherellavo": "giocherellare",
    "giocherellerai": "giocherellare",
    "giocherelleran": "giocherellare",
    "giocherelleranno": "giocherellare",
    "giocherellerebbe": "giocherellare",
    "giocherellerebber": "giocherellare",
    "giocherellerebbero": "giocherellare",
    "giocherellerei": "giocherellare",
    "giocherelleremmo": "giocherellare",
    "giocherelleremo": "giocherellare",
    "giocherellereste": "giocherellare",
    "giocherelleresti": "giocherellare",
    "giocherellerete": "giocherellare",
    "giocherellerà": "giocherellare",
    "giocherellerò": "giocherellare",
    "giocherelli": "giocherellare",
    "giocherelliamo": "giocherellare",
    "giocherelliate": "giocherellare",
    "giocherellin": "giocherellare",
    "giocherellino": "giocherellare",
    "giocherello": "giocherellare",
    "giocherelloni": "giocherellone",
    "giocherellò": "giocherellare",
    "giocheremmo": "giocare",
    "giocheremo": "giocare",
    "giochereste": "giocare",
    "giocheresti": "giocare",
    "giocherete": "giocare",
    "giocherà": "giocare",
    "giocherò": "giocare",
    "giochetti": "giochetto",
    "giochi": "gioco",
    "giochiamo": "giocare",
    "giochiate": "giocare",
    "giochin": "giocare",
    "giochini": "giochino",
    "giochino": "giocare",
    "gioco": "giocare",
    "giocolieri": "giocoliere",
    "gioconda": "giocondo",
    "gioconde": "giocondo",
    "giocondi": "giocondo",
    "giocosa": "giocoso",
    "giocose": "giocoso",
    "giocosi": "giocoso",
    "giocò": "giocare",
    "gioendo": "gioire",
    "gioente": "gioire",
    "gioenti": "gioire",
    "gioghi": "giogo",
    "gioiamo": "gioire",
    "gioiate": "gioire",
    "gioie": "gioia",
    "gioiellerie": "gioielleria",
    "gioielli": "gioiello",
    "gioiellieri": "gioielliere",
    "gioiellini": "gioiellino",
    "gioii": "gioire",
    "gioimmo": "gioire",
    "gioiosa": "gioioso",
    "gioiose": "gioioso",
    "gioiosi": "gioioso",
    "gioir": "gioire",
    "gioirai": "gioire",
    "gioiran": "gioire",
    "gioiranno": "gioire",
    "gioirebbe": "gioire",
    "gioirebber": "gioire",
    "gioirebbero": "gioire",
    "gioirei": "gioire",
    "gioiremmo": "gioire",
    "gioiremo": "gioire",
    "gioireste": "gioire",
    "gioiresti": "gioire",
    "gioirete": "gioire",
    "gioiron": "gioire",
    "gioirono": "gioire",
    "gioirà": "gioire",
    "gioirò": "gioire",
    "gioisca": "gioire",
    "gioiscan": "gioire",
    "gioiscano": "gioire",
    "gioisce": "gioire",
    "gioisci": "gioire",
    "gioisco": "gioire",
    "gioiscon": "gioire",
    "gioiscono": "gioire",
    "gioisse": "gioire",
    "gioisser": "gioire",
    "gioissero": "gioire",
    "gioissi": "gioire",
    "gioissimo": "gioire",
    "gioiste": "gioire",
    "gioisti": "gioire",
    "gioita": "gioire",
    "gioite": "gioire",
    "gioiti": "gioire",
    "gioito": "gioire",
    "gioiva": "gioire",
    "gioivamo": "gioire",
    "gioivan": "gioire",
    "gioivano": "gioire",
    "gioivate": "gioire",
    "gioivi": "gioire",
    "gioivo": "gioire",
    "giordana": "giordano",
    "giordane": "giordano",
    "giordani": "giordano",
    "giordano-palestinesi": "giordano-palestinese",
    "giornalacci": "giornalaccio",
    "giornalai": "giornalaio",
    "giornaletti": "giornaletto",
    "giornali": "giornale",
    "giornaliera": "giornaliero",
    "giornaliere": "giornaliero",
    "giornalieri": "giornaliero",
    "giornalini": "giornalino",
    "giornalismi": "giornalismo",
    "giornaliste": "giornalista",
    "giornalisti": "giornalista",
    "giornalisti-scrittori": "giornalista-scrittore",
    "giornalistica": "giornalistico",
    "giornalistiche": "giornalistico",
    "giornalistici": "giornalistico",
    "giornatacce": "giornataccia",
    "giornate": "giornata",
    "giorni": "giorno",
    "giostra": "giostrare",
    "giostrai": "giostrare",
    "giostrammo": "giostrare",
    "giostran": "giostrare",
    "giostrando": "giostrare",
    "giostrano": "giostrare",
    "giostrante": "giostrare",
    "giostranti": "giostrare",
    "giostrar": "giostrare",
    "giostraron": "giostrare",
    "giostrarono": "giostrare",
    "giostrasse": "giostrare",
    "giostrasser": "giostrare",
    "giostrassero": "giostrare",
    "giostrassi": "giostrare",
    "giostrassimo": "giostrare",
    "giostraste": "giostrare",
    "giostrasti": "giostrare",
    "giostrata": "giostrare",
    "giostrate": "giostrare",
    "giostrati": "giostrare",
    "giostrato": "giostrare",
    "giostrava": "giostrare",
    "giostravamo": "giostrare",
    "giostravan": "giostrare",
    "giostravano": "giostrare",
    "giostravate": "giostrare",
    "giostravi": "giostrare",
    "giostravo": "giostrare",
    "giostre": "giostra",
    "giostrerai": "giostrare",
    "giostreran": "giostrare",
    "giostreranno": "giostrare",
    "giostrerebbe": "giostrare",
    "giostrerebber": "giostrare",
    "giostrerebbero": "giostrare",
    "giostrerei": "giostrare",
    "giostreremmo": "giostrare",
    "giostreremo": "giostrare",
    "giostrereste": "giostrare",
    "giostreresti": "giostrare",
    "giostrerete": "giostrare",
    "giostrerà": "giostrare",
    "giostrerò": "giostrare",
    "giostri": "giostrare",
    "giostriamo": "giostrare",
    "giostriate": "giostrare",
    "giostrin": "giostrare",
    "giostrino": "giostrare",
    "giostro": "giostrare",
    "giostrò": "giostrare",
    "giova": "giovare",
    "giovai": "giovare",
    "giovammo": "giovare",
    "giovan": "giovare",
    "giovando": "giovare",
    "giovanette": "giovanetta",
    "giovanetti": "giovanetto",
    "giovani": "giovane",
    "giovanili": "giovanile",
    "giovanilismi": "giovanilismo",
    "giovannea": "giovanneo",
    "giovannee": "giovanneo",
    "giovannei": "giovanneo",
    "giovano": "giovare",
    "giovanotti": "giovanotto",
    "giovanottoni": "giovanottone",
    "giovante": "giovare",
    "giovanti": "giovare",
    "giovar": "giovare",
    "giovaron": "giovare",
    "giovarono": "giovare",
    "giovasse": "giovare",
    "giovasser": "giovare",
    "giovassero": "giovare",
    "giovassi": "giovare",
    "giovassimo": "giovare",
    "giovaste": "giovare",
    "giovasti": "giovare",
    "giovata": "giovare",
    "giovate": "giovare",
    "giovati": "giovare",
    "giovato": "giovare",
    "giovava": "giovare",
    "giovavamo": "giovare",
    "giovavan": "giovare",
    "giovavano": "giovare",
    "giovavate": "giovare",
    "giovavi": "giovare",
    "giovavo": "giovare",
    "gioverai": "giovare",
    "gioveran": "giovare",
    "gioveranno": "giovare",
    "gioverebbe": "giovare",
    "gioverebber": "giovare",
    "gioverebbero": "giovare",
    "gioverei": "giovare",
    "gioveremmo": "giovare",
    "gioveremo": "giovare",
    "giovereste": "giovare",
    "gioveresti": "giovare",
    "gioverete": "giovare",
    "gioverà": "giovare",
    "gioverò": "giovare",
    "giovevoli": "giovevole",
    "giovi": "giovare",
    "gioviali": "gioviale",
    "gioviamo": "giovare",
    "gioviate": "giovare",
    "giovin": "giovare",
    "giovinastri": "giovinastro",
    "giovincelli": "giovincello",
    "giovinette": "giovinetta",
    "giovinetti": "giovinetto",
    "giovinezze": "giovinezza",
    "giovini": "giovine",
    "giovino": "giovare",
    "giovinotti": "giovinotto",
    "giovo": "giovare",
    "giovò": "giovare",
    "gioì": "gioire",
    "gipponi": "gippone",
    "gira": "girare",
    "girai": "girare",
    "giramenti": "giramento",
    "girammo": "girare",
    "giran": "girare",
    "girando": "girare",
    "girandola": "girandolare",
    "girandolai": "girandolare",
    "girandolammo": "girandolare",
    "girandolan": "girandolare",
    "girandolando": "girandolare",
    "girandolano": "girandolare",
    "girandolante": "girandolare",
    "girandolanti": "girandolare",
    "girandolar": "girandolare",
    "girandolaron": "girandolare",
    "girandolarono": "girandolare",
    "girandolasse": "girandolare",
    "girandolasser": "girandolare",
    "girandolassero": "girandolare",
    "girandolassi": "girandolare",
    "girandolassimo": "girandolare",
    "girandolaste": "girandolare",
    "girandolasti": "girandolare",
    "girandolata": "girandolare",
    "girandolate": "girandolare",
    "girandolati": "girandolare",
    "girandolato": "girandolare",
    "girandolava": "girandolare",
    "girandolavamo": "girandolare",
    "girandolavan": "girandolare",
    "girandolavano": "girandolare",
    "girandolavate": "girandolare",
    "girandolavi": "girandolare",
    "girandolavo": "girandolare",
    "girandole": "girandola",
    "girandolerai": "girandolare",
    "girandoleran": "girandolare",
    "girandoleranno": "girandolare",
    "girandolerebbe": "girandolare",
    "girandolerebber": "girandolare",
    "girandolerebbero": "girandolare",
    "girandolerei": "girandolare",
    "girandoleremmo": "girandolare",
    "girandoleremo": "girandolare",
    "girandolereste": "girandolare",
    "girandoleresti": "girandolare",
    "girandolerete": "girandolare",
    "girandolerà": "girandolare",
    "girandolerò": "girandolare",
    "girandoli": "girandolare",
    "girandoliamo": "girandolare",
    "girandoliate": "girandolare",
    "girandolin": "girandolare",
    "girandolino": "girandolare",
    "girandolo": "girandolare",
    "girandolò": "girandolare",
    "girano": "girare",
    "girante": "girare",
    "giranti": "girare",
    "girar": "girare",
    "giraron": "girare",
    "girarono": "girare",
    "girasoli": "girasole",
    "girasse": "girare",
    "girasser": "girare",
    "girassero": "girare",
    "girassi": "girare",
    "girassimo": "girare",
    "giraste": "girare",
    "girasti": "girare",
    "girata": "girato",
    "girate": "girato",
    "girati": "girato",
    "girato": "girare",
    "girava": "girare",
    "giravamo": "girare",
    "giravan": "girare",
    "giravano": "girare",
    "giravate": "girare",
    "giravi": "girare",
    "giravo": "girare",
    "giravolte": "giravolta",
    "girella": "girellare",
    "girellai": "girellare",
    "girellammo": "girellare",
    "girellan": "girellare",
    "girellando": "girellare",
    "girellano": "girellare",
    "girellante": "girellare",
    "girellanti": "girellare",
    "girellar": "girellare",
    "girellaron": "girellare",
    "girellarono": "girellare",
    "girellasse": "girellare",
    "girellasser": "girellare",
    "girellassero": "girellare",
    "girellassi": "girellare",
    "girellassimo": "girellare",
    "girellaste": "girellare",
    "girellasti": "girellare",
    "girellata": "girellare",
    "girellate": "girellare",
    "girellati": "girellare",
    "girellato": "girellare",
    "girellava": "girellare",
    "girellavamo": "girellare",
    "girellavan": "girellare",
    "girellavano": "girellare",
    "girellavate": "girellare",
    "girellavi": "girellare",
    "girellavo": "girellare",
    "girellerai": "girellare",
    "girelleran": "girellare",
    "girelleranno": "girellare",
    "girellerebbe": "girellare",
    "girellerebber": "girellare",
    "girellerebbero": "girellare",
    "girellerei": "girellare",
    "girelleremmo": "girellare",
    "girelleremo": "girellare",
    "girellereste": "girellare",
    "girelleresti": "girellare",
    "girellerete": "girellare",
    "girellerà": "girellare",
    "girellerò": "girellare",
    "girelli": "girellare",
    "girelliamo": "girellare",
    "girelliate": "girellare",
    "girellin": "girellare",
    "girellino": "girellare",
    "girello": "girellare",
    "girellò": "girellare",
    "girerai": "girare",
    "gireran": "girare",
    "gireranno": "girare",
    "girerebbe": "girare",
    "girerebber": "girare",
    "girerebbero": "girare",
    "girerei": "girare",
    "gireremmo": "girare",
    "gireremo": "girare",
    "girereste": "girare",
    "gireresti": "girare",
    "girerete": "girare",
    "girerà": "girare",
    "girerò": "girare",
    "giretti": "giretto",
    "girevoli": "girevole",
    "giri": "giro",
    "giriamo": "girare",
    "giriate": "girare",
    "girin": "girare",
    "girini": "girino",
    "girino": "girare",
    "giro": "girare",
    "gironi": "girone",
    "gironzola": "gironzolare",
    "gironzolai": "gironzolare",
    "gironzolammo": "gironzolare",
    "gironzolan": "gironzolare",
    "gironzolando": "gironzolare",
    "gironzolano": "gironzolare",
    "gironzolante": "gironzolare",
    "gironzolanti": "gironzolare",
    "gironzolar": "gironzolare",
    "gironzolaron": "gironzolare",
    "gironzolarono": "gironzolare",
    "gironzolasse": "gironzolare",
    "gironzolasser": "gironzolare",
    "gironzolassero": "gironzolare",
    "gironzolassi": "gironzolare",
    "gironzolassimo": "gironzolare",
    "gironzolaste": "gironzolare",
    "gironzolasti": "gironzolare",
    "gironzolata": "gironzolare",
    "gironzolate": "gironzolare",
    "gironzolati": "gironzolare",
    "gironzolato": "gironzolare",
    "gironzolava": "gironzolare",
    "gironzolavamo": "gironzolare",
    "gironzolavan": "gironzolare",
    "gironzolavano": "gironzolare",
    "gironzolavate": "gironzolare",
    "gironzolavi": "gironzolare",
    "gironzolavo": "gironzolare",
    "gironzolerai": "gironzolare",
    "gironzoleran": "gironzolare",
    "gironzoleranno": "gironzolare",
    "gironzolerebbe": "gironzolare",
    "gironzolerebber": "gironzolare",
    "gironzolerebbero": "gironzolare",
    "gironzolerei": "gironzolare",
    "gironzoleremmo": "gironzolare",
    "gironzoleremo": "gironzolare",
    "gironzolereste": "gironzolare",
    "gironzoleresti": "gironzolare",
    "gironzolerete": "gironzolare",
    "gironzolerà": "gironzolare",
    "gironzolerò": "gironzolare",
    "gironzoli": "gironzolare",
    "gironzoliamo": "gironzolare",
    "gironzoliate": "gironzolare",
    "gironzolin": "gironzolare",
    "gironzolino": "gironzolare",
    "gironzolo": "gironzolare",
    "gironzolò": "gironzolare",
    "giroscopi": "giroscopio",
    "girotondi": "girotondo",
    "girovaga": "girovago",
    "girovagai": "girovagare",
    "girovagammo": "girovagare",
    "girovagan": "girovagare",
    "girovagando": "girovagare",
    "girovagano": "girovagare",
    "girovagante": "girovagare",
    "girovaganti": "girovagare",
    "girovagar": "girovagare",
    "girovagaron": "girovagare",
    "girovagarono": "girovagare",
    "girovagasse": "girovagare",
    "girovagasser": "girovagare",
    "girovagassero": "girovagare",
    "girovagassi": "girovagare",
    "girovagassimo": "girovagare",
    "girovagaste": "girovagare",
    "girovagasti": "girovagare",
    "girovagata": "girovagare",
    "girovagate": "girovagare",
    "girovagati": "girovagare",
    "girovagato": "girovagare",
    "girovagava": "girovagare",
    "girovagavamo": "girovagare",
    "girovagavan": "girovagare",
    "girovagavano": "girovagare",
    "girovagavate": "girovagare",
    "girovagavi": "girovagare",
    "girovagavo": "girovagare",
    "girovaghe": "girovago",
    "girovagherai": "girovagare",
    "girovagheran": "girovagare",
    "girovagheranno": "girovagare",
    "girovagherebbe": "girovagare",
    "girovagherebber": "girovagare",
    "girovagherebbero": "girovagare",
    "girovagherei": "girovagare",
    "girovagheremmo": "girovagare",
    "girovagheremo": "girovagare",
    "girovaghereste": "girovagare",
    "girovagheresti": "girovagare",
    "girovagherete": "girovagare",
    "girovagherà": "girovagare",
    "girovagherò": "girovagare",
    "girovaghi": "girovago",
    "girovaghiamo": "girovagare",
    "girovaghiate": "girovagare",
    "girovaghin": "girovagare",
    "girovaghino": "girovagare",
    "girovago": "girovagare",
    "girovagò": "girovagare",
    "girò": "girare",
    "gitana": "gitano",
    "gitane": "gitano",
    "gitani": "gitano",
    "gittate": "gittata",
    "giubbe": "giubba",
    "giubbetti": "giubbetto",
    "giubbini": "giubbino",
    "giubbotti": "giubbotto",
    "giubila": "giubilare",
    "giubilai": "giubilare",
    "giubilammo": "giubilare",
    "giubilan": "giubilare",
    "giubilando": "giubilare",
    "giubilano": "giubilare",
    "giubilante": "giubilare",
    "giubilanti": "giubilare",
    "giubilar": "giubilare",
    "giubilaron": "giubilare",
    "giubilarono": "giubilare",
    "giubilasse": "giubilare",
    "giubilasser": "giubilare",
    "giubilassero": "giubilare",
    "giubilassi": "giubilare",
    "giubilassimo": "giubilare",
    "giubilaste": "giubilare",
    "giubilasti": "giubilare",
    "giubilata": "giubilare",
    "giubilate": "giubilare",
    "giubilati": "giubilare",
    "giubilato": "giubilare",
    "giubilava": "giubilare",
    "giubilavamo": "giubilare",
    "giubilavan": "giubilare",
    "giubilavano": "giubilare",
    "giubilavate": "giubilare",
    "giubilavi": "giubilare",
    "giubilavo": "giubilare",
    "giubilazioni": "giubilazione",
    "giubilei": "giubileo",
    "giubilerai": "giubilare",
    "giubileran": "giubilare",
    "giubileranno": "giubilare",
    "giubilerebbe": "giubilare",
    "giubilerebber": "giubilare",
    "giubilerebbero": "giubilare",
    "giubilerei": "giubilare",
    "giubileremmo": "giubilare",
    "giubileremo": "giubilare",
    "giubilereste": "giubilare",
    "giubileresti": "giubilare",
    "giubilerete": "giubilare",
    "giubilerà": "giubilare",
    "giubilerò": "giubilare",
    "giubili": "giubilo",
    "giubiliamo": "giubilare",
    "giubiliate": "giubilare",
    "giubilin": "giubilare",
    "giubilino": "giubilare",
    "giubilo": "giubilare",
    "giubilò": "giubilare",
    "giubotti": "giubotto",
    "giudaica": "giudaico",
    "giudaiche": "giudaico",
    "giudaici": "giudaico",
    "giudaismi": "giudaismo",
    "giudica": "giudicare",
    "giudicabili": "giudicabile",
    "giudicai": "giudicare",
    "giudicammo": "giudicare",
    "giudican": "giudicare",
    "giudicando": "giudicare",
    "giudicano": "giudicare",
    "giudicante": "giudicare",
    "giudicanti": "giudicare",
    "giudicar": "giudicare",
    "giudicaron": "giudicare",
    "giudicarono": "giudicare",
    "giudicasse": "giudicare",
    "giudicasser": "giudicare",
    "giudicassero": "giudicare",
    "giudicassi": "giudicare",
    "giudicassimo": "giudicare",
    "giudicaste": "giudicare",
    "giudicasti": "giudicare",
    "giudicata": "giudicato",
    "giudicate": "giudicato",
    "giudicati": "giudicato",
    "giudicato": "giudicare",
    "giudicatori": "giudicatore",
    "giudicatrice": "giudicatore",
    "giudicatrici": "giudicatore",
    "giudicava": "giudicare",
    "giudicavamo": "giudicare",
    "giudicavan": "giudicare",
    "giudicavano": "giudicare",
    "giudicavate": "giudicare",
    "giudicavi": "giudicare",
    "giudicavo": "giudicare",
    "giudicherai": "giudicare",
    "giudicheran": "giudicare",
    "giudicheranno": "giudicare",
    "giudicherebbe": "giudicare",
    "giudicherebber": "giudicare",
    "giudicherebbero": "giudicare",
    "giudicherei": "giudicare",
    "giudicheremmo": "giudicare",
    "giudicheremo": "giudicare",
    "giudichereste": "giudicare",
    "giudicheresti": "giudicare",
    "giudicherete": "giudicare",
    "giudicherà": "giudicare",
    "giudicherò": "giudicare",
    "giudichi": "giudicare",
    "giudichiamo": "giudicare",
    "giudichiate": "giudicare",
    "giudichin": "giudicare",
    "giudichino": "giudicare",
    "giudici": "giudico",
    "giudico": "giudicare",
    "giudicò": "giudicare",
    "giudizi": "giudizio",
    "giudiziali": "giudiziale",
    "giudiziari": "giudiziario",
    "giudiziaria": "giudiziario",
    "giudiziarie": "giudiziario",
    "giudiziosa": "giudizioso",
    "giudiziose": "giudizioso",
    "giudiziosi": "giudizioso",
    "giugni": "giugno",
    "giugula": "giugulare",
    "giugulai": "giugulare",
    "giugulammo": "giugulare",
    "giugulan": "giugulare",
    "giugulando": "giugulare",
    "giugulano": "giugulare",
    "giugulante": "giugulare",
    "giugulanti": "giugulare",
    "giugular": "giugulare",
    "giugulari": "giugulare",
    "giugularon": "giugulare",
    "giugularono": "giugulare",
    "giugulasse": "giugulare",
    "giugulasser": "giugulare",
    "giugulassero": "giugulare",
    "giugulassi": "giugulare",
    "giugulassimo": "giugulare",
    "giugulaste": "giugulare",
    "giugulasti": "giugulare",
    "giugulata": "giugulare",
    "giugulate": "giugulare",
    "giugulati": "giugulare",
    "giugulato": "giugulare",
    "giugulava": "giugulare",
    "giugulavamo": "giugulare",
    "giugulavan": "giugulare",
    "giugulavano": "giugulare",
    "giugulavate": "giugulare",
    "giugulavi": "giugulare",
    "giugulavo": "giugulare",
    "giugulerai": "giugulare",
    "giuguleran": "giugulare",
    "giuguleranno": "giugulare",
    "giugulerebbe": "giugulare",
    "giugulerebber": "giugulare",
    "giugulerebbero": "giugulare",
    "giugulerei": "giugulare",
    "giuguleremmo": "giugulare",
    "giuguleremo": "giugulare",
    "giugulereste": "giugulare",
    "giuguleresti": "giugulare",
    "giugulerete": "giugulare",
    "giugulerà": "giugulare",
    "giugulerò": "giugulare",
    "giuguli": "giugulare",
    "giuguliamo": "giugulare",
    "giuguliate": "giugulare",
    "giugulin": "giugulare",
    "giugulino": "giugulare",
    "giugulo": "giugulare",
    "giugulò": "giugulare",
    "giuliana": "giuliano",
    "giuliane": "giuliano",
    "giuliani": "giuliano",
    "giuliva": "giulivo",
    "giulive": "giulivo",
    "giulivi": "giulivo",
    "giullaresca": "giullaresco",
    "giullaresche": "giullaresco",
    "giullareschi": "giullaresco",
    "giunche": "giunca",
    "giunchi": "giunco",
    "giunga": "giungere",
    "giungan": "giungere",
    "giungano": "giungere",
    "giunge": "giungere",
    "giungemmo": "giungere",
    "giungendo": "giungere",
    "giungente": "giungere",
    "giungenti": "giungere",
    "giunger": "giungere",
    "giungerai": "giungere",
    "giungeran": "giungere",
    "giungeranno": "giungere",
    "giungerebbe": "giungere",
    "giungerebber": "giungere",
    "giungerebbero": "giungere",
    "giungerei": "giungere",
    "giungeremmo": "giungere",
    "giungeremo": "giungere",
    "giungereste": "giungere",
    "giungeresti": "giungere",
    "giungerete": "giungere",
    "giungerà": "giungere",
    "giungerò": "giungere",
    "giungesse": "giungere",
    "giungesser": "giungere",
    "giungessero": "giungere",
    "giungessi": "giungere",
    "giungessimo": "giungere",
    "giungeste": "giungere",
    "giungesti": "giungere",
    "giungete": "giungere",
    "giungeva": "giungere",
    "giungevamo": "giungere",
    "giungevan": "giungere",
    "giungevano": "giungere",
    "giungevate": "giungere",
    "giungevi": "giungere",
    "giungevo": "giungere",
    "giungi": "giungere",
    "giungiamo": "giungere",
    "giungiate": "giungere",
    "giungle": "giungla",
    "giungo": "giungere",
    "giungon": "giungere",
    "giungono": "giungere",
    "giunse": "giungere",
    "giunser": "giungere",
    "giunsero": "giungere",
    "giunsi": "giungere",
    "giunta": "giunto",
    "giunte": "giunto",
    "giunti": "giunto",
    "giunto": "giungere",
    "giunture": "giuntura",
    "giunzioni": "giunzione",
    "giuochi": "giuoco",
    "giura": "giurare",
    "giurai": "giurare",
    "giuramenti": "giuramento",
    "giurammo": "giurare",
    "giuran": "giurare",
    "giurando": "giurare",
    "giurano": "giurare",
    "giurante": "giurare",
    "giuranti": "giurare",
    "giurar": "giurare",
    "giuraron": "giurare",
    "giurarono": "giurare",
    "giurasse": "giurare",
    "giurasser": "giurare",
    "giurassero": "giurare",
    "giurassi": "giurare",
    "giurassimo": "giurare",
    "giuraste": "giurare",
    "giurasti": "giurare",
    "giurata": "giurato",
    "giurate": "giurato",
    "giurati": "giurato",
    "giurato": "giurare",
    "giurava": "giurare",
    "giuravamo": "giurare",
    "giuravan": "giurare",
    "giuravano": "giurare",
    "giuravate": "giurare",
    "giuravi": "giurare",
    "giuravo": "giurare",
    "giureconsulti": "giureconsulto",
    "giurerai": "giurare",
    "giureran": "giurare",
    "giureranno": "giurare",
    "giurerebbe": "giurare",
    "giurerebber": "giurare",
    "giurerebbero": "giurare",
    "giurerei": "giurare",
    "giureremmo": "giurare",
    "giureremo": "giurare",
    "giurereste": "giurare",
    "giureresti": "giurare",
    "giurerete": "giurare",
    "giurerà": "giurare",
    "giurerò": "giurare",
    "giuri": "giurare",
    "giuriamo": "giurare",
    "giuriate": "giurare",
    "giuridica": "giuridico",
    "giuridiche": "giuridico",
    "giuridici": "giuridico",
    "giurie": "giuria",
    "giurin": "giurare",
    "giurino": "giurare",
    "giurisdizionali": "giurisdizionale",
    "giurisdizioni": "giurisdizione",
    "giurisprudenze": "giurisprudenza",
    "giurisprudenziali": "giurisprudenziale",
    "giuristi": "giurista",
    "giuro": "giurare",
    "giurìe": "giurìa",
    "giurò": "giurare",
    "giusta": "giusto",
    "giustappone": "giustapporre",
    "giustapponemmo": "giustapporre",
    "giustapponendo": "giustapporre",
    "giustapponente": "giustapporre",
    "giustapponenti": "giustapporre",
    "giustapponesse": "giustapporre",
    "giustapponesser": "giustapporre",
    "giustapponessero": "giustapporre",
    "giustapponessi": "giustapporre",
    "giustapponessimo": "giustapporre",
    "giustapponeste": "giustapporre",
    "giustapponesti": "giustapporre",
    "giustapponete": "giustapporre",
    "giustapponeva": "giustapporre",
    "giustapponevamo": "giustapporre",
    "giustapponevan": "giustapporre",
    "giustapponevano": "giustapporre",
    "giustapponevate": "giustapporre",
    "giustapponevi": "giustapporre",
    "giustapponevo": "giustapporre",
    "giustapponga": "giustapporre",
    "giustappongan": "giustapporre",
    "giustappongano": "giustapporre",
    "giustappongo": "giustapporre",
    "giustappongon": "giustapporre",
    "giustappongono": "giustapporre",
    "giustapponi": "giustapporre",
    "giustapponiamo": "giustapporre",
    "giustapponiate": "giustapporre",
    "giustapporr": "giustapporre",
    "giustapporrai": "giustapporre",
    "giustapporran": "giustapporre",
    "giustapporranno": "giustapporre",
    "giustapporrebbe": "giustapporre",
    "giustapporrebber": "giustapporre",
    "giustapporrebbero": "giustapporre",
    "giustapporrei": "giustapporre",
    "giustapporremmo": "giustapporre",
    "giustapporremo": "giustapporre",
    "giustapporreste": "giustapporre",
    "giustapporresti": "giustapporre",
    "giustapporrete": "giustapporre",
    "giustapporrà": "giustapporre",
    "giustapporrò": "giustapporre",
    "giustappose": "giustapporre",
    "giustapposer": "giustapporre",
    "giustapposero": "giustapporre",
    "giustapposi": "giustapporre",
    "giustapposizioni": "giustapposizione",
    "giustapposta": "giustapporre",
    "giustapposte": "giustapporre",
    "giustapposti": "giustapporre",
    "giustapposto": "giustapporre",
    "giuste": "giusto",
    "giustezze": "giustezza",
    "giusti": "giusto",
    "giustifica": "giustificare",
    "giustificabili": "giustificabile",
    "giustificai": "giustificare",
    "giustificammo": "giustificare",
    "giustifican": "giustificare",
    "giustificando": "giustificare",
    "giustificano": "giustificare",
    "giustificante": "giustificare",
    "giustificanti": "giustificare",
    "giustificar": "giustificare",
    "giustificaron": "giustificare",
    "giustificarono": "giustificare",
    "giustificasse": "giustificare",
    "giustificasser": "giustificare",
    "giustificassero": "giustificare",
    "giustificassi": "giustificare",
    "giustificassimo": "giustificare",
    "giustificaste": "giustificare",
    "giustificasti": "giustificare",
    "giustificata": "giustificare",
    "giustificate": "giustificare",
    "giustificati": "giustificare",
    "giustificativa": "giustificativo",
    "giustificative": "giustificativo",
    "giustificativi": "giustificativo",
    "giustificato": "giustificare",
    "giustificava": "giustificare",
    "giustificavamo": "giustificare",
    "giustificavan": "giustificare",
    "giustificavano": "giustificare",
    "giustificavate": "giustificare",
    "giustificavi": "giustificare",
    "giustificavo": "giustificare",
    "giustificazioni": "giustificazione",
    "giustificazionismi": "giustificazionismo",
    "giustificherai": "giustificare",
    "giustificheran": "giustificare",
    "giustificheranno": "giustificare",
    "giustificherebbe": "giustificare",
    "giustificherebber": "giustificare",
    "giustificherebbero": "giustificare",
    "giustificherei": "giustificare",
    "giustificheremmo": "giustificare",
    "giustificheremo": "giustificare",
    "giustifichereste": "giustificare",
    "giustificheresti": "giustificare",
    "giustificherete": "giustificare",
    "giustificherà": "giustificare",
    "giustificherò": "giustificare",
    "giustifichi": "giustificare",
    "giustifichiamo": "giustificare",
    "giustifichiate": "giustificare",
    "giustifichin": "giustificare",
    "giustifichino": "giustificare",
    "giustifico": "giustificare",
    "giustificò": "giustificare",
    "giustizi": "giustiziare",
    "giustizia": "giustiziare",
    "giustiziai": "giustiziare",
    "giustizialismi": "giustizialismo",
    "giustizialisti": "giustizialista",
    "giustiziammo": "giustiziare",
    "giustiziamo": "giustiziare",
    "giustizian": "giustiziare",
    "giustiziando": "giustiziare",
    "giustiziano": "giustiziare",
    "giustiziante": "giustiziare",
    "giustizianti": "giustiziare",
    "giustiziar": "giustiziare",
    "giustiziaron": "giustiziare",
    "giustiziarono": "giustiziare",
    "giustiziasse": "giustiziare",
    "giustiziasser": "giustiziare",
    "giustiziassero": "giustiziare",
    "giustiziassi": "giustiziare",
    "giustiziassimo": "giustiziare",
    "giustiziaste": "giustiziare",
    "giustiziasti": "giustiziare",
    "giustiziata": "giustiziato",
    "giustiziate": "giustiziato",
    "giustiziati": "giustiziato",
    "giustiziato": "giustiziare",
    "giustiziava": "giustiziare",
    "giustiziavamo": "giustiziare",
    "giustiziavan": "giustiziare",
    "giustiziavano": "giustiziare",
    "giustiziavate": "giustiziare",
    "giustiziavi": "giustiziare",
    "giustiziavo": "giustiziare",
    "giustizie": "giustizia",
    "giustizierai": "giustiziare",
    "giustizieran": "giustiziare",
    "giustizieranno": "giustiziare",
    "giustizierebbe": "giustiziare",
    "giustizierebber": "giustiziare",
    "giustizierebbero": "giustiziare",
    "giustizierei": "giustiziare",
    "giustizieremmo": "giustiziare",
    "giustizieremo": "giustiziare",
    "giustiziereste": "giustiziare",
    "giustizieresti": "giustiziare",
    "giustizierete": "giustiziare",
    "giustizieri": "giustiziere",
    "giustizierà": "giustiziare",
    "giustizierò": "giustiziare",
    "giustizin": "giustiziare",
    "giustizino": "giustiziare",
    "giustizio": "giustiziare",
    "giustiziò": "giustiziare",
    "glaciali": "glaciale",
    "glaciazioni": "glaciazione",
    "gladiatori": "gladiatorio",
    "gladiatoria": "gladiatorio",
    "gladiatorie": "gladiatorio",
    "gladiatrice": "gladiatore",
    "gladiatrici": "gladiatore",
    "gladioli": "gladiolo",
    "glauca": "glauco",
    "glauche": "glauco",
    "glauci": "glauco",
    "glaucomi": "glaucoma",
    "glebe": "gleba",
    "gli": "il",
    "glicemie": "glicemia",
    "glicini": "glicine",
    "glissa": "glissare",
    "glissai": "glissare",
    "glissammo": "glissare",
    "glissan": "glissare",
    "glissando": "glissare",
    "glissano": "glissare",
    "glissante": "glissare",
    "glissanti": "glissare",
    "glissar": "glissare",
    "glissaron": "glissare",
    "glissarono": "glissare",
    "glissasse": "glissare",
    "glissasser": "glissare",
    "glissassero": "glissare",
    "glissassi": "glissare",
    "glissassimo": "glissare",
    "glissaste": "glissare",
    "glissasti": "glissare",
    "glissata": "glissare",
    "glissate": "glissare",
    "glissati": "glissare",
    "glissato": "glissare",
    "glissava": "glissare",
    "glissavamo": "glissare",
    "glissavan": "glissare",
    "glissavano": "glissare",
    "glissavate": "glissare",
    "glissavi": "glissare",
    "glissavo": "glissare",
    "glisserai": "glissare",
    "glisseran": "glissare",
    "glisseranno": "glissare",
    "glisserebbe": "glissare",
    "glisserebber": "glissare",
    "glisserebbero": "glissare",
    "glisserei": "glissare",
    "glisseremmo": "glissare",
    "glisseremo": "glissare",
    "glissereste": "glissare",
    "glisseresti": "glissare",
    "glisserete": "glissare",
    "glisserà": "glissare",
    "glisserò": "glissare",
    "glissi": "glissare",
    "glissiamo": "glissare",
    "glissiate": "glissare",
    "glissin": "glissare",
    "glissino": "glissare",
    "glisso": "glissare",
    "glissò": "glissare",
    "globali": "globale",
    "globalizza": "globalizzare",
    "globalizzai": "globalizzare",
    "globalizzammo": "globalizzare",
    "globalizzan": "globalizzare",
    "globalizzando": "globalizzare",
    "globalizzano": "globalizzare",
    "globalizzante": "globalizzare",
    "globalizzanti": "globalizzare",
    "globalizzar": "globalizzare",
    "globalizzaron": "globalizzare",
    "globalizzarono": "globalizzare",
    "globalizzasse": "globalizzare",
    "globalizzasser": "globalizzare",
    "globalizzassero": "globalizzare",
    "globalizzassi": "globalizzare",
    "globalizzassimo": "globalizzare",
    "globalizzaste": "globalizzare",
    "globalizzasti": "globalizzare",
    "globalizzata": "globalizzare",
    "globalizzate": "globalizzare",
    "globalizzati": "globalizzare",
    "globalizzato": "globalizzare",
    "globalizzava": "globalizzare",
    "globalizzavamo": "globalizzare",
    "globalizzavan": "globalizzare",
    "globalizzavano": "globalizzare",
    "globalizzavate": "globalizzare",
    "globalizzavi": "globalizzare",
    "globalizzavo": "globalizzare",
    "globalizzazioni": "globalizzazione",
    "globalizzerai": "globalizzare",
    "globalizzeran": "globalizzare",
    "globalizzeranno": "globalizzare",
    "globalizzerebbe": "globalizzare",
    "globalizzerebber": "globalizzare",
    "globalizzerebbero": "globalizzare",
    "globalizzerei": "globalizzare",
    "globalizzeremmo": "globalizzare",
    "globalizzeremo": "globalizzare",
    "globalizzereste": "globalizzare",
    "globalizzeresti": "globalizzare",
    "globalizzerete": "globalizzare",
    "globalizzerà": "globalizzare",
    "globalizzerò": "globalizzare",
    "globalizzi": "globalizzare",
    "globalizziamo": "globalizzare",
    "globalizziate": "globalizzare",
    "globalizzin": "globalizzare",
    "globalizzino": "globalizzare",
    "globalizzo": "globalizzare",
    "globalizzò": "globalizzare",
    "globi": "globo",
    "globula": "globulare",
    "globulai": "globulare",
    "globulammo": "globulare",
    "globulan": "globulare",
    "globulando": "globulare",
    "globulano": "globulare",
    "globulante": "globulare",
    "globulanti": "globulare",
    "globular": "globulare",
    "globularon": "globulare",
    "globularono": "globulare",
    "globulasse": "globulare",
    "globulasser": "globulare",
    "globulassero": "globulare",
    "globulassi": "globulare",
    "globulassimo": "globulare",
    "globulaste": "globulare",
    "globulasti": "globulare",
    "globulata": "globulare",
    "globulate": "globulare",
    "globulati": "globulare",
    "globulato": "globulare",
    "globulava": "globulare",
    "globulavamo": "globulare",
    "globulavan": "globulare",
    "globulavano": "globulare",
    "globulavate": "globulare",
    "globulavi": "globulare",
    "globulavo": "globulare",
    "globulerai": "globulare",
    "globuleran": "globulare",
    "globuleranno": "globulare",
    "globulerebbe": "globulare",
    "globulerebber": "globulare",
    "globulerebbero": "globulare",
    "globulerei": "globulare",
    "globuleremmo": "globulare",
    "globuleremo": "globulare",
    "globulereste": "globulare",
    "globuleresti": "globulare",
    "globulerete": "globulare",
    "globulerà": "globulare",
    "globulerò": "globulare",
    "globuli": "globulo",
    "globuliamo": "globulare",
    "globuliate": "globulare",
    "globulin": "globulare",
    "globulino": "globulare",
    "globulo": "globulare",
    "globulò": "globulare",
    "glori": "gloriare",
    "gloria": "gloriare",
    "gloriai": "gloriare",
    "gloriammo": "gloriare",
    "gloriamo": "gloriare",
    "glorian": "gloriare",
    "gloriando": "gloriare",
    "gloriano": "gloriare",
    "gloriante": "gloriare",
    "glorianti": "gloriare",
    "gloriar": "gloriare",
    "gloriaron": "gloriare",
    "gloriarono": "gloriare",
    "gloriasse": "gloriare",
    "gloriasser": "gloriare",
    "gloriassero": "gloriare",
    "gloriassi": "gloriare",
    "gloriassimo": "gloriare",
    "gloriaste": "gloriare",
    "gloriasti": "gloriare",
    "gloriata": "gloriare",
    "gloriate": "gloriare",
    "gloriati": "gloriare",
    "gloriato": "gloriare",
    "gloriava": "gloriare",
    "gloriavamo": "gloriare",
    "gloriavan": "gloriare",
    "gloriavano": "gloriare",
    "gloriavate": "gloriare",
    "gloriavi": "gloriare",
    "gloriavo": "gloriare",
    "glorie": "gloria",
    "glorierai": "gloriare",
    "glorieran": "gloriare",
    "glorieranno": "gloriare",
    "glorierebbe": "gloriare",
    "glorierebber": "gloriare",
    "glorierebbero": "gloriare",
    "glorierei": "gloriare",
    "glorieremmo": "gloriare",
    "glorieremo": "gloriare",
    "gloriereste": "gloriare",
    "glorieresti": "gloriare",
    "glorierete": "gloriare",
    "glorierà": "gloriare",
    "glorierò": "gloriare",
    "glorifica": "glorificare",
    "glorificai": "glorificare",
    "glorificammo": "glorificare",
    "glorifican": "glorificare",
    "glorificando": "glorificare",
    "glorificano": "glorificare",
    "glorificante": "glorificare",
    "glorificanti": "glorificare",
    "glorificar": "glorificare",
    "glorificaron": "glorificare",
    "glorificarono": "glorificare",
    "glorificasse": "glorificare",
    "glorificasser": "glorificare",
    "glorificassero": "glorificare",
    "glorificassi": "glorificare",
    "glorificassimo": "glorificare",
    "glorificaste": "glorificare",
    "glorificasti": "glorificare",
    "glorificata": "glorificare",
    "glorificate": "glorificare",
    "glorificati": "glorificare",
    "glorificato": "glorificare",
    "glorificava": "glorificare",
    "glorificavamo": "glorificare",
    "glorificavan": "glorificare",
    "glorificavano": "glorificare",
    "glorificavate": "glorificare",
    "glorificavi": "glorificare",
    "glorificavo": "glorificare",
    "glorificazioni": "glorificazione",
    "glorificherai": "glorificare",
    "glorificheran": "glorificare",
    "glorificheranno": "glorificare",
    "glorificherebbe": "glorificare",
    "glorificherebber": "glorificare",
    "glorificherebbero": "glorificare",
    "glorificherei": "glorificare",
    "glorificheremmo": "glorificare",
    "glorificheremo": "glorificare",
    "glorifichereste": "glorificare",
    "glorificheresti": "glorificare",
    "glorificherete": "glorificare",
    "glorificherà": "glorificare",
    "glorificherò": "glorificare",
    "glorifichi": "glorificare",
    "glorifichiamo": "glorificare",
    "glorifichiate": "glorificare",
    "glorifichin": "glorificare",
    "glorifichino": "glorificare",
    "glorifico": "glorificare",
    "glorificò": "glorificare",
    "glorin": "gloriare",
    "glorino": "gloriare",
    "glorio": "gloriare",
    "gloriosa": "glorioso",
    "gloriose": "glorioso",
    "gloriosi": "glorioso",
    "gloriò": "gloriare",
    "glossa": "glossare",
    "glossai": "glossare",
    "glossammo": "glossare",
    "glossan": "glossare",
    "glossando": "glossare",
    "glossano": "glossare",
    "glossante": "glossare",
    "glossanti": "glossare",
    "glossar": "glossare",
    "glossari": "glossario",
    "glossaron": "glossare",
    "glossarono": "glossare",
    "glossasse": "glossare",
    "glossasser": "glossare",
    "glossassero": "glossare",
    "glossassi": "glossare",
    "glossassimo": "glossare",
    "glossaste": "glossare",
    "glossasti": "glossare",
    "glossata": "glossare",
    "glossate": "glossare",
    "glossati": "glossare",
    "glossato": "glossare",
    "glossava": "glossare",
    "glossavamo": "glossare",
    "glossavan": "glossare",
    "glossavano": "glossare",
    "glossavate": "glossare",
    "glossavi": "glossare",
    "glossavo": "glossare",
    "glosse": "glossa",
    "glosserai": "glossare",
    "glosseran": "glossare",
    "glosseranno": "glossare",
    "glosserebbe": "glossare",
    "glosserebber": "glossare",
    "glosserebbero": "glossare",
    "glosserei": "glossare",
    "glosseremmo": "glossare",
    "glosseremo": "glossare",
    "glossereste": "glossare",
    "glosseresti": "glossare",
    "glosserete": "glossare",
    "glosserà": "glossare",
    "glosserò": "glossare",
    "glossi": "glossare",
    "glossiamo": "glossare",
    "glossiate": "glossare",
    "glossin": "glossare",
    "glossino": "glossare",
    "glosso": "glossare",
    "glossò": "glossare",
    "glottologa": "glottologo",
    "glottologhe": "glottologo",
    "glottologhi": "glottologo",
    "glucosi": "glucosio",
    "glutei": "gluteo",
    "gnocchi": "gnocco",
    "gnomi": "gnomo",
    "gnomica": "gnomico",
    "gnomiche": "gnomico",
    "gnomici": "gnomico",
    "gnostica": "gnostico",
    "gnostiche": "gnostico",
    "gnostici": "gnostico",
    "gobba": "gobbo",
    "gobbe": "gobbo",
    "gobbi": "gobbo",
    "gocce": "goccia",
    "goccerai": "gocciare",
    "gocceran": "gocciare",
    "gocceranno": "gocciare",
    "goccerebbe": "gocciare",
    "goccerebber": "gocciare",
    "goccerebbero": "gocciare",
    "goccerei": "gocciare",
    "gocceremmo": "gocciare",
    "gocceremo": "gocciare",
    "goccereste": "gocciare",
    "gocceresti": "gocciare",
    "goccerete": "gocciare",
    "goccerà": "gocciare",
    "goccerò": "gocciare",
    "gocci": "gocciare",
    "goccia": "gocciare",
    "gocciai": "gocciare",
    "gocciammo": "gocciare",
    "gocciamo": "gocciare",
    "goccian": "gocciare",
    "gocciando": "gocciare",
    "gocciano": "gocciare",
    "gocciante": "gocciare",
    "goccianti": "gocciare",
    "gocciar": "gocciare",
    "gocciaron": "gocciare",
    "gocciarono": "gocciare",
    "gocciasse": "gocciare",
    "gocciasser": "gocciare",
    "gocciassero": "gocciare",
    "gocciassi": "gocciare",
    "gocciassimo": "gocciare",
    "gocciaste": "gocciare",
    "gocciasti": "gocciare",
    "gocciata": "gocciare",
    "gocciate": "gocciare",
    "gocciati": "gocciare",
    "gocciato": "gocciare",
    "gocciava": "gocciare",
    "gocciavamo": "gocciare",
    "gocciavan": "gocciare",
    "gocciavano": "gocciare",
    "gocciavate": "gocciare",
    "gocciavi": "gocciare",
    "gocciavo": "gocciare",
    "goccin": "gocciare",
    "goccino": "gocciare",
    "goccio": "gocciare",
    "gocciola": "gocciolare",
    "gocciolai": "gocciolare",
    "gocciolammo": "gocciolare",
    "gocciolan": "gocciolare",
    "gocciolando": "gocciolare",
    "gocciolano": "gocciolare",
    "gocciolante": "gocciolare",
    "gocciolanti": "gocciolare",
    "gocciolar": "gocciolare",
    "gocciolaron": "gocciolare",
    "gocciolarono": "gocciolare",
    "gocciolasse": "gocciolare",
    "gocciolasser": "gocciolare",
    "gocciolassero": "gocciolare",
    "gocciolassi": "gocciolare",
    "gocciolassimo": "gocciolare",
    "gocciolaste": "gocciolare",
    "gocciolasti": "gocciolare",
    "gocciolata": "gocciolare",
    "gocciolate": "gocciolare",
    "gocciolati": "gocciolare",
    "gocciolato": "gocciolare",
    "gocciolava": "gocciolare",
    "gocciolavamo": "gocciolare",
    "gocciolavan": "gocciolare",
    "gocciolavano": "gocciolare",
    "gocciolavate": "gocciolare",
    "gocciolavi": "gocciolare",
    "gocciolavo": "gocciolare",
    "gocciolerai": "gocciolare",
    "goccioleran": "gocciolare",
    "goccioleranno": "gocciolare",
    "gocciolerebbe": "gocciolare",
    "gocciolerebber": "gocciolare",
    "gocciolerebbero": "gocciolare",
    "gocciolerei": "gocciolare",
    "goccioleremmo": "gocciolare",
    "goccioleremo": "gocciolare",
    "gocciolereste": "gocciolare",
    "goccioleresti": "gocciolare",
    "gocciolerete": "gocciolare",
    "gocciolerà": "gocciolare",
    "gocciolerò": "gocciolare",
    "goccioli": "gocciolare",
    "goccioliamo": "gocciolare",
    "goccioliate": "gocciolare",
    "gocciolin": "gocciolare",
    "goccioline": "gocciolina",
    "gocciolino": "gocciolare",
    "gocciolo": "gocciolare",
    "gocciolò": "gocciolare",
    "gocciò": "gocciare",
    "goda": "godere",
    "godan": "godere",
    "godano": "godere",
    "gode": "godere",
    "godei": "godere",
    "godemmo": "godere",
    "godendo": "godere",
    "godente": "godere",
    "godenti": "godere",
    "goder": "godere",
    "goderai": "godere",
    "goderan": "godere",
    "goderanno": "godere",
    "goderebbe": "godere",
    "goderebber": "godere",
    "goderebbero": "godere",
    "goderecce": "godereccio",
    "goderecci": "godereccio",
    "godereccia": "godereccio",
    "goderei": "godere",
    "goderemmo": "godere",
    "goderemo": "godere",
    "godereste": "godere",
    "goderesti": "godere",
    "goderete": "godere",
    "goderon": "godere",
    "goderono": "godere",
    "goderà": "godere",
    "goderò": "godere",
    "godesse": "godere",
    "godesser": "godere",
    "godessero": "godere",
    "godessi": "godere",
    "godessimo": "godere",
    "godeste": "godere",
    "godesti": "godere",
    "godete": "godere",
    "godeva": "godere",
    "godevamo": "godere",
    "godevan": "godere",
    "godevano": "godere",
    "godevate": "godere",
    "godevi": "godere",
    "godevo": "godere",
    "godi": "godere",
    "godiamo": "godere",
    "godiate": "godere",
    "godibili": "godibile",
    "godimenti": "godimento",
    "godo": "godere",
    "godon": "godere",
    "godono": "godere",
    "godurie": "goduria",
    "goduta": "godere",
    "godute": "godere",
    "goduti": "godere",
    "goduto": "godere",
    "godè": "godere",
    "goffa": "goffo",
    "goffaggini": "goffaggine",
    "goffe": "goffo",
    "goffi": "goffo",
    "gogne": "gogna",
    "gole": "gola",
    "goleade": "goleada",
    "golene": "golena",
    "golette": "goletta",
    "golfetti": "golfetto",
    "golfi": "golfo",
    "golfini": "golfino",
    "golfisti": "golfista",
    "golfoni": "golfone",
    "goliardate": "goliardata",
    "goliardi": "goliardo",
    "goliardica": "goliardico",
    "goliardiche": "goliardico",
    "goliardici": "goliardico",
    "goliardie": "goliardia",
    "golletti": "golletto",
    "gollismi": "gollismo",
    "gollisti": "gollista",
    "golosa": "goloso",
    "golose": "goloso",
    "golosi": "goloso",
    "golpiste": "golpista",
    "golpisti": "golpista",
    "gomitate": "gomitata",
    "gomiti": "gomito",
    "gomitoli": "gomitolo",
    "gomma": "gommare",
    "gommai": "gommare",
    "gommammo": "gommare",
    "gomman": "gommare",
    "gommando": "gommare",
    "gommano": "gommare",
    "gommante": "gommare",
    "gommanti": "gommare",
    "gommar": "gommare",
    "gommaron": "gommare",
    "gommarono": "gommare",
    "gommasse": "gommare",
    "gommasser": "gommare",
    "gommassero": "gommare",
    "gommassi": "gommare",
    "gommassimo": "gommare",
    "gommaste": "gommare",
    "gommasti": "gommare",
    "gommata": "gommare",
    "gommate": "gommare",
    "gommati": "gommare",
    "gommato": "gommare",
    "gommava": "gommare",
    "gommavamo": "gommare",
    "gommavan": "gommare",
    "gommavano": "gommare",
    "gommavate": "gommare",
    "gommavi": "gommare",
    "gommavo": "gommare",
    "gomme": "gomma",
    "gommerai": "gommare",
    "gommeran": "gommare",
    "gommeranno": "gommare",
    "gommerebbe": "gommare",
    "gommerebber": "gommare",
    "gommerebbero": "gommare",
    "gommerei": "gommare",
    "gommeremmo": "gommare",
    "gommeremo": "gommare",
    "gommereste": "gommare",
    "gommeresti": "gommare",
    "gommerete": "gommare",
    "gommerà": "gommare",
    "gommerò": "gommare",
    "gommi": "gommare",
    "gommiamo": "gommare",
    "gommiate": "gommare",
    "gommin": "gommare",
    "gommino": "gommare",
    "gommisti": "gommista",
    "gommo": "gommare",
    "gommoni": "gommone",
    "gommosa": "gommoso",
    "gommose": "gommoso",
    "gommosi": "gommoso",
    "gommò": "gommare",
    "gonadotropine": "gonadotropina",
    "gondole": "gondola",
    "gondolieri": "gondoliere",
    "gondolini": "gondolino",
    "gonfaloni": "gonfalone",
    "gonfi": "gonfio",
    "gonfia": "gonfio",
    "gonfiai": "gonfiare",
    "gonfiamenti": "gonfiamento",
    "gonfiammo": "gonfiare",
    "gonfiamo": "gonfiare",
    "gonfian": "gonfiare",
    "gonfiando": "gonfiare",
    "gonfiano": "gonfiare",
    "gonfiante": "gonfiare",
    "gonfianti": "gonfiare",
    "gonfiar": "gonfiare",
    "gonfiaron": "gonfiare",
    "gonfiarono": "gonfiare",
    "gonfiasse": "gonfiare",
    "gonfiasser": "gonfiare",
    "gonfiassero": "gonfiare",
    "gonfiassi": "gonfiare",
    "gonfiassimo": "gonfiare",
    "gonfiaste": "gonfiare",
    "gonfiasti": "gonfiare",
    "gonfiata": "gonfiato",
    "gonfiate": "gonfiato",
    "gonfiati": "gonfiato",
    "gonfiato": "gonfiare",
    "gonfiava": "gonfiare",
    "gonfiavamo": "gonfiare",
    "gonfiavan": "gonfiare",
    "gonfiavano": "gonfiare",
    "gonfiavate": "gonfiare",
    "gonfiavi": "gonfiare",
    "gonfiavo": "gonfiare",
    "gonfie": "gonfio",
    "gonfierai": "gonfiare",
    "gonfieran": "gonfiare",
    "gonfieranno": "gonfiare",
    "gonfierebbe": "gonfiare",
    "gonfierebber": "gonfiare",
    "gonfierebbero": "gonfiare",
    "gonfierei": "gonfiare",
    "gonfieremmo": "gonfiare",
    "gonfieremo": "gonfiare",
    "gonfiereste": "gonfiare",
    "gonfieresti": "gonfiare",
    "gonfierete": "gonfiare",
    "gonfierà": "gonfiare",
    "gonfierò": "gonfiare",
    "gonfin": "gonfiare",
    "gonfino": "gonfiare",
    "gonfio": "gonfiare",
    "gonfiori": "gonfiore",
    "gonfiò": "gonfiare",
    "gongola": "gongolare",
    "gongolai": "gongolare",
    "gongolammo": "gongolare",
    "gongolan": "gongolare",
    "gongolando": "gongolare",
    "gongolano": "gongolare",
    "gongolante": "gongolare",
    "gongolanti": "gongolare",
    "gongolar": "gongolare",
    "gongolaron": "gongolare",
    "gongolarono": "gongolare",
    "gongolasse": "gongolare",
    "gongolasser": "gongolare",
    "gongolassero": "gongolare",
    "gongolassi": "gongolare",
    "gongolassimo": "gongolare",
    "gongolaste": "gongolare",
    "gongolasti": "gongolare",
    "gongolata": "gongolare",
    "gongolate": "gongolare",
    "gongolati": "gongolare",
    "gongolato": "gongolare",
    "gongolava": "gongolare",
    "gongolavamo": "gongolare",
    "gongolavan": "gongolare",
    "gongolavano": "gongolare",
    "gongolavate": "gongolare",
    "gongolavi": "gongolare",
    "gongolavo": "gongolare",
    "gongolerai": "gongolare",
    "gongoleran": "gongolare",
    "gongoleranno": "gongolare",
    "gongolerebbe": "gongolare",
    "gongolerebber": "gongolare",
    "gongolerebbero": "gongolare",
    "gongolerei": "gongolare",
    "gongoleremmo": "gongolare",
    "gongoleremo": "gongolare",
    "gongolereste": "gongolare",
    "gongoleresti": "gongolare",
    "gongolerete": "gongolare",
    "gongolerà": "gongolare",
    "gongolerò": "gongolare",
    "gongoli": "gongolare",
    "gongoliamo": "gongolare",
    "gongoliate": "gongolare",
    "gongolin": "gongolare",
    "gongolino": "gongolare",
    "gongolo": "gongolare",
    "gongolò": "gongolare",
    "gonne": "gonna",
    "gonnelle": "gonnella",
    "gonnelline": "gonnellina",
    "gonnellini": "gonnellino",
    "gonza": "gonzo",
    "gonze": "gonzo",
    "gonzi": "gonzo",
    "gorbacioviana": "gorbacioviano",
    "gorbacioviane": "gorbacioviano",
    "gorbacioviani": "gorbacioviano",
    "gorbaciovismi": "gorbaciovismo",
    "gordiana": "gordiano",
    "gordiane": "gordiano",
    "gordiani": "gordiano",
    "gorgheggerai": "gorgheggiare",
    "gorgheggeran": "gorgheggiare",
    "gorgheggeranno": "gorgheggiare",
    "gorgheggerebbe": "gorgheggiare",
    "gorgheggerebber": "gorgheggiare",
    "gorgheggerebbero": "gorgheggiare",
    "gorgheggerei": "gorgheggiare",
    "gorgheggeremmo": "gorgheggiare",
    "gorgheggeremo": "gorgheggiare",
    "gorgheggereste": "gorgheggiare",
    "gorgheggeresti": "gorgheggiare",
    "gorgheggerete": "gorgheggiare",
    "gorgheggerà": "gorgheggiare",
    "gorgheggerò": "gorgheggiare",
    "gorgheggi": "gorgheggio",
    "gorgheggia": "gorgheggiare",
    "gorgheggiai": "gorgheggiare",
    "gorgheggiammo": "gorgheggiare",
    "gorgheggiamo": "gorgheggiare",
    "gorgheggian": "gorgheggiare",
    "gorgheggiando": "gorgheggiare",
    "gorgheggiano": "gorgheggiare",
    "gorgheggiante": "gorgheggiare",
    "gorgheggianti": "gorgheggiare",
    "gorgheggiar": "gorgheggiare",
    "gorgheggiaron": "gorgheggiare",
    "gorgheggiarono": "gorgheggiare",
    "gorgheggiasse": "gorgheggiare",
    "gorgheggiasser": "gorgheggiare",
    "gorgheggiassero": "gorgheggiare",
    "gorgheggiassi": "gorgheggiare",
    "gorgheggiassimo": "gorgheggiare",
    "gorgheggiaste": "gorgheggiare",
    "gorgheggiasti": "gorgheggiare",
    "gorgheggiata": "gorgheggiare",
    "gorgheggiate": "gorgheggiare",
    "gorgheggiati": "gorgheggiare",
    "gorgheggiato": "gorgheggiare",
    "gorgheggiava": "gorgheggiare",
    "gorgheggiavamo": "gorgheggiare",
    "gorgheggiavan": "gorgheggiare",
    "gorgheggiavano": "gorgheggiare",
    "gorgheggiavate": "gorgheggiare",
    "gorgheggiavi": "gorgheggiare",
    "gorgheggiavo": "gorgheggiare",
    "gorgheggin": "gorgheggiare",
    "gorgheggino": "gorgheggiare",
    "gorgheggio": "gorgheggiare",
    "gorgheggiò": "gorgheggiare",
    "gorghi": "gorgo",
    "gorgogli": "gorgogliare",
    "gorgoglia": "gorgogliare",
    "gorgogliai": "gorgogliare",
    "gorgogliammo": "gorgogliare",
    "gorgogliamo": "gorgogliare",
    "gorgoglian": "gorgogliare",
    "gorgogliando": "gorgogliare",
    "gorgogliano": "gorgogliare",
    "gorgogliante": "gorgogliare",
    "gorgoglianti": "gorgogliare",
    "gorgogliar": "gorgogliare",
    "gorgogliaron": "gorgogliare",
    "gorgogliarono": "gorgogliare",
    "gorgogliasse": "gorgogliare",
    "gorgogliasser": "gorgogliare",
    "gorgogliassero": "gorgogliare",
    "gorgogliassi": "gorgogliare",
    "gorgogliassimo": "gorgogliare",
    "gorgogliaste": "gorgogliare",
    "gorgogliasti": "gorgogliare",
    "gorgogliata": "gorgogliare",
    "gorgogliate": "gorgogliare",
    "gorgogliati": "gorgogliare",
    "gorgogliato": "gorgogliare",
    "gorgogliava": "gorgogliare",
    "gorgogliavamo": "gorgogliare",
    "gorgogliavan": "gorgogliare",
    "gorgogliavano": "gorgogliare",
    "gorgogliavate": "gorgogliare",
    "gorgogliavi": "gorgogliare",
    "gorgogliavo": "gorgogliare",
    "gorgoglierai": "gorgogliare",
    "gorgoglieran": "gorgogliare",
    "gorgoglieranno": "gorgogliare",
    "gorgoglierebbe": "gorgogliare",
    "gorgoglierebber": "gorgogliare",
    "gorgoglierebbero": "gorgogliare",
    "gorgoglierei": "gorgogliare",
    "gorgoglieremmo": "gorgogliare",
    "gorgoglieremo": "gorgogliare",
    "gorgogliereste": "gorgogliare",
    "gorgoglieresti": "gorgogliare",
    "gorgoglierete": "gorgogliare",
    "gorgoglierà": "gorgogliare",
    "gorgoglierò": "gorgogliare",
    "gorgoglii": "gorgoglio",
    "gorgoglin": "gorgogliare",
    "gorgoglino": "gorgogliare",
    "gorgoglio": "gorgogliare",
    "gorgogliò": "gorgogliare",
    "gote": "gota",
    "goti": "goto",
    "gotica": "gotico",
    "gotiche": "gotico",
    "gotici": "gotico",
    "governa": "governare",
    "governabili": "governabile",
    "governai": "governare",
    "governammo": "governare",
    "governan": "governare",
    "governando": "governare",
    "governano": "governare",
    "governante": "governare",
    "governanti": "governare",
    "governar": "governare",
    "governaron": "governare",
    "governarono": "governare",
    "governasse": "governare",
    "governasser": "governare",
    "governassero": "governare",
    "governassi": "governare",
    "governassimo": "governare",
    "governaste": "governare",
    "governasti": "governare",
    "governata": "governare",
    "governate": "governare",
    "governati": "governato",
    "governativa": "governativo",
    "governative": "governativo",
    "governativi": "governativo",
    "governato": "governare",
    "governatorati": "governatorato",
    "governatori": "governatore",
    "governava": "governare",
    "governavamo": "governare",
    "governavan": "governare",
    "governavano": "governare",
    "governavate": "governare",
    "governavi": "governare",
    "governavo": "governare",
    "governerai": "governare",
    "governeran": "governare",
    "governeranno": "governare",
    "governerebbe": "governare",
    "governerebber": "governare",
    "governerebbero": "governare",
    "governerei": "governare",
    "governeremmo": "governare",
    "governeremo": "governare",
    "governereste": "governare",
    "governeresti": "governare",
    "governerete": "governare",
    "governerà": "governare",
    "governerò": "governare",
    "governi": "governo",
    "governi-ombra": "governo-ombra",
    "governiamo": "governare",
    "governiate": "governare",
    "governicchi": "governicchio",
    "governin": "governare",
    "governino": "governare",
    "governo": "governare",
    "governò": "governare",
    "gozzi": "gozzo",
    "gozzovigli": "gozzovigliare",
    "gozzoviglia": "gozzovigliare",
    "gozzovigliai": "gozzovigliare",
    "gozzovigliammo": "gozzovigliare",
    "gozzovigliamo": "gozzovigliare",
    "gozzoviglian": "gozzovigliare",
    "gozzovigliando": "gozzovigliare",
    "gozzovigliano": "gozzovigliare",
    "gozzovigliante": "gozzovigliare",
    "gozzoviglianti": "gozzovigliare",
    "gozzovigliar": "gozzovigliare",
    "gozzovigliaron": "gozzovigliare",
    "gozzovigliarono": "gozzovigliare",
    "gozzovigliasse": "gozzovigliare",
    "gozzovigliasser": "gozzovigliare",
    "gozzovigliassero": "gozzovigliare",
    "gozzovigliassi": "gozzovigliare",
    "gozzovigliassimo": "gozzovigliare",
    "gozzovigliaste": "gozzovigliare",
    "gozzovigliasti": "gozzovigliare",
    "gozzovigliata": "gozzovigliare",
    "gozzovigliate": "gozzovigliare",
    "gozzovigliati": "gozzovigliare",
    "gozzovigliato": "gozzovigliare",
    "gozzovigliava": "gozzovigliare",
    "gozzovigliavamo": "gozzovigliare",
    "gozzovigliavan": "gozzovigliare",
    "gozzovigliavano": "gozzovigliare",
    "gozzovigliavate": "gozzovigliare",
    "gozzovigliavi": "gozzovigliare",
    "gozzovigliavo": "gozzovigliare",
    "gozzoviglie": "gozzoviglia",
    "gozzoviglierai": "gozzovigliare",
    "gozzoviglieran": "gozzovigliare",
    "gozzoviglieranno": "gozzovigliare",
    "gozzoviglierebbe": "gozzovigliare",
    "gozzoviglierebber": "gozzovigliare",
    "gozzoviglierebbero": "gozzovigliare",
    "gozzoviglierei": "gozzovigliare",
    "gozzoviglieremmo": "gozzovigliare",
    "gozzoviglieremo": "gozzovigliare",
    "gozzovigliereste": "gozzovigliare",
    "gozzoviglieresti": "gozzovigliare",
    "gozzoviglierete": "gozzovigliare",
    "gozzoviglierà": "gozzovigliare",
    "gozzoviglierò": "gozzovigliare",
    "gozzoviglin": "gozzovigliare",
    "gozzoviglino": "gozzovigliare",
    "gozzoviglio": "gozzovigliare",
    "gozzovigliò": "gozzovigliare",
    "gozzuta": "gozzuto",
    "gozzute": "gozzuto",
    "gozzuti": "gozzuto",
    "gracchi": "gracchiare",
    "gracchia": "gracchiare",
    "gracchiai": "gracchiare",
    "gracchiammo": "gracchiare",
    "gracchiamo": "gracchiare",
    "gracchian": "gracchiare",
    "gracchiando": "gracchiare",
    "gracchiano": "gracchiare",
    "gracchiante": "gracchiare",
    "gracchianti": "gracchiare",
    "gracchiar": "gracchiare",
    "gracchiaron": "gracchiare",
    "gracchiarono": "gracchiare",
    "gracchiasse": "gracchiare",
    "gracchiasser": "gracchiare",
    "gracchiassero": "gracchiare",
    "gracchiassi": "gracchiare",
    "gracchiassimo": "gracchiare",
    "gracchiaste": "gracchiare",
    "gracchiasti": "gracchiare",
    "gracchiata": "gracchiare",
    "gracchiate": "gracchiare",
    "gracchiati": "gracchiare",
    "gracchiato": "gracchiare",
    "gracchiava": "gracchiare",
    "gracchiavamo": "gracchiare",
    "gracchiavan": "gracchiare",
    "gracchiavano": "gracchiare",
    "gracchiavate": "gracchiare",
    "gracchiavi": "gracchiare",
    "gracchiavo": "gracchiare",
    "gracchierai": "gracchiare",
    "gracchieran": "gracchiare",
    "gracchieranno": "gracchiare",
    "gracchierebbe": "gracchiare",
    "gracchierebber": "gracchiare",
    "gracchierebbero": "gracchiare",
    "gracchierei": "gracchiare",
    "gracchieremmo": "gracchiare",
    "gracchieremo": "gracchiare",
    "gracchiereste": "gracchiare",
    "gracchieresti": "gracchiare",
    "gracchierete": "gracchiare",
    "gracchierà": "gracchiare",
    "gracchierò": "gracchiare",
    "gracchin": "gracchiare",
    "gracchino": "gracchiare",
    "gracchio": "gracchiare",
    "gracchiò": "gracchiare",
    "gracida": "gracidare",
    "gracidai": "gracidare",
    "gracidammo": "gracidare",
    "gracidan": "gracidare",
    "gracidando": "gracidare",
    "gracidano": "gracidare",
    "gracidante": "gracidare",
    "gracidanti": "gracidare",
    "gracidar": "gracidare",
    "gracidaron": "gracidare",
    "gracidarono": "gracidare",
    "gracidasse": "gracidare",
    "gracidasser": "gracidare",
    "gracidassero": "gracidare",
    "gracidassi": "gracidare",
    "gracidassimo": "gracidare",
    "gracidaste": "gracidare",
    "gracidasti": "gracidare",
    "gracidata": "gracidare",
    "gracidate": "gracidare",
    "gracidati": "gracidare",
    "gracidato": "gracidare",
    "gracidava": "gracidare",
    "gracidavamo": "gracidare",
    "gracidavan": "gracidare",
    "gracidavano": "gracidare",
    "gracidavate": "gracidare",
    "gracidavi": "gracidare",
    "gracidavo": "gracidare",
    "graciderai": "gracidare",
    "gracideran": "gracidare",
    "gracideranno": "gracidare",
    "graciderebbe": "gracidare",
    "graciderebber": "gracidare",
    "graciderebbero": "gracidare",
    "graciderei": "gracidare",
    "gracideremmo": "gracidare",
    "gracideremo": "gracidare",
    "gracidereste": "gracidare",
    "gracideresti": "gracidare",
    "graciderete": "gracidare",
    "graciderà": "gracidare",
    "graciderò": "gracidare",
    "gracidi": "gracidare",
    "gracidiamo": "gracidare",
    "gracidiate": "gracidare",
    "gracidin": "gracidare",
    "gracidino": "gracidare",
    "gracido": "gracidare",
    "gracidò": "gracidare",
    "gracili": "gracile",
    "gradassi": "gradasso",
    "gradazioni": "gradazione",
    "gradendo": "gradire",
    "gradente": "gradire",
    "gradenti": "gradire",
    "gradevolezze": "gradevolezza",
    "gradevoli": "gradevole",
    "gradi": "grado",
    "gradiamo": "gradire",
    "gradiate": "gradire",
    "gradii": "gradire",
    "gradimenti": "gradimento",
    "gradimmo": "gradire",
    "gradina": "gradinare",
    "gradinai": "gradinare",
    "gradinammo": "gradinare",
    "gradinan": "gradinare",
    "gradinando": "gradinare",
    "gradinano": "gradinare",
    "gradinante": "gradinare",
    "gradinanti": "gradinare",
    "gradinar": "gradinare",
    "gradinaron": "gradinare",
    "gradinarono": "gradinare",
    "gradinasse": "gradinare",
    "gradinasser": "gradinare",
    "gradinassero": "gradinare",
    "gradinassi": "gradinare",
    "gradinassimo": "gradinare",
    "gradinaste": "gradinare",
    "gradinasti": "gradinare",
    "gradinata": "gradinare",
    "gradinate": "gradinata",
    "gradinati": "gradinare",
    "gradinato": "gradinare",
    "gradinava": "gradinare",
    "gradinavamo": "gradinare",
    "gradinavan": "gradinare",
    "gradinavano": "gradinare",
    "gradinavate": "gradinare",
    "gradinavi": "gradinare",
    "gradinavo": "gradinare",
    "gradinerai": "gradinare",
    "gradineran": "gradinare",
    "gradineranno": "gradinare",
    "gradinerebbe": "gradinare",
    "gradinerebber": "gradinare",
    "gradinerebbero": "gradinare",
    "gradinerei": "gradinare",
    "gradineremmo": "gradinare",
    "gradineremo": "gradinare",
    "gradinereste": "gradinare",
    "gradineresti": "gradinare",
    "gradinerete": "gradinare",
    "gradinerà": "gradinare",
    "gradinerò": "gradinare",
    "gradini": "gradino",
    "gradiniamo": "gradinare",
    "gradiniate": "gradinare",
    "gradinin": "gradinare",
    "gradinino": "gradinare",
    "gradino": "gradinare",
    "gradinò": "gradinare",
    "gradir": "gradire",
    "gradirai": "gradire",
    "gradiran": "gradire",
    "gradiranno": "gradire",
    "gradirebbe": "gradire",
    "gradirebber": "gradire",
    "gradirebbero": "gradire",
    "gradirei": "gradire",
    "gradiremmo": "gradire",
    "gradiremo": "gradire",
    "gradireste": "gradire",
    "gradiresti": "gradire",
    "gradirete": "gradire",
    "gradiron": "gradire",
    "gradirono": "gradire",
    "gradirà": "gradire",
    "gradirò": "gradire",
    "gradisca": "gradire",
    "gradiscan": "gradire",
    "gradiscano": "gradire",
    "gradisce": "gradire",
    "gradisci": "gradire",
    "gradisco": "gradire",
    "gradiscon": "gradire",
    "gradiscono": "gradire",
    "gradisse": "gradire",
    "gradisser": "gradire",
    "gradissero": "gradire",
    "gradissi": "gradire",
    "gradissimo": "gradire",
    "gradiste": "gradire",
    "gradisti": "gradire",
    "gradita": "gradito",
    "gradite": "gradito",
    "graditi": "gradito",
    "gradito": "gradire",
    "gradiva": "gradire",
    "gradivamo": "gradire",
    "gradivan": "gradire",
    "gradivano": "gradire",
    "gradivate": "gradire",
    "gradivi": "gradire",
    "gradivo": "gradire",
    "gradoni": "gradone",
    "gradua": "graduare",
    "graduai": "graduare",
    "graduali": "graduale",
    "gradualismi": "gradualismo",
    "gradualizza": "gradualizzare",
    "gradualizzai": "gradualizzare",
    "gradualizzammo": "gradualizzare",
    "gradualizzan": "gradualizzare",
    "gradualizzando": "gradualizzare",
    "gradualizzano": "gradualizzare",
    "gradualizzante": "gradualizzare",
    "gradualizzanti": "gradualizzare",
    "gradualizzar": "gradualizzare",
    "gradualizzaron": "gradualizzare",
    "gradualizzarono": "gradualizzare",
    "gradualizzasse": "gradualizzare",
    "gradualizzasser": "gradualizzare",
    "gradualizzassero": "gradualizzare",
    "gradualizzassi": "gradualizzare",
    "gradualizzassimo": "gradualizzare",
    "gradualizzaste": "gradualizzare",
    "gradualizzasti": "gradualizzare",
    "gradualizzata": "gradualizzare",
    "gradualizzate": "gradualizzare",
    "gradualizzati": "gradualizzare",
    "gradualizzato": "gradualizzare",
    "gradualizzava": "gradualizzare",
    "gradualizzavamo": "gradualizzare",
    "gradualizzavan": "gradualizzare",
    "gradualizzavano": "gradualizzare",
    "gradualizzavate": "gradualizzare",
    "gradualizzavi": "gradualizzare",
    "gradualizzavo": "gradualizzare",
    "gradualizzerai": "gradualizzare",
    "gradualizzeran": "gradualizzare",
    "gradualizzeranno": "gradualizzare",
    "gradualizzerebbe": "gradualizzare",
    "gradualizzerebber": "gradualizzare",
    "gradualizzerebbero": "gradualizzare",
    "gradualizzerei": "gradualizzare",
    "gradualizzeremmo": "gradualizzare",
    "gradualizzeremo": "gradualizzare",
    "gradualizzereste": "gradualizzare",
    "gradualizzeresti": "gradualizzare",
    "gradualizzerete": "gradualizzare",
    "gradualizzerà": "gradualizzare",
    "gradualizzerò": "gradualizzare",
    "gradualizzi": "gradualizzare",
    "gradualizziamo": "gradualizzare",
    "gradualizziate": "gradualizzare",
    "gradualizzin": "gradualizzare",
    "gradualizzino": "gradualizzare",
    "gradualizzo": "gradualizzare",
    "gradualizzò": "gradualizzare",
    "graduammo": "graduare",
    "graduan": "graduare",
    "graduando": "graduare",
    "graduano": "graduare",
    "graduante": "graduare",
    "graduanti": "graduare",
    "graduar": "graduare",
    "graduaron": "graduare",
    "graduarono": "graduare",
    "graduasse": "graduare",
    "graduasser": "graduare",
    "graduassero": "graduare",
    "graduassi": "graduare",
    "graduassimo": "graduare",
    "graduaste": "graduare",
    "graduasti": "graduare",
    "graduata": "graduato",
    "graduate": "graduato",
    "graduati": "graduato",
    "graduato": "graduare",
    "graduatorie": "graduatoria",
    "graduava": "graduare",
    "graduavamo": "graduare",
    "graduavan": "graduare",
    "graduavano": "graduare",
    "graduavate": "graduare",
    "graduavi": "graduare",
    "graduavo": "graduare",
    "graduazioni": "graduazione",
    "graduerai": "graduare",
    "gradueran": "graduare",
    "gradueranno": "graduare",
    "graduerebbe": "graduare",
    "graduerebber": "graduare",
    "graduerebbero": "graduare",
    "graduerei": "graduare",
    "gradueremmo": "graduare",
    "gradueremo": "graduare",
    "graduereste": "graduare",
    "gradueresti": "graduare",
    "graduerete": "graduare",
    "graduerà": "graduare",
    "graduerò": "graduare",
    "gradui": "graduare",
    "graduiamo": "graduare",
    "graduiate": "graduare",
    "graduin": "graduare",
    "graduino": "graduare",
    "graduo": "graduare",
    "graduò": "graduare",
    "gradì": "gradire",
    "graffa": "graffire",
    "graffai": "graffare",
    "graffammo": "graffare",
    "graffan": "graffire",
    "graffando": "graffare",
    "graffano": "graffire",
    "graffante": "graffare",
    "graffanti": "graffare",
    "graffar": "graffare",
    "graffaron": "graffare",
    "graffarono": "graffare",
    "graffasse": "graffare",
    "graffasser": "graffare",
    "graffassero": "graffare",
    "graffassi": "graffare",
    "graffassimo": "graffare",
    "graffaste": "graffare",
    "graffasti": "graffare",
    "graffata": "graffare",
    "graffate": "graffare",
    "graffati": "graffare",
    "graffato": "graffare",
    "graffava": "graffare",
    "graffavamo": "graffare",
    "graffavan": "graffare",
    "graffavano": "graffare",
    "graffavate": "graffare",
    "graffavi": "graffare",
    "graffavo": "graffare",
    "graffe": "graffire",
    "graffendo": "graffire",
    "graffente": "graffire",
    "graffenti": "graffire",
    "grafferai": "graffare",
    "grafferan": "graffare",
    "grafferanno": "graffare",
    "grafferebbe": "graffare",
    "grafferebber": "graffare",
    "grafferebbero": "graffare",
    "grafferei": "graffare",
    "grafferemmo": "graffare",
    "grafferemo": "graffare",
    "graffereste": "graffare",
    "grafferesti": "graffare",
    "grafferete": "graffare",
    "grafferà": "graffare",
    "grafferò": "graffare",
    "graffette": "graffetta",
    "graffi": "graffire",
    "graffia": "graffiare",
    "graffiai": "graffiare",
    "graffiammo": "graffiare",
    "graffiamo": "graffire",
    "graffian": "graffiare",
    "graffiando": "graffiare",
    "graffiano": "graffiare",
    "graffiante": "graffiare",
    "graffianti": "graffiare",
    "graffiar": "graffiare",
    "graffiaron": "graffiare",
    "graffiarono": "graffiare",
    "graffiasse": "graffiare",
    "graffiasser": "graffiare",
    "graffiassero": "graffiare",
    "graffiassi": "graffiare",
    "graffiassimo": "graffiare",
    "graffiaste": "graffiare",
    "graffiasti": "graffiare",
    "graffiata": "graffiare",
    "graffiate": "graffire",
    "graffiati": "graffiare",
    "graffiato": "graffiare",
    "graffiava": "graffiare",
    "graffiavamo": "graffiare",
    "graffiavan": "graffiare",
    "graffiavano": "graffiare",
    "graffiavate": "graffiare",
    "graffiavi": "graffiare",
    "graffiavo": "graffiare",
    "graffierai": "graffiare",
    "graffieran": "graffiare",
    "graffieranno": "graffiare",
    "graffierebbe": "graffiare",
    "graffierebber": "graffiare",
    "graffierebbero": "graffiare",
    "graffierei": "graffiare",
    "graffieremmo": "graffiare",
    "graffieremo": "graffiare",
    "graffiereste": "graffiare",
    "graffieresti": "graffiare",
    "graffierete": "graffiare",
    "graffierà": "graffiare",
    "graffierò": "graffiare",
    "graffii": "graffire",
    "graffimmo": "graffire",
    "graffin": "graffiare",
    "graffino": "graffiare",
    "graffio": "graffiare",
    "graffir": "graffire",
    "graffirai": "graffire",
    "graffiran": "graffire",
    "graffiranno": "graffire",
    "graffirebbe": "graffire",
    "graffirebber": "graffire",
    "graffirebbero": "graffire",
    "graffirei": "graffire",
    "graffiremmo": "graffire",
    "graffiremo": "graffire",
    "graffireste": "graffire",
    "graffiresti": "graffire",
    "graffirete": "graffire",
    "graffiron": "graffire",
    "graffirono": "graffire",
    "graffirà": "graffire",
    "graffirò": "graffire",
    "graffisse": "graffire",
    "graffisser": "graffire",
    "graffissero": "graffire",
    "graffissi": "graffire",
    "graffissimo": "graffire",
    "graffiste": "graffire",
    "graffisti": "graffire",
    "graffita": "graffire",
    "graffite": "graffire",
    "graffiti": "graffito",
    "graffito": "graffire",
    "graffiva": "graffire",
    "graffivamo": "graffire",
    "graffivan": "graffire",
    "graffivano": "graffire",
    "graffivate": "graffire",
    "graffivi": "graffire",
    "graffivo": "graffire",
    "graffiò": "graffiare",
    "graffo": "graffire",
    "graffon": "graffire",
    "graffono": "graffire",
    "graffì": "graffire",
    "graffò": "graffare",
    "grafica": "grafico",
    "grafiche": "grafico",
    "grafici": "grafico",
    "grafie": "grafia",
    "grafiti": "grafite",
    "gragnuole": "gragnuola",
    "grama": "gramo",
    "grame": "gramo",
    "grami": "gramo",
    "grammatica": "grammatico",
    "grammaticali": "grammaticale",
    "grammatiche": "grammatico",
    "grammatici": "grammatico",
    "grammi": "grammo",
    "grammofoni": "grammofono",
    "grana": "granire",
    "granai": "granaio",
    "granan": "granire",
    "granano": "granire",
    "granata": "granato",
    "granate": "granato",
    "granati": "granato",
    "granatieri": "granatiere",
    "grancasse": "grancassa",
    "granchi": "granchio",
    "grandeggerai": "grandeggiare",
    "grandeggeran": "grandeggiare",
    "grandeggeranno": "grandeggiare",
    "grandeggerebbe": "grandeggiare",
    "grandeggerebber": "grandeggiare",
    "grandeggerebbero": "grandeggiare",
    "grandeggerei": "grandeggiare",
    "grandeggeremmo": "grandeggiare",
    "grandeggeremo": "grandeggiare",
    "grandeggereste": "grandeggiare",
    "grandeggeresti": "grandeggiare",
    "grandeggerete": "grandeggiare",
    "grandeggerà": "grandeggiare",
    "grandeggerò": "grandeggiare",
    "grandeggi": "grandeggiare",
    "grandeggia": "grandeggiare",
    "grandeggiai": "grandeggiare",
    "grandeggiammo": "grandeggiare",
    "grandeggiamo": "grandeggiare",
    "grandeggian": "grandeggiare",
    "grandeggiando": "grandeggiare",
    "grandeggiano": "grandeggiare",
    "grandeggiante": "grandeggiare",
    "grandeggianti": "grandeggiare",
    "grandeggiar": "grandeggiare",
    "grandeggiaron": "grandeggiare",
    "grandeggiarono": "grandeggiare",
    "grandeggiasse": "grandeggiare",
    "grandeggiasser": "grandeggiare",
    "grandeggiassero": "grandeggiare",
    "grandeggiassi": "grandeggiare",
    "grandeggiassimo": "grandeggiare",
    "grandeggiaste": "grandeggiare",
    "grandeggiasti": "grandeggiare",
    "grandeggiata": "grandeggiare",
    "grandeggiate": "grandeggiare",
    "grandeggiati": "grandeggiare",
    "grandeggiato": "grandeggiare",
    "grandeggiava": "grandeggiare",
    "grandeggiavamo": "grandeggiare",
    "grandeggiavan": "grandeggiare",
    "grandeggiavano": "grandeggiare",
    "grandeggiavate": "grandeggiare",
    "grandeggiavi": "grandeggiare",
    "grandeggiavo": "grandeggiare",
    "grandeggin": "grandeggiare",
    "grandeggino": "grandeggiare",
    "grandeggio": "grandeggiare",
    "grandeggiò": "grandeggiare",
    "grandezze": "grandezza",
    "grandi": "grande",
    "grandina": "grandinare",
    "grandinai": "grandinare",
    "grandinammo": "grandinare",
    "grandinan": "grandinare",
    "grandinando": "grandinare",
    "grandinano": "grandinare",
    "grandinante": "grandinare",
    "grandinanti": "grandinare",
    "grandinar": "grandinare",
    "grandinaron": "grandinare",
    "grandinarono": "grandinare",
    "grandinasse": "grandinare",
    "grandinasser": "grandinare",
    "grandinassero": "grandinare",
    "grandinassi": "grandinare",
    "grandinassimo": "grandinare",
    "grandinaste": "grandinare",
    "grandinasti": "grandinare",
    "grandinata": "grandinare",
    "grandinate": "grandinata",
    "grandinati": "grandinare",
    "grandinato": "grandinare",
    "grandinava": "grandinare",
    "grandinavamo": "grandinare",
    "grandinavan": "grandinare",
    "grandinavano": "grandinare",
    "grandinavate": "grandinare",
    "grandinavi": "grandinare",
    "grandinavo": "grandinare",
    "grandinerai": "grandinare",
    "grandineran": "grandinare",
    "grandineranno": "grandinare",
    "grandinerebbe": "grandinare",
    "grandinerebber": "grandinare",
    "grandinerebbero": "grandinare",
    "grandinerei": "grandinare",
    "grandineremmo": "grandinare",
    "grandineremo": "grandinare",
    "grandinereste": "grandinare",
    "grandineresti": "grandinare",
    "grandinerete": "grandinare",
    "grandinerà": "grandinare",
    "grandinerò": "grandinare",
    "grandini": "grandine",
    "grandiniamo": "grandinare",
    "grandiniate": "grandinare",
    "grandinin": "grandinare",
    "grandinino": "grandinare",
    "grandino": "grandinare",
    "grandinò": "grandinare",
    "grandiosa": "grandioso",
    "grandiose": "grandioso",
    "grandiosi": "grandioso",
    "granduchi": "granduca",
    "grane": "granire",
    "granelli": "granello",
    "granellini": "granellino",
    "granendo": "granire",
    "granente": "granire",
    "granenti": "granire",
    "grani": "grano",
    "graniamo": "granire",
    "graniate": "granire",
    "granii": "granire",
    "granimmo": "granire",
    "granir": "granire",
    "granirai": "granire",
    "graniran": "granire",
    "graniranno": "granire",
    "granirebbe": "granire",
    "granirebber": "granire",
    "granirebbero": "granire",
    "granirei": "granire",
    "graniremmo": "granire",
    "graniremo": "granire",
    "granireste": "granire",
    "graniresti": "granire",
    "granirete": "granire",
    "graniron": "granire",
    "granirono": "granire",
    "granirà": "granire",
    "granirò": "granire",
    "granisse": "granire",
    "granisser": "granire",
    "granissero": "granire",
    "granissi": "granire",
    "granissimo": "granire",
    "graniste": "granire",
    "granisti": "granire",
    "granita": "granire",
    "granite": "granire",
    "graniti": "granito",
    "granitica": "granitico",
    "granitiche": "granitico",
    "granitici": "granitico",
    "granito": "granire",
    "graniva": "granire",
    "granivamo": "granire",
    "granivan": "granire",
    "granivano": "granire",
    "granivate": "granire",
    "granivi": "granire",
    "granivo": "granire",
    "grano": "granire",
    "granon": "granire",
    "granono": "granire",
    "granula": "granulare",
    "granulai": "granulare",
    "granulammo": "granulare",
    "granulan": "granulare",
    "granulando": "granulare",
    "granulano": "granulare",
    "granulante": "granulare",
    "granulanti": "granulare",
    "granular": "granulare",
    "granularon": "granulare",
    "granularono": "granulare",
    "granulasse": "granulare",
    "granulasser": "granulare",
    "granulassero": "granulare",
    "granulassi": "granulare",
    "granulassimo": "granulare",
    "granulaste": "granulare",
    "granulasti": "granulare",
    "granulata": "granulare",
    "granulate": "granulare",
    "granulati": "granulare",
    "granulato": "granulare",
    "granulava": "granulare",
    "granulavamo": "granulare",
    "granulavan": "granulare",
    "granulavano": "granulare",
    "granulavate": "granulare",
    "granulavi": "granulare",
    "granulavo": "granulare",
    "granulerai": "granulare",
    "granuleran": "granulare",
    "granuleranno": "granulare",
    "granulerebbe": "granulare",
    "granulerebber": "granulare",
    "granulerebbero": "granulare",
    "granulerei": "granulare",
    "granuleremmo": "granulare",
    "granuleremo": "granulare",
    "granulereste": "granulare",
    "granuleresti": "granulare",
    "granulerete": "granulare",
    "granulerà": "granulare",
    "granulerò": "granulare",
    "granuli": "granulare",
    "granuliamo": "granulare",
    "granuliate": "granulare",
    "granulin": "granulare",
    "granulino": "granulare",
    "granulo": "granulare",
    "granulosa": "granuloso",
    "granulose": "granuloso",
    "granulosi": "granuloso",
    "granulò": "granulare",
    "granì": "granire",
    "grappe": "grappa",
    "grappini": "grappino",
    "grappoli": "grappolo",
    "grassa": "grasso",
    "grasse": "grasso",
    "grassetta": "grassetto",
    "grassette": "grassetto",
    "grassetti": "grassetto",
    "grassezze": "grassezza",
    "grassi": "grasso",
    "grassocce": "grassoccio",
    "grassocci": "grassoccio",
    "grassoccia": "grassoccio",
    "grassoni": "grassone",
    "grata": "grato",
    "grate": "grato",
    "grati": "grato",
    "graticole": "graticola",
    "gratifica": "gratificare",
    "gratificai": "gratificare",
    "gratificammo": "gratificare",
    "gratifican": "gratificare",
    "gratificando": "gratificare",
    "gratificano": "gratificare",
    "gratificante": "gratificare",
    "gratificanti": "gratificare",
    "gratificar": "gratificare",
    "gratificaron": "gratificare",
    "gratificarono": "gratificare",
    "gratificasse": "gratificare",
    "gratificasser": "gratificare",
    "gratificassero": "gratificare",
    "gratificassi": "gratificare",
    "gratificassimo": "gratificare",
    "gratificaste": "gratificare",
    "gratificasti": "gratificare",
    "gratificata": "gratificare",
    "gratificate": "gratificare",
    "gratificati": "gratificare",
    "gratificato": "gratificare",
    "gratificava": "gratificare",
    "gratificavamo": "gratificare",
    "gratificavan": "gratificare",
    "gratificavano": "gratificare",
    "gratificavate": "gratificare",
    "gratificavi": "gratificare",
    "gratificavo": "gratificare",
    "gratificazioni": "gratificazione",
    "gratifiche": "gratifica",
    "gratificherai": "gratificare",
    "gratificheran": "gratificare",
    "gratificheranno": "gratificare",
    "gratificherebbe": "gratificare",
    "gratificherebber": "gratificare",
    "gratificherebbero": "gratificare",
    "gratificherei": "gratificare",
    "gratificheremmo": "gratificare",
    "gratificheremo": "gratificare",
    "gratifichereste": "gratificare",
    "gratificheresti": "gratificare",
    "gratificherete": "gratificare",
    "gratificherà": "gratificare",
    "gratificherò": "gratificare",
    "gratifichi": "gratificare",
    "gratifichiamo": "gratificare",
    "gratifichiate": "gratificare",
    "gratifichin": "gratificare",
    "gratifichino": "gratificare",
    "gratifico": "gratificare",
    "gratificò": "gratificare",
    "gratina": "gratinare",
    "gratinai": "gratinare",
    "gratinammo": "gratinare",
    "gratinan": "gratinare",
    "gratinando": "gratinare",
    "gratinano": "gratinare",
    "gratinante": "gratinare",
    "gratinanti": "gratinare",
    "gratinar": "gratinare",
    "gratinaron": "gratinare",
    "gratinarono": "gratinare",
    "gratinasse": "gratinare",
    "gratinasser": "gratinare",
    "gratinassero": "gratinare",
    "gratinassi": "gratinare",
    "gratinassimo": "gratinare",
    "gratinaste": "gratinare",
    "gratinasti": "gratinare",
    "gratinata": "gratinare",
    "gratinate": "gratinare",
    "gratinati": "gratinare",
    "gratinato": "gratinare",
    "gratinava": "gratinare",
    "gratinavamo": "gratinare",
    "gratinavan": "gratinare",
    "gratinavano": "gratinare",
    "gratinavate": "gratinare",
    "gratinavi": "gratinare",
    "gratinavo": "gratinare",
    "gratinerai": "gratinare",
    "gratineran": "gratinare",
    "gratineranno": "gratinare",
    "gratinerebbe": "gratinare",
    "gratinerebber": "gratinare",
    "gratinerebbero": "gratinare",
    "gratinerei": "gratinare",
    "gratineremmo": "gratinare",
    "gratineremo": "gratinare",
    "gratinereste": "gratinare",
    "gratineresti": "gratinare",
    "gratinerete": "gratinare",
    "gratinerà": "gratinare",
    "gratinerò": "gratinare",
    "gratini": "gratinare",
    "gratiniamo": "gratinare",
    "gratiniate": "gratinare",
    "gratinin": "gratinare",
    "gratinino": "gratinare",
    "gratino": "gratinare",
    "gratinò": "gratinare",
    "gratitudini": "gratitudine",
    "gratta": "grattare",
    "grattacapi": "grattacapo",
    "grattacieli": "grattacielo",
    "grattai": "grattare",
    "grattammo": "grattare",
    "grattan": "grattare",
    "grattando": "grattare",
    "grattano": "grattare",
    "grattante": "grattare",
    "grattanti": "grattare",
    "grattar": "grattare",
    "grattaron": "grattare",
    "grattarono": "grattare",
    "grattasse": "grattare",
    "grattasser": "grattare",
    "grattassero": "grattare",
    "grattassi": "grattare",
    "grattassimo": "grattare",
    "grattaste": "grattare",
    "grattasti": "grattare",
    "grattata": "grattare",
    "grattate": "grattare",
    "grattati": "grattare",
    "grattato": "grattare",
    "grattava": "grattare",
    "grattavamo": "grattare",
    "grattavan": "grattare",
    "grattavano": "grattare",
    "grattavate": "grattare",
    "grattavi": "grattare",
    "grattavo": "grattare",
    "gratterai": "grattare",
    "gratteran": "grattare",
    "gratteranno": "grattare",
    "gratterebbe": "grattare",
    "gratterebber": "grattare",
    "gratterebbero": "grattare",
    "gratterei": "grattare",
    "gratteremmo": "grattare",
    "gratteremo": "grattare",
    "grattereste": "grattare",
    "gratteresti": "grattare",
    "gratterete": "grattare",
    "gratterà": "grattare",
    "gratterò": "grattare",
    "gratti": "grattare",
    "grattiamo": "grattare",
    "grattiate": "grattare",
    "grattin": "grattare",
    "grattino": "grattare",
    "gratto": "grattare",
    "grattugerai": "grattugiare",
    "grattugeran": "grattugiare",
    "grattugeranno": "grattugiare",
    "grattugerebbe": "grattugiare",
    "grattugerebber": "grattugiare",
    "grattugerebbero": "grattugiare",
    "grattugerei": "grattugiare",
    "grattugeremmo": "grattugiare",
    "grattugeremo": "grattugiare",
    "grattugereste": "grattugiare",
    "grattugeresti": "grattugiare",
    "grattugerete": "grattugiare",
    "grattugerà": "grattugiare",
    "grattugerò": "grattugiare",
    "grattugi": "grattugiare",
    "grattugia": "grattugiare",
    "grattugiai": "grattugiare",
    "grattugiammo": "grattugiare",
    "grattugiamo": "grattugiare",
    "grattugian": "grattugiare",
    "grattugiando": "grattugiare",
    "grattugiano": "grattugiare",
    "grattugiante": "grattugiare",
    "grattugianti": "grattugiare",
    "grattugiar": "grattugiare",
    "grattugiaron": "grattugiare",
    "grattugiarono": "grattugiare",
    "grattugiasse": "grattugiare",
    "grattugiasser": "grattugiare",
    "grattugiassero": "grattugiare",
    "grattugiassi": "grattugiare",
    "grattugiassimo": "grattugiare",
    "grattugiaste": "grattugiare",
    "grattugiasti": "grattugiare",
    "grattugiata": "grattugiare",
    "grattugiate": "grattugiare",
    "grattugiati": "grattugiare",
    "grattugiato": "grattugiare",
    "grattugiava": "grattugiare",
    "grattugiavamo": "grattugiare",
    "grattugiavan": "grattugiare",
    "grattugiavano": "grattugiare",
    "grattugiavate": "grattugiare",
    "grattugiavi": "grattugiare",
    "grattugiavo": "grattugiare",
    "grattugin": "grattugiare",
    "grattugino": "grattugiare",
    "grattugio": "grattugiare",
    "grattugiò": "grattugiare",
    "grattò": "grattare",
    "gratuita": "gratuito",
    "gratuite": "gratuito",
    "gratuiti": "gratuito",
    "grava": "gravare",
    "gravai": "gravare",
    "gravami": "gravame",
    "gravammo": "gravare",
    "gravan": "gravare",
    "gravando": "gravare",
    "gravano": "gravare",
    "gravante": "gravare",
    "gravanti": "gravare",
    "gravar": "gravare",
    "gravaron": "gravare",
    "gravarono": "gravare",
    "gravasse": "gravare",
    "gravasser": "gravare",
    "gravassero": "gravare",
    "gravassi": "gravare",
    "gravassimo": "gravare",
    "gravaste": "gravare",
    "gravasti": "gravare",
    "gravata": "gravato",
    "gravate": "gravato",
    "gravati": "gravato",
    "gravato": "gravare",
    "gravava": "gravare",
    "gravavamo": "gravare",
    "gravavan": "gravare",
    "gravavano": "gravare",
    "gravavate": "gravare",
    "gravavi": "gravare",
    "gravavo": "gravare",
    "graverai": "gravare",
    "graveran": "gravare",
    "graveranno": "gravare",
    "graverebbe": "gravare",
    "graverebber": "gravare",
    "graverebbero": "gravare",
    "graverei": "gravare",
    "graveremmo": "gravare",
    "graveremo": "gravare",
    "gravereste": "gravare",
    "graveresti": "gravare",
    "graverete": "gravare",
    "graverà": "gravare",
    "graverò": "gravare",
    "gravi": "grave",
    "graviamo": "gravare",
    "graviate": "gravare",
    "gravida": "gravido",
    "gravidanze": "gravidanza",
    "gravide": "gravido",
    "gravidi": "gravido",
    "gravin": "gravare",
    "gravino": "gravare",
    "gravita": "gravitare",
    "gravitai": "gravitare",
    "gravitammo": "gravitare",
    "gravitan": "gravitare",
    "gravitando": "gravitare",
    "gravitano": "gravitare",
    "gravitante": "gravitare",
    "gravitanti": "gravitare",
    "gravitar": "gravitare",
    "gravitaron": "gravitare",
    "gravitarono": "gravitare",
    "gravitasse": "gravitare",
    "gravitasser": "gravitare",
    "gravitassero": "gravitare",
    "gravitassi": "gravitare",
    "gravitassimo": "gravitare",
    "gravitaste": "gravitare",
    "gravitasti": "gravitare",
    "gravitata": "gravitare",
    "gravitate": "gravitare",
    "gravitati": "gravitare",
    "gravitato": "gravitare",
    "gravitava": "gravitare",
    "gravitavamo": "gravitare",
    "gravitavan": "gravitare",
    "gravitavano": "gravitare",
    "gravitavate": "gravitare",
    "gravitavi": "gravitare",
    "gravitavo": "gravitare",
    "gravitazionali": "gravitazionale",
    "gravitazioni": "gravitazione",
    "graviterai": "gravitare",
    "graviteran": "gravitare",
    "graviteranno": "gravitare",
    "graviterebbe": "gravitare",
    "graviterebber": "gravitare",
    "graviterebbero": "gravitare",
    "graviterei": "gravitare",
    "graviteremmo": "gravitare",
    "graviteremo": "gravitare",
    "gravitereste": "gravitare",
    "graviteresti": "gravitare",
    "graviterete": "gravitare",
    "graviterà": "gravitare",
    "graviterò": "gravitare",
    "graviti": "gravitare",
    "gravitiamo": "gravitare",
    "gravitiate": "gravitare",
    "gravitin": "gravitare",
    "gravitino": "gravitare",
    "gravito": "gravitare",
    "gravitò": "gravitare",
    "gravo": "gravare",
    "gravosa": "gravoso",
    "gravose": "gravoso",
    "gravosi": "gravoso",
    "gravò": "gravare",
    "grazi": "graziare",
    "grazia": "graziare",
    "graziai": "graziare",
    "graziammo": "graziare",
    "graziamo": "graziare",
    "grazian": "graziare",
    "graziando": "graziare",
    "graziano": "graziare",
    "graziante": "graziare",
    "grazianti": "graziare",
    "graziar": "graziare",
    "graziaron": "graziare",
    "graziarono": "graziare",
    "graziasse": "graziare",
    "graziasser": "graziare",
    "graziassero": "graziare",
    "graziassi": "graziare",
    "graziassimo": "graziare",
    "graziaste": "graziare",
    "graziasti": "graziare",
    "graziata": "graziato",
    "graziate": "graziato",
    "graziati": "graziato",
    "graziato": "graziare",
    "graziava": "graziare",
    "graziavamo": "graziare",
    "graziavan": "graziare",
    "graziavano": "graziare",
    "graziavate": "graziare",
    "graziavi": "graziare",
    "graziavo": "graziare",
    "grazie": "grazia",
    "grazierai": "graziare",
    "grazieran": "graziare",
    "grazieranno": "graziare",
    "grazierebbe": "graziare",
    "grazierebber": "graziare",
    "grazierebbero": "graziare",
    "grazierei": "graziare",
    "grazieremmo": "graziare",
    "grazieremo": "graziare",
    "graziereste": "graziare",
    "grazieresti": "graziare",
    "grazierete": "graziare",
    "grazierà": "graziare",
    "grazierò": "graziare",
    "grazin": "graziare",
    "grazino": "graziare",
    "grazio": "graziare",
    "graziosa": "grazioso",
    "graziose": "grazioso",
    "graziosi": "grazioso",
    "graziò": "graziare",
    "greca": "greco",
    "grecali": "grecale",
    "grecanica": "grecanico",
    "grecaniche": "grecanico",
    "grecanici": "grecanico",
    "greche": "greco",
    "greci": "greco",
    "grecisti": "grecista",
    "grecizza": "grecizzare",
    "grecizzai": "grecizzare",
    "grecizzammo": "grecizzare",
    "grecizzan": "grecizzare",
    "grecizzando": "grecizzare",
    "grecizzano": "grecizzare",
    "grecizzante": "grecizzare",
    "grecizzanti": "grecizzare",
    "grecizzar": "grecizzare",
    "grecizzaron": "grecizzare",
    "grecizzarono": "grecizzare",
    "grecizzasse": "grecizzare",
    "grecizzasser": "grecizzare",
    "grecizzassero": "grecizzare",
    "grecizzassi": "grecizzare",
    "grecizzassimo": "grecizzare",
    "grecizzaste": "grecizzare",
    "grecizzasti": "grecizzare",
    "grecizzata": "grecizzare",
    "grecizzate": "grecizzare",
    "grecizzati": "grecizzare",
    "grecizzato": "grecizzare",
    "grecizzava": "grecizzare",
    "grecizzavamo": "grecizzare",
    "grecizzavan": "grecizzare",
    "grecizzavano": "grecizzare",
    "grecizzavate": "grecizzare",
    "grecizzavi": "grecizzare",
    "grecizzavo": "grecizzare",
    "grecizzerai": "grecizzare",
    "grecizzeran": "grecizzare",
    "grecizzeranno": "grecizzare",
    "grecizzerebbe": "grecizzare",
    "grecizzerebber": "grecizzare",
    "grecizzerebbero": "grecizzare",
    "grecizzerei": "grecizzare",
    "grecizzeremmo": "grecizzare",
    "grecizzeremo": "grecizzare",
    "grecizzereste": "grecizzare",
    "grecizzeresti": "grecizzare",
    "grecizzerete": "grecizzare",
    "grecizzerà": "grecizzare",
    "grecizzerò": "grecizzare",
    "grecizzi": "grecizzare",
    "grecizziamo": "grecizzare",
    "grecizziate": "grecizzare",
    "grecizzin": "grecizzare",
    "grecizzino": "grecizzare",
    "grecizzo": "grecizzare",
    "grecizzò": "grecizzare",
    "greco-ortodossa": "greco-ortodosso",
    "greco-ortodosse": "greco-ortodosso",
    "greco-ortodossi": "greco-ortodosso",
    "greco-romana": "greco-romano",
    "greco-romane": "greco-romano",
    "greco-romani": "greco-romano",
    "greenshoes": "greenshoe",
    "gregari": "gregario",
    "gregaria": "gregario",
    "gregarie": "gregario",
    "gregge": "greggio",
    "greggi": "greggio",
    "greggia": "greggio",
    "gregoriana": "gregoriano",
    "gregoriane": "gregoriano",
    "gregoriani": "gregoriano",
    "grembi": "grembo",
    "grembiuli": "grembiule",
    "grembiulini": "grembiulino",
    "grembiuloni": "grembiulone",
    "gremendo": "gremire",
    "gremente": "gremire",
    "grementi": "gremire",
    "gremiamo": "gremire",
    "gremiate": "gremire",
    "gremii": "gremire",
    "gremimmo": "gremire",
    "gremir": "gremire",
    "gremirai": "gremire",
    "gremiran": "gremire",
    "gremiranno": "gremire",
    "gremirebbe": "gremire",
    "gremirebber": "gremire",
    "gremirebbero": "gremire",
    "gremirei": "gremire",
    "gremiremmo": "gremire",
    "gremiremo": "gremire",
    "gremireste": "gremire",
    "gremiresti": "gremire",
    "gremirete": "gremire",
    "gremiron": "gremire",
    "gremirono": "gremire",
    "gremirà": "gremire",
    "gremirò": "gremire",
    "gremisca": "gremire",
    "gremiscan": "gremire",
    "gremiscano": "gremire",
    "gremisce": "gremire",
    "gremisci": "gremire",
    "gremisco": "gremire",
    "gremiscon": "gremire",
    "gremiscono": "gremire",
    "gremisse": "gremire",
    "gremisser": "gremire",
    "gremissero": "gremire",
    "gremissi": "gremire",
    "gremissimo": "gremire",
    "gremiste": "gremire",
    "gremisti": "gremire",
    "gremita": "gremire",
    "gremite": "gremire",
    "gremiti": "gremire",
    "gremito": "gremire",
    "gremiva": "gremire",
    "gremivamo": "gremire",
    "gremivan": "gremire",
    "gremivano": "gremire",
    "gremivate": "gremire",
    "gremivi": "gremire",
    "gremivo": "gremire",
    "gremì": "gremire",
    "greppie": "greppia",
    "greti": "greto",
    "gretta": "gretto",
    "grette": "gretto",
    "grettezze": "grettezza",
    "gretti": "gretto",
    "grevi": "greve",
    "grezza": "grezzo",
    "grezze": "grezzo",
    "grezzi": "grezzo",
    "grida": "grido",
    "gridai": "gridare",
    "gridammo": "gridare",
    "gridan": "gridare",
    "gridando": "gridare",
    "gridano": "gridare",
    "gridante": "gridare",
    "gridanti": "gridare",
    "gridar": "gridare",
    "gridaron": "gridare",
    "gridarono": "gridare",
    "gridasse": "gridare",
    "gridasser": "gridare",
    "gridassero": "gridare",
    "gridassi": "gridare",
    "gridassimo": "gridare",
    "gridaste": "gridare",
    "gridasti": "gridare",
    "gridata": "gridare",
    "gridate": "gridare",
    "gridati": "gridare",
    "gridato": "gridare",
    "gridava": "gridare",
    "gridavamo": "gridare",
    "gridavan": "gridare",
    "gridavano": "gridare",
    "gridavate": "gridare",
    "gridavi": "gridare",
    "gridavo": "gridare",
    "griderai": "gridare",
    "grideran": "gridare",
    "grideranno": "gridare",
    "griderebbe": "gridare",
    "griderebber": "gridare",
    "griderebbero": "gridare",
    "griderei": "gridare",
    "grideremmo": "gridare",
    "grideremo": "gridare",
    "gridereste": "gridare",
    "grideresti": "gridare",
    "griderete": "gridare",
    "griderà": "gridare",
    "griderò": "gridare",
    "gridi": "grido",
    "gridiamo": "gridare",
    "gridiate": "gridare",
    "gridin": "gridare",
    "gridino": "gridare",
    "grido": "gridare",
    "gridolini": "gridolino",
    "gridò": "gridare",
    "grifagna": "grifagno",
    "grifagne": "grifagno",
    "grifagni": "grifagno",
    "griffes": "griffe",
    "grifoni": "grifone",
    "grige": "grigia",
    "grigi": "grigio",
    "grigia": "grigio",
    "grigiastra": "grigiastro",
    "grigiastre": "grigiastro",
    "grigiastri": "grigiastro",
    "grigie": "grigio",
    "grigiori": "grigiore",
    "grigioverdi": "grigioverde",
    "grigliate": "grigliata",
    "griglie": "griglia",
    "grilla": "grillare",
    "grillai": "grillare",
    "grillammo": "grillare",
    "grillan": "grillare",
    "grillando": "grillare",
    "grillano": "grillare",
    "grillante": "grillare",
    "grillanti": "grillare",
    "grillar": "grillare",
    "grillaron": "grillare",
    "grillarono": "grillare",
    "grillasse": "grillare",
    "grillasser": "grillare",
    "grillassero": "grillare",
    "grillassi": "grillare",
    "grillassimo": "grillare",
    "grillaste": "grillare",
    "grillasti": "grillare",
    "grillata": "grillare",
    "grillate": "grillare",
    "grillati": "grillare",
    "grillato": "grillare",
    "grillava": "grillare",
    "grillavamo": "grillare",
    "grillavan": "grillare",
    "grillavano": "grillare",
    "grillavate": "grillare",
    "grillavi": "grillare",
    "grillavo": "grillare",
    "grillerai": "grillare",
    "grilleran": "grillare",
    "grilleranno": "grillare",
    "grillerebbe": "grillare",
    "grillerebber": "grillare",
    "grillerebbero": "grillare",
    "grillerei": "grillare",
    "grilleremmo": "grillare",
    "grilleremo": "grillare",
    "grillereste": "grillare",
    "grilleresti": "grillare",
    "grillerete": "grillare",
    "grillerà": "grillare",
    "grillerò": "grillare",
    "grilletti": "grilletto",
    "grilli": "grillo",
    "grilliamo": "grillare",
    "grilliate": "grillare",
    "grillin": "grillare",
    "grillino": "grillare",
    "grillo": "grillare",
    "grillò": "grillare",
    "grimaldelli": "grimaldello",
    "grinfie": "grinfia",
    "grinte": "grinta",
    "grintosa": "grintoso",
    "grintose": "grintoso",
    "grintosi": "grintoso",
    "grinzosa": "grinzoso",
    "grinzose": "grinzoso",
    "grinzosi": "grinzoso",
    "grippa": "grippare",
    "grippai": "grippare",
    "grippammo": "grippare",
    "grippan": "grippare",
    "grippando": "grippare",
    "grippano": "grippare",
    "grippante": "grippare",
    "grippanti": "grippare",
    "grippar": "grippare",
    "gripparon": "grippare",
    "gripparono": "grippare",
    "grippasse": "grippare",
    "grippasser": "grippare",
    "grippassero": "grippare",
    "grippassi": "grippare",
    "grippassimo": "grippare",
    "grippaste": "grippare",
    "grippasti": "grippare",
    "grippata": "grippare",
    "grippate": "grippare",
    "grippati": "grippare",
    "grippato": "grippare",
    "grippava": "grippare",
    "grippavamo": "grippare",
    "grippavan": "grippare",
    "grippavano": "grippare",
    "grippavate": "grippare",
    "grippavi": "grippare",
    "grippavo": "grippare",
    "gripperai": "grippare",
    "gripperan": "grippare",
    "gripperanno": "grippare",
    "gripperebbe": "grippare",
    "gripperebber": "grippare",
    "gripperebbero": "grippare",
    "gripperei": "grippare",
    "gripperemmo": "grippare",
    "gripperemo": "grippare",
    "grippereste": "grippare",
    "gripperesti": "grippare",
    "gripperete": "grippare",
    "gripperà": "grippare",
    "gripperò": "grippare",
    "grippi": "grippare",
    "grippiamo": "grippare",
    "grippiate": "grippare",
    "grippin": "grippare",
    "grippino": "grippare",
    "grippo": "grippare",
    "grippò": "grippare",
    "grisaglie": "grisaglia",
    "grissini": "grissino",
    "gronda": "grondare",
    "grondai": "grondare",
    "grondaie": "grondaia",
    "grondammo": "grondare",
    "grondan": "grondare",
    "grondando": "grondare",
    "grondano": "grondare",
    "grondante": "grondare",
    "grondanti": "grondare",
    "grondar": "grondare",
    "grondaron": "grondare",
    "grondarono": "grondare",
    "grondasse": "grondare",
    "grondasser": "grondare",
    "grondassero": "grondare",
    "grondassi": "grondare",
    "grondassimo": "grondare",
    "grondaste": "grondare",
    "grondasti": "grondare",
    "grondata": "grondare",
    "grondate": "grondare",
    "grondati": "grondare",
    "grondato": "grondare",
    "grondava": "grondare",
    "grondavamo": "grondare",
    "grondavan": "grondare",
    "grondavano": "grondare",
    "grondavate": "grondare",
    "grondavi": "grondare",
    "grondavo": "grondare",
    "gronderai": "grondare",
    "gronderan": "grondare",
    "gronderanno": "grondare",
    "gronderebbe": "grondare",
    "gronderebber": "grondare",
    "gronderebbero": "grondare",
    "gronderei": "grondare",
    "gronderemmo": "grondare",
    "gronderemo": "grondare",
    "grondereste": "grondare",
    "gronderesti": "grondare",
    "gronderete": "grondare",
    "gronderà": "grondare",
    "gronderò": "grondare",
    "grondi": "grondare",
    "grondiamo": "grondare",
    "grondiate": "grondare",
    "grondin": "grondare",
    "grondino": "grondare",
    "grondo": "grondare",
    "grondò": "grondare",
    "groppe": "groppa",
    "groppi": "groppo",
    "gropponi": "groppone",
    "grossa": "grosso",
    "grosse": "grosso",
    "grossi": "grosso",
    "grossisti": "grossista",
    "grossolana": "grossolano",
    "grossolane": "grossolano",
    "grossolani": "grossolano",
    "grotte": "grotta",
    "grottesca": "grottesco",
    "grottesche": "grottesco",
    "grotteschi": "grottesco",
    "grovigli": "groviglio",
    "grucce": "gruccia",
    "grufola": "grufolare",
    "grufolai": "grufolare",
    "grufolammo": "grufolare",
    "grufolan": "grufolare",
    "grufolando": "grufolare",
    "grufolano": "grufolare",
    "grufolante": "grufolare",
    "grufolanti": "grufolare",
    "grufolar": "grufolare",
    "grufolaron": "grufolare",
    "grufolarono": "grufolare",
    "grufolasse": "grufolare",
    "grufolasser": "grufolare",
    "grufolassero": "grufolare",
    "grufolassi": "grufolare",
    "grufolassimo": "grufolare",
    "grufolaste": "grufolare",
    "grufolasti": "grufolare",
    "grufolata": "grufolare",
    "grufolate": "grufolare",
    "grufolati": "grufolare",
    "grufolato": "grufolare",
    "grufolava": "grufolare",
    "grufolavamo": "grufolare",
    "grufolavan": "grufolare",
    "grufolavano": "grufolare",
    "grufolavate": "grufolare",
    "grufolavi": "grufolare",
    "grufolavo": "grufolare",
    "grufolerai": "grufolare",
    "grufoleran": "grufolare",
    "grufoleranno": "grufolare",
    "grufolerebbe": "grufolare",
    "grufolerebber": "grufolare",
    "grufolerebbero": "grufolare",
    "grufolerei": "grufolare",
    "grufoleremmo": "grufolare",
    "grufoleremo": "grufolare",
    "grufolereste": "grufolare",
    "grufoleresti": "grufolare",
    "grufolerete": "grufolare",
    "grufolerà": "grufolare",
    "grufolerò": "grufolare",
    "grufoli": "grufolare",
    "grufoliamo": "grufolare",
    "grufoliate": "grufolare",
    "grufolin": "grufolare",
    "grufolino": "grufolare",
    "grufolo": "grufolare",
    "grufolò": "grufolare",
    "grugna": "grugnire",
    "grugnan": "grugnire",
    "grugnano": "grugnire",
    "grugne": "grugnire",
    "grugnendo": "grugnire",
    "grugnente": "grugnire",
    "grugnenti": "grugnire",
    "grugni": "grugnire",
    "grugniamo": "grugnire",
    "grugniate": "grugnire",
    "grugnii": "grugnire",
    "grugnimmo": "grugnire",
    "grugnir": "grugnire",
    "grugnirai": "grugnire",
    "grugniran": "grugnire",
    "grugniranno": "grugnire",
    "grugnirebbe": "grugnire",
    "grugnirebber": "grugnire",
    "grugnirebbero": "grugnire",
    "grugnirei": "grugnire",
    "grugniremmo": "grugnire",
    "grugniremo": "grugnire",
    "grugnireste": "grugnire",
    "grugniresti": "grugnire",
    "grugnirete": "grugnire",
    "grugniron": "grugnire",
    "grugnirono": "grugnire",
    "grugnirà": "grugnire",
    "grugnirò": "grugnire",
    "grugnisse": "grugnire",
    "grugnisser": "grugnire",
    "grugnissero": "grugnire",
    "grugnissi": "grugnire",
    "grugnissimo": "grugnire",
    "grugniste": "grugnire",
    "grugnisti": "grugnire",
    "grugnita": "grugnire",
    "grugnite": "grugnire",
    "grugniti": "grugnito",
    "grugnito": "grugnire",
    "grugniva": "grugnire",
    "grugnivamo": "grugnire",
    "grugnivan": "grugnire",
    "grugnivano": "grugnire",
    "grugnivate": "grugnire",
    "grugnivi": "grugnire",
    "grugnivo": "grugnire",
    "grugno": "grugnire",
    "grugnon": "grugnire",
    "grugnono": "grugnire",
    "grugnì": "grugnire",
    "grulla": "grullo",
    "grulle": "grullo",
    "grulli": "grullo",
    "grumi": "grumo",
    "gruppettari": "gruppettaro",
    "gruppetti": "gruppetto",
    "gruppi": "gruppo",
    "grupponi": "gruppone",
    "gruppuscoli": "gruppuscolo",
    "gruzzoletti": "gruzzoletto",
    "gruzzoli": "gruzzolo",
    "guada": "guadare",
    "guadabili": "guadabile",
    "guadagna": "guadagnare",
    "guadagnai": "guadagnare",
    "guadagnammo": "guadagnare",
    "guadagnan": "guadagnare",
    "guadagnando": "guadagnare",
    "guadagnano": "guadagnare",
    "guadagnante": "guadagnare",
    "guadagnanti": "guadagnare",
    "guadagnar": "guadagnare",
    "guadagnaron": "guadagnare",
    "guadagnarono": "guadagnare",
    "guadagnasse": "guadagnare",
    "guadagnasser": "guadagnare",
    "guadagnassero": "guadagnare",
    "guadagnassi": "guadagnare",
    "guadagnassimo": "guadagnare",
    "guadagnaste": "guadagnare",
    "guadagnasti": "guadagnare",
    "guadagnata": "guadagnare",
    "guadagnate": "guadagnare",
    "guadagnati": "guadagnare",
    "guadagnato": "guadagnare",
    "guadagnava": "guadagnare",
    "guadagnavamo": "guadagnare",
    "guadagnavan": "guadagnare",
    "guadagnavano": "guadagnare",
    "guadagnavate": "guadagnare",
    "guadagnavi": "guadagnare",
    "guadagnavo": "guadagnare",
    "guadagnerai": "guadagnare",
    "guadagneran": "guadagnare",
    "guadagneranno": "guadagnare",
    "guadagnerebbe": "guadagnare",
    "guadagnerebber": "guadagnare",
    "guadagnerebbero": "guadagnare",
    "guadagnerei": "guadagnare",
    "guadagneremmo": "guadagnare",
    "guadagneremo": "guadagnare",
    "guadagnereste": "guadagnare",
    "guadagneresti": "guadagnare",
    "guadagnerete": "guadagnare",
    "guadagnerà": "guadagnare",
    "guadagnerò": "guadagnare",
    "guadagni": "guadagno",
    "guadagniamo": "guadagnare",
    "guadagniate": "guadagnare",
    "guadagnin": "guadagnare",
    "guadagnino": "guadagnare",
    "guadagno": "guadagnare",
    "guadagnò": "guadagnare",
    "guadai": "guadare",
    "guadammo": "guadare",
    "guadan": "guadare",
    "guadando": "guadare",
    "guadano": "guadare",
    "guadante": "guadare",
    "guadanti": "guadare",
    "guadar": "guadare",
    "guadaron": "guadare",
    "guadarono": "guadare",
    "guadasse": "guadare",
    "guadasser": "guadare",
    "guadassero": "guadare",
    "guadassi": "guadare",
    "guadassimo": "guadare",
    "guadaste": "guadare",
    "guadasti": "guadare",
    "guadata": "guadare",
    "guadate": "guadare",
    "guadati": "guadare",
    "guadato": "guadare",
    "guadava": "guadare",
    "guadavamo": "guadare",
    "guadavan": "guadare",
    "guadavano": "guadare",
    "guadavate": "guadare",
    "guadavi": "guadare",
    "guadavo": "guadare",
    "guaderai": "guadare",
    "guaderan": "guadare",
    "guaderanno": "guadare",
    "guaderebbe": "guadare",
    "guaderebber": "guadare",
    "guaderebbero": "guadare",
    "guaderei": "guadare",
    "guaderemmo": "guadare",
    "guaderemo": "guadare",
    "guadereste": "guadare",
    "guaderesti": "guadare",
    "guaderete": "guadare",
    "guaderà": "guadare",
    "guaderò": "guadare",
    "guadi": "guadare",
    "guadiamo": "guadare",
    "guadiate": "guadare",
    "guadin": "guadare",
    "guadino": "guadare",
    "guado": "guadare",
    "guadò": "guadare",
    "guaendo": "guaire",
    "guaente": "guaire",
    "guaenti": "guaire",
    "guaglioni": "guaglione",
    "guai": "guaio",
    "guaiamo": "guaire",
    "guaiate": "guaire",
    "guaii": "guaire",
    "guaimmo": "guaire",
    "guaine": "guaina",
    "guair": "guaire",
    "guairai": "guaire",
    "guairan": "guaire",
    "guairanno": "guaire",
    "guairebbe": "guaire",
    "guairebber": "guaire",
    "guairebbero": "guaire",
    "guairei": "guaire",
    "guairemmo": "guaire",
    "guairemo": "guaire",
    "guaireste": "guaire",
    "guairesti": "guaire",
    "guairete": "guaire",
    "guairon": "guaire",
    "guairono": "guaire",
    "guairà": "guaire",
    "guairò": "guaire",
    "guaisca": "guaire",
    "guaiscan": "guaire",
    "guaiscano": "guaire",
    "guaisce": "guaire",
    "guaisci": "guaire",
    "guaisco": "guaire",
    "guaiscon": "guaire",
    "guaiscono": "guaire",
    "guaisse": "guaire",
    "guaisser": "guaire",
    "guaissero": "guaire",
    "guaissi": "guaire",
    "guaissimo": "guaire",
    "guaiste": "guaire",
    "guaisti": "guaire",
    "guaita": "guaire",
    "guaite": "guaire",
    "guaiti": "guaito",
    "guaito": "guaire",
    "guaiva": "guaire",
    "guaivamo": "guaire",
    "guaivan": "guaire",
    "guaivano": "guaire",
    "guaivate": "guaire",
    "guaivi": "guaire",
    "guaivo": "guaire",
    "gualca": "gualcire",
    "gualcan": "gualcire",
    "gualcano": "gualcire",
    "gualce": "gualcire",
    "gualcendo": "gualcire",
    "gualcente": "gualcire",
    "gualcenti": "gualcire",
    "gualci": "gualcire",
    "gualciamo": "gualcire",
    "gualciate": "gualcire",
    "gualcii": "gualcire",
    "gualcimmo": "gualcire",
    "gualcir": "gualcire",
    "gualcirai": "gualcire",
    "gualciran": "gualcire",
    "gualciranno": "gualcire",
    "gualcirebbe": "gualcire",
    "gualcirebber": "gualcire",
    "gualcirebbero": "gualcire",
    "gualcirei": "gualcire",
    "gualciremmo": "gualcire",
    "gualciremo": "gualcire",
    "gualcireste": "gualcire",
    "gualciresti": "gualcire",
    "gualcirete": "gualcire",
    "gualciron": "gualcire",
    "gualcirono": "gualcire",
    "gualcirà": "gualcire",
    "gualcirò": "gualcire",
    "gualcisse": "gualcire",
    "gualcisser": "gualcire",
    "gualcissero": "gualcire",
    "gualcissi": "gualcire",
    "gualcissimo": "gualcire",
    "gualciste": "gualcire",
    "gualcisti": "gualcire",
    "gualcita": "gualcire",
    "gualcite": "gualcire",
    "gualciti": "gualcire",
    "gualcito": "gualcire",
    "gualciva": "gualcire",
    "gualcivamo": "gualcire",
    "gualcivan": "gualcire",
    "gualcivano": "gualcire",
    "gualcivate": "gualcire",
    "gualcivi": "gualcire",
    "gualcivo": "gualcire",
    "gualco": "gualcire",
    "gualcon": "gualcire",
    "gualcono": "gualcire",
    "gualcì": "gualcire",
    "gualdrappe": "gualdrappa",
    "guance": "guancia",
    "guanti": "guanto",
    "guantoni": "guantone",
    "guappi": "guappo",
    "guarda": "guardare",
    "guardai": "guardare",
    "guardammo": "guardare",
    "guardan": "guardare",
    "guardando": "guardare",
    "guardano": "guardare",
    "guardante": "guardare",
    "guardanti": "guardare",
    "guardar": "guardare",
    "guardaron": "guardare",
    "guardarono": "guardare",
    "guardasse": "guardare",
    "guardasser": "guardare",
    "guardassero": "guardare",
    "guardassi": "guardare",
    "guardassimo": "guardare",
    "guardaste": "guardare",
    "guardasti": "guardare",
    "guardata": "guardare",
    "guardate": "guardare",
    "guardati": "guardare",
    "guardato": "guardare",
    "guardava": "guardare",
    "guardavamo": "guardare",
    "guardavan": "guardare",
    "guardavano": "guardare",
    "guardavate": "guardare",
    "guardavi": "guardare",
    "guardavo": "guardare",
    "guarderai": "guardare",
    "guarderan": "guardare",
    "guarderanno": "guardare",
    "guarderebbe": "guardare",
    "guarderebber": "guardare",
    "guarderebbero": "guardare",
    "guarderei": "guardare",
    "guarderemmo": "guardare",
    "guarderemo": "guardare",
    "guardereste": "guardare",
    "guarderesti": "guardare",
    "guarderete": "guardare",
    "guarderà": "guardare",
    "guarderò": "guardare",
    "guardi": "guardare",
    "guardiamo": "guardare",
    "guardiani": "guardiano",
    "guardiate": "guardare",
    "guardie": "guardia",
    "guardin": "guardare",
    "guardinga": "guardingo",
    "guardinghe": "guardingo",
    "guardinghi": "guardingo",
    "guardino": "guardare",
    "guardiole": "guardiola",
    "guardo": "guardare",
    "guardoni": "guardone",
    "guardò": "guardare",
    "guarendo": "guarire",
    "guarente": "guarire",
    "guarenti": "guarire",
    "guarentigie": "guarentigia",
    "guariamo": "guarire",
    "guariate": "guarire",
    "guaribili": "guaribile",
    "guarigioni": "guarigione",
    "guarii": "guarire",
    "guarimmo": "guarire",
    "guarir": "guarire",
    "guarirai": "guarire",
    "guariran": "guarire",
    "guariranno": "guarire",
    "guarirebbe": "guarire",
    "guarirebber": "guarire",
    "guarirebbero": "guarire",
    "guarirei": "guarire",
    "guariremmo": "guarire",
    "guariremo": "guarire",
    "guarireste": "guarire",
    "guariresti": "guarire",
    "guarirete": "guarire",
    "guariron": "guarire",
    "guarirono": "guarire",
    "guarirà": "guarire",
    "guarirò": "guarire",
    "guarisca": "guarire",
    "guariscan": "guarire",
    "guariscano": "guarire",
    "guarisce": "guarire",
    "guarisci": "guarire",
    "guarisco": "guarire",
    "guariscon": "guarire",
    "guariscono": "guarire",
    "guarisse": "guarire",
    "guarisser": "guarire",
    "guarissero": "guarire",
    "guarissi": "guarire",
    "guarissimo": "guarire",
    "guariste": "guarire",
    "guaristi": "guarire",
    "guarita": "guarire",
    "guarite": "guarire",
    "guariti": "guarire",
    "guarito": "guarire",
    "guaritori": "guaritore",
    "guariva": "guarire",
    "guarivamo": "guarire",
    "guarivan": "guarire",
    "guarivano": "guarire",
    "guarivate": "guarire",
    "guarivi": "guarire",
    "guarivo": "guarire",
    "guarna": "guarnire",
    "guarnan": "guarnire",
    "guarnano": "guarnire",
    "guarne": "guarnire",
    "guarnendo": "guarnire",
    "guarnente": "guarnire",
    "guarnenti": "guarnire",
    "guarni": "guarnire",
    "guarniamo": "guarnire",
    "guarniate": "guarnire",
    "guarnigioni": "guarnigione",
    "guarnii": "guarnire",
    "guarnimmo": "guarnire",
    "guarnir": "guarnire",
    "guarnirai": "guarnire",
    "guarniran": "guarnire",
    "guarniranno": "guarnire",
    "guarnirebbe": "guarnire",
    "guarnirebber": "guarnire",
    "guarnirebbero": "guarnire",
    "guarnirei": "guarnire",
    "guarniremmo": "guarnire",
    "guarniremo": "guarnire",
    "guarnireste": "guarnire",
    "guarniresti": "guarnire",
    "guarnirete": "guarnire",
    "guarniron": "guarnire",
    "guarnirono": "guarnire",
    "guarnirà": "guarnire",
    "guarnirò": "guarnire",
    "guarnisse": "guarnire",
    "guarnisser": "guarnire",
    "guarnissero": "guarnire",
    "guarnissi": "guarnire",
    "guarnissimo": "guarnire",
    "guarniste": "guarnire",
    "guarnisti": "guarnire",
    "guarnita": "guarnire",
    "guarnite": "guarnire",
    "guarniti": "guarnire",
    "guarnito": "guarnire",
    "guarniva": "guarnire",
    "guarnivamo": "guarnire",
    "guarnivan": "guarnire",
    "guarnivano": "guarnire",
    "guarnivate": "guarnire",
    "guarnivi": "guarnire",
    "guarnivo": "guarnire",
    "guarnizioni": "guarnizione",
    "guarno": "guarnire",
    "guarnon": "guarnire",
    "guarnono": "guarnire",
    "guarnì": "guarnire",
    "guarì": "guarire",
    "guasconate": "guasconata",
    "guasconi": "guascone",
    "guasta": "guasto",
    "guastai": "guastare",
    "guastammo": "guastare",
    "guastan": "guastare",
    "guastando": "guastare",
    "guastano": "guastare",
    "guastante": "guastare",
    "guastanti": "guastare",
    "guastar": "guastare",
    "guastaron": "guastare",
    "guastarono": "guastare",
    "guastasse": "guastare",
    "guastasser": "guastare",
    "guastassero": "guastare",
    "guastassi": "guastare",
    "guastassimo": "guastare",
    "guastaste": "guastare",
    "guastasti": "guastare",
    "guastata": "guastare",
    "guastate": "guastare",
    "guastati": "guastare",
    "guastato": "guastare",
    "guastatori": "guastatore",
    "guastava": "guastare",
    "guastavamo": "guastare",
    "guastavan": "guastare",
    "guastavano": "guastare",
    "guastavate": "guastare",
    "guastavi": "guastare",
    "guastavo": "guastare",
    "guaste": "guasto",
    "guasterai": "guastare",
    "guasteran": "guastare",
    "guasteranno": "guastare",
    "guasterebbe": "guastare",
    "guasterebber": "guastare",
    "guasterebbero": "guastare",
    "guasterei": "guastare",
    "guasteremmo": "guastare",
    "guasteremo": "guastare",
    "guastereste": "guastare",
    "guasteresti": "guastare",
    "guasterete": "guastare",
    "guasterà": "guastare",
    "guasterò": "guastare",
    "guasti": "guasto",
    "guastiamo": "guastare",
    "guastiate": "guastare",
    "guastin": "guastare",
    "guastino": "guastare",
    "guasto": "guastare",
    "guastò": "guastare",
    "guata": "guatare",
    "guatai": "guatare",
    "guatammo": "guatare",
    "guatan": "guatare",
    "guatando": "guatare",
    "guatano": "guatare",
    "guatante": "guatare",
    "guatanti": "guatare",
    "guatar": "guatare",
    "guataron": "guatare",
    "guatarono": "guatare",
    "guatasse": "guatare",
    "guatasser": "guatare",
    "guatassero": "guatare",
    "guatassi": "guatare",
    "guatassimo": "guatare",
    "guataste": "guatare",
    "guatasti": "guatare",
    "guatata": "guatare",
    "guatate": "guatare",
    "guatati": "guatare",
    "guatato": "guatare",
    "guatava": "guatare",
    "guatavamo": "guatare",
    "guatavan": "guatare",
    "guatavano": "guatare",
    "guatavate": "guatare",
    "guatavi": "guatare",
    "guatavo": "guatare",
    "guatemalteca": "guatemalteco",
    "guatemalteche": "guatemalteco",
    "guatemaltechi": "guatemalteco",
    "guatemalteci": "guatemalteco",
    "guaterai": "guatare",
    "guateran": "guatare",
    "guateranno": "guatare",
    "guaterebbe": "guatare",
    "guaterebber": "guatare",
    "guaterebbero": "guatare",
    "guaterei": "guatare",
    "guateremmo": "guatare",
    "guateremo": "guatare",
    "guatereste": "guatare",
    "guateresti": "guatare",
    "guaterete": "guatare",
    "guaterà": "guatare",
    "guaterò": "guatare",
    "guati": "guatare",
    "guatiamo": "guatare",
    "guatiate": "guatare",
    "guatin": "guatare",
    "guatino": "guatare",
    "guato": "guatare",
    "guatò": "guatare",
    "guazza": "guazzare",
    "guazzabuglii": "guazzabuglio",
    "guazzai": "guazzare",
    "guazzalochiana": "guazzalochiano",
    "guazzalochiane": "guazzalochiano",
    "guazzalochiani": "guazzalochiano",
    "guazzammo": "guazzare",
    "guazzan": "guazzare",
    "guazzando": "guazzare",
    "guazzano": "guazzare",
    "guazzante": "guazzare",
    "guazzanti": "guazzare",
    "guazzar": "guazzare",
    "guazzaron": "guazzare",
    "guazzarono": "guazzare",
    "guazzasse": "guazzare",
    "guazzasser": "guazzare",
    "guazzassero": "guazzare",
    "guazzassi": "guazzare",
    "guazzassimo": "guazzare",
    "guazzaste": "guazzare",
    "guazzasti": "guazzare",
    "guazzata": "guazzare",
    "guazzate": "guazzare",
    "guazzati": "guazzare",
    "guazzato": "guazzare",
    "guazzava": "guazzare",
    "guazzavamo": "guazzare",
    "guazzavan": "guazzare",
    "guazzavano": "guazzare",
    "guazzavate": "guazzare",
    "guazzavi": "guazzare",
    "guazzavo": "guazzare",
    "guazzerai": "guazzare",
    "guazzeran": "guazzare",
    "guazzeranno": "guazzare",
    "guazzerebbe": "guazzare",
    "guazzerebber": "guazzare",
    "guazzerebbero": "guazzare",
    "guazzerei": "guazzare",
    "guazzeremmo": "guazzare",
    "guazzeremo": "guazzare",
    "guazzereste": "guazzare",
    "guazzeresti": "guazzare",
    "guazzerete": "guazzare",
    "guazzerà": "guazzare",
    "guazzerò": "guazzare",
    "guazzi": "guazzare",
    "guazziamo": "guazzare",
    "guazziate": "guazzare",
    "guazzin": "guazzare",
    "guazzino": "guazzare",
    "guazzo": "guazzare",
    "guazzò": "guazzare",
    "guaì": "guaire",
    "guelfa": "guelfo",
    "guelfe": "guelfo",
    "guelfi": "guelfo",
    "guerrafondai": "guerrafondaio",
    "guerrafondaia": "guerrafondaio",
    "guerrafondaie": "guerrafondaio",
    "guerre": "guerra",
    "guerreggerai": "guerreggiare",
    "guerreggeran": "guerreggiare",
    "guerreggeranno": "guerreggiare",
    "guerreggerebbe": "guerreggiare",
    "guerreggerebber": "guerreggiare",
    "guerreggerebbero": "guerreggiare",
    "guerreggerei": "guerreggiare",
    "guerreggeremmo": "guerreggiare",
    "guerreggeremo": "guerreggiare",
    "guerreggereste": "guerreggiare",
    "guerreggeresti": "guerreggiare",
    "guerreggerete": "guerreggiare",
    "guerreggerà": "guerreggiare",
    "guerreggerò": "guerreggiare",
    "guerreggi": "guerreggiare",
    "guerreggia": "guerreggiare",
    "guerreggiai": "guerreggiare",
    "guerreggiammo": "guerreggiare",
    "guerreggiamo": "guerreggiare",
    "guerreggian": "guerreggiare",
    "guerreggiando": "guerreggiare",
    "guerreggiano": "guerreggiare",
    "guerreggiante": "guerreggiare",
    "guerreggianti": "guerreggiare",
    "guerreggiar": "guerreggiare",
    "guerreggiaron": "guerreggiare",
    "guerreggiarono": "guerreggiare",
    "guerreggiasse": "guerreggiare",
    "guerreggiasser": "guerreggiare",
    "guerreggiassero": "guerreggiare",
    "guerreggiassi": "guerreggiare",
    "guerreggiassimo": "guerreggiare",
    "guerreggiaste": "guerreggiare",
    "guerreggiasti": "guerreggiare",
    "guerreggiata": "guerreggiare",
    "guerreggiate": "guerreggiare",
    "guerreggiati": "guerreggiare",
    "guerreggiato": "guerreggiare",
    "guerreggiava": "guerreggiare",
    "guerreggiavamo": "guerreggiare",
    "guerreggiavan": "guerreggiare",
    "guerreggiavano": "guerreggiare",
    "guerreggiavate": "guerreggiare",
    "guerreggiavi": "guerreggiare",
    "guerreggiavo": "guerreggiare",
    "guerreggin": "guerreggiare",
    "guerreggino": "guerreggiare",
    "guerreggio": "guerreggiare",
    "guerreggiò": "guerreggiare",
    "guerresca": "guerresco",
    "guerresche": "guerresco",
    "guerreschi": "guerresco",
    "guerriera": "guerriero",
    "guerriere": "guerriero",
    "guerrieri": "guerriero",
    "guerriglie": "guerriglia",
    "guerriglieri": "guerrigliero",
    "gufa": "gufare",
    "gufai": "gufare",
    "gufammo": "gufare",
    "gufan": "gufare",
    "gufando": "gufare",
    "gufano": "gufare",
    "gufante": "gufare",
    "gufanti": "gufare",
    "gufar": "gufare",
    "gufaron": "gufare",
    "gufarono": "gufare",
    "gufasse": "gufare",
    "gufasser": "gufare",
    "gufassero": "gufare",
    "gufassi": "gufare",
    "gufassimo": "gufare",
    "gufaste": "gufare",
    "gufasti": "gufare",
    "gufata": "gufare",
    "gufate": "gufare",
    "gufati": "gufare",
    "gufato": "gufare",
    "gufava": "gufare",
    "gufavamo": "gufare",
    "gufavan": "gufare",
    "gufavano": "gufare",
    "gufavate": "gufare",
    "gufavi": "gufare",
    "gufavo": "gufare",
    "guferai": "gufare",
    "guferan": "gufare",
    "guferanno": "gufare",
    "guferebbe": "gufare",
    "guferebber": "gufare",
    "guferebbero": "gufare",
    "guferei": "gufare",
    "guferemmo": "gufare",
    "guferemo": "gufare",
    "gufereste": "gufare",
    "guferesti": "gufare",
    "guferete": "gufare",
    "guferà": "gufare",
    "guferò": "gufare",
    "gufi": "gufo",
    "gufiamo": "gufare",
    "gufiate": "gufare",
    "gufin": "gufare",
    "gufino": "gufare",
    "gufo": "gufare",
    "gufò": "gufare",
    "guglie": "guglia",
    "guida": "guidare",
    "guidai": "guidare",
    "guidammo": "guidare",
    "guidan": "guidare",
    "guidando": "guidare",
    "guidano": "guidare",
    "guidante": "guidare",
    "guidanti": "guidare",
    "guidar": "guidare",
    "guidaron": "guidare",
    "guidarono": "guidare",
    "guidasse": "guidare",
    "guidasser": "guidare",
    "guidassero": "guidare",
    "guidassi": "guidare",
    "guidassimo": "guidare",
    "guidaste": "guidare",
    "guidasti": "guidare",
    "guidata": "guidare",
    "guidate": "guidare",
    "guidati": "guidare",
    "guidato": "guidare",
    "guidatori": "guidatore",
    "guidava": "guidare",
    "guidavamo": "guidare",
    "guidavan": "guidare",
    "guidavano": "guidare",
    "guidavate": "guidare",
    "guidavi": "guidare",
    "guidavo": "guidare",
    "guide": "guida",
    "guiderai": "guidare",
    "guideran": "guidare",
    "guideranno": "guidare",
    "guiderebbe": "guidare",
    "guiderebber": "guidare",
    "guiderebbero": "guidare",
    "guiderei": "guidare",
    "guideremmo": "guidare",
    "guideremo": "guidare",
    "guidereste": "guidare",
    "guideresti": "guidare",
    "guiderete": "guidare",
    "guiderà": "guidare",
    "guiderò": "guidare",
    "guidi": "guidare",
    "guidiamo": "guidare",
    "guidiate": "guidare",
    "guidin": "guidare",
    "guidino": "guidare",
    "guido": "guidare",
    "guidò": "guidare",
    "guinzagli": "guinzaglio",
    "guise": "guisa",
    "guitta": "guitto",
    "guitte": "guitto",
    "guitti": "guitto",
    "guizza": "guizzare",
    "guizzai": "guizzare",
    "guizzammo": "guizzare",
    "guizzan": "guizzare",
    "guizzando": "guizzare",
    "guizzano": "guizzare",
    "guizzante": "guizzare",
    "guizzanti": "guizzare",
    "guizzar": "guizzare",
    "guizzaron": "guizzare",
    "guizzarono": "guizzare",
    "guizzasse": "guizzare",
    "guizzasser": "guizzare",
    "guizzassero": "guizzare",
    "guizzassi": "guizzare",
    "guizzassimo": "guizzare",
    "guizzaste": "guizzare",
    "guizzasti": "guizzare",
    "guizzata": "guizzare",
    "guizzate": "guizzare",
    "guizzati": "guizzare",
    "guizzato": "guizzare",
    "guizzava": "guizzare",
    "guizzavamo": "guizzare",
    "guizzavan": "guizzare",
    "guizzavano": "guizzare",
    "guizzavate": "guizzare",
    "guizzavi": "guizzare",
    "guizzavo": "guizzare",
    "guizzerai": "guizzare",
    "guizzeran": "guizzare",
    "guizzeranno": "guizzare",
    "guizzerebbe": "guizzare",
    "guizzerebber": "guizzare",
    "guizzerebbero": "guizzare",
    "guizzerei": "guizzare",
    "guizzeremmo": "guizzare",
    "guizzeremo": "guizzare",
    "guizzereste": "guizzare",
    "guizzeresti": "guizzare",
    "guizzerete": "guizzare",
    "guizzerà": "guizzare",
    "guizzerò": "guizzare",
    "guizzi": "guizzo",
    "guizziamo": "guizzare",
    "guizziate": "guizzare",
    "guizzin": "guizzare",
    "guizzino": "guizzare",
    "guizzo": "guizzare",
    "guizzò": "guizzare",
    "gullottiana": "gullottiano",
    "gullottiane": "gullottiano",
    "gullottiani": "gullottiano",
    "gusci": "guscio",
    "gusta": "gustare",
    "gustai": "gustare",
    "gustammo": "gustare",
    "gustan": "gustare",
    "gustando": "gustare",
    "gustano": "gustare",
    "gustante": "gustare",
    "gustanti": "gustare",
    "gustar": "gustare",
    "gustaron": "gustare",
    "gustarono": "gustare",
    "gustasse": "gustare",
    "gustasser": "gustare",
    "gustassero": "gustare",
    "gustassi": "gustare",
    "gustassimo": "gustare",
    "gustaste": "gustare",
    "gustasti": "gustare",
    "gustata": "gustare",
    "gustate": "gustare",
    "gustati": "gustare",
    "gustativa": "gustativo",
    "gustative": "gustativo",
    "gustativi": "gustativo",
    "gustato": "gustare",
    "gustava": "gustare",
    "gustavamo": "gustare",
    "gustavan": "gustare",
    "gustavano": "gustare",
    "gustavate": "gustare",
    "gustavi": "gustare",
    "gustavo": "gustare",
    "gusterai": "gustare",
    "gusteran": "gustare",
    "gusteranno": "gustare",
    "gusterebbe": "gustare",
    "gusterebber": "gustare",
    "gusterebbero": "gustare",
    "gusterei": "gustare",
    "gusteremmo": "gustare",
    "gusteremo": "gustare",
    "gustereste": "gustare",
    "gusteresti": "gustare",
    "gusterete": "gustare",
    "gusterà": "gustare",
    "gusterò": "gustare",
    "gusti": "gusto",
    "gustiamo": "gustare",
    "gustiate": "gustare",
    "gustin": "gustare",
    "gustino": "gustare",
    "gusto": "gustare",
    "gustosa": "gustoso",
    "gustose": "gustoso",
    "gustosi": "gustoso",
    "gustò": "gustare",
    "gutturali": "gutturale",
    "ha": "avere",
    "hackers": "hacker",
    "hai": "avere",
    "haiderizzata": "haiderizzato",
    "haiderizzate": "haiderizzato",
    "haiderizzati": "haiderizzato",
    "haitiana": "haitiano",
    "haitiane": "haitiano",
    "haitiani": "haitiano",
    "han": "avere",
    "handicappa": "handicappare",
    "handicappai": "handicappare",
    "handicappammo": "handicappare",
    "handicappan": "handicappare",
    "handicappando": "handicappare",
    "handicappano": "handicappare",
    "handicappante": "handicappare",
    "handicappanti": "handicappare",
    "handicappar": "handicappare",
    "handicapparon": "handicappare",
    "handicapparono": "handicappare",
    "handicappasse": "handicappare",
    "handicappasser": "handicappare",
    "handicappassero": "handicappare",
    "handicappassi": "handicappare",
    "handicappassimo": "handicappare",
    "handicappaste": "handicappare",
    "handicappasti": "handicappare",
    "handicappata": "handicappato",
    "handicappate": "handicappato",
    "handicappati": "handicappato",
    "handicappato": "handicappare",
    "handicappava": "handicappare",
    "handicappavamo": "handicappare",
    "handicappavan": "handicappare",
    "handicappavano": "handicappare",
    "handicappavate": "handicappare",
    "handicappavi": "handicappare",
    "handicappavo": "handicappare",
    "handicapperai": "handicappare",
    "handicapperan": "handicappare",
    "handicapperanno": "handicappare",
    "handicapperebbe": "handicappare",
    "handicapperebber": "handicappare",
    "handicapperebbero": "handicappare",
    "handicapperei": "handicappare",
    "handicapperemmo": "handicappare",
    "handicapperemo": "handicappare",
    "handicappereste": "handicappare",
    "handicapperesti": "handicappare",
    "handicapperete": "handicappare",
    "handicapperà": "handicappare",
    "handicapperò": "handicappare",
    "handicappi": "handicappare",
    "handicappiamo": "handicappare",
    "handicappiate": "handicappare",
    "handicappin": "handicappare",
    "handicappino": "handicappare",
    "handicappo": "handicappare",
    "handicappò": "handicappare",
    "hanno": "avere",
    "hegeliana": "hegeliano",
    "hegeliane": "hegeliano",
    "hegeliani": "hegeliano",
    "heiderian-lepeniste": "heiderian-lepenista",
    "heiderian-lepenisti": "heiderian-lepenista",
    "hippies": "hippy",
    "hitleriana": "hitleriano",
    "hitleriane": "hitleriano",
    "hitleriani": "hitleriano",
    "ho": "avere",
    "hobbies": "hobby",
    "hollywoodiana": "hollywoodiano",
    "hollywoodiane": "hollywoodiano",
    "hollywoodiani": "hollywoodiano",
    "hooligans": "hooligan",
    "i": "il",
    "iattanze": "iattanza",
    "iatture": "iattura",
    "iberica": "iberico",
    "iberiche": "iberico",
    "iberici": "iberico",
    "iberna": "ibernare",
    "ibernai": "ibernare",
    "ibernammo": "ibernare",
    "ibernan": "ibernare",
    "ibernando": "ibernare",
    "ibernano": "ibernare",
    "ibernante": "ibernare",
    "ibernanti": "ibernare",
    "ibernar": "ibernare",
    "ibernaron": "ibernare",
    "ibernarono": "ibernare",
    "ibernasse": "ibernare",
    "ibernasser": "ibernare",
    "ibernassero": "ibernare",
    "ibernassi": "ibernare",
    "ibernassimo": "ibernare",
    "ibernaste": "ibernare",
    "ibernasti": "ibernare",
    "ibernata": "ibernare",
    "ibernate": "ibernare",
    "ibernati": "ibernare",
    "ibernato": "ibernare",
    "ibernava": "ibernare",
    "ibernavamo": "ibernare",
    "ibernavan": "ibernare",
    "ibernavano": "ibernare",
    "ibernavate": "ibernare",
    "ibernavi": "ibernare",
    "ibernavo": "ibernare",
    "ibernerai": "ibernare",
    "iberneran": "ibernare",
    "iberneranno": "ibernare",
    "ibernerebbe": "ibernare",
    "ibernerebber": "ibernare",
    "ibernerebbero": "ibernare",
    "ibernerei": "ibernare",
    "iberneremmo": "ibernare",
    "iberneremo": "ibernare",
    "ibernereste": "ibernare",
    "iberneresti": "ibernare",
    "ibernerete": "ibernare",
    "ibernerà": "ibernare",
    "ibernerò": "ibernare",
    "iberni": "ibernare",
    "iberniamo": "ibernare",
    "iberniate": "ibernare",
    "ibernin": "ibernare",
    "ibernino": "ibernare",
    "iberno": "ibernare",
    "ibernò": "ibernare",
    "ibrida": "ibrido",
    "ibridai": "ibridare",
    "ibridammo": "ibridare",
    "ibridan": "ibridare",
    "ibridando": "ibridare",
    "ibridano": "ibridare",
    "ibridante": "ibridare",
    "ibridanti": "ibridare",
    "ibridar": "ibridare",
    "ibridaron": "ibridare",
    "ibridarono": "ibridare",
    "ibridasse": "ibridare",
    "ibridasser": "ibridare",
    "ibridassero": "ibridare",
    "ibridassi": "ibridare",
    "ibridassimo": "ibridare",
    "ibridaste": "ibridare",
    "ibridasti": "ibridare",
    "ibridata": "ibridare",
    "ibridate": "ibridare",
    "ibridati": "ibridare",
    "ibridato": "ibridare",
    "ibridava": "ibridare",
    "ibridavamo": "ibridare",
    "ibridavan": "ibridare",
    "ibridavano": "ibridare",
    "ibridavate": "ibridare",
    "ibridavi": "ibridare",
    "ibridavo": "ibridare",
    "ibridazioni": "ibridazione",
    "ibride": "ibrido",
    "ibriderai": "ibridare",
    "ibrideran": "ibridare",
    "ibrideranno": "ibridare",
    "ibriderebbe": "ibridare",
    "ibriderebber": "ibridare",
    "ibriderebbero": "ibridare",
    "ibriderei": "ibridare",
    "ibrideremmo": "ibridare",
    "ibrideremo": "ibridare",
    "ibridereste": "ibridare",
    "ibrideresti": "ibridare",
    "ibriderete": "ibridare",
    "ibriderà": "ibridare",
    "ibriderò": "ibridare",
    "ibridi": "ibrido",
    "ibridiamo": "ibridare",
    "ibridiate": "ibridare",
    "ibridin": "ibridare",
    "ibridino": "ibridare",
    "ibrido": "ibridare",
    "ibridò": "ibridare",
    "icone": "icona",
    "iconica": "iconico",
    "iconiche": "iconico",
    "iconici": "iconico",
    "iconizza": "iconizzare",
    "iconizzai": "iconizzare",
    "iconizzammo": "iconizzare",
    "iconizzan": "iconizzare",
    "iconizzando": "iconizzare",
    "iconizzano": "iconizzare",
    "iconizzante": "iconizzare",
    "iconizzanti": "iconizzare",
    "iconizzar": "iconizzare",
    "iconizzaron": "iconizzare",
    "iconizzarono": "iconizzare",
    "iconizzasse": "iconizzare",
    "iconizzasser": "iconizzare",
    "iconizzassero": "iconizzare",
    "iconizzassi": "iconizzare",
    "iconizzassimo": "iconizzare",
    "iconizzaste": "iconizzare",
    "iconizzasti": "iconizzare",
    "iconizzata": "iconizzare",
    "iconizzate": "iconizzare",
    "iconizzati": "iconizzare",
    "iconizzato": "iconizzare",
    "iconizzava": "iconizzare",
    "iconizzavamo": "iconizzare",
    "iconizzavan": "iconizzare",
    "iconizzavano": "iconizzare",
    "iconizzavate": "iconizzare",
    "iconizzavi": "iconizzare",
    "iconizzavo": "iconizzare",
    "iconizzerai": "iconizzare",
    "iconizzeran": "iconizzare",
    "iconizzeranno": "iconizzare",
    "iconizzerebbe": "iconizzare",
    "iconizzerebber": "iconizzare",
    "iconizzerebbero": "iconizzare",
    "iconizzerei": "iconizzare",
    "iconizzeremmo": "iconizzare",
    "iconizzeremo": "iconizzare",
    "iconizzereste": "iconizzare",
    "iconizzeresti": "iconizzare",
    "iconizzerete": "iconizzare",
    "iconizzerà": "iconizzare",
    "iconizzerò": "iconizzare",
    "iconizzi": "iconizzare",
    "iconizziamo": "iconizzare",
    "iconizziate": "iconizzare",
    "iconizzin": "iconizzare",
    "iconizzino": "iconizzare",
    "iconizzo": "iconizzare",
    "iconizzò": "iconizzare",
    "iconoclasta": "iconoclasto",
    "iconoclaste": "iconoclasto",
    "iconoclasti": "iconoclasto",
    "iconografica": "iconografico",
    "iconografiche": "iconografico",
    "iconografici": "iconografico",
    "iconografie": "iconografia",
    "idea": "ideare",
    "ideai": "ideare",
    "ideali": "ideale",
    "idealismi": "idealismo",
    "idealiste": "idealista",
    "idealisti": "idealista",
    "idealistica": "idealistico",
    "idealistiche": "idealistico",
    "idealistici": "idealistico",
    "idealizza": "idealizzare",
    "idealizzai": "idealizzare",
    "idealizzammo": "idealizzare",
    "idealizzan": "idealizzare",
    "idealizzando": "idealizzare",
    "idealizzano": "idealizzare",
    "idealizzante": "idealizzare",
    "idealizzanti": "idealizzare",
    "idealizzar": "idealizzare",
    "idealizzaron": "idealizzare",
    "idealizzarono": "idealizzare",
    "idealizzasse": "idealizzare",
    "idealizzasser": "idealizzare",
    "idealizzassero": "idealizzare",
    "idealizzassi": "idealizzare",
    "idealizzassimo": "idealizzare",
    "idealizzaste": "idealizzare",
    "idealizzasti": "idealizzare",
    "idealizzata": "idealizzare",
    "idealizzate": "idealizzare",
    "idealizzati": "idealizzare",
    "idealizzato": "idealizzare",
    "idealizzava": "idealizzare",
    "idealizzavamo": "idealizzare",
    "idealizzavan": "idealizzare",
    "idealizzavano": "idealizzare",
    "idealizzavate": "idealizzare",
    "idealizzavi": "idealizzare",
    "idealizzavo": "idealizzare",
    "idealizzazioni": "idealizzazione",
    "idealizzerai": "idealizzare",
    "idealizzeran": "idealizzare",
    "idealizzeranno": "idealizzare",
    "idealizzerebbe": "idealizzare",
    "idealizzerebber": "idealizzare",
    "idealizzerebbero": "idealizzare",
    "idealizzerei": "idealizzare",
    "idealizzeremmo": "idealizzare",
    "idealizzeremo": "idealizzare",
    "idealizzereste": "idealizzare",
    "idealizzeresti": "idealizzare",
    "idealizzerete": "idealizzare",
    "idealizzerà": "idealizzare",
    "idealizzerò": "idealizzare",
    "idealizzi": "idealizzare",
    "idealizziamo": "idealizzare",
    "idealizziate": "idealizzare",
    "idealizzin": "idealizzare",
    "idealizzino": "idealizzare",
    "idealizzo": "idealizzare",
    "idealizzò": "idealizzare",
    "ideammo": "ideare",
    "idean": "ideare",
    "ideando": "ideare",
    "ideano": "ideare",
    "ideante": "ideare",
    "ideanti": "ideare",
    "idear": "ideare",
    "idearon": "ideare",
    "idearono": "ideare",
    "ideasse": "ideare",
    "ideasser": "ideare",
    "ideassero": "ideare",
    "ideassi": "ideare",
    "ideassimo": "ideare",
    "ideaste": "ideare",
    "ideasti": "ideare",
    "ideata": "ideare",
    "ideate": "ideare",
    "ideati": "ideare",
    "ideato": "ideare",
    "ideatori": "ideatore",
    "ideava": "ideare",
    "ideavamo": "ideare",
    "ideavan": "ideare",
    "ideavano": "ideare",
    "ideavate": "ideare",
    "ideavi": "ideare",
    "ideavo": "ideare",
    "ideazioni": "ideazione",
    "idee": "idea",
    "ideerai": "ideare",
    "ideeran": "ideare",
    "ideeranno": "ideare",
    "ideerebbe": "ideare",
    "ideerebber": "ideare",
    "ideerebbero": "ideare",
    "ideerei": "ideare",
    "ideeremmo": "ideare",
    "ideeremo": "ideare",
    "ideereste": "ideare",
    "ideeresti": "ideare",
    "ideerete": "ideare",
    "ideerà": "ideare",
    "ideerò": "ideare",
    "idei": "ideare",
    "ideiamo": "ideare",
    "ideiate": "ideare",
    "idein": "ideare",
    "ideino": "ideare",
    "identica": "identico",
    "identiche": "identico",
    "identici": "identico",
    "identifica": "identificare",
    "identificabili": "identificabile",
    "identificai": "identificare",
    "identificammo": "identificare",
    "identifican": "identificare",
    "identificando": "identificare",
    "identificano": "identificare",
    "identificante": "identificare",
    "identificanti": "identificare",
    "identificar": "identificare",
    "identificaron": "identificare",
    "identificarono": "identificare",
    "identificasse": "identificare",
    "identificasser": "identificare",
    "identificassero": "identificare",
    "identificassi": "identificare",
    "identificassimo": "identificare",
    "identificaste": "identificare",
    "identificasti": "identificare",
    "identificata": "identificare",
    "identificate": "identificare",
    "identificati": "identificare",
    "identificato": "identificare",
    "identificava": "identificare",
    "identificavamo": "identificare",
    "identificavan": "identificare",
    "identificavano": "identificare",
    "identificavate": "identificare",
    "identificavi": "identificare",
    "identificavo": "identificare",
    "identificazioni": "identificazione",
    "identificherai": "identificare",
    "identificheran": "identificare",
    "identificheranno": "identificare",
    "identificherebbe": "identificare",
    "identificherebber": "identificare",
    "identificherebbero": "identificare",
    "identificherei": "identificare",
    "identificheremmo": "identificare",
    "identificheremo": "identificare",
    "identifichereste": "identificare",
    "identificheresti": "identificare",
    "identificherete": "identificare",
    "identificherà": "identificare",
    "identificherò": "identificare",
    "identifichi": "identificare",
    "identifichiamo": "identificare",
    "identifichiate": "identificare",
    "identifichin": "identificare",
    "identifichino": "identificare",
    "identifico": "identificare",
    "identificò": "identificare",
    "ideo": "ideare",
    "ideogrammi": "ideogramma",
    "ideologi": "ideologo",
    "ideologica": "ideologico",
    "ideologiche": "ideologico",
    "ideologici": "ideologico",
    "ideologie": "ideologia",
    "ideologismi": "ideologismo",
    "ideuzze": "ideuzza",
    "ideò": "ideare",
    "idilli": "idillio",
    "idilliaca": "idilliaco",
    "idilliache": "idilliaco",
    "idilliaci": "idilliaco",
    "idillica": "idillico",
    "idilliche": "idillico",
    "idillici": "idillico",
    "idiomi": "idioma",
    "idiosincrasie": "idiosincrasia",
    "idiote": "idiota",
    "idioti": "idiota",
    "idiozie": "idiozia",
    "idolatrie": "idolatria",
    "idoleggerai": "idoleggiare",
    "idoleggeran": "idoleggiare",
    "idoleggeranno": "idoleggiare",
    "idoleggerebbe": "idoleggiare",
    "idoleggerebber": "idoleggiare",
    "idoleggerebbero": "idoleggiare",
    "idoleggerei": "idoleggiare",
    "idoleggeremmo": "idoleggiare",
    "idoleggeremo": "idoleggiare",
    "idoleggereste": "idoleggiare",
    "idoleggeresti": "idoleggiare",
    "idoleggerete": "idoleggiare",
    "idoleggerà": "idoleggiare",
    "idoleggerò": "idoleggiare",
    "idoleggi": "idoleggiare",
    "idoleggia": "idoleggiare",
    "idoleggiai": "idoleggiare",
    "idoleggiammo": "idoleggiare",
    "idoleggiamo": "idoleggiare",
    "idoleggian": "idoleggiare",
    "idoleggiando": "idoleggiare",
    "idoleggiano": "idoleggiare",
    "idoleggiante": "idoleggiare",
    "idoleggianti": "idoleggiare",
    "idoleggiar": "idoleggiare",
    "idoleggiaron": "idoleggiare",
    "idoleggiarono": "idoleggiare",
    "idoleggiasse": "idoleggiare",
    "idoleggiasser": "idoleggiare",
    "idoleggiassero": "idoleggiare",
    "idoleggiassi": "idoleggiare",
    "idoleggiassimo": "idoleggiare",
    "idoleggiaste": "idoleggiare",
    "idoleggiasti": "idoleggiare",
    "idoleggiata": "idoleggiare",
    "idoleggiate": "idoleggiare",
    "idoleggiati": "idoleggiare",
    "idoleggiato": "idoleggiare",
    "idoleggiava": "idoleggiare",
    "idoleggiavamo": "idoleggiare",
    "idoleggiavan": "idoleggiare",
    "idoleggiavano": "idoleggiare",
    "idoleggiavate": "idoleggiare",
    "idoleggiavi": "idoleggiare",
    "idoleggiavo": "idoleggiare",
    "idoleggin": "idoleggiare",
    "idoleggino": "idoleggiare",
    "idoleggio": "idoleggiare",
    "idoleggiò": "idoleggiare",
    "idoli": "idolo",
    "idonea": "idoneo",
    "idonee": "idoneo",
    "idonei": "idoneo",
    "idranti": "idrante",
    "idrata": "idratare",
    "idratai": "idratare",
    "idratammo": "idratare",
    "idratan": "idratare",
    "idratando": "idratare",
    "idratano": "idratare",
    "idratante": "idratare",
    "idratanti": "idratare",
    "idratar": "idratare",
    "idrataron": "idratare",
    "idratarono": "idratare",
    "idratasse": "idratare",
    "idratasser": "idratare",
    "idratassero": "idratare",
    "idratassi": "idratare",
    "idratassimo": "idratare",
    "idrataste": "idratare",
    "idratasti": "idratare",
    "idratata": "idratare",
    "idratate": "idratare",
    "idratati": "idratare",
    "idratato": "idratare",
    "idratava": "idratare",
    "idratavamo": "idratare",
    "idratavan": "idratare",
    "idratavano": "idratare",
    "idratavate": "idratare",
    "idratavi": "idratare",
    "idratavo": "idratare",
    "idraterai": "idratare",
    "idrateran": "idratare",
    "idrateranno": "idratare",
    "idraterebbe": "idratare",
    "idraterebber": "idratare",
    "idraterebbero": "idratare",
    "idraterei": "idratare",
    "idrateremmo": "idratare",
    "idrateremo": "idratare",
    "idratereste": "idratare",
    "idrateresti": "idratare",
    "idraterete": "idratare",
    "idraterà": "idratare",
    "idraterò": "idratare",
    "idrati": "idratare",
    "idratiamo": "idratare",
    "idratiate": "idratare",
    "idratin": "idratare",
    "idratino": "idratare",
    "idrato": "idratare",
    "idratò": "idratare",
    "idraulica": "idraulico",
    "idrauliche": "idraulico",
    "idraulici": "idraulico",
    "idrica": "idrico",
    "idriche": "idrico",
    "idrici": "idrico",
    "idroelettrica": "idroelettrico",
    "idroelettriche": "idroelettrico",
    "idroelettrici": "idroelettrico",
    "idrofila": "idrofilo",
    "idrofile": "idrofilo",
    "idrofili": "idrofilo",
    "idrogena": "idrogenare",
    "idrogenai": "idrogenare",
    "idrogenammo": "idrogenare",
    "idrogenan": "idrogenare",
    "idrogenando": "idrogenare",
    "idrogenano": "idrogenare",
    "idrogenante": "idrogenare",
    "idrogenanti": "idrogenare",
    "idrogenar": "idrogenare",
    "idrogenaron": "idrogenare",
    "idrogenarono": "idrogenare",
    "idrogenasse": "idrogenare",
    "idrogenasser": "idrogenare",
    "idrogenassero": "idrogenare",
    "idrogenassi": "idrogenare",
    "idrogenassimo": "idrogenare",
    "idrogenaste": "idrogenare",
    "idrogenasti": "idrogenare",
    "idrogenata": "idrogenare",
    "idrogenate": "idrogenare",
    "idrogenati": "idrogenare",
    "idrogenato": "idrogenare",
    "idrogenava": "idrogenare",
    "idrogenavamo": "idrogenare",
    "idrogenavan": "idrogenare",
    "idrogenavano": "idrogenare",
    "idrogenavate": "idrogenare",
    "idrogenavi": "idrogenare",
    "idrogenavo": "idrogenare",
    "idrogenerai": "idrogenare",
    "idrogeneran": "idrogenare",
    "idrogeneranno": "idrogenare",
    "idrogenerebbe": "idrogenare",
    "idrogenerebber": "idrogenare",
    "idrogenerebbero": "idrogenare",
    "idrogenerei": "idrogenare",
    "idrogeneremmo": "idrogenare",
    "idrogeneremo": "idrogenare",
    "idrogenereste": "idrogenare",
    "idrogeneresti": "idrogenare",
    "idrogenerete": "idrogenare",
    "idrogenerà": "idrogenare",
    "idrogenerò": "idrogenare",
    "idrogeni": "idrogenare",
    "idrogeniamo": "idrogenare",
    "idrogeniate": "idrogenare",
    "idrogenin": "idrogenare",
    "idrogenino": "idrogenare",
    "idrogeno": "idrogenare",
    "idrogenò": "idrogenare",
    "idrogeologica": "idrogeologico",
    "idrogeologiche": "idrogeologico",
    "idrogeologici": "idrogeologico",
    "idrografica": "idrografico",
    "idrografiche": "idrografico",
    "idrografici": "idrografico",
    "idrolizza": "idrolizzare",
    "idrolizzai": "idrolizzare",
    "idrolizzammo": "idrolizzare",
    "idrolizzan": "idrolizzare",
    "idrolizzando": "idrolizzare",
    "idrolizzano": "idrolizzare",
    "idrolizzante": "idrolizzare",
    "idrolizzanti": "idrolizzare",
    "idrolizzar": "idrolizzare",
    "idrolizzaron": "idrolizzare",
    "idrolizzarono": "idrolizzare",
    "idrolizzasse": "idrolizzare",
    "idrolizzasser": "idrolizzare",
    "idrolizzassero": "idrolizzare",
    "idrolizzassi": "idrolizzare",
    "idrolizzassimo": "idrolizzare",
    "idrolizzaste": "idrolizzare",
    "idrolizzasti": "idrolizzare",
    "idrolizzata": "idrolizzare",
    "idrolizzate": "idrolizzare",
    "idrolizzati": "idrolizzare",
    "idrolizzato": "idrolizzare",
    "idrolizzava": "idrolizzare",
    "idrolizzavamo": "idrolizzare",
    "idrolizzavan": "idrolizzare",
    "idrolizzavano": "idrolizzare",
    "idrolizzavate": "idrolizzare",
    "idrolizzavi": "idrolizzare",
    "idrolizzavo": "idrolizzare",
    "idrolizzerai": "idrolizzare",
    "idrolizzeran": "idrolizzare",
    "idrolizzeranno": "idrolizzare",
    "idrolizzerebbe": "idrolizzare",
    "idrolizzerebber": "idrolizzare",
    "idrolizzerebbero": "idrolizzare",
    "idrolizzerei": "idrolizzare",
    "idrolizzeremmo": "idrolizzare",
    "idrolizzeremo": "idrolizzare",
    "idrolizzereste": "idrolizzare",
    "idrolizzeresti": "idrolizzare",
    "idrolizzerete": "idrolizzare",
    "idrolizzerà": "idrolizzare",
    "idrolizzerò": "idrolizzare",
    "idrolizzi": "idrolizzare",
    "idrolizziamo": "idrolizzare",
    "idrolizziate": "idrolizzare",
    "idrolizzin": "idrolizzare",
    "idrolizzino": "idrolizzare",
    "idrolizzo": "idrolizzare",
    "idrolizzò": "idrolizzare",
    "idromassaggi": "idromassaggio",
    "idrometrica": "idrometrico",
    "idrometriche": "idrometrico",
    "idrometrici": "idrometrico",
    "idrotermali": "idrotermale",
    "idrovolanti": "idrovolante",
    "idrovora": "idrovoro",
    "idrovore": "idrovoro",
    "idrovori": "idrovoro",
    "iellata": "iellato",
    "iellate": "iellato",
    "iellati": "iellato",
    "ielle": "iella",
    "iene": "iena",
    "ieratica": "ieratico",
    "ieratiche": "ieratico",
    "ieratici": "ieratico",
    "iettatori": "iettatore",
    "igieni": "igiene",
    "igienica": "igienico",
    "igieniche": "igienico",
    "igienici": "igienico",
    "igienisti": "igienista",
    "ignara": "ignaro",
    "ignare": "ignaro",
    "ignari": "ignaro",
    "ignava": "ignavo",
    "ignave": "ignavo",
    "ignavi": "ignavo",
    "ignifuga": "ignifugo",
    "ignifughe": "ignifugo",
    "ignifughi": "ignifugo",
    "ignobili": "ignobile",
    "ignominie": "ignominia",
    "ignora": "ignorare",
    "ignorai": "ignorare",
    "ignorammo": "ignorare",
    "ignoran": "ignorare",
    "ignorando": "ignorare",
    "ignorano": "ignorare",
    "ignorante": "ignorare",
    "ignoranti": "ignorare",
    "ignoranze": "ignoranza",
    "ignorar": "ignorare",
    "ignoraron": "ignorare",
    "ignorarono": "ignorare",
    "ignorasse": "ignorare",
    "ignorasser": "ignorare",
    "ignorassero": "ignorare",
    "ignorassi": "ignorare",
    "ignorassimo": "ignorare",
    "ignoraste": "ignorare",
    "ignorasti": "ignorare",
    "ignorata": "ignorare",
    "ignorate": "ignorare",
    "ignorati": "ignorare",
    "ignorato": "ignorare",
    "ignorava": "ignorare",
    "ignoravamo": "ignorare",
    "ignoravan": "ignorare",
    "ignoravano": "ignorare",
    "ignoravate": "ignorare",
    "ignoravi": "ignorare",
    "ignoravo": "ignorare",
    "ignorerai": "ignorare",
    "ignoreran": "ignorare",
    "ignoreranno": "ignorare",
    "ignorerebbe": "ignorare",
    "ignorerebber": "ignorare",
    "ignorerebbero": "ignorare",
    "ignorerei": "ignorare",
    "ignoreremmo": "ignorare",
    "ignoreremo": "ignorare",
    "ignorereste": "ignorare",
    "ignoreresti": "ignorare",
    "ignorerete": "ignorare",
    "ignorerà": "ignorare",
    "ignorerò": "ignorare",
    "ignori": "ignorare",
    "ignoriamo": "ignorare",
    "ignoriate": "ignorare",
    "ignorin": "ignorare",
    "ignorino": "ignorare",
    "ignoro": "ignorare",
    "ignorò": "ignorare",
    "ignota": "ignoto",
    "ignote": "ignoto",
    "ignoti": "ignoto",
    "ignuda": "ignudo",
    "ignude": "ignudo",
    "ignudi": "ignudo",
    "ilari": "ilare",
    "iliaca": "iliaco",
    "iliache": "iliaco",
    "iliaci": "iliaco",
    "illanguidendo": "illanguidire",
    "illanguidente": "illanguidire",
    "illanguidenti": "illanguidire",
    "illanguidiamo": "illanguidire",
    "illanguidiate": "illanguidire",
    "illanguidii": "illanguidire",
    "illanguidimmo": "illanguidire",
    "illanguidir": "illanguidire",
    "illanguidirai": "illanguidire",
    "illanguidiran": "illanguidire",
    "illanguidiranno": "illanguidire",
    "illanguidirebbe": "illanguidire",
    "illanguidirebber": "illanguidire",
    "illanguidirebbero": "illanguidire",
    "illanguidirei": "illanguidire",
    "illanguidiremmo": "illanguidire",
    "illanguidiremo": "illanguidire",
    "illanguidireste": "illanguidire",
    "illanguidiresti": "illanguidire",
    "illanguidirete": "illanguidire",
    "illanguidiron": "illanguidire",
    "illanguidirono": "illanguidire",
    "illanguidirà": "illanguidire",
    "illanguidirò": "illanguidire",
    "illanguidisca": "illanguidire",
    "illanguidiscan": "illanguidire",
    "illanguidiscano": "illanguidire",
    "illanguidisce": "illanguidire",
    "illanguidisci": "illanguidire",
    "illanguidisco": "illanguidire",
    "illanguidiscon": "illanguidire",
    "illanguidiscono": "illanguidire",
    "illanguidisse": "illanguidire",
    "illanguidisser": "illanguidire",
    "illanguidissero": "illanguidire",
    "illanguidissi": "illanguidire",
    "illanguidissimo": "illanguidire",
    "illanguidiste": "illanguidire",
    "illanguidisti": "illanguidire",
    "illanguidita": "illanguidire",
    "illanguidite": "illanguidire",
    "illanguiditi": "illanguidire",
    "illanguidito": "illanguidire",
    "illanguidiva": "illanguidire",
    "illanguidivamo": "illanguidire",
    "illanguidivan": "illanguidire",
    "illanguidivano": "illanguidire",
    "illanguidivate": "illanguidire",
    "illanguidivi": "illanguidire",
    "illanguidivo": "illanguidire",
    "illanguidì": "illanguidire",
    "illazioni": "illazione",
    "illecita": "illecito",
    "illecite": "illecito",
    "illeciti": "illecito",
    "illegali": "illegale",
    "illeggiadra": "illeggiadrire",
    "illeggiadran": "illeggiadrire",
    "illeggiadrano": "illeggiadrire",
    "illeggiadre": "illeggiadrire",
    "illeggiadrendo": "illeggiadrire",
    "illeggiadrente": "illeggiadrire",
    "illeggiadrenti": "illeggiadrire",
    "illeggiadri": "illeggiadrire",
    "illeggiadriamo": "illeggiadrire",
    "illeggiadriate": "illeggiadrire",
    "illeggiadrii": "illeggiadrire",
    "illeggiadrimmo": "illeggiadrire",
    "illeggiadrir": "illeggiadrire",
    "illeggiadrirai": "illeggiadrire",
    "illeggiadriran": "illeggiadrire",
    "illeggiadriranno": "illeggiadrire",
    "illeggiadrirebbe": "illeggiadrire",
    "illeggiadrirebber": "illeggiadrire",
    "illeggiadrirebbero": "illeggiadrire",
    "illeggiadrirei": "illeggiadrire",
    "illeggiadriremmo": "illeggiadrire",
    "illeggiadriremo": "illeggiadrire",
    "illeggiadrireste": "illeggiadrire",
    "illeggiadriresti": "illeggiadrire",
    "illeggiadrirete": "illeggiadrire",
    "illeggiadriron": "illeggiadrire",
    "illeggiadrirono": "illeggiadrire",
    "illeggiadrirà": "illeggiadrire",
    "illeggiadrirò": "illeggiadrire",
    "illeggiadrisse": "illeggiadrire",
    "illeggiadrisser": "illeggiadrire",
    "illeggiadrissero": "illeggiadrire",
    "illeggiadrissi": "illeggiadrire",
    "illeggiadrissimo": "illeggiadrire",
    "illeggiadriste": "illeggiadrire",
    "illeggiadristi": "illeggiadrire",
    "illeggiadrita": "illeggiadrire",
    "illeggiadrite": "illeggiadrire",
    "illeggiadriti": "illeggiadrire",
    "illeggiadrito": "illeggiadrire",
    "illeggiadriva": "illeggiadrire",
    "illeggiadrivamo": "illeggiadrire",
    "illeggiadrivan": "illeggiadrire",
    "illeggiadrivano": "illeggiadrire",
    "illeggiadrivate": "illeggiadrire",
    "illeggiadrivi": "illeggiadrire",
    "illeggiadrivo": "illeggiadrire",
    "illeggiadro": "illeggiadrire",
    "illeggiadron": "illeggiadrire",
    "illeggiadrono": "illeggiadrire",
    "illeggiadrì": "illeggiadrire",
    "illeggibili": "illeggibile",
    "illegittima": "illegittimo",
    "illegittime": "illegittimo",
    "illegittimi": "illegittimo",
    "illesa": "illeso",
    "illese": "illeso",
    "illesi": "illeso",
    "illetterata": "illetterato",
    "illetterate": "illetterato",
    "illetterati": "illetterato",
    "illibata": "illibato",
    "illibate": "illibato",
    "illibati": "illibato",
    "illiberali": "illiberale",
    "illimitata": "illimitato",
    "illimitate": "illimitato",
    "illimitati": "illimitato",
    "illividendo": "illividire",
    "illividente": "illividire",
    "illividenti": "illividire",
    "illividiamo": "illividire",
    "illividiate": "illividire",
    "illividii": "illividire",
    "illividimmo": "illividire",
    "illividir": "illividire",
    "illividirai": "illividire",
    "illividiran": "illividire",
    "illividiranno": "illividire",
    "illividirebbe": "illividire",
    "illividirebber": "illividire",
    "illividirebbero": "illividire",
    "illividirei": "illividire",
    "illividiremmo": "illividire",
    "illividiremo": "illividire",
    "illividireste": "illividire",
    "illividiresti": "illividire",
    "illividirete": "illividire",
    "illividiron": "illividire",
    "illividirono": "illividire",
    "illividirà": "illividire",
    "illividirò": "illividire",
    "illividisca": "illividire",
    "illividiscan": "illividire",
    "illividiscano": "illividire",
    "illividisce": "illividire",
    "illividisci": "illividire",
    "illividisco": "illividire",
    "illividiscon": "illividire",
    "illividiscono": "illividire",
    "illividisse": "illividire",
    "illividisser": "illividire",
    "illividissero": "illividire",
    "illividissi": "illividire",
    "illividissimo": "illividire",
    "illividiste": "illividire",
    "illividisti": "illividire",
    "illividita": "illividire",
    "illividite": "illividire",
    "illividiti": "illividire",
    "illividito": "illividire",
    "illividiva": "illividire",
    "illividivamo": "illividire",
    "illividivan": "illividire",
    "illividivano": "illividire",
    "illividivate": "illividire",
    "illividivi": "illividire",
    "illividivo": "illividire",
    "illividì": "illividire",
    "illogica": "illogico",
    "illogiche": "illogico",
    "illogici": "illogico",
    "illuda": "illudere",
    "illudan": "illudere",
    "illudano": "illudere",
    "illude": "illudere",
    "illudemmo": "illudere",
    "illudendo": "illudere",
    "illudente": "illudere",
    "illudenti": "illudere",
    "illuder": "illudere",
    "illuderai": "illudere",
    "illuderan": "illudere",
    "illuderanno": "illudere",
    "illuderebbe": "illudere",
    "illuderebber": "illudere",
    "illuderebbero": "illudere",
    "illuderei": "illudere",
    "illuderemmo": "illudere",
    "illuderemo": "illudere",
    "illudereste": "illudere",
    "illuderesti": "illudere",
    "illuderete": "illudere",
    "illuderà": "illudere",
    "illuderò": "illudere",
    "illudesse": "illudere",
    "illudesser": "illudere",
    "illudessero": "illudere",
    "illudessi": "illudere",
    "illudessimo": "illudere",
    "illudeste": "illudere",
    "illudesti": "illudere",
    "illudete": "illudere",
    "illudeva": "illudere",
    "illudevamo": "illudere",
    "illudevan": "illudere",
    "illudevano": "illudere",
    "illudevate": "illudere",
    "illudevi": "illudere",
    "illudevo": "illudere",
    "illudi": "illudere",
    "illudiamo": "illudere",
    "illudiate": "illudere",
    "illudo": "illudere",
    "illudon": "illudere",
    "illudono": "illudere",
    "illumina": "illuminare",
    "illuminai": "illuminare",
    "illuminammo": "illuminare",
    "illuminan": "illuminare",
    "illuminando": "illuminare",
    "illuminano": "illuminare",
    "illuminante": "illuminare",
    "illuminanti": "illuminare",
    "illuminar": "illuminare",
    "illuminaron": "illuminare",
    "illuminarono": "illuminare",
    "illuminasse": "illuminare",
    "illuminasser": "illuminare",
    "illuminassero": "illuminare",
    "illuminassi": "illuminare",
    "illuminassimo": "illuminare",
    "illuminaste": "illuminare",
    "illuminasti": "illuminare",
    "illuminata": "illuminato",
    "illuminate": "illuminato",
    "illuminati": "illuminato",
    "illuminato": "illuminare",
    "illuminava": "illuminare",
    "illuminavamo": "illuminare",
    "illuminavan": "illuminare",
    "illuminavano": "illuminare",
    "illuminavate": "illuminare",
    "illuminavi": "illuminare",
    "illuminavo": "illuminare",
    "illuminazioni": "illuminazione",
    "illuminerai": "illuminare",
    "illumineran": "illuminare",
    "illumineranno": "illuminare",
    "illuminerebbe": "illuminare",
    "illuminerebber": "illuminare",
    "illuminerebbero": "illuminare",
    "illuminerei": "illuminare",
    "illumineremmo": "illuminare",
    "illumineremo": "illuminare",
    "illuminereste": "illuminare",
    "illumineresti": "illuminare",
    "illuminerete": "illuminare",
    "illuminerà": "illuminare",
    "illuminerò": "illuminare",
    "illumini": "illuminare",
    "illuminiamo": "illuminare",
    "illuminiate": "illuminare",
    "illuminin": "illuminare",
    "illuminino": "illuminare",
    "illuminismi": "illuminismo",
    "illuministe": "illuminista",
    "illuministi": "illuminista",
    "illuministica": "illuministico",
    "illuministiche": "illuministico",
    "illuministici": "illuministico",
    "illumino": "illuminare",
    "illuminò": "illuminare",
    "illusa": "illuso",
    "illuse": "illuso",
    "illuser": "illudere",
    "illusero": "illudere",
    "illusi": "illuso",
    "illusioni": "illusione",
    "illusionismi": "illusionismo",
    "illusionisti": "illusionista",
    "illuso": "illudere",
    "illusori": "illusorio",
    "illusoria": "illusorio",
    "illusorie": "illusorio",
    "illustra": "illustrare",
    "illustrai": "illustrare",
    "illustrammo": "illustrare",
    "illustran": "illustrare",
    "illustrando": "illustrare",
    "illustrano": "illustrare",
    "illustrante": "illustrare",
    "illustranti": "illustrare",
    "illustrar": "illustrare",
    "illustraron": "illustrare",
    "illustrarono": "illustrare",
    "illustrasse": "illustrare",
    "illustrasser": "illustrare",
    "illustrassero": "illustrare",
    "illustrassi": "illustrare",
    "illustrassimo": "illustrare",
    "illustraste": "illustrare",
    "illustrasti": "illustrare",
    "illustrata": "illustrato",
    "illustrate": "illustrato",
    "illustrati": "illustrato",
    "illustrativa": "illustrativo",
    "illustrative": "illustrativo",
    "illustrativi": "illustrativo",
    "illustrato": "illustrare",
    "illustratori": "illustratore",
    "illustrava": "illustrare",
    "illustravamo": "illustrare",
    "illustravan": "illustrare",
    "illustravano": "illustrare",
    "illustravate": "illustrare",
    "illustravi": "illustrare",
    "illustravo": "illustrare",
    "illustrazioni": "illustrazione",
    "illustrerai": "illustrare",
    "illustreran": "illustrare",
    "illustreranno": "illustrare",
    "illustrerebbe": "illustrare",
    "illustrerebber": "illustrare",
    "illustrerebbero": "illustrare",
    "illustrerei": "illustrare",
    "illustreremmo": "illustrare",
    "illustreremo": "illustrare",
    "illustrereste": "illustrare",
    "illustreresti": "illustrare",
    "illustrerete": "illustrare",
    "illustrerà": "illustrare",
    "illustrerò": "illustrare",
    "illustri": "illustre",
    "illustriamo": "illustrare",
    "illustriate": "illustrare",
    "illustrin": "illustrare",
    "illustrino": "illustrare",
    "illustro": "illustrare",
    "illustrò": "illustrare",
    "ima": "imo",
    "imbacucca": "imbacuccare",
    "imbacuccai": "imbacuccare",
    "imbacuccammo": "imbacuccare",
    "imbacuccan": "imbacuccare",
    "imbacuccando": "imbacuccare",
    "imbacuccano": "imbacuccare",
    "imbacuccante": "imbacuccare",
    "imbacuccanti": "imbacuccare",
    "imbacuccar": "imbacuccare",
    "imbacuccaron": "imbacuccare",
    "imbacuccarono": "imbacuccare",
    "imbacuccasse": "imbacuccare",
    "imbacuccasser": "imbacuccare",
    "imbacuccassero": "imbacuccare",
    "imbacuccassi": "imbacuccare",
    "imbacuccassimo": "imbacuccare",
    "imbacuccaste": "imbacuccare",
    "imbacuccasti": "imbacuccare",
    "imbacuccata": "imbacuccare",
    "imbacuccate": "imbacuccare",
    "imbacuccati": "imbacuccare",
    "imbacuccato": "imbacuccare",
    "imbacuccava": "imbacuccare",
    "imbacuccavamo": "imbacuccare",
    "imbacuccavan": "imbacuccare",
    "imbacuccavano": "imbacuccare",
    "imbacuccavate": "imbacuccare",
    "imbacuccavi": "imbacuccare",
    "imbacuccavo": "imbacuccare",
    "imbacuccherai": "imbacuccare",
    "imbacuccheran": "imbacuccare",
    "imbacuccheranno": "imbacuccare",
    "imbacuccherebbe": "imbacuccare",
    "imbacuccherebber": "imbacuccare",
    "imbacuccherebbero": "imbacuccare",
    "imbacuccherei": "imbacuccare",
    "imbacuccheremmo": "imbacuccare",
    "imbacuccheremo": "imbacuccare",
    "imbacucchereste": "imbacuccare",
    "imbacuccheresti": "imbacuccare",
    "imbacuccherete": "imbacuccare",
    "imbacuccherà": "imbacuccare",
    "imbacuccherò": "imbacuccare",
    "imbacucchi": "imbacuccare",
    "imbacucchiamo": "imbacuccare",
    "imbacucchiate": "imbacuccare",
    "imbacucchin": "imbacuccare",
    "imbacucchino": "imbacuccare",
    "imbacucco": "imbacuccare",
    "imbacuccò": "imbacuccare",
    "imballa": "imballare",
    "imballaggi": "imballaggio",
    "imballai": "imballare",
    "imballammo": "imballare",
    "imballan": "imballare",
    "imballando": "imballare",
    "imballano": "imballare",
    "imballante": "imballare",
    "imballanti": "imballare",
    "imballar": "imballare",
    "imballaron": "imballare",
    "imballarono": "imballare",
    "imballasse": "imballare",
    "imballasser": "imballare",
    "imballassero": "imballare",
    "imballassi": "imballare",
    "imballassimo": "imballare",
    "imballaste": "imballare",
    "imballasti": "imballare",
    "imballata": "imballato",
    "imballate": "imballato",
    "imballati": "imballato",
    "imballato": "imballare",
    "imballava": "imballare",
    "imballavamo": "imballare",
    "imballavan": "imballare",
    "imballavano": "imballare",
    "imballavate": "imballare",
    "imballavi": "imballare",
    "imballavo": "imballare",
    "imballerai": "imballare",
    "imballeran": "imballare",
    "imballeranno": "imballare",
    "imballerebbe": "imballare",
    "imballerebber": "imballare",
    "imballerebbero": "imballare",
    "imballerei": "imballare",
    "imballeremmo": "imballare",
    "imballeremo": "imballare",
    "imballereste": "imballare",
    "imballeresti": "imballare",
    "imballerete": "imballare",
    "imballerà": "imballare",
    "imballerò": "imballare",
    "imballi": "imballare",
    "imballiamo": "imballare",
    "imballiate": "imballare",
    "imballin": "imballare",
    "imballino": "imballare",
    "imballo": "imballare",
    "imballò": "imballare",
    "imbalsama": "imbalsamare",
    "imbalsamai": "imbalsamare",
    "imbalsamammo": "imbalsamare",
    "imbalsaman": "imbalsamare",
    "imbalsamando": "imbalsamare",
    "imbalsamano": "imbalsamare",
    "imbalsamante": "imbalsamare",
    "imbalsamanti": "imbalsamare",
    "imbalsamar": "imbalsamare",
    "imbalsamaron": "imbalsamare",
    "imbalsamarono": "imbalsamare",
    "imbalsamasse": "imbalsamare",
    "imbalsamasser": "imbalsamare",
    "imbalsamassero": "imbalsamare",
    "imbalsamassi": "imbalsamare",
    "imbalsamassimo": "imbalsamare",
    "imbalsamaste": "imbalsamare",
    "imbalsamasti": "imbalsamare",
    "imbalsamata": "imbalsamare",
    "imbalsamate": "imbalsamare",
    "imbalsamati": "imbalsamare",
    "imbalsamato": "imbalsamare",
    "imbalsamava": "imbalsamare",
    "imbalsamavamo": "imbalsamare",
    "imbalsamavan": "imbalsamare",
    "imbalsamavano": "imbalsamare",
    "imbalsamavate": "imbalsamare",
    "imbalsamavi": "imbalsamare",
    "imbalsamavo": "imbalsamare",
    "imbalsamerai": "imbalsamare",
    "imbalsameran": "imbalsamare",
    "imbalsameranno": "imbalsamare",
    "imbalsamerebbe": "imbalsamare",
    "imbalsamerebber": "imbalsamare",
    "imbalsamerebbero": "imbalsamare",
    "imbalsamerei": "imbalsamare",
    "imbalsameremmo": "imbalsamare",
    "imbalsameremo": "imbalsamare",
    "imbalsamereste": "imbalsamare",
    "imbalsameresti": "imbalsamare",
    "imbalsamerete": "imbalsamare",
    "imbalsamerà": "imbalsamare",
    "imbalsamerò": "imbalsamare",
    "imbalsami": "imbalsamare",
    "imbalsamiamo": "imbalsamare",
    "imbalsamiate": "imbalsamare",
    "imbalsamin": "imbalsamare",
    "imbalsamino": "imbalsamare",
    "imbalsamo": "imbalsamare",
    "imbalsamò": "imbalsamare",
    "imbambolata": "imbambolato",
    "imbambolate": "imbambolato",
    "imbambolati": "imbambolato",
    "imbandendo": "imbandire",
    "imbandente": "imbandire",
    "imbandenti": "imbandire",
    "imbandiamo": "imbandire",
    "imbandiate": "imbandire",
    "imbandiera": "imbandierare",
    "imbandierai": "imbandierare",
    "imbandierammo": "imbandierare",
    "imbandieran": "imbandierare",
    "imbandierando": "imbandierare",
    "imbandierano": "imbandierare",
    "imbandierante": "imbandierare",
    "imbandieranti": "imbandierare",
    "imbandierar": "imbandierare",
    "imbandieraron": "imbandierare",
    "imbandierarono": "imbandierare",
    "imbandierasse": "imbandierare",
    "imbandierasser": "imbandierare",
    "imbandierassero": "imbandierare",
    "imbandierassi": "imbandierare",
    "imbandierassimo": "imbandierare",
    "imbandieraste": "imbandierare",
    "imbandierasti": "imbandierare",
    "imbandierata": "imbandierare",
    "imbandierate": "imbandierare",
    "imbandierati": "imbandierare",
    "imbandierato": "imbandierare",
    "imbandierava": "imbandierare",
    "imbandieravamo": "imbandierare",
    "imbandieravan": "imbandierare",
    "imbandieravano": "imbandierare",
    "imbandieravate": "imbandierare",
    "imbandieravi": "imbandierare",
    "imbandieravo": "imbandierare",
    "imbandiererai": "imbandierare",
    "imbandiereran": "imbandierare",
    "imbandiereranno": "imbandierare",
    "imbandiererebbe": "imbandierare",
    "imbandiererebber": "imbandierare",
    "imbandiererebbero": "imbandierare",
    "imbandiererei": "imbandierare",
    "imbandiereremmo": "imbandierare",
    "imbandiereremo": "imbandierare",
    "imbandierereste": "imbandierare",
    "imbandiereresti": "imbandierare",
    "imbandiererete": "imbandierare",
    "imbandiererà": "imbandierare",
    "imbandiererò": "imbandierare",
    "imbandieri": "imbandierare",
    "imbandieriamo": "imbandierare",
    "imbandieriate": "imbandierare",
    "imbandierin": "imbandierare",
    "imbandierino": "imbandierare",
    "imbandiero": "imbandierare",
    "imbandierò": "imbandierare",
    "imbandii": "imbandire",
    "imbandimmo": "imbandire",
    "imbandir": "imbandire",
    "imbandirai": "imbandire",
    "imbandiran": "imbandire",
    "imbandiranno": "imbandire",
    "imbandirebbe": "imbandire",
    "imbandirebber": "imbandire",
    "imbandirebbero": "imbandire",
    "imbandirei": "imbandire",
    "imbandiremmo": "imbandire",
    "imbandiremo": "imbandire",
    "imbandireste": "imbandire",
    "imbandiresti": "imbandire",
    "imbandirete": "imbandire",
    "imbandiron": "imbandire",
    "imbandirono": "imbandire",
    "imbandirà": "imbandire",
    "imbandirò": "imbandire",
    "imbandisca": "imbandire",
    "imbandiscan": "imbandire",
    "imbandiscano": "imbandire",
    "imbandisce": "imbandire",
    "imbandisci": "imbandire",
    "imbandisco": "imbandire",
    "imbandiscon": "imbandire",
    "imbandiscono": "imbandire",
    "imbandisse": "imbandire",
    "imbandisser": "imbandire",
    "imbandissero": "imbandire",
    "imbandissi": "imbandire",
    "imbandissimo": "imbandire",
    "imbandiste": "imbandire",
    "imbandisti": "imbandire",
    "imbandita": "imbandire",
    "imbandite": "imbandire",
    "imbanditi": "imbandire",
    "imbandito": "imbandire",
    "imbandiva": "imbandire",
    "imbandivamo": "imbandire",
    "imbandivan": "imbandire",
    "imbandivano": "imbandire",
    "imbandivate": "imbandire",
    "imbandivi": "imbandire",
    "imbandivo": "imbandire",
    "imbandì": "imbandire",
    "imbarazza": "imbarazzare",
    "imbarazzai": "imbarazzare",
    "imbarazzammo": "imbarazzare",
    "imbarazzan": "imbarazzare",
    "imbarazzando": "imbarazzare",
    "imbarazzano": "imbarazzare",
    "imbarazzante": "imbarazzare",
    "imbarazzanti": "imbarazzare",
    "imbarazzar": "imbarazzare",
    "imbarazzaron": "imbarazzare",
    "imbarazzarono": "imbarazzare",
    "imbarazzasse": "imbarazzare",
    "imbarazzasser": "imbarazzare",
    "imbarazzassero": "imbarazzare",
    "imbarazzassi": "imbarazzare",
    "imbarazzassimo": "imbarazzare",
    "imbarazzaste": "imbarazzare",
    "imbarazzasti": "imbarazzare",
    "imbarazzata": "imbarazzato",
    "imbarazzate": "imbarazzato",
    "imbarazzati": "imbarazzato",
    "imbarazzato": "imbarazzare",
    "imbarazzava": "imbarazzare",
    "imbarazzavamo": "imbarazzare",
    "imbarazzavan": "imbarazzare",
    "imbarazzavano": "imbarazzare",
    "imbarazzavate": "imbarazzare",
    "imbarazzavi": "imbarazzare",
    "imbarazzavo": "imbarazzare",
    "imbarazzerai": "imbarazzare",
    "imbarazzeran": "imbarazzare",
    "imbarazzeranno": "imbarazzare",
    "imbarazzerebbe": "imbarazzare",
    "imbarazzerebber": "imbarazzare",
    "imbarazzerebbero": "imbarazzare",
    "imbarazzerei": "imbarazzare",
    "imbarazzeremmo": "imbarazzare",
    "imbarazzeremo": "imbarazzare",
    "imbarazzereste": "imbarazzare",
    "imbarazzeresti": "imbarazzare",
    "imbarazzerete": "imbarazzare",
    "imbarazzerà": "imbarazzare",
    "imbarazzerò": "imbarazzare",
    "imbarazzi": "imbarazzo",
    "imbarazziamo": "imbarazzare",
    "imbarazziate": "imbarazzare",
    "imbarazzin": "imbarazzare",
    "imbarazzino": "imbarazzare",
    "imbarazzo": "imbarazzare",
    "imbarazzò": "imbarazzare",
    "imbarbara": "imbarbarire",
    "imbarbaran": "imbarbarire",
    "imbarbarano": "imbarbarire",
    "imbarbare": "imbarbarire",
    "imbarbarendo": "imbarbarire",
    "imbarbarente": "imbarbarire",
    "imbarbarenti": "imbarbarire",
    "imbarbari": "imbarbarire",
    "imbarbariamo": "imbarbarire",
    "imbarbariate": "imbarbarire",
    "imbarbarii": "imbarbarire",
    "imbarbarimenti": "imbarbarimento",
    "imbarbarimmo": "imbarbarire",
    "imbarbarir": "imbarbarire",
    "imbarbarirai": "imbarbarire",
    "imbarbariran": "imbarbarire",
    "imbarbariranno": "imbarbarire",
    "imbarbarirebbe": "imbarbarire",
    "imbarbarirebber": "imbarbarire",
    "imbarbarirebbero": "imbarbarire",
    "imbarbarirei": "imbarbarire",
    "imbarbariremmo": "imbarbarire",
    "imbarbariremo": "imbarbarire",
    "imbarbarireste": "imbarbarire",
    "imbarbariresti": "imbarbarire",
    "imbarbarirete": "imbarbarire",
    "imbarbariron": "imbarbarire",
    "imbarbarirono": "imbarbarire",
    "imbarbarirà": "imbarbarire",
    "imbarbarirò": "imbarbarire",
    "imbarbarisse": "imbarbarire",
    "imbarbarisser": "imbarbarire",
    "imbarbarissero": "imbarbarire",
    "imbarbarissi": "imbarbarire",
    "imbarbarissimo": "imbarbarire",
    "imbarbariste": "imbarbarire",
    "imbarbaristi": "imbarbarire",
    "imbarbarita": "imbarbarire",
    "imbarbarite": "imbarbarire",
    "imbarbariti": "imbarbarire",
    "imbarbarito": "imbarbarire",
    "imbarbariva": "imbarbarire",
    "imbarbarivamo": "imbarbarire",
    "imbarbarivan": "imbarbarire",
    "imbarbarivano": "imbarbarire",
    "imbarbarivate": "imbarbarire",
    "imbarbarivi": "imbarbarire",
    "imbarbarivo": "imbarbarire",
    "imbarbaro": "imbarbarire",
    "imbarbaron": "imbarbarire",
    "imbarbarono": "imbarbarire",
    "imbarbarì": "imbarbarire",
    "imbarca": "imbarcare",
    "imbarcaderi": "imbarcadero",
    "imbarcai": "imbarcare",
    "imbarcammo": "imbarcare",
    "imbarcan": "imbarcare",
    "imbarcando": "imbarcare",
    "imbarcano": "imbarcare",
    "imbarcante": "imbarcare",
    "imbarcanti": "imbarcare",
    "imbarcar": "imbarcare",
    "imbarcaron": "imbarcare",
    "imbarcarono": "imbarcare",
    "imbarcasse": "imbarcare",
    "imbarcasser": "imbarcare",
    "imbarcassero": "imbarcare",
    "imbarcassi": "imbarcare",
    "imbarcassimo": "imbarcare",
    "imbarcaste": "imbarcare",
    "imbarcasti": "imbarcare",
    "imbarcata": "imbarcare",
    "imbarcate": "imbarcare",
    "imbarcati": "imbarcare",
    "imbarcato": "imbarcare",
    "imbarcava": "imbarcare",
    "imbarcavamo": "imbarcare",
    "imbarcavan": "imbarcare",
    "imbarcavano": "imbarcare",
    "imbarcavate": "imbarcare",
    "imbarcavi": "imbarcare",
    "imbarcavo": "imbarcare",
    "imbarcazioni": "imbarcazione",
    "imbarcherai": "imbarcare",
    "imbarcheran": "imbarcare",
    "imbarcheranno": "imbarcare",
    "imbarcherebbe": "imbarcare",
    "imbarcherebber": "imbarcare",
    "imbarcherebbero": "imbarcare",
    "imbarcherei": "imbarcare",
    "imbarcheremmo": "imbarcare",
    "imbarcheremo": "imbarcare",
    "imbarchereste": "imbarcare",
    "imbarcheresti": "imbarcare",
    "imbarcherete": "imbarcare",
    "imbarcherà": "imbarcare",
    "imbarcherò": "imbarcare",
    "imbarchi": "imbarco",
    "imbarchiamo": "imbarcare",
    "imbarchiate": "imbarcare",
    "imbarchin": "imbarcare",
    "imbarchino": "imbarcare",
    "imbarco": "imbarcare",
    "imbarcò": "imbarcare",
    "imbastardendo": "imbastardire",
    "imbastardente": "imbastardire",
    "imbastardenti": "imbastardire",
    "imbastardiamo": "imbastardire",
    "imbastardiate": "imbastardire",
    "imbastardii": "imbastardire",
    "imbastardimmo": "imbastardire",
    "imbastardir": "imbastardire",
    "imbastardirai": "imbastardire",
    "imbastardiran": "imbastardire",
    "imbastardiranno": "imbastardire",
    "imbastardirebbe": "imbastardire",
    "imbastardirebber": "imbastardire",
    "imbastardirebbero": "imbastardire",
    "imbastardirei": "imbastardire",
    "imbastardiremmo": "imbastardire",
    "imbastardiremo": "imbastardire",
    "imbastardireste": "imbastardire",
    "imbastardiresti": "imbastardire",
    "imbastardirete": "imbastardire",
    "imbastardiron": "imbastardire",
    "imbastardirono": "imbastardire",
    "imbastardirà": "imbastardire",
    "imbastardirò": "imbastardire",
    "imbastardisca": "imbastardire",
    "imbastardiscan": "imbastardire",
    "imbastardiscano": "imbastardire",
    "imbastardisce": "imbastardire",
    "imbastardisci": "imbastardire",
    "imbastardisco": "imbastardire",
    "imbastardiscon": "imbastardire",
    "imbastardiscono": "imbastardire",
    "imbastardisse": "imbastardire",
    "imbastardisser": "imbastardire",
    "imbastardissero": "imbastardire",
    "imbastardissi": "imbastardire",
    "imbastardissimo": "imbastardire",
    "imbastardiste": "imbastardire",
    "imbastardisti": "imbastardire",
    "imbastardita": "imbastardire",
    "imbastardite": "imbastardire",
    "imbastarditi": "imbastardire",
    "imbastardito": "imbastardire",
    "imbastardiva": "imbastardire",
    "imbastardivamo": "imbastardire",
    "imbastardivan": "imbastardire",
    "imbastardivano": "imbastardire",
    "imbastardivate": "imbastardire",
    "imbastardivi": "imbastardire",
    "imbastardivo": "imbastardire",
    "imbastardì": "imbastardire",
    "imbastendo": "imbastire",
    "imbastente": "imbastire",
    "imbastenti": "imbastire",
    "imbastiamo": "imbastire",
    "imbastiate": "imbastire",
    "imbastii": "imbastire",
    "imbastimmo": "imbastire",
    "imbastir": "imbastire",
    "imbastirai": "imbastire",
    "imbastiran": "imbastire",
    "imbastiranno": "imbastire",
    "imbastirebbe": "imbastire",
    "imbastirebber": "imbastire",
    "imbastirebbero": "imbastire",
    "imbastirei": "imbastire",
    "imbastiremmo": "imbastire",
    "imbastiremo": "imbastire",
    "imbastireste": "imbastire",
    "imbastiresti": "imbastire",
    "imbastirete": "imbastire",
    "imbastiron": "imbastire",
    "imbastirono": "imbastire",
    "imbastirà": "imbastire",
    "imbastirò": "imbastire",
    "imbastisca": "imbastire",
    "imbastiscan": "imbastire",
    "imbastiscano": "imbastire",
    "imbastisce": "imbastire",
    "imbastisci": "imbastire",
    "imbastisco": "imbastire",
    "imbastiscon": "imbastire",
    "imbastiscono": "imbastire",
    "imbastisse": "imbastire",
    "imbastisser": "imbastire",
    "imbastissero": "imbastire",
    "imbastissi": "imbastire",
    "imbastissimo": "imbastire",
    "imbastiste": "imbastire",
    "imbastisti": "imbastire",
    "imbastita": "imbastire",
    "imbastite": "imbastire",
    "imbastiti": "imbastire",
    "imbastito": "imbastire",
    "imbastiva": "imbastire",
    "imbastivamo": "imbastire",
    "imbastivan": "imbastire",
    "imbastivano": "imbastire",
    "imbastivate": "imbastire",
    "imbastivi": "imbastire",
    "imbastivo": "imbastire",
    "imbastì": "imbastire",
    "imbatta": "imbattere",
    "imbattan": "imbattere",
    "imbattano": "imbattere",
    "imbatte": "imbattere",
    "imbattei": "imbattere",
    "imbattemmo": "imbattere",
    "imbattendo": "imbattere",
    "imbatter": "imbattere",
    "imbatterai": "imbattere",
    "imbatteran": "imbattere",
    "imbatteranno": "imbattere",
    "imbatterebbe": "imbattere",
    "imbatterebber": "imbattere",
    "imbatterebbero": "imbattere",
    "imbatterei": "imbattere",
    "imbatteremmo": "imbattere",
    "imbatteremo": "imbattere",
    "imbattereste": "imbattere",
    "imbatteresti": "imbattere",
    "imbatterete": "imbattere",
    "imbatteron": "imbattere",
    "imbatterono": "imbattere",
    "imbatterà": "imbattere",
    "imbatterò": "imbattere",
    "imbattesse": "imbattere",
    "imbattesser": "imbattere",
    "imbattessero": "imbattere",
    "imbattessi": "imbattere",
    "imbattessimo": "imbattere",
    "imbatteste": "imbattere",
    "imbattesti": "imbattere",
    "imbattete": "imbattere",
    "imbatteva": "imbattere",
    "imbattevamo": "imbattere",
    "imbattevan": "imbattere",
    "imbattevano": "imbattere",
    "imbattevate": "imbattere",
    "imbattevi": "imbattere",
    "imbattevo": "imbattere",
    "imbatti": "imbattere",
    "imbattiamo": "imbattere",
    "imbattiate": "imbattere",
    "imbattibili": "imbattibile",
    "imbatto": "imbattere",
    "imbatton": "imbattere",
    "imbattono": "imbattere",
    "imbattuta": "imbattuto",
    "imbattute": "imbattuto",
    "imbattuti": "imbattuto",
    "imbattuto": "imbattere",
    "imbattè": "imbattere",
    "imbavagli": "imbavagliare",
    "imbavaglia": "imbavagliare",
    "imbavagliai": "imbavagliare",
    "imbavagliammo": "imbavagliare",
    "imbavagliamo": "imbavagliare",
    "imbavaglian": "imbavagliare",
    "imbavagliando": "imbavagliare",
    "imbavagliano": "imbavagliare",
    "imbavagliante": "imbavagliare",
    "imbavaglianti": "imbavagliare",
    "imbavagliar": "imbavagliare",
    "imbavagliaron": "imbavagliare",
    "imbavagliarono": "imbavagliare",
    "imbavagliasse": "imbavagliare",
    "imbavagliasser": "imbavagliare",
    "imbavagliassero": "imbavagliare",
    "imbavagliassi": "imbavagliare",
    "imbavagliassimo": "imbavagliare",
    "imbavagliaste": "imbavagliare",
    "imbavagliasti": "imbavagliare",
    "imbavagliata": "imbavagliare",
    "imbavagliate": "imbavagliare",
    "imbavagliati": "imbavagliare",
    "imbavagliato": "imbavagliare",
    "imbavagliava": "imbavagliare",
    "imbavagliavamo": "imbavagliare",
    "imbavagliavan": "imbavagliare",
    "imbavagliavano": "imbavagliare",
    "imbavagliavate": "imbavagliare",
    "imbavagliavi": "imbavagliare",
    "imbavagliavo": "imbavagliare",
    "imbavaglierai": "imbavagliare",
    "imbavaglieran": "imbavagliare",
    "imbavaglieranno": "imbavagliare",
    "imbavaglierebbe": "imbavagliare",
    "imbavaglierebber": "imbavagliare",
    "imbavaglierebbero": "imbavagliare",
    "imbavaglierei": "imbavagliare",
    "imbavaglieremmo": "imbavagliare",
    "imbavaglieremo": "imbavagliare",
    "imbavagliereste": "imbavagliare",
    "imbavaglieresti": "imbavagliare",
    "imbavaglierete": "imbavagliare",
    "imbavaglierà": "imbavagliare",
    "imbavaglierò": "imbavagliare",
    "imbavaglin": "imbavagliare",
    "imbavaglino": "imbavagliare",
    "imbavaglio": "imbavagliare",
    "imbavagliò": "imbavagliare",
    "imbecca": "imbeccare",
    "imbeccai": "imbeccare",
    "imbeccammo": "imbeccare",
    "imbeccan": "imbeccare",
    "imbeccando": "imbeccare",
    "imbeccano": "imbeccare",
    "imbeccante": "imbeccare",
    "imbeccanti": "imbeccare",
    "imbeccar": "imbeccare",
    "imbeccaron": "imbeccare",
    "imbeccarono": "imbeccare",
    "imbeccasse": "imbeccare",
    "imbeccasser": "imbeccare",
    "imbeccassero": "imbeccare",
    "imbeccassi": "imbeccare",
    "imbeccassimo": "imbeccare",
    "imbeccaste": "imbeccare",
    "imbeccasti": "imbeccare",
    "imbeccata": "imbeccare",
    "imbeccate": "imbeccare",
    "imbeccati": "imbeccare",
    "imbeccato": "imbeccare",
    "imbeccava": "imbeccare",
    "imbeccavamo": "imbeccare",
    "imbeccavan": "imbeccare",
    "imbeccavano": "imbeccare",
    "imbeccavate": "imbeccare",
    "imbeccavi": "imbeccare",
    "imbeccavo": "imbeccare",
    "imbeccherai": "imbeccare",
    "imbeccheran": "imbeccare",
    "imbeccheranno": "imbeccare",
    "imbeccherebbe": "imbeccare",
    "imbeccherebber": "imbeccare",
    "imbeccherebbero": "imbeccare",
    "imbeccherei": "imbeccare",
    "imbeccheremmo": "imbeccare",
    "imbeccheremo": "imbeccare",
    "imbecchereste": "imbeccare",
    "imbeccheresti": "imbeccare",
    "imbeccherete": "imbeccare",
    "imbeccherà": "imbeccare",
    "imbeccherò": "imbeccare",
    "imbecchi": "imbeccare",
    "imbecchiamo": "imbeccare",
    "imbecchiate": "imbeccare",
    "imbecchin": "imbeccare",
    "imbecchino": "imbeccare",
    "imbecco": "imbeccare",
    "imbeccò": "imbeccare",
    "imbecilli": "imbecille",
    "imbella": "imbellire",
    "imbellan": "imbellire",
    "imbellano": "imbellire",
    "imbelle": "imbellire",
    "imbellendo": "imbellire",
    "imbellente": "imbellire",
    "imbellenti": "imbellire",
    "imbelletta": "imbellettare",
    "imbellettai": "imbellettare",
    "imbellettammo": "imbellettare",
    "imbellettan": "imbellettare",
    "imbellettando": "imbellettare",
    "imbellettano": "imbellettare",
    "imbellettante": "imbellettare",
    "imbellettanti": "imbellettare",
    "imbellettar": "imbellettare",
    "imbellettaron": "imbellettare",
    "imbellettarono": "imbellettare",
    "imbellettasse": "imbellettare",
    "imbellettasser": "imbellettare",
    "imbellettassero": "imbellettare",
    "imbellettassi": "imbellettare",
    "imbellettassimo": "imbellettare",
    "imbellettaste": "imbellettare",
    "imbellettasti": "imbellettare",
    "imbellettata": "imbellettare",
    "imbellettate": "imbellettare",
    "imbellettati": "imbellettare",
    "imbellettato": "imbellettare",
    "imbellettava": "imbellettare",
    "imbellettavamo": "imbellettare",
    "imbellettavan": "imbellettare",
    "imbellettavano": "imbellettare",
    "imbellettavate": "imbellettare",
    "imbellettavi": "imbellettare",
    "imbellettavo": "imbellettare",
    "imbelletterai": "imbellettare",
    "imbelletteran": "imbellettare",
    "imbelletteranno": "imbellettare",
    "imbelletterebbe": "imbellettare",
    "imbelletterebber": "imbellettare",
    "imbelletterebbero": "imbellettare",
    "imbelletterei": "imbellettare",
    "imbelletteremmo": "imbellettare",
    "imbelletteremo": "imbellettare",
    "imbellettereste": "imbellettare",
    "imbelletteresti": "imbellettare",
    "imbelletterete": "imbellettare",
    "imbelletterà": "imbellettare",
    "imbelletterò": "imbellettare",
    "imbelletti": "imbellettare",
    "imbellettiamo": "imbellettare",
    "imbellettiate": "imbellettare",
    "imbellettin": "imbellettare",
    "imbellettino": "imbellettare",
    "imbelletto": "imbellettare",
    "imbellettò": "imbellettare",
    "imbelli": "imbellire",
    "imbelliamo": "imbellire",
    "imbelliate": "imbellire",
    "imbellii": "imbellire",
    "imbellimmo": "imbellire",
    "imbellir": "imbellire",
    "imbellirai": "imbellire",
    "imbelliran": "imbellire",
    "imbelliranno": "imbellire",
    "imbellirebbe": "imbellire",
    "imbellirebber": "imbellire",
    "imbellirebbero": "imbellire",
    "imbellirei": "imbellire",
    "imbelliremmo": "imbellire",
    "imbelliremo": "imbellire",
    "imbellireste": "imbellire",
    "imbelliresti": "imbellire",
    "imbellirete": "imbellire",
    "imbelliron": "imbellire",
    "imbellirono": "imbellire",
    "imbellirà": "imbellire",
    "imbellirò": "imbellire",
    "imbellisse": "imbellire",
    "imbellisser": "imbellire",
    "imbellissero": "imbellire",
    "imbellissi": "imbellire",
    "imbellissimo": "imbellire",
    "imbelliste": "imbellire",
    "imbellisti": "imbellire",
    "imbellita": "imbellire",
    "imbellite": "imbellire",
    "imbelliti": "imbellire",
    "imbellito": "imbellire",
    "imbelliva": "imbellire",
    "imbellivamo": "imbellire",
    "imbellivan": "imbellire",
    "imbellivano": "imbellire",
    "imbellivate": "imbellire",
    "imbellivi": "imbellire",
    "imbellivo": "imbellire",
    "imbello": "imbellire",
    "imbellon": "imbellire",
    "imbellono": "imbellire",
    "imbellì": "imbellire",
    "imberbi": "imberbe",
    "imbestiala": "imbestialire",
    "imbestialan": "imbestialire",
    "imbestialano": "imbestialire",
    "imbestiale": "imbestialire",
    "imbestialendo": "imbestialire",
    "imbestialente": "imbestialire",
    "imbestialenti": "imbestialire",
    "imbestiali": "imbestialire",
    "imbestialiamo": "imbestialire",
    "imbestialiate": "imbestialire",
    "imbestialii": "imbestialire",
    "imbestialimmo": "imbestialire",
    "imbestialir": "imbestialire",
    "imbestialirai": "imbestialire",
    "imbestialiran": "imbestialire",
    "imbestialiranno": "imbestialire",
    "imbestialirebbe": "imbestialire",
    "imbestialirebber": "imbestialire",
    "imbestialirebbero": "imbestialire",
    "imbestialirei": "imbestialire",
    "imbestialiremmo": "imbestialire",
    "imbestialiremo": "imbestialire",
    "imbestialireste": "imbestialire",
    "imbestialiresti": "imbestialire",
    "imbestialirete": "imbestialire",
    "imbestialiron": "imbestialire",
    "imbestialirono": "imbestialire",
    "imbestialirà": "imbestialire",
    "imbestialirò": "imbestialire",
    "imbestialisse": "imbestialire",
    "imbestialisser": "imbestialire",
    "imbestialissero": "imbestialire",
    "imbestialissi": "imbestialire",
    "imbestialissimo": "imbestialire",
    "imbestialiste": "imbestialire",
    "imbestialisti": "imbestialire",
    "imbestialita": "imbestialire",
    "imbestialite": "imbestialire",
    "imbestialiti": "imbestialire",
    "imbestialito": "imbestialire",
    "imbestialiva": "imbestialire",
    "imbestialivamo": "imbestialire",
    "imbestialivan": "imbestialire",
    "imbestialivano": "imbestialire",
    "imbestialivate": "imbestialire",
    "imbestialivi": "imbestialire",
    "imbestialivo": "imbestialire",
    "imbestialo": "imbestialire",
    "imbestialon": "imbestialire",
    "imbestialono": "imbestialire",
    "imbestialì": "imbestialire",
    "imbeva": "imbevere",
    "imbevan": "imbevere",
    "imbevano": "imbevere",
    "imbeve": "imbevere",
    "imbevei": "imbevere",
    "imbevemmo": "imbevere",
    "imbevendo": "imbevere",
    "imbevente": "imbevere",
    "imbeventi": "imbevere",
    "imbever": "imbevere",
    "imbeverai": "imbevere",
    "imbeveran": "imbevere",
    "imbeveranno": "imbevere",
    "imbeverebbe": "imbevere",
    "imbeverebber": "imbevere",
    "imbeverebbero": "imbevere",
    "imbeverei": "imbevere",
    "imbeveremmo": "imbevere",
    "imbeveremo": "imbevere",
    "imbevereste": "imbevere",
    "imbeveresti": "imbevere",
    "imbeverete": "imbevere",
    "imbeveron": "imbevere",
    "imbeverono": "imbevere",
    "imbeverà": "imbevere",
    "imbeverò": "imbevere",
    "imbevesse": "imbevere",
    "imbevesser": "imbevere",
    "imbevessero": "imbevere",
    "imbevessi": "imbevere",
    "imbevessimo": "imbevere",
    "imbeveste": "imbevere",
    "imbevesti": "imbevere",
    "imbevete": "imbevere",
    "imbeveva": "imbevere",
    "imbevevamo": "imbevere",
    "imbevevan": "imbevere",
    "imbevevano": "imbevere",
    "imbevevate": "imbevere",
    "imbevevi": "imbevere",
    "imbevevo": "imbevere",
    "imbevi": "imbevere",
    "imbeviamo": "imbevere",
    "imbeviate": "imbevere",
    "imbevo": "imbevere",
    "imbevon": "imbevere",
    "imbevono": "imbevere",
    "imbevuta": "imbevere",
    "imbevute": "imbevere",
    "imbevuti": "imbevere",
    "imbevuto": "imbevere",
    "imbevè": "imbevere",
    "imbiacca": "imbiaccare",
    "imbiaccai": "imbiaccare",
    "imbiaccammo": "imbiaccare",
    "imbiaccan": "imbiaccare",
    "imbiaccando": "imbiaccare",
    "imbiaccano": "imbiaccare",
    "imbiaccante": "imbiaccare",
    "imbiaccanti": "imbiaccare",
    "imbiaccar": "imbiaccare",
    "imbiaccaron": "imbiaccare",
    "imbiaccarono": "imbiaccare",
    "imbiaccasse": "imbiaccare",
    "imbiaccasser": "imbiaccare",
    "imbiaccassero": "imbiaccare",
    "imbiaccassi": "imbiaccare",
    "imbiaccassimo": "imbiaccare",
    "imbiaccaste": "imbiaccare",
    "imbiaccasti": "imbiaccare",
    "imbiaccata": "imbiaccare",
    "imbiaccate": "imbiaccare",
    "imbiaccati": "imbiaccare",
    "imbiaccato": "imbiaccare",
    "imbiaccava": "imbiaccare",
    "imbiaccavamo": "imbiaccare",
    "imbiaccavan": "imbiaccare",
    "imbiaccavano": "imbiaccare",
    "imbiaccavate": "imbiaccare",
    "imbiaccavi": "imbiaccare",
    "imbiaccavo": "imbiaccare",
    "imbiaccherai": "imbiaccare",
    "imbiaccheran": "imbiaccare",
    "imbiaccheranno": "imbiaccare",
    "imbiaccherebbe": "imbiaccare",
    "imbiaccherebber": "imbiaccare",
    "imbiaccherebbero": "imbiaccare",
    "imbiaccherei": "imbiaccare",
    "imbiaccheremmo": "imbiaccare",
    "imbiaccheremo": "imbiaccare",
    "imbiacchereste": "imbiaccare",
    "imbiaccheresti": "imbiaccare",
    "imbiaccherete": "imbiaccare",
    "imbiaccherà": "imbiaccare",
    "imbiaccherò": "imbiaccare",
    "imbiacchi": "imbiaccare",
    "imbiacchiamo": "imbiaccare",
    "imbiacchiate": "imbiaccare",
    "imbiacchin": "imbiaccare",
    "imbiacchino": "imbiaccare",
    "imbiacco": "imbiaccare",
    "imbiaccò": "imbiaccare",
    "imbianca": "imbiancare",
    "imbiancai": "imbiancare",
    "imbiancammo": "imbiancare",
    "imbiancan": "imbiancare",
    "imbiancando": "imbiancare",
    "imbiancano": "imbiancare",
    "imbiancante": "imbiancare",
    "imbiancanti": "imbiancare",
    "imbiancar": "imbiancare",
    "imbiancaron": "imbiancare",
    "imbiancarono": "imbiancare",
    "imbiancasse": "imbiancare",
    "imbiancasser": "imbiancare",
    "imbiancassero": "imbiancare",
    "imbiancassi": "imbiancare",
    "imbiancassimo": "imbiancare",
    "imbiancaste": "imbiancare",
    "imbiancasti": "imbiancare",
    "imbiancata": "imbiancato",
    "imbiancate": "imbiancato",
    "imbiancati": "imbiancato",
    "imbiancato": "imbiancare",
    "imbiancava": "imbiancare",
    "imbiancavamo": "imbiancare",
    "imbiancavan": "imbiancare",
    "imbiancavano": "imbiancare",
    "imbiancavate": "imbiancare",
    "imbiancavi": "imbiancare",
    "imbiancavo": "imbiancare",
    "imbiancherai": "imbiancare",
    "imbiancheran": "imbiancare",
    "imbiancheranno": "imbiancare",
    "imbiancherebbe": "imbiancare",
    "imbiancherebber": "imbiancare",
    "imbiancherebbero": "imbiancare",
    "imbiancherei": "imbiancare",
    "imbiancheremmo": "imbiancare",
    "imbiancheremo": "imbiancare",
    "imbianchereste": "imbiancare",
    "imbiancheresti": "imbiancare",
    "imbiancherete": "imbiancare",
    "imbiancherà": "imbiancare",
    "imbiancherò": "imbiancare",
    "imbianchi": "imbiancare",
    "imbianchiamo": "imbiancare",
    "imbianchiate": "imbiancare",
    "imbianchin": "imbiancare",
    "imbianchini": "imbianchino",
    "imbianchino": "imbiancare",
    "imbianco": "imbiancare",
    "imbiancò": "imbiancare",
    "imbionda": "imbiondire",
    "imbiondan": "imbiondire",
    "imbiondano": "imbiondire",
    "imbionde": "imbiondire",
    "imbiondendo": "imbiondire",
    "imbiondente": "imbiondire",
    "imbiondenti": "imbiondire",
    "imbiondi": "imbiondire",
    "imbiondiamo": "imbiondire",
    "imbiondiate": "imbiondire",
    "imbiondii": "imbiondire",
    "imbiondimmo": "imbiondire",
    "imbiondir": "imbiondire",
    "imbiondirai": "imbiondire",
    "imbiondiran": "imbiondire",
    "imbiondiranno": "imbiondire",
    "imbiondirebbe": "imbiondire",
    "imbiondirebber": "imbiondire",
    "imbiondirebbero": "imbiondire",
    "imbiondirei": "imbiondire",
    "imbiondiremmo": "imbiondire",
    "imbiondiremo": "imbiondire",
    "imbiondireste": "imbiondire",
    "imbiondiresti": "imbiondire",
    "imbiondirete": "imbiondire",
    "imbiondiron": "imbiondire",
    "imbiondirono": "imbiondire",
    "imbiondirà": "imbiondire",
    "imbiondirò": "imbiondire",
    "imbiondisse": "imbiondire",
    "imbiondisser": "imbiondire",
    "imbiondissero": "imbiondire",
    "imbiondissi": "imbiondire",
    "imbiondissimo": "imbiondire",
    "imbiondiste": "imbiondire",
    "imbiondisti": "imbiondire",
    "imbiondita": "imbiondire",
    "imbiondite": "imbiondire",
    "imbionditi": "imbiondire",
    "imbiondito": "imbiondire",
    "imbiondiva": "imbiondire",
    "imbiondivamo": "imbiondire",
    "imbiondivan": "imbiondire",
    "imbiondivano": "imbiondire",
    "imbiondivate": "imbiondire",
    "imbiondivi": "imbiondire",
    "imbiondivo": "imbiondire",
    "imbiondo": "imbiondire",
    "imbiondon": "imbiondire",
    "imbiondono": "imbiondire",
    "imbiondì": "imbiondire",
    "imbizzarra": "imbizzarrire",
    "imbizzarran": "imbizzarrire",
    "imbizzarrano": "imbizzarrire",
    "imbizzarre": "imbizzarrire",
    "imbizzarrendo": "imbizzarrire",
    "imbizzarrente": "imbizzarrire",
    "imbizzarrenti": "imbizzarrire",
    "imbizzarri": "imbizzarrire",
    "imbizzarriamo": "imbizzarrire",
    "imbizzarriate": "imbizzarrire",
    "imbizzarrii": "imbizzarrire",
    "imbizzarrimmo": "imbizzarrire",
    "imbizzarrir": "imbizzarrire",
    "imbizzarrirai": "imbizzarrire",
    "imbizzarriran": "imbizzarrire",
    "imbizzarriranno": "imbizzarrire",
    "imbizzarrirebbe": "imbizzarrire",
    "imbizzarrirebber": "imbizzarrire",
    "imbizzarrirebbero": "imbizzarrire",
    "imbizzarrirei": "imbizzarrire",
    "imbizzarriremmo": "imbizzarrire",
    "imbizzarriremo": "imbizzarrire",
    "imbizzarrireste": "imbizzarrire",
    "imbizzarriresti": "imbizzarrire",
    "imbizzarrirete": "imbizzarrire",
    "imbizzarriron": "imbizzarrire",
    "imbizzarrirono": "imbizzarrire",
    "imbizzarrirà": "imbizzarrire",
    "imbizzarrirò": "imbizzarrire",
    "imbizzarrisse": "imbizzarrire",
    "imbizzarrisser": "imbizzarrire",
    "imbizzarrissero": "imbizzarrire",
    "imbizzarrissi": "imbizzarrire",
    "imbizzarrissimo": "imbizzarrire",
    "imbizzarriste": "imbizzarrire",
    "imbizzarristi": "imbizzarrire",
    "imbizzarrita": "imbizzarrire",
    "imbizzarrite": "imbizzarrire",
    "imbizzarriti": "imbizzarrire",
    "imbizzarrito": "imbizzarrire",
    "imbizzarriva": "imbizzarrire",
    "imbizzarrivamo": "imbizzarrire",
    "imbizzarrivan": "imbizzarrire",
    "imbizzarrivano": "imbizzarrire",
    "imbizzarrivate": "imbizzarrire",
    "imbizzarrivi": "imbizzarrire",
    "imbizzarrivo": "imbizzarrire",
    "imbizzarro": "imbizzarrire",
    "imbizzarron": "imbizzarrire",
    "imbizzarrono": "imbizzarrire",
    "imbizzarrì": "imbizzarrire",
    "imbocca": "imboccare",
    "imboccai": "imboccare",
    "imboccammo": "imboccare",
    "imboccan": "imboccare",
    "imboccando": "imboccare",
    "imboccano": "imboccare",
    "imboccante": "imboccare",
    "imboccanti": "imboccare",
    "imboccar": "imboccare",
    "imboccaron": "imboccare",
    "imboccarono": "imboccare",
    "imboccasse": "imboccare",
    "imboccasser": "imboccare",
    "imboccassero": "imboccare",
    "imboccassi": "imboccare",
    "imboccassimo": "imboccare",
    "imboccaste": "imboccare",
    "imboccasti": "imboccare",
    "imboccata": "imboccare",
    "imboccate": "imboccare",
    "imboccati": "imboccare",
    "imboccato": "imboccare",
    "imboccature": "imboccatura",
    "imboccava": "imboccare",
    "imboccavamo": "imboccare",
    "imboccavan": "imboccare",
    "imboccavano": "imboccare",
    "imboccavate": "imboccare",
    "imboccavi": "imboccare",
    "imboccavo": "imboccare",
    "imboccherai": "imboccare",
    "imboccheran": "imboccare",
    "imboccheranno": "imboccare",
    "imboccherebbe": "imboccare",
    "imboccherebber": "imboccare",
    "imboccherebbero": "imboccare",
    "imboccherei": "imboccare",
    "imboccheremmo": "imboccare",
    "imboccheremo": "imboccare",
    "imbocchereste": "imboccare",
    "imboccheresti": "imboccare",
    "imboccherete": "imboccare",
    "imboccherà": "imboccare",
    "imboccherò": "imboccare",
    "imbocchi": "imboccare",
    "imbocchiamo": "imboccare",
    "imbocchiate": "imboccare",
    "imbocchin": "imboccare",
    "imbocchino": "imboccare",
    "imbocco": "imboccare",
    "imboccò": "imboccare",
    "imbolsa": "imbolsire",
    "imbolsan": "imbolsire",
    "imbolsano": "imbolsire",
    "imbolse": "imbolsire",
    "imbolsendo": "imbolsire",
    "imbolsente": "imbolsire",
    "imbolsenti": "imbolsire",
    "imbolsi": "imbolsire",
    "imbolsiamo": "imbolsire",
    "imbolsiate": "imbolsire",
    "imbolsii": "imbolsire",
    "imbolsimmo": "imbolsire",
    "imbolsir": "imbolsire",
    "imbolsirai": "imbolsire",
    "imbolsiran": "imbolsire",
    "imbolsiranno": "imbolsire",
    "imbolsirebbe": "imbolsire",
    "imbolsirebber": "imbolsire",
    "imbolsirebbero": "imbolsire",
    "imbolsirei": "imbolsire",
    "imbolsiremmo": "imbolsire",
    "imbolsiremo": "imbolsire",
    "imbolsireste": "imbolsire",
    "imbolsiresti": "imbolsire",
    "imbolsirete": "imbolsire",
    "imbolsiron": "imbolsire",
    "imbolsirono": "imbolsire",
    "imbolsirà": "imbolsire",
    "imbolsirò": "imbolsire",
    "imbolsisse": "imbolsire",
    "imbolsisser": "imbolsire",
    "imbolsissero": "imbolsire",
    "imbolsissi": "imbolsire",
    "imbolsissimo": "imbolsire",
    "imbolsiste": "imbolsire",
    "imbolsisti": "imbolsire",
    "imbolsita": "imbolsire",
    "imbolsite": "imbolsire",
    "imbolsiti": "imbolsire",
    "imbolsito": "imbolsire",
    "imbolsiva": "imbolsire",
    "imbolsivamo": "imbolsire",
    "imbolsivan": "imbolsire",
    "imbolsivano": "imbolsire",
    "imbolsivate": "imbolsire",
    "imbolsivi": "imbolsire",
    "imbolsivo": "imbolsire",
    "imbolso": "imbolsire",
    "imbolson": "imbolsire",
    "imbolsono": "imbolsire",
    "imbolsì": "imbolsire",
    "imbona": "imbonire",
    "imbonan": "imbonire",
    "imbonano": "imbonire",
    "imbone": "imbonire",
    "imbonendo": "imbonire",
    "imbonente": "imbonire",
    "imbonenti": "imbonire",
    "imboni": "imbonire",
    "imboniamo": "imbonire",
    "imboniate": "imbonire",
    "imbonii": "imbonire",
    "imbonimenti": "imbonimento",
    "imbonimmo": "imbonire",
    "imbonir": "imbonire",
    "imbonirai": "imbonire",
    "imboniran": "imbonire",
    "imboniranno": "imbonire",
    "imbonirebbe": "imbonire",
    "imbonirebber": "imbonire",
    "imbonirebbero": "imbonire",
    "imbonirei": "imbonire",
    "imboniremmo": "imbonire",
    "imboniremo": "imbonire",
    "imbonireste": "imbonire",
    "imboniresti": "imbonire",
    "imbonirete": "imbonire",
    "imboniron": "imbonire",
    "imbonirono": "imbonire",
    "imbonirà": "imbonire",
    "imbonirò": "imbonire",
    "imbonisse": "imbonire",
    "imbonisser": "imbonire",
    "imbonissero": "imbonire",
    "imbonissi": "imbonire",
    "imbonissimo": "imbonire",
    "imboniste": "imbonire",
    "imbonisti": "imbonire",
    "imbonita": "imbonire",
    "imbonite": "imbonire",
    "imboniti": "imbonire",
    "imbonito": "imbonire",
    "imbonitori": "imbonitore",
    "imboniva": "imbonire",
    "imbonivamo": "imbonire",
    "imbonivan": "imbonire",
    "imbonivano": "imbonire",
    "imbonivate": "imbonire",
    "imbonivi": "imbonire",
    "imbonivo": "imbonire",
    "imbono": "imbonire",
    "imbonon": "imbonire",
    "imbonono": "imbonire",
    "imbonì": "imbonire",
    "imborghesa": "imborghesire",
    "imborghesan": "imborghesire",
    "imborghesano": "imborghesire",
    "imborghese": "imborghesire",
    "imborghesendo": "imborghesire",
    "imborghesente": "imborghesire",
    "imborghesenti": "imborghesire",
    "imborghesi": "imborghesire",
    "imborghesiamo": "imborghesire",
    "imborghesiate": "imborghesire",
    "imborghesii": "imborghesire",
    "imborghesimmo": "imborghesire",
    "imborghesir": "imborghesire",
    "imborghesirai": "imborghesire",
    "imborghesiran": "imborghesire",
    "imborghesiranno": "imborghesire",
    "imborghesirebbe": "imborghesire",
    "imborghesirebber": "imborghesire",
    "imborghesirebbero": "imborghesire",
    "imborghesirei": "imborghesire",
    "imborghesiremmo": "imborghesire",
    "imborghesiremo": "imborghesire",
    "imborghesireste": "imborghesire",
    "imborghesiresti": "imborghesire",
    "imborghesirete": "imborghesire",
    "imborghesiron": "imborghesire",
    "imborghesirono": "imborghesire",
    "imborghesirà": "imborghesire",
    "imborghesirò": "imborghesire",
    "imborghesisse": "imborghesire",
    "imborghesisser": "imborghesire",
    "imborghesissero": "imborghesire",
    "imborghesissi": "imborghesire",
    "imborghesissimo": "imborghesire",
    "imborghesiste": "imborghesire",
    "imborghesisti": "imborghesire",
    "imborghesita": "imborghesire",
    "imborghesite": "imborghesire",
    "imborghesiti": "imborghesire",
    "imborghesito": "imborghesire",
    "imborghesiva": "imborghesire",
    "imborghesivamo": "imborghesire",
    "imborghesivan": "imborghesire",
    "imborghesivano": "imborghesire",
    "imborghesivate": "imborghesire",
    "imborghesivi": "imborghesire",
    "imborghesivo": "imborghesire",
    "imborgheso": "imborghesire",
    "imborgheson": "imborghesire",
    "imborghesono": "imborghesire",
    "imborghesì": "imborghesire",
    "imbosca": "imboscare",
    "imboscai": "imboscare",
    "imboscammo": "imboscare",
    "imboscan": "imboscare",
    "imboscando": "imboscare",
    "imboscano": "imboscare",
    "imboscante": "imboscare",
    "imboscanti": "imboscare",
    "imboscar": "imboscare",
    "imboscaron": "imboscare",
    "imboscarono": "imboscare",
    "imboscasse": "imboscare",
    "imboscasser": "imboscare",
    "imboscassero": "imboscare",
    "imboscassi": "imboscare",
    "imboscassimo": "imboscare",
    "imboscaste": "imboscare",
    "imboscasti": "imboscare",
    "imboscata": "imboscato",
    "imboscate": "imboscato",
    "imboscati": "imboscato",
    "imboscato": "imboscare",
    "imboscava": "imboscare",
    "imboscavamo": "imboscare",
    "imboscavan": "imboscare",
    "imboscavano": "imboscare",
    "imboscavate": "imboscare",
    "imboscavi": "imboscare",
    "imboscavo": "imboscare",
    "imboscherai": "imboscare",
    "imboscheran": "imboscare",
    "imboscheranno": "imboscare",
    "imboscherebbe": "imboscare",
    "imboscherebber": "imboscare",
    "imboscherebbero": "imboscare",
    "imboscherei": "imboscare",
    "imboscheremmo": "imboscare",
    "imboscheremo": "imboscare",
    "imboschereste": "imboscare",
    "imboscheresti": "imboscare",
    "imboscherete": "imboscare",
    "imboscherà": "imboscare",
    "imboscherò": "imboscare",
    "imboschi": "imboscare",
    "imboschiamo": "imboscare",
    "imboschiate": "imboscare",
    "imboschin": "imboscare",
    "imboschino": "imboscare",
    "imbosco": "imboscare",
    "imboscò": "imboscare",
    "imbottendo": "imbottire",
    "imbottente": "imbottire",
    "imbottenti": "imbottire",
    "imbottiamo": "imbottire",
    "imbottiate": "imbottire",
    "imbottigli": "imbottigliare",
    "imbottiglia": "imbottigliare",
    "imbottigliai": "imbottigliare",
    "imbottigliammo": "imbottigliare",
    "imbottigliamo": "imbottigliare",
    "imbottiglian": "imbottigliare",
    "imbottigliando": "imbottigliare",
    "imbottigliano": "imbottigliare",
    "imbottigliante": "imbottigliare",
    "imbottiglianti": "imbottigliare",
    "imbottigliar": "imbottigliare",
    "imbottigliaron": "imbottigliare",
    "imbottigliarono": "imbottigliare",
    "imbottigliasse": "imbottigliare",
    "imbottigliasser": "imbottigliare",
    "imbottigliassero": "imbottigliare",
    "imbottigliassi": "imbottigliare",
    "imbottigliassimo": "imbottigliare",
    "imbottigliaste": "imbottigliare",
    "imbottigliasti": "imbottigliare",
    "imbottigliata": "imbottigliare",
    "imbottigliate": "imbottigliare",
    "imbottigliati": "imbottigliare",
    "imbottigliato": "imbottigliare",
    "imbottigliava": "imbottigliare",
    "imbottigliavamo": "imbottigliare",
    "imbottigliavan": "imbottigliare",
    "imbottigliavano": "imbottigliare",
    "imbottigliavate": "imbottigliare",
    "imbottigliavi": "imbottigliare",
    "imbottigliavo": "imbottigliare",
    "imbottiglierai": "imbottigliare",
    "imbottiglieran": "imbottigliare",
    "imbottiglieranno": "imbottigliare",
    "imbottiglierebbe": "imbottigliare",
    "imbottiglierebber": "imbottigliare",
    "imbottiglierebbero": "imbottigliare",
    "imbottiglierei": "imbottigliare",
    "imbottiglieremmo": "imbottigliare",
    "imbottiglieremo": "imbottigliare",
    "imbottigliereste": "imbottigliare",
    "imbottiglieresti": "imbottigliare",
    "imbottiglierete": "imbottigliare",
    "imbottiglierà": "imbottigliare",
    "imbottiglierò": "imbottigliare",
    "imbottiglin": "imbottigliare",
    "imbottiglino": "imbottigliare",
    "imbottiglio": "imbottigliare",
    "imbottigliò": "imbottigliare",
    "imbottii": "imbottire",
    "imbottimmo": "imbottire",
    "imbottir": "imbottire",
    "imbottirai": "imbottire",
    "imbottiran": "imbottire",
    "imbottiranno": "imbottire",
    "imbottirebbe": "imbottire",
    "imbottirebber": "imbottire",
    "imbottirebbero": "imbottire",
    "imbottirei": "imbottire",
    "imbottiremmo": "imbottire",
    "imbottiremo": "imbottire",
    "imbottireste": "imbottire",
    "imbottiresti": "imbottire",
    "imbottirete": "imbottire",
    "imbottiron": "imbottire",
    "imbottirono": "imbottire",
    "imbottirà": "imbottire",
    "imbottirò": "imbottire",
    "imbottisca": "imbottire",
    "imbottiscan": "imbottire",
    "imbottiscano": "imbottire",
    "imbottisce": "imbottire",
    "imbottisci": "imbottire",
    "imbottisco": "imbottire",
    "imbottiscon": "imbottire",
    "imbottiscono": "imbottire",
    "imbottisse": "imbottire",
    "imbottisser": "imbottire",
    "imbottissero": "imbottire",
    "imbottissi": "imbottire",
    "imbottissimo": "imbottire",
    "imbottiste": "imbottire",
    "imbottisti": "imbottire",
    "imbottita": "imbottito",
    "imbottite": "imbottito",
    "imbottiti": "imbottito",
    "imbottito": "imbottire",
    "imbottiture": "imbottitura",
    "imbottiva": "imbottire",
    "imbottivamo": "imbottire",
    "imbottivan": "imbottire",
    "imbottivano": "imbottire",
    "imbottivate": "imbottire",
    "imbottivi": "imbottire",
    "imbottivo": "imbottire",
    "imbottì": "imbottire",
    "imbraca": "imbracare",
    "imbracai": "imbracare",
    "imbracammo": "imbracare",
    "imbracan": "imbracare",
    "imbracando": "imbracare",
    "imbracano": "imbracare",
    "imbracante": "imbracare",
    "imbracanti": "imbracare",
    "imbracar": "imbracare",
    "imbracaron": "imbracare",
    "imbracarono": "imbracare",
    "imbracasse": "imbracare",
    "imbracasser": "imbracare",
    "imbracassero": "imbracare",
    "imbracassi": "imbracare",
    "imbracassimo": "imbracare",
    "imbracaste": "imbracare",
    "imbracasti": "imbracare",
    "imbracata": "imbracare",
    "imbracate": "imbracare",
    "imbracati": "imbracare",
    "imbracato": "imbracare",
    "imbracava": "imbracare",
    "imbracavamo": "imbracare",
    "imbracavan": "imbracare",
    "imbracavano": "imbracare",
    "imbracavate": "imbracare",
    "imbracavi": "imbracare",
    "imbracavo": "imbracare",
    "imbraccerai": "imbracciare",
    "imbracceran": "imbracciare",
    "imbracceranno": "imbracciare",
    "imbraccerebbe": "imbracciare",
    "imbraccerebber": "imbracciare",
    "imbraccerebbero": "imbracciare",
    "imbraccerei": "imbracciare",
    "imbracceremmo": "imbracciare",
    "imbracceremo": "imbracciare",
    "imbraccereste": "imbracciare",
    "imbracceresti": "imbracciare",
    "imbraccerete": "imbracciare",
    "imbraccerà": "imbracciare",
    "imbraccerò": "imbracciare",
    "imbracci": "imbracciare",
    "imbraccia": "imbracciare",
    "imbracciai": "imbracciare",
    "imbracciammo": "imbracciare",
    "imbracciamo": "imbracciare",
    "imbraccian": "imbracciare",
    "imbracciando": "imbracciare",
    "imbracciano": "imbracciare",
    "imbracciante": "imbracciare",
    "imbraccianti": "imbracciare",
    "imbracciar": "imbracciare",
    "imbracciaron": "imbracciare",
    "imbracciarono": "imbracciare",
    "imbracciasse": "imbracciare",
    "imbracciasser": "imbracciare",
    "imbracciassero": "imbracciare",
    "imbracciassi": "imbracciare",
    "imbracciassimo": "imbracciare",
    "imbracciaste": "imbracciare",
    "imbracciasti": "imbracciare",
    "imbracciata": "imbracciare",
    "imbracciate": "imbracciare",
    "imbracciati": "imbracciare",
    "imbracciato": "imbracciare",
    "imbracciava": "imbracciare",
    "imbracciavamo": "imbracciare",
    "imbracciavan": "imbracciare",
    "imbracciavano": "imbracciare",
    "imbracciavate": "imbracciare",
    "imbracciavi": "imbracciare",
    "imbracciavo": "imbracciare",
    "imbraccin": "imbracciare",
    "imbraccino": "imbracciare",
    "imbraccio": "imbracciare",
    "imbracciò": "imbracciare",
    "imbracherai": "imbracare",
    "imbracheran": "imbracare",
    "imbracheranno": "imbracare",
    "imbracherebbe": "imbracare",
    "imbracherebber": "imbracare",
    "imbracherebbero": "imbracare",
    "imbracherei": "imbracare",
    "imbracheremmo": "imbracare",
    "imbracheremo": "imbracare",
    "imbrachereste": "imbracare",
    "imbracheresti": "imbracare",
    "imbracherete": "imbracare",
    "imbracherà": "imbracare",
    "imbracherò": "imbracare",
    "imbrachetta": "imbrachettare",
    "imbrachettai": "imbrachettare",
    "imbrachettammo": "imbrachettare",
    "imbrachettan": "imbrachettare",
    "imbrachettando": "imbrachettare",
    "imbrachettano": "imbrachettare",
    "imbrachettante": "imbrachettare",
    "imbrachettanti": "imbrachettare",
    "imbrachettar": "imbrachettare",
    "imbrachettaron": "imbrachettare",
    "imbrachettarono": "imbrachettare",
    "imbrachettasse": "imbrachettare",
    "imbrachettasser": "imbrachettare",
    "imbrachettassero": "imbrachettare",
    "imbrachettassi": "imbrachettare",
    "imbrachettassimo": "imbrachettare",
    "imbrachettaste": "imbrachettare",
    "imbrachettasti": "imbrachettare",
    "imbrachettata": "imbrachettare",
    "imbrachettate": "imbrachettare",
    "imbrachettati": "imbrachettare",
    "imbrachettato": "imbrachettare",
    "imbrachettava": "imbrachettare",
    "imbrachettavamo": "imbrachettare",
    "imbrachettavan": "imbrachettare",
    "imbrachettavano": "imbrachettare",
    "imbrachettavate": "imbrachettare",
    "imbrachettavi": "imbrachettare",
    "imbrachettavo": "imbrachettare",
    "imbrachetterai": "imbrachettare",
    "imbrachetteran": "imbrachettare",
    "imbrachetteranno": "imbrachettare",
    "imbrachetterebbe": "imbrachettare",
    "imbrachetterebber": "imbrachettare",
    "imbrachetterebbero": "imbrachettare",
    "imbrachetterei": "imbrachettare",
    "imbrachetteremmo": "imbrachettare",
    "imbrachetteremo": "imbrachettare",
    "imbrachettereste": "imbrachettare",
    "imbrachetteresti": "imbrachettare",
    "imbrachetterete": "imbrachettare",
    "imbrachetterà": "imbrachettare",
    "imbrachetterò": "imbrachettare",
    "imbrachetti": "imbrachettare",
    "imbrachettiamo": "imbrachettare",
    "imbrachettiate": "imbrachettare",
    "imbrachettin": "imbrachettare",
    "imbrachettino": "imbrachettare",
    "imbrachetto": "imbrachettare",
    "imbrachettò": "imbrachettare",
    "imbrachi": "imbracare",
    "imbrachiamo": "imbracare",
    "imbrachiate": "imbracare",
    "imbrachin": "imbracare",
    "imbrachino": "imbracare",
    "imbraco": "imbracare",
    "imbracò": "imbracare",
    "imbranata": "imbranato",
    "imbranate": "imbranato",
    "imbranati": "imbranato",
    "imbranca": "imbrancare",
    "imbrancai": "imbrancare",
    "imbrancammo": "imbrancare",
    "imbrancan": "imbrancare",
    "imbrancando": "imbrancare",
    "imbrancano": "imbrancare",
    "imbrancante": "imbrancare",
    "imbrancanti": "imbrancare",
    "imbrancar": "imbrancare",
    "imbrancaron": "imbrancare",
    "imbrancarono": "imbrancare",
    "imbrancasse": "imbrancare",
    "imbrancasser": "imbrancare",
    "imbrancassero": "imbrancare",
    "imbrancassi": "imbrancare",
    "imbrancassimo": "imbrancare",
    "imbrancaste": "imbrancare",
    "imbrancasti": "imbrancare",
    "imbrancata": "imbrancare",
    "imbrancate": "imbrancare",
    "imbrancati": "imbrancare",
    "imbrancato": "imbrancare",
    "imbrancava": "imbrancare",
    "imbrancavamo": "imbrancare",
    "imbrancavan": "imbrancare",
    "imbrancavano": "imbrancare",
    "imbrancavate": "imbrancare",
    "imbrancavi": "imbrancare",
    "imbrancavo": "imbrancare",
    "imbrancherai": "imbrancare",
    "imbrancheran": "imbrancare",
    "imbrancheranno": "imbrancare",
    "imbrancherebbe": "imbrancare",
    "imbrancherebber": "imbrancare",
    "imbrancherebbero": "imbrancare",
    "imbrancherei": "imbrancare",
    "imbrancheremmo": "imbrancare",
    "imbrancheremo": "imbrancare",
    "imbranchereste": "imbrancare",
    "imbrancheresti": "imbrancare",
    "imbrancherete": "imbrancare",
    "imbrancherà": "imbrancare",
    "imbrancherò": "imbrancare",
    "imbranchi": "imbrancare",
    "imbranchiamo": "imbrancare",
    "imbranchiate": "imbrancare",
    "imbranchin": "imbrancare",
    "imbranchino": "imbrancare",
    "imbranco": "imbrancare",
    "imbrancò": "imbrancare",
    "imbratta": "imbrattare",
    "imbrattai": "imbrattare",
    "imbrattammo": "imbrattare",
    "imbrattan": "imbrattare",
    "imbrattando": "imbrattare",
    "imbrattano": "imbrattare",
    "imbrattante": "imbrattare",
    "imbrattanti": "imbrattare",
    "imbrattar": "imbrattare",
    "imbrattaron": "imbrattare",
    "imbrattarono": "imbrattare",
    "imbrattasse": "imbrattare",
    "imbrattasser": "imbrattare",
    "imbrattassero": "imbrattare",
    "imbrattassi": "imbrattare",
    "imbrattassimo": "imbrattare",
    "imbrattaste": "imbrattare",
    "imbrattasti": "imbrattare",
    "imbrattata": "imbrattare",
    "imbrattate": "imbrattare",
    "imbrattati": "imbrattare",
    "imbrattato": "imbrattare",
    "imbrattava": "imbrattare",
    "imbrattavamo": "imbrattare",
    "imbrattavan": "imbrattare",
    "imbrattavano": "imbrattare",
    "imbrattavate": "imbrattare",
    "imbrattavi": "imbrattare",
    "imbrattavo": "imbrattare",
    "imbratterai": "imbrattare",
    "imbratteran": "imbrattare",
    "imbratteranno": "imbrattare",
    "imbratterebbe": "imbrattare",
    "imbratterebber": "imbrattare",
    "imbratterebbero": "imbrattare",
    "imbratterei": "imbrattare",
    "imbratteremmo": "imbrattare",
    "imbratteremo": "imbrattare",
    "imbrattereste": "imbrattare",
    "imbratteresti": "imbrattare",
    "imbratterete": "imbrattare",
    "imbratterà": "imbrattare",
    "imbratterò": "imbrattare",
    "imbratti": "imbrattare",
    "imbrattiamo": "imbrattare",
    "imbrattiate": "imbrattare",
    "imbrattin": "imbrattare",
    "imbrattino": "imbrattare",
    "imbratto": "imbrattare",
    "imbrattò": "imbrattare",
    "imbrifera": "imbrifero",
    "imbrifere": "imbrifero",
    "imbriferi": "imbrifero",
    "imbrigli": "imbrigliare",
    "imbriglia": "imbrigliare",
    "imbrigliai": "imbrigliare",
    "imbrigliammo": "imbrigliare",
    "imbrigliamo": "imbrigliare",
    "imbriglian": "imbrigliare",
    "imbrigliando": "imbrigliare",
    "imbrigliano": "imbrigliare",
    "imbrigliante": "imbrigliare",
    "imbriglianti": "imbrigliare",
    "imbrigliar": "imbrigliare",
    "imbrigliaron": "imbrigliare",
    "imbrigliarono": "imbrigliare",
    "imbrigliasse": "imbrigliare",
    "imbrigliasser": "imbrigliare",
    "imbrigliassero": "imbrigliare",
    "imbrigliassi": "imbrigliare",
    "imbrigliassimo": "imbrigliare",
    "imbrigliaste": "imbrigliare",
    "imbrigliasti": "imbrigliare",
    "imbrigliata": "imbrigliare",
    "imbrigliate": "imbrigliare",
    "imbrigliati": "imbrigliare",
    "imbrigliato": "imbrigliare",
    "imbrigliava": "imbrigliare",
    "imbrigliavamo": "imbrigliare",
    "imbrigliavan": "imbrigliare",
    "imbrigliavano": "imbrigliare",
    "imbrigliavate": "imbrigliare",
    "imbrigliavi": "imbrigliare",
    "imbrigliavo": "imbrigliare",
    "imbriglierai": "imbrigliare",
    "imbriglieran": "imbrigliare",
    "imbriglieranno": "imbrigliare",
    "imbriglierebbe": "imbrigliare",
    "imbriglierebber": "imbrigliare",
    "imbriglierebbero": "imbrigliare",
    "imbriglierei": "imbrigliare",
    "imbriglieremmo": "imbrigliare",
    "imbriglieremo": "imbrigliare",
    "imbrigliereste": "imbrigliare",
    "imbriglieresti": "imbrigliare",
    "imbriglierete": "imbrigliare",
    "imbriglierà": "imbrigliare",
    "imbriglierò": "imbrigliare",
    "imbriglin": "imbrigliare",
    "imbriglino": "imbrigliare",
    "imbriglio": "imbrigliare",
    "imbrigliò": "imbrigliare",
    "imbrillantina": "imbrillantinare",
    "imbrillantinai": "imbrillantinare",
    "imbrillantinammo": "imbrillantinare",
    "imbrillantinan": "imbrillantinare",
    "imbrillantinando": "imbrillantinare",
    "imbrillantinano": "imbrillantinare",
    "imbrillantinante": "imbrillantinare",
    "imbrillantinanti": "imbrillantinare",
    "imbrillantinar": "imbrillantinare",
    "imbrillantinaron": "imbrillantinare",
    "imbrillantinarono": "imbrillantinare",
    "imbrillantinasse": "imbrillantinare",
    "imbrillantinasser": "imbrillantinare",
    "imbrillantinassero": "imbrillantinare",
    "imbrillantinassi": "imbrillantinare",
    "imbrillantinassimo": "imbrillantinare",
    "imbrillantinaste": "imbrillantinare",
    "imbrillantinasti": "imbrillantinare",
    "imbrillantinata": "imbrillantinare",
    "imbrillantinate": "imbrillantinare",
    "imbrillantinati": "imbrillantinare",
    "imbrillantinato": "imbrillantinare",
    "imbrillantinava": "imbrillantinare",
    "imbrillantinavamo": "imbrillantinare",
    "imbrillantinavan": "imbrillantinare",
    "imbrillantinavano": "imbrillantinare",
    "imbrillantinavate": "imbrillantinare",
    "imbrillantinavi": "imbrillantinare",
    "imbrillantinavo": "imbrillantinare",
    "imbrillantinerai": "imbrillantinare",
    "imbrillantineran": "imbrillantinare",
    "imbrillantineranno": "imbrillantinare",
    "imbrillantinerebbe": "imbrillantinare",
    "imbrillantinerebber": "imbrillantinare",
    "imbrillantinerebbero": "imbrillantinare",
    "imbrillantinerei": "imbrillantinare",
    "imbrillantineremmo": "imbrillantinare",
    "imbrillantineremo": "imbrillantinare",
    "imbrillantinereste": "imbrillantinare",
    "imbrillantineresti": "imbrillantinare",
    "imbrillantinerete": "imbrillantinare",
    "imbrillantinerà": "imbrillantinare",
    "imbrillantinerò": "imbrillantinare",
    "imbrillantini": "imbrillantinare",
    "imbrillantiniamo": "imbrillantinare",
    "imbrillantiniate": "imbrillantinare",
    "imbrillantinin": "imbrillantinare",
    "imbrillantinino": "imbrillantinare",
    "imbrillantino": "imbrillantinare",
    "imbrillantinò": "imbrillantinare",
    "imbrocca": "imbroccare",
    "imbroccai": "imbroccare",
    "imbroccammo": "imbroccare",
    "imbroccan": "imbroccare",
    "imbroccando": "imbroccare",
    "imbroccano": "imbroccare",
    "imbroccante": "imbroccare",
    "imbroccanti": "imbroccare",
    "imbroccar": "imbroccare",
    "imbroccaron": "imbroccare",
    "imbroccarono": "imbroccare",
    "imbroccasse": "imbroccare",
    "imbroccasser": "imbroccare",
    "imbroccassero": "imbroccare",
    "imbroccassi": "imbroccare",
    "imbroccassimo": "imbroccare",
    "imbroccaste": "imbroccare",
    "imbroccasti": "imbroccare",
    "imbroccata": "imbroccare",
    "imbroccate": "imbroccare",
    "imbroccati": "imbroccare",
    "imbroccato": "imbroccare",
    "imbroccava": "imbroccare",
    "imbroccavamo": "imbroccare",
    "imbroccavan": "imbroccare",
    "imbroccavano": "imbroccare",
    "imbroccavate": "imbroccare",
    "imbroccavi": "imbroccare",
    "imbroccavo": "imbroccare",
    "imbroccherai": "imbroccare",
    "imbroccheran": "imbroccare",
    "imbroccheranno": "imbroccare",
    "imbroccherebbe": "imbroccare",
    "imbroccherebber": "imbroccare",
    "imbroccherebbero": "imbroccare",
    "imbroccherei": "imbroccare",
    "imbroccheremmo": "imbroccare",
    "imbroccheremo": "imbroccare",
    "imbrocchereste": "imbroccare",
    "imbroccheresti": "imbroccare",
    "imbroccherete": "imbroccare",
    "imbroccherà": "imbroccare",
    "imbroccherò": "imbroccare",
    "imbrocchi": "imbroccare",
    "imbrocchiamo": "imbroccare",
    "imbrocchiate": "imbroccare",
    "imbrocchin": "imbroccare",
    "imbrocchino": "imbroccare",
    "imbrocco": "imbroccare",
    "imbroccò": "imbroccare",
    "imbroda": "imbrodare",
    "imbrodai": "imbrodare",
    "imbrodammo": "imbrodare",
    "imbrodan": "imbrodare",
    "imbrodando": "imbrodare",
    "imbrodano": "imbrodare",
    "imbrodante": "imbrodare",
    "imbrodanti": "imbrodare",
    "imbrodar": "imbrodare",
    "imbrodaron": "imbrodare",
    "imbrodarono": "imbrodare",
    "imbrodasse": "imbrodare",
    "imbrodasser": "imbrodare",
    "imbrodassero": "imbrodare",
    "imbrodassi": "imbrodare",
    "imbrodassimo": "imbrodare",
    "imbrodaste": "imbrodare",
    "imbrodasti": "imbrodare",
    "imbrodata": "imbrodare",
    "imbrodate": "imbrodare",
    "imbrodati": "imbrodare",
    "imbrodato": "imbrodare",
    "imbrodava": "imbrodare",
    "imbrodavamo": "imbrodare",
    "imbrodavan": "imbrodare",
    "imbrodavano": "imbrodare",
    "imbrodavate": "imbrodare",
    "imbrodavi": "imbrodare",
    "imbrodavo": "imbrodare",
    "imbroderai": "imbrodare",
    "imbroderan": "imbrodare",
    "imbroderanno": "imbrodare",
    "imbroderebbe": "imbrodare",
    "imbroderebber": "imbrodare",
    "imbroderebbero": "imbrodare",
    "imbroderei": "imbrodare",
    "imbroderemmo": "imbrodare",
    "imbroderemo": "imbrodare",
    "imbrodereste": "imbrodare",
    "imbroderesti": "imbrodare",
    "imbroderete": "imbrodare",
    "imbroderà": "imbrodare",
    "imbroderò": "imbrodare",
    "imbrodi": "imbrodare",
    "imbrodiamo": "imbrodare",
    "imbrodiate": "imbrodare",
    "imbrodin": "imbrodare",
    "imbrodino": "imbrodare",
    "imbrodo": "imbrodare",
    "imbrodola": "imbrodolare",
    "imbrodolai": "imbrodolare",
    "imbrodolammo": "imbrodolare",
    "imbrodolan": "imbrodolare",
    "imbrodolando": "imbrodolare",
    "imbrodolano": "imbrodolare",
    "imbrodolante": "imbrodolare",
    "imbrodolanti": "imbrodolare",
    "imbrodolar": "imbrodolare",
    "imbrodolaron": "imbrodolare",
    "imbrodolarono": "imbrodolare",
    "imbrodolasse": "imbrodolare",
    "imbrodolasser": "imbrodolare",
    "imbrodolassero": "imbrodolare",
    "imbrodolassi": "imbrodolare",
    "imbrodolassimo": "imbrodolare",
    "imbrodolaste": "imbrodolare",
    "imbrodolasti": "imbrodolare",
    "imbrodolata": "imbrodolare",
    "imbrodolate": "imbrodolare",
    "imbrodolati": "imbrodolare",
    "imbrodolato": "imbrodolare",
    "imbrodolava": "imbrodolare",
    "imbrodolavamo": "imbrodolare",
    "imbrodolavan": "imbrodolare",
    "imbrodolavano": "imbrodolare",
    "imbrodolavate": "imbrodolare",
    "imbrodolavi": "imbrodolare",
    "imbrodolavo": "imbrodolare",
    "imbrodolerai": "imbrodolare",
    "imbrodoleran": "imbrodolare",
    "imbrodoleranno": "imbrodolare",
    "imbrodolerebbe": "imbrodolare",
    "imbrodolerebber": "imbrodolare",
    "imbrodolerebbero": "imbrodolare",
    "imbrodolerei": "imbrodolare",
    "imbrodoleremmo": "imbrodolare",
    "imbrodoleremo": "imbrodolare",
    "imbrodolereste": "imbrodolare",
    "imbrodoleresti": "imbrodolare",
    "imbrodolerete": "imbrodolare",
    "imbrodolerà": "imbrodolare",
    "imbrodolerò": "imbrodolare",
    "imbrodoli": "imbrodolare",
    "imbrodoliamo": "imbrodolare",
    "imbrodoliate": "imbrodolare",
    "imbrodolin": "imbrodolare",
    "imbrodolino": "imbrodolare",
    "imbrodolo": "imbrodolare",
    "imbrodolò": "imbrodolare",
    "imbrodò": "imbrodare",
    "imbrogli": "imbroglio",
    "imbroglia": "imbrogliare",
    "imbrogliai": "imbrogliare",
    "imbrogliammo": "imbrogliare",
    "imbrogliamo": "imbrogliare",
    "imbroglian": "imbrogliare",
    "imbrogliando": "imbrogliare",
    "imbrogliano": "imbrogliare",
    "imbrogliante": "imbrogliare",
    "imbroglianti": "imbrogliare",
    "imbrogliar": "imbrogliare",
    "imbrogliaron": "imbrogliare",
    "imbrogliarono": "imbrogliare",
    "imbrogliasse": "imbrogliare",
    "imbrogliasser": "imbrogliare",
    "imbrogliassero": "imbrogliare",
    "imbrogliassi": "imbrogliare",
    "imbrogliassimo": "imbrogliare",
    "imbrogliaste": "imbrogliare",
    "imbrogliasti": "imbrogliare",
    "imbrogliata": "imbrogliare",
    "imbrogliate": "imbrogliare",
    "imbrogliati": "imbrogliare",
    "imbrogliato": "imbrogliare",
    "imbrogliava": "imbrogliare",
    "imbrogliavamo": "imbrogliare",
    "imbrogliavan": "imbrogliare",
    "imbrogliavano": "imbrogliare",
    "imbrogliavate": "imbrogliare",
    "imbrogliavi": "imbrogliare",
    "imbrogliavo": "imbrogliare",
    "imbroglierai": "imbrogliare",
    "imbroglieran": "imbrogliare",
    "imbroglieranno": "imbrogliare",
    "imbroglierebbe": "imbrogliare",
    "imbroglierebber": "imbrogliare",
    "imbroglierebbero": "imbrogliare",
    "imbroglierei": "imbrogliare",
    "imbroglieremmo": "imbrogliare",
    "imbroglieremo": "imbrogliare",
    "imbrogliereste": "imbrogliare",
    "imbroglieresti": "imbrogliare",
    "imbroglierete": "imbrogliare",
    "imbroglierà": "imbrogliare",
    "imbroglierò": "imbrogliare",
    "imbroglin": "imbrogliare",
    "imbroglino": "imbrogliare",
    "imbroglio": "imbrogliare",
    "imbroglioni": "imbroglione",
    "imbrogliò": "imbrogliare",
    "imbroncerai": "imbronciare",
    "imbronceran": "imbronciare",
    "imbronceranno": "imbronciare",
    "imbroncerebbe": "imbronciare",
    "imbroncerebber": "imbronciare",
    "imbroncerebbero": "imbronciare",
    "imbroncerei": "imbronciare",
    "imbronceremmo": "imbronciare",
    "imbronceremo": "imbronciare",
    "imbroncereste": "imbronciare",
    "imbronceresti": "imbronciare",
    "imbroncerete": "imbronciare",
    "imbroncerà": "imbronciare",
    "imbroncerò": "imbronciare",
    "imbronci": "imbronciare",
    "imbroncia": "imbronciare",
    "imbronciai": "imbronciare",
    "imbronciammo": "imbronciare",
    "imbronciamo": "imbronciare",
    "imbroncian": "imbronciare",
    "imbronciando": "imbronciare",
    "imbronciano": "imbronciare",
    "imbronciante": "imbronciare",
    "imbroncianti": "imbronciare",
    "imbronciar": "imbronciare",
    "imbronciaron": "imbronciare",
    "imbronciarono": "imbronciare",
    "imbronciasse": "imbronciare",
    "imbronciasser": "imbronciare",
    "imbronciassero": "imbronciare",
    "imbronciassi": "imbronciare",
    "imbronciassimo": "imbronciare",
    "imbronciaste": "imbronciare",
    "imbronciasti": "imbronciare",
    "imbronciata": "imbronciato",
    "imbronciate": "imbronciato",
    "imbronciati": "imbronciato",
    "imbronciato": "imbronciare",
    "imbronciava": "imbronciare",
    "imbronciavamo": "imbronciare",
    "imbronciavan": "imbronciare",
    "imbronciavano": "imbronciare",
    "imbronciavate": "imbronciare",
    "imbronciavi": "imbronciare",
    "imbronciavo": "imbronciare",
    "imbroncin": "imbronciare",
    "imbroncino": "imbronciare",
    "imbroncio": "imbronciare",
    "imbronciò": "imbronciare",
    "imbruna": "imbrunire",
    "imbrunan": "imbrunire",
    "imbrunano": "imbrunire",
    "imbrune": "imbrunire",
    "imbrunendo": "imbrunire",
    "imbrunente": "imbrunire",
    "imbrunenti": "imbrunire",
    "imbruni": "imbrunire",
    "imbruniamo": "imbrunire",
    "imbruniate": "imbrunire",
    "imbrunii": "imbrunire",
    "imbrunimmo": "imbrunire",
    "imbrunir": "imbrunire",
    "imbrunirai": "imbrunire",
    "imbruniran": "imbrunire",
    "imbruniranno": "imbrunire",
    "imbrunirebbe": "imbrunire",
    "imbrunirebber": "imbrunire",
    "imbrunirebbero": "imbrunire",
    "imbrunirei": "imbrunire",
    "imbruniremmo": "imbrunire",
    "imbruniremo": "imbrunire",
    "imbrunireste": "imbrunire",
    "imbruniresti": "imbrunire",
    "imbrunirete": "imbrunire",
    "imbruniron": "imbrunire",
    "imbrunirono": "imbrunire",
    "imbrunirà": "imbrunire",
    "imbrunirò": "imbrunire",
    "imbrunisse": "imbrunire",
    "imbrunisser": "imbrunire",
    "imbrunissero": "imbrunire",
    "imbrunissi": "imbrunire",
    "imbrunissimo": "imbrunire",
    "imbruniste": "imbrunire",
    "imbrunisti": "imbrunire",
    "imbrunita": "imbrunire",
    "imbrunite": "imbrunire",
    "imbruniti": "imbrunire",
    "imbrunito": "imbrunire",
    "imbruniva": "imbrunire",
    "imbrunivamo": "imbrunire",
    "imbrunivan": "imbrunire",
    "imbrunivano": "imbrunire",
    "imbrunivate": "imbrunire",
    "imbrunivi": "imbrunire",
    "imbrunivo": "imbrunire",
    "imbruno": "imbrunire",
    "imbrunon": "imbrunire",
    "imbrunono": "imbrunire",
    "imbrunì": "imbrunire",
    "imbrutta": "imbruttire",
    "imbruttan": "imbruttire",
    "imbruttano": "imbruttire",
    "imbrutte": "imbruttire",
    "imbruttendo": "imbruttire",
    "imbruttente": "imbruttire",
    "imbruttenti": "imbruttire",
    "imbrutti": "imbruttire",
    "imbruttiamo": "imbruttire",
    "imbruttiate": "imbruttire",
    "imbruttii": "imbruttire",
    "imbruttimmo": "imbruttire",
    "imbruttir": "imbruttire",
    "imbruttirai": "imbruttire",
    "imbruttiran": "imbruttire",
    "imbruttiranno": "imbruttire",
    "imbruttirebbe": "imbruttire",
    "imbruttirebber": "imbruttire",
    "imbruttirebbero": "imbruttire",
    "imbruttirei": "imbruttire",
    "imbruttiremmo": "imbruttire",
    "imbruttiremo": "imbruttire",
    "imbruttireste": "imbruttire",
    "imbruttiresti": "imbruttire",
    "imbruttirete": "imbruttire",
    "imbruttiron": "imbruttire",
    "imbruttirono": "imbruttire",
    "imbruttirà": "imbruttire",
    "imbruttirò": "imbruttire",
    "imbruttisse": "imbruttire",
    "imbruttisser": "imbruttire",
    "imbruttissero": "imbruttire",
    "imbruttissi": "imbruttire",
    "imbruttissimo": "imbruttire",
    "imbruttiste": "imbruttire",
    "imbruttisti": "imbruttire",
    "imbruttita": "imbruttire",
    "imbruttite": "imbruttire",
    "imbruttiti": "imbruttire",
    "imbruttito": "imbruttire",
    "imbruttiva": "imbruttire",
    "imbruttivamo": "imbruttire",
    "imbruttivan": "imbruttire",
    "imbruttivano": "imbruttire",
    "imbruttivate": "imbruttire",
    "imbruttivi": "imbruttire",
    "imbruttivo": "imbruttire",
    "imbrutto": "imbruttire",
    "imbrutton": "imbruttire",
    "imbruttono": "imbruttire",
    "imbruttì": "imbruttire",
    "imbuca": "imbucare",
    "imbucai": "imbucare",
    "imbucammo": "imbucare",
    "imbucan": "imbucare",
    "imbucando": "imbucare",
    "imbucano": "imbucare",
    "imbucante": "imbucare",
    "imbucanti": "imbucare",
    "imbucar": "imbucare",
    "imbucaron": "imbucare",
    "imbucarono": "imbucare",
    "imbucasse": "imbucare",
    "imbucasser": "imbucare",
    "imbucassero": "imbucare",
    "imbucassi": "imbucare",
    "imbucassimo": "imbucare",
    "imbucaste": "imbucare",
    "imbucasti": "imbucare",
    "imbucata": "imbucare",
    "imbucate": "imbucare",
    "imbucati": "imbucare",
    "imbucato": "imbucare",
    "imbucava": "imbucare",
    "imbucavamo": "imbucare",
    "imbucavan": "imbucare",
    "imbucavano": "imbucare",
    "imbucavate": "imbucare",
    "imbucavi": "imbucare",
    "imbucavo": "imbucare",
    "imbucherai": "imbucare",
    "imbucheran": "imbucare",
    "imbucheranno": "imbucare",
    "imbucherebbe": "imbucare",
    "imbucherebber": "imbucare",
    "imbucherebbero": "imbucare",
    "imbucherei": "imbucare",
    "imbucheremmo": "imbucare",
    "imbucheremo": "imbucare",
    "imbuchereste": "imbucare",
    "imbucheresti": "imbucare",
    "imbucherete": "imbucare",
    "imbucherà": "imbucare",
    "imbucherò": "imbucare",
    "imbuchi": "imbucare",
    "imbuchiamo": "imbucare",
    "imbuchiate": "imbucare",
    "imbuchin": "imbucare",
    "imbuchino": "imbucare",
    "imbuco": "imbucare",
    "imbucò": "imbucare",
    "imbulletta": "imbullettare",
    "imbullettai": "imbullettare",
    "imbullettammo": "imbullettare",
    "imbullettan": "imbullettare",
    "imbullettando": "imbullettare",
    "imbullettano": "imbullettare",
    "imbullettante": "imbullettare",
    "imbullettanti": "imbullettare",
    "imbullettar": "imbullettare",
    "imbullettaron": "imbullettare",
    "imbullettarono": "imbullettare",
    "imbullettasse": "imbullettare",
    "imbullettasser": "imbullettare",
    "imbullettassero": "imbullettare",
    "imbullettassi": "imbullettare",
    "imbullettassimo": "imbullettare",
    "imbullettaste": "imbullettare",
    "imbullettasti": "imbullettare",
    "imbullettata": "imbullettare",
    "imbullettate": "imbullettare",
    "imbullettati": "imbullettare",
    "imbullettato": "imbullettare",
    "imbullettava": "imbullettare",
    "imbullettavamo": "imbullettare",
    "imbullettavan": "imbullettare",
    "imbullettavano": "imbullettare",
    "imbullettavate": "imbullettare",
    "imbullettavi": "imbullettare",
    "imbullettavo": "imbullettare",
    "imbulletterai": "imbullettare",
    "imbulletteran": "imbullettare",
    "imbulletteranno": "imbullettare",
    "imbulletterebbe": "imbullettare",
    "imbulletterebber": "imbullettare",
    "imbulletterebbero": "imbullettare",
    "imbulletterei": "imbullettare",
    "imbulletteremmo": "imbullettare",
    "imbulletteremo": "imbullettare",
    "imbullettereste": "imbullettare",
    "imbulletteresti": "imbullettare",
    "imbulletterete": "imbullettare",
    "imbulletterà": "imbullettare",
    "imbulletterò": "imbullettare",
    "imbulletti": "imbullettare",
    "imbullettiamo": "imbullettare",
    "imbullettiate": "imbullettare",
    "imbullettin": "imbullettare",
    "imbullettino": "imbullettare",
    "imbulletto": "imbullettare",
    "imbullettò": "imbullettare",
    "imbullona": "imbullonare",
    "imbullonai": "imbullonare",
    "imbullonammo": "imbullonare",
    "imbullonan": "imbullonare",
    "imbullonando": "imbullonare",
    "imbullonano": "imbullonare",
    "imbullonante": "imbullonare",
    "imbullonanti": "imbullonare",
    "imbullonar": "imbullonare",
    "imbullonaron": "imbullonare",
    "imbullonarono": "imbullonare",
    "imbullonasse": "imbullonare",
    "imbullonasser": "imbullonare",
    "imbullonassero": "imbullonare",
    "imbullonassi": "imbullonare",
    "imbullonassimo": "imbullonare",
    "imbullonaste": "imbullonare",
    "imbullonasti": "imbullonare",
    "imbullonata": "imbullonare",
    "imbullonate": "imbullonare",
    "imbullonati": "imbullonare",
    "imbullonato": "imbullonare",
    "imbullonava": "imbullonare",
    "imbullonavamo": "imbullonare",
    "imbullonavan": "imbullonare",
    "imbullonavano": "imbullonare",
    "imbullonavate": "imbullonare",
    "imbullonavi": "imbullonare",
    "imbullonavo": "imbullonare",
    "imbullonerai": "imbullonare",
    "imbulloneran": "imbullonare",
    "imbulloneranno": "imbullonare",
    "imbullonerebbe": "imbullonare",
    "imbullonerebber": "imbullonare",
    "imbullonerebbero": "imbullonare",
    "imbullonerei": "imbullonare",
    "imbulloneremmo": "imbullonare",
    "imbulloneremo": "imbullonare",
    "imbullonereste": "imbullonare",
    "imbulloneresti": "imbullonare",
    "imbullonerete": "imbullonare",
    "imbullonerà": "imbullonare",
    "imbullonerò": "imbullonare",
    "imbulloni": "imbullonare",
    "imbulloniamo": "imbullonare",
    "imbulloniate": "imbullonare",
    "imbullonin": "imbullonare",
    "imbullonino": "imbullonare",
    "imbullono": "imbullonare",
    "imbullonò": "imbullonare",
    "imburra": "imburrare",
    "imburrai": "imburrare",
    "imburrammo": "imburrare",
    "imburran": "imburrare",
    "imburrando": "imburrare",
    "imburrano": "imburrare",
    "imburrante": "imburrare",
    "imburranti": "imburrare",
    "imburrar": "imburrare",
    "imburraron": "imburrare",
    "imburrarono": "imburrare",
    "imburrasse": "imburrare",
    "imburrasser": "imburrare",
    "imburrassero": "imburrare",
    "imburrassi": "imburrare",
    "imburrassimo": "imburrare",
    "imburraste": "imburrare",
    "imburrasti": "imburrare",
    "imburrata": "imburrare",
    "imburrate": "imburrare",
    "imburrati": "imburrare",
    "imburrato": "imburrare",
    "imburrava": "imburrare",
    "imburravamo": "imburrare",
    "imburravan": "imburrare",
    "imburravano": "imburrare",
    "imburravate": "imburrare",
    "imburravi": "imburrare",
    "imburravo": "imburrare",
    "imburrerai": "imburrare",
    "imburreran": "imburrare",
    "imburreranno": "imburrare",
    "imburrerebbe": "imburrare",
    "imburrerebber": "imburrare",
    "imburrerebbero": "imburrare",
    "imburrerei": "imburrare",
    "imburreremmo": "imburrare",
    "imburreremo": "imburrare",
    "imburrereste": "imburrare",
    "imburreresti": "imburrare",
    "imburrerete": "imburrare",
    "imburrerà": "imburrare",
    "imburrerò": "imburrare",
    "imburri": "imburrare",
    "imburriamo": "imburrare",
    "imburriate": "imburrare",
    "imburrin": "imburrare",
    "imburrino": "imburrare",
    "imburro": "imburrare",
    "imburrò": "imburrare",
    "imbussola": "imbussolare",
    "imbussolai": "imbussolare",
    "imbussolammo": "imbussolare",
    "imbussolan": "imbussolare",
    "imbussolando": "imbussolare",
    "imbussolano": "imbussolare",
    "imbussolante": "imbussolare",
    "imbussolanti": "imbussolare",
    "imbussolar": "imbussolare",
    "imbussolaron": "imbussolare",
    "imbussolarono": "imbussolare",
    "imbussolasse": "imbussolare",
    "imbussolasser": "imbussolare",
    "imbussolassero": "imbussolare",
    "imbussolassi": "imbussolare",
    "imbussolassimo": "imbussolare",
    "imbussolaste": "imbussolare",
    "imbussolasti": "imbussolare",
    "imbussolata": "imbussolare",
    "imbussolate": "imbussolare",
    "imbussolati": "imbussolare",
    "imbussolato": "imbussolare",
    "imbussolava": "imbussolare",
    "imbussolavamo": "imbussolare",
    "imbussolavan": "imbussolare",
    "imbussolavano": "imbussolare",
    "imbussolavate": "imbussolare",
    "imbussolavi": "imbussolare",
    "imbussolavo": "imbussolare",
    "imbussolerai": "imbussolare",
    "imbussoleran": "imbussolare",
    "imbussoleranno": "imbussolare",
    "imbussolerebbe": "imbussolare",
    "imbussolerebber": "imbussolare",
    "imbussolerebbero": "imbussolare",
    "imbussolerei": "imbussolare",
    "imbussoleremmo": "imbussolare",
    "imbussoleremo": "imbussolare",
    "imbussolereste": "imbussolare",
    "imbussoleresti": "imbussolare",
    "imbussolerete": "imbussolare",
    "imbussolerà": "imbussolare",
    "imbussolerò": "imbussolare",
    "imbussoli": "imbussolare",
    "imbussoliamo": "imbussolare",
    "imbussoliate": "imbussolare",
    "imbussolin": "imbussolare",
    "imbussolino": "imbussolare",
    "imbussolo": "imbussolare",
    "imbussolò": "imbussolare",
    "imbuti": "imbuto",
    "ime": "imo",
    "imi": "imo",
    "imita": "imitare",
    "imitabili": "imitabile",
    "imitai": "imitare",
    "imitammo": "imitare",
    "imitan": "imitare",
    "imitando": "imitare",
    "imitano": "imitare",
    "imitante": "imitare",
    "imitanti": "imitare",
    "imitar": "imitare",
    "imitaron": "imitare",
    "imitarono": "imitare",
    "imitasse": "imitare",
    "imitasser": "imitare",
    "imitassero": "imitare",
    "imitassi": "imitare",
    "imitassimo": "imitare",
    "imitaste": "imitare",
    "imitasti": "imitare",
    "imitata": "imitare",
    "imitate": "imitare",
    "imitati": "imitare",
    "imitativa": "imitativo",
    "imitative": "imitativo",
    "imitativi": "imitativo",
    "imitato": "imitare",
    "imitatori": "imitatore",
    "imitava": "imitare",
    "imitavamo": "imitare",
    "imitavan": "imitare",
    "imitavano": "imitare",
    "imitavate": "imitare",
    "imitavi": "imitare",
    "imitavo": "imitare",
    "imitazioni": "imitazione",
    "imiterai": "imitare",
    "imiteran": "imitare",
    "imiteranno": "imitare",
    "imiterebbe": "imitare",
    "imiterebber": "imitare",
    "imiterebbero": "imitare",
    "imiterei": "imitare",
    "imiteremmo": "imitare",
    "imiteremo": "imitare",
    "imitereste": "imitare",
    "imiteresti": "imitare",
    "imiterete": "imitare",
    "imiterà": "imitare",
    "imiterò": "imitare",
    "imiti": "imitare",
    "imitiamo": "imitare",
    "imitiate": "imitare",
    "imitin": "imitare",
    "imitino": "imitare",
    "imito": "imitare",
    "imitò": "imitare",
    "immacolata": "immacolato",
    "immacolate": "immacolato",
    "immacolati": "immacolato",
    "immagazzina": "immagazzinare",
    "immagazzinai": "immagazzinare",
    "immagazzinammo": "immagazzinare",
    "immagazzinan": "immagazzinare",
    "immagazzinando": "immagazzinare",
    "immagazzinano": "immagazzinare",
    "immagazzinante": "immagazzinare",
    "immagazzinanti": "immagazzinare",
    "immagazzinar": "immagazzinare",
    "immagazzinaron": "immagazzinare",
    "immagazzinarono": "immagazzinare",
    "immagazzinasse": "immagazzinare",
    "immagazzinasser": "immagazzinare",
    "immagazzinassero": "immagazzinare",
    "immagazzinassi": "immagazzinare",
    "immagazzinassimo": "immagazzinare",
    "immagazzinaste": "immagazzinare",
    "immagazzinasti": "immagazzinare",
    "immagazzinata": "immagazzinare",
    "immagazzinate": "immagazzinare",
    "immagazzinati": "immagazzinare",
    "immagazzinato": "immagazzinare",
    "immagazzinava": "immagazzinare",
    "immagazzinavamo": "immagazzinare",
    "immagazzinavan": "immagazzinare",
    "immagazzinavano": "immagazzinare",
    "immagazzinavate": "immagazzinare",
    "immagazzinavi": "immagazzinare",
    "immagazzinavo": "immagazzinare",
    "immagazzinerai": "immagazzinare",
    "immagazzineran": "immagazzinare",
    "immagazzineranno": "immagazzinare",
    "immagazzinerebbe": "immagazzinare",
    "immagazzinerebber": "immagazzinare",
    "immagazzinerebbero": "immagazzinare",
    "immagazzinerei": "immagazzinare",
    "immagazzineremmo": "immagazzinare",
    "immagazzineremo": "immagazzinare",
    "immagazzinereste": "immagazzinare",
    "immagazzineresti": "immagazzinare",
    "immagazzinerete": "immagazzinare",
    "immagazzinerà": "immagazzinare",
    "immagazzinerò": "immagazzinare",
    "immagazzini": "immagazzinare",
    "immagazziniamo": "immagazzinare",
    "immagazziniate": "immagazzinare",
    "immagazzinin": "immagazzinare",
    "immagazzinino": "immagazzinare",
    "immagazzino": "immagazzinare",
    "immagazzinò": "immagazzinare",
    "immagina": "immaginare",
    "immaginabili": "immaginabile",
    "immaginai": "immaginare",
    "immaginammo": "immaginare",
    "immaginan": "immaginare",
    "immaginando": "immaginare",
    "immaginano": "immaginare",
    "immaginante": "immaginare",
    "immaginanti": "immaginare",
    "immaginar": "immaginare",
    "immaginari": "immaginario",
    "immaginaria": "immaginario",
    "immaginarie": "immaginario",
    "immaginaron": "immaginare",
    "immaginarono": "immaginare",
    "immaginasse": "immaginare",
    "immaginasser": "immaginare",
    "immaginassero": "immaginare",
    "immaginassi": "immaginare",
    "immaginassimo": "immaginare",
    "immaginaste": "immaginare",
    "immaginasti": "immaginare",
    "immaginata": "immaginare",
    "immaginate": "immaginare",
    "immaginati": "immaginare",
    "immaginativa": "immaginativo",
    "immaginative": "immaginativo",
    "immaginativi": "immaginativo",
    "immaginato": "immaginare",
    "immaginava": "immaginare",
    "immaginavamo": "immaginare",
    "immaginavan": "immaginare",
    "immaginavano": "immaginare",
    "immaginavate": "immaginare",
    "immaginavi": "immaginare",
    "immaginavo": "immaginare",
    "immaginazioni": "immaginazione",
    "immaginerai": "immaginare",
    "immagineran": "immaginare",
    "immagineranno": "immaginare",
    "immaginerebbe": "immaginare",
    "immaginerebber": "immaginare",
    "immaginerebbero": "immaginare",
    "immaginerei": "immaginare",
    "immagineremmo": "immaginare",
    "immagineremo": "immaginare",
    "immaginereste": "immaginare",
    "immagineresti": "immaginare",
    "immaginerete": "immaginare",
    "immaginerà": "immaginare",
    "immaginerò": "immaginare",
    "immaginette": "immaginetta",
    "immagini": "immagine",
    "immaginiamo": "immaginare",
    "immaginiate": "immaginare",
    "immaginifica": "immaginifico",
    "immaginifiche": "immaginifico",
    "immaginifici": "immaginifico",
    "immaginin": "immaginare",
    "immaginino": "immaginare",
    "immagino": "immaginare",
    "immaginosa": "immaginoso",
    "immaginose": "immaginoso",
    "immaginosi": "immaginoso",
    "immaginò": "immaginare",
    "immalinconendo": "immalinconire",
    "immalinconente": "immalinconire",
    "immalinconenti": "immalinconire",
    "immalinconiamo": "immalinconire",
    "immalinconiate": "immalinconire",
    "immalinconii": "immalinconire",
    "immalinconimmo": "immalinconire",
    "immalinconir": "immalinconire",
    "immalinconirai": "immalinconire",
    "immalinconiran": "immalinconire",
    "immalinconiranno": "immalinconire",
    "immalinconirebbe": "immalinconire",
    "immalinconirebber": "immalinconire",
    "immalinconirebbero": "immalinconire",
    "immalinconirei": "immalinconire",
    "immalinconiremmo": "immalinconire",
    "immalinconiremo": "immalinconire",
    "immalinconireste": "immalinconire",
    "immalinconiresti": "immalinconire",
    "immalinconirete": "immalinconire",
    "immalinconiron": "immalinconire",
    "immalinconirono": "immalinconire",
    "immalinconirà": "immalinconire",
    "immalinconirò": "immalinconire",
    "immalinconisca": "immalinconire",
    "immalinconiscan": "immalinconire",
    "immalinconiscano": "immalinconire",
    "immalinconisce": "immalinconire",
    "immalinconisci": "immalinconire",
    "immalinconisco": "immalinconire",
    "immalinconiscon": "immalinconire",
    "immalinconiscono": "immalinconire",
    "immalinconisse": "immalinconire",
    "immalinconisser": "immalinconire",
    "immalinconissero": "immalinconire",
    "immalinconissi": "immalinconire",
    "immalinconissimo": "immalinconire",
    "immalinconiste": "immalinconire",
    "immalinconisti": "immalinconire",
    "immalinconita": "immalinconire",
    "immalinconite": "immalinconire",
    "immalinconiti": "immalinconire",
    "immalinconito": "immalinconire",
    "immalinconiva": "immalinconire",
    "immalinconivamo": "immalinconire",
    "immalinconivan": "immalinconire",
    "immalinconivano": "immalinconire",
    "immalinconivate": "immalinconire",
    "immalinconivi": "immalinconire",
    "immalinconivo": "immalinconire",
    "immalinconì": "immalinconire",
    "immancabili": "immancabile",
    "immanenti": "immanente",
    "immangiabili": "immangiabile",
    "immani": "immane",
    "immarcescibili": "immarcescibile",
    "immateriali": "immateriale",
    "immatricola": "immatricolare",
    "immatricolai": "immatricolare",
    "immatricolammo": "immatricolare",
    "immatricolan": "immatricolare",
    "immatricolando": "immatricolare",
    "immatricolano": "immatricolare",
    "immatricolante": "immatricolare",
    "immatricolanti": "immatricolare",
    "immatricolar": "immatricolare",
    "immatricolaron": "immatricolare",
    "immatricolarono": "immatricolare",
    "immatricolasse": "immatricolare",
    "immatricolasser": "immatricolare",
    "immatricolassero": "immatricolare",
    "immatricolassi": "immatricolare",
    "immatricolassimo": "immatricolare",
    "immatricolaste": "immatricolare",
    "immatricolasti": "immatricolare",
    "immatricolata": "immatricolare",
    "immatricolate": "immatricolare",
    "immatricolati": "immatricolare",
    "immatricolato": "immatricolare",
    "immatricolava": "immatricolare",
    "immatricolavamo": "immatricolare",
    "immatricolavan": "immatricolare",
    "immatricolavano": "immatricolare",
    "immatricolavate": "immatricolare",
    "immatricolavi": "immatricolare",
    "immatricolavo": "immatricolare",
    "immatricolazioni": "immatricolazione",
    "immatricolerai": "immatricolare",
    "immatricoleran": "immatricolare",
    "immatricoleranno": "immatricolare",
    "immatricolerebbe": "immatricolare",
    "immatricolerebber": "immatricolare",
    "immatricolerebbero": "immatricolare",
    "immatricolerei": "immatricolare",
    "immatricoleremmo": "immatricolare",
    "immatricoleremo": "immatricolare",
    "immatricolereste": "immatricolare",
    "immatricoleresti": "immatricolare",
    "immatricolerete": "immatricolare",
    "immatricolerà": "immatricolare",
    "immatricolerò": "immatricolare",
    "immatricoli": "immatricolare",
    "immatricoliamo": "immatricolare",
    "immatricoliate": "immatricolare",
    "immatricolin": "immatricolare",
    "immatricolino": "immatricolare",
    "immatricolo": "immatricolare",
    "immatricolò": "immatricolare",
    "immatura": "immaturo",
    "immature": "immaturo",
    "immaturi": "immaturo",
    "immedesima": "immedesimare",
    "immedesimai": "immedesimare",
    "immedesimammo": "immedesimare",
    "immedesiman": "immedesimare",
    "immedesimando": "immedesimare",
    "immedesimano": "immedesimare",
    "immedesimante": "immedesimare",
    "immedesimanti": "immedesimare",
    "immedesimar": "immedesimare",
    "immedesimaron": "immedesimare",
    "immedesimarono": "immedesimare",
    "immedesimasse": "immedesimare",
    "immedesimasser": "immedesimare",
    "immedesimassero": "immedesimare",
    "immedesimassi": "immedesimare",
    "immedesimassimo": "immedesimare",
    "immedesimaste": "immedesimare",
    "immedesimasti": "immedesimare",
    "immedesimata": "immedesimare",
    "immedesimate": "immedesimare",
    "immedesimati": "immedesimare",
    "immedesimato": "immedesimare",
    "immedesimava": "immedesimare",
    "immedesimavamo": "immedesimare",
    "immedesimavan": "immedesimare",
    "immedesimavano": "immedesimare",
    "immedesimavate": "immedesimare",
    "immedesimavi": "immedesimare",
    "immedesimavo": "immedesimare",
    "immedesimazioni": "immedesimazione",
    "immedesimerai": "immedesimare",
    "immedesimeran": "immedesimare",
    "immedesimeranno": "immedesimare",
    "immedesimerebbe": "immedesimare",
    "immedesimerebber": "immedesimare",
    "immedesimerebbero": "immedesimare",
    "immedesimerei": "immedesimare",
    "immedesimeremmo": "immedesimare",
    "immedesimeremo": "immedesimare",
    "immedesimereste": "immedesimare",
    "immedesimeresti": "immedesimare",
    "immedesimerete": "immedesimare",
    "immedesimerà": "immedesimare",
    "immedesimerò": "immedesimare",
    "immedesimi": "immedesimare",
    "immedesimiamo": "immedesimare",
    "immedesimiate": "immedesimare",
    "immedesimin": "immedesimare",
    "immedesimino": "immedesimare",
    "immedesimo": "immedesimare",
    "immedesimò": "immedesimare",
    "immediata": "immediato",
    "immediate": "immediato",
    "immediati": "immediato",
    "immemorabili": "immemorabile",
    "immemori": "immemore",
    "immensa": "immenso",
    "immense": "immenso",
    "immensi": "immenso",
    "immerga": "immergere",
    "immergan": "immergere",
    "immergano": "immergere",
    "immerge": "immergere",
    "immergemmo": "immergere",
    "immergendo": "immergere",
    "immergente": "immergere",
    "immergenti": "immergere",
    "immerger": "immergere",
    "immergerai": "immergere",
    "immergeran": "immergere",
    "immergeranno": "immergere",
    "immergerebbe": "immergere",
    "immergerebber": "immergere",
    "immergerebbero": "immergere",
    "immergerei": "immergere",
    "immergeremmo": "immergere",
    "immergeremo": "immergere",
    "immergereste": "immergere",
    "immergeresti": "immergere",
    "immergerete": "immergere",
    "immergerà": "immergere",
    "immergerò": "immergere",
    "immergesse": "immergere",
    "immergesser": "immergere",
    "immergessero": "immergere",
    "immergessi": "immergere",
    "immergessimo": "immergere",
    "immergeste": "immergere",
    "immergesti": "immergere",
    "immergete": "immergere",
    "immergeva": "immergere",
    "immergevamo": "immergere",
    "immergevan": "immergere",
    "immergevano": "immergere",
    "immergevate": "immergere",
    "immergevi": "immergere",
    "immergevo": "immergere",
    "immergi": "immergere",
    "immergiamo": "immergere",
    "immergiate": "immergere",
    "immergo": "immergere",
    "immergon": "immergere",
    "immergono": "immergere",
    "immeritata": "immeritato",
    "immeritate": "immeritato",
    "immeritati": "immeritato",
    "immersa": "immerso",
    "immerse": "immerso",
    "immerser": "immergere",
    "immersero": "immergere",
    "immersi": "immerso",
    "immersioni": "immersione",
    "immerso": "immergere",
    "immessa": "immettere",
    "immesse": "immettere",
    "immessi": "immettere",
    "immesso": "immettere",
    "immetta": "immettere",
    "immettan": "immettere",
    "immettano": "immettere",
    "immette": "immettere",
    "immettemmo": "immettere",
    "immettendo": "immettere",
    "immettente": "immettere",
    "immettenti": "immettere",
    "immetter": "immettere",
    "immetterai": "immettere",
    "immetteran": "immettere",
    "immetteranno": "immettere",
    "immetterebbe": "immettere",
    "immetterebber": "immettere",
    "immetterebbero": "immettere",
    "immetterei": "immettere",
    "immetteremmo": "immettere",
    "immetteremo": "immettere",
    "immettereste": "immettere",
    "immetteresti": "immettere",
    "immetterete": "immettere",
    "immetterà": "immettere",
    "immetterò": "immettere",
    "immettesse": "immettere",
    "immettesser": "immettere",
    "immettessero": "immettere",
    "immettessi": "immettere",
    "immettessimo": "immettere",
    "immetteste": "immettere",
    "immettesti": "immettere",
    "immettete": "immettere",
    "immetteva": "immettere",
    "immettevamo": "immettere",
    "immettevan": "immettere",
    "immettevano": "immettere",
    "immettevate": "immettere",
    "immettevi": "immettere",
    "immettevo": "immettere",
    "immetti": "immettere",
    "immettiamo": "immettere",
    "immettiate": "immettere",
    "immetto": "immettere",
    "immetton": "immettere",
    "immettono": "immettere",
    "immigra": "immigrare",
    "immigrai": "immigrare",
    "immigrammo": "immigrare",
    "immigran": "immigrare",
    "immigrando": "immigrare",
    "immigrano": "immigrare",
    "immigrante": "immigrare",
    "immigranti": "immigrare",
    "immigrar": "immigrare",
    "immigraron": "immigrare",
    "immigrarono": "immigrare",
    "immigrasse": "immigrare",
    "immigrasser": "immigrare",
    "immigrassero": "immigrare",
    "immigrassi": "immigrare",
    "immigrassimo": "immigrare",
    "immigraste": "immigrare",
    "immigrasti": "immigrare",
    "immigrata": "immigrato",
    "immigrate": "immigrato",
    "immigrati": "immigrato",
    "immigrato": "immigrare",
    "immigratori": "immigratorio",
    "immigratoria": "immigratorio",
    "immigratorie": "immigratorio",
    "immigrava": "immigrare",
    "immigravamo": "immigrare",
    "immigravan": "immigrare",
    "immigravano": "immigrare",
    "immigravate": "immigrare",
    "immigravi": "immigrare",
    "immigravo": "immigrare",
    "immigrazioni": "immigrazione",
    "immigrerai": "immigrare",
    "immigreran": "immigrare",
    "immigreranno": "immigrare",
    "immigrerebbe": "immigrare",
    "immigrerebber": "immigrare",
    "immigrerebbero": "immigrare",
    "immigrerei": "immigrare",
    "immigreremmo": "immigrare",
    "immigreremo": "immigrare",
    "immigrereste": "immigrare",
    "immigreresti": "immigrare",
    "immigrerete": "immigrare",
    "immigrerà": "immigrare",
    "immigrerò": "immigrare",
    "immigri": "immigrare",
    "immigriamo": "immigrare",
    "immigriate": "immigrare",
    "immigrin": "immigrare",
    "immigrino": "immigrare",
    "immigro": "immigrare",
    "immigrò": "immigrare",
    "imminenti": "imminente",
    "immischi": "immischiare",
    "immischia": "immischiare",
    "immischiai": "immischiare",
    "immischiammo": "immischiare",
    "immischiamo": "immischiare",
    "immischian": "immischiare",
    "immischiando": "immischiare",
    "immischiano": "immischiare",
    "immischiante": "immischiare",
    "immischianti": "immischiare",
    "immischiar": "immischiare",
    "immischiaron": "immischiare",
    "immischiarono": "immischiare",
    "immischiasse": "immischiare",
    "immischiasser": "immischiare",
    "immischiassero": "immischiare",
    "immischiassi": "immischiare",
    "immischiassimo": "immischiare",
    "immischiaste": "immischiare",
    "immischiasti": "immischiare",
    "immischiata": "immischiare",
    "immischiate": "immischiare",
    "immischiati": "immischiare",
    "immischiato": "immischiare",
    "immischiava": "immischiare",
    "immischiavamo": "immischiare",
    "immischiavan": "immischiare",
    "immischiavano": "immischiare",
    "immischiavate": "immischiare",
    "immischiavi": "immischiare",
    "immischiavo": "immischiare",
    "immischierai": "immischiare",
    "immischieran": "immischiare",
    "immischieranno": "immischiare",
    "immischierebbe": "immischiare",
    "immischierebber": "immischiare",
    "immischierebbero": "immischiare",
    "immischierei": "immischiare",
    "immischieremmo": "immischiare",
    "immischieremo": "immischiare",
    "immischiereste": "immischiare",
    "immischieresti": "immischiare",
    "immischierete": "immischiare",
    "immischierà": "immischiare",
    "immischierò": "immischiare",
    "immischin": "immischiare",
    "immischino": "immischiare",
    "immischio": "immischiare",
    "immischiò": "immischiare",
    "immise": "immettere",
    "immiser": "immettere",
    "immiserendo": "immiserire",
    "immiserente": "immiserire",
    "immiserenti": "immiserire",
    "immiseriamo": "immiserire",
    "immiseriate": "immiserire",
    "immiserii": "immiserire",
    "immiserimmo": "immiserire",
    "immiserir": "immiserire",
    "immiserirai": "immiserire",
    "immiseriran": "immiserire",
    "immiseriranno": "immiserire",
    "immiserirebbe": "immiserire",
    "immiserirebber": "immiserire",
    "immiserirebbero": "immiserire",
    "immiserirei": "immiserire",
    "immiseriremmo": "immiserire",
    "immiseriremo": "immiserire",
    "immiserireste": "immiserire",
    "immiseriresti": "immiserire",
    "immiserirete": "immiserire",
    "immiseriron": "immiserire",
    "immiserirono": "immiserire",
    "immiserirà": "immiserire",
    "immiserirò": "immiserire",
    "immiserisca": "immiserire",
    "immiseriscan": "immiserire",
    "immiseriscano": "immiserire",
    "immiserisce": "immiserire",
    "immiserisci": "immiserire",
    "immiserisco": "immiserire",
    "immiseriscon": "immiserire",
    "immiseriscono": "immiserire",
    "immiserisse": "immiserire",
    "immiserisser": "immiserire",
    "immiserissero": "immiserire",
    "immiserissi": "immiserire",
    "immiserissimo": "immiserire",
    "immiseriste": "immiserire",
    "immiseristi": "immiserire",
    "immiserita": "immiserire",
    "immiserite": "immiserire",
    "immiseriti": "immiserire",
    "immiserito": "immiserire",
    "immiseriva": "immiserire",
    "immiserivamo": "immiserire",
    "immiserivan": "immiserire",
    "immiserivano": "immiserire",
    "immiserivate": "immiserire",
    "immiserivi": "immiserire",
    "immiserivo": "immiserire",
    "immisero": "immettere",
    "immiserì": "immiserire",
    "immisi": "immettere",
    "immissioni": "immissione",
    "immobili": "immobile",
    "immobiliari": "immobiliare",
    "immobiliaristi": "immobiliarista",
    "immobilismi": "immobilismo",
    "immobilistica": "immobilistico",
    "immobilistiche": "immobilistico",
    "immobilistici": "immobilistico",
    "immobilizza": "immobilizzare",
    "immobilizzai": "immobilizzare",
    "immobilizzammo": "immobilizzare",
    "immobilizzan": "immobilizzare",
    "immobilizzando": "immobilizzare",
    "immobilizzano": "immobilizzare",
    "immobilizzante": "immobilizzare",
    "immobilizzanti": "immobilizzare",
    "immobilizzar": "immobilizzare",
    "immobilizzaron": "immobilizzare",
    "immobilizzarono": "immobilizzare",
    "immobilizzasse": "immobilizzare",
    "immobilizzasser": "immobilizzare",
    "immobilizzassero": "immobilizzare",
    "immobilizzassi": "immobilizzare",
    "immobilizzassimo": "immobilizzare",
    "immobilizzaste": "immobilizzare",
    "immobilizzasti": "immobilizzare",
    "immobilizzata": "immobilizzare",
    "immobilizzate": "immobilizzare",
    "immobilizzati": "immobilizzare",
    "immobilizzato": "immobilizzare",
    "immobilizzava": "immobilizzare",
    "immobilizzavamo": "immobilizzare",
    "immobilizzavan": "immobilizzare",
    "immobilizzavano": "immobilizzare",
    "immobilizzavate": "immobilizzare",
    "immobilizzavi": "immobilizzare",
    "immobilizzavo": "immobilizzare",
    "immobilizzazioni": "immobilizzazione",
    "immobilizzerai": "immobilizzare",
    "immobilizzeran": "immobilizzare",
    "immobilizzeranno": "immobilizzare",
    "immobilizzerebbe": "immobilizzare",
    "immobilizzerebber": "immobilizzare",
    "immobilizzerebbero": "immobilizzare",
    "immobilizzerei": "immobilizzare",
    "immobilizzeremmo": "immobilizzare",
    "immobilizzeremo": "immobilizzare",
    "immobilizzereste": "immobilizzare",
    "immobilizzeresti": "immobilizzare",
    "immobilizzerete": "immobilizzare",
    "immobilizzerà": "immobilizzare",
    "immobilizzerò": "immobilizzare",
    "immobilizzi": "immobilizzo",
    "immobilizziamo": "immobilizzare",
    "immobilizziate": "immobilizzare",
    "immobilizzin": "immobilizzare",
    "immobilizzino": "immobilizzare",
    "immobilizzo": "immobilizzare",
    "immobilizzò": "immobilizzare",
    "immodesta": "immodesto",
    "immodeste": "immodesto",
    "immodesti": "immodesto",
    "immola": "immolare",
    "immolai": "immolare",
    "immolammo": "immolare",
    "immolan": "immolare",
    "immolando": "immolare",
    "immolano": "immolare",
    "immolante": "immolare",
    "immolanti": "immolare",
    "immolar": "immolare",
    "immolaron": "immolare",
    "immolarono": "immolare",
    "immolasse": "immolare",
    "immolasser": "immolare",
    "immolassero": "immolare",
    "immolassi": "immolare",
    "immolassimo": "immolare",
    "immolaste": "immolare",
    "immolasti": "immolare",
    "immolata": "immolare",
    "immolate": "immolare",
    "immolati": "immolare",
    "immolato": "immolare",
    "immolava": "immolare",
    "immolavamo": "immolare",
    "immolavan": "immolare",
    "immolavano": "immolare",
    "immolavate": "immolare",
    "immolavi": "immolare",
    "immolavo": "immolare",
    "immolerai": "immolare",
    "immoleran": "immolare",
    "immoleranno": "immolare",
    "immolerebbe": "immolare",
    "immolerebber": "immolare",
    "immolerebbero": "immolare",
    "immolerei": "immolare",
    "immoleremmo": "immolare",
    "immoleremo": "immolare",
    "immolereste": "immolare",
    "immoleresti": "immolare",
    "immolerete": "immolare",
    "immolerà": "immolare",
    "immolerò": "immolare",
    "immoli": "immolare",
    "immoliamo": "immolare",
    "immoliate": "immolare",
    "immolin": "immolare",
    "immolino": "immolare",
    "immolo": "immolare",
    "immolò": "immolare",
    "immonda": "immondo",
    "immonde": "immondo",
    "immondezzai": "immondezzaio",
    "immondi": "immondo",
    "immondizie": "immondizia",
    "immorali": "immorale",
    "immortala": "immortalare",
    "immortalai": "immortalare",
    "immortalammo": "immortalare",
    "immortalan": "immortalare",
    "immortalando": "immortalare",
    "immortalano": "immortalare",
    "immortalante": "immortalare",
    "immortalanti": "immortalare",
    "immortalar": "immortalare",
    "immortalaron": "immortalare",
    "immortalarono": "immortalare",
    "immortalasse": "immortalare",
    "immortalasser": "immortalare",
    "immortalassero": "immortalare",
    "immortalassi": "immortalare",
    "immortalassimo": "immortalare",
    "immortalaste": "immortalare",
    "immortalasti": "immortalare",
    "immortalata": "immortalare",
    "immortalate": "immortalare",
    "immortalati": "immortalare",
    "immortalato": "immortalare",
    "immortalava": "immortalare",
    "immortalavamo": "immortalare",
    "immortalavan": "immortalare",
    "immortalavano": "immortalare",
    "immortalavate": "immortalare",
    "immortalavi": "immortalare",
    "immortalavo": "immortalare",
    "immortalerai": "immortalare",
    "immortaleran": "immortalare",
    "immortaleranno": "immortalare",
    "immortalerebbe": "immortalare",
    "immortalerebber": "immortalare",
    "immortalerebbero": "immortalare",
    "immortalerei": "immortalare",
    "immortaleremmo": "immortalare",
    "immortaleremo": "immortalare",
    "immortalereste": "immortalare",
    "immortaleresti": "immortalare",
    "immortalerete": "immortalare",
    "immortalerà": "immortalare",
    "immortalerò": "immortalare",
    "immortali": "immortale",
    "immortaliamo": "immortalare",
    "immortaliate": "immortalare",
    "immortalin": "immortalare",
    "immortalino": "immortalare",
    "immortalo": "immortalare",
    "immortalò": "immortalare",
    "immota": "immoto",
    "immote": "immoto",
    "immoti": "immoto",
    "immotivata": "immotivato",
    "immotivate": "immotivato",
    "immotivati": "immotivato",
    "immuni": "immune",
    "immunitari": "immunitario",
    "immunitaria": "immunitario",
    "immunitarie": "immunitario",
    "immunizza": "immunizzare",
    "immunizzai": "immunizzare",
    "immunizzammo": "immunizzare",
    "immunizzan": "immunizzare",
    "immunizzando": "immunizzare",
    "immunizzano": "immunizzare",
    "immunizzante": "immunizzare",
    "immunizzanti": "immunizzare",
    "immunizzar": "immunizzare",
    "immunizzaron": "immunizzare",
    "immunizzarono": "immunizzare",
    "immunizzasse": "immunizzare",
    "immunizzasser": "immunizzare",
    "immunizzassero": "immunizzare",
    "immunizzassi": "immunizzare",
    "immunizzassimo": "immunizzare",
    "immunizzaste": "immunizzare",
    "immunizzasti": "immunizzare",
    "immunizzata": "immunizzare",
    "immunizzate": "immunizzare",
    "immunizzati": "immunizzare",
    "immunizzato": "immunizzare",
    "immunizzava": "immunizzare",
    "immunizzavamo": "immunizzare",
    "immunizzavan": "immunizzare",
    "immunizzavano": "immunizzare",
    "immunizzavate": "immunizzare",
    "immunizzavi": "immunizzare",
    "immunizzavo": "immunizzare",
    "immunizzerai": "immunizzare",
    "immunizzeran": "immunizzare",
    "immunizzeranno": "immunizzare",
    "immunizzerebbe": "immunizzare",
    "immunizzerebber": "immunizzare",
    "immunizzerebbero": "immunizzare",
    "immunizzerei": "immunizzare",
    "immunizzeremmo": "immunizzare",
    "immunizzeremo": "immunizzare",
    "immunizzereste": "immunizzare",
    "immunizzeresti": "immunizzare",
    "immunizzerete": "immunizzare",
    "immunizzerà": "immunizzare",
    "immunizzerò": "immunizzare",
    "immunizzi": "immunizzare",
    "immunizziamo": "immunizzare",
    "immunizziate": "immunizzare",
    "immunizzin": "immunizzare",
    "immunizzino": "immunizzare",
    "immunizzo": "immunizzare",
    "immunizzò": "immunizzare",
    "immunodeficienze": "immunodeficienza",
    "immunologi": "immunologo",
    "immunologica": "immunologico",
    "immunologiche": "immunologico",
    "immunologici": "immunologico",
    "immunostimolanti": "immunostimolante",
    "immusona": "immusonire",
    "immusonan": "immusonire",
    "immusonano": "immusonire",
    "immusone": "immusonire",
    "immusonendo": "immusonire",
    "immusoni": "immusonire",
    "immusoniamo": "immusonire",
    "immusoniate": "immusonire",
    "immusonii": "immusonire",
    "immusonimmo": "immusonire",
    "immusonir": "immusonire",
    "immusonirai": "immusonire",
    "immusoniran": "immusonire",
    "immusoniranno": "immusonire",
    "immusonirebbe": "immusonire",
    "immusonirebber": "immusonire",
    "immusonirebbero": "immusonire",
    "immusonirei": "immusonire",
    "immusoniremmo": "immusonire",
    "immusoniremo": "immusonire",
    "immusonireste": "immusonire",
    "immusoniresti": "immusonire",
    "immusonirete": "immusonire",
    "immusoniron": "immusonire",
    "immusonirono": "immusonire",
    "immusonirà": "immusonire",
    "immusonirò": "immusonire",
    "immusonisse": "immusonire",
    "immusonisser": "immusonire",
    "immusonissero": "immusonire",
    "immusonissi": "immusonire",
    "immusonissimo": "immusonire",
    "immusoniste": "immusonire",
    "immusonisti": "immusonire",
    "immusonita": "immusonire",
    "immusonite": "immusonire",
    "immusoniti": "immusonire",
    "immusonito": "immusonire",
    "immusoniva": "immusonire",
    "immusonivamo": "immusonire",
    "immusonivan": "immusonire",
    "immusonivano": "immusonire",
    "immusonivate": "immusonire",
    "immusonivi": "immusonire",
    "immusonivo": "immusonire",
    "immusono": "immusonire",
    "immusonon": "immusonire",
    "immusonono": "immusonire",
    "immusonì": "immusonire",
    "immutabili": "immutabile",
    "immutata": "immutato",
    "immutate": "immutato",
    "immutati": "immutato",
    "impacca": "impaccare",
    "impaccai": "impaccare",
    "impaccammo": "impaccare",
    "impaccan": "impaccare",
    "impaccando": "impaccare",
    "impaccano": "impaccare",
    "impaccante": "impaccare",
    "impaccanti": "impaccare",
    "impaccar": "impaccare",
    "impaccaron": "impaccare",
    "impaccarono": "impaccare",
    "impaccasse": "impaccare",
    "impaccasser": "impaccare",
    "impaccassero": "impaccare",
    "impaccassi": "impaccare",
    "impaccassimo": "impaccare",
    "impaccaste": "impaccare",
    "impaccasti": "impaccare",
    "impaccata": "impaccare",
    "impaccate": "impaccare",
    "impaccati": "impaccare",
    "impaccato": "impaccare",
    "impaccava": "impaccare",
    "impaccavamo": "impaccare",
    "impaccavan": "impaccare",
    "impaccavano": "impaccare",
    "impaccavate": "impaccare",
    "impaccavi": "impaccare",
    "impaccavo": "impaccare",
    "impaccerai": "impacciare",
    "impacceran": "impacciare",
    "impacceranno": "impacciare",
    "impaccerebbe": "impacciare",
    "impaccerebber": "impacciare",
    "impaccerebbero": "impacciare",
    "impaccerei": "impacciare",
    "impacceremmo": "impacciare",
    "impacceremo": "impacciare",
    "impaccereste": "impacciare",
    "impacceresti": "impacciare",
    "impaccerete": "impacciare",
    "impaccerà": "impacciare",
    "impaccerò": "impacciare",
    "impaccherai": "impaccare",
    "impaccheran": "impaccare",
    "impaccheranno": "impaccare",
    "impaccherebbe": "impaccare",
    "impaccherebber": "impaccare",
    "impaccherebbero": "impaccare",
    "impaccherei": "impaccare",
    "impaccheremmo": "impaccare",
    "impaccheremo": "impaccare",
    "impacchereste": "impaccare",
    "impaccheresti": "impaccare",
    "impaccherete": "impaccare",
    "impaccherà": "impaccare",
    "impaccherò": "impaccare",
    "impacchetta": "impacchettare",
    "impacchettai": "impacchettare",
    "impacchettammo": "impacchettare",
    "impacchettan": "impacchettare",
    "impacchettando": "impacchettare",
    "impacchettano": "impacchettare",
    "impacchettante": "impacchettare",
    "impacchettanti": "impacchettare",
    "impacchettar": "impacchettare",
    "impacchettaron": "impacchettare",
    "impacchettarono": "impacchettare",
    "impacchettasse": "impacchettare",
    "impacchettasser": "impacchettare",
    "impacchettassero": "impacchettare",
    "impacchettassi": "impacchettare",
    "impacchettassimo": "impacchettare",
    "impacchettaste": "impacchettare",
    "impacchettasti": "impacchettare",
    "impacchettata": "impacchettare",
    "impacchettate": "impacchettare",
    "impacchettati": "impacchettare",
    "impacchettato": "impacchettare",
    "impacchettava": "impacchettare",
    "impacchettavamo": "impacchettare",
    "impacchettavan": "impacchettare",
    "impacchettavano": "impacchettare",
    "impacchettavate": "impacchettare",
    "impacchettavi": "impacchettare",
    "impacchettavo": "impacchettare",
    "impacchetterai": "impacchettare",
    "impacchetteran": "impacchettare",
    "impacchetteranno": "impacchettare",
    "impacchetterebbe": "impacchettare",
    "impacchetterebber": "impacchettare",
    "impacchetterebbero": "impacchettare",
    "impacchetterei": "impacchettare",
    "impacchetteremmo": "impacchettare",
    "impacchetteremo": "impacchettare",
    "impacchettereste": "impacchettare",
    "impacchetteresti": "impacchettare",
    "impacchetterete": "impacchettare",
    "impacchetterà": "impacchettare",
    "impacchetterò": "impacchettare",
    "impacchetti": "impacchettare",
    "impacchettiamo": "impacchettare",
    "impacchettiate": "impacchettare",
    "impacchettin": "impacchettare",
    "impacchettino": "impacchettare",
    "impacchetto": "impacchettare",
    "impacchettò": "impacchettare",
    "impacchi": "impacco",
    "impacchiamo": "impaccare",
    "impacchiate": "impaccare",
    "impacchin": "impaccare",
    "impacchino": "impaccare",
    "impacci": "impaccio",
    "impaccia": "impacciare",
    "impacciai": "impacciare",
    "impacciammo": "impacciare",
    "impacciamo": "impacciare",
    "impaccian": "impacciare",
    "impacciando": "impacciare",
    "impacciano": "impacciare",
    "impacciante": "impacciare",
    "impaccianti": "impacciare",
    "impacciar": "impacciare",
    "impacciaron": "impacciare",
    "impacciarono": "impacciare",
    "impacciasse": "impacciare",
    "impacciasser": "impacciare",
    "impacciassero": "impacciare",
    "impacciassi": "impacciare",
    "impacciassimo": "impacciare",
    "impacciaste": "impacciare",
    "impacciasti": "impacciare",
    "impacciata": "impacciare",
    "impacciate": "impacciare",
    "impacciati": "impacciare",
    "impacciato": "impacciare",
    "impacciava": "impacciare",
    "impacciavamo": "impacciare",
    "impacciavan": "impacciare",
    "impacciavano": "impacciare",
    "impacciavate": "impacciare",
    "impacciavi": "impacciare",
    "impacciavo": "impacciare",
    "impaccin": "impacciare",
    "impaccino": "impacciare",
    "impaccio": "impacciare",
    "impacciò": "impacciare",
    "impacco": "impaccare",
    "impaccò": "impaccare",
    "impadronendo": "impadronire",
    "impadroniamo": "impadronire",
    "impadroniate": "impadronire",
    "impadronii": "impadronire",
    "impadronimmo": "impadronire",
    "impadronir": "impadronire",
    "impadronirai": "impadronire",
    "impadroniran": "impadronire",
    "impadroniranno": "impadronire",
    "impadronirebbe": "impadronire",
    "impadronirebber": "impadronire",
    "impadronirebbero": "impadronire",
    "impadronirei": "impadronire",
    "impadroniremmo": "impadronire",
    "impadroniremo": "impadronire",
    "impadronireste": "impadronire",
    "impadroniresti": "impadronire",
    "impadronirete": "impadronire",
    "impadroniron": "impadronire",
    "impadronirono": "impadronire",
    "impadronirà": "impadronire",
    "impadronirò": "impadronire",
    "impadronisca": "impadronire",
    "impadroniscan": "impadronire",
    "impadroniscano": "impadronire",
    "impadronisce": "impadronire",
    "impadronisci": "impadronire",
    "impadronisco": "impadronire",
    "impadroniscon": "impadronire",
    "impadroniscono": "impadronire",
    "impadronisse": "impadronire",
    "impadronisser": "impadronire",
    "impadronissero": "impadronire",
    "impadronissi": "impadronire",
    "impadronissimo": "impadronire",
    "impadroniste": "impadronire",
    "impadronisti": "impadronire",
    "impadronita": "impadronire",
    "impadronite": "impadronire",
    "impadroniti": "impadronire",
    "impadronito": "impadronire",
    "impadroniva": "impadronire",
    "impadronivamo": "impadronire",
    "impadronivan": "impadronire",
    "impadronivano": "impadronire",
    "impadronivate": "impadronire",
    "impadronivi": "impadronire",
    "impadronivo": "impadronire",
    "impadronì": "impadronire",
    "impagabili": "impagabile",
    "impagina": "impaginare",
    "impaginai": "impaginare",
    "impaginammo": "impaginare",
    "impaginan": "impaginare",
    "impaginando": "impaginare",
    "impaginano": "impaginare",
    "impaginante": "impaginare",
    "impaginanti": "impaginare",
    "impaginar": "impaginare",
    "impaginaron": "impaginare",
    "impaginarono": "impaginare",
    "impaginasse": "impaginare",
    "impaginasser": "impaginare",
    "impaginassero": "impaginare",
    "impaginassi": "impaginare",
    "impaginassimo": "impaginare",
    "impaginaste": "impaginare",
    "impaginasti": "impaginare",
    "impaginata": "impaginare",
    "impaginate": "impaginare",
    "impaginati": "impaginare",
    "impaginato": "impaginare",
    "impaginava": "impaginare",
    "impaginavamo": "impaginare",
    "impaginavan": "impaginare",
    "impaginavano": "impaginare",
    "impaginavate": "impaginare",
    "impaginavi": "impaginare",
    "impaginavo": "impaginare",
    "impaginazioni": "impaginazione",
    "impaginerai": "impaginare",
    "impagineran": "impaginare",
    "impagineranno": "impaginare",
    "impaginerebbe": "impaginare",
    "impaginerebber": "impaginare",
    "impaginerebbero": "impaginare",
    "impaginerei": "impaginare",
    "impagineremmo": "impaginare",
    "impagineremo": "impaginare",
    "impaginereste": "impaginare",
    "impagineresti": "impaginare",
    "impaginerete": "impaginare",
    "impaginerà": "impaginare",
    "impaginerò": "impaginare",
    "impagini": "impaginare",
    "impaginiamo": "impaginare",
    "impaginiate": "impaginare",
    "impaginin": "impaginare",
    "impaginino": "impaginare",
    "impagino": "impaginare",
    "impaginò": "impaginare",
    "impagli": "impagliare",
    "impaglia": "impagliare",
    "impagliai": "impagliare",
    "impagliammo": "impagliare",
    "impagliamo": "impagliare",
    "impaglian": "impagliare",
    "impagliando": "impagliare",
    "impagliano": "impagliare",
    "impagliante": "impagliare",
    "impaglianti": "impagliare",
    "impagliar": "impagliare",
    "impagliaron": "impagliare",
    "impagliarono": "impagliare",
    "impagliasse": "impagliare",
    "impagliasser": "impagliare",
    "impagliassero": "impagliare",
    "impagliassi": "impagliare",
    "impagliassimo": "impagliare",
    "impagliaste": "impagliare",
    "impagliasti": "impagliare",
    "impagliata": "impagliare",
    "impagliate": "impagliare",
    "impagliati": "impagliare",
    "impagliato": "impagliare",
    "impagliava": "impagliare",
    "impagliavamo": "impagliare",
    "impagliavan": "impagliare",
    "impagliavano": "impagliare",
    "impagliavate": "impagliare",
    "impagliavi": "impagliare",
    "impagliavo": "impagliare",
    "impaglierai": "impagliare",
    "impaglieran": "impagliare",
    "impaglieranno": "impagliare",
    "impaglierebbe": "impagliare",
    "impaglierebber": "impagliare",
    "impaglierebbero": "impagliare",
    "impaglierei": "impagliare",
    "impaglieremmo": "impagliare",
    "impaglieremo": "impagliare",
    "impagliereste": "impagliare",
    "impaglieresti": "impagliare",
    "impaglierete": "impagliare",
    "impaglierà": "impagliare",
    "impaglierò": "impagliare",
    "impaglin": "impagliare",
    "impaglino": "impagliare",
    "impaglio": "impagliare",
    "impagliò": "impagliare",
    "impala": "impalare",
    "impalai": "impalare",
    "impalammo": "impalare",
    "impalan": "impalare",
    "impalando": "impalare",
    "impalano": "impalare",
    "impalante": "impalare",
    "impalanti": "impalare",
    "impalar": "impalare",
    "impalaron": "impalare",
    "impalarono": "impalare",
    "impalasse": "impalare",
    "impalasser": "impalare",
    "impalassero": "impalare",
    "impalassi": "impalare",
    "impalassimo": "impalare",
    "impalaste": "impalare",
    "impalasti": "impalare",
    "impalata": "impalare",
    "impalate": "impalare",
    "impalati": "impalare",
    "impalato": "impalare",
    "impalava": "impalare",
    "impalavamo": "impalare",
    "impalavan": "impalare",
    "impalavano": "impalare",
    "impalavate": "impalare",
    "impalavi": "impalare",
    "impalavo": "impalare",
    "impalca": "impalcare",
    "impalcai": "impalcare",
    "impalcammo": "impalcare",
    "impalcan": "impalcare",
    "impalcando": "impalcare",
    "impalcano": "impalcare",
    "impalcante": "impalcare",
    "impalcanti": "impalcare",
    "impalcar": "impalcare",
    "impalcaron": "impalcare",
    "impalcarono": "impalcare",
    "impalcasse": "impalcare",
    "impalcasser": "impalcare",
    "impalcassero": "impalcare",
    "impalcassi": "impalcare",
    "impalcassimo": "impalcare",
    "impalcaste": "impalcare",
    "impalcasti": "impalcare",
    "impalcata": "impalcare",
    "impalcate": "impalcare",
    "impalcati": "impalcare",
    "impalcato": "impalcare",
    "impalcature": "impalcatura",
    "impalcava": "impalcare",
    "impalcavamo": "impalcare",
    "impalcavan": "impalcare",
    "impalcavano": "impalcare",
    "impalcavate": "impalcare",
    "impalcavi": "impalcare",
    "impalcavo": "impalcare",
    "impalcherai": "impalcare",
    "impalcheran": "impalcare",
    "impalcheranno": "impalcare",
    "impalcherebbe": "impalcare",
    "impalcherebber": "impalcare",
    "impalcherebbero": "impalcare",
    "impalcherei": "impalcare",
    "impalcheremmo": "impalcare",
    "impalcheremo": "impalcare",
    "impalchereste": "impalcare",
    "impalcheresti": "impalcare",
    "impalcherete": "impalcare",
    "impalcherà": "impalcare",
    "impalcherò": "impalcare",
    "impalchi": "impalcare",
    "impalchiamo": "impalcare",
    "impalchiate": "impalcare",
    "impalchin": "impalcare",
    "impalchino": "impalcare",
    "impalco": "impalcare",
    "impalcò": "impalcare",
    "impalerai": "impalare",
    "impaleran": "impalare",
    "impaleranno": "impalare",
    "impalerebbe": "impalare",
    "impalerebber": "impalare",
    "impalerebbero": "impalare",
    "impalerei": "impalare",
    "impaleremmo": "impalare",
    "impaleremo": "impalare",
    "impalereste": "impalare",
    "impaleresti": "impalare",
    "impalerete": "impalare",
    "impalerà": "impalare",
    "impalerò": "impalare",
    "impali": "impalare",
    "impaliamo": "impalare",
    "impaliate": "impalare",
    "impalin": "impalare",
    "impalino": "impalare",
    "impalla": "impallare",
    "impallai": "impallare",
    "impallammo": "impallare",
    "impallan": "impallare",
    "impallando": "impallare",
    "impallano": "impallare",
    "impallante": "impallare",
    "impallanti": "impallare",
    "impallar": "impallare",
    "impallaron": "impallare",
    "impallarono": "impallare",
    "impallasse": "impallare",
    "impallasser": "impallare",
    "impallassero": "impallare",
    "impallassi": "impallare",
    "impallassimo": "impallare",
    "impallaste": "impallare",
    "impallasti": "impallare",
    "impallata": "impallare",
    "impallate": "impallare",
    "impallati": "impallare",
    "impallato": "impallare",
    "impallava": "impallare",
    "impallavamo": "impallare",
    "impallavan": "impallare",
    "impallavano": "impallare",
    "impallavate": "impallare",
    "impallavi": "impallare",
    "impallavo": "impallare",
    "impallerai": "impallare",
    "impalleran": "impallare",
    "impalleranno": "impallare",
    "impallerebbe": "impallare",
    "impallerebber": "impallare",
    "impallerebbero": "impallare",
    "impallerei": "impallare",
    "impalleremmo": "impallare",
    "impalleremo": "impallare",
    "impallereste": "impallare",
    "impalleresti": "impallare",
    "impallerete": "impallare",
    "impallerà": "impallare",
    "impallerò": "impallare",
    "impalli": "impallare",
    "impalliamo": "impallare",
    "impalliate": "impallare",
    "impallidendo": "impallidire",
    "impallidente": "impallidire",
    "impallidenti": "impallidire",
    "impallidiamo": "impallidire",
    "impallidiate": "impallidire",
    "impallidii": "impallidire",
    "impallidimmo": "impallidire",
    "impallidir": "impallidire",
    "impallidirai": "impallidire",
    "impallidiran": "impallidire",
    "impallidiranno": "impallidire",
    "impallidirebbe": "impallidire",
    "impallidirebber": "impallidire",
    "impallidirebbero": "impallidire",
    "impallidirei": "impallidire",
    "impallidiremmo": "impallidire",
    "impallidiremo": "impallidire",
    "impallidireste": "impallidire",
    "impallidiresti": "impallidire",
    "impallidirete": "impallidire",
    "impallidiron": "impallidire",
    "impallidirono": "impallidire",
    "impallidirà": "impallidire",
    "impallidirò": "impallidire",
    "impallidisca": "impallidire",
    "impallidiscan": "impallidire",
    "impallidiscano": "impallidire",
    "impallidisce": "impallidire",
    "impallidisci": "impallidire",
    "impallidisco": "impallidire",
    "impallidiscon": "impallidire",
    "impallidiscono": "impallidire",
    "impallidisse": "impallidire",
    "impallidisser": "impallidire",
    "impallidissero": "impallidire",
    "impallidissi": "impallidire",
    "impallidissimo": "impallidire",
    "impallidiste": "impallidire",
    "impallidisti": "impallidire",
    "impallidita": "impallidire",
    "impallidite": "impallidire",
    "impalliditi": "impallidire",
    "impallidito": "impallidire",
    "impallidiva": "impallidire",
    "impallidivamo": "impallidire",
    "impallidivan": "impallidire",
    "impallidivano": "impallidire",
    "impallidivate": "impallidire",
    "impallidivi": "impallidire",
    "impallidivo": "impallidire",
    "impallidì": "impallidire",
    "impallin": "impallare",
    "impallina": "impallinare",
    "impallinai": "impallinare",
    "impallinammo": "impallinare",
    "impallinan": "impallinare",
    "impallinando": "impallinare",
    "impallinano": "impallinare",
    "impallinante": "impallinare",
    "impallinanti": "impallinare",
    "impallinar": "impallinare",
    "impallinaron": "impallinare",
    "impallinarono": "impallinare",
    "impallinasse": "impallinare",
    "impallinasser": "impallinare",
    "impallinassero": "impallinare",
    "impallinassi": "impallinare",
    "impallinassimo": "impallinare",
    "impallinaste": "impallinare",
    "impallinasti": "impallinare",
    "impallinata": "impallinare",
    "impallinate": "impallinare",
    "impallinati": "impallinare",
    "impallinato": "impallinare",
    "impallinava": "impallinare",
    "impallinavamo": "impallinare",
    "impallinavan": "impallinare",
    "impallinavano": "impallinare",
    "impallinavate": "impallinare",
    "impallinavi": "impallinare",
    "impallinavo": "impallinare",
    "impallinerai": "impallinare",
    "impallineran": "impallinare",
    "impallineranno": "impallinare",
    "impallinerebbe": "impallinare",
    "impallinerebber": "impallinare",
    "impallinerebbero": "impallinare",
    "impallinerei": "impallinare",
    "impallineremmo": "impallinare",
    "impallineremo": "impallinare",
    "impallinereste": "impallinare",
    "impallineresti": "impallinare",
    "impallinerete": "impallinare",
    "impallinerà": "impallinare",
    "impallinerò": "impallinare",
    "impallini": "impallinare",
    "impalliniamo": "impallinare",
    "impalliniate": "impallinare",
    "impallinin": "impallinare",
    "impallinino": "impallinare",
    "impallino": "impallinare",
    "impallinò": "impallinare",
    "impallo": "impallare",
    "impallò": "impallare",
    "impalma": "impalmare",
    "impalmai": "impalmare",
    "impalmammo": "impalmare",
    "impalman": "impalmare",
    "impalmando": "impalmare",
    "impalmano": "impalmare",
    "impalmante": "impalmare",
    "impalmanti": "impalmare",
    "impalmar": "impalmare",
    "impalmaron": "impalmare",
    "impalmarono": "impalmare",
    "impalmasse": "impalmare",
    "impalmasser": "impalmare",
    "impalmassero": "impalmare",
    "impalmassi": "impalmare",
    "impalmassimo": "impalmare",
    "impalmaste": "impalmare",
    "impalmasti": "impalmare",
    "impalmata": "impalmare",
    "impalmate": "impalmare",
    "impalmati": "impalmare",
    "impalmato": "impalmare",
    "impalmava": "impalmare",
    "impalmavamo": "impalmare",
    "impalmavan": "impalmare",
    "impalmavano": "impalmare",
    "impalmavate": "impalmare",
    "impalmavi": "impalmare",
    "impalmavo": "impalmare",
    "impalmerai": "impalmare",
    "impalmeran": "impalmare",
    "impalmeranno": "impalmare",
    "impalmerebbe": "impalmare",
    "impalmerebber": "impalmare",
    "impalmerebbero": "impalmare",
    "impalmerei": "impalmare",
    "impalmeremmo": "impalmare",
    "impalmeremo": "impalmare",
    "impalmereste": "impalmare",
    "impalmeresti": "impalmare",
    "impalmerete": "impalmare",
    "impalmerà": "impalmare",
    "impalmerò": "impalmare",
    "impalmi": "impalmare",
    "impalmiamo": "impalmare",
    "impalmiate": "impalmare",
    "impalmin": "impalmare",
    "impalmino": "impalmare",
    "impalmo": "impalmare",
    "impalmò": "impalmare",
    "impalo": "impalare",
    "impalpabili": "impalpabile",
    "impaluda": "impaludare",
    "impaludai": "impaludare",
    "impaludammo": "impaludare",
    "impaludan": "impaludare",
    "impaludando": "impaludare",
    "impaludano": "impaludare",
    "impaludante": "impaludare",
    "impaludanti": "impaludare",
    "impaludar": "impaludare",
    "impaludaron": "impaludare",
    "impaludarono": "impaludare",
    "impaludasse": "impaludare",
    "impaludasser": "impaludare",
    "impaludassero": "impaludare",
    "impaludassi": "impaludare",
    "impaludassimo": "impaludare",
    "impaludaste": "impaludare",
    "impaludasti": "impaludare",
    "impaludata": "impaludare",
    "impaludate": "impaludare",
    "impaludati": "impaludare",
    "impaludato": "impaludare",
    "impaludava": "impaludare",
    "impaludavamo": "impaludare",
    "impaludavan": "impaludare",
    "impaludavano": "impaludare",
    "impaludavate": "impaludare",
    "impaludavi": "impaludare",
    "impaludavo": "impaludare",
    "impaluderai": "impaludare",
    "impaluderan": "impaludare",
    "impaluderanno": "impaludare",
    "impaluderebbe": "impaludare",
    "impaluderebber": "impaludare",
    "impaluderebbero": "impaludare",
    "impaluderei": "impaludare",
    "impaluderemmo": "impaludare",
    "impaluderemo": "impaludare",
    "impaludereste": "impaludare",
    "impaluderesti": "impaludare",
    "impaluderete": "impaludare",
    "impaluderà": "impaludare",
    "impaluderò": "impaludare",
    "impaludi": "impaludare",
    "impaludiamo": "impaludare",
    "impaludiate": "impaludare",
    "impaludin": "impaludare",
    "impaludino": "impaludare",
    "impaludo": "impaludare",
    "impaludò": "impaludare",
    "impalò": "impalare",
    "impana": "impanare",
    "impanai": "impanare",
    "impanammo": "impanare",
    "impanan": "impanare",
    "impanando": "impanare",
    "impanano": "impanare",
    "impanante": "impanare",
    "impananti": "impanare",
    "impanar": "impanare",
    "impanaron": "impanare",
    "impanarono": "impanare",
    "impanasse": "impanare",
    "impanasser": "impanare",
    "impanassero": "impanare",
    "impanassi": "impanare",
    "impanassimo": "impanare",
    "impanaste": "impanare",
    "impanasti": "impanare",
    "impanata": "impanare",
    "impanate": "impanare",
    "impanati": "impanare",
    "impanato": "impanare",
    "impanava": "impanare",
    "impanavamo": "impanare",
    "impanavan": "impanare",
    "impanavano": "impanare",
    "impanavate": "impanare",
    "impanavi": "impanare",
    "impanavo": "impanare",
    "impanca": "impancare",
    "impancai": "impancare",
    "impancammo": "impancare",
    "impancan": "impancare",
    "impancando": "impancare",
    "impancano": "impancare",
    "impancar": "impancare",
    "impancaron": "impancare",
    "impancarono": "impancare",
    "impancasse": "impancare",
    "impancasser": "impancare",
    "impancassero": "impancare",
    "impancassi": "impancare",
    "impancassimo": "impancare",
    "impancaste": "impancare",
    "impancasti": "impancare",
    "impancata": "impancare",
    "impancate": "impancare",
    "impancati": "impancare",
    "impancato": "impancare",
    "impancava": "impancare",
    "impancavamo": "impancare",
    "impancavan": "impancare",
    "impancavano": "impancare",
    "impancavate": "impancare",
    "impancavi": "impancare",
    "impancavo": "impancare",
    "impancherai": "impancare",
    "impancheran": "impancare",
    "impancheranno": "impancare",
    "impancherebbe": "impancare",
    "impancherebber": "impancare",
    "impancherebbero": "impancare",
    "impancherei": "impancare",
    "impancheremmo": "impancare",
    "impancheremo": "impancare",
    "impanchereste": "impancare",
    "impancheresti": "impancare",
    "impancherete": "impancare",
    "impancherà": "impancare",
    "impancherò": "impancare",
    "impanchi": "impancare",
    "impanchiamo": "impancare",
    "impanchiate": "impancare",
    "impanchin": "impancare",
    "impanchino": "impancare",
    "impanco": "impancare",
    "impancò": "impancare",
    "impanerai": "impanare",
    "impaneran": "impanare",
    "impaneranno": "impanare",
    "impanerebbe": "impanare",
    "impanerebber": "impanare",
    "impanerebbero": "impanare",
    "impanerei": "impanare",
    "impaneremmo": "impanare",
    "impaneremo": "impanare",
    "impanereste": "impanare",
    "impaneresti": "impanare",
    "impanerete": "impanare",
    "impanerà": "impanare",
    "impanerò": "impanare",
    "impani": "impaniare",
    "impania": "impaniare",
    "impaniai": "impaniare",
    "impaniammo": "impaniare",
    "impaniamo": "impaniare",
    "impanian": "impaniare",
    "impaniando": "impaniare",
    "impaniano": "impaniare",
    "impaniante": "impaniare",
    "impanianti": "impaniare",
    "impaniar": "impaniare",
    "impaniaron": "impaniare",
    "impaniarono": "impaniare",
    "impaniasse": "impaniare",
    "impaniasser": "impaniare",
    "impaniassero": "impaniare",
    "impaniassi": "impaniare",
    "impaniassimo": "impaniare",
    "impaniaste": "impaniare",
    "impaniasti": "impaniare",
    "impaniata": "impaniare",
    "impaniate": "impaniare",
    "impaniati": "impaniare",
    "impaniato": "impaniare",
    "impaniava": "impaniare",
    "impaniavamo": "impaniare",
    "impaniavan": "impaniare",
    "impaniavano": "impaniare",
    "impaniavate": "impaniare",
    "impaniavi": "impaniare",
    "impaniavo": "impaniare",
    "impanierai": "impaniare",
    "impanieran": "impaniare",
    "impanieranno": "impaniare",
    "impanierebbe": "impaniare",
    "impanierebber": "impaniare",
    "impanierebbero": "impaniare",
    "impanierei": "impaniare",
    "impanieremmo": "impaniare",
    "impanieremo": "impaniare",
    "impaniereste": "impaniare",
    "impanieresti": "impaniare",
    "impanierete": "impaniare",
    "impanierà": "impaniare",
    "impanierò": "impaniare",
    "impanin": "impaniare",
    "impanino": "impaniare",
    "impanio": "impaniare",
    "impaniò": "impaniare",
    "impano": "impanare",
    "impantana": "impantanare",
    "impantanai": "impantanare",
    "impantanammo": "impantanare",
    "impantanan": "impantanare",
    "impantanando": "impantanare",
    "impantanano": "impantanare",
    "impantanante": "impantanare",
    "impantananti": "impantanare",
    "impantanar": "impantanare",
    "impantanaron": "impantanare",
    "impantanarono": "impantanare",
    "impantanasse": "impantanare",
    "impantanasser": "impantanare",
    "impantanassero": "impantanare",
    "impantanassi": "impantanare",
    "impantanassimo": "impantanare",
    "impantanaste": "impantanare",
    "impantanasti": "impantanare",
    "impantanata": "impantanare",
    "impantanate": "impantanare",
    "impantanati": "impantanare",
    "impantanato": "impantanare",
    "impantanava": "impantanare",
    "impantanavamo": "impantanare",
    "impantanavan": "impantanare",
    "impantanavano": "impantanare",
    "impantanavate": "impantanare",
    "impantanavi": "impantanare",
    "impantanavo": "impantanare",
    "impantanerai": "impantanare",
    "impantaneran": "impantanare",
    "impantaneranno": "impantanare",
    "impantanerebbe": "impantanare",
    "impantanerebber": "impantanare",
    "impantanerebbero": "impantanare",
    "impantanerei": "impantanare",
    "impantaneremmo": "impantanare",
    "impantaneremo": "impantanare",
    "impantanereste": "impantanare",
    "impantaneresti": "impantanare",
    "impantanerete": "impantanare",
    "impantanerà": "impantanare",
    "impantanerò": "impantanare",
    "impantani": "impantanare",
    "impantaniamo": "impantanare",
    "impantaniate": "impantanare",
    "impantanin": "impantanare",
    "impantanino": "impantanare",
    "impantano": "impantanare",
    "impantanò": "impantanare",
    "impanò": "impanare",
    "impapera": "impaperare",
    "impaperai": "impaperare",
    "impaperammo": "impaperare",
    "impaperan": "impaperare",
    "impaperando": "impaperare",
    "impaperano": "impaperare",
    "impaperar": "impaperare",
    "impaperaron": "impaperare",
    "impaperarono": "impaperare",
    "impaperasse": "impaperare",
    "impaperasser": "impaperare",
    "impaperassero": "impaperare",
    "impaperassi": "impaperare",
    "impaperassimo": "impaperare",
    "impaperaste": "impaperare",
    "impaperasti": "impaperare",
    "impaperata": "impaperare",
    "impaperate": "impaperare",
    "impaperati": "impaperare",
    "impaperato": "impaperare",
    "impaperava": "impaperare",
    "impaperavamo": "impaperare",
    "impaperavan": "impaperare",
    "impaperavano": "impaperare",
    "impaperavate": "impaperare",
    "impaperavi": "impaperare",
    "impaperavo": "impaperare",
    "impapererai": "impaperare",
    "impapereran": "impaperare",
    "impapereranno": "impaperare",
    "impapererebbe": "impaperare",
    "impapererebber": "impaperare",
    "impapererebbero": "impaperare",
    "impapererei": "impaperare",
    "impapereremmo": "impaperare",
    "impapereremo": "impaperare",
    "impaperereste": "impaperare",
    "impapereresti": "impaperare",
    "impapererete": "impaperare",
    "impapererà": "impaperare",
    "impapererò": "impaperare",
    "impaperi": "impaperare",
    "impaperiamo": "impaperare",
    "impaperiate": "impaperare",
    "impaperin": "impaperare",
    "impaperino": "impaperare",
    "impapero": "impaperare",
    "impaperò": "impaperare",
    "impappina": "impappinare",
    "impappinai": "impappinare",
    "impappinammo": "impappinare",
    "impappinan": "impappinare",
    "impappinando": "impappinare",
    "impappinano": "impappinare",
    "impappinante": "impappinare",
    "impappinanti": "impappinare",
    "impappinar": "impappinare",
    "impappinaron": "impappinare",
    "impappinarono": "impappinare",
    "impappinasse": "impappinare",
    "impappinasser": "impappinare",
    "impappinassero": "impappinare",
    "impappinassi": "impappinare",
    "impappinassimo": "impappinare",
    "impappinaste": "impappinare",
    "impappinasti": "impappinare",
    "impappinata": "impappinare",
    "impappinate": "impappinare",
    "impappinati": "impappinare",
    "impappinato": "impappinare",
    "impappinava": "impappinare",
    "impappinavamo": "impappinare",
    "impappinavan": "impappinare",
    "impappinavano": "impappinare",
    "impappinavate": "impappinare",
    "impappinavi": "impappinare",
    "impappinavo": "impappinare",
    "impappinerai": "impappinare",
    "impappineran": "impappinare",
    "impappineranno": "impappinare",
    "impappinerebbe": "impappinare",
    "impappinerebber": "impappinare",
    "impappinerebbero": "impappinare",
    "impappinerei": "impappinare",
    "impappineremmo": "impappinare",
    "impappineremo": "impappinare",
    "impappinereste": "impappinare",
    "impappineresti": "impappinare",
    "impappinerete": "impappinare",
    "impappinerà": "impappinare",
    "impappinerò": "impappinare",
    "impappini": "impappinare",
    "impappiniamo": "impappinare",
    "impappiniate": "impappinare",
    "impappinin": "impappinare",
    "impappinino": "impappinare",
    "impappino": "impappinare",
    "impappinò": "impappinare",
    "impara": "imparare",
    "imparabili": "imparabile",
    "imparai": "imparare",
    "imparammo": "imparare",
    "imparan": "imparare",
    "imparando": "imparare",
    "imparano": "imparare",
    "imparante": "imparare",
    "imparanti": "imparare",
    "imparar": "imparare",
    "impararon": "imparare",
    "impararono": "imparare",
    "imparasse": "imparare",
    "imparasser": "imparare",
    "imparassero": "imparare",
    "imparassi": "imparare",
    "imparassimo": "imparare",
    "imparaste": "imparare",
    "imparasti": "imparare",
    "imparata": "imparare",
    "imparate": "imparare",
    "imparati": "imparare",
    "imparato": "imparare",
    "imparava": "imparare",
    "imparavamo": "imparare",
    "imparavan": "imparare",
    "imparavano": "imparare",
    "imparavate": "imparare",
    "imparavi": "imparare",
    "imparavo": "imparare",
    "impareggiabili": "impareggiabile",
    "imparenta": "imparentare",
    "imparentai": "imparentare",
    "imparentammo": "imparentare",
    "imparentan": "imparentare",
    "imparentando": "imparentare",
    "imparentano": "imparentare",
    "imparentante": "imparentare",
    "imparentanti": "imparentare",
    "imparentar": "imparentare",
    "imparentaron": "imparentare",
    "imparentarono": "imparentare",
    "imparentasse": "imparentare",
    "imparentasser": "imparentare",
    "imparentassero": "imparentare",
    "imparentassi": "imparentare",
    "imparentassimo": "imparentare",
    "imparentaste": "imparentare",
    "imparentasti": "imparentare",
    "imparentata": "imparentare",
    "imparentate": "imparentare",
    "imparentati": "imparentare",
    "imparentato": "imparentare",
    "imparentava": "imparentare",
    "imparentavamo": "imparentare",
    "imparentavan": "imparentare",
    "imparentavano": "imparentare",
    "imparentavate": "imparentare",
    "imparentavi": "imparentare",
    "imparentavo": "imparentare",
    "imparenterai": "imparentare",
    "imparenteran": "imparentare",
    "imparenteranno": "imparentare",
    "imparenterebbe": "imparentare",
    "imparenterebber": "imparentare",
    "imparenterebbero": "imparentare",
    "imparenterei": "imparentare",
    "imparenteremmo": "imparentare",
    "imparenteremo": "imparentare",
    "imparentereste": "imparentare",
    "imparenteresti": "imparentare",
    "imparenterete": "imparentare",
    "imparenterà": "imparentare",
    "imparenterò": "imparentare",
    "imparenti": "imparentare",
    "imparentiamo": "imparentare",
    "imparentiate": "imparentare",
    "imparentin": "imparentare",
    "imparentino": "imparentare",
    "imparento": "imparentare",
    "imparentò": "imparentare",
    "imparerai": "imparare",
    "impareran": "imparare",
    "impareranno": "imparare",
    "imparerebbe": "imparare",
    "imparerebber": "imparare",
    "imparerebbero": "imparare",
    "imparerei": "imparare",
    "impareremmo": "imparare",
    "impareremo": "imparare",
    "imparereste": "imparare",
    "impareresti": "imparare",
    "imparerete": "imparare",
    "imparerà": "imparare",
    "imparerò": "imparare",
    "impari": "imparare",
    "impariamo": "imparare",
    "impariate": "imparare",
    "imparin": "imparare",
    "imparino": "imparare",
    "imparo": "imparare",
    "imparrucca": "imparruccare",
    "imparruccai": "imparruccare",
    "imparruccammo": "imparruccare",
    "imparruccan": "imparruccare",
    "imparruccando": "imparruccare",
    "imparruccano": "imparruccare",
    "imparruccante": "imparruccare",
    "imparruccanti": "imparruccare",
    "imparruccar": "imparruccare",
    "imparruccaron": "imparruccare",
    "imparruccarono": "imparruccare",
    "imparruccasse": "imparruccare",
    "imparruccasser": "imparruccare",
    "imparruccassero": "imparruccare",
    "imparruccassi": "imparruccare",
    "imparruccassimo": "imparruccare",
    "imparruccaste": "imparruccare",
    "imparruccasti": "imparruccare",
    "imparruccata": "imparruccare",
    "imparruccate": "imparruccare",
    "imparruccati": "imparruccare",
    "imparruccato": "imparruccare",
    "imparruccava": "imparruccare",
    "imparruccavamo": "imparruccare",
    "imparruccavan": "imparruccare",
    "imparruccavano": "imparruccare",
    "imparruccavate": "imparruccare",
    "imparruccavi": "imparruccare",
    "imparruccavo": "imparruccare",
    "imparruccherai": "imparruccare",
    "imparruccheran": "imparruccare",
    "imparruccheranno": "imparruccare",
    "imparruccherebbe": "imparruccare",
    "imparruccherebber": "imparruccare",
    "imparruccherebbero": "imparruccare",
    "imparruccherei": "imparruccare",
    "imparruccheremmo": "imparruccare",
    "imparruccheremo": "imparruccare",
    "imparrucchereste": "imparruccare",
    "imparruccheresti": "imparruccare",
    "imparruccherete": "imparruccare",
    "imparruccherà": "imparruccare",
    "imparruccherò": "imparruccare",
    "imparrucchi": "imparruccare",
    "imparrucchiamo": "imparruccare",
    "imparrucchiate": "imparruccare",
    "imparrucchin": "imparruccare",
    "imparrucchino": "imparruccare",
    "imparrucco": "imparruccare",
    "imparruccò": "imparruccare",
    "impartendo": "impartire",
    "impartente": "impartire",
    "impartenti": "impartire",
    "impartiamo": "impartire",
    "impartiate": "impartire",
    "impartii": "impartire",
    "impartimmo": "impartire",
    "impartir": "impartire",
    "impartirai": "impartire",
    "impartiran": "impartire",
    "impartiranno": "impartire",
    "impartirebbe": "impartire",
    "impartirebber": "impartire",
    "impartirebbero": "impartire",
    "impartirei": "impartire",
    "impartiremmo": "impartire",
    "impartiremo": "impartire",
    "impartireste": "impartire",
    "impartiresti": "impartire",
    "impartirete": "impartire",
    "impartiron": "impartire",
    "impartirono": "impartire",
    "impartirà": "impartire",
    "impartirò": "impartire",
    "impartisca": "impartire",
    "impartiscan": "impartire",
    "impartiscano": "impartire",
    "impartisce": "impartire",
    "impartisci": "impartire",
    "impartisco": "impartire",
    "impartiscon": "impartire",
    "impartiscono": "impartire",
    "impartisse": "impartire",
    "impartisser": "impartire",
    "impartissero": "impartire",
    "impartissi": "impartire",
    "impartissimo": "impartire",
    "impartiste": "impartire",
    "impartisti": "impartire",
    "impartita": "impartire",
    "impartite": "impartire",
    "impartiti": "impartire",
    "impartito": "impartire",
    "impartiva": "impartire",
    "impartivamo": "impartire",
    "impartivan": "impartire",
    "impartivano": "impartire",
    "impartivate": "impartire",
    "impartivi": "impartire",
    "impartivo": "impartire",
    "impartì": "impartire",
    "imparziali": "imparziale",
    "imparò": "imparare",
    "impassibili": "impassibile",
    "impasta": "impastare",
    "impastai": "impastare",
    "impastammo": "impastare",
    "impastan": "impastare",
    "impastando": "impastare",
    "impastano": "impastare",
    "impastante": "impastare",
    "impastanti": "impastare",
    "impastar": "impastare",
    "impastaron": "impastare",
    "impastarono": "impastare",
    "impastasse": "impastare",
    "impastasser": "impastare",
    "impastassero": "impastare",
    "impastassi": "impastare",
    "impastassimo": "impastare",
    "impastaste": "impastare",
    "impastasti": "impastare",
    "impastata": "impastato",
    "impastate": "impastato",
    "impastati": "impastato",
    "impastato": "impastare",
    "impastava": "impastare",
    "impastavamo": "impastare",
    "impastavan": "impastare",
    "impastavano": "impastare",
    "impastavate": "impastare",
    "impastavi": "impastare",
    "impastavo": "impastare",
    "impasterai": "impastare",
    "impasteran": "impastare",
    "impasteranno": "impastare",
    "impasterebbe": "impastare",
    "impasterebber": "impastare",
    "impasterebbero": "impastare",
    "impasterei": "impastare",
    "impasteremmo": "impastare",
    "impasteremo": "impastare",
    "impastereste": "impastare",
    "impasteresti": "impastare",
    "impasterete": "impastare",
    "impasterà": "impastare",
    "impasterò": "impastare",
    "impasti": "impasto",
    "impastiamo": "impastare",
    "impastiate": "impastare",
    "impastin": "impastare",
    "impastino": "impastare",
    "impasto": "impastare",
    "impastoi": "impastoiare",
    "impastoia": "impastoiare",
    "impastoiai": "impastoiare",
    "impastoiammo": "impastoiare",
    "impastoiamo": "impastoiare",
    "impastoian": "impastoiare",
    "impastoiando": "impastoiare",
    "impastoiano": "impastoiare",
    "impastoiante": "impastoiare",
    "impastoianti": "impastoiare",
    "impastoiar": "impastoiare",
    "impastoiaron": "impastoiare",
    "impastoiarono": "impastoiare",
    "impastoiasse": "impastoiare",
    "impastoiasser": "impastoiare",
    "impastoiassero": "impastoiare",
    "impastoiassi": "impastoiare",
    "impastoiassimo": "impastoiare",
    "impastoiaste": "impastoiare",
    "impastoiasti": "impastoiare",
    "impastoiata": "impastoiare",
    "impastoiate": "impastoiare",
    "impastoiati": "impastoiare",
    "impastoiato": "impastoiare",
    "impastoiava": "impastoiare",
    "impastoiavamo": "impastoiare",
    "impastoiavan": "impastoiare",
    "impastoiavano": "impastoiare",
    "impastoiavate": "impastoiare",
    "impastoiavi": "impastoiare",
    "impastoiavo": "impastoiare",
    "impastoierai": "impastoiare",
    "impastoieran": "impastoiare",
    "impastoieranno": "impastoiare",
    "impastoierebbe": "impastoiare",
    "impastoierebber": "impastoiare",
    "impastoierebbero": "impastoiare",
    "impastoierei": "impastoiare",
    "impastoieremmo": "impastoiare",
    "impastoieremo": "impastoiare",
    "impastoiereste": "impastoiare",
    "impastoieresti": "impastoiare",
    "impastoierete": "impastoiare",
    "impastoierà": "impastoiare",
    "impastoierò": "impastoiare",
    "impastoin": "impastoiare",
    "impastoino": "impastoiare",
    "impastoio": "impastoiare",
    "impastoiò": "impastoiare",
    "impastò": "impastare",
    "impatacca": "impataccare",
    "impataccai": "impataccare",
    "impataccammo": "impataccare",
    "impataccan": "impataccare",
    "impataccando": "impataccare",
    "impataccano": "impataccare",
    "impataccante": "impataccare",
    "impataccanti": "impataccare",
    "impataccar": "impataccare",
    "impataccaron": "impataccare",
    "impataccarono": "impataccare",
    "impataccasse": "impataccare",
    "impataccasser": "impataccare",
    "impataccassero": "impataccare",
    "impataccassi": "impataccare",
    "impataccassimo": "impataccare",
    "impataccaste": "impataccare",
    "impataccasti": "impataccare",
    "impataccata": "impataccare",
    "impataccate": "impataccare",
    "impataccati": "impataccare",
    "impataccato": "impataccare",
    "impataccava": "impataccare",
    "impataccavamo": "impataccare",
    "impataccavan": "impataccare",
    "impataccavano": "impataccare",
    "impataccavate": "impataccare",
    "impataccavi": "impataccare",
    "impataccavo": "impataccare",
    "impataccherai": "impataccare",
    "impataccheran": "impataccare",
    "impataccheranno": "impataccare",
    "impataccherebbe": "impataccare",
    "impataccherebber": "impataccare",
    "impataccherebbero": "impataccare",
    "impataccherei": "impataccare",
    "impataccheremmo": "impataccare",
    "impataccheremo": "impataccare",
    "impatacchereste": "impataccare",
    "impataccheresti": "impataccare",
    "impataccherete": "impataccare",
    "impataccherà": "impataccare",
    "impataccherò": "impataccare",
    "impatacchi": "impataccare",
    "impatacchiamo": "impataccare",
    "impatacchiate": "impataccare",
    "impatacchin": "impataccare",
    "impatacchino": "impataccare",
    "impatacco": "impataccare",
    "impataccò": "impataccare",
    "impatta": "impattare",
    "impattai": "impattare",
    "impattammo": "impattare",
    "impattan": "impattare",
    "impattando": "impattare",
    "impattano": "impattare",
    "impattante": "impattare",
    "impattanti": "impattare",
    "impattar": "impattare",
    "impattaron": "impattare",
    "impattarono": "impattare",
    "impattasse": "impattare",
    "impattasser": "impattare",
    "impattassero": "impattare",
    "impattassi": "impattare",
    "impattassimo": "impattare",
    "impattaste": "impattare",
    "impattasti": "impattare",
    "impattata": "impattare",
    "impattate": "impattare",
    "impattati": "impattare",
    "impattato": "impattare",
    "impattava": "impattare",
    "impattavamo": "impattare",
    "impattavan": "impattare",
    "impattavano": "impattare",
    "impattavate": "impattare",
    "impattavi": "impattare",
    "impattavo": "impattare",
    "impatterai": "impattare",
    "impatteran": "impattare",
    "impatteranno": "impattare",
    "impatterebbe": "impattare",
    "impatterebber": "impattare",
    "impatterebbero": "impattare",
    "impatterei": "impattare",
    "impatteremmo": "impattare",
    "impatteremo": "impattare",
    "impattereste": "impattare",
    "impatteresti": "impattare",
    "impatterete": "impattare",
    "impatterà": "impattare",
    "impatterò": "impattare",
    "impatti": "impatto",
    "impattiamo": "impattare",
    "impattiate": "impattare",
    "impattin": "impattare",
    "impattino": "impattare",
    "impatto": "impattare",
    "impattò": "impattare",
    "impaurendo": "impaurire",
    "impaurente": "impaurire",
    "impaurenti": "impaurire",
    "impauriamo": "impaurire",
    "impauriate": "impaurire",
    "impaurii": "impaurire",
    "impaurimmo": "impaurire",
    "impaurir": "impaurire",
    "impaurirai": "impaurire",
    "impauriran": "impaurire",
    "impauriranno": "impaurire",
    "impaurirebbe": "impaurire",
    "impaurirebber": "impaurire",
    "impaurirebbero": "impaurire",
    "impaurirei": "impaurire",
    "impauriremmo": "impaurire",
    "impauriremo": "impaurire",
    "impaurireste": "impaurire",
    "impauriresti": "impaurire",
    "impaurirete": "impaurire",
    "impauriron": "impaurire",
    "impaurirono": "impaurire",
    "impaurirà": "impaurire",
    "impaurirò": "impaurire",
    "impaurisca": "impaurire",
    "impauriscan": "impaurire",
    "impauriscano": "impaurire",
    "impaurisce": "impaurire",
    "impaurisci": "impaurire",
    "impaurisco": "impaurire",
    "impauriscon": "impaurire",
    "impauriscono": "impaurire",
    "impaurisse": "impaurire",
    "impaurisser": "impaurire",
    "impaurissero": "impaurire",
    "impaurissi": "impaurire",
    "impaurissimo": "impaurire",
    "impauriste": "impaurire",
    "impauristi": "impaurire",
    "impaurita": "impaurire",
    "impaurite": "impaurire",
    "impauriti": "impaurire",
    "impaurito": "impaurire",
    "impauriva": "impaurire",
    "impaurivamo": "impaurire",
    "impaurivan": "impaurire",
    "impaurivano": "impaurire",
    "impaurivate": "impaurire",
    "impaurivi": "impaurire",
    "impaurivo": "impaurire",
    "impaurì": "impaurire",
    "impavesa": "impavesare",
    "impavesai": "impavesare",
    "impavesammo": "impavesare",
    "impavesan": "impavesare",
    "impavesando": "impavesare",
    "impavesano": "impavesare",
    "impavesante": "impavesare",
    "impavesanti": "impavesare",
    "impavesar": "impavesare",
    "impavesaron": "impavesare",
    "impavesarono": "impavesare",
    "impavesasse": "impavesare",
    "impavesasser": "impavesare",
    "impavesassero": "impavesare",
    "impavesassi": "impavesare",
    "impavesassimo": "impavesare",
    "impavesaste": "impavesare",
    "impavesasti": "impavesare",
    "impavesata": "impavesare",
    "impavesate": "impavesare",
    "impavesati": "impavesare",
    "impavesato": "impavesare",
    "impavesava": "impavesare",
    "impavesavamo": "impavesare",
    "impavesavan": "impavesare",
    "impavesavano": "impavesare",
    "impavesavate": "impavesare",
    "impavesavi": "impavesare",
    "impavesavo": "impavesare",
    "impaveserai": "impavesare",
    "impaveseran": "impavesare",
    "impaveseranno": "impavesare",
    "impaveserebbe": "impavesare",
    "impaveserebber": "impavesare",
    "impaveserebbero": "impavesare",
    "impaveserei": "impavesare",
    "impaveseremmo": "impavesare",
    "impaveseremo": "impavesare",
    "impavesereste": "impavesare",
    "impaveseresti": "impavesare",
    "impaveserete": "impavesare",
    "impaveserà": "impavesare",
    "impaveserò": "impavesare",
    "impavesi": "impavesare",
    "impavesiamo": "impavesare",
    "impavesiate": "impavesare",
    "impavesin": "impavesare",
    "impavesino": "impavesare",
    "impaveso": "impavesare",
    "impavesò": "impavesare",
    "impavida": "impavido",
    "impavide": "impavido",
    "impavidi": "impavido",
    "impazienti": "impaziente",
    "impazienze": "impazienza",
    "impazza": "impazzare",
    "impazzai": "impazzare",
    "impazzammo": "impazzare",
    "impazzan": "impazzare",
    "impazzando": "impazzare",
    "impazzano": "impazzare",
    "impazzante": "impazzare",
    "impazzanti": "impazzare",
    "impazzar": "impazzare",
    "impazzaron": "impazzare",
    "impazzarono": "impazzare",
    "impazzasse": "impazzare",
    "impazzasser": "impazzare",
    "impazzassero": "impazzare",
    "impazzassi": "impazzare",
    "impazzassimo": "impazzare",
    "impazzaste": "impazzare",
    "impazzasti": "impazzare",
    "impazzata": "impazzare",
    "impazzate": "impazzare",
    "impazzati": "impazzare",
    "impazzato": "impazzare",
    "impazzava": "impazzare",
    "impazzavamo": "impazzare",
    "impazzavan": "impazzare",
    "impazzavano": "impazzare",
    "impazzavate": "impazzare",
    "impazzavi": "impazzare",
    "impazzavo": "impazzare",
    "impazzendo": "impazzire",
    "impazzente": "impazzire",
    "impazzenti": "impazzire",
    "impazzerai": "impazzare",
    "impazzeran": "impazzare",
    "impazzeranno": "impazzare",
    "impazzerebbe": "impazzare",
    "impazzerebber": "impazzare",
    "impazzerebbero": "impazzare",
    "impazzerei": "impazzare",
    "impazzeremmo": "impazzare",
    "impazzeremo": "impazzare",
    "impazzereste": "impazzare",
    "impazzeresti": "impazzare",
    "impazzerete": "impazzare",
    "impazzerà": "impazzare",
    "impazzerò": "impazzare",
    "impazzi": "impazzare",
    "impazziamo": "impazzire",
    "impazziate": "impazzire",
    "impazzii": "impazzire",
    "impazzimmo": "impazzire",
    "impazzin": "impazzare",
    "impazzino": "impazzare",
    "impazzir": "impazzire",
    "impazzirai": "impazzire",
    "impazziran": "impazzire",
    "impazziranno": "impazzire",
    "impazzirebbe": "impazzire",
    "impazzirebber": "impazzire",
    "impazzirebbero": "impazzire",
    "impazzirei": "impazzire",
    "impazziremmo": "impazzire",
    "impazziremo": "impazzire",
    "impazzireste": "impazzire",
    "impazziresti": "impazzire",
    "impazzirete": "impazzire",
    "impazziron": "impazzire",
    "impazzirono": "impazzire",
    "impazzirà": "impazzire",
    "impazzirò": "impazzire",
    "impazzisca": "impazzire",
    "impazziscan": "impazzire",
    "impazziscano": "impazzire",
    "impazzisce": "impazzire",
    "impazzisci": "impazzire",
    "impazzisco": "impazzire",
    "impazziscon": "impazzire",
    "impazziscono": "impazzire",
    "impazzisse": "impazzire",
    "impazzisser": "impazzire",
    "impazzissero": "impazzire",
    "impazzissi": "impazzire",
    "impazzissimo": "impazzire",
    "impazziste": "impazzire",
    "impazzisti": "impazzire",
    "impazzita": "impazzire",
    "impazzite": "impazzire",
    "impazziti": "impazzire",
    "impazzito": "impazzire",
    "impazziva": "impazzire",
    "impazzivamo": "impazzire",
    "impazzivan": "impazzire",
    "impazzivano": "impazzire",
    "impazzivate": "impazzire",
    "impazzivi": "impazzire",
    "impazzivo": "impazzire",
    "impazzo": "impazzare",
    "impazzì": "impazzire",
    "impazzò": "impazzare",
    "impeccabili": "impeccabile",
    "impecerai": "impeciare",
    "impeceran": "impeciare",
    "impeceranno": "impeciare",
    "impecerebbe": "impeciare",
    "impecerebber": "impeciare",
    "impecerebbero": "impeciare",
    "impecerei": "impeciare",
    "impeceremmo": "impeciare",
    "impeceremo": "impeciare",
    "impecereste": "impeciare",
    "impeceresti": "impeciare",
    "impecerete": "impeciare",
    "impecerà": "impeciare",
    "impecerò": "impeciare",
    "impeci": "impeciare",
    "impecia": "impeciare",
    "impeciai": "impeciare",
    "impeciammo": "impeciare",
    "impeciamo": "impeciare",
    "impecian": "impeciare",
    "impeciando": "impeciare",
    "impeciano": "impeciare",
    "impeciante": "impeciare",
    "impecianti": "impeciare",
    "impeciar": "impeciare",
    "impeciaron": "impeciare",
    "impeciarono": "impeciare",
    "impeciasse": "impeciare",
    "impeciasser": "impeciare",
    "impeciassero": "impeciare",
    "impeciassi": "impeciare",
    "impeciassimo": "impeciare",
    "impeciaste": "impeciare",
    "impeciasti": "impeciare",
    "impeciata": "impeciare",
    "impeciate": "impeciare",
    "impeciati": "impeciare",
    "impeciato": "impeciare",
    "impeciava": "impeciare",
    "impeciavamo": "impeciare",
    "impeciavan": "impeciare",
    "impeciavano": "impeciare",
    "impeciavate": "impeciare",
    "impeciavi": "impeciare",
    "impeciavo": "impeciare",
    "impecin": "impeciare",
    "impecino": "impeciare",
    "impecio": "impeciare",
    "impeciò": "impeciare",
    "impedendo": "impedire",
    "impedente": "impedire",
    "impedenti": "impedire",
    "impediamo": "impedire",
    "impediate": "impedire",
    "impedii": "impedire",
    "impedimenti": "impedimento",
    "impedimmo": "impedire",
    "impedir": "impedire",
    "impedirai": "impedire",
    "impediran": "impedire",
    "impediranno": "impedire",
    "impedirebbe": "impedire",
    "impedirebber": "impedire",
    "impedirebbero": "impedire",
    "impedirei": "impedire",
    "impediremmo": "impedire",
    "impediremo": "impedire",
    "impedireste": "impedire",
    "impediresti": "impedire",
    "impedirete": "impedire",
    "impediron": "impedire",
    "impedirono": "impedire",
    "impedirà": "impedire",
    "impedirò": "impedire",
    "impedisca": "impedire",
    "impediscan": "impedire",
    "impediscano": "impedire",
    "impedisce": "impedire",
    "impedisci": "impedire",
    "impedisco": "impedire",
    "impediscon": "impedire",
    "impediscono": "impedire",
    "impedisse": "impedire",
    "impedisser": "impedire",
    "impedissero": "impedire",
    "impedissi": "impedire",
    "impedissimo": "impedire",
    "impediste": "impedire",
    "impedisti": "impedire",
    "impedita": "impedito",
    "impedite": "impedito",
    "impediti": "impedito",
    "impedito": "impedire",
    "impediva": "impedire",
    "impedivamo": "impedire",
    "impedivan": "impedire",
    "impedivano": "impedire",
    "impedivate": "impedire",
    "impedivi": "impedire",
    "impedivo": "impedire",
    "impedì": "impedire",
    "impegna": "impegnare",
    "impegnai": "impegnare",
    "impegnammo": "impegnare",
    "impegnan": "impegnare",
    "impegnando": "impegnare",
    "impegnano": "impegnare",
    "impegnante": "impegnare",
    "impegnanti": "impegnare",
    "impegnar": "impegnare",
    "impegnaron": "impegnare",
    "impegnarono": "impegnare",
    "impegnasse": "impegnare",
    "impegnasser": "impegnare",
    "impegnassero": "impegnare",
    "impegnassi": "impegnare",
    "impegnassimo": "impegnare",
    "impegnaste": "impegnare",
    "impegnasti": "impegnare",
    "impegnata": "impegnato",
    "impegnate": "impegnato",
    "impegnati": "impegnato",
    "impegnativa": "impegnativo",
    "impegnative": "impegnativo",
    "impegnativi": "impegnativo",
    "impegnato": "impegnare",
    "impegnava": "impegnare",
    "impegnavamo": "impegnare",
    "impegnavan": "impegnare",
    "impegnavano": "impegnare",
    "impegnavate": "impegnare",
    "impegnavi": "impegnare",
    "impegnavo": "impegnare",
    "impegnerai": "impegnare",
    "impegneran": "impegnare",
    "impegneranno": "impegnare",
    "impegnerebbe": "impegnare",
    "impegnerebber": "impegnare",
    "impegnerebbero": "impegnare",
    "impegnerei": "impegnare",
    "impegneremmo": "impegnare",
    "impegneremo": "impegnare",
    "impegnereste": "impegnare",
    "impegneresti": "impegnare",
    "impegnerete": "impegnare",
    "impegnerà": "impegnare",
    "impegnerò": "impegnare",
    "impegni": "impegno",
    "impegniamo": "impegnare",
    "impegniate": "impegnare",
    "impegnin": "impegnare",
    "impegnino": "impegnare",
    "impegno": "impegnare",
    "impegnò": "impegnare",
    "impegola": "impegolare",
    "impegolai": "impegolare",
    "impegolammo": "impegolare",
    "impegolan": "impegolare",
    "impegolando": "impegolare",
    "impegolano": "impegolare",
    "impegolante": "impegolare",
    "impegolanti": "impegolare",
    "impegolar": "impegolare",
    "impegolaron": "impegolare",
    "impegolarono": "impegolare",
    "impegolasse": "impegolare",
    "impegolasser": "impegolare",
    "impegolassero": "impegolare",
    "impegolassi": "impegolare",
    "impegolassimo": "impegolare",
    "impegolaste": "impegolare",
    "impegolasti": "impegolare",
    "impegolata": "impegolare",
    "impegolate": "impegolare",
    "impegolati": "impegolare",
    "impegolato": "impegolare",
    "impegolava": "impegolare",
    "impegolavamo": "impegolare",
    "impegolavan": "impegolare",
    "impegolavano": "impegolare",
    "impegolavate": "impegolare",
    "impegolavi": "impegolare",
    "impegolavo": "impegolare",
    "impegolerai": "impegolare",
    "impegoleran": "impegolare",
    "impegoleranno": "impegolare",
    "impegolerebbe": "impegolare",
    "impegolerebber": "impegolare",
    "impegolerebbero": "impegolare",
    "impegolerei": "impegolare",
    "impegoleremmo": "impegolare",
    "impegoleremo": "impegolare",
    "impegolereste": "impegolare",
    "impegoleresti": "impegolare",
    "impegolerete": "impegolare",
    "impegolerà": "impegolare",
    "impegolerò": "impegolare",
    "impegoli": "impegolare",
    "impegoliamo": "impegolare",
    "impegoliate": "impegolare",
    "impegolin": "impegolare",
    "impegolino": "impegolare",
    "impegolo": "impegolare",
    "impegolò": "impegolare",
    "impelaga": "impelagare",
    "impelagai": "impelagare",
    "impelagammo": "impelagare",
    "impelagan": "impelagare",
    "impelagando": "impelagare",
    "impelagano": "impelagare",
    "impelagar": "impelagare",
    "impelagaron": "impelagare",
    "impelagarono": "impelagare",
    "impelagasse": "impelagare",
    "impelagasser": "impelagare",
    "impelagassero": "impelagare",
    "impelagassi": "impelagare",
    "impelagassimo": "impelagare",
    "impelagaste": "impelagare",
    "impelagasti": "impelagare",
    "impelagata": "impelagare",
    "impelagate": "impelagare",
    "impelagati": "impelagare",
    "impelagato": "impelagare",
    "impelagava": "impelagare",
    "impelagavamo": "impelagare",
    "impelagavan": "impelagare",
    "impelagavano": "impelagare",
    "impelagavate": "impelagare",
    "impelagavi": "impelagare",
    "impelagavo": "impelagare",
    "impelagherai": "impelagare",
    "impelagheran": "impelagare",
    "impelagheranno": "impelagare",
    "impelagherebbe": "impelagare",
    "impelagherebber": "impelagare",
    "impelagherebbero": "impelagare",
    "impelagherei": "impelagare",
    "impelagheremmo": "impelagare",
    "impelagheremo": "impelagare",
    "impelaghereste": "impelagare",
    "impelagheresti": "impelagare",
    "impelagherete": "impelagare",
    "impelagherà": "impelagare",
    "impelagherò": "impelagare",
    "impelaghi": "impelagare",
    "impelaghiamo": "impelagare",
    "impelaghiate": "impelagare",
    "impelaghin": "impelagare",
    "impelaghino": "impelagare",
    "impelago": "impelagare",
    "impelagò": "impelagare",
    "impellenti": "impellente",
    "impellenze": "impellenza",
    "impelliccerai": "impellicciare",
    "impellicceran": "impellicciare",
    "impellicceranno": "impellicciare",
    "impelliccerebbe": "impellicciare",
    "impelliccerebber": "impellicciare",
    "impelliccerebbero": "impellicciare",
    "impelliccerei": "impellicciare",
    "impellicceremmo": "impellicciare",
    "impellicceremo": "impellicciare",
    "impelliccereste": "impellicciare",
    "impellicceresti": "impellicciare",
    "impelliccerete": "impellicciare",
    "impelliccerà": "impellicciare",
    "impelliccerò": "impellicciare",
    "impellicci": "impellicciare",
    "impelliccia": "impellicciare",
    "impellicciai": "impellicciare",
    "impellicciammo": "impellicciare",
    "impellicciamo": "impellicciare",
    "impelliccian": "impellicciare",
    "impellicciando": "impellicciare",
    "impellicciano": "impellicciare",
    "impellicciante": "impellicciare",
    "impelliccianti": "impellicciare",
    "impellicciar": "impellicciare",
    "impellicciaron": "impellicciare",
    "impellicciarono": "impellicciare",
    "impellicciasse": "impellicciare",
    "impellicciasser": "impellicciare",
    "impellicciassero": "impellicciare",
    "impellicciassi": "impellicciare",
    "impellicciassimo": "impellicciare",
    "impellicciaste": "impellicciare",
    "impellicciasti": "impellicciare",
    "impellicciata": "impellicciare",
    "impellicciate": "impellicciare",
    "impellicciati": "impellicciare",
    "impellicciato": "impellicciare",
    "impellicciava": "impellicciare",
    "impellicciavamo": "impellicciare",
    "impellicciavan": "impellicciare",
    "impellicciavano": "impellicciare",
    "impellicciavate": "impellicciare",
    "impellicciavi": "impellicciare",
    "impellicciavo": "impellicciare",
    "impelliccin": "impellicciare",
    "impelliccino": "impellicciare",
    "impelliccio": "impellicciare",
    "impellicciò": "impellicciare",
    "impenetrabili": "impenetrabile",
    "impenitenti": "impenitente",
    "impenna": "impennare",
    "impennacchi": "impennacchiare",
    "impennacchia": "impennacchiare",
    "impennacchiai": "impennacchiare",
    "impennacchiammo": "impennacchiare",
    "impennacchiamo": "impennacchiare",
    "impennacchian": "impennacchiare",
    "impennacchiando": "impennacchiare",
    "impennacchiano": "impennacchiare",
    "impennacchiante": "impennacchiare",
    "impennacchianti": "impennacchiare",
    "impennacchiar": "impennacchiare",
    "impennacchiaron": "impennacchiare",
    "impennacchiarono": "impennacchiare",
    "impennacchiasse": "impennacchiare",
    "impennacchiasser": "impennacchiare",
    "impennacchiassero": "impennacchiare",
    "impennacchiassi": "impennacchiare",
    "impennacchiassimo": "impennacchiare",
    "impennacchiaste": "impennacchiare",
    "impennacchiasti": "impennacchiare",
    "impennacchiata": "impennacchiare",
    "impennacchiate": "impennacchiare",
    "impennacchiati": "impennacchiare",
    "impennacchiato": "impennacchiare",
    "impennacchiava": "impennacchiare",
    "impennacchiavamo": "impennacchiare",
    "impennacchiavan": "impennacchiare",
    "impennacchiavano": "impennacchiare",
    "impennacchiavate": "impennacchiare",
    "impennacchiavi": "impennacchiare",
    "impennacchiavo": "impennacchiare",
    "impennacchierai": "impennacchiare",
    "impennacchieran": "impennacchiare",
    "impennacchieranno": "impennacchiare",
    "impennacchierebbe": "impennacchiare",
    "impennacchierebber": "impennacchiare",
    "impennacchierebbero": "impennacchiare",
    "impennacchierei": "impennacchiare",
    "impennacchieremmo": "impennacchiare",
    "impennacchieremo": "impennacchiare",
    "impennacchiereste": "impennacchiare",
    "impennacchieresti": "impennacchiare",
    "impennacchierete": "impennacchiare",
    "impennacchierà": "impennacchiare",
    "impennacchierò": "impennacchiare",
    "impennacchin": "impennacchiare",
    "impennacchino": "impennacchiare",
    "impennacchio": "impennacchiare",
    "impennacchiò": "impennacchiare",
    "impennai": "impennare",
    "impennammo": "impennare",
    "impennan": "impennare",
    "impennando": "impennare",
    "impennano": "impennare",
    "impennante": "impennare",
    "impennanti": "impennare",
    "impennar": "impennare",
    "impennaron": "impennare",
    "impennarono": "impennare",
    "impennasse": "impennare",
    "impennasser": "impennare",
    "impennassero": "impennare",
    "impennassi": "impennare",
    "impennassimo": "impennare",
    "impennaste": "impennare",
    "impennasti": "impennare",
    "impennata": "impennare",
    "impennate": "impennata",
    "impennati": "impennare",
    "impennato": "impennare",
    "impennava": "impennare",
    "impennavamo": "impennare",
    "impennavan": "impennare",
    "impennavano": "impennare",
    "impennavate": "impennare",
    "impennavi": "impennare",
    "impennavo": "impennare",
    "impennerai": "impennare",
    "impenneran": "impennare",
    "impenneranno": "impennare",
    "impennerebbe": "impennare",
    "impennerebber": "impennare",
    "impennerebbero": "impennare",
    "impennerei": "impennare",
    "impenneremmo": "impennare",
    "impenneremo": "impennare",
    "impennereste": "impennare",
    "impenneresti": "impennare",
    "impennerete": "impennare",
    "impennerà": "impennare",
    "impennerò": "impennare",
    "impenni": "impennare",
    "impenniamo": "impennare",
    "impenniate": "impennare",
    "impennin": "impennare",
    "impennino": "impennare",
    "impenno": "impennare",
    "impennò": "impennare",
    "impensabili": "impensabile",
    "impensata": "impensato",
    "impensate": "impensato",
    "impensati": "impensato",
    "impensierendo": "impensierire",
    "impensierente": "impensierire",
    "impensierenti": "impensierire",
    "impensieriamo": "impensierire",
    "impensieriate": "impensierire",
    "impensierii": "impensierire",
    "impensierimmo": "impensierire",
    "impensierir": "impensierire",
    "impensierirai": "impensierire",
    "impensieriran": "impensierire",
    "impensieriranno": "impensierire",
    "impensierirebbe": "impensierire",
    "impensierirebber": "impensierire",
    "impensierirebbero": "impensierire",
    "impensierirei": "impensierire",
    "impensieriremmo": "impensierire",
    "impensieriremo": "impensierire",
    "impensierireste": "impensierire",
    "impensieriresti": "impensierire",
    "impensierirete": "impensierire",
    "impensieriron": "impensierire",
    "impensierirono": "impensierire",
    "impensierirà": "impensierire",
    "impensierirò": "impensierire",
    "impensierisca": "impensierire",
    "impensieriscan": "impensierire",
    "impensieriscano": "impensierire",
    "impensierisce": "impensierire",
    "impensierisci": "impensierire",
    "impensierisco": "impensierire",
    "impensieriscon": "impensierire",
    "impensieriscono": "impensierire",
    "impensierisse": "impensierire",
    "impensierisser": "impensierire",
    "impensierissero": "impensierire",
    "impensierissi": "impensierire",
    "impensierissimo": "impensierire",
    "impensieriste": "impensierire",
    "impensieristi": "impensierire",
    "impensierita": "impensierire",
    "impensierite": "impensierire",
    "impensieriti": "impensierire",
    "impensierito": "impensierire",
    "impensieriva": "impensierire",
    "impensierivamo": "impensierire",
    "impensierivan": "impensierire",
    "impensierivano": "impensierire",
    "impensierivate": "impensierire",
    "impensierivi": "impensierire",
    "impensierivo": "impensierire",
    "impensierì": "impensierire",
    "impepa": "impepare",
    "impepai": "impepare",
    "impepammo": "impepare",
    "impepan": "impepare",
    "impepando": "impepare",
    "impepano": "impepare",
    "impepante": "impepare",
    "impepanti": "impepare",
    "impepar": "impepare",
    "impeparon": "impepare",
    "impeparono": "impepare",
    "impepasse": "impepare",
    "impepasser": "impepare",
    "impepassero": "impepare",
    "impepassi": "impepare",
    "impepassimo": "impepare",
    "impepaste": "impepare",
    "impepasti": "impepare",
    "impepata": "impepare",
    "impepate": "impepare",
    "impepati": "impepare",
    "impepato": "impepare",
    "impepava": "impepare",
    "impepavamo": "impepare",
    "impepavan": "impepare",
    "impepavano": "impepare",
    "impepavate": "impepare",
    "impepavi": "impepare",
    "impepavo": "impepare",
    "impeperai": "impepare",
    "impeperan": "impepare",
    "impeperanno": "impepare",
    "impeperebbe": "impepare",
    "impeperebber": "impepare",
    "impeperebbero": "impepare",
    "impeperei": "impepare",
    "impeperemmo": "impepare",
    "impeperemo": "impepare",
    "impepereste": "impepare",
    "impeperesti": "impepare",
    "impeperete": "impepare",
    "impeperà": "impepare",
    "impeperò": "impepare",
    "impepi": "impepare",
    "impepiamo": "impepare",
    "impepiate": "impepare",
    "impepin": "impepare",
    "impepino": "impepare",
    "impepo": "impepare",
    "impepò": "impepare",
    "impera": "imperare",
    "imperai": "imperare",
    "imperammo": "imperare",
    "imperan": "imperare",
    "imperando": "imperare",
    "imperano": "imperare",
    "imperante": "imperare",
    "imperanti": "imperare",
    "imperar": "imperare",
    "imperaron": "imperare",
    "imperarono": "imperare",
    "imperasse": "imperare",
    "imperasser": "imperare",
    "imperassero": "imperare",
    "imperassi": "imperare",
    "imperassimo": "imperare",
    "imperaste": "imperare",
    "imperasti": "imperare",
    "imperata": "imperare",
    "imperate": "imperare",
    "imperati": "imperare",
    "imperativa": "imperativo",
    "imperative": "imperativo",
    "imperativi": "imperativo",
    "imperato": "imperare",
    "imperatori": "imperatore",
    "imperatrici": "imperatrice",
    "imperava": "imperare",
    "imperavamo": "imperare",
    "imperavan": "imperare",
    "imperavano": "imperare",
    "imperavate": "imperare",
    "imperavi": "imperare",
    "imperavo": "imperare",
    "impercettibili": "impercettibile",
    "imperdonabili": "imperdonabile",
    "impererai": "imperare",
    "impereran": "imperare",
    "impereranno": "imperare",
    "impererebbe": "imperare",
    "impererebber": "imperare",
    "impererebbero": "imperare",
    "impererei": "imperare",
    "impereremmo": "imperare",
    "impereremo": "imperare",
    "imperereste": "imperare",
    "impereresti": "imperare",
    "impererete": "imperare",
    "impererà": "imperare",
    "impererò": "imperare",
    "imperfetta": "imperfetto",
    "imperfette": "imperfetto",
    "imperfetti": "imperfetto",
    "imperfezioni": "imperfezione",
    "imperi": "impero",
    "imperia": "imperiare",
    "imperiai": "imperiare",
    "imperiali": "imperiale",
    "imperialismi": "imperialismo",
    "imperialiste": "imperialista",
    "imperialisti": "imperialista",
    "imperialistica": "imperialistico",
    "imperialistiche": "imperialistico",
    "imperialistici": "imperialistico",
    "imperiammo": "imperiare",
    "imperiamo": "imperiare",
    "imperian": "imperiare",
    "imperiando": "imperiare",
    "imperiano": "imperiare",
    "imperiante": "imperiare",
    "imperianti": "imperiare",
    "imperiar": "imperiare",
    "imperiaron": "imperiare",
    "imperiarono": "imperiare",
    "imperiasse": "imperiare",
    "imperiasser": "imperiare",
    "imperiassero": "imperiare",
    "imperiassi": "imperiare",
    "imperiassimo": "imperiare",
    "imperiaste": "imperiare",
    "imperiasti": "imperiare",
    "imperiata": "imperiare",
    "imperiate": "imperiare",
    "imperiati": "imperiare",
    "imperiato": "imperiare",
    "imperiava": "imperiare",
    "imperiavamo": "imperiare",
    "imperiavan": "imperiare",
    "imperiavano": "imperiare",
    "imperiavate": "imperiare",
    "imperiavi": "imperiare",
    "imperiavo": "imperiare",
    "imperierai": "imperiare",
    "imperieran": "imperiare",
    "imperieranno": "imperiare",
    "imperierebbe": "imperiare",
    "imperierebber": "imperiare",
    "imperierebbero": "imperiare",
    "imperierei": "imperiare",
    "imperieremmo": "imperiare",
    "imperieremo": "imperiare",
    "imperiereste": "imperiare",
    "imperieresti": "imperiare",
    "imperierete": "imperiare",
    "imperierà": "imperiare",
    "imperierò": "imperiare",
    "imperin": "imperiare",
    "imperino": "imperiare",
    "imperio": "imperiare",
    "imperiosa": "imperioso",
    "imperiose": "imperioso",
    "imperiosi": "imperioso",
    "imperita": "imperito",
    "imperite": "imperito",
    "imperiti": "imperito",
    "imperitura": "imperituro",
    "imperiture": "imperituro",
    "imperituri": "imperituro",
    "imperizie": "imperizia",
    "imperiò": "imperiare",
    "impermala": "impermalire",
    "impermalan": "impermalire",
    "impermalano": "impermalire",
    "impermale": "impermalire",
    "impermalendo": "impermalire",
    "impermalente": "impermalire",
    "impermalenti": "impermalire",
    "impermali": "impermalire",
    "impermaliamo": "impermalire",
    "impermaliate": "impermalire",
    "impermalii": "impermalire",
    "impermalimmo": "impermalire",
    "impermalir": "impermalire",
    "impermalirai": "impermalire",
    "impermaliran": "impermalire",
    "impermaliranno": "impermalire",
    "impermalirebbe": "impermalire",
    "impermalirebber": "impermalire",
    "impermalirebbero": "impermalire",
    "impermalirei": "impermalire",
    "impermaliremmo": "impermalire",
    "impermaliremo": "impermalire",
    "impermalireste": "impermalire",
    "impermaliresti": "impermalire",
    "impermalirete": "impermalire",
    "impermaliron": "impermalire",
    "impermalirono": "impermalire",
    "impermalirà": "impermalire",
    "impermalirò": "impermalire",
    "impermalisse": "impermalire",
    "impermalisser": "impermalire",
    "impermalissero": "impermalire",
    "impermalissi": "impermalire",
    "impermalissimo": "impermalire",
    "impermaliste": "impermalire",
    "impermalisti": "impermalire",
    "impermalita": "impermalire",
    "impermalite": "impermalire",
    "impermaliti": "impermalire",
    "impermalito": "impermalire",
    "impermaliva": "impermalire",
    "impermalivamo": "impermalire",
    "impermalivan": "impermalire",
    "impermalivano": "impermalire",
    "impermalivate": "impermalire",
    "impermalivi": "impermalire",
    "impermalivo": "impermalire",
    "impermalo": "impermalire",
    "impermalon": "impermalire",
    "impermalono": "impermalire",
    "impermalì": "impermalire",
    "impermeabili": "impermeabile",
    "impermeabilizza": "impermeabilizzare",
    "impermeabilizzai": "impermeabilizzare",
    "impermeabilizzammo": "impermeabilizzare",
    "impermeabilizzan": "impermeabilizzare",
    "impermeabilizzando": "impermeabilizzare",
    "impermeabilizzano": "impermeabilizzare",
    "impermeabilizzante": "impermeabilizzare",
    "impermeabilizzanti": "impermeabilizzare",
    "impermeabilizzar": "impermeabilizzare",
    "impermeabilizzaron": "impermeabilizzare",
    "impermeabilizzarono": "impermeabilizzare",
    "impermeabilizzasse": "impermeabilizzare",
    "impermeabilizzasser": "impermeabilizzare",
    "impermeabilizzassero": "impermeabilizzare",
    "impermeabilizzassi": "impermeabilizzare",
    "impermeabilizzassimo": "impermeabilizzare",
    "impermeabilizzaste": "impermeabilizzare",
    "impermeabilizzasti": "impermeabilizzare",
    "impermeabilizzata": "impermeabilizzare",
    "impermeabilizzate": "impermeabilizzare",
    "impermeabilizzati": "impermeabilizzare",
    "impermeabilizzato": "impermeabilizzare",
    "impermeabilizzava": "impermeabilizzare",
    "impermeabilizzavamo": "impermeabilizzare",
    "impermeabilizzavan": "impermeabilizzare",
    "impermeabilizzavano": "impermeabilizzare",
    "impermeabilizzavate": "impermeabilizzare",
    "impermeabilizzavi": "impermeabilizzare",
    "impermeabilizzavo": "impermeabilizzare",
    "impermeabilizzerai": "impermeabilizzare",
    "impermeabilizzeran": "impermeabilizzare",
    "impermeabilizzeranno": "impermeabilizzare",
    "impermeabilizzerebbe": "impermeabilizzare",
    "impermeabilizzerebber": "impermeabilizzare",
    "impermeabilizzerebbero": "impermeabilizzare",
    "impermeabilizzerei": "impermeabilizzare",
    "impermeabilizzeremmo": "impermeabilizzare",
    "impermeabilizzeremo": "impermeabilizzare",
    "impermeabilizzereste": "impermeabilizzare",
    "impermeabilizzeresti": "impermeabilizzare",
    "impermeabilizzerete": "impermeabilizzare",
    "impermeabilizzerà": "impermeabilizzare",
    "impermeabilizzerò": "impermeabilizzare",
    "impermeabilizzi": "impermeabilizzare",
    "impermeabilizziamo": "impermeabilizzare",
    "impermeabilizziate": "impermeabilizzare",
    "impermeabilizzin": "impermeabilizzare",
    "impermeabilizzino": "impermeabilizzare",
    "impermeabilizzo": "impermeabilizzare",
    "impermeabilizzò": "impermeabilizzare",
    "imperni": "imperniare",
    "impernia": "imperniare",
    "imperniai": "imperniare",
    "imperniammo": "imperniare",
    "imperniamo": "imperniare",
    "impernian": "imperniare",
    "imperniando": "imperniare",
    "imperniano": "imperniare",
    "imperniante": "imperniare",
    "impernianti": "imperniare",
    "imperniar": "imperniare",
    "imperniaron": "imperniare",
    "imperniarono": "imperniare",
    "imperniasse": "imperniare",
    "imperniasser": "imperniare",
    "imperniassero": "imperniare",
    "imperniassi": "imperniare",
    "imperniassimo": "imperniare",
    "imperniaste": "imperniare",
    "imperniasti": "imperniare",
    "imperniata": "imperniare",
    "imperniate": "imperniare",
    "imperniati": "imperniare",
    "imperniato": "imperniare",
    "imperniava": "imperniare",
    "imperniavamo": "imperniare",
    "imperniavan": "imperniare",
    "imperniavano": "imperniare",
    "imperniavate": "imperniare",
    "imperniavi": "imperniare",
    "imperniavo": "imperniare",
    "impernierai": "imperniare",
    "impernieran": "imperniare",
    "impernieranno": "imperniare",
    "impernierebbe": "imperniare",
    "impernierebber": "imperniare",
    "impernierebbero": "imperniare",
    "impernierei": "imperniare",
    "impernieremmo": "imperniare",
    "impernieremo": "imperniare",
    "imperniereste": "imperniare",
    "impernieresti": "imperniare",
    "impernierete": "imperniare",
    "impernierà": "imperniare",
    "impernierò": "imperniare",
    "impernin": "imperniare",
    "impernino": "imperniare",
    "impernio": "imperniare",
    "imperniò": "imperniare",
    "impero": "imperare",
    "imperscrutabili": "imperscrutabile",
    "impersona": "impersonare",
    "impersonai": "impersonare",
    "impersonali": "impersonale",
    "impersonammo": "impersonare",
    "impersonan": "impersonare",
    "impersonando": "impersonare",
    "impersonano": "impersonare",
    "impersonante": "impersonare",
    "impersonanti": "impersonare",
    "impersonar": "impersonare",
    "impersonaron": "impersonare",
    "impersonarono": "impersonare",
    "impersonasse": "impersonare",
    "impersonasser": "impersonare",
    "impersonassero": "impersonare",
    "impersonassi": "impersonare",
    "impersonassimo": "impersonare",
    "impersonaste": "impersonare",
    "impersonasti": "impersonare",
    "impersonata": "impersonare",
    "impersonate": "impersonare",
    "impersonati": "impersonare",
    "impersonato": "impersonare",
    "impersonava": "impersonare",
    "impersonavamo": "impersonare",
    "impersonavan": "impersonare",
    "impersonavano": "impersonare",
    "impersonavate": "impersonare",
    "impersonavi": "impersonare",
    "impersonavo": "impersonare",
    "impersonerai": "impersonare",
    "impersoneran": "impersonare",
    "impersoneranno": "impersonare",
    "impersonerebbe": "impersonare",
    "impersonerebber": "impersonare",
    "impersonerebbero": "impersonare",
    "impersonerei": "impersonare",
    "impersoneremmo": "impersonare",
    "impersoneremo": "impersonare",
    "impersonereste": "impersonare",
    "impersoneresti": "impersonare",
    "impersonerete": "impersonare",
    "impersonerà": "impersonare",
    "impersonerò": "impersonare",
    "impersoni": "impersonare",
    "impersoniamo": "impersonare",
    "impersoniate": "impersonare",
    "impersonin": "impersonare",
    "impersonino": "impersonare",
    "impersono": "impersonare",
    "impersonò": "impersonare",
    "imperterrita": "imperterrito",
    "imperterrite": "imperterrito",
    "imperterriti": "imperterrito",
    "impertinenti": "impertinente",
    "impertinenze": "impertinenza",
    "imperturbabili": "imperturbabile",
    "imperturbata": "imperturbato",
    "imperturbate": "imperturbato",
    "imperturbati": "imperturbato",
    "imperversa": "imperversare",
    "imperversai": "imperversare",
    "imperversammo": "imperversare",
    "imperversan": "imperversare",
    "imperversando": "imperversare",
    "imperversano": "imperversare",
    "imperversante": "imperversare",
    "imperversanti": "imperversare",
    "imperversar": "imperversare",
    "imperversaron": "imperversare",
    "imperversarono": "imperversare",
    "imperversasse": "imperversare",
    "imperversasser": "imperversare",
    "imperversassero": "imperversare",
    "imperversassi": "imperversare",
    "imperversassimo": "imperversare",
    "imperversaste": "imperversare",
    "imperversasti": "imperversare",
    "imperversata": "imperversare",
    "imperversate": "imperversare",
    "imperversati": "imperversare",
    "imperversato": "imperversare",
    "imperversava": "imperversare",
    "imperversavamo": "imperversare",
    "imperversavan": "imperversare",
    "imperversavano": "imperversare",
    "imperversavate": "imperversare",
    "imperversavi": "imperversare",
    "imperversavo": "imperversare",
    "imperverserai": "imperversare",
    "imperverseran": "imperversare",
    "imperverseranno": "imperversare",
    "imperverserebbe": "imperversare",
    "imperverserebber": "imperversare",
    "imperverserebbero": "imperversare",
    "imperverserei": "imperversare",
    "imperverseremmo": "imperversare",
    "imperverseremo": "imperversare",
    "imperversereste": "imperversare",
    "imperverseresti": "imperversare",
    "imperverserete": "imperversare",
    "imperverserà": "imperversare",
    "imperverserò": "imperversare",
    "imperversi": "imperversare",
    "imperversiamo": "imperversare",
    "imperversiate": "imperversare",
    "imperversin": "imperversare",
    "imperversino": "imperversare",
    "imperverso": "imperversare",
    "imperversò": "imperversare",
    "impervi": "impervio",
    "impervia": "impervio",
    "impervie": "impervio",
    "imperò": "imperare",
    "impesta": "impestare",
    "impestai": "impestare",
    "impestammo": "impestare",
    "impestan": "impestare",
    "impestando": "impestare",
    "impestano": "impestare",
    "impestante": "impestare",
    "impestanti": "impestare",
    "impestar": "impestare",
    "impestaron": "impestare",
    "impestarono": "impestare",
    "impestasse": "impestare",
    "impestasser": "impestare",
    "impestassero": "impestare",
    "impestassi": "impestare",
    "impestassimo": "impestare",
    "impestaste": "impestare",
    "impestasti": "impestare",
    "impestata": "impestare",
    "impestate": "impestare",
    "impestati": "impestare",
    "impestato": "impestare",
    "impestava": "impestare",
    "impestavamo": "impestare",
    "impestavan": "impestare",
    "impestavano": "impestare",
    "impestavate": "impestare",
    "impestavi": "impestare",
    "impestavo": "impestare",
    "impesterai": "impestare",
    "impesteran": "impestare",
    "impesteranno": "impestare",
    "impesterebbe": "impestare",
    "impesterebber": "impestare",
    "impesterebbero": "impestare",
    "impesterei": "impestare",
    "impesteremmo": "impestare",
    "impesteremo": "impestare",
    "impestereste": "impestare",
    "impesteresti": "impestare",
    "impesterete": "impestare",
    "impesterà": "impestare",
    "impesterò": "impestare",
    "impesti": "impestare",
    "impestiamo": "impestare",
    "impestiate": "impestare",
    "impestin": "impestare",
    "impestino": "impestare",
    "impesto": "impestare",
    "impestò": "impestare",
    "impeti": "impeto",
    "impetra": "impetrare",
    "impetrai": "impetrare",
    "impetrammo": "impetrare",
    "impetran": "impetrare",
    "impetrando": "impetrare",
    "impetrano": "impetrare",
    "impetrante": "impetrare",
    "impetranti": "impetrare",
    "impetrar": "impetrare",
    "impetraron": "impetrare",
    "impetrarono": "impetrare",
    "impetrasse": "impetrare",
    "impetrasser": "impetrare",
    "impetrassero": "impetrare",
    "impetrassi": "impetrare",
    "impetrassimo": "impetrare",
    "impetraste": "impetrare",
    "impetrasti": "impetrare",
    "impetrata": "impetrare",
    "impetrate": "impetrare",
    "impetrati": "impetrare",
    "impetrato": "impetrare",
    "impetrava": "impetrare",
    "impetravamo": "impetrare",
    "impetravan": "impetrare",
    "impetravano": "impetrare",
    "impetravate": "impetrare",
    "impetravi": "impetrare",
    "impetravo": "impetrare",
    "impetrerai": "impetrare",
    "impetreran": "impetrare",
    "impetreranno": "impetrare",
    "impetrerebbe": "impetrare",
    "impetrerebber": "impetrare",
    "impetrerebbero": "impetrare",
    "impetrerei": "impetrare",
    "impetreremmo": "impetrare",
    "impetreremo": "impetrare",
    "impetrereste": "impetrare",
    "impetreresti": "impetrare",
    "impetrerete": "impetrare",
    "impetrerà": "impetrare",
    "impetrerò": "impetrare",
    "impetri": "impetrare",
    "impetriamo": "impetrare",
    "impetriate": "impetrare",
    "impetrin": "impetrare",
    "impetrino": "impetrare",
    "impetro": "impetrare",
    "impetrò": "impetrare",
    "impetuosa": "impetuoso",
    "impetuose": "impetuoso",
    "impetuosi": "impetuoso",
    "impiaga": "impiagare",
    "impiagai": "impiagare",
    "impiagammo": "impiagare",
    "impiagan": "impiagare",
    "impiagando": "impiagare",
    "impiagano": "impiagare",
    "impiagante": "impiagare",
    "impiaganti": "impiagare",
    "impiagar": "impiagare",
    "impiagaron": "impiagare",
    "impiagarono": "impiagare",
    "impiagasse": "impiagare",
    "impiagasser": "impiagare",
    "impiagassero": "impiagare",
    "impiagassi": "impiagare",
    "impiagassimo": "impiagare",
    "impiagaste": "impiagare",
    "impiagasti": "impiagare",
    "impiagata": "impiagare",
    "impiagate": "impiagare",
    "impiagati": "impiagare",
    "impiagato": "impiagare",
    "impiagava": "impiagare",
    "impiagavamo": "impiagare",
    "impiagavan": "impiagare",
    "impiagavano": "impiagare",
    "impiagavate": "impiagare",
    "impiagavi": "impiagare",
    "impiagavo": "impiagare",
    "impiagherai": "impiagare",
    "impiagheran": "impiagare",
    "impiagheranno": "impiagare",
    "impiagherebbe": "impiagare",
    "impiagherebber": "impiagare",
    "impiagherebbero": "impiagare",
    "impiagherei": "impiagare",
    "impiagheremmo": "impiagare",
    "impiagheremo": "impiagare",
    "impiaghereste": "impiagare",
    "impiagheresti": "impiagare",
    "impiagherete": "impiagare",
    "impiagherà": "impiagare",
    "impiagherò": "impiagare",
    "impiaghi": "impiagare",
    "impiaghiamo": "impiagare",
    "impiaghiate": "impiagare",
    "impiaghin": "impiagare",
    "impiaghino": "impiagare",
    "impiago": "impiagare",
    "impiagò": "impiagare",
    "impiallaccerai": "impiallacciare",
    "impiallacceran": "impiallacciare",
    "impiallacceranno": "impiallacciare",
    "impiallaccerebbe": "impiallacciare",
    "impiallaccerebber": "impiallacciare",
    "impiallaccerebbero": "impiallacciare",
    "impiallaccerei": "impiallacciare",
    "impiallacceremmo": "impiallacciare",
    "impiallacceremo": "impiallacciare",
    "impiallaccereste": "impiallacciare",
    "impiallacceresti": "impiallacciare",
    "impiallaccerete": "impiallacciare",
    "impiallaccerà": "impiallacciare",
    "impiallaccerò": "impiallacciare",
    "impiallacci": "impiallacciare",
    "impiallaccia": "impiallacciare",
    "impiallacciai": "impiallacciare",
    "impiallacciammo": "impiallacciare",
    "impiallacciamo": "impiallacciare",
    "impiallaccian": "impiallacciare",
    "impiallacciando": "impiallacciare",
    "impiallacciano": "impiallacciare",
    "impiallacciante": "impiallacciare",
    "impiallaccianti": "impiallacciare",
    "impiallacciar": "impiallacciare",
    "impiallacciaron": "impiallacciare",
    "impiallacciarono": "impiallacciare",
    "impiallacciasse": "impiallacciare",
    "impiallacciasser": "impiallacciare",
    "impiallacciassero": "impiallacciare",
    "impiallacciassi": "impiallacciare",
    "impiallacciassimo": "impiallacciare",
    "impiallacciaste": "impiallacciare",
    "impiallacciasti": "impiallacciare",
    "impiallacciata": "impiallacciare",
    "impiallacciate": "impiallacciare",
    "impiallacciati": "impiallacciare",
    "impiallacciato": "impiallacciare",
    "impiallacciava": "impiallacciare",
    "impiallacciavamo": "impiallacciare",
    "impiallacciavan": "impiallacciare",
    "impiallacciavano": "impiallacciare",
    "impiallacciavate": "impiallacciare",
    "impiallacciavi": "impiallacciare",
    "impiallacciavo": "impiallacciare",
    "impiallaccin": "impiallacciare",
    "impiallaccino": "impiallacciare",
    "impiallaccio": "impiallacciare",
    "impiallacciò": "impiallacciare",
    "impianta": "impiantire",
    "impiantai": "impiantare",
    "impiantammo": "impiantare",
    "impiantan": "impiantire",
    "impiantando": "impiantare",
    "impiantano": "impiantire",
    "impiantante": "impiantare",
    "impiantanti": "impiantare",
    "impiantar": "impiantare",
    "impiantaron": "impiantare",
    "impiantarono": "impiantare",
    "impiantasse": "impiantare",
    "impiantasser": "impiantare",
    "impiantassero": "impiantare",
    "impiantassi": "impiantare",
    "impiantassimo": "impiantare",
    "impiantaste": "impiantare",
    "impiantasti": "impiantare",
    "impiantata": "impiantare",
    "impiantate": "impiantare",
    "impiantati": "impiantare",
    "impiantato": "impiantare",
    "impiantava": "impiantare",
    "impiantavamo": "impiantare",
    "impiantavan": "impiantare",
    "impiantavano": "impiantare",
    "impiantavate": "impiantare",
    "impiantavi": "impiantare",
    "impiantavo": "impiantare",
    "impiante": "impiantire",
    "impiantendo": "impiantire",
    "impiantente": "impiantire",
    "impiantenti": "impiantire",
    "impianterai": "impiantare",
    "impianteran": "impiantare",
    "impianteranno": "impiantare",
    "impianterebbe": "impiantare",
    "impianterebber": "impiantare",
    "impianterebbero": "impiantare",
    "impianterei": "impiantare",
    "impianteremmo": "impiantare",
    "impianteremo": "impiantare",
    "impiantereste": "impiantare",
    "impianteresti": "impiantare",
    "impianterete": "impiantare",
    "impianterà": "impiantare",
    "impianterò": "impiantare",
    "impianti": "impianto",
    "impiantiamo": "impiantire",
    "impiantiate": "impiantire",
    "impiantii": "impiantire",
    "impiantimmo": "impiantire",
    "impiantin": "impiantare",
    "impiantino": "impiantare",
    "impiantir": "impiantire",
    "impiantirai": "impiantire",
    "impiantiran": "impiantire",
    "impiantiranno": "impiantire",
    "impiantirebbe": "impiantire",
    "impiantirebber": "impiantire",
    "impiantirebbero": "impiantire",
    "impiantirei": "impiantire",
    "impiantiremmo": "impiantire",
    "impiantiremo": "impiantire",
    "impiantireste": "impiantire",
    "impiantiresti": "impiantire",
    "impiantirete": "impiantire",
    "impiantiron": "impiantire",
    "impiantirono": "impiantire",
    "impiantirà": "impiantire",
    "impiantirò": "impiantire",
    "impiantisse": "impiantire",
    "impiantisser": "impiantire",
    "impiantissero": "impiantire",
    "impiantissi": "impiantire",
    "impiantissimo": "impiantire",
    "impiantiste": "impiantire",
    "impiantisti": "impiantire",
    "impiantistiche": "impiantistica",
    "impiantita": "impiantire",
    "impiantite": "impiantire",
    "impiantiti": "impiantire",
    "impiantito": "impiantire",
    "impiantiva": "impiantire",
    "impiantivamo": "impiantire",
    "impiantivan": "impiantire",
    "impiantivano": "impiantire",
    "impiantivate": "impiantire",
    "impiantivi": "impiantire",
    "impiantivo": "impiantire",
    "impianto": "impiantire",
    "impianton": "impiantire",
    "impiantono": "impiantire",
    "impiantì": "impiantire",
    "impiantò": "impiantare",
    "impiastra": "impiastrare",
    "impiastrai": "impiastrare",
    "impiastrammo": "impiastrare",
    "impiastran": "impiastrare",
    "impiastrando": "impiastrare",
    "impiastrano": "impiastrare",
    "impiastrante": "impiastrare",
    "impiastranti": "impiastrare",
    "impiastrar": "impiastrare",
    "impiastraron": "impiastrare",
    "impiastrarono": "impiastrare",
    "impiastrasse": "impiastrare",
    "impiastrasser": "impiastrare",
    "impiastrassero": "impiastrare",
    "impiastrassi": "impiastrare",
    "impiastrassimo": "impiastrare",
    "impiastraste": "impiastrare",
    "impiastrasti": "impiastrare",
    "impiastrata": "impiastrare",
    "impiastrate": "impiastrare",
    "impiastrati": "impiastrare",
    "impiastrato": "impiastrare",
    "impiastrava": "impiastrare",
    "impiastravamo": "impiastrare",
    "impiastravan": "impiastrare",
    "impiastravano": "impiastrare",
    "impiastravate": "impiastrare",
    "impiastravi": "impiastrare",
    "impiastravo": "impiastrare",
    "impiastrerai": "impiastrare",
    "impiastreran": "impiastrare",
    "impiastreranno": "impiastrare",
    "impiastrerebbe": "impiastrare",
    "impiastrerebber": "impiastrare",
    "impiastrerebbero": "impiastrare",
    "impiastrerei": "impiastrare",
    "impiastreremmo": "impiastrare",
    "impiastreremo": "impiastrare",
    "impiastrereste": "impiastrare",
    "impiastreresti": "impiastrare",
    "impiastrerete": "impiastrare",
    "impiastrerà": "impiastrare",
    "impiastrerò": "impiastrare",
    "impiastri": "impiastrare",
    "impiastriamo": "impiastrare",
    "impiastriate": "impiastrare",
    "impiastriccerai": "impiastricciare",
    "impiastricceran": "impiastricciare",
    "impiastricceranno": "impiastricciare",
    "impiastriccerebbe": "impiastricciare",
    "impiastriccerebber": "impiastricciare",
    "impiastriccerebbero": "impiastricciare",
    "impiastriccerei": "impiastricciare",
    "impiastricceremmo": "impiastricciare",
    "impiastricceremo": "impiastricciare",
    "impiastriccereste": "impiastricciare",
    "impiastricceresti": "impiastricciare",
    "impiastriccerete": "impiastricciare",
    "impiastriccerà": "impiastricciare",
    "impiastriccerò": "impiastricciare",
    "impiastricci": "impiastricciare",
    "impiastriccia": "impiastricciare",
    "impiastricciai": "impiastricciare",
    "impiastricciammo": "impiastricciare",
    "impiastricciamo": "impiastricciare",
    "impiastriccian": "impiastricciare",
    "impiastricciando": "impiastricciare",
    "impiastricciano": "impiastricciare",
    "impiastricciante": "impiastricciare",
    "impiastriccianti": "impiastricciare",
    "impiastricciar": "impiastricciare",
    "impiastricciaron": "impiastricciare",
    "impiastricciarono": "impiastricciare",
    "impiastricciasse": "impiastricciare",
    "impiastricciasser": "impiastricciare",
    "impiastricciassero": "impiastricciare",
    "impiastricciassi": "impiastricciare",
    "impiastricciassimo": "impiastricciare",
    "impiastricciaste": "impiastricciare",
    "impiastricciasti": "impiastricciare",
    "impiastricciata": "impiastricciare",
    "impiastricciate": "impiastricciare",
    "impiastricciati": "impiastricciare",
    "impiastricciato": "impiastricciare",
    "impiastricciava": "impiastricciare",
    "impiastricciavamo": "impiastricciare",
    "impiastricciavan": "impiastricciare",
    "impiastricciavano": "impiastricciare",
    "impiastricciavate": "impiastricciare",
    "impiastricciavi": "impiastricciare",
    "impiastricciavo": "impiastricciare",
    "impiastriccin": "impiastricciare",
    "impiastriccino": "impiastricciare",
    "impiastriccio": "impiastricciare",
    "impiastricciò": "impiastricciare",
    "impiastrin": "impiastrare",
    "impiastrino": "impiastrare",
    "impiastro": "impiastrare",
    "impiastrò": "impiastrare",
    "impicca": "impiccare",
    "impiccagioni": "impiccagione",
    "impiccai": "impiccare",
    "impiccammo": "impiccare",
    "impiccan": "impiccare",
    "impiccando": "impiccare",
    "impiccano": "impiccare",
    "impiccante": "impiccare",
    "impiccanti": "impiccare",
    "impiccar": "impiccare",
    "impiccaron": "impiccare",
    "impiccarono": "impiccare",
    "impiccasse": "impiccare",
    "impiccasser": "impiccare",
    "impiccassero": "impiccare",
    "impiccassi": "impiccare",
    "impiccassimo": "impiccare",
    "impiccaste": "impiccare",
    "impiccasti": "impiccare",
    "impiccata": "impiccato",
    "impiccate": "impiccato",
    "impiccati": "impiccato",
    "impiccato": "impiccare",
    "impiccava": "impiccare",
    "impiccavamo": "impiccare",
    "impiccavan": "impiccare",
    "impiccavano": "impiccare",
    "impiccavate": "impiccare",
    "impiccavi": "impiccare",
    "impiccavo": "impiccare",
    "impiccerai": "impicciare",
    "impicceran": "impicciare",
    "impicceranno": "impicciare",
    "impiccerebbe": "impicciare",
    "impiccerebber": "impicciare",
    "impiccerebbero": "impicciare",
    "impiccerei": "impicciare",
    "impicceremmo": "impicciare",
    "impicceremo": "impicciare",
    "impiccereste": "impicciare",
    "impicceresti": "impicciare",
    "impiccerete": "impicciare",
    "impiccerà": "impicciare",
    "impiccerò": "impicciare",
    "impiccherai": "impiccare",
    "impiccheran": "impiccare",
    "impiccheranno": "impiccare",
    "impiccherebbe": "impiccare",
    "impiccherebber": "impiccare",
    "impiccherebbero": "impiccare",
    "impiccherei": "impiccare",
    "impiccheremmo": "impiccare",
    "impiccheremo": "impiccare",
    "impicchereste": "impiccare",
    "impiccheresti": "impiccare",
    "impiccherete": "impiccare",
    "impiccherà": "impiccare",
    "impiccherò": "impiccare",
    "impicchi": "impiccare",
    "impicchiamo": "impiccare",
    "impicchiate": "impiccare",
    "impicchin": "impiccare",
    "impicchino": "impiccare",
    "impicci": "impiccio",
    "impiccia": "impicciare",
    "impicciai": "impicciare",
    "impicciammo": "impicciare",
    "impicciamo": "impicciare",
    "impiccian": "impicciare",
    "impicciando": "impicciare",
    "impicciano": "impicciare",
    "impicciante": "impicciare",
    "impiccianti": "impicciare",
    "impicciar": "impicciare",
    "impicciaron": "impicciare",
    "impicciarono": "impicciare",
    "impicciasse": "impicciare",
    "impicciasser": "impicciare",
    "impicciassero": "impicciare",
    "impicciassi": "impicciare",
    "impicciassimo": "impicciare",
    "impicciaste": "impicciare",
    "impicciasti": "impicciare",
    "impicciata": "impicciare",
    "impicciate": "impicciare",
    "impicciati": "impicciare",
    "impicciato": "impicciare",
    "impicciava": "impicciare",
    "impicciavamo": "impicciare",
    "impicciavan": "impicciare",
    "impicciavano": "impicciare",
    "impicciavate": "impicciare",
    "impicciavi": "impicciare",
    "impicciavo": "impicciare",
    "impiccin": "impicciare",
    "impiccino": "impicciare",
    "impiccio": "impicciare",
    "impicciò": "impicciare",
    "impicco": "impiccare",
    "impiccò": "impiccare",
    "impiega": "impiegare",
    "impiegai": "impiegare",
    "impiegammo": "impiegare",
    "impiegan": "impiegare",
    "impiegando": "impiegare",
    "impiegano": "impiegare",
    "impiegante": "impiegare",
    "impieganti": "impiegare",
    "impiegar": "impiegare",
    "impiegaron": "impiegare",
    "impiegarono": "impiegare",
    "impiegasse": "impiegare",
    "impiegasser": "impiegare",
    "impiegassero": "impiegare",
    "impiegassi": "impiegare",
    "impiegassimo": "impiegare",
    "impiegaste": "impiegare",
    "impiegasti": "impiegare",
    "impiegata": "impiegato",
    "impiegate": "impiegato",
    "impiegati": "impiegato",
    "impiegatizi": "impiegatizio",
    "impiegatizia": "impiegatizio",
    "impiegatizie": "impiegatizio",
    "impiegato": "impiegare",
    "impiegava": "impiegare",
    "impiegavamo": "impiegare",
    "impiegavan": "impiegare",
    "impiegavano": "impiegare",
    "impiegavate": "impiegare",
    "impiegavi": "impiegare",
    "impiegavo": "impiegare",
    "impiegherai": "impiegare",
    "impiegheran": "impiegare",
    "impiegheranno": "impiegare",
    "impiegherebbe": "impiegare",
    "impiegherebber": "impiegare",
    "impiegherebbero": "impiegare",
    "impiegherei": "impiegare",
    "impiegheremmo": "impiegare",
    "impiegheremo": "impiegare",
    "impieghereste": "impiegare",
    "impiegheresti": "impiegare",
    "impiegherete": "impiegare",
    "impiegherà": "impiegare",
    "impiegherò": "impiegare",
    "impieghi": "impiego",
    "impieghiamo": "impiegare",
    "impieghiate": "impiegare",
    "impieghin": "impiegare",
    "impieghino": "impiegare",
    "impiego": "impiegare",
    "impiegò": "impiegare",
    "impietosa": "impietoso",
    "impietosan": "impietosire",
    "impietosano": "impietosire",
    "impietose": "impietoso",
    "impietosendo": "impietosire",
    "impietosente": "impietosire",
    "impietosenti": "impietosire",
    "impietosi": "impietoso",
    "impietosiamo": "impietosire",
    "impietosiate": "impietosire",
    "impietosii": "impietosire",
    "impietosimmo": "impietosire",
    "impietosir": "impietosire",
    "impietosirai": "impietosire",
    "impietosiran": "impietosire",
    "impietosiranno": "impietosire",
    "impietosirebbe": "impietosire",
    "impietosirebber": "impietosire",
    "impietosirebbero": "impietosire",
    "impietosirei": "impietosire",
    "impietosiremmo": "impietosire",
    "impietosiremo": "impietosire",
    "impietosireste": "impietosire",
    "impietosiresti": "impietosire",
    "impietosirete": "impietosire",
    "impietosiron": "impietosire",
    "impietosirono": "impietosire",
    "impietosirà": "impietosire",
    "impietosirò": "impietosire",
    "impietosisse": "impietosire",
    "impietosisser": "impietosire",
    "impietosissero": "impietosire",
    "impietosissi": "impietosire",
    "impietosissimo": "impietosire",
    "impietosiste": "impietosire",
    "impietosisti": "impietosire",
    "impietosita": "impietosire",
    "impietosite": "impietosire",
    "impietositi": "impietosire",
    "impietosito": "impietosire",
    "impietosiva": "impietosire",
    "impietosivamo": "impietosire",
    "impietosivan": "impietosire",
    "impietosivano": "impietosire",
    "impietosivate": "impietosire",
    "impietosivi": "impietosire",
    "impietosivo": "impietosire",
    "impietoso": "impietosire",
    "impietoson": "impietosire",
    "impietosono": "impietosire",
    "impietosì": "impietosire",
    "impietra": "impietrire",
    "impietran": "impietrire",
    "impietrano": "impietrire",
    "impietre": "impietrire",
    "impietrendo": "impietrire",
    "impietrente": "impietrire",
    "impietrenti": "impietrire",
    "impietri": "impietrire",
    "impietriamo": "impietrire",
    "impietriate": "impietrire",
    "impietrii": "impietrire",
    "impietrimmo": "impietrire",
    "impietrir": "impietrire",
    "impietrirai": "impietrire",
    "impietriran": "impietrire",
    "impietriranno": "impietrire",
    "impietrirebbe": "impietrire",
    "impietrirebber": "impietrire",
    "impietrirebbero": "impietrire",
    "impietrirei": "impietrire",
    "impietriremmo": "impietrire",
    "impietriremo": "impietrire",
    "impietrireste": "impietrire",
    "impietriresti": "impietrire",
    "impietrirete": "impietrire",
    "impietriron": "impietrire",
    "impietrirono": "impietrire",
    "impietrirà": "impietrire",
    "impietrirò": "impietrire",
    "impietrisse": "impietrire",
    "impietrisser": "impietrire",
    "impietrissero": "impietrire",
    "impietrissi": "impietrire",
    "impietrissimo": "impietrire",
    "impietriste": "impietrire",
    "impietristi": "impietrire",
    "impietrita": "impietrire",
    "impietrite": "impietrire",
    "impietriti": "impietrire",
    "impietrito": "impietrire",
    "impietriva": "impietrire",
    "impietrivamo": "impietrire",
    "impietrivan": "impietrire",
    "impietrivano": "impietrire",
    "impietrivate": "impietrire",
    "impietrivi": "impietrire",
    "impietrivo": "impietrire",
    "impietro": "impietrire",
    "impietron": "impietrire",
    "impietrono": "impietrire",
    "impietrì": "impietrire",
    "impigli": "impigliare",
    "impiglia": "impigliare",
    "impigliai": "impigliare",
    "impigliammo": "impigliare",
    "impigliamo": "impigliare",
    "impiglian": "impigliare",
    "impigliando": "impigliare",
    "impigliano": "impigliare",
    "impigliante": "impigliare",
    "impiglianti": "impigliare",
    "impigliar": "impigliare",
    "impigliaron": "impigliare",
    "impigliarono": "impigliare",
    "impigliasse": "impigliare",
    "impigliasser": "impigliare",
    "impigliassero": "impigliare",
    "impigliassi": "impigliare",
    "impigliassimo": "impigliare",
    "impigliaste": "impigliare",
    "impigliasti": "impigliare",
    "impigliata": "impigliare",
    "impigliate": "impigliare",
    "impigliati": "impigliare",
    "impigliato": "impigliare",
    "impigliava": "impigliare",
    "impigliavamo": "impigliare",
    "impigliavan": "impigliare",
    "impigliavano": "impigliare",
    "impigliavate": "impigliare",
    "impigliavi": "impigliare",
    "impigliavo": "impigliare",
    "impiglierai": "impigliare",
    "impiglieran": "impigliare",
    "impiglieranno": "impigliare",
    "impiglierebbe": "impigliare",
    "impiglierebber": "impigliare",
    "impiglierebbero": "impigliare",
    "impiglierei": "impigliare",
    "impiglieremmo": "impigliare",
    "impiglieremo": "impigliare",
    "impigliereste": "impigliare",
    "impiglieresti": "impigliare",
    "impiglierete": "impigliare",
    "impiglierà": "impigliare",
    "impiglierò": "impigliare",
    "impiglin": "impigliare",
    "impiglino": "impigliare",
    "impiglio": "impigliare",
    "impigliò": "impigliare",
    "impigra": "impigrire",
    "impigran": "impigrire",
    "impigrano": "impigrire",
    "impigre": "impigrire",
    "impigrendo": "impigrire",
    "impigrente": "impigrire",
    "impigrenti": "impigrire",
    "impigri": "impigrire",
    "impigriamo": "impigrire",
    "impigriate": "impigrire",
    "impigrii": "impigrire",
    "impigrimmo": "impigrire",
    "impigrir": "impigrire",
    "impigrirai": "impigrire",
    "impigriran": "impigrire",
    "impigriranno": "impigrire",
    "impigrirebbe": "impigrire",
    "impigrirebber": "impigrire",
    "impigrirebbero": "impigrire",
    "impigrirei": "impigrire",
    "impigriremmo": "impigrire",
    "impigriremo": "impigrire",
    "impigrireste": "impigrire",
    "impigriresti": "impigrire",
    "impigrirete": "impigrire",
    "impigriron": "impigrire",
    "impigrirono": "impigrire",
    "impigrirà": "impigrire",
    "impigrirò": "impigrire",
    "impigrisse": "impigrire",
    "impigrisser": "impigrire",
    "impigrissero": "impigrire",
    "impigrissi": "impigrire",
    "impigrissimo": "impigrire",
    "impigriste": "impigrire",
    "impigristi": "impigrire",
    "impigrita": "impigrire",
    "impigrite": "impigrire",
    "impigriti": "impigrire",
    "impigrito": "impigrire",
    "impigriva": "impigrire",
    "impigrivamo": "impigrire",
    "impigrivan": "impigrire",
    "impigrivano": "impigrire",
    "impigrivate": "impigrire",
    "impigrivi": "impigrire",
    "impigrivo": "impigrire",
    "impigro": "impigrire",
    "impigron": "impigrire",
    "impigrono": "impigrire",
    "impigrì": "impigrire",
    "impila": "impilare",
    "impilai": "impilare",
    "impilammo": "impilare",
    "impilan": "impilare",
    "impilando": "impilare",
    "impilano": "impilare",
    "impilante": "impilare",
    "impilanti": "impilare",
    "impilar": "impilare",
    "impilaron": "impilare",
    "impilarono": "impilare",
    "impilasse": "impilare",
    "impilasser": "impilare",
    "impilassero": "impilare",
    "impilassi": "impilare",
    "impilassimo": "impilare",
    "impilaste": "impilare",
    "impilasti": "impilare",
    "impilata": "impilare",
    "impilate": "impilare",
    "impilati": "impilare",
    "impilato": "impilare",
    "impilava": "impilare",
    "impilavamo": "impilare",
    "impilavan": "impilare",
    "impilavano": "impilare",
    "impilavate": "impilare",
    "impilavi": "impilare",
    "impilavo": "impilare",
    "impilerai": "impilare",
    "impileran": "impilare",
    "impileranno": "impilare",
    "impilerebbe": "impilare",
    "impilerebber": "impilare",
    "impilerebbero": "impilare",
    "impilerei": "impilare",
    "impileremmo": "impilare",
    "impileremo": "impilare",
    "impilereste": "impilare",
    "impileresti": "impilare",
    "impilerete": "impilare",
    "impilerà": "impilare",
    "impilerò": "impilare",
    "impili": "impilare",
    "impiliamo": "impilare",
    "impiliate": "impilare",
    "impilin": "impilare",
    "impilino": "impilare",
    "impilo": "impilare",
    "impilò": "impilare",
    "impingua": "impinguare",
    "impinguai": "impinguare",
    "impinguammo": "impinguare",
    "impinguan": "impinguare",
    "impinguando": "impinguare",
    "impinguano": "impinguare",
    "impinguante": "impinguare",
    "impinguanti": "impinguare",
    "impinguar": "impinguare",
    "impinguaron": "impinguare",
    "impinguarono": "impinguare",
    "impinguasse": "impinguare",
    "impinguasser": "impinguare",
    "impinguassero": "impinguare",
    "impinguassi": "impinguare",
    "impinguassimo": "impinguare",
    "impinguaste": "impinguare",
    "impinguasti": "impinguare",
    "impinguata": "impinguare",
    "impinguate": "impinguare",
    "impinguati": "impinguare",
    "impinguato": "impinguare",
    "impinguava": "impinguare",
    "impinguavamo": "impinguare",
    "impinguavan": "impinguare",
    "impinguavano": "impinguare",
    "impinguavate": "impinguare",
    "impinguavi": "impinguare",
    "impinguavo": "impinguare",
    "impinguerai": "impinguare",
    "impingueran": "impinguare",
    "impingueranno": "impinguare",
    "impinguerebbe": "impinguare",
    "impinguerebber": "impinguare",
    "impinguerebbero": "impinguare",
    "impinguerei": "impinguare",
    "impingueremmo": "impinguare",
    "impingueremo": "impinguare",
    "impinguereste": "impinguare",
    "impingueresti": "impinguare",
    "impinguerete": "impinguare",
    "impinguerà": "impinguare",
    "impinguerò": "impinguare",
    "impingui": "impinguare",
    "impinguiamo": "impinguare",
    "impinguiate": "impinguare",
    "impinguin": "impinguare",
    "impinguino": "impinguare",
    "impinguo": "impinguare",
    "impinguò": "impinguare",
    "impiomba": "impiombare",
    "impiombai": "impiombare",
    "impiombammo": "impiombare",
    "impiomban": "impiombare",
    "impiombando": "impiombare",
    "impiombano": "impiombare",
    "impiombante": "impiombare",
    "impiombanti": "impiombare",
    "impiombar": "impiombare",
    "impiombaron": "impiombare",
    "impiombarono": "impiombare",
    "impiombasse": "impiombare",
    "impiombasser": "impiombare",
    "impiombassero": "impiombare",
    "impiombassi": "impiombare",
    "impiombassimo": "impiombare",
    "impiombaste": "impiombare",
    "impiombasti": "impiombare",
    "impiombata": "impiombare",
    "impiombate": "impiombare",
    "impiombati": "impiombare",
    "impiombato": "impiombare",
    "impiombava": "impiombare",
    "impiombavamo": "impiombare",
    "impiombavan": "impiombare",
    "impiombavano": "impiombare",
    "impiombavate": "impiombare",
    "impiombavi": "impiombare",
    "impiombavo": "impiombare",
    "impiomberai": "impiombare",
    "impiomberan": "impiombare",
    "impiomberanno": "impiombare",
    "impiomberebbe": "impiombare",
    "impiomberebber": "impiombare",
    "impiomberebbero": "impiombare",
    "impiomberei": "impiombare",
    "impiomberemmo": "impiombare",
    "impiomberemo": "impiombare",
    "impiombereste": "impiombare",
    "impiomberesti": "impiombare",
    "impiomberete": "impiombare",
    "impiomberà": "impiombare",
    "impiomberò": "impiombare",
    "impiombi": "impiombare",
    "impiombiamo": "impiombare",
    "impiombiate": "impiombare",
    "impiombin": "impiombare",
    "impiombino": "impiombare",
    "impiombo": "impiombare",
    "impiombò": "impiombare",
    "impipa": "impipare",
    "impipai": "impipare",
    "impipammo": "impipare",
    "impipan": "impipare",
    "impipando": "impipare",
    "impipano": "impipare",
    "impipar": "impipare",
    "impiparon": "impipare",
    "impiparono": "impipare",
    "impipasse": "impipare",
    "impipasser": "impipare",
    "impipassero": "impipare",
    "impipassi": "impipare",
    "impipassimo": "impipare",
    "impipaste": "impipare",
    "impipasti": "impipare",
    "impipata": "impipare",
    "impipate": "impipare",
    "impipati": "impipare",
    "impipato": "impipare",
    "impipava": "impipare",
    "impipavamo": "impipare",
    "impipavan": "impipare",
    "impipavano": "impipare",
    "impipavate": "impipare",
    "impipavi": "impipare",
    "impipavo": "impipare",
    "impiperai": "impipare",
    "impiperan": "impipare",
    "impiperanno": "impipare",
    "impiperebbe": "impipare",
    "impiperebber": "impipare",
    "impiperebbero": "impipare",
    "impiperei": "impipare",
    "impiperemmo": "impipare",
    "impiperemo": "impipare",
    "impipereste": "impipare",
    "impiperesti": "impipare",
    "impiperete": "impipare",
    "impiperà": "impipare",
    "impiperò": "impipare",
    "impipi": "impipare",
    "impipiamo": "impipare",
    "impipiate": "impipare",
    "impipin": "impipare",
    "impipino": "impipare",
    "impipo": "impipare",
    "impipò": "impipare",
    "impiuma": "impiumare",
    "impiumai": "impiumare",
    "impiumammo": "impiumare",
    "impiuman": "impiumare",
    "impiumando": "impiumare",
    "impiumano": "impiumare",
    "impiumante": "impiumare",
    "impiumanti": "impiumare",
    "impiumar": "impiumare",
    "impiumaron": "impiumare",
    "impiumarono": "impiumare",
    "impiumasse": "impiumare",
    "impiumasser": "impiumare",
    "impiumassero": "impiumare",
    "impiumassi": "impiumare",
    "impiumassimo": "impiumare",
    "impiumaste": "impiumare",
    "impiumasti": "impiumare",
    "impiumata": "impiumare",
    "impiumate": "impiumare",
    "impiumati": "impiumare",
    "impiumato": "impiumare",
    "impiumava": "impiumare",
    "impiumavamo": "impiumare",
    "impiumavan": "impiumare",
    "impiumavano": "impiumare",
    "impiumavate": "impiumare",
    "impiumavi": "impiumare",
    "impiumavo": "impiumare",
    "impiumerai": "impiumare",
    "impiumeran": "impiumare",
    "impiumeranno": "impiumare",
    "impiumerebbe": "impiumare",
    "impiumerebber": "impiumare",
    "impiumerebbero": "impiumare",
    "impiumerei": "impiumare",
    "impiumeremmo": "impiumare",
    "impiumeremo": "impiumare",
    "impiumereste": "impiumare",
    "impiumeresti": "impiumare",
    "impiumerete": "impiumare",
    "impiumerà": "impiumare",
    "impiumerò": "impiumare",
    "impiumi": "impiumare",
    "impiumiamo": "impiumare",
    "impiumiate": "impiumare",
    "impiumin": "impiumare",
    "impiumino": "impiumare",
    "impiumo": "impiumare",
    "impiumò": "impiumare",
    "implacabili": "implacabile",
    "implementa": "implementare",
    "implementai": "implementare",
    "implementammo": "implementare",
    "implementan": "implementare",
    "implementando": "implementare",
    "implementano": "implementare",
    "implementante": "implementare",
    "implementanti": "implementare",
    "implementar": "implementare",
    "implementaron": "implementare",
    "implementarono": "implementare",
    "implementasse": "implementare",
    "implementasser": "implementare",
    "implementassero": "implementare",
    "implementassi": "implementare",
    "implementassimo": "implementare",
    "implementaste": "implementare",
    "implementasti": "implementare",
    "implementata": "implementare",
    "implementate": "implementare",
    "implementati": "implementare",
    "implementato": "implementare",
    "implementava": "implementare",
    "implementavamo": "implementare",
    "implementavan": "implementare",
    "implementavano": "implementare",
    "implementavate": "implementare",
    "implementavi": "implementare",
    "implementavo": "implementare",
    "implementerai": "implementare",
    "implementeran": "implementare",
    "implementeranno": "implementare",
    "implementerebbe": "implementare",
    "implementerebber": "implementare",
    "implementerebbero": "implementare",
    "implementerei": "implementare",
    "implementeremmo": "implementare",
    "implementeremo": "implementare",
    "implementereste": "implementare",
    "implementeresti": "implementare",
    "implementerete": "implementare",
    "implementerà": "implementare",
    "implementerò": "implementare",
    "implementi": "implementare",
    "implementiamo": "implementare",
    "implementiate": "implementare",
    "implementin": "implementare",
    "implementino": "implementare",
    "implemento": "implementare",
    "implementò": "implementare",
    "implica": "implicare",
    "implicai": "implicare",
    "implicammo": "implicare",
    "implican": "implicare",
    "implicando": "implicare",
    "implicano": "implicare",
    "implicante": "implicare",
    "implicanti": "implicare",
    "implicar": "implicare",
    "implicaron": "implicare",
    "implicarono": "implicare",
    "implicasse": "implicare",
    "implicasser": "implicare",
    "implicassero": "implicare",
    "implicassi": "implicare",
    "implicassimo": "implicare",
    "implicaste": "implicare",
    "implicasti": "implicare",
    "implicata": "implicare",
    "implicate": "implicare",
    "implicati": "implicare",
    "implicato": "implicare",
    "implicava": "implicare",
    "implicavamo": "implicare",
    "implicavan": "implicare",
    "implicavano": "implicare",
    "implicavate": "implicare",
    "implicavi": "implicare",
    "implicavo": "implicare",
    "implicazioni": "implicazione",
    "implicherai": "implicare",
    "implicheran": "implicare",
    "implicheranno": "implicare",
    "implicherebbe": "implicare",
    "implicherebber": "implicare",
    "implicherebbero": "implicare",
    "implicherei": "implicare",
    "implicheremmo": "implicare",
    "implicheremo": "implicare",
    "implichereste": "implicare",
    "implicheresti": "implicare",
    "implicherete": "implicare",
    "implicherà": "implicare",
    "implicherò": "implicare",
    "implichi": "implicare",
    "implichiamo": "implicare",
    "implichiate": "implicare",
    "implichin": "implicare",
    "implichino": "implicare",
    "implicita": "implicito",
    "implicite": "implicito",
    "impliciti": "implicito",
    "implico": "implicare",
    "implicò": "implicare",
    "implora": "implorare",
    "implorai": "implorare",
    "implorammo": "implorare",
    "imploran": "implorare",
    "implorando": "implorare",
    "implorano": "implorare",
    "implorante": "implorare",
    "imploranti": "implorare",
    "implorar": "implorare",
    "imploraron": "implorare",
    "implorarono": "implorare",
    "implorasse": "implorare",
    "implorasser": "implorare",
    "implorassero": "implorare",
    "implorassi": "implorare",
    "implorassimo": "implorare",
    "imploraste": "implorare",
    "implorasti": "implorare",
    "implorata": "implorare",
    "implorate": "implorare",
    "implorati": "implorare",
    "implorato": "implorare",
    "implorava": "implorare",
    "imploravamo": "implorare",
    "imploravan": "implorare",
    "imploravano": "implorare",
    "imploravate": "implorare",
    "imploravi": "implorare",
    "imploravo": "implorare",
    "implorazioni": "implorazione",
    "implorerai": "implorare",
    "imploreran": "implorare",
    "imploreranno": "implorare",
    "implorerebbe": "implorare",
    "implorerebber": "implorare",
    "implorerebbero": "implorare",
    "implorerei": "implorare",
    "imploreremmo": "implorare",
    "imploreremo": "implorare",
    "implorereste": "implorare",
    "imploreresti": "implorare",
    "implorerete": "implorare",
    "implorerà": "implorare",
    "implorerò": "implorare",
    "implori": "implorare",
    "imploriamo": "implorare",
    "imploriate": "implorare",
    "implorin": "implorare",
    "implorino": "implorare",
    "imploro": "implorare",
    "implorò": "implorare",
    "implosioni": "implosione",
    "impolitica": "impolitico",
    "impolitiche": "impolitico",
    "impolitici": "impolitico",
    "impollina": "impollinare",
    "impollinai": "impollinare",
    "impollinammo": "impollinare",
    "impollinan": "impollinare",
    "impollinando": "impollinare",
    "impollinano": "impollinare",
    "impollinante": "impollinare",
    "impollinanti": "impollinare",
    "impollinar": "impollinare",
    "impollinaron": "impollinare",
    "impollinarono": "impollinare",
    "impollinasse": "impollinare",
    "impollinasser": "impollinare",
    "impollinassero": "impollinare",
    "impollinassi": "impollinare",
    "impollinassimo": "impollinare",
    "impollinaste": "impollinare",
    "impollinasti": "impollinare",
    "impollinata": "impollinare",
    "impollinate": "impollinare",
    "impollinati": "impollinare",
    "impollinato": "impollinare",
    "impollinava": "impollinare",
    "impollinavamo": "impollinare",
    "impollinavan": "impollinare",
    "impollinavano": "impollinare",
    "impollinavate": "impollinare",
    "impollinavi": "impollinare",
    "impollinavo": "impollinare",
    "impollinerai": "impollinare",
    "impollineran": "impollinare",
    "impollineranno": "impollinare",
    "impollinerebbe": "impollinare",
    "impollinerebber": "impollinare",
    "impollinerebbero": "impollinare",
    "impollinerei": "impollinare",
    "impollineremmo": "impollinare",
    "impollineremo": "impollinare",
    "impollinereste": "impollinare",
    "impollineresti": "impollinare",
    "impollinerete": "impollinare",
    "impollinerà": "impollinare",
    "impollinerò": "impollinare",
    "impollini": "impollinare",
    "impolliniamo": "impollinare",
    "impolliniate": "impollinare",
    "impollinin": "impollinare",
    "impollinino": "impollinare",
    "impollino": "impollinare",
    "impollinò": "impollinare",
    "impoltrona": "impoltronire",
    "impoltronan": "impoltronire",
    "impoltronano": "impoltronire",
    "impoltrone": "impoltronire",
    "impoltronendo": "impoltronire",
    "impoltronente": "impoltronire",
    "impoltronenti": "impoltronire",
    "impoltroni": "impoltronire",
    "impoltroniamo": "impoltronire",
    "impoltroniate": "impoltronire",
    "impoltronii": "impoltronire",
    "impoltronimmo": "impoltronire",
    "impoltronir": "impoltronire",
    "impoltronirai": "impoltronire",
    "impoltroniran": "impoltronire",
    "impoltroniranno": "impoltronire",
    "impoltronirebbe": "impoltronire",
    "impoltronirebber": "impoltronire",
    "impoltronirebbero": "impoltronire",
    "impoltronirei": "impoltronire",
    "impoltroniremmo": "impoltronire",
    "impoltroniremo": "impoltronire",
    "impoltronireste": "impoltronire",
    "impoltroniresti": "impoltronire",
    "impoltronirete": "impoltronire",
    "impoltroniron": "impoltronire",
    "impoltronirono": "impoltronire",
    "impoltronirà": "impoltronire",
    "impoltronirò": "impoltronire",
    "impoltronisse": "impoltronire",
    "impoltronisser": "impoltronire",
    "impoltronissero": "impoltronire",
    "impoltronissi": "impoltronire",
    "impoltronissimo": "impoltronire",
    "impoltroniste": "impoltronire",
    "impoltronisti": "impoltronire",
    "impoltronita": "impoltronire",
    "impoltronite": "impoltronire",
    "impoltroniti": "impoltronire",
    "impoltronito": "impoltronire",
    "impoltroniva": "impoltronire",
    "impoltronivamo": "impoltronire",
    "impoltronivan": "impoltronire",
    "impoltronivano": "impoltronire",
    "impoltronivate": "impoltronire",
    "impoltronivi": "impoltronire",
    "impoltronivo": "impoltronire",
    "impoltrono": "impoltronire",
    "impoltronon": "impoltronire",
    "impoltronono": "impoltronire",
    "impoltronì": "impoltronire",
    "impolvera": "impolverare",
    "impolverai": "impolverare",
    "impolverammo": "impolverare",
    "impolveran": "impolverare",
    "impolverando": "impolverare",
    "impolverano": "impolverare",
    "impolverante": "impolverare",
    "impolveranti": "impolverare",
    "impolverar": "impolverare",
    "impolveraron": "impolverare",
    "impolverarono": "impolverare",
    "impolverasse": "impolverare",
    "impolverasser": "impolverare",
    "impolverassero": "impolverare",
    "impolverassi": "impolverare",
    "impolverassimo": "impolverare",
    "impolveraste": "impolverare",
    "impolverasti": "impolverare",
    "impolverata": "impolverare",
    "impolverate": "impolverare",
    "impolverati": "impolverare",
    "impolverato": "impolverare",
    "impolverava": "impolverare",
    "impolveravamo": "impolverare",
    "impolveravan": "impolverare",
    "impolveravano": "impolverare",
    "impolveravate": "impolverare",
    "impolveravi": "impolverare",
    "impolveravo": "impolverare",
    "impolvererai": "impolverare",
    "impolvereran": "impolverare",
    "impolvereranno": "impolverare",
    "impolvererebbe": "impolverare",
    "impolvererebber": "impolverare",
    "impolvererebbero": "impolverare",
    "impolvererei": "impolverare",
    "impolvereremmo": "impolverare",
    "impolvereremo": "impolverare",
    "impolverereste": "impolverare",
    "impolvereresti": "impolverare",
    "impolvererete": "impolverare",
    "impolvererà": "impolverare",
    "impolvererò": "impolverare",
    "impolveri": "impolverare",
    "impolveriamo": "impolverare",
    "impolveriate": "impolverare",
    "impolverin": "impolverare",
    "impolverino": "impolverare",
    "impolvero": "impolverare",
    "impolverò": "impolverare",
    "impomata": "impomatare",
    "impomatai": "impomatare",
    "impomatammo": "impomatare",
    "impomatan": "impomatare",
    "impomatando": "impomatare",
    "impomatano": "impomatare",
    "impomatante": "impomatare",
    "impomatanti": "impomatare",
    "impomatar": "impomatare",
    "impomataron": "impomatare",
    "impomatarono": "impomatare",
    "impomatasse": "impomatare",
    "impomatasser": "impomatare",
    "impomatassero": "impomatare",
    "impomatassi": "impomatare",
    "impomatassimo": "impomatare",
    "impomataste": "impomatare",
    "impomatasti": "impomatare",
    "impomatata": "impomatare",
    "impomatate": "impomatare",
    "impomatati": "impomatare",
    "impomatato": "impomatare",
    "impomatava": "impomatare",
    "impomatavamo": "impomatare",
    "impomatavan": "impomatare",
    "impomatavano": "impomatare",
    "impomatavate": "impomatare",
    "impomatavi": "impomatare",
    "impomatavo": "impomatare",
    "impomaterai": "impomatare",
    "impomateran": "impomatare",
    "impomateranno": "impomatare",
    "impomaterebbe": "impomatare",
    "impomaterebber": "impomatare",
    "impomaterebbero": "impomatare",
    "impomaterei": "impomatare",
    "impomateremmo": "impomatare",
    "impomateremo": "impomatare",
    "impomatereste": "impomatare",
    "impomateresti": "impomatare",
    "impomaterete": "impomatare",
    "impomaterà": "impomatare",
    "impomaterò": "impomatare",
    "impomati": "impomatare",
    "impomatiamo": "impomatare",
    "impomatiate": "impomatare",
    "impomatin": "impomatare",
    "impomatino": "impomatare",
    "impomato": "impomatare",
    "impomatò": "impomatare",
    "imponderabili": "imponderabile",
    "impone": "imporre",
    "imponemmo": "imporre",
    "imponendo": "imporre",
    "imponente": "imporre",
    "imponenti": "imporre",
    "imponenze": "imponenza",
    "imponesse": "imporre",
    "imponesser": "imporre",
    "imponessero": "imporre",
    "imponessi": "imporre",
    "imponessimo": "imporre",
    "imponeste": "imporre",
    "imponesti": "imporre",
    "imponete": "imporre",
    "imponeva": "imporre",
    "imponevamo": "imporre",
    "imponevan": "imporre",
    "imponevano": "imporre",
    "imponevate": "imporre",
    "imponevi": "imporre",
    "imponevo": "imporre",
    "imponga": "imporre",
    "impongan": "imporre",
    "impongano": "imporre",
    "impongo": "imporre",
    "impongon": "imporre",
    "impongono": "imporre",
    "imponi": "imporre",
    "imponiamo": "imporre",
    "imponiate": "imporre",
    "imponibili": "imponibile",
    "impopola": "impopolare",
    "impopolai": "impopolare",
    "impopolammo": "impopolare",
    "impopolan": "impopolare",
    "impopolando": "impopolare",
    "impopolano": "impopolare",
    "impopolante": "impopolare",
    "impopolanti": "impopolare",
    "impopolar": "impopolare",
    "impopolari": "impopolare",
    "impopolaron": "impopolare",
    "impopolarono": "impopolare",
    "impopolasse": "impopolare",
    "impopolasser": "impopolare",
    "impopolassero": "impopolare",
    "impopolassi": "impopolare",
    "impopolassimo": "impopolare",
    "impopolaste": "impopolare",
    "impopolasti": "impopolare",
    "impopolata": "impopolare",
    "impopolate": "impopolare",
    "impopolati": "impopolare",
    "impopolato": "impopolare",
    "impopolava": "impopolare",
    "impopolavamo": "impopolare",
    "impopolavan": "impopolare",
    "impopolavano": "impopolare",
    "impopolavate": "impopolare",
    "impopolavi": "impopolare",
    "impopolavo": "impopolare",
    "impopolerai": "impopolare",
    "impopoleran": "impopolare",
    "impopoleranno": "impopolare",
    "impopolerebbe": "impopolare",
    "impopolerebber": "impopolare",
    "impopolerebbero": "impopolare",
    "impopolerei": "impopolare",
    "impopoleremmo": "impopolare",
    "impopoleremo": "impopolare",
    "impopolereste": "impopolare",
    "impopoleresti": "impopolare",
    "impopolerete": "impopolare",
    "impopolerà": "impopolare",
    "impopolerò": "impopolare",
    "impopoli": "impopolare",
    "impopoliamo": "impopolare",
    "impopoliate": "impopolare",
    "impopolin": "impopolare",
    "impopolino": "impopolare",
    "impopolo": "impopolare",
    "impopolò": "impopolare",
    "imporpora": "imporporare",
    "imporporai": "imporporare",
    "imporporammo": "imporporare",
    "imporporan": "imporporare",
    "imporporando": "imporporare",
    "imporporano": "imporporare",
    "imporporante": "imporporare",
    "imporporanti": "imporporare",
    "imporporar": "imporporare",
    "imporporaron": "imporporare",
    "imporporarono": "imporporare",
    "imporporasse": "imporporare",
    "imporporasser": "imporporare",
    "imporporassero": "imporporare",
    "imporporassi": "imporporare",
    "imporporassimo": "imporporare",
    "imporporaste": "imporporare",
    "imporporasti": "imporporare",
    "imporporata": "imporporare",
    "imporporate": "imporporare",
    "imporporati": "imporporare",
    "imporporato": "imporporare",
    "imporporava": "imporporare",
    "imporporavamo": "imporporare",
    "imporporavan": "imporporare",
    "imporporavano": "imporporare",
    "imporporavate": "imporporare",
    "imporporavi": "imporporare",
    "imporporavo": "imporporare",
    "imporporerai": "imporporare",
    "imporporeran": "imporporare",
    "imporporeranno": "imporporare",
    "imporporerebbe": "imporporare",
    "imporporerebber": "imporporare",
    "imporporerebbero": "imporporare",
    "imporporerei": "imporporare",
    "imporporeremmo": "imporporare",
    "imporporeremo": "imporporare",
    "imporporereste": "imporporare",
    "imporporeresti": "imporporare",
    "imporporerete": "imporporare",
    "imporporerà": "imporporare",
    "imporporerò": "imporporare",
    "imporpori": "imporporare",
    "imporporiamo": "imporporare",
    "imporporiate": "imporporare",
    "imporporin": "imporporare",
    "imporporino": "imporporare",
    "imporporo": "imporporare",
    "imporporò": "imporporare",
    "imporr": "imporre",
    "imporrai": "imporre",
    "imporran": "imporre",
    "imporranno": "imporre",
    "imporrebbe": "imporre",
    "imporrebber": "imporre",
    "imporrebbero": "imporre",
    "imporrei": "imporre",
    "imporremmo": "imporre",
    "imporremo": "imporre",
    "imporreste": "imporre",
    "imporresti": "imporre",
    "imporrete": "imporre",
    "imporrà": "imporre",
    "imporrò": "imporre",
    "importa": "importare",
    "importai": "importare",
    "importammo": "importare",
    "importan": "importare",
    "importando": "importare",
    "importano": "importare",
    "importante": "importare",
    "importanti": "importare",
    "importanze": "importanza",
    "importar": "importare",
    "importaron": "importare",
    "importarono": "importare",
    "importasse": "importare",
    "importasser": "importare",
    "importassero": "importare",
    "importassi": "importare",
    "importassimo": "importare",
    "importaste": "importare",
    "importasti": "importare",
    "importata": "importare",
    "importate": "importare",
    "importati": "importare",
    "importato": "importare",
    "importatori": "importatore",
    "importatrice": "importatore",
    "importatrici": "importatore",
    "importava": "importare",
    "importavamo": "importare",
    "importavan": "importare",
    "importavano": "importare",
    "importavate": "importare",
    "importavi": "importare",
    "importavo": "importare",
    "importazioni": "importazione",
    "importerai": "importare",
    "importeran": "importare",
    "importeranno": "importare",
    "importerebbe": "importare",
    "importerebber": "importare",
    "importerebbero": "importare",
    "importerei": "importare",
    "importeremmo": "importare",
    "importeremo": "importare",
    "importereste": "importare",
    "importeresti": "importare",
    "importerete": "importare",
    "importerà": "importare",
    "importerò": "importare",
    "importi": "importo",
    "importiamo": "importare",
    "importiate": "importare",
    "importin": "importare",
    "importino": "importare",
    "importo": "importare",
    "importuna": "importuno",
    "importunai": "importunare",
    "importunammo": "importunare",
    "importunan": "importunare",
    "importunando": "importunare",
    "importunano": "importunare",
    "importunante": "importunare",
    "importunanti": "importunare",
    "importunar": "importunare",
    "importunaron": "importunare",
    "importunarono": "importunare",
    "importunasse": "importunare",
    "importunasser": "importunare",
    "importunassero": "importunare",
    "importunassi": "importunare",
    "importunassimo": "importunare",
    "importunaste": "importunare",
    "importunasti": "importunare",
    "importunata": "importunare",
    "importunate": "importunare",
    "importunati": "importunare",
    "importunato": "importunare",
    "importunava": "importunare",
    "importunavamo": "importunare",
    "importunavan": "importunare",
    "importunavano": "importunare",
    "importunavate": "importunare",
    "importunavi": "importunare",
    "importunavo": "importunare",
    "importune": "importuno",
    "importunerai": "importunare",
    "importuneran": "importunare",
    "importuneranno": "importunare",
    "importunerebbe": "importunare",
    "importunerebber": "importunare",
    "importunerebbero": "importunare",
    "importunerei": "importunare",
    "importuneremmo": "importunare",
    "importuneremo": "importunare",
    "importunereste": "importunare",
    "importuneresti": "importunare",
    "importunerete": "importunare",
    "importunerà": "importunare",
    "importunerò": "importunare",
    "importuni": "importuno",
    "importuniamo": "importunare",
    "importuniate": "importunare",
    "importunin": "importunare",
    "importunino": "importunare",
    "importuno": "importunare",
    "importunò": "importunare",
    "importò": "importare",
    "impose": "imporre",
    "imposer": "imporre",
    "imposero": "imporre",
    "imposi": "imporre",
    "impositiva": "impositivo",
    "impositive": "impositivo",
    "impositivi": "impositivo",
    "imposizioni": "imposizione",
    "impossessa": "impossessare",
    "impossessai": "impossessare",
    "impossessammo": "impossessare",
    "impossessan": "impossessare",
    "impossessando": "impossessare",
    "impossessano": "impossessare",
    "impossessar": "impossessare",
    "impossessaron": "impossessare",
    "impossessarono": "impossessare",
    "impossessasse": "impossessare",
    "impossessasser": "impossessare",
    "impossessassero": "impossessare",
    "impossessassi": "impossessare",
    "impossessassimo": "impossessare",
    "impossessaste": "impossessare",
    "impossessasti": "impossessare",
    "impossessata": "impossessare",
    "impossessate": "impossessare",
    "impossessati": "impossessare",
    "impossessato": "impossessare",
    "impossessava": "impossessare",
    "impossessavamo": "impossessare",
    "impossessavan": "impossessare",
    "impossessavano": "impossessare",
    "impossessavate": "impossessare",
    "impossessavi": "impossessare",
    "impossessavo": "impossessare",
    "impossesserai": "impossessare",
    "impossesseran": "impossessare",
    "impossesseranno": "impossessare",
    "impossesserebbe": "impossessare",
    "impossesserebber": "impossessare",
    "impossesserebbero": "impossessare",
    "impossesserei": "impossessare",
    "impossesseremmo": "impossessare",
    "impossesseremo": "impossessare",
    "impossessereste": "impossessare",
    "impossesseresti": "impossessare",
    "impossesserete": "impossessare",
    "impossesserà": "impossessare",
    "impossesserò": "impossessare",
    "impossessi": "impossessare",
    "impossessiamo": "impossessare",
    "impossessiate": "impossessare",
    "impossessin": "impossessare",
    "impossessino": "impossessare",
    "impossesso": "impossessare",
    "impossessò": "impossessare",
    "impossibili": "impossibile",
    "impossibilita": "impossibilitare",
    "impossibilitai": "impossibilitare",
    "impossibilitammo": "impossibilitare",
    "impossibilitan": "impossibilitare",
    "impossibilitando": "impossibilitare",
    "impossibilitano": "impossibilitare",
    "impossibilitante": "impossibilitare",
    "impossibilitanti": "impossibilitare",
    "impossibilitar": "impossibilitare",
    "impossibilitaron": "impossibilitare",
    "impossibilitarono": "impossibilitare",
    "impossibilitasse": "impossibilitare",
    "impossibilitasser": "impossibilitare",
    "impossibilitassero": "impossibilitare",
    "impossibilitassi": "impossibilitare",
    "impossibilitassimo": "impossibilitare",
    "impossibilitaste": "impossibilitare",
    "impossibilitasti": "impossibilitare",
    "impossibilitata": "impossibilitato",
    "impossibilitate": "impossibilitato",
    "impossibilitati": "impossibilitato",
    "impossibilitato": "impossibilitare",
    "impossibilitava": "impossibilitare",
    "impossibilitavamo": "impossibilitare",
    "impossibilitavan": "impossibilitare",
    "impossibilitavano": "impossibilitare",
    "impossibilitavate": "impossibilitare",
    "impossibilitavi": "impossibilitare",
    "impossibilitavo": "impossibilitare",
    "impossibiliterai": "impossibilitare",
    "impossibiliteran": "impossibilitare",
    "impossibiliteranno": "impossibilitare",
    "impossibiliterebbe": "impossibilitare",
    "impossibiliterebber": "impossibilitare",
    "impossibiliterebbero": "impossibilitare",
    "impossibiliterei": "impossibilitare",
    "impossibiliteremmo": "impossibilitare",
    "impossibiliteremo": "impossibilitare",
    "impossibilitereste": "impossibilitare",
    "impossibiliteresti": "impossibilitare",
    "impossibiliterete": "impossibilitare",
    "impossibiliterà": "impossibilitare",
    "impossibiliterò": "impossibilitare",
    "impossibiliti": "impossibilitare",
    "impossibilitiamo": "impossibilitare",
    "impossibilitiate": "impossibilitare",
    "impossibilitin": "impossibilitare",
    "impossibilitino": "impossibilitare",
    "impossibilito": "impossibilitare",
    "impossibilitò": "impossibilitare",
    "imposta": "impostare",
    "impostai": "impostare",
    "impostammo": "impostare",
    "impostan": "impostare",
    "impostando": "impostare",
    "impostano": "impostare",
    "impostante": "impostare",
    "impostanti": "impostare",
    "impostar": "impostare",
    "impostaron": "impostare",
    "impostarono": "impostare",
    "impostasse": "impostare",
    "impostasser": "impostare",
    "impostassero": "impostare",
    "impostassi": "impostare",
    "impostassimo": "impostare",
    "impostaste": "impostare",
    "impostasti": "impostare",
    "impostata": "impostare",
    "impostate": "impostare",
    "impostati": "impostare",
    "impostato": "impostare",
    "impostava": "impostare",
    "impostavamo": "impostare",
    "impostavan": "impostare",
    "impostavano": "impostare",
    "impostavate": "impostare",
    "impostavi": "impostare",
    "impostavo": "impostare",
    "impostazioni": "impostazione",
    "imposte": "imposta",
    "imposterai": "impostare",
    "imposteran": "impostare",
    "imposteranno": "impostare",
    "imposterebbe": "impostare",
    "imposterebber": "impostare",
    "imposterebbero": "impostare",
    "imposterei": "impostare",
    "imposteremmo": "impostare",
    "imposteremo": "impostare",
    "impostereste": "impostare",
    "imposteresti": "impostare",
    "imposterete": "impostare",
    "imposterà": "impostare",
    "imposterò": "impostare",
    "imposti": "impostare",
    "impostiamo": "impostare",
    "impostiate": "impostare",
    "impostin": "impostare",
    "impostino": "impostare",
    "imposto": "impostare",
    "impostori": "impostore",
    "imposture": "impostura",
    "impostò": "impostare",
    "impotenti": "impotente",
    "impotenze": "impotenza",
    "impoverendo": "impoverire",
    "impoverente": "impoverire",
    "impoverenti": "impoverire",
    "impoveriamo": "impoverire",
    "impoveriate": "impoverire",
    "impoverii": "impoverire",
    "impoverimenti": "impoverimento",
    "impoverimmo": "impoverire",
    "impoverir": "impoverire",
    "impoverirai": "impoverire",
    "impoveriran": "impoverire",
    "impoveriranno": "impoverire",
    "impoverirebbe": "impoverire",
    "impoverirebber": "impoverire",
    "impoverirebbero": "impoverire",
    "impoverirei": "impoverire",
    "impoveriremmo": "impoverire",
    "impoveriremo": "impoverire",
    "impoverireste": "impoverire",
    "impoveriresti": "impoverire",
    "impoverirete": "impoverire",
    "impoveriron": "impoverire",
    "impoverirono": "impoverire",
    "impoverirà": "impoverire",
    "impoverirò": "impoverire",
    "impoverisca": "impoverire",
    "impoveriscan": "impoverire",
    "impoveriscano": "impoverire",
    "impoverisce": "impoverire",
    "impoverisci": "impoverire",
    "impoverisco": "impoverire",
    "impoveriscon": "impoverire",
    "impoveriscono": "impoverire",
    "impoverisse": "impoverire",
    "impoverisser": "impoverire",
    "impoverissero": "impoverire",
    "impoverissi": "impoverire",
    "impoverissimo": "impoverire",
    "impoveriste": "impoverire",
    "impoveristi": "impoverire",
    "impoverita": "impoverire",
    "impoverite": "impoverire",
    "impoveriti": "impoverire",
    "impoverito": "impoverire",
    "impoveriva": "impoverire",
    "impoverivamo": "impoverire",
    "impoverivan": "impoverire",
    "impoverivano": "impoverire",
    "impoverivate": "impoverire",
    "impoverivi": "impoverire",
    "impoverivo": "impoverire",
    "impoverì": "impoverire",
    "impraticabili": "impraticabile",
    "impratichendo": "impratichire",
    "impratichente": "impratichire",
    "impratichenti": "impratichire",
    "impratichiamo": "impratichire",
    "impratichiate": "impratichire",
    "impratichii": "impratichire",
    "impratichimmo": "impratichire",
    "impratichir": "impratichire",
    "impratichirai": "impratichire",
    "impratichiran": "impratichire",
    "impratichiranno": "impratichire",
    "impratichirebbe": "impratichire",
    "impratichirebber": "impratichire",
    "impratichirebbero": "impratichire",
    "impratichirei": "impratichire",
    "impratichiremmo": "impratichire",
    "impratichiremo": "impratichire",
    "impratichireste": "impratichire",
    "impratichiresti": "impratichire",
    "impratichirete": "impratichire",
    "impratichiron": "impratichire",
    "impratichirono": "impratichire",
    "impratichirà": "impratichire",
    "impratichirò": "impratichire",
    "impratichisca": "impratichire",
    "impratichiscan": "impratichire",
    "impratichiscano": "impratichire",
    "impratichisce": "impratichire",
    "impratichisci": "impratichire",
    "impratichisco": "impratichire",
    "impratichiscon": "impratichire",
    "impratichiscono": "impratichire",
    "impratichisse": "impratichire",
    "impratichisser": "impratichire",
    "impratichissero": "impratichire",
    "impratichissi": "impratichire",
    "impratichissimo": "impratichire",
    "impratichiste": "impratichire",
    "impratichisti": "impratichire",
    "impratichita": "impratichire",
    "impratichite": "impratichire",
    "impratichiti": "impratichire",
    "impratichito": "impratichire",
    "impratichiva": "impratichire",
    "impratichivamo": "impratichire",
    "impratichivan": "impratichire",
    "impratichivano": "impratichire",
    "impratichivate": "impratichire",
    "impratichivi": "impratichire",
    "impratichivo": "impratichire",
    "impratichì": "impratichire",
    "impreca": "imprecare",
    "imprecai": "imprecare",
    "imprecammo": "imprecare",
    "imprecan": "imprecare",
    "imprecando": "imprecare",
    "imprecano": "imprecare",
    "imprecante": "imprecare",
    "imprecanti": "imprecare",
    "imprecar": "imprecare",
    "imprecaron": "imprecare",
    "imprecarono": "imprecare",
    "imprecasse": "imprecare",
    "imprecasser": "imprecare",
    "imprecassero": "imprecare",
    "imprecassi": "imprecare",
    "imprecassimo": "imprecare",
    "imprecaste": "imprecare",
    "imprecasti": "imprecare",
    "imprecata": "imprecare",
    "imprecate": "imprecare",
    "imprecati": "imprecare",
    "imprecato": "imprecare",
    "imprecava": "imprecare",
    "imprecavamo": "imprecare",
    "imprecavan": "imprecare",
    "imprecavano": "imprecare",
    "imprecavate": "imprecare",
    "imprecavi": "imprecare",
    "imprecavo": "imprecare",
    "imprecazioni": "imprecazione",
    "imprecherai": "imprecare",
    "imprecheran": "imprecare",
    "imprecheranno": "imprecare",
    "imprecherebbe": "imprecare",
    "imprecherebber": "imprecare",
    "imprecherebbero": "imprecare",
    "imprecherei": "imprecare",
    "imprecheremmo": "imprecare",
    "imprecheremo": "imprecare",
    "imprechereste": "imprecare",
    "imprecheresti": "imprecare",
    "imprecherete": "imprecare",
    "imprecherà": "imprecare",
    "imprecherò": "imprecare",
    "imprechi": "imprecare",
    "imprechiamo": "imprecare",
    "imprechiate": "imprecare",
    "imprechin": "imprecare",
    "imprechino": "imprecare",
    "imprecisa": "impreciso",
    "imprecisabili": "imprecisabile",
    "imprecisata": "imprecisato",
    "imprecisate": "imprecisato",
    "imprecisati": "imprecisato",
    "imprecise": "impreciso",
    "imprecisi": "impreciso",
    "imprecisioni": "imprecisione",
    "impreco": "imprecare",
    "imprecò": "imprecare",
    "impreditori": "impreditore",
    "impregna": "impregnare",
    "impregnai": "impregnare",
    "impregnammo": "impregnare",
    "impregnan": "impregnare",
    "impregnando": "impregnare",
    "impregnano": "impregnare",
    "impregnante": "impregnare",
    "impregnanti": "impregnare",
    "impregnar": "impregnare",
    "impregnaron": "impregnare",
    "impregnarono": "impregnare",
    "impregnasse": "impregnare",
    "impregnasser": "impregnare",
    "impregnassero": "impregnare",
    "impregnassi": "impregnare",
    "impregnassimo": "impregnare",
    "impregnaste": "impregnare",
    "impregnasti": "impregnare",
    "impregnata": "impregnare",
    "impregnate": "impregnare",
    "impregnati": "impregnare",
    "impregnato": "impregnare",
    "impregnava": "impregnare",
    "impregnavamo": "impregnare",
    "impregnavan": "impregnare",
    "impregnavano": "impregnare",
    "impregnavate": "impregnare",
    "impregnavi": "impregnare",
    "impregnavo": "impregnare",
    "impregnerai": "impregnare",
    "impregneran": "impregnare",
    "impregneranno": "impregnare",
    "impregnerebbe": "impregnare",
    "impregnerebber": "impregnare",
    "impregnerebbero": "impregnare",
    "impregnerei": "impregnare",
    "impregneremmo": "impregnare",
    "impregneremo": "impregnare",
    "impregnereste": "impregnare",
    "impregneresti": "impregnare",
    "impregnerete": "impregnare",
    "impregnerà": "impregnare",
    "impregnerò": "impregnare",
    "impregni": "impregnare",
    "impregniamo": "impregnare",
    "impregniate": "impregnare",
    "impregnin": "impregnare",
    "impregnino": "impregnare",
    "impregno": "impregnare",
    "impregnò": "impregnare",
    "imprenda": "imprendere",
    "imprendan": "imprendere",
    "imprendano": "imprendere",
    "imprende": "imprendere",
    "imprendemmo": "imprendere",
    "imprendendo": "imprendere",
    "imprendente": "imprendere",
    "imprendenti": "imprendere",
    "imprender": "imprendere",
    "imprenderai": "imprendere",
    "imprenderan": "imprendere",
    "imprenderanno": "imprendere",
    "imprenderebbe": "imprendere",
    "imprenderebber": "imprendere",
    "imprenderebbero": "imprendere",
    "imprenderei": "imprendere",
    "imprenderemmo": "imprendere",
    "imprenderemo": "imprendere",
    "imprendereste": "imprendere",
    "imprenderesti": "imprendere",
    "imprenderete": "imprendere",
    "imprenderà": "imprendere",
    "imprenderò": "imprendere",
    "imprendesse": "imprendere",
    "imprendesser": "imprendere",
    "imprendessero": "imprendere",
    "imprendessi": "imprendere",
    "imprendessimo": "imprendere",
    "imprendeste": "imprendere",
    "imprendesti": "imprendere",
    "imprendete": "imprendere",
    "imprendeva": "imprendere",
    "imprendevamo": "imprendere",
    "imprendevan": "imprendere",
    "imprendevano": "imprendere",
    "imprendevate": "imprendere",
    "imprendevi": "imprendere",
    "imprendevo": "imprendere",
    "imprendi": "imprendere",
    "imprendiamo": "imprendere",
    "imprendiate": "imprendere",
    "imprendibili": "imprendibile",
    "imprenditori": "imprenditore",
    "imprenditoriali": "imprenditoriale",
    "imprenditorie": "imprenditoria",
    "imprenditrici": "imprenditrice",
    "imprendo": "imprendere",
    "imprendon": "imprendere",
    "imprendono": "imprendere",
    "impreparata": "impreparato",
    "impreparate": "impreparato",
    "impreparati": "impreparato",
    "impresa": "imprendere",
    "impresari": "impresario",
    "imprescindibili": "imprescindibile",
    "imprescrittibili": "imprescrittibile",
    "imprese": "impresa",
    "impreser": "imprendere",
    "impresero": "imprendere",
    "impresi": "imprendere",
    "impreso": "imprendere",
    "impressa": "imprimere",
    "impresse": "imprimere",
    "impresser": "imprimere",
    "impressero": "imprimere",
    "impressi": "imprimere",
    "impressiona": "impressionare",
    "impressionabili": "impressionabile",
    "impressionai": "impressionare",
    "impressionammo": "impressionare",
    "impressionan": "impressionare",
    "impressionando": "impressionare",
    "impressionano": "impressionare",
    "impressionante": "impressionare",
    "impressionanti": "impressionare",
    "impressionar": "impressionare",
    "impressionaron": "impressionare",
    "impressionarono": "impressionare",
    "impressionasse": "impressionare",
    "impressionasser": "impressionare",
    "impressionassero": "impressionare",
    "impressionassi": "impressionare",
    "impressionassimo": "impressionare",
    "impressionaste": "impressionare",
    "impressionasti": "impressionare",
    "impressionata": "impressionare",
    "impressionate": "impressionare",
    "impressionati": "impressionare",
    "impressionato": "impressionare",
    "impressionava": "impressionare",
    "impressionavamo": "impressionare",
    "impressionavan": "impressionare",
    "impressionavano": "impressionare",
    "impressionavate": "impressionare",
    "impressionavi": "impressionare",
    "impressionavo": "impressionare",
    "impressionerai": "impressionare",
    "impressioneran": "impressionare",
    "impressioneranno": "impressionare",
    "impressionerebbe": "impressionare",
    "impressionerebber": "impressionare",
    "impressionerebbero": "impressionare",
    "impressionerei": "impressionare",
    "impressioneremmo": "impressionare",
    "impressioneremo": "impressionare",
    "impressionereste": "impressionare",
    "impressioneresti": "impressionare",
    "impressionerete": "impressionare",
    "impressionerà": "impressionare",
    "impressionerò": "impressionare",
    "impressioni": "impressione",
    "impressioniamo": "impressionare",
    "impressioniate": "impressionare",
    "impressionin": "impressionare",
    "impressionino": "impressionare",
    "impressioniste": "impressionista",
    "impressionisti": "impressionista",
    "impressionistica": "impressionistico",
    "impressionistiche": "impressionistico",
    "impressionistici": "impressionistico",
    "impressiono": "impressionare",
    "impressionò": "impressionare",
    "impresso": "imprimere",
    "impresta": "imprestare",
    "imprestai": "imprestare",
    "imprestammo": "imprestare",
    "imprestan": "imprestare",
    "imprestando": "imprestare",
    "imprestano": "imprestare",
    "imprestante": "imprestare",
    "imprestanti": "imprestare",
    "imprestar": "imprestare",
    "imprestaron": "imprestare",
    "imprestarono": "imprestare",
    "imprestasse": "imprestare",
    "imprestasser": "imprestare",
    "imprestassero": "imprestare",
    "imprestassi": "imprestare",
    "imprestassimo": "imprestare",
    "imprestaste": "imprestare",
    "imprestasti": "imprestare",
    "imprestata": "imprestare",
    "imprestate": "imprestare",
    "imprestati": "imprestare",
    "imprestato": "imprestare",
    "imprestava": "imprestare",
    "imprestavamo": "imprestare",
    "imprestavan": "imprestare",
    "imprestavano": "imprestare",
    "imprestavate": "imprestare",
    "imprestavi": "imprestare",
    "imprestavo": "imprestare",
    "impresterai": "imprestare",
    "impresteran": "imprestare",
    "impresteranno": "imprestare",
    "impresterebbe": "imprestare",
    "impresterebber": "imprestare",
    "impresterebbero": "imprestare",
    "impresterei": "imprestare",
    "impresteremmo": "imprestare",
    "impresteremo": "imprestare",
    "imprestereste": "imprestare",
    "impresteresti": "imprestare",
    "impresterete": "imprestare",
    "impresterà": "imprestare",
    "impresterò": "imprestare",
    "impresti": "imprestare",
    "imprestiamo": "imprestare",
    "imprestiate": "imprestare",
    "imprestin": "imprestare",
    "imprestino": "imprestare",
    "impresto": "imprestare",
    "imprestò": "imprestare",
    "impresè": "imprendere",
    "imprevedibili": "imprevedibile",
    "imprevidenti": "imprevidente",
    "imprevista": "imprevisto",
    "impreviste": "imprevisto",
    "imprevisti": "imprevisto",
    "impreziosendo": "impreziosire",
    "impreziosente": "impreziosire",
    "impreziosenti": "impreziosire",
    "impreziosiamo": "impreziosire",
    "impreziosiate": "impreziosire",
    "impreziosii": "impreziosire",
    "impreziosimmo": "impreziosire",
    "impreziosir": "impreziosire",
    "impreziosirai": "impreziosire",
    "impreziosiran": "impreziosire",
    "impreziosiranno": "impreziosire",
    "impreziosirebbe": "impreziosire",
    "impreziosirebber": "impreziosire",
    "impreziosirebbero": "impreziosire",
    "impreziosirei": "impreziosire",
    "impreziosiremmo": "impreziosire",
    "impreziosiremo": "impreziosire",
    "impreziosireste": "impreziosire",
    "impreziosiresti": "impreziosire",
    "impreziosirete": "impreziosire",
    "impreziosiron": "impreziosire",
    "impreziosirono": "impreziosire",
    "impreziosirà": "impreziosire",
    "impreziosirò": "impreziosire",
    "impreziosisca": "impreziosire",
    "impreziosiscan": "impreziosire",
    "impreziosiscano": "impreziosire",
    "impreziosisce": "impreziosire",
    "impreziosisci": "impreziosire",
    "impreziosisco": "impreziosire",
    "impreziosiscon": "impreziosire",
    "impreziosiscono": "impreziosire",
    "impreziosisse": "impreziosire",
    "impreziosisser": "impreziosire",
    "impreziosissero": "impreziosire",
    "impreziosissi": "impreziosire",
    "impreziosissimo": "impreziosire",
    "impreziosiste": "impreziosire",
    "impreziosisti": "impreziosire",
    "impreziosita": "impreziosire",
    "impreziosite": "impreziosire",
    "impreziositi": "impreziosire",
    "impreziosito": "impreziosire",
    "impreziosiva": "impreziosire",
    "impreziosivamo": "impreziosire",
    "impreziosivan": "impreziosire",
    "impreziosivano": "impreziosire",
    "impreziosivate": "impreziosire",
    "impreziosivi": "impreziosire",
    "impreziosivo": "impreziosire",
    "impreziosì": "impreziosire",
    "imprigiona": "imprigionare",
    "imprigionai": "imprigionare",
    "imprigionammo": "imprigionare",
    "imprigionan": "imprigionare",
    "imprigionando": "imprigionare",
    "imprigionano": "imprigionare",
    "imprigionante": "imprigionare",
    "imprigionanti": "imprigionare",
    "imprigionar": "imprigionare",
    "imprigionaron": "imprigionare",
    "imprigionarono": "imprigionare",
    "imprigionasse": "imprigionare",
    "imprigionasser": "imprigionare",
    "imprigionassero": "imprigionare",
    "imprigionassi": "imprigionare",
    "imprigionassimo": "imprigionare",
    "imprigionaste": "imprigionare",
    "imprigionasti": "imprigionare",
    "imprigionata": "imprigionare",
    "imprigionate": "imprigionare",
    "imprigionati": "imprigionare",
    "imprigionato": "imprigionare",
    "imprigionava": "imprigionare",
    "imprigionavamo": "imprigionare",
    "imprigionavan": "imprigionare",
    "imprigionavano": "imprigionare",
    "imprigionavate": "imprigionare",
    "imprigionavi": "imprigionare",
    "imprigionavo": "imprigionare",
    "imprigionerai": "imprigionare",
    "imprigioneran": "imprigionare",
    "imprigioneranno": "imprigionare",
    "imprigionerebbe": "imprigionare",
    "imprigionerebber": "imprigionare",
    "imprigionerebbero": "imprigionare",
    "imprigionerei": "imprigionare",
    "imprigioneremmo": "imprigionare",
    "imprigioneremo": "imprigionare",
    "imprigionereste": "imprigionare",
    "imprigioneresti": "imprigionare",
    "imprigionerete": "imprigionare",
    "imprigionerà": "imprigionare",
    "imprigionerò": "imprigionare",
    "imprigioni": "imprigionare",
    "imprigioniamo": "imprigionare",
    "imprigioniate": "imprigionare",
    "imprigionin": "imprigionare",
    "imprigionino": "imprigionare",
    "imprigiono": "imprigionare",
    "imprigionò": "imprigionare",
    "imprima": "imprimere",
    "impriman": "imprimere",
    "imprimano": "imprimere",
    "imprime": "imprimere",
    "imprimemmo": "imprimere",
    "imprimendo": "imprimere",
    "imprimente": "imprimere",
    "imprimenti": "imprimere",
    "imprimer": "imprimere",
    "imprimerai": "imprimere",
    "imprimeran": "imprimere",
    "imprimeranno": "imprimere",
    "imprimerebbe": "imprimere",
    "imprimerebber": "imprimere",
    "imprimerebbero": "imprimere",
    "imprimerei": "imprimere",
    "imprimeremmo": "imprimere",
    "imprimeremo": "imprimere",
    "imprimereste": "imprimere",
    "imprimeresti": "imprimere",
    "imprimerete": "imprimere",
    "imprimerà": "imprimere",
    "imprimerò": "imprimere",
    "imprimesse": "imprimere",
    "imprimesser": "imprimere",
    "imprimessero": "imprimere",
    "imprimessi": "imprimere",
    "imprimessimo": "imprimere",
    "imprimeste": "imprimere",
    "imprimesti": "imprimere",
    "imprimete": "imprimere",
    "imprimeva": "imprimere",
    "imprimevamo": "imprimere",
    "imprimevan": "imprimere",
    "imprimevano": "imprimere",
    "imprimevate": "imprimere",
    "imprimevi": "imprimere",
    "imprimevo": "imprimere",
    "imprimi": "imprimere",
    "imprimiamo": "imprimere",
    "imprimiate": "imprimere",
    "imprimo": "imprimere",
    "imprimon": "imprimere",
    "imprimono": "imprimere",
    "improba": "improbo",
    "improbabili": "improbabile",
    "improbe": "improbo",
    "improbi": "improbo",
    "improduttiva": "improduttivo",
    "improduttive": "improduttivo",
    "improduttivi": "improduttivo",
    "impronta": "impronto",
    "improntai": "improntare",
    "improntammo": "improntare",
    "improntan": "improntare",
    "improntando": "improntare",
    "improntano": "improntare",
    "improntante": "improntare",
    "improntanti": "improntare",
    "improntar": "improntare",
    "improntaron": "improntare",
    "improntarono": "improntare",
    "improntasse": "improntare",
    "improntasser": "improntare",
    "improntassero": "improntare",
    "improntassi": "improntare",
    "improntassimo": "improntare",
    "improntaste": "improntare",
    "improntasti": "improntare",
    "improntata": "improntato",
    "improntate": "improntato",
    "improntati": "improntato",
    "improntato": "improntare",
    "improntava": "improntare",
    "improntavamo": "improntare",
    "improntavan": "improntare",
    "improntavano": "improntare",
    "improntavate": "improntare",
    "improntavi": "improntare",
    "improntavo": "improntare",
    "impronte": "impronto",
    "impronterai": "improntare",
    "impronteran": "improntare",
    "impronteranno": "improntare",
    "impronterebbe": "improntare",
    "impronterebber": "improntare",
    "impronterebbero": "improntare",
    "impronterei": "improntare",
    "impronteremmo": "improntare",
    "impronteremo": "improntare",
    "improntereste": "improntare",
    "impronteresti": "improntare",
    "impronterete": "improntare",
    "impronterà": "improntare",
    "impronterò": "improntare",
    "impronti": "impronto",
    "improntiamo": "improntare",
    "improntiate": "improntare",
    "improntin": "improntare",
    "improntino": "improntare",
    "improntitudini": "improntitudine",
    "impronto": "improntare",
    "improntò": "improntare",
    "improperi": "improperio",
    "improponibili": "improponibile",
    "impropri": "improprio",
    "impropria": "improprio",
    "improprie": "improprio",
    "improrogabili": "improrogabile",
    "improvvida": "improvvido",
    "improvvide": "improvvido",
    "improvvidi": "improvvido",
    "improvvisa": "improvviso",
    "improvvisai": "improvvisare",
    "improvvisammo": "improvvisare",
    "improvvisan": "improvvisare",
    "improvvisando": "improvvisare",
    "improvvisano": "improvvisare",
    "improvvisante": "improvvisare",
    "improvvisanti": "improvvisare",
    "improvvisar": "improvvisare",
    "improvvisaron": "improvvisare",
    "improvvisarono": "improvvisare",
    "improvvisasse": "improvvisare",
    "improvvisasser": "improvvisare",
    "improvvisassero": "improvvisare",
    "improvvisassi": "improvvisare",
    "improvvisassimo": "improvvisare",
    "improvvisaste": "improvvisare",
    "improvvisasti": "improvvisare",
    "improvvisata": "improvvisare",
    "improvvisate": "improvvisata",
    "improvvisati": "improvvisare",
    "improvvisato": "improvvisare",
    "improvvisatori": "improvvisatore",
    "improvvisava": "improvvisare",
    "improvvisavamo": "improvvisare",
    "improvvisavan": "improvvisare",
    "improvvisavano": "improvvisare",
    "improvvisavate": "improvvisare",
    "improvvisavi": "improvvisare",
    "improvvisavo": "improvvisare",
    "improvvisazioni": "improvvisazione",
    "improvvise": "improvviso",
    "improvviserai": "improvvisare",
    "improvviseran": "improvvisare",
    "improvviseranno": "improvvisare",
    "improvviserebbe": "improvvisare",
    "improvviserebber": "improvvisare",
    "improvviserebbero": "improvvisare",
    "improvviserei": "improvvisare",
    "improvviseremmo": "improvvisare",
    "improvviseremo": "improvvisare",
    "improvvisereste": "improvvisare",
    "improvviseresti": "improvvisare",
    "improvviserete": "improvvisare",
    "improvviserà": "improvvisare",
    "improvviserò": "improvvisare",
    "improvvisi": "improvviso",
    "improvvisiamo": "improvvisare",
    "improvvisiate": "improvvisare",
    "improvvisin": "improvvisare",
    "improvvisino": "improvvisare",
    "improvviso": "improvvisare",
    "improvvisò": "improvvisare",
    "imprudenti": "imprudente",
    "imprudenze": "imprudenza",
    "impudenti": "impudente",
    "impudenze": "impudenza",
    "impudica": "impudico",
    "impudiche": "impudico",
    "impudici": "impudico",
    "impugna": "impugnare",
    "impugnai": "impugnare",
    "impugnammo": "impugnare",
    "impugnan": "impugnare",
    "impugnando": "impugnare",
    "impugnano": "impugnare",
    "impugnante": "impugnare",
    "impugnanti": "impugnare",
    "impugnar": "impugnare",
    "impugnaron": "impugnare",
    "impugnarono": "impugnare",
    "impugnasse": "impugnare",
    "impugnasser": "impugnare",
    "impugnassero": "impugnare",
    "impugnassi": "impugnare",
    "impugnassimo": "impugnare",
    "impugnaste": "impugnare",
    "impugnasti": "impugnare",
    "impugnata": "impugnare",
    "impugnate": "impugnare",
    "impugnati": "impugnare",
    "impugnato": "impugnare",
    "impugnature": "impugnatura",
    "impugnava": "impugnare",
    "impugnavamo": "impugnare",
    "impugnavan": "impugnare",
    "impugnavano": "impugnare",
    "impugnavate": "impugnare",
    "impugnavi": "impugnare",
    "impugnavo": "impugnare",
    "impugnazioni": "impugnazione",
    "impugnerai": "impugnare",
    "impugneran": "impugnare",
    "impugneranno": "impugnare",
    "impugnerebbe": "impugnare",
    "impugnerebber": "impugnare",
    "impugnerebbero": "impugnare",
    "impugnerei": "impugnare",
    "impugneremmo": "impugnare",
    "impugneremo": "impugnare",
    "impugnereste": "impugnare",
    "impugneresti": "impugnare",
    "impugnerete": "impugnare",
    "impugnerà": "impugnare",
    "impugnerò": "impugnare",
    "impugni": "impugnare",
    "impugniamo": "impugnare",
    "impugniate": "impugnare",
    "impugnin": "impugnare",
    "impugnino": "impugnare",
    "impugno": "impugnare",
    "impugnò": "impugnare",
    "impulsi": "impulso",
    "impulsiva": "impulsivo",
    "impulsive": "impulsivo",
    "impulsivi": "impulsivo",
    "impunita": "impunito",
    "impunite": "impunito",
    "impuniti": "impunito",
    "impunta": "impuntare",
    "impuntai": "impuntare",
    "impuntammo": "impuntare",
    "impuntan": "impuntare",
    "impuntando": "impuntare",
    "impuntano": "impuntare",
    "impuntante": "impuntare",
    "impuntanti": "impuntare",
    "impuntar": "impuntare",
    "impuntaron": "impuntare",
    "impuntarono": "impuntare",
    "impuntasse": "impuntare",
    "impuntasser": "impuntare",
    "impuntassero": "impuntare",
    "impuntassi": "impuntare",
    "impuntassimo": "impuntare",
    "impuntaste": "impuntare",
    "impuntasti": "impuntare",
    "impuntata": "impuntare",
    "impuntate": "impuntare",
    "impuntati": "impuntare",
    "impuntato": "impuntare",
    "impuntature": "impuntatura",
    "impuntava": "impuntare",
    "impuntavamo": "impuntare",
    "impuntavan": "impuntare",
    "impuntavano": "impuntare",
    "impuntavate": "impuntare",
    "impuntavi": "impuntare",
    "impuntavo": "impuntare",
    "impunterai": "impuntare",
    "impunteran": "impuntare",
    "impunteranno": "impuntare",
    "impunterebbe": "impuntare",
    "impunterebber": "impuntare",
    "impunterebbero": "impuntare",
    "impunterei": "impuntare",
    "impunteremmo": "impuntare",
    "impunteremo": "impuntare",
    "impuntereste": "impuntare",
    "impunteresti": "impuntare",
    "impunterete": "impuntare",
    "impunterà": "impuntare",
    "impunterò": "impuntare",
    "impunti": "impuntare",
    "impuntiamo": "impuntare",
    "impuntiate": "impuntare",
    "impuntin": "impuntare",
    "impuntino": "impuntare",
    "impunto": "impuntare",
    "impuntura": "impunturare",
    "impunturai": "impunturare",
    "impunturammo": "impunturare",
    "impunturan": "impunturare",
    "impunturando": "impunturare",
    "impunturano": "impunturare",
    "impunturante": "impunturare",
    "impunturanti": "impunturare",
    "impunturar": "impunturare",
    "impunturaron": "impunturare",
    "impunturarono": "impunturare",
    "impunturasse": "impunturare",
    "impunturasser": "impunturare",
    "impunturassero": "impunturare",
    "impunturassi": "impunturare",
    "impunturassimo": "impunturare",
    "impunturaste": "impunturare",
    "impunturasti": "impunturare",
    "impunturata": "impunturare",
    "impunturate": "impunturare",
    "impunturati": "impunturare",
    "impunturato": "impunturare",
    "impunturava": "impunturare",
    "impunturavamo": "impunturare",
    "impunturavan": "impunturare",
    "impunturavano": "impunturare",
    "impunturavate": "impunturare",
    "impunturavi": "impunturare",
    "impunturavo": "impunturare",
    "impunturerai": "impunturare",
    "impuntureran": "impunturare",
    "impuntureranno": "impunturare",
    "impunturerebbe": "impunturare",
    "impunturerebber": "impunturare",
    "impunturerebbero": "impunturare",
    "impunturerei": "impunturare",
    "impuntureremmo": "impunturare",
    "impuntureremo": "impunturare",
    "impunturereste": "impunturare",
    "impuntureresti": "impunturare",
    "impunturerete": "impunturare",
    "impunturerà": "impunturare",
    "impunturerò": "impunturare",
    "impunturi": "impunturare",
    "impunturiamo": "impunturare",
    "impunturiate": "impunturare",
    "impunturin": "impunturare",
    "impunturino": "impunturare",
    "impunturo": "impunturare",
    "impunturò": "impunturare",
    "impuntò": "impuntare",
    "impura": "impuro",
    "impure": "impuro",
    "impuri": "impuro",
    "imputa": "imputare",
    "imputabili": "imputabile",
    "imputai": "imputare",
    "imputammo": "imputare",
    "imputan": "imputare",
    "imputando": "imputare",
    "imputano": "imputare",
    "imputante": "imputare",
    "imputanti": "imputare",
    "imputar": "imputare",
    "imputaron": "imputare",
    "imputarono": "imputare",
    "imputasse": "imputare",
    "imputasser": "imputare",
    "imputassero": "imputare",
    "imputassi": "imputare",
    "imputassimo": "imputare",
    "imputaste": "imputare",
    "imputasti": "imputare",
    "imputata": "imputare",
    "imputate": "imputata",
    "imputati": "imputato",
    "imputato": "imputare",
    "imputava": "imputare",
    "imputavamo": "imputare",
    "imputavan": "imputare",
    "imputavano": "imputare",
    "imputavate": "imputare",
    "imputavi": "imputare",
    "imputavo": "imputare",
    "imputazioni": "imputazione",
    "imputerai": "imputare",
    "imputeran": "imputare",
    "imputeranno": "imputare",
    "imputerebbe": "imputare",
    "imputerebber": "imputare",
    "imputerebbero": "imputare",
    "imputerei": "imputare",
    "imputeremmo": "imputare",
    "imputeremo": "imputare",
    "imputereste": "imputare",
    "imputeresti": "imputare",
    "imputerete": "imputare",
    "imputerà": "imputare",
    "imputerò": "imputare",
    "imputi": "imputare",
    "imputiamo": "imputare",
    "imputiate": "imputare",
    "imputin": "imputare",
    "imputino": "imputare",
    "imputo": "imputare",
    "imputrida": "imputridire",
    "imputridan": "imputridire",
    "imputridano": "imputridire",
    "imputride": "imputridire",
    "imputridendo": "imputridire",
    "imputridente": "imputridire",
    "imputridenti": "imputridire",
    "imputridi": "imputridire",
    "imputridiamo": "imputridire",
    "imputridiate": "imputridire",
    "imputridii": "imputridire",
    "imputridimmo": "imputridire",
    "imputridir": "imputridire",
    "imputridirai": "imputridire",
    "imputridiran": "imputridire",
    "imputridiranno": "imputridire",
    "imputridirebbe": "imputridire",
    "imputridirebber": "imputridire",
    "imputridirebbero": "imputridire",
    "imputridirei": "imputridire",
    "imputridiremmo": "imputridire",
    "imputridiremo": "imputridire",
    "imputridireste": "imputridire",
    "imputridiresti": "imputridire",
    "imputridirete": "imputridire",
    "imputridiron": "imputridire",
    "imputridirono": "imputridire",
    "imputridirà": "imputridire",
    "imputridirò": "imputridire",
    "imputridisse": "imputridire",
    "imputridisser": "imputridire",
    "imputridissero": "imputridire",
    "imputridissi": "imputridire",
    "imputridissimo": "imputridire",
    "imputridiste": "imputridire",
    "imputridisti": "imputridire",
    "imputridita": "imputridire",
    "imputridite": "imputridire",
    "imputriditi": "imputridire",
    "imputridito": "imputridire",
    "imputridiva": "imputridire",
    "imputridivamo": "imputridire",
    "imputridivan": "imputridire",
    "imputridivano": "imputridire",
    "imputridivate": "imputridire",
    "imputridivi": "imputridire",
    "imputridivo": "imputridire",
    "imputrido": "imputridire",
    "imputridon": "imputridire",
    "imputridono": "imputridire",
    "imputridì": "imputridire",
    "imputò": "imputare",
    "impuzzolenta": "impuzzolentire",
    "impuzzolentan": "impuzzolentire",
    "impuzzolentano": "impuzzolentire",
    "impuzzolente": "impuzzolentire",
    "impuzzolentendo": "impuzzolentire",
    "impuzzolentente": "impuzzolentire",
    "impuzzolententi": "impuzzolentire",
    "impuzzolenti": "impuzzolentire",
    "impuzzolentiamo": "impuzzolentire",
    "impuzzolentiate": "impuzzolentire",
    "impuzzolentii": "impuzzolentire",
    "impuzzolentimmo": "impuzzolentire",
    "impuzzolentir": "impuzzolentire",
    "impuzzolentirai": "impuzzolentire",
    "impuzzolentiran": "impuzzolentire",
    "impuzzolentiranno": "impuzzolentire",
    "impuzzolentirebbe": "impuzzolentire",
    "impuzzolentirebber": "impuzzolentire",
    "impuzzolentirebbero": "impuzzolentire",
    "impuzzolentirei": "impuzzolentire",
    "impuzzolentiremmo": "impuzzolentire",
    "impuzzolentiremo": "impuzzolentire",
    "impuzzolentireste": "impuzzolentire",
    "impuzzolentiresti": "impuzzolentire",
    "impuzzolentirete": "impuzzolentire",
    "impuzzolentiron": "impuzzolentire",
    "impuzzolentirono": "impuzzolentire",
    "impuzzolentirà": "impuzzolentire",
    "impuzzolentirò": "impuzzolentire",
    "impuzzolentisse": "impuzzolentire",
    "impuzzolentisser": "impuzzolentire",
    "impuzzolentissero": "impuzzolentire",
    "impuzzolentissi": "impuzzolentire",
    "impuzzolentissimo": "impuzzolentire",
    "impuzzolentiste": "impuzzolentire",
    "impuzzolentisti": "impuzzolentire",
    "impuzzolentita": "impuzzolentire",
    "impuzzolentite": "impuzzolentire",
    "impuzzolentiti": "impuzzolentire",
    "impuzzolentito": "impuzzolentire",
    "impuzzolentiva": "impuzzolentire",
    "impuzzolentivamo": "impuzzolentire",
    "impuzzolentivan": "impuzzolentire",
    "impuzzolentivano": "impuzzolentire",
    "impuzzolentivate": "impuzzolentire",
    "impuzzolentivi": "impuzzolentire",
    "impuzzolentivo": "impuzzolentire",
    "impuzzolento": "impuzzolentire",
    "impuzzolenton": "impuzzolentire",
    "impuzzolentono": "impuzzolentire",
    "impuzzolentì": "impuzzolentire",
    "inabbordabili": "inabbordabile",
    "inabili": "inabile",
    "inabilita": "inabilitare",
    "inabilitai": "inabilitare",
    "inabilitammo": "inabilitare",
    "inabilitan": "inabilitare",
    "inabilitando": "inabilitare",
    "inabilitano": "inabilitare",
    "inabilitante": "inabilitare",
    "inabilitanti": "inabilitare",
    "inabilitar": "inabilitare",
    "inabilitaron": "inabilitare",
    "inabilitarono": "inabilitare",
    "inabilitasse": "inabilitare",
    "inabilitasser": "inabilitare",
    "inabilitassero": "inabilitare",
    "inabilitassi": "inabilitare",
    "inabilitassimo": "inabilitare",
    "inabilitaste": "inabilitare",
    "inabilitasti": "inabilitare",
    "inabilitata": "inabilitare",
    "inabilitate": "inabilitare",
    "inabilitati": "inabilitare",
    "inabilitato": "inabilitare",
    "inabilitava": "inabilitare",
    "inabilitavamo": "inabilitare",
    "inabilitavan": "inabilitare",
    "inabilitavano": "inabilitare",
    "inabilitavate": "inabilitare",
    "inabilitavi": "inabilitare",
    "inabilitavo": "inabilitare",
    "inabiliterai": "inabilitare",
    "inabiliteran": "inabilitare",
    "inabiliteranno": "inabilitare",
    "inabiliterebbe": "inabilitare",
    "inabiliterebber": "inabilitare",
    "inabiliterebbero": "inabilitare",
    "inabiliterei": "inabilitare",
    "inabiliteremmo": "inabilitare",
    "inabiliteremo": "inabilitare",
    "inabilitereste": "inabilitare",
    "inabiliteresti": "inabilitare",
    "inabiliterete": "inabilitare",
    "inabiliterà": "inabilitare",
    "inabiliterò": "inabilitare",
    "inabiliti": "inabilitare",
    "inabilitiamo": "inabilitare",
    "inabilitiate": "inabilitare",
    "inabilitin": "inabilitare",
    "inabilitino": "inabilitare",
    "inabilito": "inabilitare",
    "inabilitò": "inabilitare",
    "inabissa": "inabissare",
    "inabissai": "inabissare",
    "inabissammo": "inabissare",
    "inabissan": "inabissare",
    "inabissando": "inabissare",
    "inabissano": "inabissare",
    "inabissante": "inabissare",
    "inabissanti": "inabissare",
    "inabissar": "inabissare",
    "inabissaron": "inabissare",
    "inabissarono": "inabissare",
    "inabissasse": "inabissare",
    "inabissasser": "inabissare",
    "inabissassero": "inabissare",
    "inabissassi": "inabissare",
    "inabissassimo": "inabissare",
    "inabissaste": "inabissare",
    "inabissasti": "inabissare",
    "inabissata": "inabissare",
    "inabissate": "inabissare",
    "inabissati": "inabissare",
    "inabissato": "inabissare",
    "inabissava": "inabissare",
    "inabissavamo": "inabissare",
    "inabissavan": "inabissare",
    "inabissavano": "inabissare",
    "inabissavate": "inabissare",
    "inabissavi": "inabissare",
    "inabissavo": "inabissare",
    "inabisserai": "inabissare",
    "inabisseran": "inabissare",
    "inabisseranno": "inabissare",
    "inabisserebbe": "inabissare",
    "inabisserebber": "inabissare",
    "inabisserebbero": "inabissare",
    "inabisserei": "inabissare",
    "inabisseremmo": "inabissare",
    "inabisseremo": "inabissare",
    "inabissereste": "inabissare",
    "inabisseresti": "inabissare",
    "inabisserete": "inabissare",
    "inabisserà": "inabissare",
    "inabisserò": "inabissare",
    "inabissi": "inabissare",
    "inabissiamo": "inabissare",
    "inabissiate": "inabissare",
    "inabissin": "inabissare",
    "inabissino": "inabissare",
    "inabisso": "inabissare",
    "inabissò": "inabissare",
    "inabitabili": "inabitabile",
    "inaccessibili": "inaccessibile",
    "inaccettabili": "inaccettabile",
    "inaccostabili": "inaccostabile",
    "inacerba": "inacerbire",
    "inacerban": "inacerbire",
    "inacerbano": "inacerbire",
    "inacerbe": "inacerbire",
    "inacerbendo": "inacerbire",
    "inacerbente": "inacerbire",
    "inacerbenti": "inacerbire",
    "inacerbi": "inacerbire",
    "inacerbiamo": "inacerbire",
    "inacerbiate": "inacerbire",
    "inacerbii": "inacerbire",
    "inacerbimmo": "inacerbire",
    "inacerbir": "inacerbire",
    "inacerbirai": "inacerbire",
    "inacerbiran": "inacerbire",
    "inacerbiranno": "inacerbire",
    "inacerbirebbe": "inacerbire",
    "inacerbirebber": "inacerbire",
    "inacerbirebbero": "inacerbire",
    "inacerbirei": "inacerbire",
    "inacerbiremmo": "inacerbire",
    "inacerbiremo": "inacerbire",
    "inacerbireste": "inacerbire",
    "inacerbiresti": "inacerbire",
    "inacerbirete": "inacerbire",
    "inacerbiron": "inacerbire",
    "inacerbirono": "inacerbire",
    "inacerbirà": "inacerbire",
    "inacerbirò": "inacerbire",
    "inacerbisse": "inacerbire",
    "inacerbisser": "inacerbire",
    "inacerbissero": "inacerbire",
    "inacerbissi": "inacerbire",
    "inacerbissimo": "inacerbire",
    "inacerbiste": "inacerbire",
    "inacerbisti": "inacerbire",
    "inacerbita": "inacerbire",
    "inacerbite": "inacerbire",
    "inacerbiti": "inacerbire",
    "inacerbito": "inacerbire",
    "inacerbiva": "inacerbire",
    "inacerbivamo": "inacerbire",
    "inacerbivan": "inacerbire",
    "inacerbivano": "inacerbire",
    "inacerbivate": "inacerbire",
    "inacerbivi": "inacerbire",
    "inacerbivo": "inacerbire",
    "inacerbo": "inacerbire",
    "inacerbon": "inacerbire",
    "inacerbono": "inacerbire",
    "inacerbì": "inacerbire",
    "inaceta": "inacetire",
    "inacetan": "inacetire",
    "inacetano": "inacetire",
    "inacete": "inacetire",
    "inacetendo": "inacetire",
    "inacetente": "inacetire",
    "inacetenti": "inacetire",
    "inaceti": "inacetire",
    "inacetiamo": "inacetire",
    "inacetiate": "inacetire",
    "inacetii": "inacetire",
    "inacetimmo": "inacetire",
    "inacetir": "inacetire",
    "inacetirai": "inacetire",
    "inacetiran": "inacetire",
    "inacetiranno": "inacetire",
    "inacetirebbe": "inacetire",
    "inacetirebber": "inacetire",
    "inacetirebbero": "inacetire",
    "inacetirei": "inacetire",
    "inacetiremmo": "inacetire",
    "inacetiremo": "inacetire",
    "inacetireste": "inacetire",
    "inacetiresti": "inacetire",
    "inacetirete": "inacetire",
    "inacetiron": "inacetire",
    "inacetirono": "inacetire",
    "inacetirà": "inacetire",
    "inacetirò": "inacetire",
    "inacetisse": "inacetire",
    "inacetisser": "inacetire",
    "inacetissero": "inacetire",
    "inacetissi": "inacetire",
    "inacetissimo": "inacetire",
    "inacetiste": "inacetire",
    "inacetisti": "inacetire",
    "inacetita": "inacetire",
    "inacetite": "inacetire",
    "inacetiti": "inacetire",
    "inacetito": "inacetire",
    "inacetiva": "inacetire",
    "inacetivamo": "inacetire",
    "inacetivan": "inacetire",
    "inacetivano": "inacetire",
    "inacetivate": "inacetire",
    "inacetivi": "inacetire",
    "inacetivo": "inacetire",
    "inaceto": "inacetire",
    "inaceton": "inacetire",
    "inacetono": "inacetire",
    "inacetì": "inacetire",
    "inacida": "inacidire",
    "inacidan": "inacidire",
    "inacidano": "inacidire",
    "inacide": "inacidire",
    "inacidendo": "inacidire",
    "inacidente": "inacidire",
    "inacidenti": "inacidire",
    "inacidi": "inacidire",
    "inacidiamo": "inacidire",
    "inacidiate": "inacidire",
    "inacidii": "inacidire",
    "inacidimmo": "inacidire",
    "inacidir": "inacidire",
    "inacidirai": "inacidire",
    "inacidiran": "inacidire",
    "inacidiranno": "inacidire",
    "inacidirebbe": "inacidire",
    "inacidirebber": "inacidire",
    "inacidirebbero": "inacidire",
    "inacidirei": "inacidire",
    "inacidiremmo": "inacidire",
    "inacidiremo": "inacidire",
    "inacidireste": "inacidire",
    "inacidiresti": "inacidire",
    "inacidirete": "inacidire",
    "inacidiron": "inacidire",
    "inacidirono": "inacidire",
    "inacidirà": "inacidire",
    "inacidirò": "inacidire",
    "inacidisse": "inacidire",
    "inacidisser": "inacidire",
    "inacidissero": "inacidire",
    "inacidissi": "inacidire",
    "inacidissimo": "inacidire",
    "inacidiste": "inacidire",
    "inacidisti": "inacidire",
    "inacidita": "inacidire",
    "inacidite": "inacidire",
    "inaciditi": "inacidire",
    "inacidito": "inacidire",
    "inacidiva": "inacidire",
    "inacidivamo": "inacidire",
    "inacidivan": "inacidire",
    "inacidivano": "inacidire",
    "inacidivate": "inacidire",
    "inacidivi": "inacidire",
    "inacidivo": "inacidire",
    "inacido": "inacidire",
    "inacidon": "inacidire",
    "inacidono": "inacidire",
    "inacidì": "inacidire",
    "inadatta": "inadatto",
    "inadatte": "inadatto",
    "inadatti": "inadatto",
    "inadeguata": "inadeguato",
    "inadeguate": "inadeguato",
    "inadeguatezze": "inadeguatezza",
    "inadeguati": "inadeguato",
    "inadempienti": "inadempiente",
    "inadempienze": "inadempienza",
    "inadempimenti": "inadempimento",
    "inafferrabili": "inafferrabile",
    "inaffidabili": "inaffidabile",
    "inagibili": "inagibile",
    "inala": "inalare",
    "inalai": "inalare",
    "inalammo": "inalare",
    "inalan": "inalare",
    "inalando": "inalare",
    "inalano": "inalare",
    "inalante": "inalare",
    "inalanti": "inalare",
    "inalar": "inalare",
    "inalaron": "inalare",
    "inalarono": "inalare",
    "inalasse": "inalare",
    "inalasser": "inalare",
    "inalassero": "inalare",
    "inalassi": "inalare",
    "inalassimo": "inalare",
    "inalaste": "inalare",
    "inalasti": "inalare",
    "inalata": "inalare",
    "inalate": "inalare",
    "inalati": "inalare",
    "inalato": "inalare",
    "inalava": "inalare",
    "inalavamo": "inalare",
    "inalavan": "inalare",
    "inalavano": "inalare",
    "inalavate": "inalare",
    "inalavi": "inalare",
    "inalavo": "inalare",
    "inalazioni": "inalazione",
    "inalbera": "inalberare",
    "inalberai": "inalberare",
    "inalberammo": "inalberare",
    "inalberan": "inalberare",
    "inalberando": "inalberare",
    "inalberano": "inalberare",
    "inalberante": "inalberare",
    "inalberanti": "inalberare",
    "inalberar": "inalberare",
    "inalberaron": "inalberare",
    "inalberarono": "inalberare",
    "inalberasse": "inalberare",
    "inalberasser": "inalberare",
    "inalberassero": "inalberare",
    "inalberassi": "inalberare",
    "inalberassimo": "inalberare",
    "inalberaste": "inalberare",
    "inalberasti": "inalberare",
    "inalberata": "inalberare",
    "inalberate": "inalberare",
    "inalberati": "inalberare",
    "inalberato": "inalberare",
    "inalberava": "inalberare",
    "inalberavamo": "inalberare",
    "inalberavan": "inalberare",
    "inalberavano": "inalberare",
    "inalberavate": "inalberare",
    "inalberavi": "inalberare",
    "inalberavo": "inalberare",
    "inalbererai": "inalberare",
    "inalbereran": "inalberare",
    "inalbereranno": "inalberare",
    "inalbererebbe": "inalberare",
    "inalbererebber": "inalberare",
    "inalbererebbero": "inalberare",
    "inalbererei": "inalberare",
    "inalbereremmo": "inalberare",
    "inalbereremo": "inalberare",
    "inalberereste": "inalberare",
    "inalbereresti": "inalberare",
    "inalbererete": "inalberare",
    "inalbererà": "inalberare",
    "inalbererò": "inalberare",
    "inalberi": "inalberare",
    "inalberiamo": "inalberare",
    "inalberiate": "inalberare",
    "inalberin": "inalberare",
    "inalberino": "inalberare",
    "inalbero": "inalberare",
    "inalberò": "inalberare",
    "inalerai": "inalare",
    "inaleran": "inalare",
    "inaleranno": "inalare",
    "inalerebbe": "inalare",
    "inalerebber": "inalare",
    "inalerebbero": "inalare",
    "inalerei": "inalare",
    "inaleremmo": "inalare",
    "inaleremo": "inalare",
    "inalereste": "inalare",
    "inaleresti": "inalare",
    "inalerete": "inalare",
    "inalerà": "inalare",
    "inalerò": "inalare",
    "inali": "inalare",
    "inaliamo": "inalare",
    "inaliate": "inalare",
    "inalienabili": "inalienabile",
    "inalin": "inalare",
    "inalino": "inalare",
    "inalo": "inalare",
    "inalterabili": "inalterabile",
    "inalterata": "inalterato",
    "inalterate": "inalterato",
    "inalterati": "inalterato",
    "inalvea": "inalveare",
    "inalveai": "inalveare",
    "inalveammo": "inalveare",
    "inalvean": "inalveare",
    "inalveando": "inalveare",
    "inalveano": "inalveare",
    "inalveante": "inalveare",
    "inalveanti": "inalveare",
    "inalvear": "inalveare",
    "inalvearon": "inalveare",
    "inalvearono": "inalveare",
    "inalveasse": "inalveare",
    "inalveasser": "inalveare",
    "inalveassero": "inalveare",
    "inalveassi": "inalveare",
    "inalveassimo": "inalveare",
    "inalveaste": "inalveare",
    "inalveasti": "inalveare",
    "inalveata": "inalveare",
    "inalveate": "inalveare",
    "inalveati": "inalveare",
    "inalveato": "inalveare",
    "inalveava": "inalveare",
    "inalveavamo": "inalveare",
    "inalveavan": "inalveare",
    "inalveavano": "inalveare",
    "inalveavate": "inalveare",
    "inalveavi": "inalveare",
    "inalveavo": "inalveare",
    "inalveerai": "inalveare",
    "inalveeran": "inalveare",
    "inalveeranno": "inalveare",
    "inalveerebbe": "inalveare",
    "inalveerebber": "inalveare",
    "inalveerebbero": "inalveare",
    "inalveerei": "inalveare",
    "inalveeremmo": "inalveare",
    "inalveeremo": "inalveare",
    "inalveereste": "inalveare",
    "inalveeresti": "inalveare",
    "inalveerete": "inalveare",
    "inalveerà": "inalveare",
    "inalveerò": "inalveare",
    "inalvei": "inalveare",
    "inalveiamo": "inalveare",
    "inalveiate": "inalveare",
    "inalvein": "inalveare",
    "inalveino": "inalveare",
    "inalveo": "inalveare",
    "inalveò": "inalveare",
    "inalò": "inalare",
    "inamida": "inamidare",
    "inamidai": "inamidare",
    "inamidammo": "inamidare",
    "inamidan": "inamidare",
    "inamidando": "inamidare",
    "inamidano": "inamidare",
    "inamidante": "inamidare",
    "inamidanti": "inamidare",
    "inamidar": "inamidare",
    "inamidaron": "inamidare",
    "inamidarono": "inamidare",
    "inamidasse": "inamidare",
    "inamidasser": "inamidare",
    "inamidassero": "inamidare",
    "inamidassi": "inamidare",
    "inamidassimo": "inamidare",
    "inamidaste": "inamidare",
    "inamidasti": "inamidare",
    "inamidata": "inamidato",
    "inamidate": "inamidato",
    "inamidati": "inamidato",
    "inamidato": "inamidare",
    "inamidava": "inamidare",
    "inamidavamo": "inamidare",
    "inamidavan": "inamidare",
    "inamidavano": "inamidare",
    "inamidavate": "inamidare",
    "inamidavi": "inamidare",
    "inamidavo": "inamidare",
    "inamiderai": "inamidare",
    "inamideran": "inamidare",
    "inamideranno": "inamidare",
    "inamiderebbe": "inamidare",
    "inamiderebber": "inamidare",
    "inamiderebbero": "inamidare",
    "inamiderei": "inamidare",
    "inamideremmo": "inamidare",
    "inamideremo": "inamidare",
    "inamidereste": "inamidare",
    "inamideresti": "inamidare",
    "inamiderete": "inamidare",
    "inamiderà": "inamidare",
    "inamiderò": "inamidare",
    "inamidi": "inamidare",
    "inamidiamo": "inamidare",
    "inamidiate": "inamidare",
    "inamidin": "inamidare",
    "inamidino": "inamidare",
    "inamido": "inamidare",
    "inamidò": "inamidare",
    "inammissibili": "inammissibile",
    "inamovibili": "inamovibile",
    "inanella": "inanellare",
    "inanellai": "inanellare",
    "inanellammo": "inanellare",
    "inanellan": "inanellare",
    "inanellando": "inanellare",
    "inanellano": "inanellare",
    "inanellante": "inanellare",
    "inanellanti": "inanellare",
    "inanellar": "inanellare",
    "inanellaron": "inanellare",
    "inanellarono": "inanellare",
    "inanellasse": "inanellare",
    "inanellasser": "inanellare",
    "inanellassero": "inanellare",
    "inanellassi": "inanellare",
    "inanellassimo": "inanellare",
    "inanellaste": "inanellare",
    "inanellasti": "inanellare",
    "inanellata": "inanellare",
    "inanellate": "inanellare",
    "inanellati": "inanellare",
    "inanellato": "inanellare",
    "inanellava": "inanellare",
    "inanellavamo": "inanellare",
    "inanellavan": "inanellare",
    "inanellavano": "inanellare",
    "inanellavate": "inanellare",
    "inanellavi": "inanellare",
    "inanellavo": "inanellare",
    "inanellerai": "inanellare",
    "inanelleran": "inanellare",
    "inanelleranno": "inanellare",
    "inanellerebbe": "inanellare",
    "inanellerebber": "inanellare",
    "inanellerebbero": "inanellare",
    "inanellerei": "inanellare",
    "inanelleremmo": "inanellare",
    "inanelleremo": "inanellare",
    "inanellereste": "inanellare",
    "inanelleresti": "inanellare",
    "inanellerete": "inanellare",
    "inanellerà": "inanellare",
    "inanellerò": "inanellare",
    "inanelli": "inanellare",
    "inanelliamo": "inanellare",
    "inanelliate": "inanellare",
    "inanellin": "inanellare",
    "inanellino": "inanellare",
    "inanello": "inanellare",
    "inanellò": "inanellare",
    "inanimata": "inanimato",
    "inanimate": "inanimato",
    "inanimati": "inanimato",
    "inappagabili": "inappagabile",
    "inappagata": "inappagato",
    "inappagate": "inappagato",
    "inappagati": "inappagato",
    "inappellabili": "inappellabile",
    "inapplicabili": "inapplicabile",
    "inarca": "inarcare",
    "inarcai": "inarcare",
    "inarcammo": "inarcare",
    "inarcan": "inarcare",
    "inarcando": "inarcare",
    "inarcano": "inarcare",
    "inarcante": "inarcare",
    "inarcanti": "inarcare",
    "inarcar": "inarcare",
    "inarcaron": "inarcare",
    "inarcarono": "inarcare",
    "inarcasse": "inarcare",
    "inarcasser": "inarcare",
    "inarcassero": "inarcare",
    "inarcassi": "inarcare",
    "inarcassimo": "inarcare",
    "inarcaste": "inarcare",
    "inarcasti": "inarcare",
    "inarcata": "inarcare",
    "inarcate": "inarcare",
    "inarcati": "inarcare",
    "inarcato": "inarcare",
    "inarcava": "inarcare",
    "inarcavamo": "inarcare",
    "inarcavan": "inarcare",
    "inarcavano": "inarcare",
    "inarcavate": "inarcare",
    "inarcavi": "inarcare",
    "inarcavo": "inarcare",
    "inarcherai": "inarcare",
    "inarcheran": "inarcare",
    "inarcheranno": "inarcare",
    "inarcherebbe": "inarcare",
    "inarcherebber": "inarcare",
    "inarcherebbero": "inarcare",
    "inarcherei": "inarcare",
    "inarcheremmo": "inarcare",
    "inarcheremo": "inarcare",
    "inarchereste": "inarcare",
    "inarcheresti": "inarcare",
    "inarcherete": "inarcare",
    "inarcherà": "inarcare",
    "inarcherò": "inarcare",
    "inarchi": "inarcare",
    "inarchiamo": "inarcare",
    "inarchiate": "inarcare",
    "inarchin": "inarcare",
    "inarchino": "inarcare",
    "inarco": "inarcare",
    "inarcò": "inarcare",
    "inargenta": "inargentare",
    "inargentai": "inargentare",
    "inargentammo": "inargentare",
    "inargentan": "inargentare",
    "inargentando": "inargentare",
    "inargentano": "inargentare",
    "inargentante": "inargentare",
    "inargentanti": "inargentare",
    "inargentar": "inargentare",
    "inargentaron": "inargentare",
    "inargentarono": "inargentare",
    "inargentasse": "inargentare",
    "inargentasser": "inargentare",
    "inargentassero": "inargentare",
    "inargentassi": "inargentare",
    "inargentassimo": "inargentare",
    "inargentaste": "inargentare",
    "inargentasti": "inargentare",
    "inargentata": "inargentare",
    "inargentate": "inargentare",
    "inargentati": "inargentare",
    "inargentato": "inargentare",
    "inargentava": "inargentare",
    "inargentavamo": "inargentare",
    "inargentavan": "inargentare",
    "inargentavano": "inargentare",
    "inargentavate": "inargentare",
    "inargentavi": "inargentare",
    "inargentavo": "inargentare",
    "inargenterai": "inargentare",
    "inargenteran": "inargentare",
    "inargenteranno": "inargentare",
    "inargenterebbe": "inargentare",
    "inargenterebber": "inargentare",
    "inargenterebbero": "inargentare",
    "inargenterei": "inargentare",
    "inargenteremmo": "inargentare",
    "inargenteremo": "inargentare",
    "inargentereste": "inargentare",
    "inargenteresti": "inargentare",
    "inargenterete": "inargentare",
    "inargenterà": "inargentare",
    "inargenterò": "inargentare",
    "inargenti": "inargentare",
    "inargentiamo": "inargentare",
    "inargentiate": "inargentare",
    "inargentin": "inargentare",
    "inargentino": "inargentare",
    "inargento": "inargentare",
    "inargentò": "inargentare",
    "inaridendo": "inaridire",
    "inaridente": "inaridire",
    "inaridenti": "inaridire",
    "inaridiamo": "inaridire",
    "inaridiate": "inaridire",
    "inaridii": "inaridire",
    "inaridimmo": "inaridire",
    "inaridir": "inaridire",
    "inaridirai": "inaridire",
    "inaridiran": "inaridire",
    "inaridiranno": "inaridire",
    "inaridirebbe": "inaridire",
    "inaridirebber": "inaridire",
    "inaridirebbero": "inaridire",
    "inaridirei": "inaridire",
    "inaridiremmo": "inaridire",
    "inaridiremo": "inaridire",
    "inaridireste": "inaridire",
    "inaridiresti": "inaridire",
    "inaridirete": "inaridire",
    "inaridiron": "inaridire",
    "inaridirono": "inaridire",
    "inaridirà": "inaridire",
    "inaridirò": "inaridire",
    "inaridisca": "inaridire",
    "inaridiscan": "inaridire",
    "inaridiscano": "inaridire",
    "inaridisce": "inaridire",
    "inaridisci": "inaridire",
    "inaridisco": "inaridire",
    "inaridiscon": "inaridire",
    "inaridiscono": "inaridire",
    "inaridisse": "inaridire",
    "inaridisser": "inaridire",
    "inaridissero": "inaridire",
    "inaridissi": "inaridire",
    "inaridissimo": "inaridire",
    "inaridiste": "inaridire",
    "inaridisti": "inaridire",
    "inaridita": "inaridire",
    "inaridite": "inaridire",
    "inariditi": "inaridire",
    "inaridito": "inaridire",
    "inaridiva": "inaridire",
    "inaridivamo": "inaridire",
    "inaridivan": "inaridire",
    "inaridivano": "inaridire",
    "inaridivate": "inaridire",
    "inaridivi": "inaridire",
    "inaridivo": "inaridire",
    "inaridì": "inaridire",
    "inarrestabili": "inarrestabile",
    "inarrivabili": "inarrivabile",
    "inarticolata": "inarticolato",
    "inarticolate": "inarticolato",
    "inarticolati": "inarticolato",
    "inascoltata": "inascoltato",
    "inascoltate": "inascoltato",
    "inascoltati": "inascoltato",
    "inaspettata": "inaspettato",
    "inaspettate": "inaspettato",
    "inaspettati": "inaspettato",
    "inasprendo": "inasprire",
    "inasprente": "inasprire",
    "inasprenti": "inasprire",
    "inaspriamo": "inasprire",
    "inaspriate": "inasprire",
    "inasprii": "inasprire",
    "inasprimenti": "inasprimento",
    "inasprimmo": "inasprire",
    "inasprir": "inasprire",
    "inasprirai": "inasprire",
    "inaspriran": "inasprire",
    "inaspriranno": "inasprire",
    "inasprirebbe": "inasprire",
    "inasprirebber": "inasprire",
    "inasprirebbero": "inasprire",
    "inasprirei": "inasprire",
    "inaspriremmo": "inasprire",
    "inaspriremo": "inasprire",
    "inasprireste": "inasprire",
    "inaspriresti": "inasprire",
    "inasprirete": "inasprire",
    "inaspriron": "inasprire",
    "inasprirono": "inasprire",
    "inasprirà": "inasprire",
    "inasprirò": "inasprire",
    "inasprisca": "inasprire",
    "inaspriscan": "inasprire",
    "inaspriscano": "inasprire",
    "inasprisce": "inasprire",
    "inasprisci": "inasprire",
    "inasprisco": "inasprire",
    "inaspriscon": "inasprire",
    "inaspriscono": "inasprire",
    "inasprisse": "inasprire",
    "inasprisser": "inasprire",
    "inasprissero": "inasprire",
    "inasprissi": "inasprire",
    "inasprissimo": "inasprire",
    "inaspriste": "inasprire",
    "inaspristi": "inasprire",
    "inasprita": "inasprire",
    "inasprite": "inasprire",
    "inaspriti": "inasprire",
    "inasprito": "inasprire",
    "inaspriva": "inasprire",
    "inasprivamo": "inasprire",
    "inasprivan": "inasprire",
    "inasprivano": "inasprire",
    "inasprivate": "inasprire",
    "inasprivi": "inasprire",
    "inasprivo": "inasprire",
    "inasprì": "inasprire",
    "inasta": "inastare",
    "inastai": "inastare",
    "inastammo": "inastare",
    "inastan": "inastare",
    "inastando": "inastare",
    "inastano": "inastare",
    "inastante": "inastare",
    "inastanti": "inastare",
    "inastar": "inastare",
    "inastaron": "inastare",
    "inastarono": "inastare",
    "inastasse": "inastare",
    "inastasser": "inastare",
    "inastassero": "inastare",
    "inastassi": "inastare",
    "inastassimo": "inastare",
    "inastaste": "inastare",
    "inastasti": "inastare",
    "inastata": "inastare",
    "inastate": "inastare",
    "inastati": "inastare",
    "inastato": "inastare",
    "inastava": "inastare",
    "inastavamo": "inastare",
    "inastavan": "inastare",
    "inastavano": "inastare",
    "inastavate": "inastare",
    "inastavi": "inastare",
    "inastavo": "inastare",
    "inasterai": "inastare",
    "inasteran": "inastare",
    "inasteranno": "inastare",
    "inasterebbe": "inastare",
    "inasterebber": "inastare",
    "inasterebbero": "inastare",
    "inasterei": "inastare",
    "inasteremmo": "inastare",
    "inasteremo": "inastare",
    "inastereste": "inastare",
    "inasteresti": "inastare",
    "inasterete": "inastare",
    "inasterà": "inastare",
    "inasterò": "inastare",
    "inasti": "inastare",
    "inastiamo": "inastare",
    "inastiate": "inastare",
    "inastin": "inastare",
    "inastino": "inastare",
    "inasto": "inastare",
    "inastò": "inastare",
    "inattaccabili": "inattaccabile",
    "inattendibili": "inattendibile",
    "inattesa": "inatteso",
    "inattese": "inatteso",
    "inattesi": "inatteso",
    "inattiva": "inattivo",
    "inattivai": "inattivare",
    "inattivammo": "inattivare",
    "inattivan": "inattivare",
    "inattivando": "inattivare",
    "inattivano": "inattivare",
    "inattivante": "inattivare",
    "inattivanti": "inattivare",
    "inattivar": "inattivare",
    "inattivaron": "inattivare",
    "inattivarono": "inattivare",
    "inattivasse": "inattivare",
    "inattivasser": "inattivare",
    "inattivassero": "inattivare",
    "inattivassi": "inattivare",
    "inattivassimo": "inattivare",
    "inattivaste": "inattivare",
    "inattivasti": "inattivare",
    "inattivata": "inattivare",
    "inattivate": "inattivare",
    "inattivati": "inattivare",
    "inattivato": "inattivare",
    "inattivava": "inattivare",
    "inattivavamo": "inattivare",
    "inattivavan": "inattivare",
    "inattivavano": "inattivare",
    "inattivavate": "inattivare",
    "inattivavi": "inattivare",
    "inattivavo": "inattivare",
    "inattive": "inattivo",
    "inattiverai": "inattivare",
    "inattiveran": "inattivare",
    "inattiveranno": "inattivare",
    "inattiverebbe": "inattivare",
    "inattiverebber": "inattivare",
    "inattiverebbero": "inattivare",
    "inattiverei": "inattivare",
    "inattiveremmo": "inattivare",
    "inattiveremo": "inattivare",
    "inattivereste": "inattivare",
    "inattiveresti": "inattivare",
    "inattiverete": "inattivare",
    "inattiverà": "inattivare",
    "inattiverò": "inattivare",
    "inattivi": "inattivo",
    "inattiviamo": "inattivare",
    "inattiviate": "inattivare",
    "inattivin": "inattivare",
    "inattivino": "inattivare",
    "inattivo": "inattivare",
    "inattivò": "inattivare",
    "inattuabili": "inattuabile",
    "inattuali": "inattuale",
    "inaudita": "inaudito",
    "inaudite": "inaudito",
    "inauditi": "inaudito",
    "inaugura": "inaugurare",
    "inaugurai": "inaugurare",
    "inaugurali": "inaugurale",
    "inaugurammo": "inaugurare",
    "inauguran": "inaugurare",
    "inaugurando": "inaugurare",
    "inaugurano": "inaugurare",
    "inaugurante": "inaugurare",
    "inauguranti": "inaugurare",
    "inaugurar": "inaugurare",
    "inauguraron": "inaugurare",
    "inaugurarono": "inaugurare",
    "inaugurasse": "inaugurare",
    "inaugurasser": "inaugurare",
    "inaugurassero": "inaugurare",
    "inaugurassi": "inaugurare",
    "inaugurassimo": "inaugurare",
    "inauguraste": "inaugurare",
    "inaugurasti": "inaugurare",
    "inaugurata": "inaugurato",
    "inaugurate": "inaugurato",
    "inaugurati": "inaugurato",
    "inaugurato": "inaugurare",
    "inaugurava": "inaugurare",
    "inauguravamo": "inaugurare",
    "inauguravan": "inaugurare",
    "inauguravano": "inaugurare",
    "inauguravate": "inaugurare",
    "inauguravi": "inaugurare",
    "inauguravo": "inaugurare",
    "inaugurazioni": "inaugurazione",
    "inaugurerai": "inaugurare",
    "inaugureran": "inaugurare",
    "inaugureranno": "inaugurare",
    "inaugurerebbe": "inaugurare",
    "inaugurerebber": "inaugurare",
    "inaugurerebbero": "inaugurare",
    "inaugurerei": "inaugurare",
    "inaugureremmo": "inaugurare",
    "inaugureremo": "inaugurare",
    "inaugurereste": "inaugurare",
    "inaugureresti": "inaugurare",
    "inaugurerete": "inaugurare",
    "inaugurerà": "inaugurare",
    "inaugurerò": "inaugurare",
    "inauguri": "inaugurare",
    "inauguriamo": "inaugurare",
    "inauguriate": "inaugurare",
    "inaugurin": "inaugurare",
    "inaugurino": "inaugurare",
    "inauguro": "inaugurare",
    "inaugurò": "inaugurare",
    "inavvicinabili": "inavvicinabile",
    "incagli": "incagliare",
    "incaglia": "incagliare",
    "incagliai": "incagliare",
    "incagliammo": "incagliare",
    "incagliamo": "incagliare",
    "incaglian": "incagliare",
    "incagliando": "incagliare",
    "incagliano": "incagliare",
    "incagliante": "incagliare",
    "incaglianti": "incagliare",
    "incagliar": "incagliare",
    "incagliaron": "incagliare",
    "incagliarono": "incagliare",
    "incagliasse": "incagliare",
    "incagliasser": "incagliare",
    "incagliassero": "incagliare",
    "incagliassi": "incagliare",
    "incagliassimo": "incagliare",
    "incagliaste": "incagliare",
    "incagliasti": "incagliare",
    "incagliata": "incagliare",
    "incagliate": "incagliare",
    "incagliati": "incagliare",
    "incagliato": "incagliare",
    "incagliava": "incagliare",
    "incagliavamo": "incagliare",
    "incagliavan": "incagliare",
    "incagliavano": "incagliare",
    "incagliavate": "incagliare",
    "incagliavi": "incagliare",
    "incagliavo": "incagliare",
    "incaglierai": "incagliare",
    "incaglieran": "incagliare",
    "incaglieranno": "incagliare",
    "incaglierebbe": "incagliare",
    "incaglierebber": "incagliare",
    "incaglierebbero": "incagliare",
    "incaglierei": "incagliare",
    "incaglieremmo": "incagliare",
    "incaglieremo": "incagliare",
    "incagliereste": "incagliare",
    "incaglieresti": "incagliare",
    "incaglierete": "incagliare",
    "incaglierà": "incagliare",
    "incaglierò": "incagliare",
    "incaglin": "incagliare",
    "incaglino": "incagliare",
    "incaglio": "incagliare",
    "incagliò": "incagliare",
    "incalcina": "incalcinare",
    "incalcinai": "incalcinare",
    "incalcinammo": "incalcinare",
    "incalcinan": "incalcinare",
    "incalcinando": "incalcinare",
    "incalcinano": "incalcinare",
    "incalcinante": "incalcinare",
    "incalcinanti": "incalcinare",
    "incalcinar": "incalcinare",
    "incalcinaron": "incalcinare",
    "incalcinarono": "incalcinare",
    "incalcinasse": "incalcinare",
    "incalcinasser": "incalcinare",
    "incalcinassero": "incalcinare",
    "incalcinassi": "incalcinare",
    "incalcinassimo": "incalcinare",
    "incalcinaste": "incalcinare",
    "incalcinasti": "incalcinare",
    "incalcinata": "incalcinare",
    "incalcinate": "incalcinare",
    "incalcinati": "incalcinare",
    "incalcinato": "incalcinare",
    "incalcinava": "incalcinare",
    "incalcinavamo": "incalcinare",
    "incalcinavan": "incalcinare",
    "incalcinavano": "incalcinare",
    "incalcinavate": "incalcinare",
    "incalcinavi": "incalcinare",
    "incalcinavo": "incalcinare",
    "incalcinerai": "incalcinare",
    "incalcineran": "incalcinare",
    "incalcineranno": "incalcinare",
    "incalcinerebbe": "incalcinare",
    "incalcinerebber": "incalcinare",
    "incalcinerebbero": "incalcinare",
    "incalcinerei": "incalcinare",
    "incalcineremmo": "incalcinare",
    "incalcineremo": "incalcinare",
    "incalcinereste": "incalcinare",
    "incalcineresti": "incalcinare",
    "incalcinerete": "incalcinare",
    "incalcinerà": "incalcinare",
    "incalcinerò": "incalcinare",
    "incalcini": "incalcinare",
    "incalciniamo": "incalcinare",
    "incalciniate": "incalcinare",
    "incalcinin": "incalcinare",
    "incalcinino": "incalcinare",
    "incalcino": "incalcinare",
    "incalcinò": "incalcinare",
    "incalcolabili": "incalcolabile",
    "incalla": "incallire",
    "incallan": "incallire",
    "incallano": "incallire",
    "incalle": "incallire",
    "incallendo": "incallire",
    "incallente": "incallire",
    "incallenti": "incallire",
    "incalli": "incallire",
    "incalliamo": "incallire",
    "incalliate": "incallire",
    "incallii": "incallire",
    "incallimmo": "incallire",
    "incallir": "incallire",
    "incallirai": "incallire",
    "incalliran": "incallire",
    "incalliranno": "incallire",
    "incallirebbe": "incallire",
    "incallirebber": "incallire",
    "incallirebbero": "incallire",
    "incallirei": "incallire",
    "incalliremmo": "incallire",
    "incalliremo": "incallire",
    "incallireste": "incallire",
    "incalliresti": "incallire",
    "incallirete": "incallire",
    "incalliron": "incallire",
    "incallirono": "incallire",
    "incallirà": "incallire",
    "incallirò": "incallire",
    "incallisse": "incallire",
    "incallisser": "incallire",
    "incallissero": "incallire",
    "incallissi": "incallire",
    "incallissimo": "incallire",
    "incalliste": "incallire",
    "incallisti": "incallire",
    "incallita": "incallito",
    "incallite": "incallito",
    "incalliti": "incallito",
    "incallito": "incallire",
    "incalliva": "incallire",
    "incallivamo": "incallire",
    "incallivan": "incallire",
    "incallivano": "incallire",
    "incallivate": "incallire",
    "incallivi": "incallire",
    "incallivo": "incallire",
    "incallo": "incallire",
    "incallon": "incallire",
    "incallono": "incallire",
    "incallì": "incallire",
    "incalora": "incalorire",
    "incaloran": "incalorire",
    "incalorano": "incalorire",
    "incalore": "incalorire",
    "incalorendo": "incalorire",
    "incalorente": "incalorire",
    "incalorenti": "incalorire",
    "incalori": "incalorire",
    "incaloriamo": "incalorire",
    "incaloriate": "incalorire",
    "incalorii": "incalorire",
    "incalorimmo": "incalorire",
    "incalorir": "incalorire",
    "incalorirai": "incalorire",
    "incaloriran": "incalorire",
    "incaloriranno": "incalorire",
    "incalorirebbe": "incalorire",
    "incalorirebber": "incalorire",
    "incalorirebbero": "incalorire",
    "incalorirei": "incalorire",
    "incaloriremmo": "incalorire",
    "incaloriremo": "incalorire",
    "incalorireste": "incalorire",
    "incaloriresti": "incalorire",
    "incalorirete": "incalorire",
    "incaloriron": "incalorire",
    "incalorirono": "incalorire",
    "incalorirà": "incalorire",
    "incalorirò": "incalorire",
    "incalorisse": "incalorire",
    "incalorisser": "incalorire",
    "incalorissero": "incalorire",
    "incalorissi": "incalorire",
    "incalorissimo": "incalorire",
    "incaloriste": "incalorire",
    "incaloristi": "incalorire",
    "incalorita": "incalorire",
    "incalorite": "incalorire",
    "incaloriti": "incalorire",
    "incalorito": "incalorire",
    "incaloriva": "incalorire",
    "incalorivamo": "incalorire",
    "incalorivan": "incalorire",
    "incalorivano": "incalorire",
    "incalorivate": "incalorire",
    "incalorivi": "incalorire",
    "incalorivo": "incalorire",
    "incaloro": "incalorire",
    "incaloron": "incalorire",
    "incalorono": "incalorire",
    "incalorì": "incalorire",
    "incalza": "incalzare",
    "incalzai": "incalzare",
    "incalzammo": "incalzare",
    "incalzan": "incalzare",
    "incalzando": "incalzare",
    "incalzano": "incalzare",
    "incalzante": "incalzare",
    "incalzanti": "incalzare",
    "incalzar": "incalzare",
    "incalzaron": "incalzare",
    "incalzarono": "incalzare",
    "incalzasse": "incalzare",
    "incalzasser": "incalzare",
    "incalzassero": "incalzare",
    "incalzassi": "incalzare",
    "incalzassimo": "incalzare",
    "incalzaste": "incalzare",
    "incalzasti": "incalzare",
    "incalzata": "incalzare",
    "incalzate": "incalzare",
    "incalzati": "incalzare",
    "incalzato": "incalzare",
    "incalzava": "incalzare",
    "incalzavamo": "incalzare",
    "incalzavan": "incalzare",
    "incalzavano": "incalzare",
    "incalzavate": "incalzare",
    "incalzavi": "incalzare",
    "incalzavo": "incalzare",
    "incalzerai": "incalzare",
    "incalzeran": "incalzare",
    "incalzeranno": "incalzare",
    "incalzerebbe": "incalzare",
    "incalzerebber": "incalzare",
    "incalzerebbero": "incalzare",
    "incalzerei": "incalzare",
    "incalzeremmo": "incalzare",
    "incalzeremo": "incalzare",
    "incalzereste": "incalzare",
    "incalzeresti": "incalzare",
    "incalzerete": "incalzare",
    "incalzerà": "incalzare",
    "incalzerò": "incalzare",
    "incalzi": "incalzare",
    "incalziamo": "incalzare",
    "incalziate": "incalzare",
    "incalzin": "incalzare",
    "incalzino": "incalzare",
    "incalzo": "incalzare",
    "incalzò": "incalzare",
    "incamera": "incamerare",
    "incamerai": "incamerare",
    "incamerammo": "incamerare",
    "incameran": "incamerare",
    "incamerando": "incamerare",
    "incamerano": "incamerare",
    "incamerante": "incamerare",
    "incameranti": "incamerare",
    "incamerar": "incamerare",
    "incameraron": "incamerare",
    "incamerarono": "incamerare",
    "incamerasse": "incamerare",
    "incamerasser": "incamerare",
    "incamerassero": "incamerare",
    "incamerassi": "incamerare",
    "incamerassimo": "incamerare",
    "incameraste": "incamerare",
    "incamerasti": "incamerare",
    "incamerata": "incamerare",
    "incamerate": "incamerare",
    "incamerati": "incamerare",
    "incamerato": "incamerare",
    "incamerava": "incamerare",
    "incameravamo": "incamerare",
    "incameravan": "incamerare",
    "incameravano": "incamerare",
    "incameravate": "incamerare",
    "incameravi": "incamerare",
    "incameravo": "incamerare",
    "incamererai": "incamerare",
    "incamereran": "incamerare",
    "incamereranno": "incamerare",
    "incamererebbe": "incamerare",
    "incamererebber": "incamerare",
    "incamererebbero": "incamerare",
    "incamererei": "incamerare",
    "incamereremmo": "incamerare",
    "incamereremo": "incamerare",
    "incamerereste": "incamerare",
    "incamereresti": "incamerare",
    "incamererete": "incamerare",
    "incamererà": "incamerare",
    "incamererò": "incamerare",
    "incameri": "incamerare",
    "incameriamo": "incamerare",
    "incameriate": "incamerare",
    "incamerin": "incamerare",
    "incamerino": "incamerare",
    "incamero": "incamerare",
    "incamerò": "incamerare",
    "incamicerai": "incamiciare",
    "incamiceran": "incamiciare",
    "incamiceranno": "incamiciare",
    "incamicerebbe": "incamiciare",
    "incamicerebber": "incamiciare",
    "incamicerebbero": "incamiciare",
    "incamicerei": "incamiciare",
    "incamiceremmo": "incamiciare",
    "incamiceremo": "incamiciare",
    "incamicereste": "incamiciare",
    "incamiceresti": "incamiciare",
    "incamicerete": "incamiciare",
    "incamicerà": "incamiciare",
    "incamicerò": "incamiciare",
    "incamici": "incamiciare",
    "incamicia": "incamiciare",
    "incamiciai": "incamiciare",
    "incamiciammo": "incamiciare",
    "incamiciamo": "incamiciare",
    "incamician": "incamiciare",
    "incamiciando": "incamiciare",
    "incamiciano": "incamiciare",
    "incamiciante": "incamiciare",
    "incamicianti": "incamiciare",
    "incamiciar": "incamiciare",
    "incamiciaron": "incamiciare",
    "incamiciarono": "incamiciare",
    "incamiciasse": "incamiciare",
    "incamiciasser": "incamiciare",
    "incamiciassero": "incamiciare",
    "incamiciassi": "incamiciare",
    "incamiciassimo": "incamiciare",
    "incamiciaste": "incamiciare",
    "incamiciasti": "incamiciare",
    "incamiciata": "incamiciare",
    "incamiciate": "incamiciare",
    "incamiciati": "incamiciare",
    "incamiciato": "incamiciare",
    "incamiciava": "incamiciare",
    "incamiciavamo": "incamiciare",
    "incamiciavan": "incamiciare",
    "incamiciavano": "incamiciare",
    "incamiciavate": "incamiciare",
    "incamiciavi": "incamiciare",
    "incamiciavo": "incamiciare",
    "incamicin": "incamiciare",
    "incamicino": "incamiciare",
    "incamicio": "incamiciare",
    "incamiciò": "incamiciare",
    "incammina": "incamminare",
    "incamminai": "incamminare",
    "incamminammo": "incamminare",
    "incamminan": "incamminare",
    "incamminando": "incamminare",
    "incamminano": "incamminare",
    "incamminante": "incamminare",
    "incamminanti": "incamminare",
    "incamminar": "incamminare",
    "incamminaron": "incamminare",
    "incamminarono": "incamminare",
    "incamminasse": "incamminare",
    "incamminasser": "incamminare",
    "incamminassero": "incamminare",
    "incamminassi": "incamminare",
    "incamminassimo": "incamminare",
    "incamminaste": "incamminare",
    "incamminasti": "incamminare",
    "incamminata": "incamminare",
    "incamminate": "incamminare",
    "incamminati": "incamminare",
    "incamminato": "incamminare",
    "incamminava": "incamminare",
    "incamminavamo": "incamminare",
    "incamminavan": "incamminare",
    "incamminavano": "incamminare",
    "incamminavate": "incamminare",
    "incamminavi": "incamminare",
    "incamminavo": "incamminare",
    "incamminerai": "incamminare",
    "incammineran": "incamminare",
    "incammineranno": "incamminare",
    "incamminerebbe": "incamminare",
    "incamminerebber": "incamminare",
    "incamminerebbero": "incamminare",
    "incamminerei": "incamminare",
    "incammineremmo": "incamminare",
    "incammineremo": "incamminare",
    "incamminereste": "incamminare",
    "incammineresti": "incamminare",
    "incamminerete": "incamminare",
    "incamminerà": "incamminare",
    "incamminerò": "incamminare",
    "incammini": "incamminare",
    "incamminiamo": "incamminare",
    "incamminiate": "incamminare",
    "incamminin": "incamminare",
    "incamminino": "incamminare",
    "incammino": "incamminare",
    "incamminò": "incamminare",
    "incanala": "incanalare",
    "incanalai": "incanalare",
    "incanalammo": "incanalare",
    "incanalan": "incanalare",
    "incanalando": "incanalare",
    "incanalano": "incanalare",
    "incanalante": "incanalare",
    "incanalanti": "incanalare",
    "incanalar": "incanalare",
    "incanalaron": "incanalare",
    "incanalarono": "incanalare",
    "incanalasse": "incanalare",
    "incanalasser": "incanalare",
    "incanalassero": "incanalare",
    "incanalassi": "incanalare",
    "incanalassimo": "incanalare",
    "incanalaste": "incanalare",
    "incanalasti": "incanalare",
    "incanalata": "incanalare",
    "incanalate": "incanalare",
    "incanalati": "incanalare",
    "incanalato": "incanalare",
    "incanalava": "incanalare",
    "incanalavamo": "incanalare",
    "incanalavan": "incanalare",
    "incanalavano": "incanalare",
    "incanalavate": "incanalare",
    "incanalavi": "incanalare",
    "incanalavo": "incanalare",
    "incanalerai": "incanalare",
    "incanaleran": "incanalare",
    "incanaleranno": "incanalare",
    "incanalerebbe": "incanalare",
    "incanalerebber": "incanalare",
    "incanalerebbero": "incanalare",
    "incanalerei": "incanalare",
    "incanaleremmo": "incanalare",
    "incanaleremo": "incanalare",
    "incanalereste": "incanalare",
    "incanaleresti": "incanalare",
    "incanalerete": "incanalare",
    "incanalerà": "incanalare",
    "incanalerò": "incanalare",
    "incanali": "incanalare",
    "incanaliamo": "incanalare",
    "incanaliate": "incanalare",
    "incanalin": "incanalare",
    "incanalino": "incanalare",
    "incanalo": "incanalare",
    "incanalò": "incanalare",
    "incancellabili": "incancellabile",
    "incancrenendo": "incancrenire",
    "incancrenente": "incancrenire",
    "incancrenenti": "incancrenire",
    "incancreniamo": "incancrenire",
    "incancreniate": "incancrenire",
    "incancrenii": "incancrenire",
    "incancrenimmo": "incancrenire",
    "incancrenir": "incancrenire",
    "incancrenirai": "incancrenire",
    "incancreniran": "incancrenire",
    "incancreniranno": "incancrenire",
    "incancrenirebbe": "incancrenire",
    "incancrenirebber": "incancrenire",
    "incancrenirebbero": "incancrenire",
    "incancrenirei": "incancrenire",
    "incancreniremmo": "incancrenire",
    "incancreniremo": "incancrenire",
    "incancrenireste": "incancrenire",
    "incancreniresti": "incancrenire",
    "incancrenirete": "incancrenire",
    "incancreniron": "incancrenire",
    "incancrenirono": "incancrenire",
    "incancrenirà": "incancrenire",
    "incancrenirò": "incancrenire",
    "incancrenisca": "incancrenire",
    "incancreniscan": "incancrenire",
    "incancreniscano": "incancrenire",
    "incancrenisce": "incancrenire",
    "incancrenisci": "incancrenire",
    "incancrenisco": "incancrenire",
    "incancreniscon": "incancrenire",
    "incancreniscono": "incancrenire",
    "incancrenisse": "incancrenire",
    "incancrenisser": "incancrenire",
    "incancrenissero": "incancrenire",
    "incancrenissi": "incancrenire",
    "incancrenissimo": "incancrenire",
    "incancreniste": "incancrenire",
    "incancrenisti": "incancrenire",
    "incancrenita": "incancrenire",
    "incancrenite": "incancrenire",
    "incancreniti": "incancrenire",
    "incancrenito": "incancrenire",
    "incancreniva": "incancrenire",
    "incancrenivamo": "incancrenire",
    "incancrenivan": "incancrenire",
    "incancrenivano": "incancrenire",
    "incancrenivate": "incancrenire",
    "incancrenivi": "incancrenire",
    "incancrenivo": "incancrenire",
    "incancrenì": "incancrenire",
    "incandescenti": "incandescente",
    "incanta": "incantare",
    "incantai": "incantare",
    "incantamenti": "incantamento",
    "incantammo": "incantare",
    "incantan": "incantare",
    "incantando": "incantare",
    "incantano": "incantare",
    "incantante": "incantare",
    "incantanti": "incantare",
    "incantar": "incantare",
    "incantaron": "incantare",
    "incantarono": "incantare",
    "incantasse": "incantare",
    "incantasser": "incantare",
    "incantassero": "incantare",
    "incantassi": "incantare",
    "incantassimo": "incantare",
    "incantaste": "incantare",
    "incantasti": "incantare",
    "incantata": "incantato",
    "incantate": "incantato",
    "incantati": "incantato",
    "incantato": "incantare",
    "incantatori": "incantatore",
    "incantatrice": "incantatore",
    "incantatrici": "incantatore",
    "incantava": "incantare",
    "incantavamo": "incantare",
    "incantavan": "incantare",
    "incantavano": "incantare",
    "incantavate": "incantare",
    "incantavi": "incantare",
    "incantavo": "incantare",
    "incanterai": "incantare",
    "incanteran": "incantare",
    "incanteranno": "incantare",
    "incanterebbe": "incantare",
    "incanterebber": "incantare",
    "incanterebbero": "incantare",
    "incanterei": "incantare",
    "incanteremmo": "incantare",
    "incanteremo": "incantare",
    "incantereste": "incantare",
    "incanteresti": "incantare",
    "incanterete": "incantare",
    "incanterà": "incantare",
    "incanterò": "incantare",
    "incantesimi": "incantesimo",
    "incantevoli": "incantevole",
    "incanti": "incanto",
    "incantiamo": "incantare",
    "incantiate": "incantare",
    "incantin": "incantare",
    "incantino": "incantare",
    "incanto": "incantare",
    "incantò": "incantare",
    "incanuta": "incanutire",
    "incanutan": "incanutire",
    "incanutano": "incanutire",
    "incanute": "incanutire",
    "incanutendo": "incanutire",
    "incanutente": "incanutire",
    "incanutenti": "incanutire",
    "incanuti": "incanutire",
    "incanutiamo": "incanutire",
    "incanutiate": "incanutire",
    "incanutii": "incanutire",
    "incanutimmo": "incanutire",
    "incanutir": "incanutire",
    "incanutirai": "incanutire",
    "incanutiran": "incanutire",
    "incanutiranno": "incanutire",
    "incanutirebbe": "incanutire",
    "incanutirebber": "incanutire",
    "incanutirebbero": "incanutire",
    "incanutirei": "incanutire",
    "incanutiremmo": "incanutire",
    "incanutiremo": "incanutire",
    "incanutireste": "incanutire",
    "incanutiresti": "incanutire",
    "incanutirete": "incanutire",
    "incanutiron": "incanutire",
    "incanutirono": "incanutire",
    "incanutirà": "incanutire",
    "incanutirò": "incanutire",
    "incanutisse": "incanutire",
    "incanutisser": "incanutire",
    "incanutissero": "incanutire",
    "incanutissi": "incanutire",
    "incanutissimo": "incanutire",
    "incanutiste": "incanutire",
    "incanutisti": "incanutire",
    "incanutita": "incanutire",
    "incanutite": "incanutire",
    "incanutiti": "incanutire",
    "incanutito": "incanutire",
    "incanutiva": "incanutire",
    "incanutivamo": "incanutire",
    "incanutivan": "incanutire",
    "incanutivano": "incanutire",
    "incanutivate": "incanutire",
    "incanutivi": "incanutire",
    "incanutivo": "incanutire",
    "incanuto": "incanutire",
    "incanuton": "incanutire",
    "incanutono": "incanutire",
    "incanutì": "incanutire",
    "incapaci": "incapace",
    "incapona": "incaponire",
    "incaponan": "incaponire",
    "incaponano": "incaponire",
    "incapone": "incaponire",
    "incaponendo": "incaponire",
    "incaponi": "incaponire",
    "incaponiamo": "incaponire",
    "incaponiate": "incaponire",
    "incaponii": "incaponire",
    "incaponimmo": "incaponire",
    "incaponir": "incaponire",
    "incaponirai": "incaponire",
    "incaponiran": "incaponire",
    "incaponiranno": "incaponire",
    "incaponirebbe": "incaponire",
    "incaponirebber": "incaponire",
    "incaponirebbero": "incaponire",
    "incaponirei": "incaponire",
    "incaponiremmo": "incaponire",
    "incaponiremo": "incaponire",
    "incaponireste": "incaponire",
    "incaponiresti": "incaponire",
    "incaponirete": "incaponire",
    "incaponiron": "incaponire",
    "incaponirono": "incaponire",
    "incaponirà": "incaponire",
    "incaponirò": "incaponire",
    "incaponisse": "incaponire",
    "incaponisser": "incaponire",
    "incaponissero": "incaponire",
    "incaponissi": "incaponire",
    "incaponissimo": "incaponire",
    "incaponiste": "incaponire",
    "incaponisti": "incaponire",
    "incaponita": "incaponire",
    "incaponite": "incaponire",
    "incaponiti": "incaponire",
    "incaponito": "incaponire",
    "incaponiva": "incaponire",
    "incaponivamo": "incaponire",
    "incaponivan": "incaponire",
    "incaponivano": "incaponire",
    "incaponivate": "incaponire",
    "incaponivi": "incaponire",
    "incaponivo": "incaponire",
    "incapono": "incaponire",
    "incaponon": "incaponire",
    "incaponono": "incaponire",
    "incaponì": "incaponire",
    "incappa": "incappare",
    "incappai": "incappare",
    "incappammo": "incappare",
    "incappan": "incappare",
    "incappando": "incappare",
    "incappano": "incappare",
    "incappante": "incappare",
    "incappanti": "incappare",
    "incappar": "incappare",
    "incapparon": "incappare",
    "incapparono": "incappare",
    "incappasse": "incappare",
    "incappasser": "incappare",
    "incappassero": "incappare",
    "incappassi": "incappare",
    "incappassimo": "incappare",
    "incappaste": "incappare",
    "incappasti": "incappare",
    "incappata": "incappare",
    "incappate": "incappare",
    "incappati": "incappare",
    "incappato": "incappare",
    "incappava": "incappare",
    "incappavamo": "incappare",
    "incappavan": "incappare",
    "incappavano": "incappare",
    "incappavate": "incappare",
    "incappavi": "incappare",
    "incappavo": "incappare",
    "incappella": "incappellare",
    "incappellai": "incappellare",
    "incappellammo": "incappellare",
    "incappellan": "incappellare",
    "incappellando": "incappellare",
    "incappellano": "incappellare",
    "incappellante": "incappellare",
    "incappellanti": "incappellare",
    "incappellar": "incappellare",
    "incappellaron": "incappellare",
    "incappellarono": "incappellare",
    "incappellasse": "incappellare",
    "incappellasser": "incappellare",
    "incappellassero": "incappellare",
    "incappellassi": "incappellare",
    "incappellassimo": "incappellare",
    "incappellaste": "incappellare",
    "incappellasti": "incappellare",
    "incappellata": "incappellare",
    "incappellate": "incappellare",
    "incappellati": "incappellare",
    "incappellato": "incappellare",
    "incappellava": "incappellare",
    "incappellavamo": "incappellare",
    "incappellavan": "incappellare",
    "incappellavano": "incappellare",
    "incappellavate": "incappellare",
    "incappellavi": "incappellare",
    "incappellavo": "incappellare",
    "incappellerai": "incappellare",
    "incappelleran": "incappellare",
    "incappelleranno": "incappellare",
    "incappellerebbe": "incappellare",
    "incappellerebber": "incappellare",
    "incappellerebbero": "incappellare",
    "incappellerei": "incappellare",
    "incappelleremmo": "incappellare",
    "incappelleremo": "incappellare",
    "incappellereste": "incappellare",
    "incappelleresti": "incappellare",
    "incappellerete": "incappellare",
    "incappellerà": "incappellare",
    "incappellerò": "incappellare",
    "incappelli": "incappellare",
    "incappelliamo": "incappellare",
    "incappelliate": "incappellare",
    "incappellin": "incappellare",
    "incappellino": "incappellare",
    "incappello": "incappellare",
    "incappellò": "incappellare",
    "incapperai": "incappare",
    "incapperan": "incappare",
    "incapperanno": "incappare",
    "incapperebbe": "incappare",
    "incapperebber": "incappare",
    "incapperebbero": "incappare",
    "incapperei": "incappare",
    "incapperemmo": "incappare",
    "incapperemo": "incappare",
    "incappereste": "incappare",
    "incapperesti": "incappare",
    "incapperete": "incappare",
    "incapperà": "incappare",
    "incapperò": "incappare",
    "incappi": "incappare",
    "incappiamo": "incappare",
    "incappiate": "incappare",
    "incappin": "incappare",
    "incappino": "incappare",
    "incappo": "incappare",
    "incappotta": "incappottare",
    "incappottai": "incappottare",
    "incappottammo": "incappottare",
    "incappottan": "incappottare",
    "incappottando": "incappottare",
    "incappottano": "incappottare",
    "incappottante": "incappottare",
    "incappottanti": "incappottare",
    "incappottar": "incappottare",
    "incappottaron": "incappottare",
    "incappottarono": "incappottare",
    "incappottasse": "incappottare",
    "incappottasser": "incappottare",
    "incappottassero": "incappottare",
    "incappottassi": "incappottare",
    "incappottassimo": "incappottare",
    "incappottaste": "incappottare",
    "incappottasti": "incappottare",
    "incappottata": "incappottare",
    "incappottate": "incappottare",
    "incappottati": "incappottare",
    "incappottato": "incappottare",
    "incappottava": "incappottare",
    "incappottavamo": "incappottare",
    "incappottavan": "incappottare",
    "incappottavano": "incappottare",
    "incappottavate": "incappottare",
    "incappottavi": "incappottare",
    "incappottavo": "incappottare",
    "incappotterai": "incappottare",
    "incappotteran": "incappottare",
    "incappotteranno": "incappottare",
    "incappotterebbe": "incappottare",
    "incappotterebber": "incappottare",
    "incappotterebbero": "incappottare",
    "incappotterei": "incappottare",
    "incappotteremmo": "incappottare",
    "incappotteremo": "incappottare",
    "incappottereste": "incappottare",
    "incappotteresti": "incappottare",
    "incappotterete": "incappottare",
    "incappotterà": "incappottare",
    "incappotterò": "incappottare",
    "incappotti": "incappottare",
    "incappottiamo": "incappottare",
    "incappottiate": "incappottare",
    "incappottin": "incappottare",
    "incappottino": "incappottare",
    "incappotto": "incappottare",
    "incappottò": "incappottare",
    "incappuccerai": "incappucciare",
    "incappucceran": "incappucciare",
    "incappucceranno": "incappucciare",
    "incappuccerebbe": "incappucciare",
    "incappuccerebber": "incappucciare",
    "incappuccerebbero": "incappucciare",
    "incappuccerei": "incappucciare",
    "incappucceremmo": "incappucciare",
    "incappucceremo": "incappucciare",
    "incappuccereste": "incappucciare",
    "incappucceresti": "incappucciare",
    "incappuccerete": "incappucciare",
    "incappuccerà": "incappucciare",
    "incappuccerò": "incappucciare",
    "incappucci": "incappucciare",
    "incappuccia": "incappucciare",
    "incappucciai": "incappucciare",
    "incappucciammo": "incappucciare",
    "incappucciamo": "incappucciare",
    "incappuccian": "incappucciare",
    "incappucciando": "incappucciare",
    "incappucciano": "incappucciare",
    "incappucciante": "incappucciare",
    "incappuccianti": "incappucciare",
    "incappucciar": "incappucciare",
    "incappucciaron": "incappucciare",
    "incappucciarono": "incappucciare",
    "incappucciasse": "incappucciare",
    "incappucciasser": "incappucciare",
    "incappucciassero": "incappucciare",
    "incappucciassi": "incappucciare",
    "incappucciassimo": "incappucciare",
    "incappucciaste": "incappucciare",
    "incappucciasti": "incappucciare",
    "incappucciata": "incappucciare",
    "incappucciate": "incappucciare",
    "incappucciati": "incappucciare",
    "incappucciato": "incappucciare",
    "incappucciava": "incappucciare",
    "incappucciavamo": "incappucciare",
    "incappucciavan": "incappucciare",
    "incappucciavano": "incappucciare",
    "incappucciavate": "incappucciare",
    "incappucciavi": "incappucciare",
    "incappucciavo": "incappucciare",
    "incappuccin": "incappucciare",
    "incappuccino": "incappucciare",
    "incappuccio": "incappucciare",
    "incappucciò": "incappucciare",
    "incappò": "incappare",
    "incapriccerai": "incapricciare",
    "incapricceran": "incapricciare",
    "incapricceranno": "incapricciare",
    "incapriccerebbe": "incapricciare",
    "incapriccerebber": "incapricciare",
    "incapriccerebbero": "incapricciare",
    "incapriccerei": "incapricciare",
    "incapricceremmo": "incapricciare",
    "incapricceremo": "incapricciare",
    "incapriccereste": "incapricciare",
    "incapricceresti": "incapricciare",
    "incapriccerete": "incapricciare",
    "incapriccerà": "incapricciare",
    "incapriccerò": "incapricciare",
    "incapricci": "incapricciare",
    "incapriccia": "incapricciare",
    "incapricciai": "incapricciare",
    "incapricciammo": "incapricciare",
    "incapricciamo": "incapricciare",
    "incapriccian": "incapricciare",
    "incapricciando": "incapricciare",
    "incapricciano": "incapricciare",
    "incapricciar": "incapricciare",
    "incapricciaron": "incapricciare",
    "incapricciarono": "incapricciare",
    "incapricciasse": "incapricciare",
    "incapricciasser": "incapricciare",
    "incapricciassero": "incapricciare",
    "incapricciassi": "incapricciare",
    "incapricciassimo": "incapricciare",
    "incapricciaste": "incapricciare",
    "incapricciasti": "incapricciare",
    "incapricciata": "incapricciare",
    "incapricciate": "incapricciare",
    "incapricciati": "incapricciare",
    "incapricciato": "incapricciare",
    "incapricciava": "incapricciare",
    "incapricciavamo": "incapricciare",
    "incapricciavan": "incapricciare",
    "incapricciavano": "incapricciare",
    "incapricciavate": "incapricciare",
    "incapricciavi": "incapricciare",
    "incapricciavo": "incapricciare",
    "incapriccin": "incapricciare",
    "incapriccino": "incapricciare",
    "incapriccio": "incapricciare",
    "incapricciò": "incapricciare",
    "incapsula": "incapsulare",
    "incapsulai": "incapsulare",
    "incapsulammo": "incapsulare",
    "incapsulan": "incapsulare",
    "incapsulando": "incapsulare",
    "incapsulano": "incapsulare",
    "incapsulante": "incapsulare",
    "incapsulanti": "incapsulare",
    "incapsular": "incapsulare",
    "incapsularon": "incapsulare",
    "incapsularono": "incapsulare",
    "incapsulasse": "incapsulare",
    "incapsulasser": "incapsulare",
    "incapsulassero": "incapsulare",
    "incapsulassi": "incapsulare",
    "incapsulassimo": "incapsulare",
    "incapsulaste": "incapsulare",
    "incapsulasti": "incapsulare",
    "incapsulata": "incapsulare",
    "incapsulate": "incapsulare",
    "incapsulati": "incapsulare",
    "incapsulato": "incapsulare",
    "incapsulava": "incapsulare",
    "incapsulavamo": "incapsulare",
    "incapsulavan": "incapsulare",
    "incapsulavano": "incapsulare",
    "incapsulavate": "incapsulare",
    "incapsulavi": "incapsulare",
    "incapsulavo": "incapsulare",
    "incapsulerai": "incapsulare",
    "incapsuleran": "incapsulare",
    "incapsuleranno": "incapsulare",
    "incapsulerebbe": "incapsulare",
    "incapsulerebber": "incapsulare",
    "incapsulerebbero": "incapsulare",
    "incapsulerei": "incapsulare",
    "incapsuleremmo": "incapsulare",
    "incapsuleremo": "incapsulare",
    "incapsulereste": "incapsulare",
    "incapsuleresti": "incapsulare",
    "incapsulerete": "incapsulare",
    "incapsulerà": "incapsulare",
    "incapsulerò": "incapsulare",
    "incapsuli": "incapsulare",
    "incapsuliamo": "incapsulare",
    "incapsuliate": "incapsulare",
    "incapsulin": "incapsulare",
    "incapsulino": "incapsulare",
    "incapsulo": "incapsulare",
    "incapsulò": "incapsulare",
    "incarcera": "incarcerare",
    "incarcerai": "incarcerare",
    "incarcerammo": "incarcerare",
    "incarceran": "incarcerare",
    "incarcerando": "incarcerare",
    "incarcerano": "incarcerare",
    "incarcerante": "incarcerare",
    "incarceranti": "incarcerare",
    "incarcerar": "incarcerare",
    "incarceraron": "incarcerare",
    "incarcerarono": "incarcerare",
    "incarcerasse": "incarcerare",
    "incarcerasser": "incarcerare",
    "incarcerassero": "incarcerare",
    "incarcerassi": "incarcerare",
    "incarcerassimo": "incarcerare",
    "incarceraste": "incarcerare",
    "incarcerasti": "incarcerare",
    "incarcerata": "incarcerare",
    "incarcerate": "incarcerare",
    "incarcerati": "incarcerare",
    "incarcerato": "incarcerare",
    "incarcerava": "incarcerare",
    "incarceravamo": "incarcerare",
    "incarceravan": "incarcerare",
    "incarceravano": "incarcerare",
    "incarceravate": "incarcerare",
    "incarceravi": "incarcerare",
    "incarceravo": "incarcerare",
    "incarcerazioni": "incarcerazione",
    "incarcererai": "incarcerare",
    "incarcereran": "incarcerare",
    "incarcereranno": "incarcerare",
    "incarcererebbe": "incarcerare",
    "incarcererebber": "incarcerare",
    "incarcererebbero": "incarcerare",
    "incarcererei": "incarcerare",
    "incarcereremmo": "incarcerare",
    "incarcereremo": "incarcerare",
    "incarcerereste": "incarcerare",
    "incarcereresti": "incarcerare",
    "incarcererete": "incarcerare",
    "incarcererà": "incarcerare",
    "incarcererò": "incarcerare",
    "incarceri": "incarcerare",
    "incarceriamo": "incarcerare",
    "incarceriate": "incarcerare",
    "incarcerin": "incarcerare",
    "incarcerino": "incarcerare",
    "incarcero": "incarcerare",
    "incarcerò": "incarcerare",
    "incardina": "incardinare",
    "incardinai": "incardinare",
    "incardinammo": "incardinare",
    "incardinan": "incardinare",
    "incardinando": "incardinare",
    "incardinano": "incardinare",
    "incardinante": "incardinare",
    "incardinanti": "incardinare",
    "incardinar": "incardinare",
    "incardinaron": "incardinare",
    "incardinarono": "incardinare",
    "incardinasse": "incardinare",
    "incardinasser": "incardinare",
    "incardinassero": "incardinare",
    "incardinassi": "incardinare",
    "incardinassimo": "incardinare",
    "incardinaste": "incardinare",
    "incardinasti": "incardinare",
    "incardinata": "incardinare",
    "incardinate": "incardinare",
    "incardinati": "incardinare",
    "incardinato": "incardinare",
    "incardinava": "incardinare",
    "incardinavamo": "incardinare",
    "incardinavan": "incardinare",
    "incardinavano": "incardinare",
    "incardinavate": "incardinare",
    "incardinavi": "incardinare",
    "incardinavo": "incardinare",
    "incardinerai": "incardinare",
    "incardineran": "incardinare",
    "incardineranno": "incardinare",
    "incardinerebbe": "incardinare",
    "incardinerebber": "incardinare",
    "incardinerebbero": "incardinare",
    "incardinerei": "incardinare",
    "incardineremmo": "incardinare",
    "incardineremo": "incardinare",
    "incardinereste": "incardinare",
    "incardineresti": "incardinare",
    "incardinerete": "incardinare",
    "incardinerà": "incardinare",
    "incardinerò": "incardinare",
    "incardini": "incardinare",
    "incardiniamo": "incardinare",
    "incardiniate": "incardinare",
    "incardinin": "incardinare",
    "incardinino": "incardinare",
    "incardino": "incardinare",
    "incardinò": "incardinare",
    "incarica": "incaricare",
    "incaricai": "incaricare",
    "incaricammo": "incaricare",
    "incarican": "incaricare",
    "incaricando": "incaricare",
    "incaricano": "incaricare",
    "incaricante": "incaricare",
    "incaricanti": "incaricare",
    "incaricar": "incaricare",
    "incaricaron": "incaricare",
    "incaricarono": "incaricare",
    "incaricasse": "incaricare",
    "incaricasser": "incaricare",
    "incaricassero": "incaricare",
    "incaricassi": "incaricare",
    "incaricassimo": "incaricare",
    "incaricaste": "incaricare",
    "incaricasti": "incaricare",
    "incaricata": "incaricato",
    "incaricate": "incaricato",
    "incaricati": "incaricato",
    "incaricato": "incaricare",
    "incaricava": "incaricare",
    "incaricavamo": "incaricare",
    "incaricavan": "incaricare",
    "incaricavano": "incaricare",
    "incaricavate": "incaricare",
    "incaricavi": "incaricare",
    "incaricavo": "incaricare",
    "incaricherai": "incaricare",
    "incaricheran": "incaricare",
    "incaricheranno": "incaricare",
    "incaricherebbe": "incaricare",
    "incaricherebber": "incaricare",
    "incaricherebbero": "incaricare",
    "incaricherei": "incaricare",
    "incaricheremmo": "incaricare",
    "incaricheremo": "incaricare",
    "incarichereste": "incaricare",
    "incaricheresti": "incaricare",
    "incaricherete": "incaricare",
    "incaricherà": "incaricare",
    "incaricherò": "incaricare",
    "incarichi": "incarico",
    "incarichiamo": "incaricare",
    "incarichiate": "incaricare",
    "incarichin": "incaricare",
    "incarichino": "incaricare",
    "incarico": "incaricare",
    "incaricò": "incaricare",
    "incarna": "incarnire",
    "incarnai": "incarnare",
    "incarnammo": "incarnare",
    "incarnan": "incarnire",
    "incarnando": "incarnare",
    "incarnano": "incarnire",
    "incarnante": "incarnare",
    "incarnanti": "incarnare",
    "incarnar": "incarnare",
    "incarnaron": "incarnare",
    "incarnarono": "incarnare",
    "incarnasse": "incarnare",
    "incarnasser": "incarnare",
    "incarnassero": "incarnare",
    "incarnassi": "incarnare",
    "incarnassimo": "incarnare",
    "incarnaste": "incarnare",
    "incarnasti": "incarnare",
    "incarnata": "incarnato",
    "incarnate": "incarnato",
    "incarnati": "incarnato",
    "incarnato": "incarnare",
    "incarnava": "incarnare",
    "incarnavamo": "incarnare",
    "incarnavan": "incarnare",
    "incarnavano": "incarnare",
    "incarnavate": "incarnare",
    "incarnavi": "incarnare",
    "incarnavo": "incarnare",
    "incarnazioni": "incarnazione",
    "incarne": "incarnire",
    "incarnendo": "incarnire",
    "incarnente": "incarnire",
    "incarnenti": "incarnire",
    "incarnerai": "incarnare",
    "incarneran": "incarnare",
    "incarneranno": "incarnare",
    "incarnerebbe": "incarnare",
    "incarnerebber": "incarnare",
    "incarnerebbero": "incarnare",
    "incarnerei": "incarnare",
    "incarneremmo": "incarnare",
    "incarneremo": "incarnare",
    "incarnereste": "incarnare",
    "incarneresti": "incarnare",
    "incarnerete": "incarnare",
    "incarnerà": "incarnare",
    "incarnerò": "incarnare",
    "incarni": "incarnire",
    "incarniamo": "incarnire",
    "incarniate": "incarnire",
    "incarnii": "incarnire",
    "incarnimmo": "incarnire",
    "incarnin": "incarnare",
    "incarnino": "incarnare",
    "incarnir": "incarnire",
    "incarnirai": "incarnire",
    "incarniran": "incarnire",
    "incarniranno": "incarnire",
    "incarnirebbe": "incarnire",
    "incarnirebber": "incarnire",
    "incarnirebbero": "incarnire",
    "incarnirei": "incarnire",
    "incarniremmo": "incarnire",
    "incarniremo": "incarnire",
    "incarnireste": "incarnire",
    "incarniresti": "incarnire",
    "incarnirete": "incarnire",
    "incarniron": "incarnire",
    "incarnirono": "incarnire",
    "incarnirà": "incarnire",
    "incarnirò": "incarnire",
    "incarnisse": "incarnire",
    "incarnisser": "incarnire",
    "incarnissero": "incarnire",
    "incarnissi": "incarnire",
    "incarnissimo": "incarnire",
    "incarniste": "incarnire",
    "incarnisti": "incarnire",
    "incarnita": "incarnire",
    "incarnite": "incarnire",
    "incarniti": "incarnire",
    "incarnito": "incarnire",
    "incarniva": "incarnire",
    "incarnivamo": "incarnire",
    "incarnivan": "incarnire",
    "incarnivano": "incarnire",
    "incarnivate": "incarnire",
    "incarnivi": "incarnire",
    "incarnivo": "incarnire",
    "incarno": "incarnire",
    "incarnon": "incarnire",
    "incarnono": "incarnire",
    "incarnì": "incarnire",
    "incarnò": "incarnare",
    "incarognendo": "incarognire",
    "incarognente": "incarognire",
    "incarognenti": "incarognire",
    "incarogniamo": "incarognire",
    "incarogniate": "incarognire",
    "incarognii": "incarognire",
    "incarognimmo": "incarognire",
    "incarognir": "incarognire",
    "incarognirai": "incarognire",
    "incarogniran": "incarognire",
    "incarogniranno": "incarognire",
    "incarognirebbe": "incarognire",
    "incarognirebber": "incarognire",
    "incarognirebbero": "incarognire",
    "incarognirei": "incarognire",
    "incarogniremmo": "incarognire",
    "incarogniremo": "incarognire",
    "incarognireste": "incarognire",
    "incarogniresti": "incarognire",
    "incarognirete": "incarognire",
    "incarogniron": "incarognire",
    "incarognirono": "incarognire",
    "incarognirà": "incarognire",
    "incarognirò": "incarognire",
    "incarognisca": "incarognire",
    "incarogniscan": "incarognire",
    "incarogniscano": "incarognire",
    "incarognisce": "incarognire",
    "incarognisci": "incarognire",
    "incarognisco": "incarognire",
    "incarogniscon": "incarognire",
    "incarogniscono": "incarognire",
    "incarognisse": "incarognire",
    "incarognisser": "incarognire",
    "incarognissero": "incarognire",
    "incarognissi": "incarognire",
    "incarognissimo": "incarognire",
    "incarogniste": "incarognire",
    "incarognisti": "incarognire",
    "incarognita": "incarognire",
    "incarognite": "incarognire",
    "incarogniti": "incarognire",
    "incarognito": "incarognire",
    "incarogniva": "incarognire",
    "incarognivamo": "incarognire",
    "incarognivan": "incarognire",
    "incarognivano": "incarognire",
    "incarognivate": "incarognire",
    "incarognivi": "incarognire",
    "incarognivo": "incarognire",
    "incarognì": "incarognire",
    "incarta": "incartare",
    "incartai": "incartare",
    "incartamenti": "incartamento",
    "incartammo": "incartare",
    "incartan": "incartare",
    "incartando": "incartare",
    "incartano": "incartare",
    "incartante": "incartare",
    "incartanti": "incartare",
    "incartapecora": "incartapecorire",
    "incartapecoran": "incartapecorire",
    "incartapecorano": "incartapecorire",
    "incartapecore": "incartapecorire",
    "incartapecorendo": "incartapecorire",
    "incartapecorente": "incartapecorire",
    "incartapecorenti": "incartapecorire",
    "incartapecori": "incartapecorire",
    "incartapecoriamo": "incartapecorire",
    "incartapecoriate": "incartapecorire",
    "incartapecorii": "incartapecorire",
    "incartapecorimmo": "incartapecorire",
    "incartapecorir": "incartapecorire",
    "incartapecorirai": "incartapecorire",
    "incartapecoriran": "incartapecorire",
    "incartapecoriranno": "incartapecorire",
    "incartapecorirebbe": "incartapecorire",
    "incartapecorirebber": "incartapecorire",
    "incartapecorirebbero": "incartapecorire",
    "incartapecorirei": "incartapecorire",
    "incartapecoriremmo": "incartapecorire",
    "incartapecoriremo": "incartapecorire",
    "incartapecorireste": "incartapecorire",
    "incartapecoriresti": "incartapecorire",
    "incartapecorirete": "incartapecorire",
    "incartapecoriron": "incartapecorire",
    "incartapecorirono": "incartapecorire",
    "incartapecorirà": "incartapecorire",
    "incartapecorirò": "incartapecorire",
    "incartapecorisse": "incartapecorire",
    "incartapecorisser": "incartapecorire",
    "incartapecorissero": "incartapecorire",
    "incartapecorissi": "incartapecorire",
    "incartapecorissimo": "incartapecorire",
    "incartapecoriste": "incartapecorire",
    "incartapecoristi": "incartapecorire",
    "incartapecorita": "incartapecorire",
    "incartapecorite": "incartapecorire",
    "incartapecoriti": "incartapecorire",
    "incartapecorito": "incartapecorire",
    "incartapecoriva": "incartapecorire",
    "incartapecorivamo": "incartapecorire",
    "incartapecorivan": "incartapecorire",
    "incartapecorivano": "incartapecorire",
    "incartapecorivate": "incartapecorire",
    "incartapecorivi": "incartapecorire",
    "incartapecorivo": "incartapecorire",
    "incartapecoro": "incartapecorire",
    "incartapecoron": "incartapecorire",
    "incartapecorono": "incartapecorire",
    "incartapecorì": "incartapecorire",
    "incartar": "incartare",
    "incartaron": "incartare",
    "incartarono": "incartare",
    "incartasse": "incartare",
    "incartasser": "incartare",
    "incartassero": "incartare",
    "incartassi": "incartare",
    "incartassimo": "incartare",
    "incartaste": "incartare",
    "incartasti": "incartare",
    "incartata": "incartare",
    "incartate": "incartare",
    "incartati": "incartare",
    "incartato": "incartare",
    "incartava": "incartare",
    "incartavamo": "incartare",
    "incartavan": "incartare",
    "incartavano": "incartare",
    "incartavate": "incartare",
    "incartavi": "incartare",
    "incartavo": "incartare",
    "incarterai": "incartare",
    "incarteran": "incartare",
    "incarteranno": "incartare",
    "incarterebbe": "incartare",
    "incarterebber": "incartare",
    "incarterebbero": "incartare",
    "incarterei": "incartare",
    "incarteremmo": "incartare",
    "incarteremo": "incartare",
    "incartereste": "incartare",
    "incarteresti": "incartare",
    "incarterete": "incartare",
    "incarterà": "incartare",
    "incarterò": "incartare",
    "incarti": "incartare",
    "incartiamo": "incartare",
    "incartiate": "incartare",
    "incartin": "incartare",
    "incartino": "incartare",
    "incarto": "incartare",
    "incartoccerai": "incartocciare",
    "incartocceran": "incartocciare",
    "incartocceranno": "incartocciare",
    "incartoccerebbe": "incartocciare",
    "incartoccerebber": "incartocciare",
    "incartoccerebbero": "incartocciare",
    "incartoccerei": "incartocciare",
    "incartocceremmo": "incartocciare",
    "incartocceremo": "incartocciare",
    "incartoccereste": "incartocciare",
    "incartocceresti": "incartocciare",
    "incartoccerete": "incartocciare",
    "incartoccerà": "incartocciare",
    "incartoccerò": "incartocciare",
    "incartocci": "incartocciare",
    "incartoccia": "incartocciare",
    "incartocciai": "incartocciare",
    "incartocciammo": "incartocciare",
    "incartocciamo": "incartocciare",
    "incartoccian": "incartocciare",
    "incartocciando": "incartocciare",
    "incartocciano": "incartocciare",
    "incartocciante": "incartocciare",
    "incartoccianti": "incartocciare",
    "incartocciar": "incartocciare",
    "incartocciaron": "incartocciare",
    "incartocciarono": "incartocciare",
    "incartocciasse": "incartocciare",
    "incartocciasser": "incartocciare",
    "incartocciassero": "incartocciare",
    "incartocciassi": "incartocciare",
    "incartocciassimo": "incartocciare",
    "incartocciaste": "incartocciare",
    "incartocciasti": "incartocciare",
    "incartocciata": "incartocciare",
    "incartocciate": "incartocciare",
    "incartocciati": "incartocciare",
    "incartocciato": "incartocciare",
    "incartocciava": "incartocciare",
    "incartocciavamo": "incartocciare",
    "incartocciavan": "incartocciare",
    "incartocciavano": "incartocciare",
    "incartocciavate": "incartocciare",
    "incartocciavi": "incartocciare",
    "incartocciavo": "incartocciare",
    "incartoccin": "incartocciare",
    "incartoccino": "incartocciare",
    "incartoccio": "incartocciare",
    "incartocciò": "incartocciare",
    "incartò": "incartare",
    "incasella": "incasellare",
    "incasellai": "incasellare",
    "incasellammo": "incasellare",
    "incasellan": "incasellare",
    "incasellando": "incasellare",
    "incasellano": "incasellare",
    "incasellante": "incasellare",
    "incasellanti": "incasellare",
    "incasellar": "incasellare",
    "incasellaron": "incasellare",
    "incasellarono": "incasellare",
    "incasellasse": "incasellare",
    "incasellasser": "incasellare",
    "incasellassero": "incasellare",
    "incasellassi": "incasellare",
    "incasellassimo": "incasellare",
    "incasellaste": "incasellare",
    "incasellasti": "incasellare",
    "incasellata": "incasellare",
    "incasellate": "incasellare",
    "incasellati": "incasellare",
    "incasellato": "incasellare",
    "incasellava": "incasellare",
    "incasellavamo": "incasellare",
    "incasellavan": "incasellare",
    "incasellavano": "incasellare",
    "incasellavate": "incasellare",
    "incasellavi": "incasellare",
    "incasellavo": "incasellare",
    "incasellerai": "incasellare",
    "incaselleran": "incasellare",
    "incaselleranno": "incasellare",
    "incasellerebbe": "incasellare",
    "incasellerebber": "incasellare",
    "incasellerebbero": "incasellare",
    "incasellerei": "incasellare",
    "incaselleremmo": "incasellare",
    "incaselleremo": "incasellare",
    "incasellereste": "incasellare",
    "incaselleresti": "incasellare",
    "incasellerete": "incasellare",
    "incasellerà": "incasellare",
    "incasellerò": "incasellare",
    "incaselli": "incasellare",
    "incaselliamo": "incasellare",
    "incaselliate": "incasellare",
    "incasellin": "incasellare",
    "incasellino": "incasellare",
    "incasello": "incasellare",
    "incasellò": "incasellare",
    "incasina": "incasinare",
    "incasinai": "incasinare",
    "incasinammo": "incasinare",
    "incasinan": "incasinare",
    "incasinando": "incasinare",
    "incasinano": "incasinare",
    "incasinante": "incasinare",
    "incasinanti": "incasinare",
    "incasinar": "incasinare",
    "incasinaron": "incasinare",
    "incasinarono": "incasinare",
    "incasinasse": "incasinare",
    "incasinasser": "incasinare",
    "incasinassero": "incasinare",
    "incasinassi": "incasinare",
    "incasinassimo": "incasinare",
    "incasinaste": "incasinare",
    "incasinasti": "incasinare",
    "incasinata": "incasinato",
    "incasinate": "incasinato",
    "incasinati": "incasinato",
    "incasinato": "incasinare",
    "incasinava": "incasinare",
    "incasinavamo": "incasinare",
    "incasinavan": "incasinare",
    "incasinavano": "incasinare",
    "incasinavate": "incasinare",
    "incasinavi": "incasinare",
    "incasinavo": "incasinare",
    "incasinerai": "incasinare",
    "incasineran": "incasinare",
    "incasineranno": "incasinare",
    "incasinerebbe": "incasinare",
    "incasinerebber": "incasinare",
    "incasinerebbero": "incasinare",
    "incasinerei": "incasinare",
    "incasineremmo": "incasinare",
    "incasineremo": "incasinare",
    "incasinereste": "incasinare",
    "incasineresti": "incasinare",
    "incasinerete": "incasinare",
    "incasinerà": "incasinare",
    "incasinerò": "incasinare",
    "incasini": "incasinare",
    "incasiniamo": "incasinare",
    "incasiniate": "incasinare",
    "incasinin": "incasinare",
    "incasinino": "incasinare",
    "incasino": "incasinare",
    "incasinò": "incasinare",
    "incassa": "incassare",
    "incassai": "incassare",
    "incassammo": "incassare",
    "incassan": "incassare",
    "incassando": "incassare",
    "incassano": "incassare",
    "incassante": "incassare",
    "incassanti": "incassare",
    "incassar": "incassare",
    "incassaron": "incassare",
    "incassarono": "incassare",
    "incassasse": "incassare",
    "incassasser": "incassare",
    "incassassero": "incassare",
    "incassassi": "incassare",
    "incassassimo": "incassare",
    "incassaste": "incassare",
    "incassasti": "incassare",
    "incassata": "incassato",
    "incassate": "incassato",
    "incassati": "incassato",
    "incassato": "incassare",
    "incassava": "incassare",
    "incassavamo": "incassare",
    "incassavan": "incassare",
    "incassavano": "incassare",
    "incassavate": "incassare",
    "incassavi": "incassare",
    "incassavo": "incassare",
    "incasserai": "incassare",
    "incasseran": "incassare",
    "incasseranno": "incassare",
    "incasserebbe": "incassare",
    "incasserebber": "incassare",
    "incasserebbero": "incassare",
    "incasserei": "incassare",
    "incasseremmo": "incassare",
    "incasseremo": "incassare",
    "incassereste": "incassare",
    "incasseresti": "incassare",
    "incasserete": "incassare",
    "incasserà": "incassare",
    "incasserò": "incassare",
    "incassi": "incasso",
    "incassiamo": "incassare",
    "incassiate": "incassare",
    "incassin": "incassare",
    "incassino": "incassare",
    "incasso": "incassare",
    "incassò": "incassare",
    "incastona": "incastonare",
    "incastonai": "incastonare",
    "incastonammo": "incastonare",
    "incastonan": "incastonare",
    "incastonando": "incastonare",
    "incastonano": "incastonare",
    "incastonante": "incastonare",
    "incastonanti": "incastonare",
    "incastonar": "incastonare",
    "incastonaron": "incastonare",
    "incastonarono": "incastonare",
    "incastonasse": "incastonare",
    "incastonasser": "incastonare",
    "incastonassero": "incastonare",
    "incastonassi": "incastonare",
    "incastonassimo": "incastonare",
    "incastonaste": "incastonare",
    "incastonasti": "incastonare",
    "incastonata": "incastonare",
    "incastonate": "incastonare",
    "incastonati": "incastonare",
    "incastonato": "incastonare",
    "incastonava": "incastonare",
    "incastonavamo": "incastonare",
    "incastonavan": "incastonare",
    "incastonavano": "incastonare",
    "incastonavate": "incastonare",
    "incastonavi": "incastonare",
    "incastonavo": "incastonare",
    "incastonerai": "incastonare",
    "incastoneran": "incastonare",
    "incastoneranno": "incastonare",
    "incastonerebbe": "incastonare",
    "incastonerebber": "incastonare",
    "incastonerebbero": "incastonare",
    "incastonerei": "incastonare",
    "incastoneremmo": "incastonare",
    "incastoneremo": "incastonare",
    "incastonereste": "incastonare",
    "incastoneresti": "incastonare",
    "incastonerete": "incastonare",
    "incastonerà": "incastonare",
    "incastonerò": "incastonare",
    "incastoni": "incastonare",
    "incastoniamo": "incastonare",
    "incastoniate": "incastonare",
    "incastonin": "incastonare",
    "incastonino": "incastonare",
    "incastono": "incastonare",
    "incastonò": "incastonare",
    "incastra": "incastrare",
    "incastrai": "incastrare",
    "incastrammo": "incastrare",
    "incastran": "incastrare",
    "incastrando": "incastrare",
    "incastrano": "incastrare",
    "incastrante": "incastrare",
    "incastranti": "incastrare",
    "incastrar": "incastrare",
    "incastraron": "incastrare",
    "incastrarono": "incastrare",
    "incastrasse": "incastrare",
    "incastrasser": "incastrare",
    "incastrassero": "incastrare",
    "incastrassi": "incastrare",
    "incastrassimo": "incastrare",
    "incastraste": "incastrare",
    "incastrasti": "incastrare",
    "incastrata": "incastrare",
    "incastrate": "incastrare",
    "incastrati": "incastrare",
    "incastrato": "incastrare",
    "incastrava": "incastrare",
    "incastravamo": "incastrare",
    "incastravan": "incastrare",
    "incastravano": "incastrare",
    "incastravate": "incastrare",
    "incastravi": "incastrare",
    "incastravo": "incastrare",
    "incastrerai": "incastrare",
    "incastreran": "incastrare",
    "incastreranno": "incastrare",
    "incastrerebbe": "incastrare",
    "incastrerebber": "incastrare",
    "incastrerebbero": "incastrare",
    "incastrerei": "incastrare",
    "incastreremmo": "incastrare",
    "incastreremo": "incastrare",
    "incastrereste": "incastrare",
    "incastreresti": "incastrare",
    "incastrerete": "incastrare",
    "incastrerà": "incastrare",
    "incastrerò": "incastrare",
    "incastri": "incastro",
    "incastriamo": "incastrare",
    "incastriate": "incastrare",
    "incastrin": "incastrare",
    "incastrino": "incastrare",
    "incastro": "incastrare",
    "incastrò": "incastrare",
    "incatena": "incatenare",
    "incatenai": "incatenare",
    "incatenammo": "incatenare",
    "incatenan": "incatenare",
    "incatenando": "incatenare",
    "incatenano": "incatenare",
    "incatenante": "incatenare",
    "incatenanti": "incatenare",
    "incatenar": "incatenare",
    "incatenaron": "incatenare",
    "incatenarono": "incatenare",
    "incatenasse": "incatenare",
    "incatenasser": "incatenare",
    "incatenassero": "incatenare",
    "incatenassi": "incatenare",
    "incatenassimo": "incatenare",
    "incatenaste": "incatenare",
    "incatenasti": "incatenare",
    "incatenata": "incatenare",
    "incatenate": "incatenare",
    "incatenati": "incatenare",
    "incatenato": "incatenare",
    "incatenava": "incatenare",
    "incatenavamo": "incatenare",
    "incatenavan": "incatenare",
    "incatenavano": "incatenare",
    "incatenavate": "incatenare",
    "incatenavi": "incatenare",
    "incatenavo": "incatenare",
    "incatenerai": "incatenare",
    "incateneran": "incatenare",
    "incateneranno": "incatenare",
    "incatenerebbe": "incatenare",
    "incatenerebber": "incatenare",
    "incatenerebbero": "incatenare",
    "incatenerei": "incatenare",
    "incateneremmo": "incatenare",
    "incateneremo": "incatenare",
    "incatenereste": "incatenare",
    "incateneresti": "incatenare",
    "incatenerete": "incatenare",
    "incatenerà": "incatenare",
    "incatenerò": "incatenare",
    "incateni": "incatenare",
    "incateniamo": "incatenare",
    "incateniate": "incatenare",
    "incatenin": "incatenare",
    "incatenino": "incatenare",
    "incateno": "incatenare",
    "incatenò": "incatenare",
    "incatrama": "incatramare",
    "incatramai": "incatramare",
    "incatramammo": "incatramare",
    "incatraman": "incatramare",
    "incatramando": "incatramare",
    "incatramano": "incatramare",
    "incatramante": "incatramare",
    "incatramanti": "incatramare",
    "incatramar": "incatramare",
    "incatramaron": "incatramare",
    "incatramarono": "incatramare",
    "incatramasse": "incatramare",
    "incatramasser": "incatramare",
    "incatramassero": "incatramare",
    "incatramassi": "incatramare",
    "incatramassimo": "incatramare",
    "incatramaste": "incatramare",
    "incatramasti": "incatramare",
    "incatramata": "incatramare",
    "incatramate": "incatramare",
    "incatramati": "incatramare",
    "incatramato": "incatramare",
    "incatramava": "incatramare",
    "incatramavamo": "incatramare",
    "incatramavan": "incatramare",
    "incatramavano": "incatramare",
    "incatramavate": "incatramare",
    "incatramavi": "incatramare",
    "incatramavo": "incatramare",
    "incatramerai": "incatramare",
    "incatrameran": "incatramare",
    "incatrameranno": "incatramare",
    "incatramerebbe": "incatramare",
    "incatramerebber": "incatramare",
    "incatramerebbero": "incatramare",
    "incatramerei": "incatramare",
    "incatrameremmo": "incatramare",
    "incatrameremo": "incatramare",
    "incatramereste": "incatramare",
    "incatrameresti": "incatramare",
    "incatramerete": "incatramare",
    "incatramerà": "incatramare",
    "incatramerò": "incatramare",
    "incatrami": "incatramare",
    "incatramiamo": "incatramare",
    "incatramiate": "incatramare",
    "incatramin": "incatramare",
    "incatramino": "incatramare",
    "incatramo": "incatramare",
    "incatramò": "incatramare",
    "incattivendo": "incattivire",
    "incattivente": "incattivire",
    "incattiventi": "incattivire",
    "incattiviamo": "incattivire",
    "incattiviate": "incattivire",
    "incattivii": "incattivire",
    "incattivimmo": "incattivire",
    "incattivir": "incattivire",
    "incattivirai": "incattivire",
    "incattiviran": "incattivire",
    "incattiviranno": "incattivire",
    "incattivirebbe": "incattivire",
    "incattivirebber": "incattivire",
    "incattivirebbero": "incattivire",
    "incattivirei": "incattivire",
    "incattiviremmo": "incattivire",
    "incattiviremo": "incattivire",
    "incattivireste": "incattivire",
    "incattiviresti": "incattivire",
    "incattivirete": "incattivire",
    "incattiviron": "incattivire",
    "incattivirono": "incattivire",
    "incattivirà": "incattivire",
    "incattivirò": "incattivire",
    "incattivisca": "incattivire",
    "incattiviscan": "incattivire",
    "incattiviscano": "incattivire",
    "incattivisce": "incattivire",
    "incattivisci": "incattivire",
    "incattivisco": "incattivire",
    "incattiviscon": "incattivire",
    "incattiviscono": "incattivire",
    "incattivisse": "incattivire",
    "incattivisser": "incattivire",
    "incattivissero": "incattivire",
    "incattivissi": "incattivire",
    "incattivissimo": "incattivire",
    "incattiviste": "incattivire",
    "incattivisti": "incattivire",
    "incattivita": "incattivire",
    "incattivite": "incattivire",
    "incattiviti": "incattivire",
    "incattivito": "incattivire",
    "incattiviva": "incattivire",
    "incattivivamo": "incattivire",
    "incattivivan": "incattivire",
    "incattivivano": "incattivire",
    "incattivivate": "incattivire",
    "incattivivi": "incattivire",
    "incattivivo": "incattivire",
    "incattivì": "incattivire",
    "incauta": "incauto",
    "incaute": "incauto",
    "incauti": "incauto",
    "incava": "incavare",
    "incavai": "incavare",
    "incavammo": "incavare",
    "incavan": "incavare",
    "incavando": "incavare",
    "incavano": "incavare",
    "incavante": "incavare",
    "incavanti": "incavare",
    "incavar": "incavare",
    "incavaron": "incavare",
    "incavarono": "incavare",
    "incavasse": "incavare",
    "incavasser": "incavare",
    "incavassero": "incavare",
    "incavassi": "incavare",
    "incavassimo": "incavare",
    "incavaste": "incavare",
    "incavasti": "incavare",
    "incavata": "incavato",
    "incavate": "incavato",
    "incavati": "incavato",
    "incavato": "incavare",
    "incavava": "incavare",
    "incavavamo": "incavare",
    "incavavan": "incavare",
    "incavavano": "incavare",
    "incavavate": "incavare",
    "incavavi": "incavare",
    "incavavo": "incavare",
    "incaverai": "incavare",
    "incaveran": "incavare",
    "incaveranno": "incavare",
    "incaverebbe": "incavare",
    "incaverebber": "incavare",
    "incaverebbero": "incavare",
    "incaverei": "incavare",
    "incaveremmo": "incavare",
    "incaveremo": "incavare",
    "incavereste": "incavare",
    "incaveresti": "incavare",
    "incaverete": "incavare",
    "incaverà": "incavare",
    "incaverò": "incavare",
    "incavi": "incavare",
    "incaviamo": "incavare",
    "incaviate": "incavare",
    "incavin": "incavare",
    "incavino": "incavare",
    "incavo": "incavare",
    "incavola": "incavolare",
    "incavolai": "incavolare",
    "incavolammo": "incavolare",
    "incavolan": "incavolare",
    "incavolando": "incavolare",
    "incavolano": "incavolare",
    "incavolar": "incavolare",
    "incavolaron": "incavolare",
    "incavolarono": "incavolare",
    "incavolasse": "incavolare",
    "incavolasser": "incavolare",
    "incavolassero": "incavolare",
    "incavolassi": "incavolare",
    "incavolassimo": "incavolare",
    "incavolaste": "incavolare",
    "incavolasti": "incavolare",
    "incavolata": "incavolare",
    "incavolate": "incavolare",
    "incavolati": "incavolare",
    "incavolato": "incavolare",
    "incavolava": "incavolare",
    "incavolavamo": "incavolare",
    "incavolavan": "incavolare",
    "incavolavano": "incavolare",
    "incavolavate": "incavolare",
    "incavolavi": "incavolare",
    "incavolavo": "incavolare",
    "incavolerai": "incavolare",
    "incavoleran": "incavolare",
    "incavoleranno": "incavolare",
    "incavolerebbe": "incavolare",
    "incavolerebber": "incavolare",
    "incavolerebbero": "incavolare",
    "incavolerei": "incavolare",
    "incavoleremmo": "incavolare",
    "incavoleremo": "incavolare",
    "incavolereste": "incavolare",
    "incavoleresti": "incavolare",
    "incavolerete": "incavolare",
    "incavolerà": "incavolare",
    "incavolerò": "incavolare",
    "incavoli": "incavolare",
    "incavoliamo": "incavolare",
    "incavoliate": "incavolare",
    "incavolin": "incavolare",
    "incavolino": "incavolare",
    "incavolo": "incavolare",
    "incavolò": "incavolare",
    "incavò": "incavare",
    "incazza": "incazzare",
    "incazzai": "incazzare",
    "incazzammo": "incazzare",
    "incazzan": "incazzare",
    "incazzando": "incazzare",
    "incazzano": "incazzare",
    "incazzar": "incazzare",
    "incazzaron": "incazzare",
    "incazzarono": "incazzare",
    "incazzasse": "incazzare",
    "incazzasser": "incazzare",
    "incazzassero": "incazzare",
    "incazzassi": "incazzare",
    "incazzassimo": "incazzare",
    "incazzaste": "incazzare",
    "incazzasti": "incazzare",
    "incazzata": "incazzare",
    "incazzate": "incazzare",
    "incazzati": "incazzare",
    "incazzato": "incazzare",
    "incazzature": "incazzatura",
    "incazzava": "incazzare",
    "incazzavamo": "incazzare",
    "incazzavan": "incazzare",
    "incazzavano": "incazzare",
    "incazzavate": "incazzare",
    "incazzavi": "incazzare",
    "incazzavo": "incazzare",
    "incazzerai": "incazzare",
    "incazzeran": "incazzare",
    "incazzeranno": "incazzare",
    "incazzerebbe": "incazzare",
    "incazzerebber": "incazzare",
    "incazzerebbero": "incazzare",
    "incazzerei": "incazzare",
    "incazzeremmo": "incazzare",
    "incazzeremo": "incazzare",
    "incazzereste": "incazzare",
    "incazzeresti": "incazzare",
    "incazzerete": "incazzare",
    "incazzerà": "incazzare",
    "incazzerò": "incazzare",
    "incazzi": "incazzare",
    "incazziamo": "incazzare",
    "incazziate": "incazzare",
    "incazzin": "incazzare",
    "incazzino": "incazzare",
    "incazzo": "incazzare",
    "incazzò": "incazzare",
    "inceda": "incedere",
    "incedan": "incedere",
    "incedano": "incedere",
    "incede": "incedere",
    "incedei": "incedere",
    "incedemmo": "incedere",
    "incedendo": "incedere",
    "incedente": "incedere",
    "incedenti": "incedere",
    "inceder": "incedere",
    "incederai": "incedere",
    "incederan": "incedere",
    "incederanno": "incedere",
    "incederebbe": "incedere",
    "incederebber": "incedere",
    "incederebbero": "incedere",
    "incederei": "incedere",
    "incederemmo": "incedere",
    "incederemo": "incedere",
    "incedereste": "incedere",
    "incederesti": "incedere",
    "incederete": "incedere",
    "incederon": "incedere",
    "incederono": "incedere",
    "incederà": "incedere",
    "incederò": "incedere",
    "incedesse": "incedere",
    "incedesser": "incedere",
    "incedessero": "incedere",
    "incedessi": "incedere",
    "incedessimo": "incedere",
    "incedeste": "incedere",
    "incedesti": "incedere",
    "incedete": "incedere",
    "incedeva": "incedere",
    "incedevamo": "incedere",
    "incedevan": "incedere",
    "incedevano": "incedere",
    "incedevate": "incedere",
    "incedevi": "incedere",
    "incedevo": "incedere",
    "incedi": "incedere",
    "incediamo": "incedere",
    "incediate": "incedere",
    "incedibili": "incedibile",
    "incedo": "incedere",
    "incedon": "incedere",
    "incedono": "incedere",
    "inceduta": "incedere",
    "incedute": "incedere",
    "inceduti": "incedere",
    "inceduto": "incedere",
    "incedè": "incedere",
    "incendi": "incendio",
    "incendia": "incendiare",
    "incendiai": "incendiare",
    "incendiammo": "incendiare",
    "incendiamo": "incendiare",
    "incendian": "incendiare",
    "incendiando": "incendiare",
    "incendiano": "incendiare",
    "incendiante": "incendiare",
    "incendianti": "incendiare",
    "incendiar": "incendiare",
    "incendiari": "incendiario",
    "incendiaria": "incendiario",
    "incendiarie": "incendiario",
    "incendiaron": "incendiare",
    "incendiarono": "incendiare",
    "incendiasse": "incendiare",
    "incendiasser": "incendiare",
    "incendiassero": "incendiare",
    "incendiassi": "incendiare",
    "incendiassimo": "incendiare",
    "incendiaste": "incendiare",
    "incendiasti": "incendiare",
    "incendiata": "incendiare",
    "incendiate": "incendiare",
    "incendiati": "incendiare",
    "incendiato": "incendiare",
    "incendiava": "incendiare",
    "incendiavamo": "incendiare",
    "incendiavan": "incendiare",
    "incendiavano": "incendiare",
    "incendiavate": "incendiare",
    "incendiavi": "incendiare",
    "incendiavo": "incendiare",
    "incendierai": "incendiare",
    "incendieran": "incendiare",
    "incendieranno": "incendiare",
    "incendierebbe": "incendiare",
    "incendierebber": "incendiare",
    "incendierebbero": "incendiare",
    "incendierei": "incendiare",
    "incendieremmo": "incendiare",
    "incendieremo": "incendiare",
    "incendiereste": "incendiare",
    "incendieresti": "incendiare",
    "incendierete": "incendiare",
    "incendierà": "incendiare",
    "incendierò": "incendiare",
    "incendin": "incendiare",
    "incendino": "incendiare",
    "incendio": "incendiare",
    "incendiò": "incendiare",
    "incenerendo": "incenerire",
    "incenerente": "incenerire",
    "incenerenti": "incenerire",
    "inceneriamo": "incenerire",
    "inceneriate": "incenerire",
    "incenerii": "incenerire",
    "incenerimmo": "incenerire",
    "incenerir": "incenerire",
    "incenerirai": "incenerire",
    "inceneriran": "incenerire",
    "inceneriranno": "incenerire",
    "incenerirebbe": "incenerire",
    "incenerirebber": "incenerire",
    "incenerirebbero": "incenerire",
    "incenerirei": "incenerire",
    "inceneriremmo": "incenerire",
    "inceneriremo": "incenerire",
    "incenerireste": "incenerire",
    "inceneriresti": "incenerire",
    "incenerirete": "incenerire",
    "inceneriron": "incenerire",
    "incenerirono": "incenerire",
    "incenerirà": "incenerire",
    "incenerirò": "incenerire",
    "incenerisca": "incenerire",
    "inceneriscan": "incenerire",
    "inceneriscano": "incenerire",
    "incenerisce": "incenerire",
    "incenerisci": "incenerire",
    "incenerisco": "incenerire",
    "inceneriscon": "incenerire",
    "inceneriscono": "incenerire",
    "incenerisse": "incenerire",
    "incenerisser": "incenerire",
    "incenerissero": "incenerire",
    "incenerissi": "incenerire",
    "incenerissimo": "incenerire",
    "inceneriste": "incenerire",
    "inceneristi": "incenerire",
    "incenerita": "incenerire",
    "incenerite": "incenerire",
    "inceneriti": "incenerire",
    "incenerito": "incenerire",
    "inceneritori": "inceneritore",
    "inceneriva": "incenerire",
    "incenerivamo": "incenerire",
    "incenerivan": "incenerire",
    "incenerivano": "incenerire",
    "incenerivate": "incenerire",
    "incenerivi": "incenerire",
    "incenerivo": "incenerire",
    "incenerì": "incenerire",
    "incensa": "incensare",
    "incensai": "incensare",
    "incensammo": "incensare",
    "incensan": "incensare",
    "incensando": "incensare",
    "incensano": "incensare",
    "incensante": "incensare",
    "incensanti": "incensare",
    "incensar": "incensare",
    "incensaron": "incensare",
    "incensarono": "incensare",
    "incensasse": "incensare",
    "incensasser": "incensare",
    "incensassero": "incensare",
    "incensassi": "incensare",
    "incensassimo": "incensare",
    "incensaste": "incensare",
    "incensasti": "incensare",
    "incensata": "incensare",
    "incensate": "incensare",
    "incensati": "incensare",
    "incensato": "incensare",
    "incensava": "incensare",
    "incensavamo": "incensare",
    "incensavan": "incensare",
    "incensavano": "incensare",
    "incensavate": "incensare",
    "incensavi": "incensare",
    "incensavo": "incensare",
    "incenserai": "incensare",
    "incenseran": "incensare",
    "incenseranno": "incensare",
    "incenserebbe": "incensare",
    "incenserebber": "incensare",
    "incenserebbero": "incensare",
    "incenserei": "incensare",
    "incenseremmo": "incensare",
    "incenseremo": "incensare",
    "incensereste": "incensare",
    "incenseresti": "incensare",
    "incenserete": "incensare",
    "incenserà": "incensare",
    "incenserò": "incensare",
    "incensi": "incenso",
    "incensiamo": "incensare",
    "incensiate": "incensare",
    "incensin": "incensare",
    "incensino": "incensare",
    "incenso": "incensare",
    "incensurabili": "incensurabile",
    "incensurata": "incensurato",
    "incensurate": "incensurato",
    "incensurati": "incensurato",
    "incensò": "incensare",
    "incentiva": "incentivare",
    "incentivai": "incentivare",
    "incentivammo": "incentivare",
    "incentivan": "incentivare",
    "incentivando": "incentivare",
    "incentivano": "incentivare",
    "incentivante": "incentivare",
    "incentivanti": "incentivare",
    "incentivar": "incentivare",
    "incentivaron": "incentivare",
    "incentivarono": "incentivare",
    "incentivasse": "incentivare",
    "incentivasser": "incentivare",
    "incentivassero": "incentivare",
    "incentivassi": "incentivare",
    "incentivassimo": "incentivare",
    "incentivaste": "incentivare",
    "incentivasti": "incentivare",
    "incentivata": "incentivare",
    "incentivate": "incentivare",
    "incentivati": "incentivare",
    "incentivato": "incentivare",
    "incentivava": "incentivare",
    "incentivavamo": "incentivare",
    "incentivavan": "incentivare",
    "incentivavano": "incentivare",
    "incentivavate": "incentivare",
    "incentivavi": "incentivare",
    "incentivavo": "incentivare",
    "incentivazioni": "incentivazione",
    "incentiverai": "incentivare",
    "incentiveran": "incentivare",
    "incentiveranno": "incentivare",
    "incentiverebbe": "incentivare",
    "incentiverebber": "incentivare",
    "incentiverebbero": "incentivare",
    "incentiverei": "incentivare",
    "incentiveremmo": "incentivare",
    "incentiveremo": "incentivare",
    "incentivereste": "incentivare",
    "incentiveresti": "incentivare",
    "incentiverete": "incentivare",
    "incentiverà": "incentivare",
    "incentiverò": "incentivare",
    "incentivi": "incentivo",
    "incentiviamo": "incentivare",
    "incentiviate": "incentivare",
    "incentivin": "incentivare",
    "incentivino": "incentivare",
    "incentivo": "incentivare",
    "incentivò": "incentivare",
    "incentra": "incentrare",
    "incentrai": "incentrare",
    "incentrammo": "incentrare",
    "incentran": "incentrare",
    "incentrando": "incentrare",
    "incentrano": "incentrare",
    "incentrante": "incentrare",
    "incentranti": "incentrare",
    "incentrar": "incentrare",
    "incentraron": "incentrare",
    "incentrarono": "incentrare",
    "incentrasse": "incentrare",
    "incentrasser": "incentrare",
    "incentrassero": "incentrare",
    "incentrassi": "incentrare",
    "incentrassimo": "incentrare",
    "incentraste": "incentrare",
    "incentrasti": "incentrare",
    "incentrata": "incentrare",
    "incentrate": "incentrare",
    "incentrati": "incentrare",
    "incentrato": "incentrare",
    "incentrava": "incentrare",
    "incentravamo": "incentrare",
    "incentravan": "incentrare",
    "incentravano": "incentrare",
    "incentravate": "incentrare",
    "incentravi": "incentrare",
    "incentravo": "incentrare",
    "incentrerai": "incentrare",
    "incentreran": "incentrare",
    "incentreranno": "incentrare",
    "incentrerebbe": "incentrare",
    "incentrerebber": "incentrare",
    "incentrerebbero": "incentrare",
    "incentrerei": "incentrare",
    "incentreremmo": "incentrare",
    "incentreremo": "incentrare",
    "incentrereste": "incentrare",
    "incentreresti": "incentrare",
    "incentrerete": "incentrare",
    "incentrerà": "incentrare",
    "incentrerò": "incentrare",
    "incentri": "incentrare",
    "incentriamo": "incentrare",
    "incentriate": "incentrare",
    "incentrin": "incentrare",
    "incentrino": "incentrare",
    "incentro": "incentrare",
    "incentrò": "incentrare",
    "inceppa": "inceppare",
    "inceppai": "inceppare",
    "inceppammo": "inceppare",
    "inceppan": "inceppare",
    "inceppando": "inceppare",
    "inceppano": "inceppare",
    "inceppante": "inceppare",
    "inceppanti": "inceppare",
    "inceppar": "inceppare",
    "incepparon": "inceppare",
    "incepparono": "inceppare",
    "inceppasse": "inceppare",
    "inceppasser": "inceppare",
    "inceppassero": "inceppare",
    "inceppassi": "inceppare",
    "inceppassimo": "inceppare",
    "inceppaste": "inceppare",
    "inceppasti": "inceppare",
    "inceppata": "inceppare",
    "inceppate": "inceppare",
    "inceppati": "inceppare",
    "inceppato": "inceppare",
    "inceppava": "inceppare",
    "inceppavamo": "inceppare",
    "inceppavan": "inceppare",
    "inceppavano": "inceppare",
    "inceppavate": "inceppare",
    "inceppavi": "inceppare",
    "inceppavo": "inceppare",
    "incepperai": "inceppare",
    "incepperan": "inceppare",
    "incepperanno": "inceppare",
    "incepperebbe": "inceppare",
    "incepperebber": "inceppare",
    "incepperebbero": "inceppare",
    "incepperei": "inceppare",
    "incepperemmo": "inceppare",
    "incepperemo": "inceppare",
    "inceppereste": "inceppare",
    "incepperesti": "inceppare",
    "incepperete": "inceppare",
    "incepperà": "inceppare",
    "incepperò": "inceppare",
    "inceppi": "inceppare",
    "inceppiamo": "inceppare",
    "inceppiate": "inceppare",
    "inceppin": "inceppare",
    "inceppino": "inceppare",
    "inceppo": "inceppare",
    "inceppò": "inceppare",
    "incera": "incerare",
    "incerai": "incerare",
    "incerammo": "incerare",
    "inceran": "incerare",
    "incerando": "incerare",
    "incerano": "incerare",
    "incerante": "incerare",
    "inceranti": "incerare",
    "incerar": "incerare",
    "inceraron": "incerare",
    "incerarono": "incerare",
    "incerasse": "incerare",
    "incerasser": "incerare",
    "incerassero": "incerare",
    "incerassi": "incerare",
    "incerassimo": "incerare",
    "inceraste": "incerare",
    "incerasti": "incerare",
    "incerata": "incerare",
    "incerate": "incerare",
    "incerati": "incerare",
    "incerato": "incerare",
    "incerava": "incerare",
    "inceravamo": "incerare",
    "inceravan": "incerare",
    "inceravano": "incerare",
    "inceravate": "incerare",
    "inceravi": "incerare",
    "inceravo": "incerare",
    "incererai": "incerare",
    "incereran": "incerare",
    "incereranno": "incerare",
    "incererebbe": "incerare",
    "incererebber": "incerare",
    "incererebbero": "incerare",
    "incererei": "incerare",
    "incereremmo": "incerare",
    "incereremo": "incerare",
    "incerereste": "incerare",
    "incereresti": "incerare",
    "incererete": "incerare",
    "incererà": "incerare",
    "incererò": "incerare",
    "inceri": "incerare",
    "inceriamo": "incerare",
    "inceriate": "incerare",
    "incerin": "incerare",
    "incerino": "incerare",
    "incerniera": "incernierare",
    "incernierai": "incernierare",
    "incernierammo": "incernierare",
    "incernieran": "incernierare",
    "incernierando": "incernierare",
    "incernierano": "incernierare",
    "incernierante": "incernierare",
    "incernieranti": "incernierare",
    "incernierar": "incernierare",
    "incernieraron": "incernierare",
    "incernierarono": "incernierare",
    "incernierasse": "incernierare",
    "incernierasser": "incernierare",
    "incernierassero": "incernierare",
    "incernierassi": "incernierare",
    "incernierassimo": "incernierare",
    "incernieraste": "incernierare",
    "incernierasti": "incernierare",
    "incernierata": "incernierare",
    "incernierate": "incernierare",
    "incernierati": "incernierare",
    "incernierato": "incernierare",
    "incernierava": "incernierare",
    "incernieravamo": "incernierare",
    "incernieravan": "incernierare",
    "incernieravano": "incernierare",
    "incernieravate": "incernierare",
    "incernieravi": "incernierare",
    "incernieravo": "incernierare",
    "incerniererai": "incernierare",
    "incerniereran": "incernierare",
    "incerniereranno": "incernierare",
    "incerniererebbe": "incernierare",
    "incerniererebber": "incernierare",
    "incerniererebbero": "incernierare",
    "incerniererei": "incernierare",
    "incerniereremmo": "incernierare",
    "incerniereremo": "incernierare",
    "incernierereste": "incernierare",
    "incerniereresti": "incernierare",
    "incerniererete": "incernierare",
    "incerniererà": "incernierare",
    "incerniererò": "incernierare",
    "incernieri": "incernierare",
    "incernieriamo": "incernierare",
    "incernieriate": "incernierare",
    "incernierin": "incernierare",
    "incernierino": "incernierare",
    "incerniero": "incernierare",
    "incernierò": "incernierare",
    "incero": "incerare",
    "incerta": "incerto",
    "incerte": "incerto",
    "incertezze": "incertezza",
    "incerti": "incerto",
    "incerò": "incerare",
    "incespica": "incespicare",
    "incespicai": "incespicare",
    "incespicammo": "incespicare",
    "incespican": "incespicare",
    "incespicando": "incespicare",
    "incespicano": "incespicare",
    "incespicante": "incespicare",
    "incespicanti": "incespicare",
    "incespicar": "incespicare",
    "incespicaron": "incespicare",
    "incespicarono": "incespicare",
    "incespicasse": "incespicare",
    "incespicasser": "incespicare",
    "incespicassero": "incespicare",
    "incespicassi": "incespicare",
    "incespicassimo": "incespicare",
    "incespicaste": "incespicare",
    "incespicasti": "incespicare",
    "incespicata": "incespicare",
    "incespicate": "incespicare",
    "incespicati": "incespicare",
    "incespicato": "incespicare",
    "incespicava": "incespicare",
    "incespicavamo": "incespicare",
    "incespicavan": "incespicare",
    "incespicavano": "incespicare",
    "incespicavate": "incespicare",
    "incespicavi": "incespicare",
    "incespicavo": "incespicare",
    "incespicherai": "incespicare",
    "incespicheran": "incespicare",
    "incespicheranno": "incespicare",
    "incespicherebbe": "incespicare",
    "incespicherebber": "incespicare",
    "incespicherebbero": "incespicare",
    "incespicherei": "incespicare",
    "incespicheremmo": "incespicare",
    "incespicheremo": "incespicare",
    "incespichereste": "incespicare",
    "incespicheresti": "incespicare",
    "incespicherete": "incespicare",
    "incespicherà": "incespicare",
    "incespicherò": "incespicare",
    "incespichi": "incespicare",
    "incespichiamo": "incespicare",
    "incespichiate": "incespicare",
    "incespichin": "incespicare",
    "incespichino": "incespicare",
    "incespico": "incespicare",
    "incespicò": "incespicare",
    "incessanti": "incessante",
    "incesti": "incesto",
    "incestuosa": "incestuoso",
    "incestuose": "incestuoso",
    "incestuosi": "incestuoso",
    "incetta": "incettare",
    "incettai": "incettare",
    "incettammo": "incettare",
    "incettan": "incettare",
    "incettando": "incettare",
    "incettano": "incettare",
    "incettante": "incettare",
    "incettanti": "incettare",
    "incettar": "incettare",
    "incettaron": "incettare",
    "incettarono": "incettare",
    "incettasse": "incettare",
    "incettasser": "incettare",
    "incettassero": "incettare",
    "incettassi": "incettare",
    "incettassimo": "incettare",
    "incettaste": "incettare",
    "incettasti": "incettare",
    "incettata": "incettare",
    "incettate": "incettare",
    "incettati": "incettare",
    "incettato": "incettare",
    "incettava": "incettare",
    "incettavamo": "incettare",
    "incettavan": "incettare",
    "incettavano": "incettare",
    "incettavate": "incettare",
    "incettavi": "incettare",
    "incettavo": "incettare",
    "incetterai": "incettare",
    "incetteran": "incettare",
    "incetteranno": "incettare",
    "incetterebbe": "incettare",
    "incetterebber": "incettare",
    "incetterebbero": "incettare",
    "incetterei": "incettare",
    "incetteremmo": "incettare",
    "incetteremo": "incettare",
    "incettereste": "incettare",
    "incetteresti": "incettare",
    "incetterete": "incettare",
    "incetterà": "incettare",
    "incetterò": "incettare",
    "incetti": "incettare",
    "incettiamo": "incettare",
    "incettiate": "incettare",
    "incettin": "incettare",
    "incettino": "incettare",
    "incetto": "incettare",
    "incettò": "incettare",
    "inchieste": "inchiesta",
    "inchina": "inchinare",
    "inchinai": "inchinare",
    "inchinammo": "inchinare",
    "inchinan": "inchinare",
    "inchinando": "inchinare",
    "inchinano": "inchinare",
    "inchinante": "inchinare",
    "inchinanti": "inchinare",
    "inchinar": "inchinare",
    "inchinaron": "inchinare",
    "inchinarono": "inchinare",
    "inchinasse": "inchinare",
    "inchinasser": "inchinare",
    "inchinassero": "inchinare",
    "inchinassi": "inchinare",
    "inchinassimo": "inchinare",
    "inchinaste": "inchinare",
    "inchinasti": "inchinare",
    "inchinata": "inchinare",
    "inchinate": "inchinare",
    "inchinati": "inchinare",
    "inchinato": "inchinare",
    "inchinava": "inchinare",
    "inchinavamo": "inchinare",
    "inchinavan": "inchinare",
    "inchinavano": "inchinare",
    "inchinavate": "inchinare",
    "inchinavi": "inchinare",
    "inchinavo": "inchinare",
    "inchinerai": "inchinare",
    "inchineran": "inchinare",
    "inchineranno": "inchinare",
    "inchinerebbe": "inchinare",
    "inchinerebber": "inchinare",
    "inchinerebbero": "inchinare",
    "inchinerei": "inchinare",
    "inchineremmo": "inchinare",
    "inchineremo": "inchinare",
    "inchinereste": "inchinare",
    "inchineresti": "inchinare",
    "inchinerete": "inchinare",
    "inchinerà": "inchinare",
    "inchinerò": "inchinare",
    "inchini": "inchino",
    "inchiniamo": "inchinare",
    "inchiniate": "inchinare",
    "inchinin": "inchinare",
    "inchinino": "inchinare",
    "inchino": "inchinare",
    "inchinò": "inchinare",
    "inchioda": "inchiodare",
    "inchiodai": "inchiodare",
    "inchiodammo": "inchiodare",
    "inchiodan": "inchiodare",
    "inchiodando": "inchiodare",
    "inchiodano": "inchiodare",
    "inchiodante": "inchiodare",
    "inchiodanti": "inchiodare",
    "inchiodar": "inchiodare",
    "inchiodaron": "inchiodare",
    "inchiodarono": "inchiodare",
    "inchiodasse": "inchiodare",
    "inchiodasser": "inchiodare",
    "inchiodassero": "inchiodare",
    "inchiodassi": "inchiodare",
    "inchiodassimo": "inchiodare",
    "inchiodaste": "inchiodare",
    "inchiodasti": "inchiodare",
    "inchiodata": "inchiodare",
    "inchiodate": "inchiodare",
    "inchiodati": "inchiodare",
    "inchiodato": "inchiodare",
    "inchiodava": "inchiodare",
    "inchiodavamo": "inchiodare",
    "inchiodavan": "inchiodare",
    "inchiodavano": "inchiodare",
    "inchiodavate": "inchiodare",
    "inchiodavi": "inchiodare",
    "inchiodavo": "inchiodare",
    "inchioderai": "inchiodare",
    "inchioderan": "inchiodare",
    "inchioderanno": "inchiodare",
    "inchioderebbe": "inchiodare",
    "inchioderebber": "inchiodare",
    "inchioderebbero": "inchiodare",
    "inchioderei": "inchiodare",
    "inchioderemmo": "inchiodare",
    "inchioderemo": "inchiodare",
    "inchiodereste": "inchiodare",
    "inchioderesti": "inchiodare",
    "inchioderete": "inchiodare",
    "inchioderà": "inchiodare",
    "inchioderò": "inchiodare",
    "inchiodi": "inchiodare",
    "inchiodiamo": "inchiodare",
    "inchiodiate": "inchiodare",
    "inchiodin": "inchiodare",
    "inchiodino": "inchiodare",
    "inchiodo": "inchiodare",
    "inchiodò": "inchiodare",
    "inchiostra": "inchiostrare",
    "inchiostrai": "inchiostrare",
    "inchiostrammo": "inchiostrare",
    "inchiostran": "inchiostrare",
    "inchiostrando": "inchiostrare",
    "inchiostrano": "inchiostrare",
    "inchiostrante": "inchiostrare",
    "inchiostranti": "inchiostrare",
    "inchiostrar": "inchiostrare",
    "inchiostraron": "inchiostrare",
    "inchiostrarono": "inchiostrare",
    "inchiostrasse": "inchiostrare",
    "inchiostrasser": "inchiostrare",
    "inchiostrassero": "inchiostrare",
    "inchiostrassi": "inchiostrare",
    "inchiostrassimo": "inchiostrare",
    "inchiostraste": "inchiostrare",
    "inchiostrasti": "inchiostrare",
    "inchiostrata": "inchiostrare",
    "inchiostrate": "inchiostrare",
    "inchiostrati": "inchiostrare",
    "inchiostrato": "inchiostrare",
    "inchiostrava": "inchiostrare",
    "inchiostravamo": "inchiostrare",
    "inchiostravan": "inchiostrare",
    "inchiostravano": "inchiostrare",
    "inchiostravate": "inchiostrare",
    "inchiostravi": "inchiostrare",
    "inchiostravo": "inchiostrare",
    "inchiostrerai": "inchiostrare",
    "inchiostreran": "inchiostrare",
    "inchiostreranno": "inchiostrare",
    "inchiostrerebbe": "inchiostrare",
    "inchiostrerebber": "inchiostrare",
    "inchiostrerebbero": "inchiostrare",
    "inchiostrerei": "inchiostrare",
    "inchiostreremmo": "inchiostrare",
    "inchiostreremo": "inchiostrare",
    "inchiostrereste": "inchiostrare",
    "inchiostreresti": "inchiostrare",
    "inchiostrerete": "inchiostrare",
    "inchiostrerà": "inchiostrare",
    "inchiostrerò": "inchiostrare",
    "inchiostri": "inchiostro",
    "inchiostriamo": "inchiostrare",
    "inchiostriate": "inchiostrare",
    "inchiostrin": "inchiostrare",
    "inchiostrino": "inchiostrare",
    "inchiostro": "inchiostrare",
    "inchiostrò": "inchiostrare",
    "inciampa": "inciampare",
    "inciampai": "inciampare",
    "inciampammo": "inciampare",
    "inciampan": "inciampare",
    "inciampando": "inciampare",
    "inciampano": "inciampare",
    "inciampante": "inciampare",
    "inciampanti": "inciampare",
    "inciampar": "inciampare",
    "inciamparon": "inciampare",
    "inciamparono": "inciampare",
    "inciampasse": "inciampare",
    "inciampasser": "inciampare",
    "inciampassero": "inciampare",
    "inciampassi": "inciampare",
    "inciampassimo": "inciampare",
    "inciampaste": "inciampare",
    "inciampasti": "inciampare",
    "inciampata": "inciampare",
    "inciampate": "inciampare",
    "inciampati": "inciampare",
    "inciampato": "inciampare",
    "inciampava": "inciampare",
    "inciampavamo": "inciampare",
    "inciampavan": "inciampare",
    "inciampavano": "inciampare",
    "inciampavate": "inciampare",
    "inciampavi": "inciampare",
    "inciampavo": "inciampare",
    "inciamperai": "inciampare",
    "inciamperan": "inciampare",
    "inciamperanno": "inciampare",
    "inciamperebbe": "inciampare",
    "inciamperebber": "inciampare",
    "inciamperebbero": "inciampare",
    "inciamperei": "inciampare",
    "inciamperemmo": "inciampare",
    "inciamperemo": "inciampare",
    "inciampereste": "inciampare",
    "inciamperesti": "inciampare",
    "inciamperete": "inciampare",
    "inciamperà": "inciampare",
    "inciamperò": "inciampare",
    "inciampi": "inciampo",
    "inciampiamo": "inciampare",
    "inciampiate": "inciampare",
    "inciampin": "inciampare",
    "inciampino": "inciampare",
    "inciampo": "inciampare",
    "inciampò": "inciampare",
    "incida": "incidere",
    "incidan": "incidere",
    "incidano": "incidere",
    "incide": "incidere",
    "incidemmo": "incidere",
    "incidendo": "incidere",
    "incidentali": "incidentale",
    "incidente": "incidere",
    "incidenti": "incidere",
    "incidenze": "incidenza",
    "incider": "incidere",
    "inciderai": "incidere",
    "incideran": "incidere",
    "incideranno": "incidere",
    "inciderebbe": "incidere",
    "inciderebber": "incidere",
    "inciderebbero": "incidere",
    "inciderei": "incidere",
    "incideremmo": "incidere",
    "incideremo": "incidere",
    "incidereste": "incidere",
    "incideresti": "incidere",
    "inciderete": "incidere",
    "inciderà": "incidere",
    "inciderò": "incidere",
    "incidesse": "incidere",
    "incidesser": "incidere",
    "incidessero": "incidere",
    "incidessi": "incidere",
    "incidessimo": "incidere",
    "incideste": "incidere",
    "incidesti": "incidere",
    "incidete": "incidere",
    "incideva": "incidere",
    "incidevamo": "incidere",
    "incidevan": "incidere",
    "incidevano": "incidere",
    "incidevate": "incidere",
    "incidevi": "incidere",
    "incidevo": "incidere",
    "incidi": "incidere",
    "incidiamo": "incidere",
    "incidiate": "incidere",
    "incido": "incidere",
    "incidon": "incidere",
    "incidono": "incidere",
    "incinera": "incinerare",
    "incinerai": "incinerare",
    "incinerammo": "incinerare",
    "incineran": "incinerare",
    "incinerando": "incinerare",
    "incinerano": "incinerare",
    "incinerante": "incinerare",
    "incineranti": "incinerare",
    "incinerar": "incinerare",
    "incineraron": "incinerare",
    "incinerarono": "incinerare",
    "incinerasse": "incinerare",
    "incinerasser": "incinerare",
    "incinerassero": "incinerare",
    "incinerassi": "incinerare",
    "incinerassimo": "incinerare",
    "incineraste": "incinerare",
    "incinerasti": "incinerare",
    "incinerata": "incinerare",
    "incinerate": "incinerare",
    "incinerati": "incinerare",
    "incinerato": "incinerare",
    "incinerava": "incinerare",
    "incineravamo": "incinerare",
    "incineravan": "incinerare",
    "incineravano": "incinerare",
    "incineravate": "incinerare",
    "incineravi": "incinerare",
    "incineravo": "incinerare",
    "incinererai": "incinerare",
    "incinereran": "incinerare",
    "incinereranno": "incinerare",
    "incinererebbe": "incinerare",
    "incinererebber": "incinerare",
    "incinererebbero": "incinerare",
    "incinererei": "incinerare",
    "incinereremmo": "incinerare",
    "incinereremo": "incinerare",
    "incinerereste": "incinerare",
    "incinereresti": "incinerare",
    "incinererete": "incinerare",
    "incinererà": "incinerare",
    "incinererò": "incinerare",
    "incineri": "incinerare",
    "incineriamo": "incinerare",
    "incineriate": "incinerare",
    "incinerin": "incinerare",
    "incinerino": "incinerare",
    "incinero": "incinerare",
    "incinerò": "incinerare",
    "incinta": "incinto",
    "incinte": "incinto",
    "incinti": "incinto",
    "incipienti": "incipiente",
    "incipri": "incipriare",
    "incipria": "incipriare",
    "incipriai": "incipriare",
    "incipriammo": "incipriare",
    "incipriamo": "incipriare",
    "inciprian": "incipriare",
    "incipriando": "incipriare",
    "incipriano": "incipriare",
    "incipriante": "incipriare",
    "inciprianti": "incipriare",
    "incipriar": "incipriare",
    "incipriaron": "incipriare",
    "incipriarono": "incipriare",
    "incipriasse": "incipriare",
    "incipriasser": "incipriare",
    "incipriassero": "incipriare",
    "incipriassi": "incipriare",
    "incipriassimo": "incipriare",
    "incipriaste": "incipriare",
    "incipriasti": "incipriare",
    "incipriata": "incipriare",
    "incipriate": "incipriare",
    "incipriati": "incipriare",
    "incipriato": "incipriare",
    "incipriava": "incipriare",
    "incipriavamo": "incipriare",
    "incipriavan": "incipriare",
    "incipriavano": "incipriare",
    "incipriavate": "incipriare",
    "incipriavi": "incipriare",
    "incipriavo": "incipriare",
    "inciprierai": "incipriare",
    "inciprieran": "incipriare",
    "inciprieranno": "incipriare",
    "inciprierebbe": "incipriare",
    "inciprierebber": "incipriare",
    "inciprierebbero": "incipriare",
    "inciprierei": "incipriare",
    "inciprieremmo": "incipriare",
    "inciprieremo": "incipriare",
    "incipriereste": "incipriare",
    "inciprieresti": "incipriare",
    "inciprierete": "incipriare",
    "inciprierà": "incipriare",
    "inciprierò": "incipriare",
    "inciprin": "incipriare",
    "inciprino": "incipriare",
    "inciprio": "incipriare",
    "incipriò": "incipriare",
    "incisa": "incidere",
    "incise": "incidere",
    "inciser": "incidere",
    "incisero": "incidere",
    "incisi": "incidere",
    "incisioni": "incisione",
    "incisiva": "incisivo",
    "incisive": "incisivo",
    "incisivi": "incisivo",
    "inciso": "incidere",
    "incisori": "incisore",
    "incista": "incistare",
    "incistai": "incistare",
    "incistammo": "incistare",
    "incistan": "incistare",
    "incistando": "incistare",
    "incistano": "incistare",
    "incistante": "incistare",
    "incistanti": "incistare",
    "incistar": "incistare",
    "incistaron": "incistare",
    "incistarono": "incistare",
    "incistasse": "incistare",
    "incistasser": "incistare",
    "incistassero": "incistare",
    "incistassi": "incistare",
    "incistassimo": "incistare",
    "incistaste": "incistare",
    "incistasti": "incistare",
    "incistata": "incistare",
    "incistate": "incistare",
    "incistati": "incistare",
    "incistato": "incistare",
    "incistava": "incistare",
    "incistavamo": "incistare",
    "incistavan": "incistare",
    "incistavano": "incistare",
    "incistavate": "incistare",
    "incistavi": "incistare",
    "incistavo": "incistare",
    "incisterai": "incistare",
    "incisteran": "incistare",
    "incisteranno": "incistare",
    "incisterebbe": "incistare",
    "incisterebber": "incistare",
    "incisterebbero": "incistare",
    "incisterei": "incistare",
    "incisteremmo": "incistare",
    "incisteremo": "incistare",
    "incistereste": "incistare",
    "incisteresti": "incistare",
    "incisterete": "incistare",
    "incisterà": "incistare",
    "incisterò": "incistare",
    "incisti": "incistare",
    "incistiamo": "incistare",
    "incistiate": "incistare",
    "incistin": "incistare",
    "incistino": "incistare",
    "incisto": "incistare",
    "incistò": "incistare",
    "incita": "incitare",
    "incitai": "incitare",
    "incitamenti": "incitamento",
    "incitammo": "incitare",
    "incitan": "incitare",
    "incitando": "incitare",
    "incitano": "incitare",
    "incitante": "incitare",
    "incitanti": "incitare",
    "incitar": "incitare",
    "incitaron": "incitare",
    "incitarono": "incitare",
    "incitasse": "incitare",
    "incitasser": "incitare",
    "incitassero": "incitare",
    "incitassi": "incitare",
    "incitassimo": "incitare",
    "incitaste": "incitare",
    "incitasti": "incitare",
    "incitata": "incitare",
    "incitate": "incitare",
    "incitati": "incitare",
    "incitato": "incitare",
    "incitatori": "incitatore",
    "incitatrice": "incitatore",
    "incitatrici": "incitatore",
    "incitava": "incitare",
    "incitavamo": "incitare",
    "incitavan": "incitare",
    "incitavano": "incitare",
    "incitavate": "incitare",
    "incitavi": "incitare",
    "incitavo": "incitare",
    "inciterai": "incitare",
    "inciteran": "incitare",
    "inciteranno": "incitare",
    "inciterebbe": "incitare",
    "inciterebber": "incitare",
    "inciterebbero": "incitare",
    "inciterei": "incitare",
    "inciteremmo": "incitare",
    "inciteremo": "incitare",
    "incitereste": "incitare",
    "inciteresti": "incitare",
    "inciterete": "incitare",
    "inciterà": "incitare",
    "inciterò": "incitare",
    "inciti": "incitare",
    "incitiamo": "incitare",
    "incitiate": "incitare",
    "incitin": "incitare",
    "incitino": "incitare",
    "incito": "incitare",
    "incitò": "incitare",
    "inciuci": "inciucio",
    "incivila": "incivilire",
    "incivilan": "incivilire",
    "incivilano": "incivilire",
    "incivile": "incivilire",
    "incivilendo": "incivilire",
    "incivilente": "incivilire",
    "incivilenti": "incivilire",
    "incivili": "incivilire",
    "inciviliamo": "incivilire",
    "inciviliate": "incivilire",
    "incivilii": "incivilire",
    "incivilimmo": "incivilire",
    "incivilir": "incivilire",
    "incivilirai": "incivilire",
    "inciviliran": "incivilire",
    "inciviliranno": "incivilire",
    "incivilirebbe": "incivilire",
    "incivilirebber": "incivilire",
    "incivilirebbero": "incivilire",
    "incivilirei": "incivilire",
    "inciviliremmo": "incivilire",
    "inciviliremo": "incivilire",
    "incivilireste": "incivilire",
    "inciviliresti": "incivilire",
    "incivilirete": "incivilire",
    "inciviliron": "incivilire",
    "incivilirono": "incivilire",
    "incivilirà": "incivilire",
    "incivilirò": "incivilire",
    "incivilisse": "incivilire",
    "incivilisser": "incivilire",
    "incivilissero": "incivilire",
    "incivilissi": "incivilire",
    "incivilissimo": "incivilire",
    "inciviliste": "incivilire",
    "incivilisti": "incivilire",
    "incivilita": "incivilire",
    "incivilite": "incivilire",
    "inciviliti": "incivilire",
    "incivilito": "incivilire",
    "inciviliva": "incivilire",
    "incivilivamo": "incivilire",
    "incivilivan": "incivilire",
    "incivilivano": "incivilire",
    "incivilivate": "incivilire",
    "incivilivi": "incivilire",
    "incivilivo": "incivilire",
    "incivilo": "incivilire",
    "incivilon": "incivilire",
    "incivilono": "incivilire",
    "incivilì": "incivilire",
    "inclementi": "inclemente",
    "inclina": "inclinare",
    "inclinai": "inclinare",
    "inclinammo": "inclinare",
    "inclinan": "inclinare",
    "inclinando": "inclinare",
    "inclinano": "inclinare",
    "inclinante": "inclinare",
    "inclinanti": "inclinare",
    "inclinar": "inclinare",
    "inclinaron": "inclinare",
    "inclinarono": "inclinare",
    "inclinasse": "inclinare",
    "inclinasser": "inclinare",
    "inclinassero": "inclinare",
    "inclinassi": "inclinare",
    "inclinassimo": "inclinare",
    "inclinaste": "inclinare",
    "inclinasti": "inclinare",
    "inclinata": "inclinato",
    "inclinate": "inclinato",
    "inclinati": "inclinato",
    "inclinato": "inclinare",
    "inclinava": "inclinare",
    "inclinavamo": "inclinare",
    "inclinavan": "inclinare",
    "inclinavano": "inclinare",
    "inclinavate": "inclinare",
    "inclinavi": "inclinare",
    "inclinavo": "inclinare",
    "inclinazioni": "inclinazione",
    "inclinerai": "inclinare",
    "inclineran": "inclinare",
    "inclineranno": "inclinare",
    "inclinerebbe": "inclinare",
    "inclinerebber": "inclinare",
    "inclinerebbero": "inclinare",
    "inclinerei": "inclinare",
    "inclineremmo": "inclinare",
    "inclineremo": "inclinare",
    "inclinereste": "inclinare",
    "inclineresti": "inclinare",
    "inclinerete": "inclinare",
    "inclinerà": "inclinare",
    "inclinerò": "inclinare",
    "inclini": "incline",
    "incliniamo": "inclinare",
    "incliniate": "inclinare",
    "inclinin": "inclinare",
    "inclinino": "inclinare",
    "inclino": "inclinare",
    "inclinò": "inclinare",
    "inclita": "inclito",
    "inclite": "inclito",
    "incliti": "inclito",
    "includa": "includere",
    "includan": "includere",
    "includano": "includere",
    "include": "includere",
    "includemmo": "includere",
    "includendo": "includere",
    "includente": "includere",
    "includenti": "includere",
    "includer": "includere",
    "includerai": "includere",
    "includeran": "includere",
    "includeranno": "includere",
    "includerebbe": "includere",
    "includerebber": "includere",
    "includerebbero": "includere",
    "includerei": "includere",
    "includeremmo": "includere",
    "includeremo": "includere",
    "includereste": "includere",
    "includeresti": "includere",
    "includerete": "includere",
    "includerà": "includere",
    "includerò": "includere",
    "includesse": "includere",
    "includesser": "includere",
    "includessero": "includere",
    "includessi": "includere",
    "includessimo": "includere",
    "includeste": "includere",
    "includesti": "includere",
    "includete": "includere",
    "includeva": "includere",
    "includevamo": "includere",
    "includevan": "includere",
    "includevano": "includere",
    "includevate": "includere",
    "includevi": "includere",
    "includevo": "includere",
    "includi": "includere",
    "includiamo": "includere",
    "includiate": "includere",
    "includo": "includere",
    "includon": "includere",
    "includono": "includere",
    "inclusa": "incluso",
    "incluse": "incluso",
    "incluser": "includere",
    "inclusero": "includere",
    "inclusi": "incluso",
    "inclusioni": "inclusione",
    "inclusiva": "inclusivo",
    "inclusive": "inclusivo",
    "inclusivi": "inclusivo",
    "incluso": "includere",
    "incocca": "incoccare",
    "incoccai": "incoccare",
    "incoccammo": "incoccare",
    "incoccan": "incoccare",
    "incoccando": "incoccare",
    "incoccano": "incoccare",
    "incoccante": "incoccare",
    "incoccanti": "incoccare",
    "incoccar": "incoccare",
    "incoccaron": "incoccare",
    "incoccarono": "incoccare",
    "incoccasse": "incoccare",
    "incoccasser": "incoccare",
    "incoccassero": "incoccare",
    "incoccassi": "incoccare",
    "incoccassimo": "incoccare",
    "incoccaste": "incoccare",
    "incoccasti": "incoccare",
    "incoccata": "incoccare",
    "incoccate": "incoccare",
    "incoccati": "incoccare",
    "incoccato": "incoccare",
    "incoccava": "incoccare",
    "incoccavamo": "incoccare",
    "incoccavan": "incoccare",
    "incoccavano": "incoccare",
    "incoccavate": "incoccare",
    "incoccavi": "incoccare",
    "incoccavo": "incoccare",
    "incoccerai": "incocciare",
    "incocceran": "incocciare",
    "incocceranno": "incocciare",
    "incoccerebbe": "incocciare",
    "incoccerebber": "incocciare",
    "incoccerebbero": "incocciare",
    "incoccerei": "incocciare",
    "incocceremmo": "incocciare",
    "incocceremo": "incocciare",
    "incoccereste": "incocciare",
    "incocceresti": "incocciare",
    "incoccerete": "incocciare",
    "incoccerà": "incocciare",
    "incoccerò": "incocciare",
    "incoccherai": "incoccare",
    "incoccheran": "incoccare",
    "incoccheranno": "incoccare",
    "incoccherebbe": "incoccare",
    "incoccherebber": "incoccare",
    "incoccherebbero": "incoccare",
    "incoccherei": "incoccare",
    "incoccheremmo": "incoccare",
    "incoccheremo": "incoccare",
    "incocchereste": "incoccare",
    "incoccheresti": "incoccare",
    "incoccherete": "incoccare",
    "incoccherà": "incoccare",
    "incoccherò": "incoccare",
    "incocchi": "incoccare",
    "incocchiamo": "incoccare",
    "incocchiate": "incoccare",
    "incocchin": "incoccare",
    "incocchino": "incoccare",
    "incocci": "incocciare",
    "incoccia": "incocciare",
    "incocciai": "incocciare",
    "incocciammo": "incocciare",
    "incocciamo": "incocciare",
    "incoccian": "incocciare",
    "incocciando": "incocciare",
    "incocciano": "incocciare",
    "incocciante": "incocciare",
    "incoccianti": "incocciare",
    "incocciar": "incocciare",
    "incocciaron": "incocciare",
    "incocciarono": "incocciare",
    "incocciasse": "incocciare",
    "incocciasser": "incocciare",
    "incocciassero": "incocciare",
    "incocciassi": "incocciare",
    "incocciassimo": "incocciare",
    "incocciaste": "incocciare",
    "incocciasti": "incocciare",
    "incocciata": "incocciare",
    "incocciate": "incocciare",
    "incocciati": "incocciare",
    "incocciato": "incocciare",
    "incocciava": "incocciare",
    "incocciavamo": "incocciare",
    "incocciavan": "incocciare",
    "incocciavano": "incocciare",
    "incocciavate": "incocciare",
    "incocciavi": "incocciare",
    "incocciavo": "incocciare",
    "incoccin": "incocciare",
    "incoccino": "incocciare",
    "incoccio": "incocciare",
    "incocciò": "incocciare",
    "incocco": "incoccare",
    "incoccò": "incoccare",
    "incoercibili": "incoercibile",
    "incoerenti": "incoerente",
    "incoerenze": "incoerenza",
    "incogli": "incogliere",
    "incogliamo": "incogliere",
    "incogliate": "incogliere",
    "incoglie": "incogliere",
    "incogliemmo": "incogliere",
    "incogliendo": "incogliere",
    "incogliente": "incogliere",
    "incoglienti": "incogliere",
    "incoglier": "incogliere",
    "incoglierai": "incogliere",
    "incoglieran": "incogliere",
    "incoglieranno": "incogliere",
    "incoglierebbe": "incogliere",
    "incoglierebber": "incogliere",
    "incoglierebbero": "incogliere",
    "incoglierei": "incogliere",
    "incoglieremmo": "incogliere",
    "incoglieremo": "incogliere",
    "incogliereste": "incogliere",
    "incoglieresti": "incogliere",
    "incoglierete": "incogliere",
    "incoglierà": "incogliere",
    "incoglierò": "incogliere",
    "incogliesse": "incogliere",
    "incogliesser": "incogliere",
    "incogliessero": "incogliere",
    "incogliessi": "incogliere",
    "incogliessimo": "incogliere",
    "incoglieste": "incogliere",
    "incogliesti": "incogliere",
    "incogliete": "incogliere",
    "incoglieva": "incogliere",
    "incoglievamo": "incogliere",
    "incoglievan": "incogliere",
    "incoglievano": "incogliere",
    "incoglievate": "incogliere",
    "incoglievi": "incogliere",
    "incoglievo": "incogliere",
    "incognita": "incognito",
    "incognite": "incognito",
    "incogniti": "incognito",
    "incolga": "incogliere",
    "incolgan": "incogliere",
    "incolgano": "incogliere",
    "incolgo": "incogliere",
    "incolgon": "incogliere",
    "incolgono": "incogliere",
    "incolla": "incollare",
    "incollai": "incollare",
    "incollammo": "incollare",
    "incollan": "incollare",
    "incollando": "incollare",
    "incollano": "incollare",
    "incollante": "incollare",
    "incollanti": "incollare",
    "incollar": "incollare",
    "incollaron": "incollare",
    "incollarono": "incollare",
    "incollasse": "incollare",
    "incollasser": "incollare",
    "incollassero": "incollare",
    "incollassi": "incollare",
    "incollassimo": "incollare",
    "incollaste": "incollare",
    "incollasti": "incollare",
    "incollata": "incollare",
    "incollate": "incollare",
    "incollati": "incollare",
    "incollato": "incollare",
    "incollature": "incollatura",
    "incollava": "incollare",
    "incollavamo": "incollare",
    "incollavan": "incollare",
    "incollavano": "incollare",
    "incollavate": "incollare",
    "incollavi": "incollare",
    "incollavo": "incollare",
    "incollera": "incollerire",
    "incollerai": "incollare",
    "incolleran": "incollerire",
    "incolleranno": "incollare",
    "incollerano": "incollerire",
    "incollere": "incollerire",
    "incollerebbe": "incollare",
    "incollerebber": "incollare",
    "incollerebbero": "incollare",
    "incollerei": "incollare",
    "incolleremmo": "incollare",
    "incolleremo": "incollare",
    "incollerendo": "incollerire",
    "incollerente": "incollerire",
    "incollerenti": "incollerire",
    "incollereste": "incollare",
    "incolleresti": "incollare",
    "incollerete": "incollare",
    "incolleri": "incollerire",
    "incolleriamo": "incollerire",
    "incolleriate": "incollerire",
    "incollerii": "incollerire",
    "incollerimmo": "incollerire",
    "incollerir": "incollerire",
    "incollerirai": "incollerire",
    "incolleriran": "incollerire",
    "incolleriranno": "incollerire",
    "incollerirebbe": "incollerire",
    "incollerirebber": "incollerire",
    "incollerirebbero": "incollerire",
    "incollerirei": "incollerire",
    "incolleriremmo": "incollerire",
    "incolleriremo": "incollerire",
    "incollerireste": "incollerire",
    "incolleriresti": "incollerire",
    "incollerirete": "incollerire",
    "incolleriron": "incollerire",
    "incollerirono": "incollerire",
    "incollerirà": "incollerire",
    "incollerirò": "incollerire",
    "incollerisse": "incollerire",
    "incollerisser": "incollerire",
    "incollerissero": "incollerire",
    "incollerissi": "incollerire",
    "incollerissimo": "incollerire",
    "incolleriste": "incollerire",
    "incolleristi": "incollerire",
    "incollerita": "incollerire",
    "incollerite": "incollerire",
    "incolleriti": "incollerire",
    "incollerito": "incollerire",
    "incolleriva": "incollerire",
    "incollerivamo": "incollerire",
    "incollerivan": "incollerire",
    "incollerivano": "incollerire",
    "incollerivate": "incollerire",
    "incollerivi": "incollerire",
    "incollerivo": "incollerire",
    "incollero": "incollerire",
    "incolleron": "incollerire",
    "incollerono": "incollerire",
    "incollerà": "incollare",
    "incollerì": "incollerire",
    "incollerò": "incollare",
    "incolli": "incollare",
    "incolliamo": "incollare",
    "incolliate": "incollare",
    "incollin": "incollare",
    "incollino": "incollare",
    "incollo": "incollare",
    "incollò": "incollare",
    "incolmabili": "incolmabile",
    "incolonna": "incolonnare",
    "incolonnai": "incolonnare",
    "incolonnamenti": "incolonnamento",
    "incolonnammo": "incolonnare",
    "incolonnan": "incolonnare",
    "incolonnando": "incolonnare",
    "incolonnano": "incolonnare",
    "incolonnante": "incolonnare",
    "incolonnanti": "incolonnare",
    "incolonnar": "incolonnare",
    "incolonnaron": "incolonnare",
    "incolonnarono": "incolonnare",
    "incolonnasse": "incolonnare",
    "incolonnasser": "incolonnare",
    "incolonnassero": "incolonnare",
    "incolonnassi": "incolonnare",
    "incolonnassimo": "incolonnare",
    "incolonnaste": "incolonnare",
    "incolonnasti": "incolonnare",
    "incolonnata": "incolonnare",
    "incolonnate": "incolonnare",
    "incolonnati": "incolonnare",
    "incolonnato": "incolonnare",
    "incolonnava": "incolonnare",
    "incolonnavamo": "incolonnare",
    "incolonnavan": "incolonnare",
    "incolonnavano": "incolonnare",
    "incolonnavate": "incolonnare",
    "incolonnavi": "incolonnare",
    "incolonnavo": "incolonnare",
    "incolonnerai": "incolonnare",
    "incolonneran": "incolonnare",
    "incolonneranno": "incolonnare",
    "incolonnerebbe": "incolonnare",
    "incolonnerebber": "incolonnare",
    "incolonnerebbero": "incolonnare",
    "incolonnerei": "incolonnare",
    "incolonneremmo": "incolonnare",
    "incolonneremo": "incolonnare",
    "incolonnereste": "incolonnare",
    "incolonneresti": "incolonnare",
    "incolonnerete": "incolonnare",
    "incolonnerà": "incolonnare",
    "incolonnerò": "incolonnare",
    "incolonni": "incolonnare",
    "incolonniamo": "incolonnare",
    "incolonniate": "incolonnare",
    "incolonnin": "incolonnare",
    "incolonnino": "incolonnare",
    "incolonno": "incolonnare",
    "incolonnò": "incolonnare",
    "incolori": "incolore",
    "incolpa": "incolpare",
    "incolpai": "incolpare",
    "incolpammo": "incolpare",
    "incolpan": "incolpare",
    "incolpando": "incolpare",
    "incolpano": "incolpare",
    "incolpante": "incolpare",
    "incolpanti": "incolpare",
    "incolpar": "incolpare",
    "incolparon": "incolpare",
    "incolparono": "incolpare",
    "incolpasse": "incolpare",
    "incolpasser": "incolpare",
    "incolpassero": "incolpare",
    "incolpassi": "incolpare",
    "incolpassimo": "incolpare",
    "incolpaste": "incolpare",
    "incolpasti": "incolpare",
    "incolpata": "incolpare",
    "incolpate": "incolpare",
    "incolpati": "incolpare",
    "incolpato": "incolpare",
    "incolpava": "incolpare",
    "incolpavamo": "incolpare",
    "incolpavan": "incolpare",
    "incolpavano": "incolpare",
    "incolpavate": "incolpare",
    "incolpavi": "incolpare",
    "incolpavo": "incolpare",
    "incolpazioni": "incolpazione",
    "incolperai": "incolpare",
    "incolperan": "incolpare",
    "incolperanno": "incolpare",
    "incolperebbe": "incolpare",
    "incolperebber": "incolpare",
    "incolperebbero": "incolpare",
    "incolperei": "incolpare",
    "incolperemmo": "incolpare",
    "incolperemo": "incolpare",
    "incolpereste": "incolpare",
    "incolperesti": "incolpare",
    "incolperete": "incolpare",
    "incolperà": "incolpare",
    "incolperò": "incolpare",
    "incolpevoli": "incolpevole",
    "incolpi": "incolpare",
    "incolpiamo": "incolpare",
    "incolpiate": "incolpare",
    "incolpin": "incolpare",
    "incolpino": "incolpare",
    "incolpo": "incolpare",
    "incolpò": "incolpare",
    "incolse": "incogliere",
    "incolser": "incogliere",
    "incolsero": "incogliere",
    "incolsi": "incogliere",
    "incolta": "incolto",
    "incolte": "incolto",
    "incolti": "incolto",
    "incolto": "incogliere",
    "incolumi": "incolume",
    "incomba": "incombere",
    "incomban": "incombere",
    "incombano": "incombere",
    "incombe": "incombere",
    "incombei": "incombere",
    "incombemmo": "incombere",
    "incombendo": "incombere",
    "incombente": "incombere",
    "incombenti": "incombere",
    "incombenze": "incombenza",
    "incomber": "incombere",
    "incomberai": "incombere",
    "incomberan": "incombere",
    "incomberanno": "incombere",
    "incomberebbe": "incombere",
    "incomberebber": "incombere",
    "incomberebbero": "incombere",
    "incomberei": "incombere",
    "incomberemmo": "incombere",
    "incomberemo": "incombere",
    "incombereste": "incombere",
    "incomberesti": "incombere",
    "incomberete": "incombere",
    "incomberon": "incombere",
    "incomberono": "incombere",
    "incomberà": "incombere",
    "incomberò": "incombere",
    "incombesse": "incombere",
    "incombesser": "incombere",
    "incombessero": "incombere",
    "incombessi": "incombere",
    "incombessimo": "incombere",
    "incombeste": "incombere",
    "incombesti": "incombere",
    "incombete": "incombere",
    "incombeva": "incombere",
    "incombevamo": "incombere",
    "incombevan": "incombere",
    "incombevano": "incombere",
    "incombevate": "incombere",
    "incombevi": "incombere",
    "incombevo": "incombere",
    "incombi": "incombere",
    "incombiamo": "incombere",
    "incombiate": "incombere",
    "incombo": "incombere",
    "incombon": "incombere",
    "incombono": "incombere",
    "incombuta": "incombere",
    "incombute": "incombere",
    "incombuti": "incombere",
    "incombuto": "incombere",
    "incombè": "incombere",
    "incomincerai": "incominciare",
    "incominceran": "incominciare",
    "incominceranno": "incominciare",
    "incomincerebbe": "incominciare",
    "incomincerebber": "incominciare",
    "incomincerebbero": "incominciare",
    "incomincerei": "incominciare",
    "incominceremmo": "incominciare",
    "incominceremo": "incominciare",
    "incomincereste": "incominciare",
    "incominceresti": "incominciare",
    "incomincerete": "incominciare",
    "incomincerà": "incominciare",
    "incomincerò": "incominciare",
    "incominci": "incominciare",
    "incomincia": "incominciare",
    "incominciai": "incominciare",
    "incominciammo": "incominciare",
    "incominciamo": "incominciare",
    "incomincian": "incominciare",
    "incominciando": "incominciare",
    "incominciano": "incominciare",
    "incominciante": "incominciare",
    "incomincianti": "incominciare",
    "incominciar": "incominciare",
    "incominciaron": "incominciare",
    "incominciarono": "incominciare",
    "incominciasse": "incominciare",
    "incominciasser": "incominciare",
    "incominciassero": "incominciare",
    "incominciassi": "incominciare",
    "incominciassimo": "incominciare",
    "incominciaste": "incominciare",
    "incominciasti": "incominciare",
    "incominciata": "incominciare",
    "incominciate": "incominciare",
    "incominciati": "incominciare",
    "incominciato": "incominciare",
    "incominciava": "incominciare",
    "incominciavamo": "incominciare",
    "incominciavan": "incominciare",
    "incominciavano": "incominciare",
    "incominciavate": "incominciare",
    "incominciavi": "incominciare",
    "incominciavo": "incominciare",
    "incomincin": "incominciare",
    "incomincino": "incominciare",
    "incomincio": "incominciare",
    "incominciò": "incominciare",
    "incommensurabili": "incommensurabile",
    "incomoda": "incomodo",
    "incomodai": "incomodare",
    "incomodammo": "incomodare",
    "incomodan": "incomodare",
    "incomodando": "incomodare",
    "incomodano": "incomodare",
    "incomodante": "incomodare",
    "incomodanti": "incomodare",
    "incomodar": "incomodare",
    "incomodaron": "incomodare",
    "incomodarono": "incomodare",
    "incomodasse": "incomodare",
    "incomodasser": "incomodare",
    "incomodassero": "incomodare",
    "incomodassi": "incomodare",
    "incomodassimo": "incomodare",
    "incomodaste": "incomodare",
    "incomodasti": "incomodare",
    "incomodata": "incomodare",
    "incomodate": "incomodare",
    "incomodati": "incomodare",
    "incomodato": "incomodare",
    "incomodava": "incomodare",
    "incomodavamo": "incomodare",
    "incomodavan": "incomodare",
    "incomodavano": "incomodare",
    "incomodavate": "incomodare",
    "incomodavi": "incomodare",
    "incomodavo": "incomodare",
    "incomode": "incomodo",
    "incomoderai": "incomodare",
    "incomoderan": "incomodare",
    "incomoderanno": "incomodare",
    "incomoderebbe": "incomodare",
    "incomoderebber": "incomodare",
    "incomoderebbero": "incomodare",
    "incomoderei": "incomodare",
    "incomoderemmo": "incomodare",
    "incomoderemo": "incomodare",
    "incomodereste": "incomodare",
    "incomoderesti": "incomodare",
    "incomoderete": "incomodare",
    "incomoderà": "incomodare",
    "incomoderò": "incomodare",
    "incomodi": "incomodo",
    "incomodiamo": "incomodare",
    "incomodiate": "incomodare",
    "incomodin": "incomodare",
    "incomodino": "incomodare",
    "incomodo": "incomodare",
    "incomodò": "incomodare",
    "incomparabili": "incomparabile",
    "incompatibili": "incompatibile",
    "incompetenti": "incompetente",
    "incompetenze": "incompetenza",
    "incompiuta": "incompiuto",
    "incompiute": "incompiuto",
    "incompiuti": "incompiuto",
    "incompleta": "incompleto",
    "incomplete": "incompleto",
    "incompletezze": "incompletezza",
    "incompleti": "incompleto",
    "incomprensibili": "incomprensibile",
    "incomprensioni": "incomprensione",
    "incompresa": "incompreso",
    "incomprese": "incompreso",
    "incompresi": "incompreso",
    "incomunicabili": "incomunicabile",
    "inconcepibili": "inconcepibile",
    "inconciliabili": "inconciliabile",
    "inconcludenti": "inconcludente",
    "incondizionata": "incondizionato",
    "incondizionate": "incondizionato",
    "incondizionati": "incondizionato",
    "inconfessabili": "inconfessabile",
    "inconfessata": "inconfessato",
    "inconfessate": "inconfessato",
    "inconfessati": "inconfessato",
    "inconfondibili": "inconfondibile",
    "inconfutabili": "inconfutabile",
    "incongrua": "incongruo",
    "incongrue": "incongruo",
    "incongruenti": "incongruente",
    "incongruenze": "incongruenza",
    "incongrui": "incongruo",
    "inconoscibili": "inconoscibile",
    "inconsapevolezze": "inconsapevolezza",
    "inconsapevoli": "inconsapevole",
    "inconsce": "inconscio",
    "inconsci": "inconscio",
    "inconscia": "inconscio",
    "inconsistenti": "inconsistente",
    "inconsistenze": "inconsistenza",
    "inconsolabili": "inconsolabile",
    "inconsueta": "inconsueto",
    "inconsuete": "inconsueto",
    "inconsueti": "inconsueto",
    "inconsulta": "inconsulto",
    "inconsulte": "inconsulto",
    "inconsulti": "inconsulto",
    "incontaminata": "incontaminato",
    "incontaminate": "incontaminato",
    "incontaminati": "incontaminato",
    "incontenibili": "incontenibile",
    "incontentabili": "incontentabile",
    "incontestabili": "incontestabile",
    "incontinenti": "incontinente",
    "incontinenze": "incontinenza",
    "incontra": "incontrare",
    "incontrai": "incontrare",
    "incontrammo": "incontrare",
    "incontran": "incontrare",
    "incontrando": "incontrare",
    "incontrano": "incontrare",
    "incontrante": "incontrare",
    "incontranti": "incontrare",
    "incontrar": "incontrare",
    "incontraron": "incontrare",
    "incontrarono": "incontrare",
    "incontrasse": "incontrare",
    "incontrasser": "incontrare",
    "incontrassero": "incontrare",
    "incontrassi": "incontrare",
    "incontrassimo": "incontrare",
    "incontrastabili": "incontrastabile",
    "incontrastata": "incontrastato",
    "incontrastate": "incontrastato",
    "incontrastati": "incontrastato",
    "incontraste": "incontrare",
    "incontrasti": "incontrare",
    "incontrata": "incontrare",
    "incontrate": "incontrare",
    "incontrati": "incontrare",
    "incontrato": "incontrare",
    "incontrava": "incontrare",
    "incontravamo": "incontrare",
    "incontravan": "incontrare",
    "incontravano": "incontrare",
    "incontravate": "incontrare",
    "incontravi": "incontrare",
    "incontravo": "incontrare",
    "incontrerai": "incontrare",
    "incontreran": "incontrare",
    "incontreranno": "incontrare",
    "incontrerebbe": "incontrare",
    "incontrerebber": "incontrare",
    "incontrerebbero": "incontrare",
    "incontrerei": "incontrare",
    "incontreremmo": "incontrare",
    "incontreremo": "incontrare",
    "incontrereste": "incontrare",
    "incontreresti": "incontrare",
    "incontrerete": "incontrare",
    "incontrerà": "incontrare",
    "incontrerò": "incontrare",
    "incontri": "incontro",
    "incontriamo": "incontrare",
    "incontriate": "incontrare",
    "incontrin": "incontrare",
    "incontrino": "incontrare",
    "incontristi": "incontrista",
    "incontro": "incontrare",
    "incontrollabili": "incontrollabile",
    "incontrollata": "incontrollato",
    "incontrollate": "incontrollato",
    "incontrollati": "incontrollato",
    "incontrovertibili": "incontrovertibile",
    "incontrò": "incontrare",
    "inconvenienti": "inconveniente",
    "incoraggerai": "incoraggiare",
    "incoraggeran": "incoraggiare",
    "incoraggeranno": "incoraggiare",
    "incoraggerebbe": "incoraggiare",
    "incoraggerebber": "incoraggiare",
    "incoraggerebbero": "incoraggiare",
    "incoraggerei": "incoraggiare",
    "incoraggeremmo": "incoraggiare",
    "incoraggeremo": "incoraggiare",
    "incoraggereste": "incoraggiare",
    "incoraggeresti": "incoraggiare",
    "incoraggerete": "incoraggiare",
    "incoraggerà": "incoraggiare",
    "incoraggerò": "incoraggiare",
    "incoraggi": "incoraggiare",
    "incoraggia": "incoraggiare",
    "incoraggiai": "incoraggiare",
    "incoraggiamenti": "incoraggiamento",
    "incoraggiammo": "incoraggiare",
    "incoraggiamo": "incoraggiare",
    "incoraggian": "incoraggiare",
    "incoraggiando": "incoraggiare",
    "incoraggiano": "incoraggiare",
    "incoraggiante": "incoraggiare",
    "incoraggianti": "incoraggiare",
    "incoraggiar": "incoraggiare",
    "incoraggiaron": "incoraggiare",
    "incoraggiarono": "incoraggiare",
    "incoraggiasse": "incoraggiare",
    "incoraggiasser": "incoraggiare",
    "incoraggiassero": "incoraggiare",
    "incoraggiassi": "incoraggiare",
    "incoraggiassimo": "incoraggiare",
    "incoraggiaste": "incoraggiare",
    "incoraggiasti": "incoraggiare",
    "incoraggiata": "incoraggiare",
    "incoraggiate": "incoraggiare",
    "incoraggiati": "incoraggiare",
    "incoraggiato": "incoraggiare",
    "incoraggiava": "incoraggiare",
    "incoraggiavamo": "incoraggiare",
    "incoraggiavan": "incoraggiare",
    "incoraggiavano": "incoraggiare",
    "incoraggiavate": "incoraggiare",
    "incoraggiavi": "incoraggiare",
    "incoraggiavo": "incoraggiare",
    "incoraggin": "incoraggiare",
    "incoraggino": "incoraggiare",
    "incoraggio": "incoraggiare",
    "incoraggiò": "incoraggiare",
    "incorda": "incordare",
    "incordai": "incordare",
    "incordammo": "incordare",
    "incordan": "incordare",
    "incordando": "incordare",
    "incordano": "incordare",
    "incordante": "incordare",
    "incordanti": "incordare",
    "incordar": "incordare",
    "incordaron": "incordare",
    "incordarono": "incordare",
    "incordasse": "incordare",
    "incordasser": "incordare",
    "incordassero": "incordare",
    "incordassi": "incordare",
    "incordassimo": "incordare",
    "incordaste": "incordare",
    "incordasti": "incordare",
    "incordata": "incordare",
    "incordate": "incordare",
    "incordati": "incordare",
    "incordato": "incordare",
    "incordava": "incordare",
    "incordavamo": "incordare",
    "incordavan": "incordare",
    "incordavano": "incordare",
    "incordavate": "incordare",
    "incordavi": "incordare",
    "incordavo": "incordare",
    "incorderai": "incordare",
    "incorderan": "incordare",
    "incorderanno": "incordare",
    "incorderebbe": "incordare",
    "incorderebber": "incordare",
    "incorderebbero": "incordare",
    "incorderei": "incordare",
    "incorderemmo": "incordare",
    "incorderemo": "incordare",
    "incordereste": "incordare",
    "incorderesti": "incordare",
    "incorderete": "incordare",
    "incorderà": "incordare",
    "incorderò": "incordare",
    "incordi": "incordare",
    "incordiamo": "incordare",
    "incordiate": "incordare",
    "incordin": "incordare",
    "incordino": "incordare",
    "incordo": "incordare",
    "incordò": "incordare",
    "incorna": "incornare",
    "incornai": "incornare",
    "incornammo": "incornare",
    "incornan": "incornare",
    "incornando": "incornare",
    "incornano": "incornare",
    "incornante": "incornare",
    "incornanti": "incornare",
    "incornar": "incornare",
    "incornaron": "incornare",
    "incornarono": "incornare",
    "incornasse": "incornare",
    "incornasser": "incornare",
    "incornassero": "incornare",
    "incornassi": "incornare",
    "incornassimo": "incornare",
    "incornaste": "incornare",
    "incornasti": "incornare",
    "incornata": "incornare",
    "incornate": "incornata",
    "incornati": "incornare",
    "incornato": "incornare",
    "incornava": "incornare",
    "incornavamo": "incornare",
    "incornavan": "incornare",
    "incornavano": "incornare",
    "incornavate": "incornare",
    "incornavi": "incornare",
    "incornavo": "incornare",
    "incornerai": "incornare",
    "incorneran": "incornare",
    "incorneranno": "incornare",
    "incornerebbe": "incornare",
    "incornerebber": "incornare",
    "incornerebbero": "incornare",
    "incornerei": "incornare",
    "incorneremmo": "incornare",
    "incorneremo": "incornare",
    "incornereste": "incornare",
    "incorneresti": "incornare",
    "incornerete": "incornare",
    "incornerà": "incornare",
    "incornerò": "incornare",
    "incorni": "incornare",
    "incorniamo": "incornare",
    "incorniate": "incornare",
    "incornicerai": "incorniciare",
    "incorniceran": "incorniciare",
    "incorniceranno": "incorniciare",
    "incornicerebbe": "incorniciare",
    "incornicerebber": "incorniciare",
    "incornicerebbero": "incorniciare",
    "incornicerei": "incorniciare",
    "incorniceremmo": "incorniciare",
    "incorniceremo": "incorniciare",
    "incornicereste": "incorniciare",
    "incorniceresti": "incorniciare",
    "incornicerete": "incorniciare",
    "incornicerà": "incorniciare",
    "incornicerò": "incorniciare",
    "incornici": "incorniciare",
    "incornicia": "incorniciare",
    "incorniciai": "incorniciare",
    "incorniciammo": "incorniciare",
    "incorniciamo": "incorniciare",
    "incornician": "incorniciare",
    "incorniciando": "incorniciare",
    "incorniciano": "incorniciare",
    "incorniciante": "incorniciare",
    "incornicianti": "incorniciare",
    "incorniciar": "incorniciare",
    "incorniciaron": "incorniciare",
    "incorniciarono": "incorniciare",
    "incorniciasse": "incorniciare",
    "incorniciasser": "incorniciare",
    "incorniciassero": "incorniciare",
    "incorniciassi": "incorniciare",
    "incorniciassimo": "incorniciare",
    "incorniciaste": "incorniciare",
    "incorniciasti": "incorniciare",
    "incorniciata": "incorniciare",
    "incorniciate": "incorniciare",
    "incorniciati": "incorniciare",
    "incorniciato": "incorniciare",
    "incorniciava": "incorniciare",
    "incorniciavamo": "incorniciare",
    "incorniciavan": "incorniciare",
    "incorniciavano": "incorniciare",
    "incorniciavate": "incorniciare",
    "incorniciavi": "incorniciare",
    "incorniciavo": "incorniciare",
    "incornicin": "incorniciare",
    "incornicino": "incorniciare",
    "incornicio": "incorniciare",
    "incorniciò": "incorniciare",
    "incornin": "incornare",
    "incornino": "incornare",
    "incorno": "incornare",
    "incornò": "incornare",
    "incorona": "incoronare",
    "incoronai": "incoronare",
    "incoronammo": "incoronare",
    "incoronan": "incoronare",
    "incoronando": "incoronare",
    "incoronano": "incoronare",
    "incoronante": "incoronare",
    "incoronanti": "incoronare",
    "incoronar": "incoronare",
    "incoronaron": "incoronare",
    "incoronarono": "incoronare",
    "incoronasse": "incoronare",
    "incoronasser": "incoronare",
    "incoronassero": "incoronare",
    "incoronassi": "incoronare",
    "incoronassimo": "incoronare",
    "incoronaste": "incoronare",
    "incoronasti": "incoronare",
    "incoronata": "incoronare",
    "incoronate": "incoronare",
    "incoronati": "incoronare",
    "incoronato": "incoronare",
    "incoronava": "incoronare",
    "incoronavamo": "incoronare",
    "incoronavan": "incoronare",
    "incoronavano": "incoronare",
    "incoronavate": "incoronare",
    "incoronavi": "incoronare",
    "incoronavo": "incoronare",
    "incoronazioni": "incoronazione",
    "incoronerai": "incoronare",
    "incoroneran": "incoronare",
    "incoroneranno": "incoronare",
    "incoronerebbe": "incoronare",
    "incoronerebber": "incoronare",
    "incoronerebbero": "incoronare",
    "incoronerei": "incoronare",
    "incoroneremmo": "incoronare",
    "incoroneremo": "incoronare",
    "incoronereste": "incoronare",
    "incoroneresti": "incoronare",
    "incoronerete": "incoronare",
    "incoronerà": "incoronare",
    "incoronerò": "incoronare",
    "incoroni": "incoronare",
    "incoroniamo": "incoronare",
    "incoroniate": "incoronare",
    "incoronin": "incoronare",
    "incoronino": "incoronare",
    "incorono": "incoronare",
    "incoronò": "incoronare",
    "incorpora": "incorporare",
    "incorporai": "incorporare",
    "incorporammo": "incorporare",
    "incorporan": "incorporare",
    "incorporando": "incorporare",
    "incorporano": "incorporare",
    "incorporante": "incorporare",
    "incorporanti": "incorporare",
    "incorporar": "incorporare",
    "incorporaron": "incorporare",
    "incorporarono": "incorporare",
    "incorporasse": "incorporare",
    "incorporasser": "incorporare",
    "incorporassero": "incorporare",
    "incorporassi": "incorporare",
    "incorporassimo": "incorporare",
    "incorporaste": "incorporare",
    "incorporasti": "incorporare",
    "incorporata": "incorporare",
    "incorporate": "incorporare",
    "incorporati": "incorporare",
    "incorporato": "incorporare",
    "incorporava": "incorporare",
    "incorporavamo": "incorporare",
    "incorporavan": "incorporare",
    "incorporavano": "incorporare",
    "incorporavate": "incorporare",
    "incorporavi": "incorporare",
    "incorporavo": "incorporare",
    "incorporazioni": "incorporazione",
    "incorporea": "incorporeo",
    "incorporee": "incorporeo",
    "incorporei": "incorporeo",
    "incorporerai": "incorporare",
    "incorporeran": "incorporare",
    "incorporeranno": "incorporare",
    "incorporerebbe": "incorporare",
    "incorporerebber": "incorporare",
    "incorporerebbero": "incorporare",
    "incorporerei": "incorporare",
    "incorporeremmo": "incorporare",
    "incorporeremo": "incorporare",
    "incorporereste": "incorporare",
    "incorporeresti": "incorporare",
    "incorporerete": "incorporare",
    "incorporerà": "incorporare",
    "incorporerò": "incorporare",
    "incorpori": "incorporare",
    "incorporiamo": "incorporare",
    "incorporiate": "incorporare",
    "incorporin": "incorporare",
    "incorporino": "incorporare",
    "incorporo": "incorporare",
    "incorporò": "incorporare",
    "incorra": "incorrere",
    "incorran": "incorrere",
    "incorrano": "incorrere",
    "incorre": "incorrere",
    "incorreggibili": "incorreggibile",
    "incorremmo": "incorrere",
    "incorrendo": "incorrere",
    "incorrente": "incorrere",
    "incorrenti": "incorrere",
    "incorrer": "incorrere",
    "incorrerai": "incorrere",
    "incorreran": "incorrere",
    "incorreranno": "incorrere",
    "incorrerebbe": "incorrere",
    "incorrerebber": "incorrere",
    "incorrerebbero": "incorrere",
    "incorrerei": "incorrere",
    "incorreremmo": "incorrere",
    "incorreremo": "incorrere",
    "incorrereste": "incorrere",
    "incorreresti": "incorrere",
    "incorrerete": "incorrere",
    "incorrerà": "incorrere",
    "incorrerò": "incorrere",
    "incorresse": "incorrere",
    "incorresser": "incorrere",
    "incorressero": "incorrere",
    "incorressi": "incorrere",
    "incorressimo": "incorrere",
    "incorreste": "incorrere",
    "incorresti": "incorrere",
    "incorrete": "incorrere",
    "incorreva": "incorrere",
    "incorrevamo": "incorrere",
    "incorrevan": "incorrere",
    "incorrevano": "incorrere",
    "incorrevate": "incorrere",
    "incorrevi": "incorrere",
    "incorrevo": "incorrere",
    "incorri": "incorrere",
    "incorriamo": "incorrere",
    "incorriate": "incorrere",
    "incorro": "incorrere",
    "incorron": "incorrere",
    "incorrono": "incorrere",
    "incorruttibili": "incorruttibile",
    "incorsa": "incorrere",
    "incorse": "incorrere",
    "incorser": "incorrere",
    "incorsero": "incorrere",
    "incorsi": "incorrere",
    "incorso": "incorrere",
    "incoscienti": "incosciente",
    "incoscienze": "incoscienza",
    "incostanti": "incostante",
    "incostanze": "incostanza",
    "incostituzionali": "incostituzionale",
    "incredibili": "incredibile",
    "incredula": "incredulo",
    "incredule": "incredulo",
    "increduli": "incredulo",
    "incrementa": "incrementare",
    "incrementai": "incrementare",
    "incrementammo": "incrementare",
    "incrementan": "incrementare",
    "incrementando": "incrementare",
    "incrementano": "incrementare",
    "incrementante": "incrementare",
    "incrementanti": "incrementare",
    "incrementar": "incrementare",
    "incrementaron": "incrementare",
    "incrementarono": "incrementare",
    "incrementasse": "incrementare",
    "incrementasser": "incrementare",
    "incrementassero": "incrementare",
    "incrementassi": "incrementare",
    "incrementassimo": "incrementare",
    "incrementaste": "incrementare",
    "incrementasti": "incrementare",
    "incrementata": "incrementare",
    "incrementate": "incrementare",
    "incrementati": "incrementare",
    "incrementato": "incrementare",
    "incrementava": "incrementare",
    "incrementavamo": "incrementare",
    "incrementavan": "incrementare",
    "incrementavano": "incrementare",
    "incrementavate": "incrementare",
    "incrementavi": "incrementare",
    "incrementavo": "incrementare",
    "incrementerai": "incrementare",
    "incrementeran": "incrementare",
    "incrementeranno": "incrementare",
    "incrementerebbe": "incrementare",
    "incrementerebber": "incrementare",
    "incrementerebbero": "incrementare",
    "incrementerei": "incrementare",
    "incrementeremmo": "incrementare",
    "incrementeremo": "incrementare",
    "incrementereste": "incrementare",
    "incrementeresti": "incrementare",
    "incrementerete": "incrementare",
    "incrementerà": "incrementare",
    "incrementerò": "incrementare",
    "incrementi": "incremento",
    "incrementiamo": "incrementare",
    "incrementiate": "incrementare",
    "incrementin": "incrementare",
    "incrementino": "incrementare",
    "incremento": "incrementare",
    "incrementò": "incrementare",
    "incresca": "increscere",
    "increscan": "increscere",
    "increscano": "increscere",
    "incresce": "increscere",
    "increscei": "increscere",
    "increscemmo": "increscere",
    "increscendo": "increscere",
    "increscente": "increscere",
    "increscenti": "increscere",
    "increscer": "increscere",
    "increscerai": "increscere",
    "incresceran": "increscere",
    "incresceranno": "increscere",
    "increscerebbe": "increscere",
    "increscerebber": "increscere",
    "increscerebbero": "increscere",
    "increscerei": "increscere",
    "incresceremmo": "increscere",
    "incresceremo": "increscere",
    "increscereste": "increscere",
    "incresceresti": "increscere",
    "increscerete": "increscere",
    "incresceron": "increscere",
    "increscerono": "increscere",
    "increscerà": "increscere",
    "increscerò": "increscere",
    "increscesse": "increscere",
    "increscesser": "increscere",
    "increscessero": "increscere",
    "increscessi": "increscere",
    "increscessimo": "increscere",
    "incresceste": "increscere",
    "increscesti": "increscere",
    "increscete": "increscere",
    "incresceva": "increscere",
    "increscevamo": "increscere",
    "increscevan": "increscere",
    "increscevano": "increscere",
    "increscevate": "increscere",
    "increscevi": "increscere",
    "increscevo": "increscere",
    "incresci": "increscere",
    "incresciamo": "increscere",
    "incresciate": "increscere",
    "incresciosa": "increscioso",
    "incresciose": "increscioso",
    "incresciosi": "increscioso",
    "incresciuta": "increscere",
    "incresciute": "increscere",
    "incresciuti": "increscere",
    "incresciuto": "increscere",
    "incresco": "increscere",
    "increscon": "increscere",
    "increscono": "increscere",
    "increscè": "increscere",
    "increspa": "increspare",
    "increspai": "increspare",
    "increspammo": "increspare",
    "increspan": "increspare",
    "increspando": "increspare",
    "increspano": "increspare",
    "increspante": "increspare",
    "increspanti": "increspare",
    "increspar": "increspare",
    "incresparon": "increspare",
    "incresparono": "increspare",
    "increspasse": "increspare",
    "increspasser": "increspare",
    "increspassero": "increspare",
    "increspassi": "increspare",
    "increspassimo": "increspare",
    "increspaste": "increspare",
    "increspasti": "increspare",
    "increspata": "increspare",
    "increspate": "increspare",
    "increspati": "increspare",
    "increspato": "increspare",
    "increspature": "increspatura",
    "increspava": "increspare",
    "increspavamo": "increspare",
    "increspavan": "increspare",
    "increspavano": "increspare",
    "increspavate": "increspare",
    "increspavi": "increspare",
    "increspavo": "increspare",
    "incresperai": "increspare",
    "incresperan": "increspare",
    "incresperanno": "increspare",
    "incresperebbe": "increspare",
    "incresperebber": "increspare",
    "incresperebbero": "increspare",
    "incresperei": "increspare",
    "incresperemmo": "increspare",
    "incresperemo": "increspare",
    "increspereste": "increspare",
    "incresperesti": "increspare",
    "incresperete": "increspare",
    "incresperà": "increspare",
    "incresperò": "increspare",
    "increspi": "increspare",
    "increspiamo": "increspare",
    "increspiate": "increspare",
    "increspin": "increspare",
    "increspino": "increspare",
    "increspo": "increspare",
    "increspò": "increspare",
    "incretina": "incretinire",
    "incretinan": "incretinire",
    "incretinano": "incretinire",
    "incretine": "incretinire",
    "incretinendo": "incretinire",
    "incretinente": "incretinire",
    "incretinenti": "incretinire",
    "incretini": "incretinire",
    "incretiniamo": "incretinire",
    "incretiniate": "incretinire",
    "incretinii": "incretinire",
    "incretinimmo": "incretinire",
    "incretinir": "incretinire",
    "incretinirai": "incretinire",
    "incretiniran": "incretinire",
    "incretiniranno": "incretinire",
    "incretinirebbe": "incretinire",
    "incretinirebber": "incretinire",
    "incretinirebbero": "incretinire",
    "incretinirei": "incretinire",
    "incretiniremmo": "incretinire",
    "incretiniremo": "incretinire",
    "incretinireste": "incretinire",
    "incretiniresti": "incretinire",
    "incretinirete": "incretinire",
    "incretiniron": "incretinire",
    "incretinirono": "incretinire",
    "incretinirà": "incretinire",
    "incretinirò": "incretinire",
    "incretinisse": "incretinire",
    "incretinisser": "incretinire",
    "incretinissero": "incretinire",
    "incretinissi": "incretinire",
    "incretinissimo": "incretinire",
    "incretiniste": "incretinire",
    "incretinisti": "incretinire",
    "incretinita": "incretinire",
    "incretinite": "incretinire",
    "incretiniti": "incretinire",
    "incretinito": "incretinire",
    "incretiniva": "incretinire",
    "incretinivamo": "incretinire",
    "incretinivan": "incretinire",
    "incretinivano": "incretinire",
    "incretinivate": "incretinire",
    "incretinivi": "incretinire",
    "incretinivo": "incretinire",
    "incretino": "incretinire",
    "incretinon": "incretinire",
    "incretinono": "incretinire",
    "incretinì": "incretinire",
    "incrimina": "incriminare",
    "incriminabili": "incriminabile",
    "incriminai": "incriminare",
    "incriminammo": "incriminare",
    "incriminan": "incriminare",
    "incriminando": "incriminare",
    "incriminano": "incriminare",
    "incriminante": "incriminare",
    "incriminanti": "incriminare",
    "incriminar": "incriminare",
    "incriminaron": "incriminare",
    "incriminarono": "incriminare",
    "incriminasse": "incriminare",
    "incriminasser": "incriminare",
    "incriminassero": "incriminare",
    "incriminassi": "incriminare",
    "incriminassimo": "incriminare",
    "incriminaste": "incriminare",
    "incriminasti": "incriminare",
    "incriminata": "incriminato",
    "incriminate": "incriminato",
    "incriminati": "incriminato",
    "incriminato": "incriminare",
    "incriminava": "incriminare",
    "incriminavamo": "incriminare",
    "incriminavan": "incriminare",
    "incriminavano": "incriminare",
    "incriminavate": "incriminare",
    "incriminavi": "incriminare",
    "incriminavo": "incriminare",
    "incriminazioni": "incriminazione",
    "incriminerai": "incriminare",
    "incrimineran": "incriminare",
    "incrimineranno": "incriminare",
    "incriminerebbe": "incriminare",
    "incriminerebber": "incriminare",
    "incriminerebbero": "incriminare",
    "incriminerei": "incriminare",
    "incrimineremmo": "incriminare",
    "incrimineremo": "incriminare",
    "incriminereste": "incriminare",
    "incrimineresti": "incriminare",
    "incriminerete": "incriminare",
    "incriminerà": "incriminare",
    "incriminerò": "incriminare",
    "incrimini": "incriminare",
    "incriminiamo": "incriminare",
    "incriminiate": "incriminare",
    "incriminin": "incriminare",
    "incriminino": "incriminare",
    "incrimino": "incriminare",
    "incriminò": "incriminare",
    "incrina": "incrinare",
    "incrinai": "incrinare",
    "incrinammo": "incrinare",
    "incrinan": "incrinare",
    "incrinando": "incrinare",
    "incrinano": "incrinare",
    "incrinante": "incrinare",
    "incrinanti": "incrinare",
    "incrinar": "incrinare",
    "incrinaron": "incrinare",
    "incrinarono": "incrinare",
    "incrinasse": "incrinare",
    "incrinasser": "incrinare",
    "incrinassero": "incrinare",
    "incrinassi": "incrinare",
    "incrinassimo": "incrinare",
    "incrinaste": "incrinare",
    "incrinasti": "incrinare",
    "incrinata": "incrinare",
    "incrinate": "incrinare",
    "incrinati": "incrinare",
    "incrinato": "incrinare",
    "incrinature": "incrinatura",
    "incrinava": "incrinare",
    "incrinavamo": "incrinare",
    "incrinavan": "incrinare",
    "incrinavano": "incrinare",
    "incrinavate": "incrinare",
    "incrinavi": "incrinare",
    "incrinavo": "incrinare",
    "incrinerai": "incrinare",
    "incrineran": "incrinare",
    "incrineranno": "incrinare",
    "incrinerebbe": "incrinare",
    "incrinerebber": "incrinare",
    "incrinerebbero": "incrinare",
    "incrinerei": "incrinare",
    "incrineremmo": "incrinare",
    "incrineremo": "incrinare",
    "incrinereste": "incrinare",
    "incrineresti": "incrinare",
    "incrinerete": "incrinare",
    "incrinerà": "incrinare",
    "incrinerò": "incrinare",
    "incrini": "incrinare",
    "incriniamo": "incrinare",
    "incriniate": "incrinare",
    "incrinin": "incrinare",
    "incrinino": "incrinare",
    "incrino": "incrinare",
    "incrinò": "incrinare",
    "incrocerai": "incrociare",
    "incroceran": "incrociare",
    "incroceranno": "incrociare",
    "incrocerebbe": "incrociare",
    "incrocerebber": "incrociare",
    "incrocerebbero": "incrociare",
    "incrocerei": "incrociare",
    "incroceremmo": "incrociare",
    "incroceremo": "incrociare",
    "incrocereste": "incrociare",
    "incroceresti": "incrociare",
    "incrocerete": "incrociare",
    "incrocerà": "incrociare",
    "incrocerò": "incrociare",
    "incroci": "incrocio",
    "incrocia": "incrociare",
    "incrociai": "incrociare",
    "incrociammo": "incrociare",
    "incrociamo": "incrociare",
    "incrocian": "incrociare",
    "incrociando": "incrociare",
    "incrociano": "incrociare",
    "incrociante": "incrociare",
    "incrocianti": "incrociare",
    "incrociar": "incrociare",
    "incrociaron": "incrociare",
    "incrociarono": "incrociare",
    "incrociasse": "incrociare",
    "incrociasser": "incrociare",
    "incrociassero": "incrociare",
    "incrociassi": "incrociare",
    "incrociassimo": "incrociare",
    "incrociaste": "incrociare",
    "incrociasti": "incrociare",
    "incrociata": "incrociare",
    "incrociate": "incrociare",
    "incrociati": "incrociare",
    "incrociato": "incrociare",
    "incrociatori": "incrociatore",
    "incrociava": "incrociare",
    "incrociavamo": "incrociare",
    "incrociavan": "incrociare",
    "incrociavano": "incrociare",
    "incrociavate": "incrociare",
    "incrociavi": "incrociare",
    "incrociavo": "incrociare",
    "incrocin": "incrociare",
    "incrocino": "incrociare",
    "incrocio": "incrociare",
    "incrociò": "incrociare",
    "incroda": "incrodare",
    "incrodai": "incrodare",
    "incrodammo": "incrodare",
    "incrodan": "incrodare",
    "incrodando": "incrodare",
    "incrodano": "incrodare",
    "incrodar": "incrodare",
    "incrodaron": "incrodare",
    "incrodarono": "incrodare",
    "incrodasse": "incrodare",
    "incrodasser": "incrodare",
    "incrodassero": "incrodare",
    "incrodassi": "incrodare",
    "incrodassimo": "incrodare",
    "incrodaste": "incrodare",
    "incrodasti": "incrodare",
    "incrodata": "incrodare",
    "incrodate": "incrodare",
    "incrodati": "incrodare",
    "incrodato": "incrodare",
    "incrodava": "incrodare",
    "incrodavamo": "incrodare",
    "incrodavan": "incrodare",
    "incrodavano": "incrodare",
    "incrodavate": "incrodare",
    "incrodavi": "incrodare",
    "incrodavo": "incrodare",
    "incroderai": "incrodare",
    "incroderan": "incrodare",
    "incroderanno": "incrodare",
    "incroderebbe": "incrodare",
    "incroderebber": "incrodare",
    "incroderebbero": "incrodare",
    "incroderei": "incrodare",
    "incroderemmo": "incrodare",
    "incroderemo": "incrodare",
    "incrodereste": "incrodare",
    "incroderesti": "incrodare",
    "incroderete": "incrodare",
    "incroderà": "incrodare",
    "incroderò": "incrodare",
    "incrodi": "incrodare",
    "incrodiamo": "incrodare",
    "incrodiate": "incrodare",
    "incrodin": "incrodare",
    "incrodino": "incrodare",
    "incrodo": "incrodare",
    "incrodò": "incrodare",
    "incrollabili": "incrollabile",
    "incrosta": "incrostare",
    "incrostai": "incrostare",
    "incrostammo": "incrostare",
    "incrostan": "incrostare",
    "incrostando": "incrostare",
    "incrostano": "incrostare",
    "incrostante": "incrostare",
    "incrostanti": "incrostare",
    "incrostar": "incrostare",
    "incrostaron": "incrostare",
    "incrostarono": "incrostare",
    "incrostasse": "incrostare",
    "incrostasser": "incrostare",
    "incrostassero": "incrostare",
    "incrostassi": "incrostare",
    "incrostassimo": "incrostare",
    "incrostaste": "incrostare",
    "incrostasti": "incrostare",
    "incrostata": "incrostare",
    "incrostate": "incrostare",
    "incrostati": "incrostare",
    "incrostato": "incrostare",
    "incrostava": "incrostare",
    "incrostavamo": "incrostare",
    "incrostavan": "incrostare",
    "incrostavano": "incrostare",
    "incrostavate": "incrostare",
    "incrostavi": "incrostare",
    "incrostavo": "incrostare",
    "incrostazioni": "incrostazione",
    "incrosterai": "incrostare",
    "incrosteran": "incrostare",
    "incrosteranno": "incrostare",
    "incrosterebbe": "incrostare",
    "incrosterebber": "incrostare",
    "incrosterebbero": "incrostare",
    "incrosterei": "incrostare",
    "incrosteremmo": "incrostare",
    "incrosteremo": "incrostare",
    "incrostereste": "incrostare",
    "incrosteresti": "incrostare",
    "incrosterete": "incrostare",
    "incrosterà": "incrostare",
    "incrosterò": "incrostare",
    "incrosti": "incrostare",
    "incrostiamo": "incrostare",
    "incrostiate": "incrostare",
    "incrostin": "incrostare",
    "incrostino": "incrostare",
    "incrosto": "incrostare",
    "incrostò": "incrostare",
    "incruda": "incrudire",
    "incrudan": "incrudire",
    "incrudano": "incrudire",
    "incrude": "incrudire",
    "incrudela": "incrudelire",
    "incrudelan": "incrudelire",
    "incrudelano": "incrudelire",
    "incrudele": "incrudelire",
    "incrudelendo": "incrudelire",
    "incrudelente": "incrudelire",
    "incrudelenti": "incrudelire",
    "incrudeli": "incrudelire",
    "incrudeliamo": "incrudelire",
    "incrudeliate": "incrudelire",
    "incrudelii": "incrudelire",
    "incrudelimmo": "incrudelire",
    "incrudelir": "incrudelire",
    "incrudelirai": "incrudelire",
    "incrudeliran": "incrudelire",
    "incrudeliranno": "incrudelire",
    "incrudelirebbe": "incrudelire",
    "incrudelirebber": "incrudelire",
    "incrudelirebbero": "incrudelire",
    "incrudelirei": "incrudelire",
    "incrudeliremmo": "incrudelire",
    "incrudeliremo": "incrudelire",
    "incrudelireste": "incrudelire",
    "incrudeliresti": "incrudelire",
    "incrudelirete": "incrudelire",
    "incrudeliron": "incrudelire",
    "incrudelirono": "incrudelire",
    "incrudelirà": "incrudelire",
    "incrudelirò": "incrudelire",
    "incrudelisse": "incrudelire",
    "incrudelisser": "incrudelire",
    "incrudelissero": "incrudelire",
    "incrudelissi": "incrudelire",
    "incrudelissimo": "incrudelire",
    "incrudeliste": "incrudelire",
    "incrudelisti": "incrudelire",
    "incrudelita": "incrudelire",
    "incrudelite": "incrudelire",
    "incrudeliti": "incrudelire",
    "incrudelito": "incrudelire",
    "incrudeliva": "incrudelire",
    "incrudelivamo": "incrudelire",
    "incrudelivan": "incrudelire",
    "incrudelivano": "incrudelire",
    "incrudelivate": "incrudelire",
    "incrudelivi": "incrudelire",
    "incrudelivo": "incrudelire",
    "incrudelo": "incrudelire",
    "incrudelon": "incrudelire",
    "incrudelono": "incrudelire",
    "incrudelì": "incrudelire",
    "incrudendo": "incrudire",
    "incrudente": "incrudire",
    "incrudenti": "incrudire",
    "incrudi": "incrudire",
    "incrudiamo": "incrudire",
    "incrudiate": "incrudire",
    "incrudii": "incrudire",
    "incrudimmo": "incrudire",
    "incrudir": "incrudire",
    "incrudirai": "incrudire",
    "incrudiran": "incrudire",
    "incrudiranno": "incrudire",
    "incrudirebbe": "incrudire",
    "incrudirebber": "incrudire",
    "incrudirebbero": "incrudire",
    "incrudirei": "incrudire",
    "incrudiremmo": "incrudire",
    "incrudiremo": "incrudire",
    "incrudireste": "incrudire",
    "incrudiresti": "incrudire",
    "incrudirete": "incrudire",
    "incrudiron": "incrudire",
    "incrudirono": "incrudire",
    "incrudirà": "incrudire",
    "incrudirò": "incrudire",
    "incrudisse": "incrudire",
    "incrudisser": "incrudire",
    "incrudissero": "incrudire",
    "incrudissi": "incrudire",
    "incrudissimo": "incrudire",
    "incrudiste": "incrudire",
    "incrudisti": "incrudire",
    "incrudita": "incrudire",
    "incrudite": "incrudire",
    "incruditi": "incrudire",
    "incrudito": "incrudire",
    "incrudiva": "incrudire",
    "incrudivamo": "incrudire",
    "incrudivan": "incrudire",
    "incrudivano": "incrudire",
    "incrudivate": "incrudire",
    "incrudivi": "incrudire",
    "incrudivo": "incrudire",
    "incrudo": "incrudire",
    "incrudon": "incrudire",
    "incrudono": "incrudire",
    "incrudì": "incrudire",
    "incruenta": "incruento",
    "incruente": "incruento",
    "incruenti": "incruento",
    "incuba": "incubare",
    "incubai": "incubare",
    "incubammo": "incubare",
    "incuban": "incubare",
    "incubando": "incubare",
    "incubano": "incubare",
    "incubante": "incubare",
    "incubanti": "incubare",
    "incubar": "incubare",
    "incubaron": "incubare",
    "incubarono": "incubare",
    "incubasse": "incubare",
    "incubasser": "incubare",
    "incubassero": "incubare",
    "incubassi": "incubare",
    "incubassimo": "incubare",
    "incubaste": "incubare",
    "incubasti": "incubare",
    "incubata": "incubare",
    "incubate": "incubare",
    "incubati": "incubare",
    "incubato": "incubare",
    "incubatori": "incubatore",
    "incubatrici": "incubatrice",
    "incubava": "incubare",
    "incubavamo": "incubare",
    "incubavan": "incubare",
    "incubavano": "incubare",
    "incubavate": "incubare",
    "incubavi": "incubare",
    "incubavo": "incubare",
    "incubazioni": "incubazione",
    "incuberai": "incubare",
    "incuberan": "incubare",
    "incuberanno": "incubare",
    "incuberebbe": "incubare",
    "incuberebber": "incubare",
    "incuberebbero": "incubare",
    "incuberei": "incubare",
    "incuberemmo": "incubare",
    "incuberemo": "incubare",
    "incubereste": "incubare",
    "incuberesti": "incubare",
    "incuberete": "incubare",
    "incuberà": "incubare",
    "incuberò": "incubare",
    "incubi": "incubo",
    "incubiamo": "incubare",
    "incubiate": "incubare",
    "incubin": "incubare",
    "incubino": "incubare",
    "incubo": "incubare",
    "incubò": "incubare",
    "inculca": "inculcare",
    "inculcai": "inculcare",
    "inculcammo": "inculcare",
    "inculcan": "inculcare",
    "inculcando": "inculcare",
    "inculcano": "inculcare",
    "inculcante": "inculcare",
    "inculcanti": "inculcare",
    "inculcar": "inculcare",
    "inculcaron": "inculcare",
    "inculcarono": "inculcare",
    "inculcasse": "inculcare",
    "inculcasser": "inculcare",
    "inculcassero": "inculcare",
    "inculcassi": "inculcare",
    "inculcassimo": "inculcare",
    "inculcaste": "inculcare",
    "inculcasti": "inculcare",
    "inculcata": "inculcare",
    "inculcate": "inculcare",
    "inculcati": "inculcare",
    "inculcato": "inculcare",
    "inculcava": "inculcare",
    "inculcavamo": "inculcare",
    "inculcavan": "inculcare",
    "inculcavano": "inculcare",
    "inculcavate": "inculcare",
    "inculcavi": "inculcare",
    "inculcavo": "inculcare",
    "inculcherai": "inculcare",
    "inculcheran": "inculcare",
    "inculcheranno": "inculcare",
    "inculcherebbe": "inculcare",
    "inculcherebber": "inculcare",
    "inculcherebbero": "inculcare",
    "inculcherei": "inculcare",
    "inculcheremmo": "inculcare",
    "inculcheremo": "inculcare",
    "inculchereste": "inculcare",
    "inculcheresti": "inculcare",
    "inculcherete": "inculcare",
    "inculcherà": "inculcare",
    "inculcherò": "inculcare",
    "inculchi": "inculcare",
    "inculchiamo": "inculcare",
    "inculchiate": "inculcare",
    "inculchin": "inculcare",
    "inculchino": "inculcare",
    "inculco": "inculcare",
    "inculcò": "inculcare",
    "inculture": "incultura",
    "incunaboli": "incunabolo",
    "incunea": "incuneare",
    "incuneai": "incuneare",
    "incuneammo": "incuneare",
    "incunean": "incuneare",
    "incuneando": "incuneare",
    "incuneano": "incuneare",
    "incuneante": "incuneare",
    "incuneanti": "incuneare",
    "incunear": "incuneare",
    "incunearon": "incuneare",
    "incunearono": "incuneare",
    "incuneasse": "incuneare",
    "incuneasser": "incuneare",
    "incuneassero": "incuneare",
    "incuneassi": "incuneare",
    "incuneassimo": "incuneare",
    "incuneaste": "incuneare",
    "incuneasti": "incuneare",
    "incuneata": "incuneare",
    "incuneate": "incuneare",
    "incuneati": "incuneare",
    "incuneato": "incuneare",
    "incuneava": "incuneare",
    "incuneavamo": "incuneare",
    "incuneavan": "incuneare",
    "incuneavano": "incuneare",
    "incuneavate": "incuneare",
    "incuneavi": "incuneare",
    "incuneavo": "incuneare",
    "incuneerai": "incuneare",
    "incuneeran": "incuneare",
    "incuneeranno": "incuneare",
    "incuneerebbe": "incuneare",
    "incuneerebber": "incuneare",
    "incuneerebbero": "incuneare",
    "incuneerei": "incuneare",
    "incuneeremmo": "incuneare",
    "incuneeremo": "incuneare",
    "incuneereste": "incuneare",
    "incuneeresti": "incuneare",
    "incuneerete": "incuneare",
    "incuneerà": "incuneare",
    "incuneerò": "incuneare",
    "incunei": "incuneare",
    "incuneiamo": "incuneare",
    "incuneiate": "incuneare",
    "incunein": "incuneare",
    "incuneino": "incuneare",
    "incuneo": "incuneare",
    "incuneò": "incuneare",
    "incupendo": "incupire",
    "incupente": "incupire",
    "incupenti": "incupire",
    "incupiamo": "incupire",
    "incupiate": "incupire",
    "incupii": "incupire",
    "incupimmo": "incupire",
    "incupir": "incupire",
    "incupirai": "incupire",
    "incupiran": "incupire",
    "incupiranno": "incupire",
    "incupirebbe": "incupire",
    "incupirebber": "incupire",
    "incupirebbero": "incupire",
    "incupirei": "incupire",
    "incupiremmo": "incupire",
    "incupiremo": "incupire",
    "incupireste": "incupire",
    "incupiresti": "incupire",
    "incupirete": "incupire",
    "incupiron": "incupire",
    "incupirono": "incupire",
    "incupirà": "incupire",
    "incupirò": "incupire",
    "incupisca": "incupire",
    "incupiscan": "incupire",
    "incupiscano": "incupire",
    "incupisce": "incupire",
    "incupisci": "incupire",
    "incupisco": "incupire",
    "incupiscon": "incupire",
    "incupiscono": "incupire",
    "incupisse": "incupire",
    "incupisser": "incupire",
    "incupissero": "incupire",
    "incupissi": "incupire",
    "incupissimo": "incupire",
    "incupiste": "incupire",
    "incupisti": "incupire",
    "incupita": "incupire",
    "incupite": "incupire",
    "incupiti": "incupire",
    "incupito": "incupire",
    "incupiva": "incupire",
    "incupivamo": "incupire",
    "incupivan": "incupire",
    "incupivano": "incupire",
    "incupivate": "incupire",
    "incupivi": "incupire",
    "incupivo": "incupire",
    "incupì": "incupire",
    "incurabili": "incurabile",
    "incuranti": "incurante",
    "incurie": "incuria",
    "incuriosendo": "incuriosire",
    "incuriosente": "incuriosire",
    "incuriosenti": "incuriosire",
    "incuriosiamo": "incuriosire",
    "incuriosiate": "incuriosire",
    "incuriosii": "incuriosire",
    "incuriosimmo": "incuriosire",
    "incuriosir": "incuriosire",
    "incuriosirai": "incuriosire",
    "incuriosiran": "incuriosire",
    "incuriosiranno": "incuriosire",
    "incuriosirebbe": "incuriosire",
    "incuriosirebber": "incuriosire",
    "incuriosirebbero": "incuriosire",
    "incuriosirei": "incuriosire",
    "incuriosiremmo": "incuriosire",
    "incuriosiremo": "incuriosire",
    "incuriosireste": "incuriosire",
    "incuriosiresti": "incuriosire",
    "incuriosirete": "incuriosire",
    "incuriosiron": "incuriosire",
    "incuriosirono": "incuriosire",
    "incuriosirà": "incuriosire",
    "incuriosirò": "incuriosire",
    "incuriosisca": "incuriosire",
    "incuriosiscan": "incuriosire",
    "incuriosiscano": "incuriosire",
    "incuriosisce": "incuriosire",
    "incuriosisci": "incuriosire",
    "incuriosisco": "incuriosire",
    "incuriosiscon": "incuriosire",
    "incuriosiscono": "incuriosire",
    "incuriosisse": "incuriosire",
    "incuriosisser": "incuriosire",
    "incuriosissero": "incuriosire",
    "incuriosissi": "incuriosire",
    "incuriosissimo": "incuriosire",
    "incuriosiste": "incuriosire",
    "incuriosisti": "incuriosire",
    "incuriosita": "incuriosire",
    "incuriosite": "incuriosire",
    "incuriositi": "incuriosire",
    "incuriosito": "incuriosire",
    "incuriosiva": "incuriosire",
    "incuriosivamo": "incuriosire",
    "incuriosivan": "incuriosire",
    "incuriosivano": "incuriosire",
    "incuriosivate": "incuriosire",
    "incuriosivi": "incuriosire",
    "incuriosivo": "incuriosire",
    "incuriosì": "incuriosire",
    "incursioni": "incursione",
    "incursori": "incursore",
    "incurva": "incurvare",
    "incurvai": "incurvare",
    "incurvammo": "incurvare",
    "incurvan": "incurvare",
    "incurvando": "incurvare",
    "incurvano": "incurvare",
    "incurvante": "incurvare",
    "incurvanti": "incurvare",
    "incurvar": "incurvare",
    "incurvaron": "incurvare",
    "incurvarono": "incurvare",
    "incurvasse": "incurvare",
    "incurvasser": "incurvare",
    "incurvassero": "incurvare",
    "incurvassi": "incurvare",
    "incurvassimo": "incurvare",
    "incurvaste": "incurvare",
    "incurvasti": "incurvare",
    "incurvata": "incurvare",
    "incurvate": "incurvare",
    "incurvati": "incurvare",
    "incurvato": "incurvare",
    "incurvava": "incurvare",
    "incurvavamo": "incurvare",
    "incurvavan": "incurvare",
    "incurvavano": "incurvare",
    "incurvavate": "incurvare",
    "incurvavi": "incurvare",
    "incurvavo": "incurvare",
    "incurverai": "incurvare",
    "incurveran": "incurvare",
    "incurveranno": "incurvare",
    "incurverebbe": "incurvare",
    "incurverebber": "incurvare",
    "incurverebbero": "incurvare",
    "incurverei": "incurvare",
    "incurveremmo": "incurvare",
    "incurveremo": "incurvare",
    "incurvereste": "incurvare",
    "incurveresti": "incurvare",
    "incurverete": "incurvare",
    "incurverà": "incurvare",
    "incurverò": "incurvare",
    "incurvi": "incurvare",
    "incurviamo": "incurvare",
    "incurviate": "incurvare",
    "incurvin": "incurvare",
    "incurvino": "incurvare",
    "incurvo": "incurvare",
    "incurvò": "incurvare",
    "incustodita": "incustodito",
    "incustodite": "incustodito",
    "incustoditi": "incustodito",
    "incuta": "incutere",
    "incutan": "incutere",
    "incutano": "incutere",
    "incute": "incutere",
    "incutei": "incutere",
    "incutemmo": "incutere",
    "incutendo": "incutere",
    "incutente": "incutere",
    "incutenti": "incutere",
    "incuter": "incutere",
    "incuterai": "incutere",
    "incuteran": "incutere",
    "incuteranno": "incutere",
    "incuterebbe": "incutere",
    "incuterebber": "incutere",
    "incuterebbero": "incutere",
    "incuterei": "incutere",
    "incuteremmo": "incutere",
    "incuteremo": "incutere",
    "incutereste": "incutere",
    "incuteresti": "incutere",
    "incuterete": "incutere",
    "incuteron": "incutere",
    "incuterono": "incutere",
    "incuterà": "incutere",
    "incuterò": "incutere",
    "incutesse": "incutere",
    "incutesser": "incutere",
    "incutessero": "incutere",
    "incutessi": "incutere",
    "incutessimo": "incutere",
    "incuteste": "incutere",
    "incutesti": "incutere",
    "incutete": "incutere",
    "incuteva": "incutere",
    "incutevamo": "incutere",
    "incutevan": "incutere",
    "incutevano": "incutere",
    "incutevate": "incutere",
    "incutevi": "incutere",
    "incutevo": "incutere",
    "incuti": "incutere",
    "incutiamo": "incutere",
    "incutiate": "incutere",
    "incuto": "incutere",
    "incuton": "incutere",
    "incutono": "incutere",
    "incututa": "incutere",
    "incutute": "incutere",
    "incututi": "incutere",
    "incututo": "incutere",
    "incutè": "incutere",
    "inda": "indo",
    "indaffarata": "indaffarato",
    "indaffarate": "indaffarato",
    "indaffarati": "indaffarato",
    "indaga": "indagare",
    "indagai": "indagare",
    "indagammo": "indagare",
    "indagan": "indagare",
    "indagando": "indagare",
    "indagano": "indagare",
    "indagante": "indagare",
    "indaganti": "indagare",
    "indagar": "indagare",
    "indagaron": "indagare",
    "indagarono": "indagare",
    "indagasse": "indagare",
    "indagasser": "indagare",
    "indagassero": "indagare",
    "indagassi": "indagare",
    "indagassimo": "indagare",
    "indagaste": "indagare",
    "indagasti": "indagare",
    "indagata": "indagare",
    "indagate": "indagare",
    "indagati": "indagato",
    "indagato": "indagare",
    "indagatori": "indagatorio",
    "indagatoria": "indagatorio",
    "indagatorie": "indagatorio",
    "indagatrice": "indagatore",
    "indagatrici": "indagatore",
    "indagava": "indagare",
    "indagavamo": "indagare",
    "indagavan": "indagare",
    "indagavano": "indagare",
    "indagavate": "indagare",
    "indagavi": "indagare",
    "indagavo": "indagare",
    "indagherai": "indagare",
    "indagheran": "indagare",
    "indagheranno": "indagare",
    "indagherebbe": "indagare",
    "indagherebber": "indagare",
    "indagherebbero": "indagare",
    "indagherei": "indagare",
    "indagheremmo": "indagare",
    "indagheremo": "indagare",
    "indaghereste": "indagare",
    "indagheresti": "indagare",
    "indagherete": "indagare",
    "indagherà": "indagare",
    "indagherò": "indagare",
    "indaghi": "indagare",
    "indaghiamo": "indagare",
    "indaghiate": "indagare",
    "indaghin": "indagare",
    "indaghino": "indagare",
    "indagini": "indagine",
    "indago": "indagare",
    "indagò": "indagare",
    "inde": "indo",
    "indebita": "indebito",
    "indebitai": "indebitare",
    "indebitamenti": "indebitamento",
    "indebitammo": "indebitare",
    "indebitan": "indebitare",
    "indebitando": "indebitare",
    "indebitano": "indebitare",
    "indebitante": "indebitare",
    "indebitanti": "indebitare",
    "indebitar": "indebitare",
    "indebitaron": "indebitare",
    "indebitarono": "indebitare",
    "indebitasse": "indebitare",
    "indebitasser": "indebitare",
    "indebitassero": "indebitare",
    "indebitassi": "indebitare",
    "indebitassimo": "indebitare",
    "indebitaste": "indebitare",
    "indebitasti": "indebitare",
    "indebitata": "indebitare",
    "indebitate": "indebitare",
    "indebitati": "indebitare",
    "indebitato": "indebitare",
    "indebitava": "indebitare",
    "indebitavamo": "indebitare",
    "indebitavan": "indebitare",
    "indebitavano": "indebitare",
    "indebitavate": "indebitare",
    "indebitavi": "indebitare",
    "indebitavo": "indebitare",
    "indebite": "indebito",
    "indebiterai": "indebitare",
    "indebiteran": "indebitare",
    "indebiteranno": "indebitare",
    "indebiterebbe": "indebitare",
    "indebiterebber": "indebitare",
    "indebiterebbero": "indebitare",
    "indebiterei": "indebitare",
    "indebiteremmo": "indebitare",
    "indebiteremo": "indebitare",
    "indebitereste": "indebitare",
    "indebiteresti": "indebitare",
    "indebiterete": "indebitare",
    "indebiterà": "indebitare",
    "indebiterò": "indebitare",
    "indebiti": "indebito",
    "indebitiamo": "indebitare",
    "indebitiate": "indebitare",
    "indebitin": "indebitare",
    "indebitino": "indebitare",
    "indebito": "indebitare",
    "indebitò": "indebitare",
    "indebolendo": "indebolire",
    "indebolente": "indebolire",
    "indebolenti": "indebolire",
    "indeboliamo": "indebolire",
    "indeboliate": "indebolire",
    "indebolii": "indebolire",
    "indebolimenti": "indebolimento",
    "indebolimmo": "indebolire",
    "indebolir": "indebolire",
    "indebolirai": "indebolire",
    "indeboliran": "indebolire",
    "indeboliranno": "indebolire",
    "indebolirebbe": "indebolire",
    "indebolirebber": "indebolire",
    "indebolirebbero": "indebolire",
    "indebolirei": "indebolire",
    "indeboliremmo": "indebolire",
    "indeboliremo": "indebolire",
    "indebolireste": "indebolire",
    "indeboliresti": "indebolire",
    "indebolirete": "indebolire",
    "indeboliron": "indebolire",
    "indebolirono": "indebolire",
    "indebolirà": "indebolire",
    "indebolirò": "indebolire",
    "indebolisca": "indebolire",
    "indeboliscan": "indebolire",
    "indeboliscano": "indebolire",
    "indebolisce": "indebolire",
    "indebolisci": "indebolire",
    "indebolisco": "indebolire",
    "indeboliscon": "indebolire",
    "indeboliscono": "indebolire",
    "indebolisse": "indebolire",
    "indebolisser": "indebolire",
    "indebolissero": "indebolire",
    "indebolissi": "indebolire",
    "indebolissimo": "indebolire",
    "indeboliste": "indebolire",
    "indebolisti": "indebolire",
    "indebolita": "indebolire",
    "indebolite": "indebolire",
    "indeboliti": "indebolire",
    "indebolito": "indebolire",
    "indeboliva": "indebolire",
    "indebolivamo": "indebolire",
    "indebolivan": "indebolire",
    "indebolivano": "indebolire",
    "indebolivate": "indebolire",
    "indebolivi": "indebolire",
    "indebolivo": "indebolire",
    "indebolì": "indebolire",
    "indecenti": "indecente",
    "indecenze": "indecenza",
    "indecifrabili": "indecifrabile",
    "indecisa": "indeciso",
    "indecise": "indeciso",
    "indecisi": "indeciso",
    "indecisioni": "indecisione",
    "indeclinabili": "indeclinabile",
    "indecorosa": "indecoroso",
    "indecorose": "indecoroso",
    "indecorosi": "indecoroso",
    "indefessa": "indefesso",
    "indefesse": "indefesso",
    "indefessi": "indefesso",
    "indefettibili": "indefettibile",
    "indefinibili": "indefinibile",
    "indefinita": "indefinito",
    "indefinite": "indefinito",
    "indefiniti": "indefinito",
    "indeformabili": "indeformabile",
    "indegna": "indegno",
    "indegne": "indegno",
    "indegni": "indegno",
    "indelebili": "indelebile",
    "indelicata": "indelicato",
    "indelicate": "indelicato",
    "indelicati": "indelicato",
    "indemoniata": "indemoniato",
    "indemoniate": "indemoniato",
    "indemoniati": "indemoniato",
    "indenni": "indenne",
    "indennizza": "indennizzare",
    "indennizzai": "indennizzare",
    "indennizzammo": "indennizzare",
    "indennizzan": "indennizzare",
    "indennizzando": "indennizzare",
    "indennizzano": "indennizzare",
    "indennizzante": "indennizzare",
    "indennizzanti": "indennizzare",
    "indennizzar": "indennizzare",
    "indennizzaron": "indennizzare",
    "indennizzarono": "indennizzare",
    "indennizzasse": "indennizzare",
    "indennizzasser": "indennizzare",
    "indennizzassero": "indennizzare",
    "indennizzassi": "indennizzare",
    "indennizzassimo": "indennizzare",
    "indennizzaste": "indennizzare",
    "indennizzasti": "indennizzare",
    "indennizzata": "indennizzare",
    "indennizzate": "indennizzare",
    "indennizzati": "indennizzare",
    "indennizzato": "indennizzare",
    "indennizzava": "indennizzare",
    "indennizzavamo": "indennizzare",
    "indennizzavan": "indennizzare",
    "indennizzavano": "indennizzare",
    "indennizzavate": "indennizzare",
    "indennizzavi": "indennizzare",
    "indennizzavo": "indennizzare",
    "indennizzerai": "indennizzare",
    "indennizzeran": "indennizzare",
    "indennizzeranno": "indennizzare",
    "indennizzerebbe": "indennizzare",
    "indennizzerebber": "indennizzare",
    "indennizzerebbero": "indennizzare",
    "indennizzerei": "indennizzare",
    "indennizzeremmo": "indennizzare",
    "indennizzeremo": "indennizzare",
    "indennizzereste": "indennizzare",
    "indennizzeresti": "indennizzare",
    "indennizzerete": "indennizzare",
    "indennizzerà": "indennizzare",
    "indennizzerò": "indennizzare",
    "indennizzi": "indennizzo",
    "indennizziamo": "indennizzare",
    "indennizziate": "indennizzare",
    "indennizzin": "indennizzare",
    "indennizzino": "indennizzare",
    "indennizzo": "indennizzare",
    "indennizzò": "indennizzare",
    "inderogabili": "inderogabile",
    "indescrivibili": "indescrivibile",
    "indesiderabili": "indesiderabile",
    "indesiderata": "indesiderato",
    "indesiderate": "indesiderato",
    "indesiderati": "indesiderato",
    "indeterminata": "indeterminato",
    "indeterminate": "indeterminato",
    "indeterminatezze": "indeterminatezza",
    "indeterminati": "indeterminato",
    "indetta": "indire",
    "indettai": "indettare",
    "indettammo": "indettare",
    "indettan": "indettare",
    "indettando": "indettare",
    "indettano": "indettare",
    "indettante": "indettare",
    "indettanti": "indettare",
    "indettar": "indettare",
    "indettaron": "indettare",
    "indettarono": "indettare",
    "indettasse": "indettare",
    "indettasser": "indettare",
    "indettassero": "indettare",
    "indettassi": "indettare",
    "indettassimo": "indettare",
    "indettaste": "indettare",
    "indettasti": "indettare",
    "indettata": "indettare",
    "indettate": "indettare",
    "indettati": "indettare",
    "indettato": "indettare",
    "indettava": "indettare",
    "indettavamo": "indettare",
    "indettavan": "indettare",
    "indettavano": "indettare",
    "indettavate": "indettare",
    "indettavi": "indettare",
    "indettavo": "indettare",
    "indette": "indire",
    "indetterai": "indettare",
    "indetteran": "indettare",
    "indetteranno": "indettare",
    "indetterebbe": "indettare",
    "indetterebber": "indettare",
    "indetterebbero": "indettare",
    "indetterei": "indettare",
    "indetteremmo": "indettare",
    "indetteremo": "indettare",
    "indettereste": "indettare",
    "indetteresti": "indettare",
    "indetterete": "indettare",
    "indetterà": "indettare",
    "indetterò": "indettare",
    "indetti": "indire",
    "indettiamo": "indettare",
    "indettiate": "indettare",
    "indettin": "indettare",
    "indettino": "indettare",
    "indetto": "indire",
    "indettò": "indettare",
    "indi": "indo",
    "india": "indio",
    "indiana": "indiano",
    "indiane": "indiano",
    "indiani": "indiano",
    "indiavolata": "indiavolato",
    "indiavolate": "indiavolato",
    "indiavolati": "indiavolato",
    "indica": "indire",
    "indicai": "indicare",
    "indicammo": "indicare",
    "indican": "indire",
    "indicando": "indicare",
    "indicano": "indire",
    "indicante": "indicare",
    "indicanti": "indicare",
    "indicar": "indicare",
    "indicaron": "indicare",
    "indicarono": "indicare",
    "indicasse": "indicare",
    "indicasser": "indicare",
    "indicassero": "indicare",
    "indicassi": "indicare",
    "indicassimo": "indicare",
    "indicaste": "indicare",
    "indicasti": "indicare",
    "indicata": "indicato",
    "indicate": "indicato",
    "indicati": "indicato",
    "indicativa": "indicativo",
    "indicative": "indicativo",
    "indicativi": "indicativo",
    "indicato": "indicare",
    "indicatori": "indicatore",
    "indicatrice": "indicatore",
    "indicatrici": "indicatore",
    "indicava": "indicare",
    "indicavamo": "indicare",
    "indicavan": "indicare",
    "indicavano": "indicare",
    "indicavate": "indicare",
    "indicavi": "indicare",
    "indicavo": "indicare",
    "indicazioni": "indicazione",
    "indice": "indire",
    "indicemmo": "indire",
    "indicendo": "indire",
    "indicente": "indire",
    "indicenti": "indire",
    "indicesse": "indire",
    "indicesser": "indire",
    "indicessero": "indire",
    "indicessi": "indire",
    "indicessimo": "indire",
    "indiceste": "indire",
    "indicesti": "indire",
    "indiceva": "indire",
    "indicevamo": "indire",
    "indicevan": "indire",
    "indicevano": "indire",
    "indicevate": "indire",
    "indicevi": "indire",
    "indicevo": "indire",
    "indiche": "indico",
    "indicherai": "indicare",
    "indicheran": "indicare",
    "indicheranno": "indicare",
    "indicherebbe": "indicare",
    "indicherebber": "indicare",
    "indicherebbero": "indicare",
    "indicherei": "indicare",
    "indicheremmo": "indicare",
    "indicheremo": "indicare",
    "indichereste": "indicare",
    "indicheresti": "indicare",
    "indicherete": "indicare",
    "indicherà": "indicare",
    "indicherò": "indicare",
    "indichi": "indicare",
    "indichiamo": "indicare",
    "indichiate": "indicare",
    "indichin": "indicare",
    "indichino": "indicare",
    "indici": "indire",
    "indiciamo": "indire",
    "indiciate": "indire",
    "indicizza": "indicizzare",
    "indicizzai": "indicizzare",
    "indicizzammo": "indicizzare",
    "indicizzan": "indicizzare",
    "indicizzando": "indicizzare",
    "indicizzano": "indicizzare",
    "indicizzante": "indicizzare",
    "indicizzanti": "indicizzare",
    "indicizzar": "indicizzare",
    "indicizzaron": "indicizzare",
    "indicizzarono": "indicizzare",
    "indicizzasse": "indicizzare",
    "indicizzasser": "indicizzare",
    "indicizzassero": "indicizzare",
    "indicizzassi": "indicizzare",
    "indicizzassimo": "indicizzare",
    "indicizzaste": "indicizzare",
    "indicizzasti": "indicizzare",
    "indicizzata": "indicizzare",
    "indicizzate": "indicizzare",
    "indicizzati": "indicizzare",
    "indicizzato": "indicizzare",
    "indicizzava": "indicizzare",
    "indicizzavamo": "indicizzare",
    "indicizzavan": "indicizzare",
    "indicizzavano": "indicizzare",
    "indicizzavate": "indicizzare",
    "indicizzavi": "indicizzare",
    "indicizzavo": "indicizzare",
    "indicizzazioni": "indicizzazione",
    "indicizzerai": "indicizzare",
    "indicizzeran": "indicizzare",
    "indicizzeranno": "indicizzare",
    "indicizzerebbe": "indicizzare",
    "indicizzerebber": "indicizzare",
    "indicizzerebbero": "indicizzare",
    "indicizzerei": "indicizzare",
    "indicizzeremmo": "indicizzare",
    "indicizzeremo": "indicizzare",
    "indicizzereste": "indicizzare",
    "indicizzeresti": "indicizzare",
    "indicizzerete": "indicizzare",
    "indicizzerà": "indicizzare",
    "indicizzerò": "indicizzare",
    "indicizzi": "indicizzare",
    "indicizziamo": "indicizzare",
    "indicizziate": "indicizzare",
    "indicizzin": "indicizzare",
    "indicizzino": "indicizzare",
    "indicizzo": "indicizzare",
    "indicizzò": "indicizzare",
    "indico": "indire",
    "indicon": "indire",
    "indicono": "indire",
    "indicò": "indicare",
    "indie": "indio",
    "indietreggerai": "indietreggiare",
    "indietreggeran": "indietreggiare",
    "indietreggeranno": "indietreggiare",
    "indietreggerebbe": "indietreggiare",
    "indietreggerebber": "indietreggiare",
    "indietreggerebbero": "indietreggiare",
    "indietreggerei": "indietreggiare",
    "indietreggeremmo": "indietreggiare",
    "indietreggeremo": "indietreggiare",
    "indietreggereste": "indietreggiare",
    "indietreggeresti": "indietreggiare",
    "indietreggerete": "indietreggiare",
    "indietreggerà": "indietreggiare",
    "indietreggerò": "indietreggiare",
    "indietreggi": "indietreggiare",
    "indietreggia": "indietreggiare",
    "indietreggiai": "indietreggiare",
    "indietreggiammo": "indietreggiare",
    "indietreggiamo": "indietreggiare",
    "indietreggian": "indietreggiare",
    "indietreggiando": "indietreggiare",
    "indietreggiano": "indietreggiare",
    "indietreggiante": "indietreggiare",
    "indietreggianti": "indietreggiare",
    "indietreggiar": "indietreggiare",
    "indietreggiaron": "indietreggiare",
    "indietreggiarono": "indietreggiare",
    "indietreggiasse": "indietreggiare",
    "indietreggiasser": "indietreggiare",
    "indietreggiassero": "indietreggiare",
    "indietreggiassi": "indietreggiare",
    "indietreggiassimo": "indietreggiare",
    "indietreggiaste": "indietreggiare",
    "indietreggiasti": "indietreggiare",
    "indietreggiata": "indietreggiare",
    "indietreggiate": "indietreggiare",
    "indietreggiati": "indietreggiare",
    "indietreggiato": "indietreggiare",
    "indietreggiava": "indietreggiare",
    "indietreggiavamo": "indietreggiare",
    "indietreggiavan": "indietreggiare",
    "indietreggiavano": "indietreggiare",
    "indietreggiavate": "indietreggiare",
    "indietreggiavi": "indietreggiare",
    "indietreggiavo": "indietreggiare",
    "indietreggin": "indietreggiare",
    "indietreggino": "indietreggiare",
    "indietreggio": "indietreggiare",
    "indietreggiò": "indietreggiare",
    "indifendibili": "indifendibile",
    "indifesa": "indifeso",
    "indifese": "indifeso",
    "indifesi": "indifeso",
    "indifferenti": "indifferente",
    "indifferenze": "indifferenza",
    "indifferenziata": "indifferenziato",
    "indifferenziate": "indifferenziato",
    "indifferenziati": "indifferenziato",
    "indifferibili": "indifferibile",
    "indigena": "indigeno",
    "indigene": "indigeno",
    "indigeni": "indigeno",
    "indigenti": "indigente",
    "indigenze": "indigenza",
    "indigesta": "indigesto",
    "indigeste": "indigesto",
    "indigesti": "indigesto",
    "indigestioni": "indigestione",
    "indigna": "indignare",
    "indignai": "indignare",
    "indignammo": "indignare",
    "indignan": "indignare",
    "indignando": "indignare",
    "indignano": "indignare",
    "indignante": "indignare",
    "indignanti": "indignare",
    "indignar": "indignare",
    "indignaron": "indignare",
    "indignarono": "indignare",
    "indignasse": "indignare",
    "indignasser": "indignare",
    "indignassero": "indignare",
    "indignassi": "indignare",
    "indignassimo": "indignare",
    "indignaste": "indignare",
    "indignasti": "indignare",
    "indignata": "indignato",
    "indignate": "indignato",
    "indignati": "indignato",
    "indignato": "indignare",
    "indignava": "indignare",
    "indignavamo": "indignare",
    "indignavan": "indignare",
    "indignavano": "indignare",
    "indignavate": "indignare",
    "indignavi": "indignare",
    "indignavo": "indignare",
    "indignazioni": "indignazione",
    "indignerai": "indignare",
    "indigneran": "indignare",
    "indigneranno": "indignare",
    "indignerebbe": "indignare",
    "indignerebber": "indignare",
    "indignerebbero": "indignare",
    "indignerei": "indignare",
    "indigneremmo": "indignare",
    "indigneremo": "indignare",
    "indignereste": "indignare",
    "indigneresti": "indignare",
    "indignerete": "indignare",
    "indignerà": "indignare",
    "indignerò": "indignare",
    "indigni": "indignare",
    "indigniamo": "indignare",
    "indigniate": "indignare",
    "indignin": "indignare",
    "indignino": "indignare",
    "indigno": "indignare",
    "indignò": "indignare",
    "indilazionabili": "indilazionabile",
    "indimenticabili": "indimenticabile",
    "indimostrabili": "indimostrabile",
    "indios": "indio",
    "indipendenti": "indipendente",
    "indipendentismi": "indipendentismo",
    "indipendentiste": "indipendentista",
    "indipendentisti": "indipendentista",
    "indipendenze": "indipendenza",
    "indir": "indire",
    "indirai": "indire",
    "indiran": "indire",
    "indiranno": "indire",
    "indirebbe": "indire",
    "indirebber": "indire",
    "indirebbero": "indire",
    "indirei": "indire",
    "indiremmo": "indire",
    "indiremo": "indire",
    "indireste": "indire",
    "indiresti": "indire",
    "indirete": "indire",
    "indiretta": "indiretto",
    "indirette": "indiretto",
    "indiretti": "indiretto",
    "indirizza": "indirizzare",
    "indirizzai": "indirizzare",
    "indirizzammo": "indirizzare",
    "indirizzan": "indirizzare",
    "indirizzando": "indirizzare",
    "indirizzano": "indirizzare",
    "indirizzante": "indirizzare",
    "indirizzanti": "indirizzare",
    "indirizzar": "indirizzare",
    "indirizzari": "indirizzario",
    "indirizzaron": "indirizzare",
    "indirizzarono": "indirizzare",
    "indirizzasse": "indirizzare",
    "indirizzasser": "indirizzare",
    "indirizzassero": "indirizzare",
    "indirizzassi": "indirizzare",
    "indirizzassimo": "indirizzare",
    "indirizzaste": "indirizzare",
    "indirizzasti": "indirizzare",
    "indirizzata": "indirizzare",
    "indirizzate": "indirizzare",
    "indirizzati": "indirizzare",
    "indirizzato": "indirizzare",
    "indirizzava": "indirizzare",
    "indirizzavamo": "indirizzare",
    "indirizzavan": "indirizzare",
    "indirizzavano": "indirizzare",
    "indirizzavate": "indirizzare",
    "indirizzavi": "indirizzare",
    "indirizzavo": "indirizzare",
    "indirizzerai": "indirizzare",
    "indirizzeran": "indirizzare",
    "indirizzeranno": "indirizzare",
    "indirizzerebbe": "indirizzare",
    "indirizzerebber": "indirizzare",
    "indirizzerebbero": "indirizzare",
    "indirizzerei": "indirizzare",
    "indirizzeremmo": "indirizzare",
    "indirizzeremo": "indirizzare",
    "indirizzereste": "indirizzare",
    "indirizzeresti": "indirizzare",
    "indirizzerete": "indirizzare",
    "indirizzerà": "indirizzare",
    "indirizzerò": "indirizzare",
    "indirizzi": "indirizzo",
    "indirizziamo": "indirizzare",
    "indirizziate": "indirizzare",
    "indirizzin": "indirizzare",
    "indirizzino": "indirizzare",
    "indirizzo": "indirizzare",
    "indirizzò": "indirizzare",
    "indirà": "indire",
    "indirò": "indire",
    "indisciplinata": "indisciplinato",
    "indisciplinate": "indisciplinato",
    "indisciplinati": "indisciplinato",
    "indiscreta": "indiscreto",
    "indiscrete": "indiscreto",
    "indiscreti": "indiscreto",
    "indiscrezioni": "indiscrezione",
    "indiscriminata": "indiscriminato",
    "indiscriminate": "indiscriminato",
    "indiscriminati": "indiscriminato",
    "indiscussa": "indiscusso",
    "indiscusse": "indiscusso",
    "indiscussi": "indiscusso",
    "indiscutibili": "indiscutibile",
    "indispensabili": "indispensabile",
    "indispettendo": "indispettire",
    "indispettente": "indispettire",
    "indispettenti": "indispettire",
    "indispettiamo": "indispettire",
    "indispettiate": "indispettire",
    "indispettii": "indispettire",
    "indispettimmo": "indispettire",
    "indispettir": "indispettire",
    "indispettirai": "indispettire",
    "indispettiran": "indispettire",
    "indispettiranno": "indispettire",
    "indispettirebbe": "indispettire",
    "indispettirebber": "indispettire",
    "indispettirebbero": "indispettire",
    "indispettirei": "indispettire",
    "indispettiremmo": "indispettire",
    "indispettiremo": "indispettire",
    "indispettireste": "indispettire",
    "indispettiresti": "indispettire",
    "indispettirete": "indispettire",
    "indispettiron": "indispettire",
    "indispettirono": "indispettire",
    "indispettirà": "indispettire",
    "indispettirò": "indispettire",
    "indispettisca": "indispettire",
    "indispettiscan": "indispettire",
    "indispettiscano": "indispettire",
    "indispettisce": "indispettire",
    "indispettisci": "indispettire",
    "indispettisco": "indispettire",
    "indispettiscon": "indispettire",
    "indispettiscono": "indispettire",
    "indispettisse": "indispettire",
    "indispettisser": "indispettire",
    "indispettissero": "indispettire",
    "indispettissi": "indispettire",
    "indispettissimo": "indispettire",
    "indispettiste": "indispettire",
    "indispettisti": "indispettire",
    "indispettita": "indispettire",
    "indispettite": "indispettire",
    "indispettiti": "indispettire",
    "indispettito": "indispettire",
    "indispettiva": "indispettire",
    "indispettivamo": "indispettire",
    "indispettivan": "indispettire",
    "indispettivano": "indispettire",
    "indispettivate": "indispettire",
    "indispettivi": "indispettire",
    "indispettivo": "indispettire",
    "indispettì": "indispettire",
    "indispone": "indisporre",
    "indisponei": "indisporre",
    "indisponemmo": "indisporre",
    "indisponendo": "indisporre",
    "indisponente": "indisporre",
    "indisponenti": "indisporre",
    "indisponerai": "indisporre",
    "indisponeran": "indisporre",
    "indisponeranno": "indisporre",
    "indisponerebbe": "indisporre",
    "indisponerebber": "indisporre",
    "indisponerebbero": "indisporre",
    "indisponerei": "indisporre",
    "indisponeremmo": "indisporre",
    "indisponeremo": "indisporre",
    "indisponereste": "indisporre",
    "indisponeresti": "indisporre",
    "indisponerete": "indisporre",
    "indisponeron": "indisporre",
    "indisponerono": "indisporre",
    "indisponerà": "indisporre",
    "indisponerò": "indisporre",
    "indisponesse": "indisporre",
    "indisponesser": "indisporre",
    "indisponessero": "indisporre",
    "indisponessi": "indisporre",
    "indisponessimo": "indisporre",
    "indisponeste": "indisporre",
    "indisponesti": "indisporre",
    "indisponete": "indisporre",
    "indisponeva": "indisporre",
    "indisponevamo": "indisporre",
    "indisponevan": "indisporre",
    "indisponevano": "indisporre",
    "indisponevate": "indisporre",
    "indisponevi": "indisporre",
    "indisponevo": "indisporre",
    "indisponga": "indisporre",
    "indispongan": "indisporre",
    "indispongano": "indisporre",
    "indispongo": "indisporre",
    "indispongon": "indisporre",
    "indispongono": "indisporre",
    "indisponi": "indisporre",
    "indisponiamo": "indisporre",
    "indisponiate": "indisporre",
    "indisponuta": "indisporre",
    "indisponute": "indisporre",
    "indisponuti": "indisporre",
    "indisponuto": "indisporre",
    "indisponè": "indisporre",
    "indisporr": "indisporre",
    "indisposizioni": "indisposizione",
    "indisposta": "indisposto",
    "indisposte": "indisposto",
    "indisposti": "indisposto",
    "indisse": "indire",
    "indisser": "indire",
    "indissero": "indire",
    "indissi": "indire",
    "indissolubili": "indissolubile",
    "indistinta": "indistinto",
    "indistinte": "indistinto",
    "indistinti": "indistinto",
    "indistruttibili": "indistruttibile",
    "indisturbata": "indisturbato",
    "indisturbate": "indisturbato",
    "indisturbati": "indisturbato",
    "indite": "indire",
    "individua": "individuare",
    "individuabili": "individuabile",
    "individuai": "individuare",
    "individuali": "individuale",
    "individualismi": "individualismo",
    "individualiste": "individualista",
    "individualisti": "individualista",
    "individualistica": "individualistico",
    "individualistiche": "individualistico",
    "individualistici": "individualistico",
    "individualizza": "individualizzare",
    "individualizzai": "individualizzare",
    "individualizzammo": "individualizzare",
    "individualizzan": "individualizzare",
    "individualizzando": "individualizzare",
    "individualizzano": "individualizzare",
    "individualizzante": "individualizzare",
    "individualizzanti": "individualizzare",
    "individualizzar": "individualizzare",
    "individualizzaron": "individualizzare",
    "individualizzarono": "individualizzare",
    "individualizzasse": "individualizzare",
    "individualizzasser": "individualizzare",
    "individualizzassero": "individualizzare",
    "individualizzassi": "individualizzare",
    "individualizzassimo": "individualizzare",
    "individualizzaste": "individualizzare",
    "individualizzasti": "individualizzare",
    "individualizzata": "individualizzare",
    "individualizzate": "individualizzare",
    "individualizzati": "individualizzare",
    "individualizzato": "individualizzare",
    "individualizzava": "individualizzare",
    "individualizzavamo": "individualizzare",
    "individualizzavan": "individualizzare",
    "individualizzavano": "individualizzare",
    "individualizzavate": "individualizzare",
    "individualizzavi": "individualizzare",
    "individualizzavo": "individualizzare",
    "individualizzerai": "individualizzare",
    "individualizzeran": "individualizzare",
    "individualizzeranno": "individualizzare",
    "individualizzerebbe": "individualizzare",
    "individualizzerebber": "individualizzare",
    "individualizzerebbero": "individualizzare",
    "individualizzerei": "individualizzare",
    "individualizzeremmo": "individualizzare",
    "individualizzeremo": "individualizzare",
    "individualizzereste": "individualizzare",
    "individualizzeresti": "individualizzare",
    "individualizzerete": "individualizzare",
    "individualizzerà": "individualizzare",
    "individualizzerò": "individualizzare",
    "individualizzi": "individualizzare",
    "individualizziamo": "individualizzare",
    "individualizziate": "individualizzare",
    "individualizzin": "individualizzare",
    "individualizzino": "individualizzare",
    "individualizzo": "individualizzare",
    "individualizzò": "individualizzare",
    "individuammo": "individuare",
    "individuan": "individuare",
    "individuando": "individuare",
    "individuano": "individuare",
    "individuante": "individuare",
    "individuanti": "individuare",
    "individuar": "individuare",
    "individuaron": "individuare",
    "individuarono": "individuare",
    "individuasse": "individuare",
    "individuasser": "individuare",
    "individuassero": "individuare",
    "individuassi": "individuare",
    "individuassimo": "individuare",
    "individuaste": "individuare",
    "individuasti": "individuare",
    "individuata": "individuare",
    "individuate": "individuare",
    "individuati": "individuare",
    "individuato": "individuare",
    "individuava": "individuare",
    "individuavamo": "individuare",
    "individuavan": "individuare",
    "individuavano": "individuare",
    "individuavate": "individuare",
    "individuavi": "individuare",
    "individuavo": "individuare",
    "individuazioni": "individuazione",
    "individuerai": "individuare",
    "individueran": "individuare",
    "individueranno": "individuare",
    "individuerebbe": "individuare",
    "individuerebber": "individuare",
    "individuerebbero": "individuare",
    "individuerei": "individuare",
    "individueremmo": "individuare",
    "individueremo": "individuare",
    "individuereste": "individuare",
    "individueresti": "individuare",
    "individuerete": "individuare",
    "individuerà": "individuare",
    "individuerò": "individuare",
    "individui": "individuo",
    "individuiamo": "individuare",
    "individuiate": "individuare",
    "individuin": "individuare",
    "individuino": "individuare",
    "individuo": "individuare",
    "individuò": "individuare",
    "indivisa": "indiviso",
    "indivise": "indiviso",
    "indivisi": "indiviso",
    "indivisibili": "indivisibile",
    "indizi": "indizio",
    "indizia": "indiziare",
    "indiziai": "indiziare",
    "indiziammo": "indiziare",
    "indiziamo": "indiziare",
    "indizian": "indiziare",
    "indiziando": "indiziare",
    "indiziano": "indiziare",
    "indiziante": "indiziare",
    "indizianti": "indiziare",
    "indiziar": "indiziare",
    "indiziaron": "indiziare",
    "indiziarono": "indiziare",
    "indiziasse": "indiziare",
    "indiziasser": "indiziare",
    "indiziassero": "indiziare",
    "indiziassi": "indiziare",
    "indiziassimo": "indiziare",
    "indiziaste": "indiziare",
    "indiziasti": "indiziare",
    "indiziata": "indiziare",
    "indiziate": "indiziare",
    "indiziati": "indiziato",
    "indiziato": "indiziare",
    "indiziava": "indiziare",
    "indiziavamo": "indiziare",
    "indiziavan": "indiziare",
    "indiziavano": "indiziare",
    "indiziavate": "indiziare",
    "indiziavi": "indiziare",
    "indiziavo": "indiziare",
    "indizierai": "indiziare",
    "indizieran": "indiziare",
    "indizieranno": "indiziare",
    "indizierebbe": "indiziare",
    "indizierebber": "indiziare",
    "indizierebbero": "indiziare",
    "indizierei": "indiziare",
    "indizieremmo": "indiziare",
    "indizieremo": "indiziare",
    "indiziereste": "indiziare",
    "indizieresti": "indiziare",
    "indizierete": "indiziare",
    "indizierà": "indiziare",
    "indizierò": "indiziare",
    "indizin": "indiziare",
    "indizino": "indiziare",
    "indizio": "indiziare",
    "indiziò": "indiziare",
    "indocili": "indocile",
    "indolenti": "indolente",
    "indolenza": "indolenzire",
    "indolenzan": "indolenzire",
    "indolenzano": "indolenzire",
    "indolenze": "indolenzire",
    "indolenzendo": "indolenzire",
    "indolenzente": "indolenzire",
    "indolenzenti": "indolenzire",
    "indolenzi": "indolenzire",
    "indolenziamo": "indolenzire",
    "indolenziate": "indolenzire",
    "indolenzii": "indolenzire",
    "indolenzimmo": "indolenzire",
    "indolenzir": "indolenzire",
    "indolenzirai": "indolenzire",
    "indolenziran": "indolenzire",
    "indolenziranno": "indolenzire",
    "indolenzirebbe": "indolenzire",
    "indolenzirebber": "indolenzire",
    "indolenzirebbero": "indolenzire",
    "indolenzirei": "indolenzire",
    "indolenziremmo": "indolenzire",
    "indolenziremo": "indolenzire",
    "indolenzireste": "indolenzire",
    "indolenziresti": "indolenzire",
    "indolenzirete": "indolenzire",
    "indolenziron": "indolenzire",
    "indolenzirono": "indolenzire",
    "indolenzirà": "indolenzire",
    "indolenzirò": "indolenzire",
    "indolenzisse": "indolenzire",
    "indolenzisser": "indolenzire",
    "indolenzissero": "indolenzire",
    "indolenzissi": "indolenzire",
    "indolenzissimo": "indolenzire",
    "indolenziste": "indolenzire",
    "indolenzisti": "indolenzire",
    "indolenzita": "indolenzire",
    "indolenzite": "indolenzire",
    "indolenziti": "indolenzire",
    "indolenzito": "indolenzire",
    "indolenziva": "indolenzire",
    "indolenzivamo": "indolenzire",
    "indolenzivan": "indolenzire",
    "indolenzivano": "indolenzire",
    "indolenzivate": "indolenzire",
    "indolenzivi": "indolenzire",
    "indolenzivo": "indolenzire",
    "indolenzo": "indolenzire",
    "indolenzon": "indolenzire",
    "indolenzono": "indolenzire",
    "indolenzì": "indolenzire",
    "indoli": "indole",
    "indolori": "indolore",
    "indomabili": "indomabile",
    "indomita": "indomito",
    "indomite": "indomito",
    "indomiti": "indomito",
    "indonesiana": "indonesiano",
    "indonesiane": "indonesiano",
    "indonesiani": "indonesiano",
    "indora": "indorare",
    "indorai": "indorare",
    "indorammo": "indorare",
    "indoran": "indorare",
    "indorando": "indorare",
    "indorano": "indorare",
    "indorante": "indorare",
    "indoranti": "indorare",
    "indorar": "indorare",
    "indoraron": "indorare",
    "indorarono": "indorare",
    "indorasse": "indorare",
    "indorasser": "indorare",
    "indorassero": "indorare",
    "indorassi": "indorare",
    "indorassimo": "indorare",
    "indoraste": "indorare",
    "indorasti": "indorare",
    "indorata": "indorare",
    "indorate": "indorare",
    "indorati": "indorare",
    "indorato": "indorare",
    "indorava": "indorare",
    "indoravamo": "indorare",
    "indoravan": "indorare",
    "indoravano": "indorare",
    "indoravate": "indorare",
    "indoravi": "indorare",
    "indoravo": "indorare",
    "indorerai": "indorare",
    "indoreran": "indorare",
    "indoreranno": "indorare",
    "indorerebbe": "indorare",
    "indorerebber": "indorare",
    "indorerebbero": "indorare",
    "indorerei": "indorare",
    "indoreremmo": "indorare",
    "indoreremo": "indorare",
    "indorereste": "indorare",
    "indoreresti": "indorare",
    "indorerete": "indorare",
    "indorerà": "indorare",
    "indorerò": "indorare",
    "indori": "indorare",
    "indoriamo": "indorare",
    "indoriate": "indorare",
    "indorin": "indorare",
    "indorino": "indorare",
    "indoro": "indorare",
    "indorò": "indorare",
    "indossa": "indossare",
    "indossai": "indossare",
    "indossammo": "indossare",
    "indossan": "indossare",
    "indossando": "indossare",
    "indossano": "indossare",
    "indossante": "indossare",
    "indossanti": "indossare",
    "indossar": "indossare",
    "indossaron": "indossare",
    "indossarono": "indossare",
    "indossasse": "indossare",
    "indossasser": "indossare",
    "indossassero": "indossare",
    "indossassi": "indossare",
    "indossassimo": "indossare",
    "indossaste": "indossare",
    "indossasti": "indossare",
    "indossata": "indossare",
    "indossate": "indossare",
    "indossati": "indossare",
    "indossato": "indossare",
    "indossatori": "indossatore",
    "indossatrici": "indossatrice",
    "indossava": "indossare",
    "indossavamo": "indossare",
    "indossavan": "indossare",
    "indossavano": "indossare",
    "indossavate": "indossare",
    "indossavi": "indossare",
    "indossavo": "indossare",
    "indosserai": "indossare",
    "indosseran": "indossare",
    "indosseranno": "indossare",
    "indosserebbe": "indossare",
    "indosserebber": "indossare",
    "indosserebbero": "indossare",
    "indosserei": "indossare",
    "indosseremmo": "indossare",
    "indosseremo": "indossare",
    "indossereste": "indossare",
    "indosseresti": "indossare",
    "indosserete": "indossare",
    "indosserà": "indossare",
    "indosserò": "indossare",
    "indossi": "indossare",
    "indossiamo": "indossare",
    "indossiate": "indossare",
    "indossin": "indossare",
    "indossino": "indossare",
    "indosso": "indossare",
    "indossò": "indossare",
    "indotta": "indurre",
    "indotte": "indurre",
    "indotti": "indurre",
    "indotto": "indurre",
    "indottrina": "indottrinare",
    "indottrinai": "indottrinare",
    "indottrinammo": "indottrinare",
    "indottrinan": "indottrinare",
    "indottrinando": "indottrinare",
    "indottrinano": "indottrinare",
    "indottrinante": "indottrinare",
    "indottrinanti": "indottrinare",
    "indottrinar": "indottrinare",
    "indottrinaron": "indottrinare",
    "indottrinarono": "indottrinare",
    "indottrinasse": "indottrinare",
    "indottrinasser": "indottrinare",
    "indottrinassero": "indottrinare",
    "indottrinassi": "indottrinare",
    "indottrinassimo": "indottrinare",
    "indottrinaste": "indottrinare",
    "indottrinasti": "indottrinare",
    "indottrinata": "indottrinare",
    "indottrinate": "indottrinare",
    "indottrinati": "indottrinare",
    "indottrinato": "indottrinare",
    "indottrinava": "indottrinare",
    "indottrinavamo": "indottrinare",
    "indottrinavan": "indottrinare",
    "indottrinavano": "indottrinare",
    "indottrinavate": "indottrinare",
    "indottrinavi": "indottrinare",
    "indottrinavo": "indottrinare",
    "indottrinerai": "indottrinare",
    "indottrineran": "indottrinare",
    "indottrineranno": "indottrinare",
    "indottrinerebbe": "indottrinare",
    "indottrinerebber": "indottrinare",
    "indottrinerebbero": "indottrinare",
    "indottrinerei": "indottrinare",
    "indottrineremmo": "indottrinare",
    "indottrineremo": "indottrinare",
    "indottrinereste": "indottrinare",
    "indottrineresti": "indottrinare",
    "indottrinerete": "indottrinare",
    "indottrinerà": "indottrinare",
    "indottrinerò": "indottrinare",
    "indottrini": "indottrinare",
    "indottriniamo": "indottrinare",
    "indottriniate": "indottrinare",
    "indottrinin": "indottrinare",
    "indottrinino": "indottrinare",
    "indottrino": "indottrinare",
    "indottrinò": "indottrinare",
    "indovina": "indovinare",
    "indovinai": "indovinare",
    "indovinammo": "indovinare",
    "indovinan": "indovinare",
    "indovinando": "indovinare",
    "indovinano": "indovinare",
    "indovinante": "indovinare",
    "indovinanti": "indovinare",
    "indovinar": "indovinare",
    "indovinaron": "indovinare",
    "indovinarono": "indovinare",
    "indovinasse": "indovinare",
    "indovinasser": "indovinare",
    "indovinassero": "indovinare",
    "indovinassi": "indovinare",
    "indovinassimo": "indovinare",
    "indovinaste": "indovinare",
    "indovinasti": "indovinare",
    "indovinata": "indovinato",
    "indovinate": "indovinato",
    "indovinati": "indovinato",
    "indovinato": "indovinare",
    "indovinava": "indovinare",
    "indovinavamo": "indovinare",
    "indovinavan": "indovinare",
    "indovinavano": "indovinare",
    "indovinavate": "indovinare",
    "indovinavi": "indovinare",
    "indovinavo": "indovinare",
    "indovinelli": "indovinello",
    "indovinerai": "indovinare",
    "indovineran": "indovinare",
    "indovineranno": "indovinare",
    "indovinerebbe": "indovinare",
    "indovinerebber": "indovinare",
    "indovinerebbero": "indovinare",
    "indovinerei": "indovinare",
    "indovineremmo": "indovinare",
    "indovineremo": "indovinare",
    "indovinereste": "indovinare",
    "indovineresti": "indovinare",
    "indovinerete": "indovinare",
    "indovinerà": "indovinare",
    "indovinerò": "indovinare",
    "indovini": "indovino",
    "indoviniamo": "indovinare",
    "indoviniate": "indovinare",
    "indovinin": "indovinare",
    "indovinino": "indovinare",
    "indovino": "indovinare",
    "indovinò": "indovinare",
    "indubbi": "indubbio",
    "indubbia": "indubbio",
    "indubbie": "indubbio",
    "indubitabili": "indubitabile",
    "induca": "indurre",
    "inducan": "indurre",
    "inducano": "indurre",
    "induce": "indurre",
    "inducemmo": "indurre",
    "inducendo": "indurre",
    "inducente": "indurre",
    "inducenti": "indurre",
    "inducesse": "indurre",
    "inducesser": "indurre",
    "inducessero": "indurre",
    "inducessi": "indurre",
    "inducessimo": "indurre",
    "induceste": "indurre",
    "inducesti": "indurre",
    "inducete": "indurre",
    "induceva": "indurre",
    "inducevamo": "indurre",
    "inducevan": "indurre",
    "inducevano": "indurre",
    "inducevate": "indurre",
    "inducevi": "indurre",
    "inducevo": "indurre",
    "induci": "indurre",
    "induciamo": "indurre",
    "induciate": "indurre",
    "induco": "indurre",
    "inducon": "indurre",
    "inducono": "indurre",
    "indugerai": "indugiare",
    "indugeran": "indugiare",
    "indugeranno": "indugiare",
    "indugerebbe": "indugiare",
    "indugerebber": "indugiare",
    "indugerebbero": "indugiare",
    "indugerei": "indugiare",
    "indugeremmo": "indugiare",
    "indugeremo": "indugiare",
    "indugereste": "indugiare",
    "indugeresti": "indugiare",
    "indugerete": "indugiare",
    "indugerà": "indugiare",
    "indugerò": "indugiare",
    "indugi": "indugio",
    "indugia": "indugiare",
    "indugiai": "indugiare",
    "indugiammo": "indugiare",
    "indugiamo": "indugiare",
    "indugian": "indugiare",
    "indugiando": "indugiare",
    "indugiano": "indugiare",
    "indugiante": "indugiare",
    "indugianti": "indugiare",
    "indugiar": "indugiare",
    "indugiaron": "indugiare",
    "indugiarono": "indugiare",
    "indugiasse": "indugiare",
    "indugiasser": "indugiare",
    "indugiassero": "indugiare",
    "indugiassi": "indugiare",
    "indugiassimo": "indugiare",
    "indugiaste": "indugiare",
    "indugiasti": "indugiare",
    "indugiata": "indugiare",
    "indugiate": "indugiare",
    "indugiati": "indugiare",
    "indugiato": "indugiare",
    "indugiava": "indugiare",
    "indugiavamo": "indugiare",
    "indugiavan": "indugiare",
    "indugiavano": "indugiare",
    "indugiavate": "indugiare",
    "indugiavi": "indugiare",
    "indugiavo": "indugiare",
    "indugin": "indugiare",
    "indugino": "indugiare",
    "indugio": "indugiare",
    "indugiò": "indugiare",
    "indulga": "indulgere",
    "indulgan": "indulgere",
    "indulgano": "indulgere",
    "indulge": "indulgere",
    "indulgei": "indulgere",
    "indulgemmo": "indulgere",
    "indulgendo": "indulgere",
    "indulgente": "indulgere",
    "indulgenti": "indulgere",
    "indulgenze": "indulgenza",
    "indulger": "indulgere",
    "indulgerai": "indulgere",
    "indulgeran": "indulgere",
    "indulgeranno": "indulgere",
    "indulgerebbe": "indulgere",
    "indulgerebber": "indulgere",
    "indulgerebbero": "indulgere",
    "indulgerei": "indulgere",
    "indulgeremmo": "indulgere",
    "indulgeremo": "indulgere",
    "indulgereste": "indulgere",
    "indulgeresti": "indulgere",
    "indulgerete": "indulgere",
    "indulgeron": "indulgere",
    "indulgerono": "indulgere",
    "indulgerà": "indulgere",
    "indulgerò": "indulgere",
    "indulgesse": "indulgere",
    "indulgesser": "indulgere",
    "indulgessero": "indulgere",
    "indulgessi": "indulgere",
    "indulgessimo": "indulgere",
    "indulgeste": "indulgere",
    "indulgesti": "indulgere",
    "indulgete": "indulgere",
    "indulgeva": "indulgere",
    "indulgevamo": "indulgere",
    "indulgevan": "indulgere",
    "indulgevano": "indulgere",
    "indulgevate": "indulgere",
    "indulgevi": "indulgere",
    "indulgevo": "indulgere",
    "indulgi": "indulgere",
    "indulgiamo": "indulgere",
    "indulgiate": "indulgere",
    "indulgo": "indulgere",
    "indulgon": "indulgere",
    "indulgono": "indulgere",
    "indulgè": "indulgere",
    "indulta": "indulgere",
    "indulte": "indulgere",
    "indulti": "indulto",
    "indulto": "indulgere",
    "indumenti": "indumento",
    "indurendo": "indurire",
    "indurente": "indurire",
    "indurenti": "indurire",
    "induriamo": "indurire",
    "induriate": "indurire",
    "indurii": "indurire",
    "indurimenti": "indurimento",
    "indurimmo": "indurire",
    "indurir": "indurire",
    "indurirai": "indurire",
    "induriran": "indurire",
    "induriranno": "indurire",
    "indurirebbe": "indurire",
    "indurirebber": "indurire",
    "indurirebbero": "indurire",
    "indurirei": "indurire",
    "induriremmo": "indurire",
    "induriremo": "indurire",
    "indurireste": "indurire",
    "induriresti": "indurire",
    "indurirete": "indurire",
    "induriron": "indurire",
    "indurirono": "indurire",
    "indurirà": "indurire",
    "indurirò": "indurire",
    "indurisca": "indurire",
    "induriscan": "indurire",
    "induriscano": "indurire",
    "indurisce": "indurire",
    "indurisci": "indurire",
    "indurisco": "indurire",
    "induriscon": "indurire",
    "induriscono": "indurire",
    "indurisse": "indurire",
    "indurisser": "indurire",
    "indurissero": "indurire",
    "indurissi": "indurire",
    "indurissimo": "indurire",
    "induriste": "indurire",
    "induristi": "indurire",
    "indurita": "indurire",
    "indurite": "indurire",
    "induriti": "indurire",
    "indurito": "indurire",
    "induriva": "indurire",
    "indurivamo": "indurire",
    "indurivan": "indurire",
    "indurivano": "indurire",
    "indurivate": "indurire",
    "indurivi": "indurire",
    "indurivo": "indurire",
    "indurr": "indurre",
    "indurrai": "indurre",
    "indurran": "indurre",
    "indurranno": "indurre",
    "indurrebbe": "indurre",
    "indurrebber": "indurre",
    "indurrebbero": "indurre",
    "indurrei": "indurre",
    "indurremmo": "indurre",
    "indurremo": "indurre",
    "indurreste": "indurre",
    "indurresti": "indurre",
    "indurrete": "indurre",
    "indurrà": "indurre",
    "indurrò": "indurre",
    "indurì": "indurire",
    "indusse": "indurre",
    "indusser": "indurre",
    "indussero": "indurre",
    "indussi": "indurre",
    "industri": "industriare",
    "industria": "industriare",
    "industriai": "industriare",
    "industrial-operaistica": "industrial-operaistico",
    "industrial-operaistiche": "industrial-operaistico",
    "industrial-operaistici": "industrial-operaistico",
    "industriali": "industriale",
    "industrializza": "industrializzare",
    "industrializzabili": "industrializzabile",
    "industrializzai": "industrializzare",
    "industrializzammo": "industrializzare",
    "industrializzan": "industrializzare",
    "industrializzando": "industrializzare",
    "industrializzano": "industrializzare",
    "industrializzante": "industrializzare",
    "industrializzanti": "industrializzare",
    "industrializzar": "industrializzare",
    "industrializzaron": "industrializzare",
    "industrializzarono": "industrializzare",
    "industrializzasse": "industrializzare",
    "industrializzasser": "industrializzare",
    "industrializzassero": "industrializzare",
    "industrializzassi": "industrializzare",
    "industrializzassimo": "industrializzare",
    "industrializzaste": "industrializzare",
    "industrializzasti": "industrializzare",
    "industrializzata": "industrializzare",
    "industrializzate": "industrializzare",
    "industrializzati": "industrializzare",
    "industrializzato": "industrializzare",
    "industrializzava": "industrializzare",
    "industrializzavamo": "industrializzare",
    "industrializzavan": "industrializzare",
    "industrializzavano": "industrializzare",
    "industrializzavate": "industrializzare",
    "industrializzavi": "industrializzare",
    "industrializzavo": "industrializzare",
    "industrializzazioni": "industrializzazione",
    "industrializzerai": "industrializzare",
    "industrializzeran": "industrializzare",
    "industrializzeranno": "industrializzare",
    "industrializzerebbe": "industrializzare",
    "industrializzerebber": "industrializzare",
    "industrializzerebbero": "industrializzare",
    "industrializzerei": "industrializzare",
    "industrializzeremmo": "industrializzare",
    "industrializzeremo": "industrializzare",
    "industrializzereste": "industrializzare",
    "industrializzeresti": "industrializzare",
    "industrializzerete": "industrializzare",
    "industrializzerà": "industrializzare",
    "industrializzerò": "industrializzare",
    "industrializzi": "industrializzare",
    "industrializziamo": "industrializzare",
    "industrializziate": "industrializzare",
    "industrializzin": "industrializzare",
    "industrializzino": "industrializzare",
    "industrializzo": "industrializzare",
    "industrializzò": "industrializzare",
    "industrialotti": "industrialotto",
    "industriammo": "industriare",
    "industriamo": "industriare",
    "industrian": "industriare",
    "industriando": "industriare",
    "industriano": "industriare",
    "industriar": "industriare",
    "industriaron": "industriare",
    "industriarono": "industriare",
    "industriasse": "industriare",
    "industriasser": "industriare",
    "industriassero": "industriare",
    "industriassi": "industriare",
    "industriassimo": "industriare",
    "industriaste": "industriare",
    "industriasti": "industriare",
    "industriata": "industriare",
    "industriate": "industriare",
    "industriati": "industriare",
    "industriato": "industriare",
    "industriava": "industriare",
    "industriavamo": "industriare",
    "industriavan": "industriare",
    "industriavano": "industriare",
    "industriavate": "industriare",
    "industriavi": "industriare",
    "industriavo": "industriare",
    "industrie": "industria",
    "industrierai": "industriare",
    "industrieran": "industriare",
    "industrieranno": "industriare",
    "industrierebbe": "industriare",
    "industrierebber": "industriare",
    "industrierebbero": "industriare",
    "industrierei": "industriare",
    "industrieremmo": "industriare",
    "industrieremo": "industriare",
    "industriereste": "industriare",
    "industrieresti": "industriare",
    "industrierete": "industriare",
    "industrierà": "industriare",
    "industrierò": "industriare",
    "industrin": "industriare",
    "industrino": "industriare",
    "industrio": "industriare",
    "industriosa": "industrioso",
    "industriose": "industrioso",
    "industriosi": "industrioso",
    "industriò": "industriare",
    "induttiva": "induttivo",
    "induttive": "induttivo",
    "induttivi": "induttivo",
    "induzioni": "induzione",
    "inebetendo": "inebetire",
    "inebetente": "inebetire",
    "inebetenti": "inebetire",
    "inebetiamo": "inebetire",
    "inebetiate": "inebetire",
    "inebetii": "inebetire",
    "inebetimmo": "inebetire",
    "inebetir": "inebetire",
    "inebetirai": "inebetire",
    "inebetiran": "inebetire",
    "inebetiranno": "inebetire",
    "inebetirebbe": "inebetire",
    "inebetirebber": "inebetire",
    "inebetirebbero": "inebetire",
    "inebetirei": "inebetire",
    "inebetiremmo": "inebetire",
    "inebetiremo": "inebetire",
    "inebetireste": "inebetire",
    "inebetiresti": "inebetire",
    "inebetirete": "inebetire",
    "inebetiron": "inebetire",
    "inebetirono": "inebetire",
    "inebetirà": "inebetire",
    "inebetirò": "inebetire",
    "inebetisca": "inebetire",
    "inebetiscan": "inebetire",
    "inebetiscano": "inebetire",
    "inebetisce": "inebetire",
    "inebetisci": "inebetire",
    "inebetisco": "inebetire",
    "inebetiscon": "inebetire",
    "inebetiscono": "inebetire",
    "inebetisse": "inebetire",
    "inebetisser": "inebetire",
    "inebetissero": "inebetire",
    "inebetissi": "inebetire",
    "inebetissimo": "inebetire",
    "inebetiste": "inebetire",
    "inebetisti": "inebetire",
    "inebetita": "inebetire",
    "inebetite": "inebetire",
    "inebetiti": "inebetire",
    "inebetito": "inebetire",
    "inebetiva": "inebetire",
    "inebetivamo": "inebetire",
    "inebetivan": "inebetire",
    "inebetivano": "inebetire",
    "inebetivate": "inebetire",
    "inebetivi": "inebetire",
    "inebetivo": "inebetire",
    "inebetì": "inebetire",
    "inebrianti": "inebriante",
    "ineccepibili": "ineccepibile",
    "inedita": "inedito",
    "inedite": "inedito",
    "inediti": "inedito",
    "ineffabili": "ineffabile",
    "inefficaci": "inefficace",
    "inefficienti": "inefficiente",
    "inefficienze": "inefficienza",
    "ineguagliabili": "ineguagliabile",
    "ineguaglianze": "ineguaglianza",
    "ineguali": "ineguale",
    "ineleganti": "inelegante",
    "ineludibili": "ineludibile",
    "ineluttabili": "ineluttabile",
    "inenarrabili": "inenarrabile",
    "inequivocabili": "inequivocabile",
    "inerenti": "inerente",
    "inermi": "inerme",
    "inerpica": "inerpicare",
    "inerpicai": "inerpicare",
    "inerpicammo": "inerpicare",
    "inerpican": "inerpicare",
    "inerpicando": "inerpicare",
    "inerpicano": "inerpicare",
    "inerpicar": "inerpicare",
    "inerpicaron": "inerpicare",
    "inerpicarono": "inerpicare",
    "inerpicasse": "inerpicare",
    "inerpicasser": "inerpicare",
    "inerpicassero": "inerpicare",
    "inerpicassi": "inerpicare",
    "inerpicassimo": "inerpicare",
    "inerpicaste": "inerpicare",
    "inerpicasti": "inerpicare",
    "inerpicata": "inerpicato",
    "inerpicate": "inerpicato",
    "inerpicati": "inerpicato",
    "inerpicato": "inerpicare",
    "inerpicava": "inerpicare",
    "inerpicavamo": "inerpicare",
    "inerpicavan": "inerpicare",
    "inerpicavano": "inerpicare",
    "inerpicavate": "inerpicare",
    "inerpicavi": "inerpicare",
    "inerpicavo": "inerpicare",
    "inerpicherai": "inerpicare",
    "inerpicheran": "inerpicare",
    "inerpicheranno": "inerpicare",
    "inerpicherebbe": "inerpicare",
    "inerpicherebber": "inerpicare",
    "inerpicherebbero": "inerpicare",
    "inerpicherei": "inerpicare",
    "inerpicheremmo": "inerpicare",
    "inerpicheremo": "inerpicare",
    "inerpichereste": "inerpicare",
    "inerpicheresti": "inerpicare",
    "inerpicherete": "inerpicare",
    "inerpicherà": "inerpicare",
    "inerpicherò": "inerpicare",
    "inerpichi": "inerpicare",
    "inerpichiamo": "inerpicare",
    "inerpichiate": "inerpicare",
    "inerpichin": "inerpicare",
    "inerpichino": "inerpicare",
    "inerpico": "inerpicare",
    "inerpicò": "inerpicare",
    "inerti": "inerte",
    "inerziali": "inerziale",
    "inerzie": "inerzia",
    "inesatta": "inesatto",
    "inesatte": "inesatto",
    "inesattezze": "inesattezza",
    "inesatti": "inesatto",
    "inesaudita": "inesaudito",
    "inesaudite": "inesaudito",
    "inesauditi": "inesaudito",
    "inesauribili": "inesauribile",
    "inesausta": "inesausto",
    "inesauste": "inesausto",
    "inesausti": "inesausto",
    "inesigibili": "inesigibile",
    "inesistenti": "inesistente",
    "inesistenze": "inesistenza",
    "inesorabili": "inesorabile",
    "inesperienze": "inesperienza",
    "inesperta": "inesperto",
    "inesperte": "inesperto",
    "inesperti": "inesperto",
    "inesplicabili": "inesplicabile",
    "inesplorata": "inesplorato",
    "inesplorate": "inesplorato",
    "inesplorati": "inesplorato",
    "inesplosa": "inesploso",
    "inesplose": "inesploso",
    "inesplosi": "inesploso",
    "inespressa": "inespresso",
    "inespresse": "inespresso",
    "inespressi": "inespresso",
    "inespressiva": "inespressivo",
    "inespressive": "inespressivo",
    "inespressivi": "inespressivo",
    "inesprimibili": "inesprimibile",
    "inespugnabili": "inespugnabile",
    "inestetismi": "inestetismo",
    "inestimabili": "inestimabile",
    "inestinguibili": "inestinguibile",
    "inestirpabili": "inestirpabile",
    "inestricabili": "inestricabile",
    "inetta": "inetto",
    "inette": "inetto",
    "inetti": "inetto",
    "inettitudini": "inettitudine",
    "inevasa": "inevaso",
    "inevase": "inevaso",
    "inevasi": "inevaso",
    "inevitabili": "inevitabile",
    "inezie": "inezia",
    "infagotta": "infagottare",
    "infagottai": "infagottare",
    "infagottammo": "infagottare",
    "infagottan": "infagottare",
    "infagottando": "infagottare",
    "infagottano": "infagottare",
    "infagottante": "infagottare",
    "infagottanti": "infagottare",
    "infagottar": "infagottare",
    "infagottaron": "infagottare",
    "infagottarono": "infagottare",
    "infagottasse": "infagottare",
    "infagottasser": "infagottare",
    "infagottassero": "infagottare",
    "infagottassi": "infagottare",
    "infagottassimo": "infagottare",
    "infagottaste": "infagottare",
    "infagottasti": "infagottare",
    "infagottata": "infagottare",
    "infagottate": "infagottare",
    "infagottati": "infagottare",
    "infagottato": "infagottare",
    "infagottava": "infagottare",
    "infagottavamo": "infagottare",
    "infagottavan": "infagottare",
    "infagottavano": "infagottare",
    "infagottavate": "infagottare",
    "infagottavi": "infagottare",
    "infagottavo": "infagottare",
    "infagotterai": "infagottare",
    "infagotteran": "infagottare",
    "infagotteranno": "infagottare",
    "infagotterebbe": "infagottare",
    "infagotterebber": "infagottare",
    "infagotterebbero": "infagottare",
    "infagotterei": "infagottare",
    "infagotteremmo": "infagottare",
    "infagotteremo": "infagottare",
    "infagottereste": "infagottare",
    "infagotteresti": "infagottare",
    "infagotterete": "infagottare",
    "infagotterà": "infagottare",
    "infagotterò": "infagottare",
    "infagotti": "infagottare",
    "infagottiamo": "infagottare",
    "infagottiate": "infagottare",
    "infagottin": "infagottare",
    "infagottino": "infagottare",
    "infagotto": "infagottare",
    "infagottò": "infagottare",
    "infallibili": "infallibile",
    "infama": "infamare",
    "infamai": "infamare",
    "infamammo": "infamare",
    "infaman": "infamare",
    "infamando": "infamare",
    "infamano": "infamare",
    "infamante": "infamare",
    "infamanti": "infamare",
    "infamar": "infamare",
    "infamaron": "infamare",
    "infamarono": "infamare",
    "infamasse": "infamare",
    "infamasser": "infamare",
    "infamassero": "infamare",
    "infamassi": "infamare",
    "infamassimo": "infamare",
    "infamaste": "infamare",
    "infamasti": "infamare",
    "infamata": "infamare",
    "infamate": "infamare",
    "infamati": "infamare",
    "infamato": "infamare",
    "infamava": "infamare",
    "infamavamo": "infamare",
    "infamavan": "infamare",
    "infamavano": "infamare",
    "infamavate": "infamare",
    "infamavi": "infamare",
    "infamavo": "infamare",
    "infamerai": "infamare",
    "infameran": "infamare",
    "infameranno": "infamare",
    "infamerebbe": "infamare",
    "infamerebber": "infamare",
    "infamerebbero": "infamare",
    "infamerei": "infamare",
    "infameremmo": "infamare",
    "infameremo": "infamare",
    "infamereste": "infamare",
    "infameresti": "infamare",
    "infamerete": "infamare",
    "infamerà": "infamare",
    "infamerò": "infamare",
    "infami": "infame",
    "infamiamo": "infamare",
    "infamiate": "infamare",
    "infamie": "infamia",
    "infamin": "infamare",
    "infamino": "infamare",
    "infamo": "infamare",
    "infamò": "infamare",
    "infanga": "infangare",
    "infangai": "infangare",
    "infangammo": "infangare",
    "infangan": "infangare",
    "infangando": "infangare",
    "infangano": "infangare",
    "infangante": "infangare",
    "infanganti": "infangare",
    "infangar": "infangare",
    "infangaron": "infangare",
    "infangarono": "infangare",
    "infangasse": "infangare",
    "infangasser": "infangare",
    "infangassero": "infangare",
    "infangassi": "infangare",
    "infangassimo": "infangare",
    "infangaste": "infangare",
    "infangasti": "infangare",
    "infangata": "infangare",
    "infangate": "infangare",
    "infangati": "infangare",
    "infangato": "infangare",
    "infangava": "infangare",
    "infangavamo": "infangare",
    "infangavan": "infangare",
    "infangavano": "infangare",
    "infangavate": "infangare",
    "infangavi": "infangare",
    "infangavo": "infangare",
    "infangherai": "infangare",
    "infangheran": "infangare",
    "infangheranno": "infangare",
    "infangherebbe": "infangare",
    "infangherebber": "infangare",
    "infangherebbero": "infangare",
    "infangherei": "infangare",
    "infangheremmo": "infangare",
    "infangheremo": "infangare",
    "infanghereste": "infangare",
    "infangheresti": "infangare",
    "infangherete": "infangare",
    "infangherà": "infangare",
    "infangherò": "infangare",
    "infanghi": "infangare",
    "infanghiamo": "infangare",
    "infanghiate": "infangare",
    "infanghin": "infangare",
    "infanghino": "infangare",
    "infango": "infangare",
    "infangò": "infangare",
    "infanti": "infante",
    "infanticidi": "infanticidio",
    "infantili": "infantile",
    "infantilismi": "infantilismo",
    "infanzie": "infanzia",
    "infarca": "infarcire",
    "infarcan": "infarcire",
    "infarcano": "infarcire",
    "infarce": "infarcire",
    "infarcendo": "infarcire",
    "infarcente": "infarcire",
    "infarcenti": "infarcire",
    "infarci": "infarcire",
    "infarciamo": "infarcire",
    "infarciate": "infarcire",
    "infarcii": "infarcire",
    "infarcimmo": "infarcire",
    "infarcir": "infarcire",
    "infarcirai": "infarcire",
    "infarciran": "infarcire",
    "infarciranno": "infarcire",
    "infarcirebbe": "infarcire",
    "infarcirebber": "infarcire",
    "infarcirebbero": "infarcire",
    "infarcirei": "infarcire",
    "infarciremmo": "infarcire",
    "infarciremo": "infarcire",
    "infarcireste": "infarcire",
    "infarciresti": "infarcire",
    "infarcirete": "infarcire",
    "infarciron": "infarcire",
    "infarcirono": "infarcire",
    "infarcirà": "infarcire",
    "infarcirò": "infarcire",
    "infarcisse": "infarcire",
    "infarcisser": "infarcire",
    "infarcissero": "infarcire",
    "infarcissi": "infarcire",
    "infarcissimo": "infarcire",
    "infarciste": "infarcire",
    "infarcisti": "infarcire",
    "infarcita": "infarcire",
    "infarcite": "infarcire",
    "infarciti": "infarcire",
    "infarcito": "infarcire",
    "infarciva": "infarcire",
    "infarcivamo": "infarcire",
    "infarcivan": "infarcire",
    "infarcivano": "infarcire",
    "infarcivate": "infarcire",
    "infarcivi": "infarcire",
    "infarcivo": "infarcire",
    "infarco": "infarcire",
    "infarcon": "infarcire",
    "infarcono": "infarcire",
    "infarcì": "infarcire",
    "infarina": "infarinare",
    "infarinai": "infarinare",
    "infarinammo": "infarinare",
    "infarinan": "infarinare",
    "infarinando": "infarinare",
    "infarinano": "infarinare",
    "infarinante": "infarinare",
    "infarinanti": "infarinare",
    "infarinar": "infarinare",
    "infarinaron": "infarinare",
    "infarinarono": "infarinare",
    "infarinasse": "infarinare",
    "infarinasser": "infarinare",
    "infarinassero": "infarinare",
    "infarinassi": "infarinare",
    "infarinassimo": "infarinare",
    "infarinaste": "infarinare",
    "infarinasti": "infarinare",
    "infarinata": "infarinare",
    "infarinate": "infarinare",
    "infarinati": "infarinare",
    "infarinato": "infarinare",
    "infarinava": "infarinare",
    "infarinavamo": "infarinare",
    "infarinavan": "infarinare",
    "infarinavano": "infarinare",
    "infarinavate": "infarinare",
    "infarinavi": "infarinare",
    "infarinavo": "infarinare",
    "infarinerai": "infarinare",
    "infarineran": "infarinare",
    "infarineranno": "infarinare",
    "infarinerebbe": "infarinare",
    "infarinerebber": "infarinare",
    "infarinerebbero": "infarinare",
    "infarinerei": "infarinare",
    "infarineremmo": "infarinare",
    "infarineremo": "infarinare",
    "infarinereste": "infarinare",
    "infarineresti": "infarinare",
    "infarinerete": "infarinare",
    "infarinerà": "infarinare",
    "infarinerò": "infarinare",
    "infarini": "infarinare",
    "infariniamo": "infarinare",
    "infariniate": "infarinare",
    "infarinin": "infarinare",
    "infarinino": "infarinare",
    "infarino": "infarinare",
    "infarinò": "infarinare",
    "infarti": "infarto",
    "infastidendo": "infastidire",
    "infastidente": "infastidire",
    "infastidenti": "infastidire",
    "infastidiamo": "infastidire",
    "infastidiate": "infastidire",
    "infastidii": "infastidire",
    "infastidimmo": "infastidire",
    "infastidir": "infastidire",
    "infastidirai": "infastidire",
    "infastidiran": "infastidire",
    "infastidiranno": "infastidire",
    "infastidirebbe": "infastidire",
    "infastidirebber": "infastidire",
    "infastidirebbero": "infastidire",
    "infastidirei": "infastidire",
    "infastidiremmo": "infastidire",
    "infastidiremo": "infastidire",
    "infastidireste": "infastidire",
    "infastidiresti": "infastidire",
    "infastidirete": "infastidire",
    "infastidiron": "infastidire",
    "infastidirono": "infastidire",
    "infastidirà": "infastidire",
    "infastidirò": "infastidire",
    "infastidisca": "infastidire",
    "infastidiscan": "infastidire",
    "infastidiscano": "infastidire",
    "infastidisce": "infastidire",
    "infastidisci": "infastidire",
    "infastidisco": "infastidire",
    "infastidiscon": "infastidire",
    "infastidiscono": "infastidire",
    "infastidisse": "infastidire",
    "infastidisser": "infastidire",
    "infastidissero": "infastidire",
    "infastidissi": "infastidire",
    "infastidissimo": "infastidire",
    "infastidiste": "infastidire",
    "infastidisti": "infastidire",
    "infastidita": "infastidire",
    "infastidite": "infastidire",
    "infastiditi": "infastidito",
    "infastidito": "infastidire",
    "infastidiva": "infastidire",
    "infastidivamo": "infastidire",
    "infastidivan": "infastidire",
    "infastidivano": "infastidire",
    "infastidivate": "infastidire",
    "infastidivi": "infastidire",
    "infastidivo": "infastidire",
    "infastidì": "infastidire",
    "infaticabili": "infaticabile",
    "infatua": "infatuare",
    "infatuai": "infatuare",
    "infatuammo": "infatuare",
    "infatuan": "infatuare",
    "infatuando": "infatuare",
    "infatuano": "infatuare",
    "infatuante": "infatuare",
    "infatuanti": "infatuare",
    "infatuar": "infatuare",
    "infatuaron": "infatuare",
    "infatuarono": "infatuare",
    "infatuasse": "infatuare",
    "infatuasser": "infatuare",
    "infatuassero": "infatuare",
    "infatuassi": "infatuare",
    "infatuassimo": "infatuare",
    "infatuaste": "infatuare",
    "infatuasti": "infatuare",
    "infatuata": "infatuare",
    "infatuate": "infatuare",
    "infatuati": "infatuare",
    "infatuato": "infatuare",
    "infatuava": "infatuare",
    "infatuavamo": "infatuare",
    "infatuavan": "infatuare",
    "infatuavano": "infatuare",
    "infatuavate": "infatuare",
    "infatuavi": "infatuare",
    "infatuavo": "infatuare",
    "infatuazioni": "infatuazione",
    "infatuerai": "infatuare",
    "infatueran": "infatuare",
    "infatueranno": "infatuare",
    "infatuerebbe": "infatuare",
    "infatuerebber": "infatuare",
    "infatuerebbero": "infatuare",
    "infatuerei": "infatuare",
    "infatueremmo": "infatuare",
    "infatueremo": "infatuare",
    "infatuereste": "infatuare",
    "infatueresti": "infatuare",
    "infatuerete": "infatuare",
    "infatuerà": "infatuare",
    "infatuerò": "infatuare",
    "infatui": "infatuare",
    "infatuiamo": "infatuare",
    "infatuiate": "infatuare",
    "infatuin": "infatuare",
    "infatuino": "infatuare",
    "infatuo": "infatuare",
    "infatuò": "infatuare",
    "infausta": "infausto",
    "infauste": "infausto",
    "infausti": "infausto",
    "infeconda": "infecondo",
    "infeconde": "infecondo",
    "infecondi": "infecondo",
    "infedeli": "infedele",
    "infelici": "infelice",
    "infeltra": "infeltrire",
    "infeltran": "infeltrire",
    "infeltrano": "infeltrire",
    "infeltre": "infeltrire",
    "infeltrendo": "infeltrire",
    "infeltrente": "infeltrire",
    "infeltrenti": "infeltrire",
    "infeltri": "infeltrire",
    "infeltriamo": "infeltrire",
    "infeltriate": "infeltrire",
    "infeltrii": "infeltrire",
    "infeltrimmo": "infeltrire",
    "infeltrir": "infeltrire",
    "infeltrirai": "infeltrire",
    "infeltriran": "infeltrire",
    "infeltriranno": "infeltrire",
    "infeltrirebbe": "infeltrire",
    "infeltrirebber": "infeltrire",
    "infeltrirebbero": "infeltrire",
    "infeltrirei": "infeltrire",
    "infeltriremmo": "infeltrire",
    "infeltriremo": "infeltrire",
    "infeltrireste": "infeltrire",
    "infeltriresti": "infeltrire",
    "infeltrirete": "infeltrire",
    "infeltriron": "infeltrire",
    "infeltrirono": "infeltrire",
    "infeltrirà": "infeltrire",
    "infeltrirò": "infeltrire",
    "infeltrisse": "infeltrire",
    "infeltrisser": "infeltrire",
    "infeltrissero": "infeltrire",
    "infeltrissi": "infeltrire",
    "infeltrissimo": "infeltrire",
    "infeltriste": "infeltrire",
    "infeltristi": "infeltrire",
    "infeltrita": "infeltrire",
    "infeltrite": "infeltrire",
    "infeltriti": "infeltrire",
    "infeltrito": "infeltrire",
    "infeltriva": "infeltrire",
    "infeltrivamo": "infeltrire",
    "infeltrivan": "infeltrire",
    "infeltrivano": "infeltrire",
    "infeltrivate": "infeltrire",
    "infeltrivi": "infeltrire",
    "infeltrivo": "infeltrire",
    "infeltro": "infeltrire",
    "infeltron": "infeltrire",
    "infeltrono": "infeltrire",
    "infeltrì": "infeltrire",
    "infera": "inferire",
    "inferan": "inferire",
    "inferano": "inferire",
    "infere": "inferire",
    "inferendo": "inferire",
    "inferente": "inferire",
    "inferenti": "inferire",
    "inferenze": "inferenza",
    "inferi": "infero",
    "inferiamo": "inferire",
    "inferiate": "inferire",
    "inferii": "inferire",
    "inferimmo": "inferire",
    "inferiori": "inferiore",
    "inferir": "inferire",
    "inferirai": "inferire",
    "inferiran": "inferire",
    "inferiranno": "inferire",
    "inferirebbe": "inferire",
    "inferirebber": "inferire",
    "inferirebbero": "inferire",
    "inferirei": "inferire",
    "inferiremmo": "inferire",
    "inferiremo": "inferire",
    "inferireste": "inferire",
    "inferiresti": "inferire",
    "inferirete": "inferire",
    "inferiron": "inferire",
    "inferirono": "inferire",
    "inferirà": "inferire",
    "inferirò": "inferire",
    "inferisse": "inferire",
    "inferisser": "inferire",
    "inferissero": "inferire",
    "inferissi": "inferire",
    "inferissimo": "inferire",
    "inferiste": "inferire",
    "inferisti": "inferire",
    "inferita": "inferire",
    "inferite": "inferire",
    "inferiti": "inferire",
    "inferito": "inferire",
    "inferiva": "inferire",
    "inferivamo": "inferire",
    "inferivan": "inferire",
    "inferivano": "inferire",
    "inferivate": "inferire",
    "inferivi": "inferire",
    "inferivo": "inferire",
    "inferma": "infermo",
    "infermai": "infermare",
    "infermammo": "infermare",
    "inferman": "infermare",
    "infermando": "infermare",
    "infermano": "infermare",
    "infermante": "infermare",
    "infermanti": "infermare",
    "infermar": "infermare",
    "infermaron": "infermare",
    "infermarono": "infermare",
    "infermasse": "infermare",
    "infermasser": "infermare",
    "infermassero": "infermare",
    "infermassi": "infermare",
    "infermassimo": "infermare",
    "infermaste": "infermare",
    "infermasti": "infermare",
    "infermata": "infermare",
    "infermate": "infermare",
    "infermati": "infermare",
    "infermato": "infermare",
    "infermava": "infermare",
    "infermavamo": "infermare",
    "infermavan": "infermare",
    "infermavano": "infermare",
    "infermavate": "infermare",
    "infermavi": "infermare",
    "infermavo": "infermare",
    "inferme": "infermo",
    "infermerai": "infermare",
    "infermeran": "infermare",
    "infermeranno": "infermare",
    "infermerebbe": "infermare",
    "infermerebber": "infermare",
    "infermerebbero": "infermare",
    "infermerei": "infermare",
    "infermeremmo": "infermare",
    "infermeremo": "infermare",
    "infermereste": "infermare",
    "infermeresti": "infermare",
    "infermerete": "infermare",
    "infermerie": "infermeria",
    "infermerà": "infermare",
    "infermerò": "infermare",
    "infermi": "infermo",
    "infermiamo": "infermare",
    "infermiate": "infermare",
    "infermiere": "infermiera",
    "infermieri": "infermiere",
    "infermieristica": "infermieristico",
    "infermieristiche": "infermieristico",
    "infermieristici": "infermieristico",
    "infermin": "infermare",
    "infermino": "infermare",
    "infermo": "infermare",
    "infermò": "infermare",
    "infernali": "infernale",
    "inferni": "inferno",
    "infero": "inferire",
    "inferoca": "inferocire",
    "inferocan": "inferocire",
    "inferocano": "inferocire",
    "inferoce": "inferocire",
    "inferocendo": "inferocire",
    "inferocente": "inferocire",
    "inferocenti": "inferocire",
    "inferoci": "inferocire",
    "inferociamo": "inferocire",
    "inferociate": "inferocire",
    "inferocii": "inferocire",
    "inferocimmo": "inferocire",
    "inferocir": "inferocire",
    "inferocirai": "inferocire",
    "inferociran": "inferocire",
    "inferociranno": "inferocire",
    "inferocirebbe": "inferocire",
    "inferocirebber": "inferocire",
    "inferocirebbero": "inferocire",
    "inferocirei": "inferocire",
    "inferociremmo": "inferocire",
    "inferociremo": "inferocire",
    "inferocireste": "inferocire",
    "inferociresti": "inferocire",
    "inferocirete": "inferocire",
    "inferociron": "inferocire",
    "inferocirono": "inferocire",
    "inferocirà": "inferocire",
    "inferocirò": "inferocire",
    "inferocisse": "inferocire",
    "inferocisser": "inferocire",
    "inferocissero": "inferocire",
    "inferocissi": "inferocire",
    "inferocissimo": "inferocire",
    "inferociste": "inferocire",
    "inferocisti": "inferocire",
    "inferocita": "inferocire",
    "inferocite": "inferocire",
    "inferociti": "inferocire",
    "inferocito": "inferocire",
    "inferociva": "inferocire",
    "inferocivamo": "inferocire",
    "inferocivan": "inferocire",
    "inferocivano": "inferocire",
    "inferocivate": "inferocire",
    "inferocivi": "inferocire",
    "inferocivo": "inferocire",
    "inferoco": "inferocire",
    "inferocon": "inferocire",
    "inferocono": "inferocire",
    "inferocì": "inferocire",
    "inferon": "inferire",
    "inferono": "inferire",
    "inferriate": "inferriata",
    "inferta": "inferto",
    "inferte": "inferto",
    "inferti": "inferto",
    "infervora": "infervorare",
    "infervorai": "infervorare",
    "infervorammo": "infervorare",
    "infervoran": "infervorare",
    "infervorando": "infervorare",
    "infervorano": "infervorare",
    "infervorante": "infervorare",
    "infervoranti": "infervorare",
    "infervorar": "infervorare",
    "infervoraron": "infervorare",
    "infervorarono": "infervorare",
    "infervorasse": "infervorare",
    "infervorasser": "infervorare",
    "infervorassero": "infervorare",
    "infervorassi": "infervorare",
    "infervorassimo": "infervorare",
    "infervoraste": "infervorare",
    "infervorasti": "infervorare",
    "infervorata": "infervorare",
    "infervorate": "infervorare",
    "infervorati": "infervorare",
    "infervorato": "infervorare",
    "infervorava": "infervorare",
    "infervoravamo": "infervorare",
    "infervoravan": "infervorare",
    "infervoravano": "infervorare",
    "infervoravate": "infervorare",
    "infervoravi": "infervorare",
    "infervoravo": "infervorare",
    "infervorerai": "infervorare",
    "infervoreran": "infervorare",
    "infervoreranno": "infervorare",
    "infervorerebbe": "infervorare",
    "infervorerebber": "infervorare",
    "infervorerebbero": "infervorare",
    "infervorerei": "infervorare",
    "infervoreremmo": "infervorare",
    "infervoreremo": "infervorare",
    "infervorereste": "infervorare",
    "infervoreresti": "infervorare",
    "infervorerete": "infervorare",
    "infervorerà": "infervorare",
    "infervorerò": "infervorare",
    "infervori": "infervorare",
    "infervoriamo": "infervorare",
    "infervoriate": "infervorare",
    "infervorin": "infervorare",
    "infervorino": "infervorare",
    "infervoro": "infervorare",
    "infervorò": "infervorare",
    "inferì": "inferire",
    "infesta": "infestare",
    "infestai": "infestare",
    "infestammo": "infestare",
    "infestan": "infestare",
    "infestando": "infestare",
    "infestano": "infestare",
    "infestante": "infestare",
    "infestanti": "infestare",
    "infestar": "infestare",
    "infestaron": "infestare",
    "infestarono": "infestare",
    "infestasse": "infestare",
    "infestasser": "infestare",
    "infestassero": "infestare",
    "infestassi": "infestare",
    "infestassimo": "infestare",
    "infestaste": "infestare",
    "infestasti": "infestare",
    "infestata": "infestare",
    "infestate": "infestare",
    "infestati": "infestare",
    "infestato": "infestare",
    "infestava": "infestare",
    "infestavamo": "infestare",
    "infestavan": "infestare",
    "infestavano": "infestare",
    "infestavate": "infestare",
    "infestavi": "infestare",
    "infestavo": "infestare",
    "infesterai": "infestare",
    "infesteran": "infestare",
    "infesteranno": "infestare",
    "infesterebbe": "infestare",
    "infesterebber": "infestare",
    "infesterebbero": "infestare",
    "infesterei": "infestare",
    "infesteremmo": "infestare",
    "infesteremo": "infestare",
    "infestereste": "infestare",
    "infesteresti": "infestare",
    "infesterete": "infestare",
    "infesterà": "infestare",
    "infesterò": "infestare",
    "infesti": "infestare",
    "infestiamo": "infestare",
    "infestiate": "infestare",
    "infestin": "infestare",
    "infestino": "infestare",
    "infesto": "infestare",
    "infestò": "infestare",
    "infetta": "infetto",
    "infettai": "infettare",
    "infettammo": "infettare",
    "infettan": "infettare",
    "infettando": "infettare",
    "infettano": "infettare",
    "infettante": "infettare",
    "infettanti": "infettare",
    "infettar": "infettare",
    "infettaron": "infettare",
    "infettarono": "infettare",
    "infettasse": "infettare",
    "infettasser": "infettare",
    "infettassero": "infettare",
    "infettassi": "infettare",
    "infettassimo": "infettare",
    "infettaste": "infettare",
    "infettasti": "infettare",
    "infettata": "infettare",
    "infettate": "infettare",
    "infettati": "infettare",
    "infettato": "infettare",
    "infettava": "infettare",
    "infettavamo": "infettare",
    "infettavan": "infettare",
    "infettavano": "infettare",
    "infettavate": "infettare",
    "infettavi": "infettare",
    "infettavo": "infettare",
    "infette": "infetto",
    "infetterai": "infettare",
    "infetteran": "infettare",
    "infetteranno": "infettare",
    "infetterebbe": "infettare",
    "infetterebber": "infettare",
    "infetterebbero": "infettare",
    "infetterei": "infettare",
    "infetteremmo": "infettare",
    "infetteremo": "infettare",
    "infettereste": "infettare",
    "infetteresti": "infettare",
    "infetterete": "infettare",
    "infetterà": "infettare",
    "infetterò": "infettare",
    "infetti": "infetto",
    "infettiamo": "infettare",
    "infettiate": "infettare",
    "infettin": "infettare",
    "infettino": "infettare",
    "infettiva": "infettivo",
    "infettive": "infettivo",
    "infettivi": "infettivo",
    "infetto": "infettare",
    "infettò": "infettare",
    "infeuda": "infeudare",
    "infeudai": "infeudare",
    "infeudammo": "infeudare",
    "infeudan": "infeudare",
    "infeudando": "infeudare",
    "infeudano": "infeudare",
    "infeudante": "infeudare",
    "infeudanti": "infeudare",
    "infeudar": "infeudare",
    "infeudaron": "infeudare",
    "infeudarono": "infeudare",
    "infeudasse": "infeudare",
    "infeudasser": "infeudare",
    "infeudassero": "infeudare",
    "infeudassi": "infeudare",
    "infeudassimo": "infeudare",
    "infeudaste": "infeudare",
    "infeudasti": "infeudare",
    "infeudata": "infeudare",
    "infeudate": "infeudare",
    "infeudati": "infeudare",
    "infeudato": "infeudare",
    "infeudava": "infeudare",
    "infeudavamo": "infeudare",
    "infeudavan": "infeudare",
    "infeudavano": "infeudare",
    "infeudavate": "infeudare",
    "infeudavi": "infeudare",
    "infeudavo": "infeudare",
    "infeuderai": "infeudare",
    "infeuderan": "infeudare",
    "infeuderanno": "infeudare",
    "infeuderebbe": "infeudare",
    "infeuderebber": "infeudare",
    "infeuderebbero": "infeudare",
    "infeuderei": "infeudare",
    "infeuderemmo": "infeudare",
    "infeuderemo": "infeudare",
    "infeudereste": "infeudare",
    "infeuderesti": "infeudare",
    "infeuderete": "infeudare",
    "infeuderà": "infeudare",
    "infeuderò": "infeudare",
    "infeudi": "infeudare",
    "infeudiamo": "infeudare",
    "infeudiate": "infeudare",
    "infeudin": "infeudare",
    "infeudino": "infeudare",
    "infeudo": "infeudare",
    "infeudò": "infeudare",
    "infezioni": "infezione",
    "infiacchendo": "infiacchire",
    "infiacchente": "infiacchire",
    "infiacchenti": "infiacchire",
    "infiacchiamo": "infiacchire",
    "infiacchiate": "infiacchire",
    "infiacchii": "infiacchire",
    "infiacchimmo": "infiacchire",
    "infiacchir": "infiacchire",
    "infiacchirai": "infiacchire",
    "infiacchiran": "infiacchire",
    "infiacchiranno": "infiacchire",
    "infiacchirebbe": "infiacchire",
    "infiacchirebber": "infiacchire",
    "infiacchirebbero": "infiacchire",
    "infiacchirei": "infiacchire",
    "infiacchiremmo": "infiacchire",
    "infiacchiremo": "infiacchire",
    "infiacchireste": "infiacchire",
    "infiacchiresti": "infiacchire",
    "infiacchirete": "infiacchire",
    "infiacchiron": "infiacchire",
    "infiacchirono": "infiacchire",
    "infiacchirà": "infiacchire",
    "infiacchirò": "infiacchire",
    "infiacchisca": "infiacchire",
    "infiacchiscan": "infiacchire",
    "infiacchiscano": "infiacchire",
    "infiacchisce": "infiacchire",
    "infiacchisci": "infiacchire",
    "infiacchisco": "infiacchire",
    "infiacchiscon": "infiacchire",
    "infiacchiscono": "infiacchire",
    "infiacchisse": "infiacchire",
    "infiacchisser": "infiacchire",
    "infiacchissero": "infiacchire",
    "infiacchissi": "infiacchire",
    "infiacchissimo": "infiacchire",
    "infiacchiste": "infiacchire",
    "infiacchisti": "infiacchire",
    "infiacchita": "infiacchire",
    "infiacchite": "infiacchire",
    "infiacchiti": "infiacchire",
    "infiacchito": "infiacchire",
    "infiacchiva": "infiacchire",
    "infiacchivamo": "infiacchire",
    "infiacchivan": "infiacchire",
    "infiacchivano": "infiacchire",
    "infiacchivate": "infiacchire",
    "infiacchivi": "infiacchire",
    "infiacchivo": "infiacchire",
    "infiacchì": "infiacchire",
    "infiala": "infialare",
    "infialai": "infialare",
    "infialammo": "infialare",
    "infialan": "infialare",
    "infialando": "infialare",
    "infialano": "infialare",
    "infialante": "infialare",
    "infialanti": "infialare",
    "infialar": "infialare",
    "infialaron": "infialare",
    "infialarono": "infialare",
    "infialasse": "infialare",
    "infialasser": "infialare",
    "infialassero": "infialare",
    "infialassi": "infialare",
    "infialassimo": "infialare",
    "infialaste": "infialare",
    "infialasti": "infialare",
    "infialata": "infialare",
    "infialate": "infialare",
    "infialati": "infialare",
    "infialato": "infialare",
    "infialava": "infialare",
    "infialavamo": "infialare",
    "infialavan": "infialare",
    "infialavano": "infialare",
    "infialavate": "infialare",
    "infialavi": "infialare",
    "infialavo": "infialare",
    "infialerai": "infialare",
    "infialeran": "infialare",
    "infialeranno": "infialare",
    "infialerebbe": "infialare",
    "infialerebber": "infialare",
    "infialerebbero": "infialare",
    "infialerei": "infialare",
    "infialeremmo": "infialare",
    "infialeremo": "infialare",
    "infialereste": "infialare",
    "infialeresti": "infialare",
    "infialerete": "infialare",
    "infialerà": "infialare",
    "infialerò": "infialare",
    "infiali": "infialare",
    "infialiamo": "infialare",
    "infialiate": "infialare",
    "infialin": "infialare",
    "infialino": "infialare",
    "infialo": "infialare",
    "infialò": "infialare",
    "infiamma": "infiammare",
    "infiammabili": "infiammabile",
    "infiammai": "infiammare",
    "infiammammo": "infiammare",
    "infiamman": "infiammare",
    "infiammando": "infiammare",
    "infiammano": "infiammare",
    "infiammante": "infiammare",
    "infiammanti": "infiammare",
    "infiammar": "infiammare",
    "infiammaron": "infiammare",
    "infiammarono": "infiammare",
    "infiammasse": "infiammare",
    "infiammasser": "infiammare",
    "infiammassero": "infiammare",
    "infiammassi": "infiammare",
    "infiammassimo": "infiammare",
    "infiammaste": "infiammare",
    "infiammasti": "infiammare",
    "infiammata": "infiammare",
    "infiammate": "infiammare",
    "infiammati": "infiammare",
    "infiammato": "infiammare",
    "infiammatori": "infiammatorio",
    "infiammatoria": "infiammatorio",
    "infiammatorie": "infiammatorio",
    "infiammava": "infiammare",
    "infiammavamo": "infiammare",
    "infiammavan": "infiammare",
    "infiammavano": "infiammare",
    "infiammavate": "infiammare",
    "infiammavi": "infiammare",
    "infiammavo": "infiammare",
    "infiammazioni": "infiammazione",
    "infiammerai": "infiammare",
    "infiammeran": "infiammare",
    "infiammeranno": "infiammare",
    "infiammerebbe": "infiammare",
    "infiammerebber": "infiammare",
    "infiammerebbero": "infiammare",
    "infiammerei": "infiammare",
    "infiammeremmo": "infiammare",
    "infiammeremo": "infiammare",
    "infiammereste": "infiammare",
    "infiammeresti": "infiammare",
    "infiammerete": "infiammare",
    "infiammerà": "infiammare",
    "infiammerò": "infiammare",
    "infiammi": "infiammare",
    "infiammiamo": "infiammare",
    "infiammiate": "infiammare",
    "infiammin": "infiammare",
    "infiammino": "infiammare",
    "infiammo": "infiammare",
    "infiammò": "infiammare",
    "inficerai": "inficiare",
    "inficeran": "inficiare",
    "inficeranno": "inficiare",
    "inficerebbe": "inficiare",
    "inficerebber": "inficiare",
    "inficerebbero": "inficiare",
    "inficerei": "inficiare",
    "inficeremmo": "inficiare",
    "inficeremo": "inficiare",
    "inficereste": "inficiare",
    "inficeresti": "inficiare",
    "inficerete": "inficiare",
    "inficerà": "inficiare",
    "inficerò": "inficiare",
    "infici": "inficiare",
    "inficia": "inficiare",
    "inficiai": "inficiare",
    "inficiammo": "inficiare",
    "inficiamo": "inficiare",
    "infician": "inficiare",
    "inficiando": "inficiare",
    "inficiano": "inficiare",
    "inficiante": "inficiare",
    "inficianti": "inficiare",
    "inficiar": "inficiare",
    "inficiaron": "inficiare",
    "inficiarono": "inficiare",
    "inficiasse": "inficiare",
    "inficiasser": "inficiare",
    "inficiassero": "inficiare",
    "inficiassi": "inficiare",
    "inficiassimo": "inficiare",
    "inficiaste": "inficiare",
    "inficiasti": "inficiare",
    "inficiata": "inficiare",
    "inficiate": "inficiare",
    "inficiati": "inficiare",
    "inficiato": "inficiare",
    "inficiava": "inficiare",
    "inficiavamo": "inficiare",
    "inficiavan": "inficiare",
    "inficiavano": "inficiare",
    "inficiavate": "inficiare",
    "inficiavi": "inficiare",
    "inficiavo": "inficiare",
    "inficin": "inficiare",
    "inficino": "inficiare",
    "inficio": "inficiare",
    "inficiò": "inficiare",
    "infida": "infido",
    "infide": "infido",
    "infidi": "infido",
    "infierendo": "infierire",
    "infierente": "infierire",
    "infierenti": "infierire",
    "infieriamo": "infierire",
    "infieriate": "infierire",
    "infierii": "infierire",
    "infierimmo": "infierire",
    "infierir": "infierire",
    "infierirai": "infierire",
    "infieriran": "infierire",
    "infieriranno": "infierire",
    "infierirebbe": "infierire",
    "infierirebber": "infierire",
    "infierirebbero": "infierire",
    "infierirei": "infierire",
    "infieriremmo": "infierire",
    "infieriremo": "infierire",
    "infierireste": "infierire",
    "infieriresti": "infierire",
    "infierirete": "infierire",
    "infieriron": "infierire",
    "infierirono": "infierire",
    "infierirà": "infierire",
    "infierirò": "infierire",
    "infierisca": "infierire",
    "infieriscan": "infierire",
    "infieriscano": "infierire",
    "infierisce": "infierire",
    "infierisci": "infierire",
    "infierisco": "infierire",
    "infieriscon": "infierire",
    "infieriscono": "infierire",
    "infierisse": "infierire",
    "infierisser": "infierire",
    "infierissero": "infierire",
    "infierissi": "infierire",
    "infierissimo": "infierire",
    "infieriste": "infierire",
    "infieristi": "infierire",
    "infierita": "infierire",
    "infierite": "infierire",
    "infieriti": "infierire",
    "infierito": "infierire",
    "infieriva": "infierire",
    "infierivamo": "infierire",
    "infierivan": "infierire",
    "infierivano": "infierire",
    "infierivate": "infierire",
    "infierivi": "infierire",
    "infierivo": "infierire",
    "infierì": "infierire",
    "infigga": "infiggere",
    "infiggan": "infiggere",
    "infiggano": "infiggere",
    "infigge": "infiggere",
    "infiggemmo": "infiggere",
    "infiggendo": "infiggere",
    "infiggente": "infiggere",
    "infiggenti": "infiggere",
    "infigger": "infiggere",
    "infiggerai": "infiggere",
    "infiggeran": "infiggere",
    "infiggeranno": "infiggere",
    "infiggerebbe": "infiggere",
    "infiggerebber": "infiggere",
    "infiggerebbero": "infiggere",
    "infiggerei": "infiggere",
    "infiggeremmo": "infiggere",
    "infiggeremo": "infiggere",
    "infiggereste": "infiggere",
    "infiggeresti": "infiggere",
    "infiggerete": "infiggere",
    "infiggerà": "infiggere",
    "infiggerò": "infiggere",
    "infiggesse": "infiggere",
    "infiggesser": "infiggere",
    "infiggessero": "infiggere",
    "infiggessi": "infiggere",
    "infiggessimo": "infiggere",
    "infiggeste": "infiggere",
    "infiggesti": "infiggere",
    "infiggete": "infiggere",
    "infiggeva": "infiggere",
    "infiggevamo": "infiggere",
    "infiggevan": "infiggere",
    "infiggevano": "infiggere",
    "infiggevate": "infiggere",
    "infiggevi": "infiggere",
    "infiggevo": "infiggere",
    "infiggi": "infiggere",
    "infiggiamo": "infiggere",
    "infiggiate": "infiggere",
    "infiggo": "infiggere",
    "infiggon": "infiggere",
    "infiggono": "infiggere",
    "infila": "infilare",
    "infilai": "infilare",
    "infilammo": "infilare",
    "infilan": "infilare",
    "infilando": "infilare",
    "infilano": "infilare",
    "infilante": "infilare",
    "infilanti": "infilare",
    "infilar": "infilare",
    "infilaron": "infilare",
    "infilarono": "infilare",
    "infilasse": "infilare",
    "infilasser": "infilare",
    "infilassero": "infilare",
    "infilassi": "infilare",
    "infilassimo": "infilare",
    "infilaste": "infilare",
    "infilasti": "infilare",
    "infilata": "infilare",
    "infilate": "infilare",
    "infilati": "infilare",
    "infilato": "infilare",
    "infilava": "infilare",
    "infilavamo": "infilare",
    "infilavan": "infilare",
    "infilavano": "infilare",
    "infilavate": "infilare",
    "infilavi": "infilare",
    "infilavo": "infilare",
    "infilerai": "infilare",
    "infileran": "infilare",
    "infileranno": "infilare",
    "infilerebbe": "infilare",
    "infilerebber": "infilare",
    "infilerebbero": "infilare",
    "infilerei": "infilare",
    "infileremmo": "infilare",
    "infileremo": "infilare",
    "infilereste": "infilare",
    "infileresti": "infilare",
    "infilerete": "infilare",
    "infilerà": "infilare",
    "infilerò": "infilare",
    "infili": "infilare",
    "infiliamo": "infilare",
    "infiliate": "infilare",
    "infilin": "infilare",
    "infilino": "infilare",
    "infilo": "infilare",
    "infiltra": "infiltrarsi",
    "infiltrai": "infiltrarsi",
    "infiltrammo": "infiltrarsi",
    "infiltran": "infiltrarsi",
    "infiltrando": "infiltrare",
    "infiltrano": "infiltrarsi",
    "infiltrante": "infiltrare",
    "infiltranti": "infiltrare",
    "infiltrar": "infiltrare",
    "infiltraron": "infiltrarsi",
    "infiltrarono": "infiltrarsi",
    "infiltrasse": "infiltrarsi",
    "infiltrasser": "infiltrarsi",
    "infiltrassero": "infiltrarsi",
    "infiltrassi": "infiltrarsi",
    "infiltrassimo": "infiltrarsi",
    "infiltraste": "infiltrarsi",
    "infiltrasti": "infiltrarsi",
    "infiltrata": "infiltrare",
    "infiltrate": "infiltrarsi",
    "infiltrati": "infiltrarsi",
    "infiltrato": "infiltrare",
    "infiltrava": "infiltrarsi",
    "infiltravamo": "infiltrarsi",
    "infiltravan": "infiltrarsi",
    "infiltravano": "infiltrarsi",
    "infiltravate": "infiltrarsi",
    "infiltravi": "infiltrarsi",
    "infiltravo": "infiltrarsi",
    "infiltrazioni": "infiltrazione",
    "infiltrerai": "infiltrarsi",
    "infiltreran": "infiltrarsi",
    "infiltreranno": "infiltrarsi",
    "infiltrerebbe": "infiltrarsi",
    "infiltrerebber": "infiltrarsi",
    "infiltrerebbero": "infiltrarsi",
    "infiltrerei": "infiltrarsi",
    "infiltreremmo": "infiltrarsi",
    "infiltreremo": "infiltrarsi",
    "infiltrereste": "infiltrarsi",
    "infiltreresti": "infiltrarsi",
    "infiltrerete": "infiltrarsi",
    "infiltrerà": "infiltrarsi",
    "infiltrerò": "infiltrarsi",
    "infiltri": "infiltrarsi",
    "infiltriamo": "infiltrarsi",
    "infiltriate": "infiltrarsi",
    "infiltrin": "infiltrarsi",
    "infiltrino": "infiltrarsi",
    "infiltro": "infiltrarsi",
    "infiltrò": "infiltrarsi",
    "infilza": "infilzare",
    "infilzai": "infilzare",
    "infilzammo": "infilzare",
    "infilzan": "infilzare",
    "infilzando": "infilzare",
    "infilzano": "infilzare",
    "infilzante": "infilzare",
    "infilzanti": "infilzare",
    "infilzar": "infilzare",
    "infilzaron": "infilzare",
    "infilzarono": "infilzare",
    "infilzasse": "infilzare",
    "infilzasser": "infilzare",
    "infilzassero": "infilzare",
    "infilzassi": "infilzare",
    "infilzassimo": "infilzare",
    "infilzaste": "infilzare",
    "infilzasti": "infilzare",
    "infilzata": "infilzare",
    "infilzate": "infilzare",
    "infilzati": "infilzare",
    "infilzato": "infilzare",
    "infilzava": "infilzare",
    "infilzavamo": "infilzare",
    "infilzavan": "infilzare",
    "infilzavano": "infilzare",
    "infilzavate": "infilzare",
    "infilzavi": "infilzare",
    "infilzavo": "infilzare",
    "infilzerai": "infilzare",
    "infilzeran": "infilzare",
    "infilzeranno": "infilzare",
    "infilzerebbe": "infilzare",
    "infilzerebber": "infilzare",
    "infilzerebbero": "infilzare",
    "infilzerei": "infilzare",
    "infilzeremmo": "infilzare",
    "infilzeremo": "infilzare",
    "infilzereste": "infilzare",
    "infilzeresti": "infilzare",
    "infilzerete": "infilzare",
    "infilzerà": "infilzare",
    "infilzerò": "infilzare",
    "infilzi": "infilzare",
    "infilziamo": "infilzare",
    "infilziate": "infilzare",
    "infilzin": "infilzare",
    "infilzino": "infilzare",
    "infilzo": "infilzare",
    "infilzò": "infilzare",
    "infilò": "infilare",
    "infima": "infimo",
    "infime": "infimo",
    "infimi": "infimo",
    "infinga": "infingere",
    "infingan": "infingere",
    "infingano": "infingere",
    "infingarda": "infingardo",
    "infingarde": "infingardo",
    "infingardi": "infingardo",
    "infinge": "infingere",
    "infingemmo": "infingere",
    "infingendo": "infingere",
    "infinger": "infingere",
    "infingerai": "infingere",
    "infingeran": "infingere",
    "infingeranno": "infingere",
    "infingerebbe": "infingere",
    "infingerebber": "infingere",
    "infingerebbero": "infingere",
    "infingerei": "infingere",
    "infingeremmo": "infingere",
    "infingeremo": "infingere",
    "infingereste": "infingere",
    "infingeresti": "infingere",
    "infingerete": "infingere",
    "infingerà": "infingere",
    "infingerò": "infingere",
    "infingesse": "infingere",
    "infingesser": "infingere",
    "infingessero": "infingere",
    "infingessi": "infingere",
    "infingessimo": "infingere",
    "infingeste": "infingere",
    "infingesti": "infingere",
    "infingete": "infingere",
    "infingeva": "infingere",
    "infingevamo": "infingere",
    "infingevan": "infingere",
    "infingevano": "infingere",
    "infingevate": "infingere",
    "infingevi": "infingere",
    "infingevo": "infingere",
    "infingi": "infingere",
    "infingiamo": "infingere",
    "infingiate": "infingere",
    "infingimenti": "infingimento",
    "infingo": "infingere",
    "infingon": "infingere",
    "infingono": "infingere",
    "infinita": "infinito",
    "infinite": "infinito",
    "infinitesimali": "infinitesimale",
    "infiniti": "infinito",
    "infinocchi": "infinocchiare",
    "infinocchia": "infinocchiare",
    "infinocchiai": "infinocchiare",
    "infinocchiammo": "infinocchiare",
    "infinocchiamo": "infinocchiare",
    "infinocchian": "infinocchiare",
    "infinocchiando": "infinocchiare",
    "infinocchiano": "infinocchiare",
    "infinocchiante": "infinocchiare",
    "infinocchianti": "infinocchiare",
    "infinocchiar": "infinocchiare",
    "infinocchiaron": "infinocchiare",
    "infinocchiarono": "infinocchiare",
    "infinocchiasse": "infinocchiare",
    "infinocchiasser": "infinocchiare",
    "infinocchiassero": "infinocchiare",
    "infinocchiassi": "infinocchiare",
    "infinocchiassimo": "infinocchiare",
    "infinocchiaste": "infinocchiare",
    "infinocchiasti": "infinocchiare",
    "infinocchiata": "infinocchiare",
    "infinocchiate": "infinocchiare",
    "infinocchiati": "infinocchiare",
    "infinocchiato": "infinocchiare",
    "infinocchiava": "infinocchiare",
    "infinocchiavamo": "infinocchiare",
    "infinocchiavan": "infinocchiare",
    "infinocchiavano": "infinocchiare",
    "infinocchiavate": "infinocchiare",
    "infinocchiavi": "infinocchiare",
    "infinocchiavo": "infinocchiare",
    "infinocchierai": "infinocchiare",
    "infinocchieran": "infinocchiare",
    "infinocchieranno": "infinocchiare",
    "infinocchierebbe": "infinocchiare",
    "infinocchierebber": "infinocchiare",
    "infinocchierebbero": "infinocchiare",
    "infinocchierei": "infinocchiare",
    "infinocchieremmo": "infinocchiare",
    "infinocchieremo": "infinocchiare",
    "infinocchiereste": "infinocchiare",
    "infinocchieresti": "infinocchiare",
    "infinocchierete": "infinocchiare",
    "infinocchierà": "infinocchiare",
    "infinocchierò": "infinocchiare",
    "infinocchin": "infinocchiare",
    "infinocchino": "infinocchiare",
    "infinocchio": "infinocchiare",
    "infinocchiò": "infinocchiare",
    "infinser": "infingere",
    "infinsero": "infingere",
    "infinsi": "infingere",
    "infinsè": "infingere",
    "infinta": "infingere",
    "infinte": "infingere",
    "infinti": "infingere",
    "infinto": "infingere",
    "infiocchetta": "infiocchettare",
    "infiocchettai": "infiocchettare",
    "infiocchettammo": "infiocchettare",
    "infiocchettan": "infiocchettare",
    "infiocchettando": "infiocchettare",
    "infiocchettano": "infiocchettare",
    "infiocchettante": "infiocchettare",
    "infiocchettanti": "infiocchettare",
    "infiocchettar": "infiocchettare",
    "infiocchettaron": "infiocchettare",
    "infiocchettarono": "infiocchettare",
    "infiocchettasse": "infiocchettare",
    "infiocchettasser": "infiocchettare",
    "infiocchettassero": "infiocchettare",
    "infiocchettassi": "infiocchettare",
    "infiocchettassimo": "infiocchettare",
    "infiocchettaste": "infiocchettare",
    "infiocchettasti": "infiocchettare",
    "infiocchettata": "infiocchettare",
    "infiocchettate": "infiocchettare",
    "infiocchettati": "infiocchettare",
    "infiocchettato": "infiocchettare",
    "infiocchettava": "infiocchettare",
    "infiocchettavamo": "infiocchettare",
    "infiocchettavan": "infiocchettare",
    "infiocchettavano": "infiocchettare",
    "infiocchettavate": "infiocchettare",
    "infiocchettavi": "infiocchettare",
    "infiocchettavo": "infiocchettare",
    "infiocchetterai": "infiocchettare",
    "infiocchetteran": "infiocchettare",
    "infiocchetteranno": "infiocchettare",
    "infiocchetterebbe": "infiocchettare",
    "infiocchetterebber": "infiocchettare",
    "infiocchetterebbero": "infiocchettare",
    "infiocchetterei": "infiocchettare",
    "infiocchetteremmo": "infiocchettare",
    "infiocchetteremo": "infiocchettare",
    "infiocchettereste": "infiocchettare",
    "infiocchetteresti": "infiocchettare",
    "infiocchetterete": "infiocchettare",
    "infiocchetterà": "infiocchettare",
    "infiocchetterò": "infiocchettare",
    "infiocchetti": "infiocchettare",
    "infiocchettiamo": "infiocchettare",
    "infiocchettiate": "infiocchettare",
    "infiocchettin": "infiocchettare",
    "infiocchettino": "infiocchettare",
    "infiocchetto": "infiocchettare",
    "infiocchettò": "infiocchettare",
    "infiora": "infiorare",
    "infiorai": "infiorare",
    "infiorammo": "infiorare",
    "infioran": "infiorare",
    "infiorando": "infiorare",
    "infiorano": "infiorare",
    "infiorante": "infiorare",
    "infioranti": "infiorare",
    "infiorar": "infiorare",
    "infioraron": "infiorare",
    "infiorarono": "infiorare",
    "infiorasse": "infiorare",
    "infiorasser": "infiorare",
    "infiorassero": "infiorare",
    "infiorassi": "infiorare",
    "infiorassimo": "infiorare",
    "infioraste": "infiorare",
    "infiorasti": "infiorare",
    "infiorata": "infiorare",
    "infiorate": "infiorare",
    "infiorati": "infiorare",
    "infiorato": "infiorare",
    "infiorava": "infiorare",
    "infioravamo": "infiorare",
    "infioravan": "infiorare",
    "infioravano": "infiorare",
    "infioravate": "infiorare",
    "infioravi": "infiorare",
    "infioravo": "infiorare",
    "infiorerai": "infiorare",
    "infioreran": "infiorare",
    "infioreranno": "infiorare",
    "infiorerebbe": "infiorare",
    "infiorerebber": "infiorare",
    "infiorerebbero": "infiorare",
    "infiorerei": "infiorare",
    "infioreremmo": "infiorare",
    "infioreremo": "infiorare",
    "infiorereste": "infiorare",
    "infioreresti": "infiorare",
    "infiorerete": "infiorare",
    "infiorerà": "infiorare",
    "infiorerò": "infiorare",
    "infioretta": "infiorettare",
    "infiorettai": "infiorettare",
    "infiorettammo": "infiorettare",
    "infiorettan": "infiorettare",
    "infiorettando": "infiorettare",
    "infiorettano": "infiorettare",
    "infiorettante": "infiorettare",
    "infiorettanti": "infiorettare",
    "infiorettar": "infiorettare",
    "infiorettaron": "infiorettare",
    "infiorettarono": "infiorettare",
    "infiorettasse": "infiorettare",
    "infiorettasser": "infiorettare",
    "infiorettassero": "infiorettare",
    "infiorettassi": "infiorettare",
    "infiorettassimo": "infiorettare",
    "infiorettaste": "infiorettare",
    "infiorettasti": "infiorettare",
    "infiorettata": "infiorettare",
    "infiorettate": "infiorettare",
    "infiorettati": "infiorettare",
    "infiorettato": "infiorettare",
    "infiorettava": "infiorettare",
    "infiorettavamo": "infiorettare",
    "infiorettavan": "infiorettare",
    "infiorettavano": "infiorettare",
    "infiorettavate": "infiorettare",
    "infiorettavi": "infiorettare",
    "infiorettavo": "infiorettare",
    "infioretterai": "infiorettare",
    "infioretteran": "infiorettare",
    "infioretteranno": "infiorettare",
    "infioretterebbe": "infiorettare",
    "infioretterebber": "infiorettare",
    "infioretterebbero": "infiorettare",
    "infioretterei": "infiorettare",
    "infioretteremmo": "infiorettare",
    "infioretteremo": "infiorettare",
    "infiorettereste": "infiorettare",
    "infioretteresti": "infiorettare",
    "infioretterete": "infiorettare",
    "infioretterà": "infiorettare",
    "infioretterò": "infiorettare",
    "infioretti": "infiorettare",
    "infiorettiamo": "infiorettare",
    "infiorettiate": "infiorettare",
    "infiorettin": "infiorettare",
    "infiorettino": "infiorettare",
    "infioretto": "infiorettare",
    "infiorettò": "infiorettare",
    "infiori": "infiorare",
    "infioriamo": "infiorare",
    "infioriate": "infiorare",
    "infiorin": "infiorare",
    "infiorino": "infiorare",
    "infioro": "infiorare",
    "infiorò": "infiorare",
    "infirma": "infirmare",
    "infirmai": "infirmare",
    "infirmammo": "infirmare",
    "infirman": "infirmare",
    "infirmando": "infirmare",
    "infirmano": "infirmare",
    "infirmante": "infirmare",
    "infirmanti": "infirmare",
    "infirmar": "infirmare",
    "infirmaron": "infirmare",
    "infirmarono": "infirmare",
    "infirmasse": "infirmare",
    "infirmasser": "infirmare",
    "infirmassero": "infirmare",
    "infirmassi": "infirmare",
    "infirmassimo": "infirmare",
    "infirmaste": "infirmare",
    "infirmasti": "infirmare",
    "infirmata": "infirmare",
    "infirmate": "infirmare",
    "infirmati": "infirmare",
    "infirmato": "infirmare",
    "infirmava": "infirmare",
    "infirmavamo": "infirmare",
    "infirmavan": "infirmare",
    "infirmavano": "infirmare",
    "infirmavate": "infirmare",
    "infirmavi": "infirmare",
    "infirmavo": "infirmare",
    "infirmerai": "infirmare",
    "infirmeran": "infirmare",
    "infirmeranno": "infirmare",
    "infirmerebbe": "infirmare",
    "infirmerebber": "infirmare",
    "infirmerebbero": "infirmare",
    "infirmerei": "infirmare",
    "infirmeremmo": "infirmare",
    "infirmeremo": "infirmare",
    "infirmereste": "infirmare",
    "infirmeresti": "infirmare",
    "infirmerete": "infirmare",
    "infirmerà": "infirmare",
    "infirmerò": "infirmare",
    "infirmi": "infirmare",
    "infirmiamo": "infirmare",
    "infirmiate": "infirmare",
    "infirmin": "infirmare",
    "infirmino": "infirmare",
    "infirmo": "infirmare",
    "infirmò": "infirmare",
    "infischi": "infischiare",
    "infischia": "infischiare",
    "infischiai": "infischiare",
    "infischiammo": "infischiare",
    "infischiamo": "infischiare",
    "infischian": "infischiare",
    "infischiando": "infischiare",
    "infischiano": "infischiare",
    "infischiar": "infischiare",
    "infischiaron": "infischiare",
    "infischiarono": "infischiare",
    "infischiasse": "infischiare",
    "infischiasser": "infischiare",
    "infischiassero": "infischiare",
    "infischiassi": "infischiare",
    "infischiassimo": "infischiare",
    "infischiaste": "infischiare",
    "infischiasti": "infischiare",
    "infischiata": "infischiare",
    "infischiate": "infischiare",
    "infischiati": "infischiare",
    "infischiato": "infischiare",
    "infischiava": "infischiare",
    "infischiavamo": "infischiare",
    "infischiavan": "infischiare",
    "infischiavano": "infischiare",
    "infischiavate": "infischiare",
    "infischiavi": "infischiare",
    "infischiavo": "infischiare",
    "infischierai": "infischiare",
    "infischieran": "infischiare",
    "infischieranno": "infischiare",
    "infischierebbe": "infischiare",
    "infischierebber": "infischiare",
    "infischierebbero": "infischiare",
    "infischierei": "infischiare",
    "infischieremmo": "infischiare",
    "infischieremo": "infischiare",
    "infischiereste": "infischiare",
    "infischieresti": "infischiare",
    "infischierete": "infischiare",
    "infischierà": "infischiare",
    "infischierò": "infischiare",
    "infischin": "infischiare",
    "infischino": "infischiare",
    "infischio": "infischiare",
    "infischiò": "infischiare",
    "infisser": "infiggere",
    "infissero": "infiggere",
    "infissi": "infisso",
    "infissè": "infiggere",
    "infitta": "infiggere",
    "infitte": "infiggere",
    "infittendo": "infittire",
    "infittente": "infittire",
    "infittenti": "infittire",
    "infitti": "infiggere",
    "infittiamo": "infittire",
    "infittiate": "infittire",
    "infittii": "infittire",
    "infittimmo": "infittire",
    "infittir": "infittire",
    "infittirai": "infittire",
    "infittiran": "infittire",
    "infittiranno": "infittire",
    "infittirebbe": "infittire",
    "infittirebber": "infittire",
    "infittirebbero": "infittire",
    "infittirei": "infittire",
    "infittiremmo": "infittire",
    "infittiremo": "infittire",
    "infittireste": "infittire",
    "infittiresti": "infittire",
    "infittirete": "infittire",
    "infittiron": "infittire",
    "infittirono": "infittire",
    "infittirà": "infittire",
    "infittirò": "infittire",
    "infittisca": "infittire",
    "infittiscan": "infittire",
    "infittiscano": "infittire",
    "infittisce": "infittire",
    "infittisci": "infittire",
    "infittisco": "infittire",
    "infittiscon": "infittire",
    "infittiscono": "infittire",
    "infittisse": "infittire",
    "infittisser": "infittire",
    "infittissero": "infittire",
    "infittissi": "infittire",
    "infittissimo": "infittire",
    "infittiste": "infittire",
    "infittisti": "infittire",
    "infittita": "infittire",
    "infittite": "infittire",
    "infittiti": "infittire",
    "infittito": "infittire",
    "infittiva": "infittire",
    "infittivamo": "infittire",
    "infittivan": "infittire",
    "infittivano": "infittire",
    "infittivate": "infittire",
    "infittivi": "infittire",
    "infittivo": "infittire",
    "infitto": "infiggere",
    "infittì": "infittire",
    "inflaziona": "inflazionare",
    "inflazionai": "inflazionare",
    "inflazionammo": "inflazionare",
    "inflazionan": "inflazionare",
    "inflazionando": "inflazionare",
    "inflazionano": "inflazionare",
    "inflazionante": "inflazionare",
    "inflazionanti": "inflazionare",
    "inflazionar": "inflazionare",
    "inflazionaron": "inflazionare",
    "inflazionarono": "inflazionare",
    "inflazionasse": "inflazionare",
    "inflazionasser": "inflazionare",
    "inflazionassero": "inflazionare",
    "inflazionassi": "inflazionare",
    "inflazionassimo": "inflazionare",
    "inflazionaste": "inflazionare",
    "inflazionasti": "inflazionare",
    "inflazionata": "inflazionare",
    "inflazionate": "inflazionare",
    "inflazionati": "inflazionare",
    "inflazionato": "inflazionare",
    "inflazionava": "inflazionare",
    "inflazionavamo": "inflazionare",
    "inflazionavan": "inflazionare",
    "inflazionavano": "inflazionare",
    "inflazionavate": "inflazionare",
    "inflazionavi": "inflazionare",
    "inflazionavo": "inflazionare",
    "inflazionerai": "inflazionare",
    "inflazioneran": "inflazionare",
    "inflazioneranno": "inflazionare",
    "inflazionerebbe": "inflazionare",
    "inflazionerebber": "inflazionare",
    "inflazionerebbero": "inflazionare",
    "inflazionerei": "inflazionare",
    "inflazioneremmo": "inflazionare",
    "inflazioneremo": "inflazionare",
    "inflazionereste": "inflazionare",
    "inflazioneresti": "inflazionare",
    "inflazionerete": "inflazionare",
    "inflazionerà": "inflazionare",
    "inflazionerò": "inflazionare",
    "inflazioni": "inflazione",
    "inflazioniamo": "inflazionare",
    "inflazioniate": "inflazionare",
    "inflazionin": "inflazionare",
    "inflazionino": "inflazionare",
    "inflazionistica": "inflazionistico",
    "inflazionistiche": "inflazionistico",
    "inflazionistici": "inflazionistico",
    "inflaziono": "inflazionare",
    "inflazionò": "inflazionare",
    "inflessibili": "inflessibile",
    "inflessioni": "inflessione",
    "infligga": "infliggere",
    "infliggan": "infliggere",
    "infliggano": "infliggere",
    "infligge": "infliggere",
    "infliggemmo": "infliggere",
    "infliggendo": "infliggere",
    "infliggente": "infliggere",
    "infliggenti": "infliggere",
    "infligger": "infliggere",
    "infliggerai": "infliggere",
    "infliggeran": "infliggere",
    "infliggeranno": "infliggere",
    "infliggerebbe": "infliggere",
    "infliggerebber": "infliggere",
    "infliggerebbero": "infliggere",
    "infliggerei": "infliggere",
    "infliggeremmo": "infliggere",
    "infliggeremo": "infliggere",
    "infliggereste": "infliggere",
    "infliggeresti": "infliggere",
    "infliggerete": "infliggere",
    "infliggerà": "infliggere",
    "infliggerò": "infliggere",
    "infliggesse": "infliggere",
    "infliggesser": "infliggere",
    "infliggessero": "infliggere",
    "infliggessi": "infliggere",
    "infliggessimo": "infliggere",
    "infliggeste": "infliggere",
    "infliggesti": "infliggere",
    "infliggete": "infliggere",
    "infliggeva": "infliggere",
    "infliggevamo": "infliggere",
    "infliggevan": "infliggere",
    "infliggevano": "infliggere",
    "infliggevate": "infliggere",
    "infliggevi": "infliggere",
    "infliggevo": "infliggere",
    "infliggi": "infliggere",
    "infliggiamo": "infliggere",
    "infliggiate": "infliggere",
    "infliggo": "infliggere",
    "infliggon": "infliggere",
    "infliggono": "infliggere",
    "inflisser": "infliggere",
    "inflissero": "infliggere",
    "inflissi": "infliggere",
    "inflissè": "infliggere",
    "inflitta": "infliggere",
    "inflitte": "infliggere",
    "inflitti": "infliggere",
    "inflitto": "infliggere",
    "influendo": "influire",
    "influente": "influire",
    "influenti": "influire",
    "influenza": "influenzare",
    "influenzabili": "influenzabile",
    "influenzai": "influenzare",
    "influenzali": "influenzale",
    "influenzammo": "influenzare",
    "influenzan": "influenzare",
    "influenzando": "influenzare",
    "influenzano": "influenzare",
    "influenzante": "influenzare",
    "influenzanti": "influenzare",
    "influenzar": "influenzare",
    "influenzaron": "influenzare",
    "influenzarono": "influenzare",
    "influenzasse": "influenzare",
    "influenzasser": "influenzare",
    "influenzassero": "influenzare",
    "influenzassi": "influenzare",
    "influenzassimo": "influenzare",
    "influenzaste": "influenzare",
    "influenzasti": "influenzare",
    "influenzata": "influenzato",
    "influenzate": "influenzato",
    "influenzati": "influenzato",
    "influenzato": "influenzare",
    "influenzava": "influenzare",
    "influenzavamo": "influenzare",
    "influenzavan": "influenzare",
    "influenzavano": "influenzare",
    "influenzavate": "influenzare",
    "influenzavi": "influenzare",
    "influenzavo": "influenzare",
    "influenze": "influenza",
    "influenzerai": "influenzare",
    "influenzeran": "influenzare",
    "influenzeranno": "influenzare",
    "influenzerebbe": "influenzare",
    "influenzerebber": "influenzare",
    "influenzerebbero": "influenzare",
    "influenzerei": "influenzare",
    "influenzeremmo": "influenzare",
    "influenzeremo": "influenzare",
    "influenzereste": "influenzare",
    "influenzeresti": "influenzare",
    "influenzerete": "influenzare",
    "influenzerà": "influenzare",
    "influenzerò": "influenzare",
    "influenzi": "influenzare",
    "influenziamo": "influenzare",
    "influenziate": "influenzare",
    "influenzin": "influenzare",
    "influenzino": "influenzare",
    "influenzo": "influenzare",
    "influenzò": "influenzare",
    "influiamo": "influire",
    "influiate": "influire",
    "influii": "influire",
    "influimmo": "influire",
    "influir": "influire",
    "influirai": "influire",
    "influiran": "influire",
    "influiranno": "influire",
    "influirebbe": "influire",
    "influirebber": "influire",
    "influirebbero": "influire",
    "influirei": "influire",
    "influiremmo": "influire",
    "influiremo": "influire",
    "influireste": "influire",
    "influiresti": "influire",
    "influirete": "influire",
    "influiron": "influire",
    "influirono": "influire",
    "influirà": "influire",
    "influirò": "influire",
    "influisca": "influire",
    "influiscan": "influire",
    "influiscano": "influire",
    "influisce": "influire",
    "influisci": "influire",
    "influisco": "influire",
    "influiscon": "influire",
    "influiscono": "influire",
    "influisse": "influire",
    "influisser": "influire",
    "influissero": "influire",
    "influissi": "influire",
    "influissimo": "influire",
    "influiste": "influire",
    "influisti": "influire",
    "influita": "influire",
    "influite": "influire",
    "influiti": "influire",
    "influito": "influire",
    "influiva": "influire",
    "influivamo": "influire",
    "influivan": "influire",
    "influivano": "influire",
    "influivate": "influire",
    "influivi": "influire",
    "influivo": "influire",
    "influssi": "influsso",
    "influì": "influire",
    "infoca": "infocare",
    "infocai": "infocare",
    "infocammo": "infocare",
    "infocan": "infocare",
    "infocando": "infocare",
    "infocano": "infocare",
    "infocante": "infocare",
    "infocanti": "infocare",
    "infocar": "infocare",
    "infocaron": "infocare",
    "infocarono": "infocare",
    "infocasse": "infocare",
    "infocasser": "infocare",
    "infocassero": "infocare",
    "infocassi": "infocare",
    "infocassimo": "infocare",
    "infocaste": "infocare",
    "infocasti": "infocare",
    "infocata": "infocare",
    "infocate": "infocare",
    "infocati": "infocare",
    "infocato": "infocare",
    "infocava": "infocare",
    "infocavamo": "infocare",
    "infocavan": "infocare",
    "infocavano": "infocare",
    "infocavate": "infocare",
    "infocavi": "infocare",
    "infocavo": "infocare",
    "infocherai": "infocare",
    "infocheran": "infocare",
    "infocheranno": "infocare",
    "infocherebbe": "infocare",
    "infocherebber": "infocare",
    "infocherebbero": "infocare",
    "infocherei": "infocare",
    "infocheremmo": "infocare",
    "infocheremo": "infocare",
    "infochereste": "infocare",
    "infocheresti": "infocare",
    "infocherete": "infocare",
    "infocherà": "infocare",
    "infocherò": "infocare",
    "infochi": "infocare",
    "infochiamo": "infocare",
    "infochiate": "infocare",
    "infochin": "infocare",
    "infochino": "infocare",
    "infoco": "infocare",
    "infocò": "infocare",
    "infogna": "infognare",
    "infognai": "infognare",
    "infognammo": "infognare",
    "infognan": "infognare",
    "infognando": "infognare",
    "infognano": "infognare",
    "infognar": "infognare",
    "infognaron": "infognare",
    "infognarono": "infognare",
    "infognasse": "infognare",
    "infognasser": "infognare",
    "infognassero": "infognare",
    "infognassi": "infognare",
    "infognassimo": "infognare",
    "infognaste": "infognare",
    "infognasti": "infognare",
    "infognata": "infognare",
    "infognate": "infognare",
    "infognati": "infognare",
    "infognato": "infognare",
    "infognava": "infognare",
    "infognavamo": "infognare",
    "infognavan": "infognare",
    "infognavano": "infognare",
    "infognavate": "infognare",
    "infognavi": "infognare",
    "infognavo": "infognare",
    "infognerai": "infognare",
    "infogneran": "infognare",
    "infogneranno": "infognare",
    "infognerebbe": "infognare",
    "infognerebber": "infognare",
    "infognerebbero": "infognare",
    "infognerei": "infognare",
    "infogneremmo": "infognare",
    "infogneremo": "infognare",
    "infognereste": "infognare",
    "infogneresti": "infognare",
    "infognerete": "infognare",
    "infognerà": "infognare",
    "infognerò": "infognare",
    "infogni": "infognare",
    "infogniamo": "infognare",
    "infogniate": "infognare",
    "infognin": "infognare",
    "infognino": "infognare",
    "infogno": "infognare",
    "infognò": "infognare",
    "infoltendo": "infoltire",
    "infoltente": "infoltire",
    "infoltenti": "infoltire",
    "infoltiamo": "infoltire",
    "infoltiate": "infoltire",
    "infoltii": "infoltire",
    "infoltimmo": "infoltire",
    "infoltir": "infoltire",
    "infoltirai": "infoltire",
    "infoltiran": "infoltire",
    "infoltiranno": "infoltire",
    "infoltirebbe": "infoltire",
    "infoltirebber": "infoltire",
    "infoltirebbero": "infoltire",
    "infoltirei": "infoltire",
    "infoltiremmo": "infoltire",
    "infoltiremo": "infoltire",
    "infoltireste": "infoltire",
    "infoltiresti": "infoltire",
    "infoltirete": "infoltire",
    "infoltiron": "infoltire",
    "infoltirono": "infoltire",
    "infoltirà": "infoltire",
    "infoltirò": "infoltire",
    "infoltisca": "infoltire",
    "infoltiscan": "infoltire",
    "infoltiscano": "infoltire",
    "infoltisce": "infoltire",
    "infoltisci": "infoltire",
    "infoltisco": "infoltire",
    "infoltiscon": "infoltire",
    "infoltiscono": "infoltire",
    "infoltisse": "infoltire",
    "infoltisser": "infoltire",
    "infoltissero": "infoltire",
    "infoltissi": "infoltire",
    "infoltissimo": "infoltire",
    "infoltiste": "infoltire",
    "infoltisti": "infoltire",
    "infoltita": "infoltire",
    "infoltite": "infoltire",
    "infoltiti": "infoltire",
    "infoltito": "infoltire",
    "infoltiva": "infoltire",
    "infoltivamo": "infoltire",
    "infoltivan": "infoltire",
    "infoltivano": "infoltire",
    "infoltivate": "infoltire",
    "infoltivi": "infoltire",
    "infoltivo": "infoltire",
    "infoltì": "infoltire",
    "infonda": "infondere",
    "infondan": "infondere",
    "infondano": "infondere",
    "infondata": "infondato",
    "infondate": "infondato",
    "infondati": "infondato",
    "infonde": "infondere",
    "infondemmo": "infondere",
    "infondendo": "infondere",
    "infondente": "infondere",
    "infondenti": "infondere",
    "infonder": "infondere",
    "infonderai": "infondere",
    "infonderan": "infondere",
    "infonderanno": "infondere",
    "infonderebbe": "infondere",
    "infonderebber": "infondere",
    "infonderebbero": "infondere",
    "infonderei": "infondere",
    "infonderemmo": "infondere",
    "infonderemo": "infondere",
    "infondereste": "infondere",
    "infonderesti": "infondere",
    "infonderete": "infondere",
    "infonderà": "infondere",
    "infonderò": "infondere",
    "infondesse": "infondere",
    "infondesser": "infondere",
    "infondessero": "infondere",
    "infondessi": "infondere",
    "infondessimo": "infondere",
    "infondeste": "infondere",
    "infondesti": "infondere",
    "infondete": "infondere",
    "infondeva": "infondere",
    "infondevamo": "infondere",
    "infondevan": "infondere",
    "infondevano": "infondere",
    "infondevate": "infondere",
    "infondevi": "infondere",
    "infondevo": "infondere",
    "infondi": "infondere",
    "infondiamo": "infondere",
    "infondiate": "infondere",
    "infondo": "infondere",
    "infondon": "infondere",
    "infondono": "infondere",
    "inforca": "inforcare",
    "inforcai": "inforcare",
    "inforcammo": "inforcare",
    "inforcan": "inforcare",
    "inforcando": "inforcare",
    "inforcano": "inforcare",
    "inforcante": "inforcare",
    "inforcanti": "inforcare",
    "inforcar": "inforcare",
    "inforcaron": "inforcare",
    "inforcarono": "inforcare",
    "inforcasse": "inforcare",
    "inforcasser": "inforcare",
    "inforcassero": "inforcare",
    "inforcassi": "inforcare",
    "inforcassimo": "inforcare",
    "inforcaste": "inforcare",
    "inforcasti": "inforcare",
    "inforcata": "inforcare",
    "inforcate": "inforcare",
    "inforcati": "inforcare",
    "inforcato": "inforcare",
    "inforcava": "inforcare",
    "inforcavamo": "inforcare",
    "inforcavan": "inforcare",
    "inforcavano": "inforcare",
    "inforcavate": "inforcare",
    "inforcavi": "inforcare",
    "inforcavo": "inforcare",
    "inforcherai": "inforcare",
    "inforcheran": "inforcare",
    "inforcheranno": "inforcare",
    "inforcherebbe": "inforcare",
    "inforcherebber": "inforcare",
    "inforcherebbero": "inforcare",
    "inforcherei": "inforcare",
    "inforcheremmo": "inforcare",
    "inforcheremo": "inforcare",
    "inforchereste": "inforcare",
    "inforcheresti": "inforcare",
    "inforcherete": "inforcare",
    "inforcherà": "inforcare",
    "inforcherò": "inforcare",
    "inforchi": "inforcare",
    "inforchiamo": "inforcare",
    "inforchiate": "inforcare",
    "inforchin": "inforcare",
    "inforchino": "inforcare",
    "inforco": "inforcare",
    "inforcò": "inforcare",
    "informa": "informare",
    "informai": "informare",
    "informali": "informale",
    "informammo": "informare",
    "informan": "informare",
    "informando": "informare",
    "informano": "informare",
    "informante": "informare",
    "informanti": "informare",
    "informar": "informare",
    "informaron": "informare",
    "informarono": "informare",
    "informasse": "informare",
    "informasser": "informare",
    "informassero": "informare",
    "informassi": "informare",
    "informassimo": "informare",
    "informaste": "informare",
    "informasti": "informare",
    "informata": "informato",
    "informate": "informato",
    "informati": "informato",
    "informatica": "informatico",
    "informatiche": "informatico",
    "informatici": "informatico",
    "informativa": "informativo",
    "informative": "informativo",
    "informativi": "informativo",
    "informatizza": "informatizzare",
    "informatizzai": "informatizzare",
    "informatizzammo": "informatizzare",
    "informatizzan": "informatizzare",
    "informatizzando": "informatizzare",
    "informatizzano": "informatizzare",
    "informatizzante": "informatizzare",
    "informatizzanti": "informatizzare",
    "informatizzar": "informatizzare",
    "informatizzaron": "informatizzare",
    "informatizzarono": "informatizzare",
    "informatizzasse": "informatizzare",
    "informatizzasser": "informatizzare",
    "informatizzassero": "informatizzare",
    "informatizzassi": "informatizzare",
    "informatizzassimo": "informatizzare",
    "informatizzaste": "informatizzare",
    "informatizzasti": "informatizzare",
    "informatizzata": "informatizzare",
    "informatizzate": "informatizzare",
    "informatizzati": "informatizzare",
    "informatizzato": "informatizzare",
    "informatizzava": "informatizzare",
    "informatizzavamo": "informatizzare",
    "informatizzavan": "informatizzare",
    "informatizzavano": "informatizzare",
    "informatizzavate": "informatizzare",
    "informatizzavi": "informatizzare",
    "informatizzavo": "informatizzare",
    "informatizzazioni": "informatizzazione",
    "informatizzerai": "informatizzare",
    "informatizzeran": "informatizzare",
    "informatizzeranno": "informatizzare",
    "informatizzerebbe": "informatizzare",
    "informatizzerebber": "informatizzare",
    "informatizzerebbero": "informatizzare",
    "informatizzerei": "informatizzare",
    "informatizzeremmo": "informatizzare",
    "informatizzeremo": "informatizzare",
    "informatizzereste": "informatizzare",
    "informatizzeresti": "informatizzare",
    "informatizzerete": "informatizzare",
    "informatizzerà": "informatizzare",
    "informatizzerò": "informatizzare",
    "informatizzi": "informatizzare",
    "informatizziamo": "informatizzare",
    "informatizziate": "informatizzare",
    "informatizzin": "informatizzare",
    "informatizzino": "informatizzare",
    "informatizzo": "informatizzare",
    "informatizzò": "informatizzare",
    "informato": "informare",
    "informatori": "informatore",
    "informatrice": "informatore",
    "informatrici": "informatore",
    "informava": "informare",
    "informavamo": "informare",
    "informavan": "informare",
    "informavano": "informare",
    "informavate": "informare",
    "informavi": "informare",
    "informavo": "informare",
    "informazioni": "informazione",
    "informerai": "informare",
    "informeran": "informare",
    "informeranno": "informare",
    "informerebbe": "informare",
    "informerebber": "informare",
    "informerebbero": "informare",
    "informerei": "informare",
    "informeremmo": "informare",
    "informeremo": "informare",
    "informereste": "informare",
    "informeresti": "informare",
    "informerete": "informare",
    "informerà": "informare",
    "informerò": "informare",
    "informi": "informe",
    "informiamo": "informare",
    "informiate": "informare",
    "informin": "informare",
    "informino": "informare",
    "informo": "informare",
    "informò": "informare",
    "inforna": "infornare",
    "infornai": "infornare",
    "infornammo": "infornare",
    "infornan": "infornare",
    "infornando": "infornare",
    "infornano": "infornare",
    "infornante": "infornare",
    "infornanti": "infornare",
    "infornar": "infornare",
    "infornaron": "infornare",
    "infornarono": "infornare",
    "infornasse": "infornare",
    "infornasser": "infornare",
    "infornassero": "infornare",
    "infornassi": "infornare",
    "infornassimo": "infornare",
    "infornaste": "infornare",
    "infornasti": "infornare",
    "infornata": "infornare",
    "infornate": "infornata",
    "infornati": "infornare",
    "infornato": "infornare",
    "infornava": "infornare",
    "infornavamo": "infornare",
    "infornavan": "infornare",
    "infornavano": "infornare",
    "infornavate": "infornare",
    "infornavi": "infornare",
    "infornavo": "infornare",
    "infornerai": "infornare",
    "inforneran": "infornare",
    "inforneranno": "infornare",
    "infornerebbe": "infornare",
    "infornerebber": "infornare",
    "infornerebbero": "infornare",
    "infornerei": "infornare",
    "inforneremmo": "infornare",
    "inforneremo": "infornare",
    "infornereste": "infornare",
    "inforneresti": "infornare",
    "infornerete": "infornare",
    "infornerà": "infornare",
    "infornerò": "infornare",
    "inforni": "infornare",
    "inforniamo": "infornare",
    "inforniate": "infornare",
    "infornin": "infornare",
    "infornino": "infornare",
    "inforno": "infornare",
    "infornò": "infornare",
    "infortuna": "infortunare",
    "infortunai": "infortunare",
    "infortunammo": "infortunare",
    "infortunan": "infortunare",
    "infortunando": "infortunare",
    "infortunano": "infortunare",
    "infortunar": "infortunare",
    "infortunaron": "infortunare",
    "infortunarono": "infortunare",
    "infortunasse": "infortunare",
    "infortunasser": "infortunare",
    "infortunassero": "infortunare",
    "infortunassi": "infortunare",
    "infortunassimo": "infortunare",
    "infortunaste": "infortunare",
    "infortunasti": "infortunare",
    "infortunata": "infortunato",
    "infortunate": "infortunato",
    "infortunati": "infortunato",
    "infortunato": "infortunare",
    "infortunava": "infortunare",
    "infortunavamo": "infortunare",
    "infortunavan": "infortunare",
    "infortunavano": "infortunare",
    "infortunavate": "infortunare",
    "infortunavi": "infortunare",
    "infortunavo": "infortunare",
    "infortunerai": "infortunare",
    "infortuneran": "infortunare",
    "infortuneranno": "infortunare",
    "infortunerebbe": "infortunare",
    "infortunerebber": "infortunare",
    "infortunerebbero": "infortunare",
    "infortunerei": "infortunare",
    "infortuneremmo": "infortunare",
    "infortuneremo": "infortunare",
    "infortunereste": "infortunare",
    "infortuneresti": "infortunare",
    "infortunerete": "infortunare",
    "infortunerà": "infortunare",
    "infortunerò": "infortunare",
    "infortuni": "infortunio",
    "infortuniamo": "infortunare",
    "infortuniate": "infortunare",
    "infortunin": "infortunare",
    "infortunino": "infortunare",
    "infortunistica": "infortunistico",
    "infortunistiche": "infortunistico",
    "infortunistici": "infortunistico",
    "infortuno": "infortunare",
    "infortunò": "infortunare",
    "infossa": "infossare",
    "infossai": "infossare",
    "infossammo": "infossare",
    "infossan": "infossare",
    "infossando": "infossare",
    "infossano": "infossare",
    "infossante": "infossare",
    "infossanti": "infossare",
    "infossar": "infossare",
    "infossaron": "infossare",
    "infossarono": "infossare",
    "infossasse": "infossare",
    "infossasser": "infossare",
    "infossassero": "infossare",
    "infossassi": "infossare",
    "infossassimo": "infossare",
    "infossaste": "infossare",
    "infossasti": "infossare",
    "infossata": "infossare",
    "infossate": "infossare",
    "infossati": "infossare",
    "infossato": "infossare",
    "infossava": "infossare",
    "infossavamo": "infossare",
    "infossavan": "infossare",
    "infossavano": "infossare",
    "infossavate": "infossare",
    "infossavi": "infossare",
    "infossavo": "infossare",
    "infosserai": "infossare",
    "infosseran": "infossare",
    "infosseranno": "infossare",
    "infosserebbe": "infossare",
    "infosserebber": "infossare",
    "infosserebbero": "infossare",
    "infosserei": "infossare",
    "infosseremmo": "infossare",
    "infosseremo": "infossare",
    "infossereste": "infossare",
    "infosseresti": "infossare",
    "infosserete": "infossare",
    "infosserà": "infossare",
    "infosserò": "infossare",
    "infossi": "infossare",
    "infossiamo": "infossare",
    "infossiate": "infossare",
    "infossin": "infossare",
    "infossino": "infossare",
    "infosso": "infossare",
    "infossò": "infossare",
    "infradicerai": "infradiciare",
    "infradiceran": "infradiciare",
    "infradiceranno": "infradiciare",
    "infradicerebbe": "infradiciare",
    "infradicerebber": "infradiciare",
    "infradicerebbero": "infradiciare",
    "infradicerei": "infradiciare",
    "infradiceremmo": "infradiciare",
    "infradiceremo": "infradiciare",
    "infradicereste": "infradiciare",
    "infradiceresti": "infradiciare",
    "infradicerete": "infradiciare",
    "infradicerà": "infradiciare",
    "infradicerò": "infradiciare",
    "infradici": "infradiciare",
    "infradicia": "infradiciare",
    "infradiciai": "infradiciare",
    "infradiciammo": "infradiciare",
    "infradiciamo": "infradiciare",
    "infradician": "infradiciare",
    "infradiciando": "infradiciare",
    "infradiciano": "infradiciare",
    "infradiciante": "infradiciare",
    "infradicianti": "infradiciare",
    "infradiciar": "infradiciare",
    "infradiciaron": "infradiciare",
    "infradiciarono": "infradiciare",
    "infradiciasse": "infradiciare",
    "infradiciasser": "infradiciare",
    "infradiciassero": "infradiciare",
    "infradiciassi": "infradiciare",
    "infradiciassimo": "infradiciare",
    "infradiciaste": "infradiciare",
    "infradiciasti": "infradiciare",
    "infradiciata": "infradiciare",
    "infradiciate": "infradiciare",
    "infradiciati": "infradiciare",
    "infradiciato": "infradiciare",
    "infradiciava": "infradiciare",
    "infradiciavamo": "infradiciare",
    "infradiciavan": "infradiciare",
    "infradiciavano": "infradiciare",
    "infradiciavate": "infradiciare",
    "infradiciavi": "infradiciare",
    "infradiciavo": "infradiciare",
    "infradicin": "infradiciare",
    "infradicino": "infradiciare",
    "infradicio": "infradiciare",
    "infradiciò": "infradiciare",
    "inframmetta": "inframmettere",
    "inframmettan": "inframmettere",
    "inframmettano": "inframmettere",
    "inframmette": "inframmettere",
    "inframmettei": "inframmettere",
    "inframmettemmo": "inframmettere",
    "inframmettendo": "inframmettere",
    "inframmettente": "inframmettere",
    "inframmettenti": "inframmettere",
    "inframmetter": "inframmettere",
    "inframmetterai": "inframmettere",
    "inframmetteran": "inframmettere",
    "inframmetteranno": "inframmettere",
    "inframmetterebbe": "inframmettere",
    "inframmetterebber": "inframmettere",
    "inframmetterebbero": "inframmettere",
    "inframmetterei": "inframmettere",
    "inframmetteremmo": "inframmettere",
    "inframmetteremo": "inframmettere",
    "inframmettereste": "inframmettere",
    "inframmetteresti": "inframmettere",
    "inframmetterete": "inframmettere",
    "inframmetteron": "inframmettere",
    "inframmetterono": "inframmettere",
    "inframmetterà": "inframmettere",
    "inframmetterò": "inframmettere",
    "inframmettesse": "inframmettere",
    "inframmettesser": "inframmettere",
    "inframmettessero": "inframmettere",
    "inframmettessi": "inframmettere",
    "inframmettessimo": "inframmettere",
    "inframmetteste": "inframmettere",
    "inframmettesti": "inframmettere",
    "inframmettete": "inframmettere",
    "inframmetteva": "inframmettere",
    "inframmettevamo": "inframmettere",
    "inframmettevan": "inframmettere",
    "inframmettevano": "inframmettere",
    "inframmettevate": "inframmettere",
    "inframmettevi": "inframmettere",
    "inframmettevo": "inframmettere",
    "inframmetti": "inframmettere",
    "inframmettiamo": "inframmettere",
    "inframmettiate": "inframmettere",
    "inframmetto": "inframmettere",
    "inframmetton": "inframmettere",
    "inframmettono": "inframmettere",
    "inframmettuta": "inframmettere",
    "inframmettute": "inframmettere",
    "inframmettuti": "inframmettere",
    "inframmettuto": "inframmettere",
    "inframmettè": "inframmettere",
    "infranga": "infrangere",
    "infrangan": "infrangere",
    "infrangano": "infrangere",
    "infrange": "infrangere",
    "infrangemmo": "infrangere",
    "infrangendo": "infrangere",
    "infrangente": "infrangere",
    "infrangenti": "infrangere",
    "infranger": "infrangere",
    "infrangerai": "infrangere",
    "infrangeran": "infrangere",
    "infrangeranno": "infrangere",
    "infrangerebbe": "infrangere",
    "infrangerebber": "infrangere",
    "infrangerebbero": "infrangere",
    "infrangerei": "infrangere",
    "infrangeremmo": "infrangere",
    "infrangeremo": "infrangere",
    "infrangereste": "infrangere",
    "infrangeresti": "infrangere",
    "infrangerete": "infrangere",
    "infrangerà": "infrangere",
    "infrangerò": "infrangere",
    "infrangesse": "infrangere",
    "infrangesser": "infrangere",
    "infrangessero": "infrangere",
    "infrangessi": "infrangere",
    "infrangessimo": "infrangere",
    "infrangeste": "infrangere",
    "infrangesti": "infrangere",
    "infrangete": "infrangere",
    "infrangeva": "infrangere",
    "infrangevamo": "infrangere",
    "infrangevan": "infrangere",
    "infrangevano": "infrangere",
    "infrangevate": "infrangere",
    "infrangevi": "infrangere",
    "infrangevo": "infrangere",
    "infrangi": "infrangere",
    "infrangiamo": "infrangere",
    "infrangiate": "infrangere",
    "infrangibili": "infrangibile",
    "infrango": "infrangere",
    "infrangon": "infrangere",
    "infrangono": "infrangere",
    "infranser": "infrangere",
    "infransero": "infrangere",
    "infransi": "infrangere",
    "infransè": "infrangere",
    "infranta": "infranto",
    "infrante": "infranto",
    "infranti": "infranto",
    "infranto": "infrangere",
    "infrarossa": "infrarosso",
    "infrarosse": "infrarosso",
    "infrarossi": "infrarosso",
    "infrasettimanali": "infrasettimanale",
    "infrastrutturali": "infrastrutturale",
    "infrastrutture": "infrastruttura",
    "infrazioni": "infrazione",
    "infredda": "infreddare",
    "infreddai": "infreddare",
    "infreddammo": "infreddare",
    "infreddan": "infreddare",
    "infreddando": "infreddare",
    "infreddano": "infreddare",
    "infreddante": "infreddare",
    "infreddanti": "infreddare",
    "infreddar": "infreddare",
    "infreddaron": "infreddare",
    "infreddarono": "infreddare",
    "infreddasse": "infreddare",
    "infreddasser": "infreddare",
    "infreddassero": "infreddare",
    "infreddassi": "infreddare",
    "infreddassimo": "infreddare",
    "infreddaste": "infreddare",
    "infreddasti": "infreddare",
    "infreddata": "infreddare",
    "infreddate": "infreddare",
    "infreddati": "infreddare",
    "infreddato": "infreddare",
    "infreddava": "infreddare",
    "infreddavamo": "infreddare",
    "infreddavan": "infreddare",
    "infreddavano": "infreddare",
    "infreddavate": "infreddare",
    "infreddavi": "infreddare",
    "infreddavo": "infreddare",
    "infredderai": "infreddare",
    "infredderan": "infreddare",
    "infredderanno": "infreddare",
    "infredderebbe": "infreddare",
    "infredderebber": "infreddare",
    "infredderebbero": "infreddare",
    "infredderei": "infreddare",
    "infredderemmo": "infreddare",
    "infredderemo": "infreddare",
    "infreddereste": "infreddare",
    "infredderesti": "infreddare",
    "infredderete": "infreddare",
    "infredderà": "infreddare",
    "infredderò": "infreddare",
    "infreddi": "infreddare",
    "infreddiamo": "infreddare",
    "infreddiate": "infreddare",
    "infreddin": "infreddare",
    "infreddino": "infreddare",
    "infreddo": "infreddare",
    "infreddola": "infreddolire",
    "infreddolan": "infreddolire",
    "infreddolano": "infreddolire",
    "infreddole": "infreddolire",
    "infreddolendo": "infreddolire",
    "infreddolente": "infreddolire",
    "infreddolenti": "infreddolire",
    "infreddoli": "infreddolire",
    "infreddoliamo": "infreddolire",
    "infreddoliate": "infreddolire",
    "infreddolii": "infreddolire",
    "infreddolimmo": "infreddolire",
    "infreddolir": "infreddolire",
    "infreddolirai": "infreddolire",
    "infreddoliran": "infreddolire",
    "infreddoliranno": "infreddolire",
    "infreddolirebbe": "infreddolire",
    "infreddolirebber": "infreddolire",
    "infreddolirebbero": "infreddolire",
    "infreddolirei": "infreddolire",
    "infreddoliremmo": "infreddolire",
    "infreddoliremo": "infreddolire",
    "infreddolireste": "infreddolire",
    "infreddoliresti": "infreddolire",
    "infreddolirete": "infreddolire",
    "infreddoliron": "infreddolire",
    "infreddolirono": "infreddolire",
    "infreddolirà": "infreddolire",
    "infreddolirò": "infreddolire",
    "infreddolisse": "infreddolire",
    "infreddolisser": "infreddolire",
    "infreddolissero": "infreddolire",
    "infreddolissi": "infreddolire",
    "infreddolissimo": "infreddolire",
    "infreddoliste": "infreddolire",
    "infreddolisti": "infreddolire",
    "infreddolita": "infreddolire",
    "infreddolite": "infreddolire",
    "infreddoliti": "infreddolire",
    "infreddolito": "infreddolire",
    "infreddoliva": "infreddolire",
    "infreddolivamo": "infreddolire",
    "infreddolivan": "infreddolire",
    "infreddolivano": "infreddolire",
    "infreddolivate": "infreddolire",
    "infreddolivi": "infreddolire",
    "infreddolivo": "infreddolire",
    "infreddolo": "infreddolire",
    "infreddolon": "infreddolire",
    "infreddolono": "infreddolire",
    "infreddolì": "infreddolire",
    "infreddò": "infreddare",
    "infruttifera": "infruttifero",
    "infruttifere": "infruttifero",
    "infruttiferi": "infruttifero",
    "infruttuosa": "infruttuoso",
    "infruttuose": "infruttuoso",
    "infruttuosi": "infruttuoso",
    "infuoca": "infuocare",
    "infuocai": "infuocare",
    "infuocammo": "infuocare",
    "infuocan": "infuocare",
    "infuocando": "infuocare",
    "infuocano": "infuocare",
    "infuocante": "infuocare",
    "infuocanti": "infuocare",
    "infuocar": "infuocare",
    "infuocaron": "infuocare",
    "infuocarono": "infuocare",
    "infuocasse": "infuocare",
    "infuocasser": "infuocare",
    "infuocassero": "infuocare",
    "infuocassi": "infuocare",
    "infuocassimo": "infuocare",
    "infuocaste": "infuocare",
    "infuocasti": "infuocare",
    "infuocata": "infuocare",
    "infuocate": "infuocare",
    "infuocati": "infuocare",
    "infuocato": "infuocare",
    "infuocava": "infuocare",
    "infuocavamo": "infuocare",
    "infuocavan": "infuocare",
    "infuocavano": "infuocare",
    "infuocavate": "infuocare",
    "infuocavi": "infuocare",
    "infuocavo": "infuocare",
    "infuocherai": "infuocare",
    "infuocheran": "infuocare",
    "infuocheranno": "infuocare",
    "infuocherebbe": "infuocare",
    "infuocherebber": "infuocare",
    "infuocherebbero": "infuocare",
    "infuocherei": "infuocare",
    "infuocheremmo": "infuocare",
    "infuocheremo": "infuocare",
    "infuochereste": "infuocare",
    "infuocheresti": "infuocare",
    "infuocherete": "infuocare",
    "infuocherà": "infuocare",
    "infuocherò": "infuocare",
    "infuochi": "infuocare",
    "infuochiamo": "infuocare",
    "infuochiate": "infuocare",
    "infuochin": "infuocare",
    "infuochino": "infuocare",
    "infuoco": "infuocare",
    "infuocò": "infuocare",
    "infuri": "infuriare",
    "infuria": "infuriare",
    "infuriai": "infuriare",
    "infuriammo": "infuriare",
    "infuriamo": "infuriare",
    "infurian": "infuriare",
    "infuriando": "infuriare",
    "infuriano": "infuriare",
    "infuriante": "infuriare",
    "infurianti": "infuriare",
    "infuriar": "infuriare",
    "infuriaron": "infuriare",
    "infuriarono": "infuriare",
    "infuriasse": "infuriare",
    "infuriasser": "infuriare",
    "infuriassero": "infuriare",
    "infuriassi": "infuriare",
    "infuriassimo": "infuriare",
    "infuriaste": "infuriare",
    "infuriasti": "infuriare",
    "infuriata": "infuriare",
    "infuriate": "infuriare",
    "infuriati": "infuriare",
    "infuriato": "infuriare",
    "infuriava": "infuriare",
    "infuriavamo": "infuriare",
    "infuriavan": "infuriare",
    "infuriavano": "infuriare",
    "infuriavate": "infuriare",
    "infuriavi": "infuriare",
    "infuriavo": "infuriare",
    "infurierai": "infuriare",
    "infurieran": "infuriare",
    "infurieranno": "infuriare",
    "infurierebbe": "infuriare",
    "infurierebber": "infuriare",
    "infurierebbero": "infuriare",
    "infurierei": "infuriare",
    "infurieremmo": "infuriare",
    "infurieremo": "infuriare",
    "infuriereste": "infuriare",
    "infurieresti": "infuriare",
    "infurierete": "infuriare",
    "infurierà": "infuriare",
    "infurierò": "infuriare",
    "infurin": "infuriare",
    "infurino": "infuriare",
    "infurio": "infuriare",
    "infuriò": "infuriare",
    "infusa": "infondere",
    "infuse": "infondere",
    "infuser": "infondere",
    "infusero": "infondere",
    "infusi": "infuso",
    "infuso": "infondere",
    "ingabbi": "ingabbiare",
    "ingabbia": "ingabbiare",
    "ingabbiai": "ingabbiare",
    "ingabbiammo": "ingabbiare",
    "ingabbiamo": "ingabbiare",
    "ingabbian": "ingabbiare",
    "ingabbiando": "ingabbiare",
    "ingabbiano": "ingabbiare",
    "ingabbiante": "ingabbiare",
    "ingabbianti": "ingabbiare",
    "ingabbiar": "ingabbiare",
    "ingabbiaron": "ingabbiare",
    "ingabbiarono": "ingabbiare",
    "ingabbiasse": "ingabbiare",
    "ingabbiasser": "ingabbiare",
    "ingabbiassero": "ingabbiare",
    "ingabbiassi": "ingabbiare",
    "ingabbiassimo": "ingabbiare",
    "ingabbiaste": "ingabbiare",
    "ingabbiasti": "ingabbiare",
    "ingabbiata": "ingabbiare",
    "ingabbiate": "ingabbiare",
    "ingabbiati": "ingabbiare",
    "ingabbiato": "ingabbiare",
    "ingabbiava": "ingabbiare",
    "ingabbiavamo": "ingabbiare",
    "ingabbiavan": "ingabbiare",
    "ingabbiavano": "ingabbiare",
    "ingabbiavate": "ingabbiare",
    "ingabbiavi": "ingabbiare",
    "ingabbiavo": "ingabbiare",
    "ingabbierai": "ingabbiare",
    "ingabbieran": "ingabbiare",
    "ingabbieranno": "ingabbiare",
    "ingabbierebbe": "ingabbiare",
    "ingabbierebber": "ingabbiare",
    "ingabbierebbero": "ingabbiare",
    "ingabbierei": "ingabbiare",
    "ingabbieremmo": "ingabbiare",
    "ingabbieremo": "ingabbiare",
    "ingabbiereste": "ingabbiare",
    "ingabbieresti": "ingabbiare",
    "ingabbierete": "ingabbiare",
    "ingabbierà": "ingabbiare",
    "ingabbierò": "ingabbiare",
    "ingabbin": "ingabbiare",
    "ingabbino": "ingabbiare",
    "ingabbio": "ingabbiare",
    "ingabbiò": "ingabbiare",
    "ingaggerai": "ingaggiare",
    "ingaggeran": "ingaggiare",
    "ingaggeranno": "ingaggiare",
    "ingaggerebbe": "ingaggiare",
    "ingaggerebber": "ingaggiare",
    "ingaggerebbero": "ingaggiare",
    "ingaggerei": "ingaggiare",
    "ingaggeremmo": "ingaggiare",
    "ingaggeremo": "ingaggiare",
    "ingaggereste": "ingaggiare",
    "ingaggeresti": "ingaggiare",
    "ingaggerete": "ingaggiare",
    "ingaggerà": "ingaggiare",
    "ingaggerò": "ingaggiare",
    "ingaggi": "ingaggio",
    "ingaggia": "ingaggiare",
    "ingaggiai": "ingaggiare",
    "ingaggiammo": "ingaggiare",
    "ingaggiamo": "ingaggiare",
    "ingaggian": "ingaggiare",
    "ingaggiando": "ingaggiare",
    "ingaggiano": "ingaggiare",
    "ingaggiante": "ingaggiare",
    "ingaggianti": "ingaggiare",
    "ingaggiar": "ingaggiare",
    "ingaggiaron": "ingaggiare",
    "ingaggiarono": "ingaggiare",
    "ingaggiasse": "ingaggiare",
    "ingaggiasser": "ingaggiare",
    "ingaggiassero": "ingaggiare",
    "ingaggiassi": "ingaggiare",
    "ingaggiassimo": "ingaggiare",
    "ingaggiaste": "ingaggiare",
    "ingaggiasti": "ingaggiare",
    "ingaggiata": "ingaggiare",
    "ingaggiate": "ingaggiare",
    "ingaggiati": "ingaggiare",
    "ingaggiato": "ingaggiare",
    "ingaggiava": "ingaggiare",
    "ingaggiavamo": "ingaggiare",
    "ingaggiavan": "ingaggiare",
    "ingaggiavano": "ingaggiare",
    "ingaggiavate": "ingaggiare",
    "ingaggiavi": "ingaggiare",
    "ingaggiavo": "ingaggiare",
    "ingaggin": "ingaggiare",
    "ingaggino": "ingaggiare",
    "ingaggio": "ingaggiare",
    "ingaggiò": "ingaggiare",
    "ingagliarda": "ingagliardire",
    "ingagliardan": "ingagliardire",
    "ingagliardano": "ingagliardire",
    "ingagliarde": "ingagliardire",
    "ingagliardendo": "ingagliardire",
    "ingagliardente": "ingagliardire",
    "ingagliardenti": "ingagliardire",
    "ingagliardi": "ingagliardire",
    "ingagliardiamo": "ingagliardire",
    "ingagliardiate": "ingagliardire",
    "ingagliardii": "ingagliardire",
    "ingagliardimmo": "ingagliardire",
    "ingagliardir": "ingagliardire",
    "ingagliardirai": "ingagliardire",
    "ingagliardiran": "ingagliardire",
    "ingagliardiranno": "ingagliardire",
    "ingagliardirebbe": "ingagliardire",
    "ingagliardirebber": "ingagliardire",
    "ingagliardirebbero": "ingagliardire",
    "ingagliardirei": "ingagliardire",
    "ingagliardiremmo": "ingagliardire",
    "ingagliardiremo": "ingagliardire",
    "ingagliardireste": "ingagliardire",
    "ingagliardiresti": "ingagliardire",
    "ingagliardirete": "ingagliardire",
    "ingagliardiron": "ingagliardire",
    "ingagliardirono": "ingagliardire",
    "ingagliardirà": "ingagliardire",
    "ingagliardirò": "ingagliardire",
    "ingagliardisse": "ingagliardire",
    "ingagliardisser": "ingagliardire",
    "ingagliardissero": "ingagliardire",
    "ingagliardissi": "ingagliardire",
    "ingagliardissimo": "ingagliardire",
    "ingagliardiste": "ingagliardire",
    "ingagliardisti": "ingagliardire",
    "ingagliardita": "ingagliardire",
    "ingagliardite": "ingagliardire",
    "ingagliarditi": "ingagliardire",
    "ingagliardito": "ingagliardire",
    "ingagliardiva": "ingagliardire",
    "ingagliardivamo": "ingagliardire",
    "ingagliardivan": "ingagliardire",
    "ingagliardivano": "ingagliardire",
    "ingagliardivate": "ingagliardire",
    "ingagliardivi": "ingagliardire",
    "ingagliardivo": "ingagliardire",
    "ingagliardo": "ingagliardire",
    "ingagliardon": "ingagliardire",
    "ingagliardono": "ingagliardire",
    "ingagliardì": "ingagliardire",
    "inganna": "ingannare",
    "ingannai": "ingannare",
    "ingannammo": "ingannare",
    "ingannan": "ingannare",
    "ingannando": "ingannare",
    "ingannano": "ingannare",
    "ingannante": "ingannare",
    "ingannanti": "ingannare",
    "ingannar": "ingannare",
    "ingannaron": "ingannare",
    "ingannarono": "ingannare",
    "ingannasse": "ingannare",
    "ingannasser": "ingannare",
    "ingannassero": "ingannare",
    "ingannassi": "ingannare",
    "ingannassimo": "ingannare",
    "ingannaste": "ingannare",
    "ingannasti": "ingannare",
    "ingannata": "ingannare",
    "ingannate": "ingannare",
    "ingannati": "ingannare",
    "ingannato": "ingannare",
    "ingannatori": "ingannatore",
    "ingannatrice": "ingannatore",
    "ingannatrici": "ingannatore",
    "ingannava": "ingannare",
    "ingannavamo": "ingannare",
    "ingannavan": "ingannare",
    "ingannavano": "ingannare",
    "ingannavate": "ingannare",
    "ingannavi": "ingannare",
    "ingannavo": "ingannare",
    "ingannerai": "ingannare",
    "inganneran": "ingannare",
    "inganneranno": "ingannare",
    "ingannerebbe": "ingannare",
    "ingannerebber": "ingannare",
    "ingannerebbero": "ingannare",
    "ingannerei": "ingannare",
    "inganneremmo": "ingannare",
    "inganneremo": "ingannare",
    "ingannereste": "ingannare",
    "inganneresti": "ingannare",
    "ingannerete": "ingannare",
    "ingannerà": "ingannare",
    "ingannerò": "ingannare",
    "ingannevoli": "ingannevole",
    "inganni": "inganno",
    "inganniamo": "ingannare",
    "inganniate": "ingannare",
    "ingannin": "ingannare",
    "ingannino": "ingannare",
    "inganno": "ingannare",
    "ingannò": "ingannare",
    "ingarbugli": "ingarbugliare",
    "ingarbuglia": "ingarbugliare",
    "ingarbugliai": "ingarbugliare",
    "ingarbugliammo": "ingarbugliare",
    "ingarbugliamo": "ingarbugliare",
    "ingarbuglian": "ingarbugliare",
    "ingarbugliando": "ingarbugliare",
    "ingarbugliano": "ingarbugliare",
    "ingarbugliante": "ingarbugliare",
    "ingarbuglianti": "ingarbugliare",
    "ingarbugliar": "ingarbugliare",
    "ingarbugliaron": "ingarbugliare",
    "ingarbugliarono": "ingarbugliare",
    "ingarbugliasse": "ingarbugliare",
    "ingarbugliasser": "ingarbugliare",
    "ingarbugliassero": "ingarbugliare",
    "ingarbugliassi": "ingarbugliare",
    "ingarbugliassimo": "ingarbugliare",
    "ingarbugliaste": "ingarbugliare",
    "ingarbugliasti": "ingarbugliare",
    "ingarbugliata": "ingarbugliare",
    "ingarbugliate": "ingarbugliata",
    "ingarbugliati": "ingarbugliare",
    "ingarbugliato": "ingarbugliare",
    "ingarbugliava": "ingarbugliare",
    "ingarbugliavamo": "ingarbugliare",
    "ingarbugliavan": "ingarbugliare",
    "ingarbugliavano": "ingarbugliare",
    "ingarbugliavate": "ingarbugliare",
    "ingarbugliavi": "ingarbugliare",
    "ingarbugliavo": "ingarbugliare",
    "ingarbuglierai": "ingarbugliare",
    "ingarbuglieran": "ingarbugliare",
    "ingarbuglieranno": "ingarbugliare",
    "ingarbuglierebbe": "ingarbugliare",
    "ingarbuglierebber": "ingarbugliare",
    "ingarbuglierebbero": "ingarbugliare",
    "ingarbuglierei": "ingarbugliare",
    "ingarbuglieremmo": "ingarbugliare",
    "ingarbuglieremo": "ingarbugliare",
    "ingarbugliereste": "ingarbugliare",
    "ingarbuglieresti": "ingarbugliare",
    "ingarbuglierete": "ingarbugliare",
    "ingarbuglierà": "ingarbugliare",
    "ingarbuglierò": "ingarbugliare",
    "ingarbuglin": "ingarbugliare",
    "ingarbuglino": "ingarbugliare",
    "ingarbuglio": "ingarbugliare",
    "ingarbugliò": "ingarbugliare",
    "ingegna": "ingegnare",
    "ingegnai": "ingegnare",
    "ingegnammo": "ingegnare",
    "ingegnan": "ingegnare",
    "ingegnando": "ingegnare",
    "ingegnano": "ingegnare",
    "ingegnar": "ingegnare",
    "ingegnaron": "ingegnare",
    "ingegnarono": "ingegnare",
    "ingegnasse": "ingegnare",
    "ingegnasser": "ingegnare",
    "ingegnassero": "ingegnare",
    "ingegnassi": "ingegnare",
    "ingegnassimo": "ingegnare",
    "ingegnaste": "ingegnare",
    "ingegnasti": "ingegnare",
    "ingegnata": "ingegnare",
    "ingegnate": "ingegnare",
    "ingegnati": "ingegnare",
    "ingegnato": "ingegnare",
    "ingegnava": "ingegnare",
    "ingegnavamo": "ingegnare",
    "ingegnavan": "ingegnare",
    "ingegnavano": "ingegnare",
    "ingegnavate": "ingegnare",
    "ingegnavi": "ingegnare",
    "ingegnavo": "ingegnare",
    "ingegner": "ingegnere",
    "ingegnerai": "ingegnare",
    "ingegneran": "ingegnare",
    "ingegneranno": "ingegnare",
    "ingegnerebbe": "ingegnare",
    "ingegnerebber": "ingegnare",
    "ingegnerebbero": "ingegnare",
    "ingegnerei": "ingegnare",
    "ingegneremmo": "ingegnare",
    "ingegneremo": "ingegnare",
    "ingegnereste": "ingegnare",
    "ingegneresti": "ingegnare",
    "ingegnerete": "ingegnare",
    "ingegneri": "ingegnere",
    "ingegnerie": "ingegneria",
    "ingegnerà": "ingegnare",
    "ingegnerò": "ingegnare",
    "ingegni": "ingegno",
    "ingegniamo": "ingegnare",
    "ingegniate": "ingegnare",
    "ingegnin": "ingegnare",
    "ingegnino": "ingegnare",
    "ingegno": "ingegnare",
    "ingegnosa": "ingegnoso",
    "ingegnose": "ingegnoso",
    "ingegnosi": "ingegnoso",
    "ingegnò": "ingegnare",
    "ingelosendo": "ingelosire",
    "ingelosente": "ingelosire",
    "ingelosenti": "ingelosire",
    "ingelosiamo": "ingelosire",
    "ingelosiate": "ingelosire",
    "ingelosii": "ingelosire",
    "ingelosimmo": "ingelosire",
    "ingelosir": "ingelosire",
    "ingelosirai": "ingelosire",
    "ingelosiran": "ingelosire",
    "ingelosiranno": "ingelosire",
    "ingelosirebbe": "ingelosire",
    "ingelosirebber": "ingelosire",
    "ingelosirebbero": "ingelosire",
    "ingelosirei": "ingelosire",
    "ingelosiremmo": "ingelosire",
    "ingelosiremo": "ingelosire",
    "ingelosireste": "ingelosire",
    "ingelosiresti": "ingelosire",
    "ingelosirete": "ingelosire",
    "ingelosiron": "ingelosire",
    "ingelosirono": "ingelosire",
    "ingelosirà": "ingelosire",
    "ingelosirò": "ingelosire",
    "ingelosisca": "ingelosire",
    "ingelosiscan": "ingelosire",
    "ingelosiscano": "ingelosire",
    "ingelosisce": "ingelosire",
    "ingelosisci": "ingelosire",
    "ingelosisco": "ingelosire",
    "ingelosiscon": "ingelosire",
    "ingelosiscono": "ingelosire",
    "ingelosisse": "ingelosire",
    "ingelosisser": "ingelosire",
    "ingelosissero": "ingelosire",
    "ingelosissi": "ingelosire",
    "ingelosissimo": "ingelosire",
    "ingelosiste": "ingelosire",
    "ingelosisti": "ingelosire",
    "ingelosita": "ingelosire",
    "ingelosite": "ingelosire",
    "ingelositi": "ingelosire",
    "ingelosito": "ingelosire",
    "ingelosiva": "ingelosire",
    "ingelosivamo": "ingelosire",
    "ingelosivan": "ingelosire",
    "ingelosivano": "ingelosire",
    "ingelosivate": "ingelosire",
    "ingelosivi": "ingelosire",
    "ingelosivo": "ingelosire",
    "ingelosì": "ingelosire",
    "ingemma": "ingemmare",
    "ingemmai": "ingemmare",
    "ingemmammo": "ingemmare",
    "ingemman": "ingemmare",
    "ingemmando": "ingemmare",
    "ingemmano": "ingemmare",
    "ingemmante": "ingemmare",
    "ingemmanti": "ingemmare",
    "ingemmar": "ingemmare",
    "ingemmaron": "ingemmare",
    "ingemmarono": "ingemmare",
    "ingemmasse": "ingemmare",
    "ingemmasser": "ingemmare",
    "ingemmassero": "ingemmare",
    "ingemmassi": "ingemmare",
    "ingemmassimo": "ingemmare",
    "ingemmaste": "ingemmare",
    "ingemmasti": "ingemmare",
    "ingemmata": "ingemmare",
    "ingemmate": "ingemmare",
    "ingemmati": "ingemmare",
    "ingemmato": "ingemmare",
    "ingemmava": "ingemmare",
    "ingemmavamo": "ingemmare",
    "ingemmavan": "ingemmare",
    "ingemmavano": "ingemmare",
    "ingemmavate": "ingemmare",
    "ingemmavi": "ingemmare",
    "ingemmavo": "ingemmare",
    "ingemmerai": "ingemmare",
    "ingemmeran": "ingemmare",
    "ingemmeranno": "ingemmare",
    "ingemmerebbe": "ingemmare",
    "ingemmerebber": "ingemmare",
    "ingemmerebbero": "ingemmare",
    "ingemmerei": "ingemmare",
    "ingemmeremmo": "ingemmare",
    "ingemmeremo": "ingemmare",
    "ingemmereste": "ingemmare",
    "ingemmeresti": "ingemmare",
    "ingemmerete": "ingemmare",
    "ingemmerà": "ingemmare",
    "ingemmerò": "ingemmare",
    "ingemmi": "ingemmare",
    "ingemmiamo": "ingemmare",
    "ingemmiate": "ingemmare",
    "ingemmin": "ingemmare",
    "ingemmino": "ingemmare",
    "ingemmo": "ingemmare",
    "ingemmò": "ingemmare",
    "ingenera": "ingenerare",
    "ingenerai": "ingenerare",
    "ingenerammo": "ingenerare",
    "ingeneran": "ingenerare",
    "ingenerando": "ingenerare",
    "ingenerano": "ingenerare",
    "ingenerante": "ingenerare",
    "ingeneranti": "ingenerare",
    "ingenerar": "ingenerare",
    "ingeneraron": "ingenerare",
    "ingenerarono": "ingenerare",
    "ingenerasse": "ingenerare",
    "ingenerasser": "ingenerare",
    "ingenerassero": "ingenerare",
    "ingenerassi": "ingenerare",
    "ingenerassimo": "ingenerare",
    "ingeneraste": "ingenerare",
    "ingenerasti": "ingenerare",
    "ingenerata": "ingenerare",
    "ingenerate": "ingenerare",
    "ingenerati": "ingenerare",
    "ingenerato": "ingenerare",
    "ingenerava": "ingenerare",
    "ingeneravamo": "ingenerare",
    "ingeneravan": "ingenerare",
    "ingeneravano": "ingenerare",
    "ingeneravate": "ingenerare",
    "ingeneravi": "ingenerare",
    "ingeneravo": "ingenerare",
    "ingenererai": "ingenerare",
    "ingenereran": "ingenerare",
    "ingenereranno": "ingenerare",
    "ingenererebbe": "ingenerare",
    "ingenererebber": "ingenerare",
    "ingenererebbero": "ingenerare",
    "ingenererei": "ingenerare",
    "ingenereremmo": "ingenerare",
    "ingenereremo": "ingenerare",
    "ingenerereste": "ingenerare",
    "ingenereresti": "ingenerare",
    "ingenererete": "ingenerare",
    "ingenererà": "ingenerare",
    "ingenererò": "ingenerare",
    "ingeneri": "ingenerare",
    "ingeneriamo": "ingenerare",
    "ingeneriate": "ingenerare",
    "ingenerin": "ingenerare",
    "ingenerino": "ingenerare",
    "ingenero": "ingenerare",
    "ingenerosa": "ingeneroso",
    "ingenerose": "ingeneroso",
    "ingenerosi": "ingeneroso",
    "ingenerò": "ingenerare",
    "ingenita": "ingenito",
    "ingenite": "ingenito",
    "ingeniti": "ingenito",
    "ingenti": "ingente",
    "ingentilendo": "ingentilire",
    "ingentilente": "ingentilire",
    "ingentilenti": "ingentilire",
    "ingentiliamo": "ingentilire",
    "ingentiliate": "ingentilire",
    "ingentilii": "ingentilire",
    "ingentilimmo": "ingentilire",
    "ingentilir": "ingentilire",
    "ingentilirai": "ingentilire",
    "ingentiliran": "ingentilire",
    "ingentiliranno": "ingentilire",
    "ingentilirebbe": "ingentilire",
    "ingentilirebber": "ingentilire",
    "ingentilirebbero": "ingentilire",
    "ingentilirei": "ingentilire",
    "ingentiliremmo": "ingentilire",
    "ingentiliremo": "ingentilire",
    "ingentilireste": "ingentilire",
    "ingentiliresti": "ingentilire",
    "ingentilirete": "ingentilire",
    "ingentiliron": "ingentilire",
    "ingentilirono": "ingentilire",
    "ingentilirà": "ingentilire",
    "ingentilirò": "ingentilire",
    "ingentilisca": "ingentilire",
    "ingentiliscan": "ingentilire",
    "ingentiliscano": "ingentilire",
    "ingentilisce": "ingentilire",
    "ingentilisci": "ingentilire",
    "ingentilisco": "ingentilire",
    "ingentiliscon": "ingentilire",
    "ingentiliscono": "ingentilire",
    "ingentilisse": "ingentilire",
    "ingentilisser": "ingentilire",
    "ingentilissero": "ingentilire",
    "ingentilissi": "ingentilire",
    "ingentilissimo": "ingentilire",
    "ingentiliste": "ingentilire",
    "ingentilisti": "ingentilire",
    "ingentilita": "ingentilire",
    "ingentilite": "ingentilire",
    "ingentiliti": "ingentilire",
    "ingentilito": "ingentilire",
    "ingentiliva": "ingentilire",
    "ingentilivamo": "ingentilire",
    "ingentilivan": "ingentilire",
    "ingentilivano": "ingentilire",
    "ingentilivate": "ingentilire",
    "ingentilivi": "ingentilire",
    "ingentilivo": "ingentilire",
    "ingentilì": "ingentilire",
    "ingenua": "ingenuo",
    "ingenue": "ingenuo",
    "ingenui": "ingenuo",
    "ingerendo": "ingerire",
    "ingerente": "ingerire",
    "ingerenti": "ingerire",
    "ingerenze": "ingerenza",
    "ingeriamo": "ingerire",
    "ingeriate": "ingerire",
    "ingerii": "ingerire",
    "ingerimmo": "ingerire",
    "ingerir": "ingerire",
    "ingerirai": "ingerire",
    "ingeriran": "ingerire",
    "ingeriranno": "ingerire",
    "ingerirebbe": "ingerire",
    "ingerirebber": "ingerire",
    "ingerirebbero": "ingerire",
    "ingerirei": "ingerire",
    "ingeriremmo": "ingerire",
    "ingeriremo": "ingerire",
    "ingerireste": "ingerire",
    "ingeriresti": "ingerire",
    "ingerirete": "ingerire",
    "ingeriron": "ingerire",
    "ingerirono": "ingerire",
    "ingerirà": "ingerire",
    "ingerirò": "ingerire",
    "ingerisca": "ingerire",
    "ingeriscan": "ingerire",
    "ingeriscano": "ingerire",
    "ingerisce": "ingerire",
    "ingerisci": "ingerire",
    "ingerisco": "ingerire",
    "ingeriscon": "ingerire",
    "ingeriscono": "ingerire",
    "ingerisse": "ingerire",
    "ingerisser": "ingerire",
    "ingerissero": "ingerire",
    "ingerissi": "ingerire",
    "ingerissimo": "ingerire",
    "ingeriste": "ingerire",
    "ingeristi": "ingerire",
    "ingerita": "ingerire",
    "ingerite": "ingerire",
    "ingeriti": "ingerire",
    "ingerito": "ingerire",
    "ingeriva": "ingerire",
    "ingerivamo": "ingerire",
    "ingerivan": "ingerire",
    "ingerivano": "ingerire",
    "ingerivate": "ingerire",
    "ingerivi": "ingerire",
    "ingerivo": "ingerire",
    "ingerì": "ingerire",
    "ingessa": "ingessare",
    "ingessai": "ingessare",
    "ingessammo": "ingessare",
    "ingessan": "ingessare",
    "ingessando": "ingessare",
    "ingessano": "ingessare",
    "ingessante": "ingessare",
    "ingessanti": "ingessare",
    "ingessar": "ingessare",
    "ingessaron": "ingessare",
    "ingessarono": "ingessare",
    "ingessasse": "ingessare",
    "ingessasser": "ingessare",
    "ingessassero": "ingessare",
    "ingessassi": "ingessare",
    "ingessassimo": "ingessare",
    "ingessaste": "ingessare",
    "ingessasti": "ingessare",
    "ingessata": "ingessare",
    "ingessate": "ingessare",
    "ingessati": "ingessare",
    "ingessato": "ingessare",
    "ingessature": "ingessatura",
    "ingessava": "ingessare",
    "ingessavamo": "ingessare",
    "ingessavan": "ingessare",
    "ingessavano": "ingessare",
    "ingessavate": "ingessare",
    "ingessavi": "ingessare",
    "ingessavo": "ingessare",
    "ingesserai": "ingessare",
    "ingesseran": "ingessare",
    "ingesseranno": "ingessare",
    "ingesserebbe": "ingessare",
    "ingesserebber": "ingessare",
    "ingesserebbero": "ingessare",
    "ingesserei": "ingessare",
    "ingesseremmo": "ingessare",
    "ingesseremo": "ingessare",
    "ingessereste": "ingessare",
    "ingesseresti": "ingessare",
    "ingesserete": "ingessare",
    "ingesserà": "ingessare",
    "ingesserò": "ingessare",
    "ingessi": "ingessare",
    "ingessiamo": "ingessare",
    "ingessiate": "ingessare",
    "ingessin": "ingessare",
    "ingessino": "ingessare",
    "ingesso": "ingessare",
    "ingessò": "ingessare",
    "ingestibili": "ingestibile",
    "inghiai": "inghiaiare",
    "inghiaia": "inghiaiare",
    "inghiaiai": "inghiaiare",
    "inghiaiammo": "inghiaiare",
    "inghiaiamo": "inghiaiare",
    "inghiaian": "inghiaiare",
    "inghiaiando": "inghiaiare",
    "inghiaiano": "inghiaiare",
    "inghiaiante": "inghiaiare",
    "inghiaianti": "inghiaiare",
    "inghiaiar": "inghiaiare",
    "inghiaiaron": "inghiaiare",
    "inghiaiarono": "inghiaiare",
    "inghiaiasse": "inghiaiare",
    "inghiaiasser": "inghiaiare",
    "inghiaiassero": "inghiaiare",
    "inghiaiassi": "inghiaiare",
    "inghiaiassimo": "inghiaiare",
    "inghiaiaste": "inghiaiare",
    "inghiaiasti": "inghiaiare",
    "inghiaiata": "inghiaiare",
    "inghiaiate": "inghiaiare",
    "inghiaiati": "inghiaiare",
    "inghiaiato": "inghiaiare",
    "inghiaiava": "inghiaiare",
    "inghiaiavamo": "inghiaiare",
    "inghiaiavan": "inghiaiare",
    "inghiaiavano": "inghiaiare",
    "inghiaiavate": "inghiaiare",
    "inghiaiavi": "inghiaiare",
    "inghiaiavo": "inghiaiare",
    "inghiaierai": "inghiaiare",
    "inghiaieran": "inghiaiare",
    "inghiaieranno": "inghiaiare",
    "inghiaierebbe": "inghiaiare",
    "inghiaierebber": "inghiaiare",
    "inghiaierebbero": "inghiaiare",
    "inghiaierei": "inghiaiare",
    "inghiaieremmo": "inghiaiare",
    "inghiaieremo": "inghiaiare",
    "inghiaiereste": "inghiaiare",
    "inghiaieresti": "inghiaiare",
    "inghiaierete": "inghiaiare",
    "inghiaierà": "inghiaiare",
    "inghiaierò": "inghiaiare",
    "inghiain": "inghiaiare",
    "inghiaino": "inghiaiare",
    "inghiaio": "inghiaiare",
    "inghiaiò": "inghiaiare",
    "inghiottendo": "inghiottire",
    "inghiottente": "inghiottire",
    "inghiottenti": "inghiottire",
    "inghiottiamo": "inghiottire",
    "inghiottiate": "inghiottire",
    "inghiottii": "inghiottire",
    "inghiottimmo": "inghiottire",
    "inghiottir": "inghiottire",
    "inghiottirai": "inghiottire",
    "inghiottiran": "inghiottire",
    "inghiottiranno": "inghiottire",
    "inghiottirebbe": "inghiottire",
    "inghiottirebber": "inghiottire",
    "inghiottirebbero": "inghiottire",
    "inghiottirei": "inghiottire",
    "inghiottiremmo": "inghiottire",
    "inghiottiremo": "inghiottire",
    "inghiottireste": "inghiottire",
    "inghiottiresti": "inghiottire",
    "inghiottirete": "inghiottire",
    "inghiottiron": "inghiottire",
    "inghiottirono": "inghiottire",
    "inghiottirà": "inghiottire",
    "inghiottirò": "inghiottire",
    "inghiottisca": "inghiottire",
    "inghiottiscan": "inghiottire",
    "inghiottiscano": "inghiottire",
    "inghiottisce": "inghiottire",
    "inghiottisci": "inghiottire",
    "inghiottisco": "inghiottire",
    "inghiottiscon": "inghiottire",
    "inghiottiscono": "inghiottire",
    "inghiottisse": "inghiottire",
    "inghiottisser": "inghiottire",
    "inghiottissero": "inghiottire",
    "inghiottissi": "inghiottire",
    "inghiottissimo": "inghiottire",
    "inghiottiste": "inghiottire",
    "inghiottisti": "inghiottire",
    "inghiottita": "inghiottire",
    "inghiottite": "inghiottire",
    "inghiottiti": "inghiottire",
    "inghiottito": "inghiottire",
    "inghiottiva": "inghiottire",
    "inghiottivamo": "inghiottire",
    "inghiottivan": "inghiottire",
    "inghiottivano": "inghiottire",
    "inghiottivate": "inghiottire",
    "inghiottivi": "inghiottire",
    "inghiottivo": "inghiottire",
    "inghiottì": "inghiottire",
    "inghirlanda": "inghirlandare",
    "inghirlandai": "inghirlandare",
    "inghirlandammo": "inghirlandare",
    "inghirlandan": "inghirlandare",
    "inghirlandando": "inghirlandare",
    "inghirlandano": "inghirlandare",
    "inghirlandante": "inghirlandare",
    "inghirlandanti": "inghirlandare",
    "inghirlandar": "inghirlandare",
    "inghirlandaron": "inghirlandare",
    "inghirlandarono": "inghirlandare",
    "inghirlandasse": "inghirlandare",
    "inghirlandasser": "inghirlandare",
    "inghirlandassero": "inghirlandare",
    "inghirlandassi": "inghirlandare",
    "inghirlandassimo": "inghirlandare",
    "inghirlandaste": "inghirlandare",
    "inghirlandasti": "inghirlandare",
    "inghirlandata": "inghirlandare",
    "inghirlandate": "inghirlandare",
    "inghirlandati": "inghirlandare",
    "inghirlandato": "inghirlandare",
    "inghirlandava": "inghirlandare",
    "inghirlandavamo": "inghirlandare",
    "inghirlandavan": "inghirlandare",
    "inghirlandavano": "inghirlandare",
    "inghirlandavate": "inghirlandare",
    "inghirlandavi": "inghirlandare",
    "inghirlandavo": "inghirlandare",
    "inghirlanderai": "inghirlandare",
    "inghirlanderan": "inghirlandare",
    "inghirlanderanno": "inghirlandare",
    "inghirlanderebbe": "inghirlandare",
    "inghirlanderebber": "inghirlandare",
    "inghirlanderebbero": "inghirlandare",
    "inghirlanderei": "inghirlandare",
    "inghirlanderemmo": "inghirlandare",
    "inghirlanderemo": "inghirlandare",
    "inghirlandereste": "inghirlandare",
    "inghirlanderesti": "inghirlandare",
    "inghirlanderete": "inghirlandare",
    "inghirlanderà": "inghirlandare",
    "inghirlanderò": "inghirlandare",
    "inghirlandi": "inghirlandare",
    "inghirlandiamo": "inghirlandare",
    "inghirlandiate": "inghirlandare",
    "inghirlandin": "inghirlandare",
    "inghirlandino": "inghirlandare",
    "inghirlando": "inghirlandare",
    "inghirlandò": "inghirlandare",
    "ingiallendo": "ingiallire",
    "ingiallente": "ingiallire",
    "ingiallenti": "ingiallire",
    "ingialliamo": "ingiallire",
    "ingialliate": "ingiallire",
    "ingiallii": "ingiallire",
    "ingiallimmo": "ingiallire",
    "ingiallir": "ingiallire",
    "ingiallirai": "ingiallire",
    "ingialliran": "ingiallire",
    "ingialliranno": "ingiallire",
    "ingiallirebbe": "ingiallire",
    "ingiallirebber": "ingiallire",
    "ingiallirebbero": "ingiallire",
    "ingiallirei": "ingiallire",
    "ingialliremmo": "ingiallire",
    "ingialliremo": "ingiallire",
    "ingiallireste": "ingiallire",
    "ingialliresti": "ingiallire",
    "ingiallirete": "ingiallire",
    "ingialliron": "ingiallire",
    "ingiallirono": "ingiallire",
    "ingiallirà": "ingiallire",
    "ingiallirò": "ingiallire",
    "ingiallisca": "ingiallire",
    "ingialliscan": "ingiallire",
    "ingialliscano": "ingiallire",
    "ingiallisce": "ingiallire",
    "ingiallisci": "ingiallire",
    "ingiallisco": "ingiallire",
    "ingialliscon": "ingiallire",
    "ingialliscono": "ingiallire",
    "ingiallisse": "ingiallire",
    "ingiallisser": "ingiallire",
    "ingiallissero": "ingiallire",
    "ingiallissi": "ingiallire",
    "ingiallissimo": "ingiallire",
    "ingialliste": "ingiallire",
    "ingiallisti": "ingiallire",
    "ingiallita": "ingiallire",
    "ingiallite": "ingiallire",
    "ingialliti": "ingiallire",
    "ingiallito": "ingiallire",
    "ingialliva": "ingiallire",
    "ingiallivamo": "ingiallire",
    "ingiallivan": "ingiallire",
    "ingiallivano": "ingiallire",
    "ingiallivate": "ingiallire",
    "ingiallivi": "ingiallire",
    "ingiallivo": "ingiallire",
    "ingiallì": "ingiallire",
    "ingigantendo": "ingigantire",
    "ingigantente": "ingigantire",
    "ingigantenti": "ingigantire",
    "ingigantiamo": "ingigantire",
    "ingigantiate": "ingigantire",
    "ingigantii": "ingigantire",
    "ingigantimmo": "ingigantire",
    "ingigantir": "ingigantire",
    "ingigantirai": "ingigantire",
    "ingigantiran": "ingigantire",
    "ingigantiranno": "ingigantire",
    "ingigantirebbe": "ingigantire",
    "ingigantirebber": "ingigantire",
    "ingigantirebbero": "ingigantire",
    "ingigantirei": "ingigantire",
    "ingigantiremmo": "ingigantire",
    "ingigantiremo": "ingigantire",
    "ingigantireste": "ingigantire",
    "ingigantiresti": "ingigantire",
    "ingigantirete": "ingigantire",
    "ingigantiron": "ingigantire",
    "ingigantirono": "ingigantire",
    "ingigantirà": "ingigantire",
    "ingigantirò": "ingigantire",
    "ingigantisca": "ingigantire",
    "ingigantiscan": "ingigantire",
    "ingigantiscano": "ingigantire",
    "ingigantisce": "ingigantire",
    "ingigantisci": "ingigantire",
    "ingigantisco": "ingigantire",
    "ingigantiscon": "ingigantire",
    "ingigantiscono": "ingigantire",
    "ingigantisse": "ingigantire",
    "ingigantisser": "ingigantire",
    "ingigantissero": "ingigantire",
    "ingigantissi": "ingigantire",
    "ingigantissimo": "ingigantire",
    "ingigantiste": "ingigantire",
    "ingigantisti": "ingigantire",
    "ingigantita": "ingigantire",
    "ingigantite": "ingigantire",
    "ingigantiti": "ingigantire",
    "ingigantito": "ingigantire",
    "ingigantiva": "ingigantire",
    "ingigantivamo": "ingigantire",
    "ingigantivan": "ingigantire",
    "ingigantivano": "ingigantire",
    "ingigantivate": "ingigantire",
    "ingigantivi": "ingigantire",
    "ingigantivo": "ingigantire",
    "ingigantì": "ingigantire",
    "inginocchi": "inginocchiare",
    "inginocchia": "inginocchiare",
    "inginocchiai": "inginocchiare",
    "inginocchiammo": "inginocchiare",
    "inginocchiamo": "inginocchiare",
    "inginocchian": "inginocchiare",
    "inginocchiando": "inginocchiare",
    "inginocchiano": "inginocchiare",
    "inginocchiar": "inginocchiare",
    "inginocchiaron": "inginocchiare",
    "inginocchiarono": "inginocchiare",
    "inginocchiasse": "inginocchiare",
    "inginocchiasser": "inginocchiare",
    "inginocchiassero": "inginocchiare",
    "inginocchiassi": "inginocchiare",
    "inginocchiassimo": "inginocchiare",
    "inginocchiaste": "inginocchiare",
    "inginocchiasti": "inginocchiare",
    "inginocchiata": "inginocchiare",
    "inginocchiate": "inginocchiare",
    "inginocchiati": "inginocchiare",
    "inginocchiato": "inginocchiare",
    "inginocchiava": "inginocchiare",
    "inginocchiavamo": "inginocchiare",
    "inginocchiavan": "inginocchiare",
    "inginocchiavano": "inginocchiare",
    "inginocchiavate": "inginocchiare",
    "inginocchiavi": "inginocchiare",
    "inginocchiavo": "inginocchiare",
    "inginocchierai": "inginocchiare",
    "inginocchieran": "inginocchiare",
    "inginocchieranno": "inginocchiare",
    "inginocchierebbe": "inginocchiare",
    "inginocchierebber": "inginocchiare",
    "inginocchierebbero": "inginocchiare",
    "inginocchierei": "inginocchiare",
    "inginocchieremmo": "inginocchiare",
    "inginocchieremo": "inginocchiare",
    "inginocchiereste": "inginocchiare",
    "inginocchieresti": "inginocchiare",
    "inginocchierete": "inginocchiare",
    "inginocchierà": "inginocchiare",
    "inginocchierò": "inginocchiare",
    "inginocchin": "inginocchiare",
    "inginocchino": "inginocchiare",
    "inginocchio": "inginocchiare",
    "inginocchiò": "inginocchiare",
    "ingioiella": "ingioiellare",
    "ingioiellai": "ingioiellare",
    "ingioiellammo": "ingioiellare",
    "ingioiellan": "ingioiellare",
    "ingioiellando": "ingioiellare",
    "ingioiellano": "ingioiellare",
    "ingioiellante": "ingioiellare",
    "ingioiellanti": "ingioiellare",
    "ingioiellar": "ingioiellare",
    "ingioiellaron": "ingioiellare",
    "ingioiellarono": "ingioiellare",
    "ingioiellasse": "ingioiellare",
    "ingioiellasser": "ingioiellare",
    "ingioiellassero": "ingioiellare",
    "ingioiellassi": "ingioiellare",
    "ingioiellassimo": "ingioiellare",
    "ingioiellaste": "ingioiellare",
    "ingioiellasti": "ingioiellare",
    "ingioiellata": "ingioiellare",
    "ingioiellate": "ingioiellare",
    "ingioiellati": "ingioiellare",
    "ingioiellato": "ingioiellare",
    "ingioiellava": "ingioiellare",
    "ingioiellavamo": "ingioiellare",
    "ingioiellavan": "ingioiellare",
    "ingioiellavano": "ingioiellare",
    "ingioiellavate": "ingioiellare",
    "ingioiellavi": "ingioiellare",
    "ingioiellavo": "ingioiellare",
    "ingioiellerai": "ingioiellare",
    "ingioielleran": "ingioiellare",
    "ingioielleranno": "ingioiellare",
    "ingioiellerebbe": "ingioiellare",
    "ingioiellerebber": "ingioiellare",
    "ingioiellerebbero": "ingioiellare",
    "ingioiellerei": "ingioiellare",
    "ingioielleremmo": "ingioiellare",
    "ingioielleremo": "ingioiellare",
    "ingioiellereste": "ingioiellare",
    "ingioielleresti": "ingioiellare",
    "ingioiellerete": "ingioiellare",
    "ingioiellerà": "ingioiellare",
    "ingioiellerò": "ingioiellare",
    "ingioielli": "ingioiellare",
    "ingioielliamo": "ingioiellare",
    "ingioielliate": "ingioiellare",
    "ingioiellin": "ingioiellare",
    "ingioiellino": "ingioiellare",
    "ingioiello": "ingioiellare",
    "ingioiellò": "ingioiellare",
    "ingiunga": "ingiungere",
    "ingiungan": "ingiungere",
    "ingiungano": "ingiungere",
    "ingiunge": "ingiungere",
    "ingiungemmo": "ingiungere",
    "ingiungendo": "ingiungere",
    "ingiungente": "ingiungere",
    "ingiungenti": "ingiungere",
    "ingiunger": "ingiungere",
    "ingiungerai": "ingiungere",
    "ingiungeran": "ingiungere",
    "ingiungeranno": "ingiungere",
    "ingiungerebbe": "ingiungere",
    "ingiungerebber": "ingiungere",
    "ingiungerebbero": "ingiungere",
    "ingiungerei": "ingiungere",
    "ingiungeremmo": "ingiungere",
    "ingiungeremo": "ingiungere",
    "ingiungereste": "ingiungere",
    "ingiungeresti": "ingiungere",
    "ingiungerete": "ingiungere",
    "ingiungerà": "ingiungere",
    "ingiungerò": "ingiungere",
    "ingiungesse": "ingiungere",
    "ingiungesser": "ingiungere",
    "ingiungessero": "ingiungere",
    "ingiungessi": "ingiungere",
    "ingiungessimo": "ingiungere",
    "ingiungeste": "ingiungere",
    "ingiungesti": "ingiungere",
    "ingiungete": "ingiungere",
    "ingiungeva": "ingiungere",
    "ingiungevamo": "ingiungere",
    "ingiungevan": "ingiungere",
    "ingiungevano": "ingiungere",
    "ingiungevate": "ingiungere",
    "ingiungevi": "ingiungere",
    "ingiungevo": "ingiungere",
    "ingiungi": "ingiungere",
    "ingiungiamo": "ingiungere",
    "ingiungiate": "ingiungere",
    "ingiungo": "ingiungere",
    "ingiungon": "ingiungere",
    "ingiungono": "ingiungere",
    "ingiunse": "ingiungere",
    "ingiunser": "ingiungere",
    "ingiunsero": "ingiungere",
    "ingiunsi": "ingiungere",
    "ingiunta": "ingiungere",
    "ingiunte": "ingiungere",
    "ingiunti": "ingiungere",
    "ingiuntiva": "ingiuntivo",
    "ingiuntive": "ingiuntivo",
    "ingiuntivi": "ingiuntivo",
    "ingiunto": "ingiungere",
    "ingiunzioni": "ingiunzione",
    "ingiuri": "ingiuriare",
    "ingiuria": "ingiuriare",
    "ingiuriai": "ingiuriare",
    "ingiuriammo": "ingiuriare",
    "ingiuriamo": "ingiuriare",
    "ingiurian": "ingiuriare",
    "ingiuriando": "ingiuriare",
    "ingiuriano": "ingiuriare",
    "ingiuriante": "ingiuriare",
    "ingiurianti": "ingiuriare",
    "ingiuriar": "ingiuriare",
    "ingiuriaron": "ingiuriare",
    "ingiuriarono": "ingiuriare",
    "ingiuriasse": "ingiuriare",
    "ingiuriasser": "ingiuriare",
    "ingiuriassero": "ingiuriare",
    "ingiuriassi": "ingiuriare",
    "ingiuriassimo": "ingiuriare",
    "ingiuriaste": "ingiuriare",
    "ingiuriasti": "ingiuriare",
    "ingiuriata": "ingiuriare",
    "ingiuriate": "ingiuriare",
    "ingiuriati": "ingiuriare",
    "ingiuriato": "ingiuriare",
    "ingiuriava": "ingiuriare",
    "ingiuriavamo": "ingiuriare",
    "ingiuriavan": "ingiuriare",
    "ingiuriavano": "ingiuriare",
    "ingiuriavate": "ingiuriare",
    "ingiuriavi": "ingiuriare",
    "ingiuriavo": "ingiuriare",
    "ingiurie": "ingiuria",
    "ingiurierai": "ingiuriare",
    "ingiurieran": "ingiuriare",
    "ingiurieranno": "ingiuriare",
    "ingiurierebbe": "ingiuriare",
    "ingiurierebber": "ingiuriare",
    "ingiurierebbero": "ingiuriare",
    "ingiurierei": "ingiuriare",
    "ingiurieremmo": "ingiuriare",
    "ingiurieremo": "ingiuriare",
    "ingiuriereste": "ingiuriare",
    "ingiurieresti": "ingiuriare",
    "ingiurierete": "ingiuriare",
    "ingiurierà": "ingiuriare",
    "ingiurierò": "ingiuriare",
    "ingiurin": "ingiuriare",
    "ingiurino": "ingiuriare",
    "ingiurio": "ingiuriare",
    "ingiuriosa": "ingiurioso",
    "ingiuriose": "ingiurioso",
    "ingiuriosi": "ingiurioso",
    "ingiuriò": "ingiuriare",
    "ingiusta": "ingiusto",
    "ingiuste": "ingiusto",
    "ingiusti": "ingiusto",
    "ingiustificabili": "ingiustificabile",
    "ingiustificata": "ingiustificato",
    "ingiustificate": "ingiustificato",
    "ingiustificati": "ingiustificato",
    "ingiustizie": "ingiustizia",
    "inglesi": "inglese",
    "ingloba": "inglobare",
    "inglobai": "inglobare",
    "inglobammo": "inglobare",
    "ingloban": "inglobare",
    "inglobando": "inglobare",
    "inglobano": "inglobare",
    "inglobante": "inglobare",
    "inglobanti": "inglobare",
    "inglobar": "inglobare",
    "inglobaron": "inglobare",
    "inglobarono": "inglobare",
    "inglobasse": "inglobare",
    "inglobasser": "inglobare",
    "inglobassero": "inglobare",
    "inglobassi": "inglobare",
    "inglobassimo": "inglobare",
    "inglobaste": "inglobare",
    "inglobasti": "inglobare",
    "inglobata": "inglobare",
    "inglobate": "inglobare",
    "inglobati": "inglobare",
    "inglobato": "inglobare",
    "inglobava": "inglobare",
    "inglobavamo": "inglobare",
    "inglobavan": "inglobare",
    "inglobavano": "inglobare",
    "inglobavate": "inglobare",
    "inglobavi": "inglobare",
    "inglobavo": "inglobare",
    "ingloberai": "inglobare",
    "ingloberan": "inglobare",
    "ingloberanno": "inglobare",
    "ingloberebbe": "inglobare",
    "ingloberebber": "inglobare",
    "ingloberebbero": "inglobare",
    "ingloberei": "inglobare",
    "ingloberemmo": "inglobare",
    "ingloberemo": "inglobare",
    "inglobereste": "inglobare",
    "ingloberesti": "inglobare",
    "ingloberete": "inglobare",
    "ingloberà": "inglobare",
    "ingloberò": "inglobare",
    "inglobi": "inglobare",
    "inglobiamo": "inglobare",
    "inglobiate": "inglobare",
    "inglobin": "inglobare",
    "inglobino": "inglobare",
    "inglobo": "inglobare",
    "inglobò": "inglobare",
    "ingloriosa": "inglorioso",
    "ingloriose": "inglorioso",
    "ingloriosi": "inglorioso",
    "ingobbendo": "ingobbire",
    "ingobbente": "ingobbire",
    "ingobbenti": "ingobbire",
    "ingobbiamo": "ingobbire",
    "ingobbiate": "ingobbire",
    "ingobbii": "ingobbire",
    "ingobbimmo": "ingobbire",
    "ingobbir": "ingobbire",
    "ingobbirai": "ingobbire",
    "ingobbiran": "ingobbire",
    "ingobbiranno": "ingobbire",
    "ingobbirebbe": "ingobbire",
    "ingobbirebber": "ingobbire",
    "ingobbirebbero": "ingobbire",
    "ingobbirei": "ingobbire",
    "ingobbiremmo": "ingobbire",
    "ingobbiremo": "ingobbire",
    "ingobbireste": "ingobbire",
    "ingobbiresti": "ingobbire",
    "ingobbirete": "ingobbire",
    "ingobbiron": "ingobbire",
    "ingobbirono": "ingobbire",
    "ingobbirà": "ingobbire",
    "ingobbirò": "ingobbire",
    "ingobbisca": "ingobbire",
    "ingobbiscan": "ingobbire",
    "ingobbiscano": "ingobbire",
    "ingobbisce": "ingobbire",
    "ingobbisci": "ingobbire",
    "ingobbisco": "ingobbire",
    "ingobbiscon": "ingobbire",
    "ingobbiscono": "ingobbire",
    "ingobbisse": "ingobbire",
    "ingobbisser": "ingobbire",
    "ingobbissero": "ingobbire",
    "ingobbissi": "ingobbire",
    "ingobbissimo": "ingobbire",
    "ingobbiste": "ingobbire",
    "ingobbisti": "ingobbire",
    "ingobbita": "ingobbire",
    "ingobbite": "ingobbire",
    "ingobbiti": "ingobbire",
    "ingobbito": "ingobbire",
    "ingobbiva": "ingobbire",
    "ingobbivamo": "ingobbire",
    "ingobbivan": "ingobbire",
    "ingobbivano": "ingobbire",
    "ingobbivate": "ingobbire",
    "ingobbivi": "ingobbire",
    "ingobbivo": "ingobbire",
    "ingobbì": "ingobbire",
    "ingoffa": "ingoffire",
    "ingoffan": "ingoffire",
    "ingoffano": "ingoffire",
    "ingoffe": "ingoffire",
    "ingoffendo": "ingoffire",
    "ingoffente": "ingoffire",
    "ingoffenti": "ingoffire",
    "ingoffi": "ingoffire",
    "ingoffiamo": "ingoffire",
    "ingoffiate": "ingoffire",
    "ingoffii": "ingoffire",
    "ingoffimmo": "ingoffire",
    "ingoffir": "ingoffire",
    "ingoffirai": "ingoffire",
    "ingoffiran": "ingoffire",
    "ingoffiranno": "ingoffire",
    "ingoffirebbe": "ingoffire",
    "ingoffirebber": "ingoffire",
    "ingoffirebbero": "ingoffire",
    "ingoffirei": "ingoffire",
    "ingoffiremmo": "ingoffire",
    "ingoffiremo": "ingoffire",
    "ingoffireste": "ingoffire",
    "ingoffiresti": "ingoffire",
    "ingoffirete": "ingoffire",
    "ingoffiron": "ingoffire",
    "ingoffirono": "ingoffire",
    "ingoffirà": "ingoffire",
    "ingoffirò": "ingoffire",
    "ingoffisse": "ingoffire",
    "ingoffisser": "ingoffire",
    "ingoffissero": "ingoffire",
    "ingoffissi": "ingoffire",
    "ingoffissimo": "ingoffire",
    "ingoffiste": "ingoffire",
    "ingoffisti": "ingoffire",
    "ingoffita": "ingoffire",
    "ingoffite": "ingoffire",
    "ingoffiti": "ingoffire",
    "ingoffito": "ingoffire",
    "ingoffiva": "ingoffire",
    "ingoffivamo": "ingoffire",
    "ingoffivan": "ingoffire",
    "ingoffivano": "ingoffire",
    "ingoffivate": "ingoffire",
    "ingoffivi": "ingoffire",
    "ingoffivo": "ingoffire",
    "ingoffo": "ingoffire",
    "ingoffon": "ingoffire",
    "ingoffono": "ingoffire",
    "ingoffì": "ingoffire",
    "ingoi": "ingoiare",
    "ingoia": "ingoiare",
    "ingoiai": "ingoiare",
    "ingoiammo": "ingoiare",
    "ingoiamo": "ingoiare",
    "ingoian": "ingoiare",
    "ingoiando": "ingoiare",
    "ingoiano": "ingoiare",
    "ingoiante": "ingoiare",
    "ingoianti": "ingoiare",
    "ingoiar": "ingoiare",
    "ingoiaron": "ingoiare",
    "ingoiarono": "ingoiare",
    "ingoiasse": "ingoiare",
    "ingoiasser": "ingoiare",
    "ingoiassero": "ingoiare",
    "ingoiassi": "ingoiare",
    "ingoiassimo": "ingoiare",
    "ingoiaste": "ingoiare",
    "ingoiasti": "ingoiare",
    "ingoiata": "ingoiare",
    "ingoiate": "ingoiare",
    "ingoiati": "ingoiare",
    "ingoiato": "ingoiare",
    "ingoiava": "ingoiare",
    "ingoiavamo": "ingoiare",
    "ingoiavan": "ingoiare",
    "ingoiavano": "ingoiare",
    "ingoiavate": "ingoiare",
    "ingoiavi": "ingoiare",
    "ingoiavo": "ingoiare",
    "ingoierai": "ingoiare",
    "ingoieran": "ingoiare",
    "ingoieranno": "ingoiare",
    "ingoierebbe": "ingoiare",
    "ingoierebber": "ingoiare",
    "ingoierebbero": "ingoiare",
    "ingoierei": "ingoiare",
    "ingoieremmo": "ingoiare",
    "ingoieremo": "ingoiare",
    "ingoiereste": "ingoiare",
    "ingoieresti": "ingoiare",
    "ingoierete": "ingoiare",
    "ingoierà": "ingoiare",
    "ingoierò": "ingoiare",
    "ingoin": "ingoiare",
    "ingoino": "ingoiare",
    "ingoio": "ingoiare",
    "ingoiò": "ingoiare",
    "ingolfa": "ingolfare",
    "ingolfai": "ingolfare",
    "ingolfammo": "ingolfare",
    "ingolfan": "ingolfare",
    "ingolfando": "ingolfare",
    "ingolfano": "ingolfare",
    "ingolfante": "ingolfare",
    "ingolfanti": "ingolfare",
    "ingolfar": "ingolfare",
    "ingolfaron": "ingolfare",
    "ingolfarono": "ingolfare",
    "ingolfasse": "ingolfare",
    "ingolfasser": "ingolfare",
    "ingolfassero": "ingolfare",
    "ingolfassi": "ingolfare",
    "ingolfassimo": "ingolfare",
    "ingolfaste": "ingolfare",
    "ingolfasti": "ingolfare",
    "ingolfata": "ingolfare",
    "ingolfate": "ingolfare",
    "ingolfati": "ingolfare",
    "ingolfato": "ingolfare",
    "ingolfava": "ingolfare",
    "ingolfavamo": "ingolfare",
    "ingolfavan": "ingolfare",
    "ingolfavano": "ingolfare",
    "ingolfavate": "ingolfare",
    "ingolfavi": "ingolfare",
    "ingolfavo": "ingolfare",
    "ingolferai": "ingolfare",
    "ingolferan": "ingolfare",
    "ingolferanno": "ingolfare",
    "ingolferebbe": "ingolfare",
    "ingolferebber": "ingolfare",
    "ingolferebbero": "ingolfare",
    "ingolferei": "ingolfare",
    "ingolferemmo": "ingolfare",
    "ingolferemo": "ingolfare",
    "ingolfereste": "ingolfare",
    "ingolferesti": "ingolfare",
    "ingolferete": "ingolfare",
    "ingolferà": "ingolfare",
    "ingolferò": "ingolfare",
    "ingolfi": "ingolfare",
    "ingolfiamo": "ingolfare",
    "ingolfiate": "ingolfare",
    "ingolfin": "ingolfare",
    "ingolfino": "ingolfare",
    "ingolfo": "ingolfare",
    "ingolfò": "ingolfare",
    "ingolla": "ingollare",
    "ingollai": "ingollare",
    "ingollammo": "ingollare",
    "ingollan": "ingollare",
    "ingollando": "ingollare",
    "ingollano": "ingollare",
    "ingollante": "ingollare",
    "ingollanti": "ingollare",
    "ingollar": "ingollare",
    "ingollaron": "ingollare",
    "ingollarono": "ingollare",
    "ingollasse": "ingollare",
    "ingollasser": "ingollare",
    "ingollassero": "ingollare",
    "ingollassi": "ingollare",
    "ingollassimo": "ingollare",
    "ingollaste": "ingollare",
    "ingollasti": "ingollare",
    "ingollata": "ingollare",
    "ingollate": "ingollare",
    "ingollati": "ingollare",
    "ingollato": "ingollare",
    "ingollava": "ingollare",
    "ingollavamo": "ingollare",
    "ingollavan": "ingollare",
    "ingollavano": "ingollare",
    "ingollavate": "ingollare",
    "ingollavi": "ingollare",
    "ingollavo": "ingollare",
    "ingollerai": "ingollare",
    "ingolleran": "ingollare",
    "ingolleranno": "ingollare",
    "ingollerebbe": "ingollare",
    "ingollerebber": "ingollare",
    "ingollerebbero": "ingollare",
    "ingollerei": "ingollare",
    "ingolleremmo": "ingollare",
    "ingolleremo": "ingollare",
    "ingollereste": "ingollare",
    "ingolleresti": "ingollare",
    "ingollerete": "ingollare",
    "ingollerà": "ingollare",
    "ingollerò": "ingollare",
    "ingolli": "ingollare",
    "ingolliamo": "ingollare",
    "ingolliate": "ingollare",
    "ingollin": "ingollare",
    "ingollino": "ingollare",
    "ingollo": "ingollare",
    "ingollò": "ingollare",
    "ingolosa": "ingolosire",
    "ingolosan": "ingolosire",
    "ingolosano": "ingolosire",
    "ingolose": "ingolosire",
    "ingolosendo": "ingolosire",
    "ingolosente": "ingolosire",
    "ingolosenti": "ingolosire",
    "ingolosi": "ingolosire",
    "ingolosiamo": "ingolosire",
    "ingolosiate": "ingolosire",
    "ingolosii": "ingolosire",
    "ingolosimmo": "ingolosire",
    "ingolosir": "ingolosire",
    "ingolosirai": "ingolosire",
    "ingolosiran": "ingolosire",
    "ingolosiranno": "ingolosire",
    "ingolosirebbe": "ingolosire",
    "ingolosirebber": "ingolosire",
    "ingolosirebbero": "ingolosire",
    "ingolosirei": "ingolosire",
    "ingolosiremmo": "ingolosire",
    "ingolosiremo": "ingolosire",
    "ingolosireste": "ingolosire",
    "ingolosiresti": "ingolosire",
    "ingolosirete": "ingolosire",
    "ingolosiron": "ingolosire",
    "ingolosirono": "ingolosire",
    "ingolosirà": "ingolosire",
    "ingolosirò": "ingolosire",
    "ingolosisse": "ingolosire",
    "ingolosisser": "ingolosire",
    "ingolosissero": "ingolosire",
    "ingolosissi": "ingolosire",
    "ingolosissimo": "ingolosire",
    "ingolosiste": "ingolosire",
    "ingolosisti": "ingolosire",
    "ingolosita": "ingolosire",
    "ingolosite": "ingolosire",
    "ingolositi": "ingolosire",
    "ingolosito": "ingolosire",
    "ingolosiva": "ingolosire",
    "ingolosivamo": "ingolosire",
    "ingolosivan": "ingolosire",
    "ingolosivano": "ingolosire",
    "ingolosivate": "ingolosire",
    "ingolosivi": "ingolosire",
    "ingolosivo": "ingolosire",
    "ingoloso": "ingolosire",
    "ingoloson": "ingolosire",
    "ingolosono": "ingolosire",
    "ingolosì": "ingolosire",
    "ingombra": "ingombro",
    "ingombrai": "ingombrare",
    "ingombrammo": "ingombrare",
    "ingombran": "ingombrare",
    "ingombrando": "ingombrare",
    "ingombrano": "ingombrare",
    "ingombrante": "ingombrare",
    "ingombranti": "ingombrare",
    "ingombrar": "ingombrare",
    "ingombraron": "ingombrare",
    "ingombrarono": "ingombrare",
    "ingombrasse": "ingombrare",
    "ingombrasser": "ingombrare",
    "ingombrassero": "ingombrare",
    "ingombrassi": "ingombrare",
    "ingombrassimo": "ingombrare",
    "ingombraste": "ingombrare",
    "ingombrasti": "ingombrare",
    "ingombrata": "ingombrare",
    "ingombrate": "ingombrare",
    "ingombrati": "ingombrare",
    "ingombrato": "ingombrare",
    "ingombrava": "ingombrare",
    "ingombravamo": "ingombrare",
    "ingombravan": "ingombrare",
    "ingombravano": "ingombrare",
    "ingombravate": "ingombrare",
    "ingombravi": "ingombrare",
    "ingombravo": "ingombrare",
    "ingombre": "ingombro",
    "ingombrerai": "ingombrare",
    "ingombreran": "ingombrare",
    "ingombreranno": "ingombrare",
    "ingombrerebbe": "ingombrare",
    "ingombrerebber": "ingombrare",
    "ingombrerebbero": "ingombrare",
    "ingombrerei": "ingombrare",
    "ingombreremmo": "ingombrare",
    "ingombreremo": "ingombrare",
    "ingombrereste": "ingombrare",
    "ingombreresti": "ingombrare",
    "ingombrerete": "ingombrare",
    "ingombrerà": "ingombrare",
    "ingombrerò": "ingombrare",
    "ingombri": "ingombro",
    "ingombriamo": "ingombrare",
    "ingombriate": "ingombrare",
    "ingombrin": "ingombrare",
    "ingombrino": "ingombrare",
    "ingombro": "ingombrare",
    "ingombrò": "ingombrare",
    "ingomma": "ingommare",
    "ingommai": "ingommare",
    "ingommammo": "ingommare",
    "ingomman": "ingommare",
    "ingommando": "ingommare",
    "ingommano": "ingommare",
    "ingommante": "ingommare",
    "ingommanti": "ingommare",
    "ingommar": "ingommare",
    "ingommaron": "ingommare",
    "ingommarono": "ingommare",
    "ingommasse": "ingommare",
    "ingommasser": "ingommare",
    "ingommassero": "ingommare",
    "ingommassi": "ingommare",
    "ingommassimo": "ingommare",
    "ingommaste": "ingommare",
    "ingommasti": "ingommare",
    "ingommata": "ingommare",
    "ingommate": "ingommare",
    "ingommati": "ingommare",
    "ingommato": "ingommare",
    "ingommava": "ingommare",
    "ingommavamo": "ingommare",
    "ingommavan": "ingommare",
    "ingommavano": "ingommare",
    "ingommavate": "ingommare",
    "ingommavi": "ingommare",
    "ingommavo": "ingommare",
    "ingommerai": "ingommare",
    "ingommeran": "ingommare",
    "ingommeranno": "ingommare",
    "ingommerebbe": "ingommare",
    "ingommerebber": "ingommare",
    "ingommerebbero": "ingommare",
    "ingommerei": "ingommare",
    "ingommeremmo": "ingommare",
    "ingommeremo": "ingommare",
    "ingommereste": "ingommare",
    "ingommeresti": "ingommare",
    "ingommerete": "ingommare",
    "ingommerà": "ingommare",
    "ingommerò": "ingommare",
    "ingommi": "ingommare",
    "ingommiamo": "ingommare",
    "ingommiate": "ingommare",
    "ingommin": "ingommare",
    "ingommino": "ingommare",
    "ingommo": "ingommare",
    "ingommò": "ingommare",
    "ingorda": "ingordo",
    "ingorde": "ingordo",
    "ingordi": "ingordo",
    "ingordigie": "ingordigia",
    "ingorga": "ingorgare",
    "ingorgai": "ingorgare",
    "ingorgammo": "ingorgare",
    "ingorgan": "ingorgare",
    "ingorgando": "ingorgare",
    "ingorgano": "ingorgare",
    "ingorgante": "ingorgare",
    "ingorganti": "ingorgare",
    "ingorgar": "ingorgare",
    "ingorgaron": "ingorgare",
    "ingorgarono": "ingorgare",
    "ingorgasse": "ingorgare",
    "ingorgasser": "ingorgare",
    "ingorgassero": "ingorgare",
    "ingorgassi": "ingorgare",
    "ingorgassimo": "ingorgare",
    "ingorgaste": "ingorgare",
    "ingorgasti": "ingorgare",
    "ingorgata": "ingorgare",
    "ingorgate": "ingorgare",
    "ingorgati": "ingorgare",
    "ingorgato": "ingorgare",
    "ingorgava": "ingorgare",
    "ingorgavamo": "ingorgare",
    "ingorgavan": "ingorgare",
    "ingorgavano": "ingorgare",
    "ingorgavate": "ingorgare",
    "ingorgavi": "ingorgare",
    "ingorgavo": "ingorgare",
    "ingorgherai": "ingorgare",
    "ingorgheran": "ingorgare",
    "ingorgheranno": "ingorgare",
    "ingorgherebbe": "ingorgare",
    "ingorgherebber": "ingorgare",
    "ingorgherebbero": "ingorgare",
    "ingorgherei": "ingorgare",
    "ingorgheremmo": "ingorgare",
    "ingorgheremo": "ingorgare",
    "ingorghereste": "ingorgare",
    "ingorgheresti": "ingorgare",
    "ingorgherete": "ingorgare",
    "ingorgherà": "ingorgare",
    "ingorgherò": "ingorgare",
    "ingorghi": "ingorgo",
    "ingorghiamo": "ingorgare",
    "ingorghiate": "ingorgare",
    "ingorghin": "ingorgare",
    "ingorghino": "ingorgare",
    "ingorgo": "ingorgare",
    "ingorgò": "ingorgare",
    "ingovernabili": "ingovernabile",
    "ingozza": "ingozzare",
    "ingozzai": "ingozzare",
    "ingozzammo": "ingozzare",
    "ingozzan": "ingozzare",
    "ingozzando": "ingozzare",
    "ingozzano": "ingozzare",
    "ingozzante": "ingozzare",
    "ingozzanti": "ingozzare",
    "ingozzar": "ingozzare",
    "ingozzaron": "ingozzare",
    "ingozzarono": "ingozzare",
    "ingozzasse": "ingozzare",
    "ingozzasser": "ingozzare",
    "ingozzassero": "ingozzare",
    "ingozzassi": "ingozzare",
    "ingozzassimo": "ingozzare",
    "ingozzaste": "ingozzare",
    "ingozzasti": "ingozzare",
    "ingozzata": "ingozzare",
    "ingozzate": "ingozzare",
    "ingozzati": "ingozzare",
    "ingozzato": "ingozzare",
    "ingozzava": "ingozzare",
    "ingozzavamo": "ingozzare",
    "ingozzavan": "ingozzare",
    "ingozzavano": "ingozzare",
    "ingozzavate": "ingozzare",
    "ingozzavi": "ingozzare",
    "ingozzavo": "ingozzare",
    "ingozzerai": "ingozzare",
    "ingozzeran": "ingozzare",
    "ingozzeranno": "ingozzare",
    "ingozzerebbe": "ingozzare",
    "ingozzerebber": "ingozzare",
    "ingozzerebbero": "ingozzare",
    "ingozzerei": "ingozzare",
    "ingozzeremmo": "ingozzare",
    "ingozzeremo": "ingozzare",
    "ingozzereste": "ingozzare",
    "ingozzeresti": "ingozzare",
    "ingozzerete": "ingozzare",
    "ingozzerà": "ingozzare",
    "ingozzerò": "ingozzare",
    "ingozzi": "ingozzare",
    "ingozziamo": "ingozzare",
    "ingozziate": "ingozzare",
    "ingozzin": "ingozzare",
    "ingozzino": "ingozzare",
    "ingozzo": "ingozzare",
    "ingozzò": "ingozzare",
    "ingrana": "ingranare",
    "ingranaggi": "ingranaggio",
    "ingranai": "ingranare",
    "ingranammo": "ingranare",
    "ingranan": "ingranare",
    "ingranando": "ingranare",
    "ingranano": "ingranare",
    "ingranante": "ingranare",
    "ingrananti": "ingranare",
    "ingranar": "ingranare",
    "ingranaron": "ingranare",
    "ingranarono": "ingranare",
    "ingranasse": "ingranare",
    "ingranasser": "ingranare",
    "ingranassero": "ingranare",
    "ingranassi": "ingranare",
    "ingranassimo": "ingranare",
    "ingranaste": "ingranare",
    "ingranasti": "ingranare",
    "ingranata": "ingranare",
    "ingranate": "ingranare",
    "ingranati": "ingranare",
    "ingranato": "ingranare",
    "ingranava": "ingranare",
    "ingranavamo": "ingranare",
    "ingranavan": "ingranare",
    "ingranavano": "ingranare",
    "ingranavate": "ingranare",
    "ingranavi": "ingranare",
    "ingranavo": "ingranare",
    "ingrandendo": "ingrandire",
    "ingrandente": "ingrandire",
    "ingrandenti": "ingrandire",
    "ingrandiamo": "ingrandire",
    "ingrandiate": "ingrandire",
    "ingrandii": "ingrandire",
    "ingrandimenti": "ingrandimento",
    "ingrandimmo": "ingrandire",
    "ingrandir": "ingrandire",
    "ingrandirai": "ingrandire",
    "ingrandiran": "ingrandire",
    "ingrandiranno": "ingrandire",
    "ingrandirebbe": "ingrandire",
    "ingrandirebber": "ingrandire",
    "ingrandirebbero": "ingrandire",
    "ingrandirei": "ingrandire",
    "ingrandiremmo": "ingrandire",
    "ingrandiremo": "ingrandire",
    "ingrandireste": "ingrandire",
    "ingrandiresti": "ingrandire",
    "ingrandirete": "ingrandire",
    "ingrandiron": "ingrandire",
    "ingrandirono": "ingrandire",
    "ingrandirà": "ingrandire",
    "ingrandirò": "ingrandire",
    "ingrandisca": "ingrandire",
    "ingrandiscan": "ingrandire",
    "ingrandiscano": "ingrandire",
    "ingrandisce": "ingrandire",
    "ingrandisci": "ingrandire",
    "ingrandisco": "ingrandire",
    "ingrandiscon": "ingrandire",
    "ingrandiscono": "ingrandire",
    "ingrandisse": "ingrandire",
    "ingrandisser": "ingrandire",
    "ingrandissero": "ingrandire",
    "ingrandissi": "ingrandire",
    "ingrandissimo": "ingrandire",
    "ingrandiste": "ingrandire",
    "ingrandisti": "ingrandire",
    "ingrandita": "ingrandire",
    "ingrandite": "ingrandire",
    "ingranditi": "ingrandire",
    "ingrandito": "ingrandire",
    "ingrandiva": "ingrandire",
    "ingrandivamo": "ingrandire",
    "ingrandivan": "ingrandire",
    "ingrandivano": "ingrandire",
    "ingrandivate": "ingrandire",
    "ingrandivi": "ingrandire",
    "ingrandivo": "ingrandire",
    "ingrandì": "ingrandire",
    "ingranerai": "ingranare",
    "ingraneran": "ingranare",
    "ingraneranno": "ingranare",
    "ingranerebbe": "ingranare",
    "ingranerebber": "ingranare",
    "ingranerebbero": "ingranare",
    "ingranerei": "ingranare",
    "ingraneremmo": "ingranare",
    "ingraneremo": "ingranare",
    "ingranereste": "ingranare",
    "ingraneresti": "ingranare",
    "ingranerete": "ingranare",
    "ingranerà": "ingranare",
    "ingranerò": "ingranare",
    "ingrani": "ingranare",
    "ingraniamo": "ingranare",
    "ingraniate": "ingranare",
    "ingranin": "ingranare",
    "ingranino": "ingranare",
    "ingrano": "ingranare",
    "ingranò": "ingranare",
    "ingrassa": "ingrassare",
    "ingrassai": "ingrassare",
    "ingrassammo": "ingrassare",
    "ingrassan": "ingrassare",
    "ingrassando": "ingrassare",
    "ingrassano": "ingrassare",
    "ingrassante": "ingrassare",
    "ingrassanti": "ingrassare",
    "ingrassar": "ingrassare",
    "ingrassaron": "ingrassare",
    "ingrassarono": "ingrassare",
    "ingrassasse": "ingrassare",
    "ingrassasser": "ingrassare",
    "ingrassassero": "ingrassare",
    "ingrassassi": "ingrassare",
    "ingrassassimo": "ingrassare",
    "ingrassaste": "ingrassare",
    "ingrassasti": "ingrassare",
    "ingrassata": "ingrassare",
    "ingrassate": "ingrassare",
    "ingrassati": "ingrassare",
    "ingrassato": "ingrassare",
    "ingrassava": "ingrassare",
    "ingrassavamo": "ingrassare",
    "ingrassavan": "ingrassare",
    "ingrassavano": "ingrassare",
    "ingrassavate": "ingrassare",
    "ingrassavi": "ingrassare",
    "ingrassavo": "ingrassare",
    "ingrasserai": "ingrassare",
    "ingrasseran": "ingrassare",
    "ingrasseranno": "ingrassare",
    "ingrasserebbe": "ingrassare",
    "ingrasserebber": "ingrassare",
    "ingrasserebbero": "ingrassare",
    "ingrasserei": "ingrassare",
    "ingrasseremmo": "ingrassare",
    "ingrasseremo": "ingrassare",
    "ingrassereste": "ingrassare",
    "ingrasseresti": "ingrassare",
    "ingrasserete": "ingrassare",
    "ingrasserà": "ingrassare",
    "ingrasserò": "ingrassare",
    "ingrassi": "ingrassare",
    "ingrassiamo": "ingrassare",
    "ingrassiate": "ingrassare",
    "ingrassin": "ingrassare",
    "ingrassino": "ingrassare",
    "ingrasso": "ingrassare",
    "ingrassò": "ingrassare",
    "ingrata": "ingrato",
    "ingrate": "ingrato",
    "ingrati": "ingrato",
    "ingratitudini": "ingratitudine",
    "ingravida": "ingravidare",
    "ingravidai": "ingravidare",
    "ingravidammo": "ingravidare",
    "ingravidan": "ingravidare",
    "ingravidando": "ingravidare",
    "ingravidano": "ingravidare",
    "ingravidante": "ingravidare",
    "ingravidanti": "ingravidare",
    "ingravidar": "ingravidare",
    "ingravidaron": "ingravidare",
    "ingravidarono": "ingravidare",
    "ingravidasse": "ingravidare",
    "ingravidasser": "ingravidare",
    "ingravidassero": "ingravidare",
    "ingravidassi": "ingravidare",
    "ingravidassimo": "ingravidare",
    "ingravidaste": "ingravidare",
    "ingravidasti": "ingravidare",
    "ingravidata": "ingravidare",
    "ingravidate": "ingravidare",
    "ingravidati": "ingravidare",
    "ingravidato": "ingravidare",
    "ingravidava": "ingravidare",
    "ingravidavamo": "ingravidare",
    "ingravidavan": "ingravidare",
    "ingravidavano": "ingravidare",
    "ingravidavate": "ingravidare",
    "ingravidavi": "ingravidare",
    "ingravidavo": "ingravidare",
    "ingraviderai": "ingravidare",
    "ingravideran": "ingravidare",
    "ingravideranno": "ingravidare",
    "ingraviderebbe": "ingravidare",
    "ingraviderebber": "ingravidare",
    "ingraviderebbero": "ingravidare",
    "ingraviderei": "ingravidare",
    "ingravideremmo": "ingravidare",
    "ingravideremo": "ingravidare",
    "ingravidereste": "ingravidare",
    "ingravideresti": "ingravidare",
    "ingraviderete": "ingravidare",
    "ingraviderà": "ingravidare",
    "ingraviderò": "ingravidare",
    "ingravidi": "ingravidare",
    "ingravidiamo": "ingravidare",
    "ingravidiate": "ingravidare",
    "ingravidin": "ingravidare",
    "ingravidino": "ingravidare",
    "ingravido": "ingravidare",
    "ingravidò": "ingravidare",
    "ingrazi": "ingraziare",
    "ingrazia": "ingraziare",
    "ingraziai": "ingraziare",
    "ingraziammo": "ingraziare",
    "ingraziamo": "ingraziare",
    "ingrazian": "ingraziare",
    "ingraziando": "ingraziare",
    "ingraziano": "ingraziare",
    "ingraziante": "ingraziare",
    "ingrazianti": "ingraziare",
    "ingraziar": "ingraziare",
    "ingraziaron": "ingraziare",
    "ingraziarono": "ingraziare",
    "ingraziasse": "ingraziare",
    "ingraziasser": "ingraziare",
    "ingraziassero": "ingraziare",
    "ingraziassi": "ingraziare",
    "ingraziassimo": "ingraziare",
    "ingraziaste": "ingraziare",
    "ingraziasti": "ingraziare",
    "ingraziata": "ingraziare",
    "ingraziate": "ingraziare",
    "ingraziati": "ingraziare",
    "ingraziato": "ingraziare",
    "ingraziava": "ingraziare",
    "ingraziavamo": "ingraziare",
    "ingraziavan": "ingraziare",
    "ingraziavano": "ingraziare",
    "ingraziavate": "ingraziare",
    "ingraziavi": "ingraziare",
    "ingraziavo": "ingraziare",
    "ingrazierai": "ingraziare",
    "ingrazieran": "ingraziare",
    "ingrazieranno": "ingraziare",
    "ingrazierebbe": "ingraziare",
    "ingrazierebber": "ingraziare",
    "ingrazierebbero": "ingraziare",
    "ingrazierei": "ingraziare",
    "ingrazieremmo": "ingraziare",
    "ingrazieremo": "ingraziare",
    "ingraziereste": "ingraziare",
    "ingrazieresti": "ingraziare",
    "ingrazierete": "ingraziare",
    "ingrazierà": "ingraziare",
    "ingrazierò": "ingraziare",
    "ingrazin": "ingraziare",
    "ingrazino": "ingraziare",
    "ingrazio": "ingraziare",
    "ingraziò": "ingraziare",
    "ingredienti": "ingrediente",
    "ingressi": "ingresso",
    "ingrossa": "ingrossare",
    "ingrossai": "ingrossare",
    "ingrossammo": "ingrossare",
    "ingrossan": "ingrossare",
    "ingrossando": "ingrossare",
    "ingrossano": "ingrossare",
    "ingrossante": "ingrossare",
    "ingrossanti": "ingrossare",
    "ingrossar": "ingrossare",
    "ingrossaron": "ingrossare",
    "ingrossarono": "ingrossare",
    "ingrossasse": "ingrossare",
    "ingrossasser": "ingrossare",
    "ingrossassero": "ingrossare",
    "ingrossassi": "ingrossare",
    "ingrossassimo": "ingrossare",
    "ingrossaste": "ingrossare",
    "ingrossasti": "ingrossare",
    "ingrossata": "ingrossare",
    "ingrossate": "ingrossare",
    "ingrossati": "ingrossare",
    "ingrossato": "ingrossare",
    "ingrossava": "ingrossare",
    "ingrossavamo": "ingrossare",
    "ingrossavan": "ingrossare",
    "ingrossavano": "ingrossare",
    "ingrossavate": "ingrossare",
    "ingrossavi": "ingrossare",
    "ingrossavo": "ingrossare",
    "ingrosserai": "ingrossare",
    "ingrosseran": "ingrossare",
    "ingrosseranno": "ingrossare",
    "ingrosserebbe": "ingrossare",
    "ingrosserebber": "ingrossare",
    "ingrosserebbero": "ingrossare",
    "ingrosserei": "ingrossare",
    "ingrosseremmo": "ingrossare",
    "ingrosseremo": "ingrossare",
    "ingrossereste": "ingrossare",
    "ingrosseresti": "ingrossare",
    "ingrosserete": "ingrossare",
    "ingrosserà": "ingrossare",
    "ingrosserò": "ingrossare",
    "ingrossi": "ingrossare",
    "ingrossiamo": "ingrossare",
    "ingrossiate": "ingrossare",
    "ingrossin": "ingrossare",
    "ingrossino": "ingrossare",
    "ingrosso": "ingrossare",
    "ingrossò": "ingrossare",
    "inguai": "inguaiare",
    "inguaia": "inguaiare",
    "inguaiai": "inguaiare",
    "inguaiammo": "inguaiare",
    "inguaiamo": "inguaiare",
    "inguaian": "inguaiare",
    "inguaiando": "inguaiare",
    "inguaiano": "inguaiare",
    "inguaiante": "inguaiare",
    "inguaianti": "inguaiare",
    "inguaiar": "inguaiare",
    "inguaiaron": "inguaiare",
    "inguaiarono": "inguaiare",
    "inguaiasse": "inguaiare",
    "inguaiasser": "inguaiare",
    "inguaiassero": "inguaiare",
    "inguaiassi": "inguaiare",
    "inguaiassimo": "inguaiare",
    "inguaiaste": "inguaiare",
    "inguaiasti": "inguaiare",
    "inguaiata": "inguaiare",
    "inguaiate": "inguaiare",
    "inguaiati": "inguaiare",
    "inguaiato": "inguaiare",
    "inguaiava": "inguaiare",
    "inguaiavamo": "inguaiare",
    "inguaiavan": "inguaiare",
    "inguaiavano": "inguaiare",
    "inguaiavate": "inguaiare",
    "inguaiavi": "inguaiare",
    "inguaiavo": "inguaiare",
    "inguaierai": "inguaiare",
    "inguaieran": "inguaiare",
    "inguaieranno": "inguaiare",
    "inguaierebbe": "inguaiare",
    "inguaierebber": "inguaiare",
    "inguaierebbero": "inguaiare",
    "inguaierei": "inguaiare",
    "inguaieremmo": "inguaiare",
    "inguaieremo": "inguaiare",
    "inguaiereste": "inguaiare",
    "inguaieresti": "inguaiare",
    "inguaierete": "inguaiare",
    "inguaierà": "inguaiare",
    "inguaierò": "inguaiare",
    "inguain": "inguaiare",
    "inguaina": "inguainare",
    "inguainai": "inguainare",
    "inguainammo": "inguainare",
    "inguainan": "inguainare",
    "inguainando": "inguainare",
    "inguainano": "inguainare",
    "inguainante": "inguainare",
    "inguainanti": "inguainare",
    "inguainar": "inguainare",
    "inguainaron": "inguainare",
    "inguainarono": "inguainare",
    "inguainasse": "inguainare",
    "inguainasser": "inguainare",
    "inguainassero": "inguainare",
    "inguainassi": "inguainare",
    "inguainassimo": "inguainare",
    "inguainaste": "inguainare",
    "inguainasti": "inguainare",
    "inguainata": "inguainare",
    "inguainate": "inguainare",
    "inguainati": "inguainare",
    "inguainato": "inguainare",
    "inguainava": "inguainare",
    "inguainavamo": "inguainare",
    "inguainavan": "inguainare",
    "inguainavano": "inguainare",
    "inguainavate": "inguainare",
    "inguainavi": "inguainare",
    "inguainavo": "inguainare",
    "inguainerai": "inguainare",
    "inguaineran": "inguainare",
    "inguaineranno": "inguainare",
    "inguainerebbe": "inguainare",
    "inguainerebber": "inguainare",
    "inguainerebbero": "inguainare",
    "inguainerei": "inguainare",
    "inguaineremmo": "inguainare",
    "inguaineremo": "inguainare",
    "inguainereste": "inguainare",
    "inguaineresti": "inguainare",
    "inguainerete": "inguainare",
    "inguainerà": "inguainare",
    "inguainerò": "inguainare",
    "inguaini": "inguainare",
    "inguainiamo": "inguainare",
    "inguainiate": "inguainare",
    "inguainin": "inguainare",
    "inguainino": "inguainare",
    "inguaino": "inguainare",
    "inguainò": "inguainare",
    "inguaio": "inguaiare",
    "inguaiò": "inguaiare",
    "inguardabili": "inguardabile",
    "inguaribili": "inguaribile",
    "inguinali": "inguinale",
    "ingurgita": "ingurgitare",
    "ingurgitai": "ingurgitare",
    "ingurgitammo": "ingurgitare",
    "ingurgitan": "ingurgitare",
    "ingurgitando": "ingurgitare",
    "ingurgitano": "ingurgitare",
    "ingurgitante": "ingurgitare",
    "ingurgitanti": "ingurgitare",
    "ingurgitar": "ingurgitare",
    "ingurgitaron": "ingurgitare",
    "ingurgitarono": "ingurgitare",
    "ingurgitasse": "ingurgitare",
    "ingurgitasser": "ingurgitare",
    "ingurgitassero": "ingurgitare",
    "ingurgitassi": "ingurgitare",
    "ingurgitassimo": "ingurgitare",
    "ingurgitaste": "ingurgitare",
    "ingurgitasti": "ingurgitare",
    "ingurgitata": "ingurgitare",
    "ingurgitate": "ingurgitare",
    "ingurgitati": "ingurgitare",
    "ingurgitato": "ingurgitare",
    "ingurgitava": "ingurgitare",
    "ingurgitavamo": "ingurgitare",
    "ingurgitavan": "ingurgitare",
    "ingurgitavano": "ingurgitare",
    "ingurgitavate": "ingurgitare",
    "ingurgitavi": "ingurgitare",
    "ingurgitavo": "ingurgitare",
    "ingurgiterai": "ingurgitare",
    "ingurgiteran": "ingurgitare",
    "ingurgiteranno": "ingurgitare",
    "ingurgiterebbe": "ingurgitare",
    "ingurgiterebber": "ingurgitare",
    "ingurgiterebbero": "ingurgitare",
    "ingurgiterei": "ingurgitare",
    "ingurgiteremmo": "ingurgitare",
    "ingurgiteremo": "ingurgitare",
    "ingurgitereste": "ingurgitare",
    "ingurgiteresti": "ingurgitare",
    "ingurgiterete": "ingurgitare",
    "ingurgiterà": "ingurgitare",
    "ingurgiterò": "ingurgitare",
    "ingurgiti": "ingurgitare",
    "ingurgitiamo": "ingurgitare",
    "ingurgitiate": "ingurgitare",
    "ingurgitin": "ingurgitare",
    "ingurgitino": "ingurgitare",
    "ingurgito": "ingurgitare",
    "ingurgitò": "ingurgitare",
    "inibendo": "inibire",
    "inibente": "inibire",
    "inibenti": "inibire",
    "inibiamo": "inibire",
    "inibiate": "inibire",
    "inibii": "inibire",
    "inibimmo": "inibire",
    "inibir": "inibire",
    "inibirai": "inibire",
    "inibiran": "inibire",
    "inibiranno": "inibire",
    "inibirebbe": "inibire",
    "inibirebber": "inibire",
    "inibirebbero": "inibire",
    "inibirei": "inibire",
    "inibiremmo": "inibire",
    "inibiremo": "inibire",
    "inibireste": "inibire",
    "inibiresti": "inibire",
    "inibirete": "inibire",
    "inibiron": "inibire",
    "inibirono": "inibire",
    "inibirà": "inibire",
    "inibirò": "inibire",
    "inibisca": "inibire",
    "inibiscan": "inibire",
    "inibiscano": "inibire",
    "inibisce": "inibire",
    "inibisci": "inibire",
    "inibisco": "inibire",
    "inibiscon": "inibire",
    "inibiscono": "inibire",
    "inibisse": "inibire",
    "inibisser": "inibire",
    "inibissero": "inibire",
    "inibissi": "inibire",
    "inibissimo": "inibire",
    "inibiste": "inibire",
    "inibisti": "inibire",
    "inibita": "inibito",
    "inibite": "inibito",
    "inibiti": "inibito",
    "inibito": "inibire",
    "inibitori": "inibitorio",
    "inibitoria": "inibitorio",
    "inibitorie": "inibitorio",
    "inibitrice": "inibitore",
    "inibitrici": "inibitore",
    "inibiva": "inibire",
    "inibivamo": "inibire",
    "inibivan": "inibire",
    "inibivano": "inibire",
    "inibivate": "inibire",
    "inibivi": "inibire",
    "inibivo": "inibire",
    "inibizioni": "inibizione",
    "inibì": "inibire",
    "inidonea": "inidoneo",
    "inidonee": "inidoneo",
    "inidonei": "inidoneo",
    "inietta": "iniettare",
    "iniettai": "iniettare",
    "iniettammo": "iniettare",
    "iniettan": "iniettare",
    "iniettando": "iniettare",
    "iniettano": "iniettare",
    "iniettante": "iniettare",
    "iniettanti": "iniettare",
    "iniettar": "iniettare",
    "iniettaron": "iniettare",
    "iniettarono": "iniettare",
    "iniettasse": "iniettare",
    "iniettasser": "iniettare",
    "iniettassero": "iniettare",
    "iniettassi": "iniettare",
    "iniettassimo": "iniettare",
    "iniettaste": "iniettare",
    "iniettasti": "iniettare",
    "iniettata": "iniettare",
    "iniettate": "iniettare",
    "iniettati": "iniettare",
    "iniettato": "iniettare",
    "iniettava": "iniettare",
    "iniettavamo": "iniettare",
    "iniettavan": "iniettare",
    "iniettavano": "iniettare",
    "iniettavate": "iniettare",
    "iniettavi": "iniettare",
    "iniettavo": "iniettare",
    "inietterai": "iniettare",
    "inietteran": "iniettare",
    "inietteranno": "iniettare",
    "inietterebbe": "iniettare",
    "inietterebber": "iniettare",
    "inietterebbero": "iniettare",
    "inietterei": "iniettare",
    "inietteremmo": "iniettare",
    "inietteremo": "iniettare",
    "iniettereste": "iniettare",
    "inietteresti": "iniettare",
    "inietterete": "iniettare",
    "inietterà": "iniettare",
    "inietterò": "iniettare",
    "inietti": "iniettare",
    "iniettiamo": "iniettare",
    "iniettiate": "iniettare",
    "iniettin": "iniettare",
    "iniettino": "iniettare",
    "inietto": "iniettare",
    "iniettò": "iniettare",
    "iniezioni": "iniezione",
    "inimica": "inimicare",
    "inimicai": "inimicare",
    "inimicammo": "inimicare",
    "inimican": "inimicare",
    "inimicando": "inimicare",
    "inimicano": "inimicare",
    "inimicante": "inimicare",
    "inimicanti": "inimicare",
    "inimicar": "inimicare",
    "inimicaron": "inimicare",
    "inimicarono": "inimicare",
    "inimicasse": "inimicare",
    "inimicasser": "inimicare",
    "inimicassero": "inimicare",
    "inimicassi": "inimicare",
    "inimicassimo": "inimicare",
    "inimicaste": "inimicare",
    "inimicasti": "inimicare",
    "inimicata": "inimicare",
    "inimicate": "inimicare",
    "inimicati": "inimicare",
    "inimicato": "inimicare",
    "inimicava": "inimicare",
    "inimicavamo": "inimicare",
    "inimicavan": "inimicare",
    "inimicavano": "inimicare",
    "inimicavate": "inimicare",
    "inimicavi": "inimicare",
    "inimicavo": "inimicare",
    "inimicherai": "inimicare",
    "inimicheran": "inimicare",
    "inimicheranno": "inimicare",
    "inimicherebbe": "inimicare",
    "inimicherebber": "inimicare",
    "inimicherebbero": "inimicare",
    "inimicherei": "inimicare",
    "inimicheremmo": "inimicare",
    "inimicheremo": "inimicare",
    "inimichereste": "inimicare",
    "inimicheresti": "inimicare",
    "inimicherete": "inimicare",
    "inimicherà": "inimicare",
    "inimicherò": "inimicare",
    "inimichi": "inimicare",
    "inimichiamo": "inimicare",
    "inimichiate": "inimicare",
    "inimichin": "inimicare",
    "inimichino": "inimicare",
    "inimicizie": "inimicizia",
    "inimico": "inimicare",
    "inimicò": "inimicare",
    "inimitabili": "inimitabile",
    "inimmaginabili": "inimmaginabile",
    "ininfiammabili": "ininfiammabile",
    "ininfluenti": "ininfluente",
    "inintelleggibili": "inintelleggibile",
    "inintelligibili": "inintelligibile",
    "ininterrotta": "ininterrotto",
    "ininterrotte": "ininterrotto",
    "ininterrotti": "ininterrotto",
    "iniqua": "iniquo",
    "inique": "iniquo",
    "iniqui": "iniquo",
    "inizi": "inizio",
    "inizia": "iniziare",
    "iniziai": "iniziare",
    "iniziali": "iniziale",
    "iniziammo": "iniziare",
    "iniziamo": "iniziare",
    "inizian": "iniziare",
    "iniziando": "iniziare",
    "iniziano": "iniziare",
    "iniziante": "iniziare",
    "inizianti": "iniziare",
    "iniziar": "iniziare",
    "iniziaron": "iniziare",
    "iniziarono": "iniziare",
    "iniziasse": "iniziare",
    "iniziasser": "iniziare",
    "iniziassero": "iniziare",
    "iniziassi": "iniziare",
    "iniziassimo": "iniziare",
    "iniziaste": "iniziare",
    "iniziasti": "iniziare",
    "iniziata": "iniziato",
    "iniziate": "iniziato",
    "iniziati": "iniziato",
    "iniziative": "iniziativa",
    "iniziato": "iniziare",
    "iniziatori": "iniziatore",
    "iniziatrice": "iniziatore",
    "iniziatrici": "iniziatore",
    "iniziava": "iniziare",
    "iniziavamo": "iniziare",
    "iniziavan": "iniziare",
    "iniziavano": "iniziare",
    "iniziavate": "iniziare",
    "iniziavi": "iniziare",
    "iniziavo": "iniziare",
    "iniziazioni": "iniziazione",
    "inizierai": "iniziare",
    "inizieran": "iniziare",
    "inizieranno": "iniziare",
    "inizierebbe": "iniziare",
    "inizierebber": "iniziare",
    "inizierebbero": "iniziare",
    "inizierei": "iniziare",
    "inizieremmo": "iniziare",
    "inizieremo": "iniziare",
    "iniziereste": "iniziare",
    "inizieresti": "iniziare",
    "inizierete": "iniziare",
    "inizierà": "iniziare",
    "inizierò": "iniziare",
    "inizin": "iniziare",
    "inizino": "iniziare",
    "inizio": "iniziare",
    "iniziò": "iniziare",
    "innaffi": "innaffiare",
    "innaffia": "innaffiare",
    "innaffiai": "innaffiare",
    "innaffiammo": "innaffiare",
    "innaffiamo": "innaffiare",
    "innaffian": "innaffiare",
    "innaffiando": "innaffiare",
    "innaffiano": "innaffiare",
    "innaffiante": "innaffiare",
    "innaffianti": "innaffiare",
    "innaffiar": "innaffiare",
    "innaffiaron": "innaffiare",
    "innaffiarono": "innaffiare",
    "innaffiasse": "innaffiare",
    "innaffiasser": "innaffiare",
    "innaffiassero": "innaffiare",
    "innaffiassi": "innaffiare",
    "innaffiassimo": "innaffiare",
    "innaffiaste": "innaffiare",
    "innaffiasti": "innaffiare",
    "innaffiata": "innaffiare",
    "innaffiate": "innaffiare",
    "innaffiati": "innaffiare",
    "innaffiato": "innaffiare",
    "innaffiava": "innaffiare",
    "innaffiavamo": "innaffiare",
    "innaffiavan": "innaffiare",
    "innaffiavano": "innaffiare",
    "innaffiavate": "innaffiare",
    "innaffiavi": "innaffiare",
    "innaffiavo": "innaffiare",
    "innaffierai": "innaffiare",
    "innaffieran": "innaffiare",
    "innaffieranno": "innaffiare",
    "innaffierebbe": "innaffiare",
    "innaffierebber": "innaffiare",
    "innaffierebbero": "innaffiare",
    "innaffierei": "innaffiare",
    "innaffieremmo": "innaffiare",
    "innaffieremo": "innaffiare",
    "innaffiereste": "innaffiare",
    "innaffieresti": "innaffiare",
    "innaffierete": "innaffiare",
    "innaffierà": "innaffiare",
    "innaffierò": "innaffiare",
    "innaffin": "innaffiare",
    "innaffino": "innaffiare",
    "innaffio": "innaffiare",
    "innaffiò": "innaffiare",
    "innalza": "innalzare",
    "innalzai": "innalzare",
    "innalzamenti": "innalzamento",
    "innalzammo": "innalzare",
    "innalzan": "innalzare",
    "innalzando": "innalzare",
    "innalzano": "innalzare",
    "innalzante": "innalzare",
    "innalzanti": "innalzare",
    "innalzar": "innalzare",
    "innalzaron": "innalzare",
    "innalzarono": "innalzare",
    "innalzasse": "innalzare",
    "innalzasser": "innalzare",
    "innalzassero": "innalzare",
    "innalzassi": "innalzare",
    "innalzassimo": "innalzare",
    "innalzaste": "innalzare",
    "innalzasti": "innalzare",
    "innalzata": "innalzare",
    "innalzate": "innalzare",
    "innalzati": "innalzare",
    "innalzato": "innalzare",
    "innalzava": "innalzare",
    "innalzavamo": "innalzare",
    "innalzavan": "innalzare",
    "innalzavano": "innalzare",
    "innalzavate": "innalzare",
    "innalzavi": "innalzare",
    "innalzavo": "innalzare",
    "innalzerai": "innalzare",
    "innalzeran": "innalzare",
    "innalzeranno": "innalzare",
    "innalzerebbe": "innalzare",
    "innalzerebber": "innalzare",
    "innalzerebbero": "innalzare",
    "innalzerei": "innalzare",
    "innalzeremmo": "innalzare",
    "innalzeremo": "innalzare",
    "innalzereste": "innalzare",
    "innalzeresti": "innalzare",
    "innalzerete": "innalzare",
    "innalzerà": "innalzare",
    "innalzerò": "innalzare",
    "innalzi": "innalzare",
    "innalziamo": "innalzare",
    "innalziate": "innalzare",
    "innalzin": "innalzare",
    "innalzino": "innalzare",
    "innalzo": "innalzare",
    "innalzò": "innalzare",
    "innamora": "innamorare",
    "innamorai": "innamorare",
    "innamoramenti": "innamoramento",
    "innamorammo": "innamorare",
    "innamoran": "innamorare",
    "innamorando": "innamorare",
    "innamorano": "innamorare",
    "innamorante": "innamorare",
    "innamoranti": "innamorare",
    "innamorar": "innamorare",
    "innamoraron": "innamorare",
    "innamorarono": "innamorare",
    "innamorasse": "innamorare",
    "innamorasser": "innamorare",
    "innamorassero": "innamorare",
    "innamorassi": "innamorare",
    "innamorassimo": "innamorare",
    "innamoraste": "innamorare",
    "innamorasti": "innamorare",
    "innamorata": "innamorato",
    "innamorate": "innamorato",
    "innamorati": "innamorato",
    "innamorato": "innamorare",
    "innamorava": "innamorare",
    "innamoravamo": "innamorare",
    "innamoravan": "innamorare",
    "innamoravano": "innamorare",
    "innamoravate": "innamorare",
    "innamoravi": "innamorare",
    "innamoravo": "innamorare",
    "innamorerai": "innamorare",
    "innamoreran": "innamorare",
    "innamoreranno": "innamorare",
    "innamorerebbe": "innamorare",
    "innamorerebber": "innamorare",
    "innamorerebbero": "innamorare",
    "innamorerei": "innamorare",
    "innamoreremmo": "innamorare",
    "innamoreremo": "innamorare",
    "innamorereste": "innamorare",
    "innamoreresti": "innamorare",
    "innamorerete": "innamorare",
    "innamorerà": "innamorare",
    "innamorerò": "innamorare",
    "innamori": "innamorare",
    "innamoriamo": "innamorare",
    "innamoriate": "innamorare",
    "innamorin": "innamorare",
    "innamorino": "innamorare",
    "innamoro": "innamorare",
    "innamorò": "innamorare",
    "innata": "innato",
    "innate": "innato",
    "innati": "innato",
    "innaturali": "innaturale",
    "innegabili": "innegabile",
    "inneggerai": "inneggiare",
    "inneggeran": "inneggiare",
    "inneggeranno": "inneggiare",
    "inneggerebbe": "inneggiare",
    "inneggerebber": "inneggiare",
    "inneggerebbero": "inneggiare",
    "inneggerei": "inneggiare",
    "inneggeremmo": "inneggiare",
    "inneggeremo": "inneggiare",
    "inneggereste": "inneggiare",
    "inneggeresti": "inneggiare",
    "inneggerete": "inneggiare",
    "inneggerà": "inneggiare",
    "inneggerò": "inneggiare",
    "inneggi": "inneggiare",
    "inneggia": "inneggiare",
    "inneggiai": "inneggiare",
    "inneggiammo": "inneggiare",
    "inneggiamo": "inneggiare",
    "inneggian": "inneggiare",
    "inneggiando": "inneggiare",
    "inneggiano": "inneggiare",
    "inneggiante": "inneggiare",
    "inneggianti": "inneggiare",
    "inneggiar": "inneggiare",
    "inneggiaron": "inneggiare",
    "inneggiarono": "inneggiare",
    "inneggiasse": "inneggiare",
    "inneggiasser": "inneggiare",
    "inneggiassero": "inneggiare",
    "inneggiassi": "inneggiare",
    "inneggiassimo": "inneggiare",
    "inneggiaste": "inneggiare",
    "inneggiasti": "inneggiare",
    "inneggiata": "inneggiare",
    "inneggiate": "inneggiare",
    "inneggiati": "inneggiare",
    "inneggiato": "inneggiare",
    "inneggiava": "inneggiare",
    "inneggiavamo": "inneggiare",
    "inneggiavan": "inneggiare",
    "inneggiavano": "inneggiare",
    "inneggiavate": "inneggiare",
    "inneggiavi": "inneggiare",
    "inneggiavo": "inneggiare",
    "inneggin": "inneggiare",
    "inneggino": "inneggiare",
    "inneggio": "inneggiare",
    "inneggiò": "inneggiare",
    "innerva": "innervare",
    "innervai": "innervare",
    "innervammo": "innervare",
    "innervan": "innervare",
    "innervando": "innervare",
    "innervano": "innervare",
    "innervante": "innervare",
    "innervanti": "innervare",
    "innervar": "innervare",
    "innervaron": "innervare",
    "innervarono": "innervare",
    "innervasse": "innervare",
    "innervasser": "innervare",
    "innervassero": "innervare",
    "innervassi": "innervare",
    "innervassimo": "innervare",
    "innervaste": "innervare",
    "innervasti": "innervare",
    "innervata": "innervare",
    "innervate": "innervare",
    "innervati": "innervare",
    "innervato": "innervare",
    "innervava": "innervare",
    "innervavamo": "innervare",
    "innervavan": "innervare",
    "innervavano": "innervare",
    "innervavate": "innervare",
    "innervavi": "innervare",
    "innervavo": "innervare",
    "innerverai": "innervare",
    "innerveran": "innervare",
    "innerveranno": "innervare",
    "innerverebbe": "innervare",
    "innerverebber": "innervare",
    "innerverebbero": "innervare",
    "innerverei": "innervare",
    "innerveremmo": "innervare",
    "innerveremo": "innervare",
    "innervereste": "innervare",
    "innerveresti": "innervare",
    "innerverete": "innervare",
    "innerverà": "innervare",
    "innerverò": "innervare",
    "innervi": "innervare",
    "innerviamo": "innervare",
    "innerviate": "innervare",
    "innervin": "innervare",
    "innervino": "innervare",
    "innervo": "innervare",
    "innervosendo": "innervosire",
    "innervosente": "innervosire",
    "innervosenti": "innervosire",
    "innervosiamo": "innervosire",
    "innervosiate": "innervosire",
    "innervosii": "innervosire",
    "innervosimmo": "innervosire",
    "innervosir": "innervosire",
    "innervosirai": "innervosire",
    "innervosiran": "innervosire",
    "innervosiranno": "innervosire",
    "innervosirebbe": "innervosire",
    "innervosirebber": "innervosire",
    "innervosirebbero": "innervosire",
    "innervosirei": "innervosire",
    "innervosiremmo": "innervosire",
    "innervosiremo": "innervosire",
    "innervosireste": "innervosire",
    "innervosiresti": "innervosire",
    "innervosirete": "innervosire",
    "innervosiron": "innervosire",
    "innervosirono": "innervosire",
    "innervosirà": "innervosire",
    "innervosirò": "innervosire",
    "innervosisca": "innervosire",
    "innervosiscan": "innervosire",
    "innervosiscano": "innervosire",
    "innervosisce": "innervosire",
    "innervosisci": "innervosire",
    "innervosisco": "innervosire",
    "innervosiscon": "innervosire",
    "innervosiscono": "innervosire",
    "innervosisse": "innervosire",
    "innervosisser": "innervosire",
    "innervosissero": "innervosire",
    "innervosissi": "innervosire",
    "innervosissimo": "innervosire",
    "innervosiste": "innervosire",
    "innervosisti": "innervosire",
    "innervosita": "innervosire",
    "innervosite": "innervosire",
    "innervositi": "innervosire",
    "innervosito": "innervosire",
    "innervosiva": "innervosire",
    "innervosivamo": "innervosire",
    "innervosivan": "innervosire",
    "innervosivano": "innervosire",
    "innervosivate": "innervosire",
    "innervosivi": "innervosire",
    "innervosivo": "innervosire",
    "innervosì": "innervosire",
    "innervò": "innervare",
    "innesca": "innescare",
    "innescai": "innescare",
    "innescammo": "innescare",
    "innescan": "innescare",
    "innescando": "innescare",
    "innescano": "innescare",
    "innescante": "innescare",
    "innescanti": "innescare",
    "innescar": "innescare",
    "innescaron": "innescare",
    "innescarono": "innescare",
    "innescasse": "innescare",
    "innescasser": "innescare",
    "innescassero": "innescare",
    "innescassi": "innescare",
    "innescassimo": "innescare",
    "innescaste": "innescare",
    "innescasti": "innescare",
    "innescata": "innescare",
    "innescate": "innescare",
    "innescati": "innescare",
    "innescato": "innescare",
    "innescava": "innescare",
    "innescavamo": "innescare",
    "innescavan": "innescare",
    "innescavano": "innescare",
    "innescavate": "innescare",
    "innescavi": "innescare",
    "innescavo": "innescare",
    "innescherai": "innescare",
    "innescheran": "innescare",
    "innescheranno": "innescare",
    "innescherebbe": "innescare",
    "innescherebber": "innescare",
    "innescherebbero": "innescare",
    "innescherei": "innescare",
    "innescheremmo": "innescare",
    "innescheremo": "innescare",
    "inneschereste": "innescare",
    "innescheresti": "innescare",
    "innescherete": "innescare",
    "innescherà": "innescare",
    "innescherò": "innescare",
    "inneschi": "innesco",
    "inneschiamo": "innescare",
    "inneschiate": "innescare",
    "inneschin": "innescare",
    "inneschino": "innescare",
    "innesco": "innescare",
    "innescò": "innescare",
    "innesta": "innestare",
    "innestai": "innestare",
    "innestammo": "innestare",
    "innestan": "innestare",
    "innestando": "innestare",
    "innestano": "innestare",
    "innestante": "innestare",
    "innestanti": "innestare",
    "innestar": "innestare",
    "innestaron": "innestare",
    "innestarono": "innestare",
    "innestasse": "innestare",
    "innestasser": "innestare",
    "innestassero": "innestare",
    "innestassi": "innestare",
    "innestassimo": "innestare",
    "innestaste": "innestare",
    "innestasti": "innestare",
    "innestata": "innestare",
    "innestate": "innestare",
    "innestati": "innestare",
    "innestato": "innestare",
    "innestava": "innestare",
    "innestavamo": "innestare",
    "innestavan": "innestare",
    "innestavano": "innestare",
    "innestavate": "innestare",
    "innestavi": "innestare",
    "innestavo": "innestare",
    "innesterai": "innestare",
    "innesteran": "innestare",
    "innesteranno": "innestare",
    "innesterebbe": "innestare",
    "innesterebber": "innestare",
    "innesterebbero": "innestare",
    "innesterei": "innestare",
    "innesteremmo": "innestare",
    "innesteremo": "innestare",
    "innestereste": "innestare",
    "innesteresti": "innestare",
    "innesterete": "innestare",
    "innesterà": "innestare",
    "innesterò": "innestare",
    "innesti": "innesto",
    "innestiamo": "innestare",
    "innestiate": "innestare",
    "innestin": "innestare",
    "innestino": "innestare",
    "innesto": "innestare",
    "innestò": "innestare",
    "inni": "inno",
    "innocenti": "innocente",
    "innocenze": "innocenza",
    "innocua": "innocuo",
    "innocue": "innocuo",
    "innocui": "innocuo",
    "innominata": "innominato",
    "innominate": "innominato",
    "innominati": "innominato",
    "innova": "innovare",
    "innovai": "innovare",
    "innovammo": "innovare",
    "innovan": "innovare",
    "innovando": "innovare",
    "innovano": "innovare",
    "innovante": "innovare",
    "innovanti": "innovare",
    "innovar": "innovare",
    "innovaron": "innovare",
    "innovarono": "innovare",
    "innovasse": "innovare",
    "innovasser": "innovare",
    "innovassero": "innovare",
    "innovassi": "innovare",
    "innovassimo": "innovare",
    "innovaste": "innovare",
    "innovasti": "innovare",
    "innovata": "innovare",
    "innovate": "innovare",
    "innovati": "innovare",
    "innovativa": "innovativo",
    "innovative": "innovativo",
    "innovativi": "innovativo",
    "innovato": "innovare",
    "innovatori": "innovatore",
    "innovatrice": "innovatore",
    "innovatrici": "innovatore",
    "innovava": "innovare",
    "innovavamo": "innovare",
    "innovavan": "innovare",
    "innovavano": "innovare",
    "innovavate": "innovare",
    "innovavi": "innovare",
    "innovavo": "innovare",
    "innovazioni": "innovazione",
    "innoverai": "innovare",
    "innoveran": "innovare",
    "innoveranno": "innovare",
    "innoverebbe": "innovare",
    "innoverebber": "innovare",
    "innoverebbero": "innovare",
    "innoverei": "innovare",
    "innoveremmo": "innovare",
    "innoveremo": "innovare",
    "innovereste": "innovare",
    "innoveresti": "innovare",
    "innoverete": "innovare",
    "innoverà": "innovare",
    "innoverò": "innovare",
    "innovi": "innovare",
    "innoviamo": "innovare",
    "innoviate": "innovare",
    "innovin": "innovare",
    "innovino": "innovare",
    "innovo": "innovare",
    "innovò": "innovare",
    "innumerevoli": "innumerevole",
    "inocula": "inoculare",
    "inoculabili": "inoculabile",
    "inoculai": "inoculare",
    "inoculammo": "inoculare",
    "inoculan": "inoculare",
    "inoculando": "inoculare",
    "inoculano": "inoculare",
    "inoculante": "inoculare",
    "inoculanti": "inoculare",
    "inocular": "inoculare",
    "inocularon": "inoculare",
    "inocularono": "inoculare",
    "inoculasse": "inoculare",
    "inoculasser": "inoculare",
    "inoculassero": "inoculare",
    "inoculassi": "inoculare",
    "inoculassimo": "inoculare",
    "inoculaste": "inoculare",
    "inoculasti": "inoculare",
    "inoculata": "inoculare",
    "inoculate": "inoculare",
    "inoculati": "inoculare",
    "inoculato": "inoculare",
    "inoculava": "inoculare",
    "inoculavamo": "inoculare",
    "inoculavan": "inoculare",
    "inoculavano": "inoculare",
    "inoculavate": "inoculare",
    "inoculavi": "inoculare",
    "inoculavo": "inoculare",
    "inoculerai": "inoculare",
    "inoculeran": "inoculare",
    "inoculeranno": "inoculare",
    "inoculerebbe": "inoculare",
    "inoculerebber": "inoculare",
    "inoculerebbero": "inoculare",
    "inoculerei": "inoculare",
    "inoculeremmo": "inoculare",
    "inoculeremo": "inoculare",
    "inoculereste": "inoculare",
    "inoculeresti": "inoculare",
    "inoculerete": "inoculare",
    "inoculerà": "inoculare",
    "inoculerò": "inoculare",
    "inoculi": "inoculare",
    "inoculiamo": "inoculare",
    "inoculiate": "inoculare",
    "inoculin": "inoculare",
    "inoculino": "inoculare",
    "inoculo": "inoculare",
    "inoculò": "inoculare",
    "inodora": "inodoro",
    "inodore": "inodoro",
    "inodori": "inodoro",
    "inoffensiva": "inoffensivo",
    "inoffensive": "inoffensivo",
    "inoffensivi": "inoffensivo",
    "inoltra": "inoltrare",
    "inoltrai": "inoltrare",
    "inoltrammo": "inoltrare",
    "inoltran": "inoltrare",
    "inoltrando": "inoltrare",
    "inoltrano": "inoltrare",
    "inoltrante": "inoltrare",
    "inoltranti": "inoltrare",
    "inoltrar": "inoltrare",
    "inoltraron": "inoltrare",
    "inoltrarono": "inoltrare",
    "inoltrasse": "inoltrare",
    "inoltrasser": "inoltrare",
    "inoltrassero": "inoltrare",
    "inoltrassi": "inoltrare",
    "inoltrassimo": "inoltrare",
    "inoltraste": "inoltrare",
    "inoltrasti": "inoltrare",
    "inoltrata": "inoltrato",
    "inoltrate": "inoltrato",
    "inoltrati": "inoltrato",
    "inoltrato": "inoltrare",
    "inoltrava": "inoltrare",
    "inoltravamo": "inoltrare",
    "inoltravan": "inoltrare",
    "inoltravano": "inoltrare",
    "inoltravate": "inoltrare",
    "inoltravi": "inoltrare",
    "inoltravo": "inoltrare",
    "inoltrerai": "inoltrare",
    "inoltreran": "inoltrare",
    "inoltreranno": "inoltrare",
    "inoltrerebbe": "inoltrare",
    "inoltrerebber": "inoltrare",
    "inoltrerebbero": "inoltrare",
    "inoltrerei": "inoltrare",
    "inoltreremmo": "inoltrare",
    "inoltreremo": "inoltrare",
    "inoltrereste": "inoltrare",
    "inoltreresti": "inoltrare",
    "inoltrerete": "inoltrare",
    "inoltrerà": "inoltrare",
    "inoltrerò": "inoltrare",
    "inoltri": "inoltrare",
    "inoltriamo": "inoltrare",
    "inoltriate": "inoltrare",
    "inoltrin": "inoltrare",
    "inoltrino": "inoltrare",
    "inoltro": "inoltrare",
    "inoltrò": "inoltrare",
    "inonda": "inondare",
    "inondai": "inondare",
    "inondammo": "inondare",
    "inondan": "inondare",
    "inondando": "inondare",
    "inondano": "inondare",
    "inondante": "inondare",
    "inondanti": "inondare",
    "inondar": "inondare",
    "inondaron": "inondare",
    "inondarono": "inondare",
    "inondasse": "inondare",
    "inondasser": "inondare",
    "inondassero": "inondare",
    "inondassi": "inondare",
    "inondassimo": "inondare",
    "inondaste": "inondare",
    "inondasti": "inondare",
    "inondata": "inondare",
    "inondate": "inondare",
    "inondati": "inondare",
    "inondato": "inondare",
    "inondava": "inondare",
    "inondavamo": "inondare",
    "inondavan": "inondare",
    "inondavano": "inondare",
    "inondavate": "inondare",
    "inondavi": "inondare",
    "inondavo": "inondare",
    "inondazioni": "inondazione",
    "inonderai": "inondare",
    "inonderan": "inondare",
    "inonderanno": "inondare",
    "inonderebbe": "inondare",
    "inonderebber": "inondare",
    "inonderebbero": "inondare",
    "inonderei": "inondare",
    "inonderemmo": "inondare",
    "inonderemo": "inondare",
    "inondereste": "inondare",
    "inonderesti": "inondare",
    "inonderete": "inondare",
    "inonderà": "inondare",
    "inonderò": "inondare",
    "inondi": "inondare",
    "inondiamo": "inondare",
    "inondiate": "inondare",
    "inondin": "inondare",
    "inondino": "inondare",
    "inondo": "inondare",
    "inondò": "inondare",
    "inoperosa": "inoperoso",
    "inoperose": "inoperoso",
    "inoperosi": "inoperoso",
    "inopinata": "inopinato",
    "inopinate": "inopinato",
    "inopinati": "inopinato",
    "inopportuna": "inopportuno",
    "inopportune": "inopportuno",
    "inopportuni": "inopportuno",
    "inoppugnabili": "inoppugnabile",
    "inorganica": "inorganico",
    "inorganiche": "inorganico",
    "inorganici": "inorganico",
    "inorgoglendo": "inorgoglire",
    "inorgoglente": "inorgoglire",
    "inorgoglenti": "inorgoglire",
    "inorgogliamo": "inorgoglire",
    "inorgogliate": "inorgoglire",
    "inorgoglii": "inorgoglire",
    "inorgoglimmo": "inorgoglire",
    "inorgoglir": "inorgoglire",
    "inorgoglirai": "inorgoglire",
    "inorgogliran": "inorgoglire",
    "inorgogliranno": "inorgoglire",
    "inorgoglirebbe": "inorgoglire",
    "inorgoglirebber": "inorgoglire",
    "inorgoglirebbero": "inorgoglire",
    "inorgoglirei": "inorgoglire",
    "inorgogliremmo": "inorgoglire",
    "inorgogliremo": "inorgoglire",
    "inorgoglireste": "inorgoglire",
    "inorgogliresti": "inorgoglire",
    "inorgoglirete": "inorgoglire",
    "inorgogliron": "inorgoglire",
    "inorgoglirono": "inorgoglire",
    "inorgoglirà": "inorgoglire",
    "inorgoglirò": "inorgoglire",
    "inorgoglisca": "inorgoglire",
    "inorgogliscan": "inorgoglire",
    "inorgogliscano": "inorgoglire",
    "inorgoglisce": "inorgoglire",
    "inorgoglisci": "inorgoglire",
    "inorgoglisco": "inorgoglire",
    "inorgogliscon": "inorgoglire",
    "inorgogliscono": "inorgoglire",
    "inorgoglisse": "inorgoglire",
    "inorgoglisser": "inorgoglire",
    "inorgoglissero": "inorgoglire",
    "inorgoglissi": "inorgoglire",
    "inorgoglissimo": "inorgoglire",
    "inorgogliste": "inorgoglire",
    "inorgoglisti": "inorgoglire",
    "inorgoglita": "inorgoglire",
    "inorgoglite": "inorgoglire",
    "inorgogliti": "inorgoglire",
    "inorgoglito": "inorgoglire",
    "inorgogliva": "inorgoglire",
    "inorgoglivamo": "inorgoglire",
    "inorgoglivan": "inorgoglire",
    "inorgoglivano": "inorgoglire",
    "inorgoglivate": "inorgoglire",
    "inorgoglivi": "inorgoglire",
    "inorgoglivo": "inorgoglire",
    "inorgoglì": "inorgoglire",
    "inorridendo": "inorridire",
    "inorridente": "inorridire",
    "inorridenti": "inorridire",
    "inorridiamo": "inorridire",
    "inorridiate": "inorridire",
    "inorridii": "inorridire",
    "inorridimmo": "inorridire",
    "inorridir": "inorridire",
    "inorridirai": "inorridire",
    "inorridiran": "inorridire",
    "inorridiranno": "inorridire",
    "inorridirebbe": "inorridire",
    "inorridirebber": "inorridire",
    "inorridirebbero": "inorridire",
    "inorridirei": "inorridire",
    "inorridiremmo": "inorridire",
    "inorridiremo": "inorridire",
    "inorridireste": "inorridire",
    "inorridiresti": "inorridire",
    "inorridirete": "inorridire",
    "inorridiron": "inorridire",
    "inorridirono": "inorridire",
    "inorridirà": "inorridire",
    "inorridirò": "inorridire",
    "inorridisca": "inorridire",
    "inorridiscan": "inorridire",
    "inorridiscano": "inorridire",
    "inorridisce": "inorridire",
    "inorridisci": "inorridire",
    "inorridisco": "inorridire",
    "inorridiscon": "inorridire",
    "inorridiscono": "inorridire",
    "inorridisse": "inorridire",
    "inorridisser": "inorridire",
    "inorridissero": "inorridire",
    "inorridissi": "inorridire",
    "inorridissimo": "inorridire",
    "inorridiste": "inorridire",
    "inorridisti": "inorridire",
    "inorridita": "inorridire",
    "inorridite": "inorridire",
    "inorriditi": "inorridire",
    "inorridito": "inorridire",
    "inorridiva": "inorridire",
    "inorridivamo": "inorridire",
    "inorridivan": "inorridire",
    "inorridivano": "inorridire",
    "inorridivate": "inorridire",
    "inorridivi": "inorridire",
    "inorridivo": "inorridire",
    "inorridì": "inorridire",
    "inospitali": "inospitale",
    "inospiti": "inospite",
    "inosservanze": "inosservanza",
    "inosservata": "inosservato",
    "inosservate": "inosservato",
    "inosservati": "inosservato",
    "inossidabili": "inossidabile",
    "inquadra": "inquadrare",
    "inquadrai": "inquadrare",
    "inquadramenti": "inquadramento",
    "inquadrammo": "inquadrare",
    "inquadran": "inquadrare",
    "inquadrando": "inquadrare",
    "inquadrano": "inquadrare",
    "inquadrante": "inquadrare",
    "inquadranti": "inquadrare",
    "inquadrar": "inquadrare",
    "inquadraron": "inquadrare",
    "inquadrarono": "inquadrare",
    "inquadrasse": "inquadrare",
    "inquadrasser": "inquadrare",
    "inquadrassero": "inquadrare",
    "inquadrassi": "inquadrare",
    "inquadrassimo": "inquadrare",
    "inquadraste": "inquadrare",
    "inquadrasti": "inquadrare",
    "inquadrata": "inquadrare",
    "inquadrate": "inquadrare",
    "inquadrati": "inquadrare",
    "inquadrato": "inquadrare",
    "inquadrature": "inquadratura",
    "inquadrava": "inquadrare",
    "inquadravamo": "inquadrare",
    "inquadravan": "inquadrare",
    "inquadravano": "inquadrare",
    "inquadravate": "inquadrare",
    "inquadravi": "inquadrare",
    "inquadravo": "inquadrare",
    "inquadrerai": "inquadrare",
    "inquadreran": "inquadrare",
    "inquadreranno": "inquadrare",
    "inquadrerebbe": "inquadrare",
    "inquadrerebber": "inquadrare",
    "inquadrerebbero": "inquadrare",
    "inquadrerei": "inquadrare",
    "inquadreremmo": "inquadrare",
    "inquadreremo": "inquadrare",
    "inquadrereste": "inquadrare",
    "inquadreresti": "inquadrare",
    "inquadrerete": "inquadrare",
    "inquadrerà": "inquadrare",
    "inquadrerò": "inquadrare",
    "inquadri": "inquadrare",
    "inquadriamo": "inquadrare",
    "inquadriate": "inquadrare",
    "inquadrin": "inquadrare",
    "inquadrino": "inquadrare",
    "inquadro": "inquadrare",
    "inquadrò": "inquadrare",
    "inqualificabili": "inqualificabile",
    "inquartata": "inquartato",
    "inquartate": "inquartato",
    "inquartati": "inquartato",
    "inquieta": "inquieto",
    "inquietai": "inquietare",
    "inquietammo": "inquietare",
    "inquietan": "inquietare",
    "inquietando": "inquietare",
    "inquietano": "inquietare",
    "inquietante": "inquietare",
    "inquietanti": "inquietare",
    "inquietar": "inquietare",
    "inquietaron": "inquietare",
    "inquietarono": "inquietare",
    "inquietasse": "inquietare",
    "inquietasser": "inquietare",
    "inquietassero": "inquietare",
    "inquietassi": "inquietare",
    "inquietassimo": "inquietare",
    "inquietaste": "inquietare",
    "inquietasti": "inquietare",
    "inquietata": "inquietare",
    "inquietate": "inquietare",
    "inquietati": "inquietare",
    "inquietato": "inquietare",
    "inquietava": "inquietare",
    "inquietavamo": "inquietare",
    "inquietavan": "inquietare",
    "inquietavano": "inquietare",
    "inquietavate": "inquietare",
    "inquietavi": "inquietare",
    "inquietavo": "inquietare",
    "inquiete": "inquieto",
    "inquieterai": "inquietare",
    "inquieteran": "inquietare",
    "inquieteranno": "inquietare",
    "inquieterebbe": "inquietare",
    "inquieterebber": "inquietare",
    "inquieterebbero": "inquietare",
    "inquieterei": "inquietare",
    "inquieteremmo": "inquietare",
    "inquieteremo": "inquietare",
    "inquietereste": "inquietare",
    "inquieteresti": "inquietare",
    "inquieterete": "inquietare",
    "inquieterà": "inquietare",
    "inquieterò": "inquietare",
    "inquieti": "inquieto",
    "inquietiamo": "inquietare",
    "inquietiate": "inquietare",
    "inquietin": "inquietare",
    "inquietino": "inquietare",
    "inquieto": "inquietare",
    "inquietudini": "inquietudine",
    "inquietò": "inquietare",
    "inquiline": "inquilina",
    "inquilini": "inquilino",
    "inquina": "inquinare",
    "inquinai": "inquinare",
    "inquinamenti": "inquinamento",
    "inquinammo": "inquinare",
    "inquinan": "inquinare",
    "inquinando": "inquinare",
    "inquinano": "inquinare",
    "inquinante": "inquinare",
    "inquinanti": "inquinare",
    "inquinar": "inquinare",
    "inquinaron": "inquinare",
    "inquinarono": "inquinare",
    "inquinasse": "inquinare",
    "inquinasser": "inquinare",
    "inquinassero": "inquinare",
    "inquinassi": "inquinare",
    "inquinassimo": "inquinare",
    "inquinaste": "inquinare",
    "inquinasti": "inquinare",
    "inquinata": "inquinato",
    "inquinate": "inquinato",
    "inquinati": "inquinato",
    "inquinato": "inquinare",
    "inquinatori": "inquinatore",
    "inquinava": "inquinare",
    "inquinavamo": "inquinare",
    "inquinavan": "inquinare",
    "inquinavano": "inquinare",
    "inquinavate": "inquinare",
    "inquinavi": "inquinare",
    "inquinavo": "inquinare",
    "inquinerai": "inquinare",
    "inquineran": "inquinare",
    "inquineranno": "inquinare",
    "inquinerebbe": "inquinare",
    "inquinerebber": "inquinare",
    "inquinerebbero": "inquinare",
    "inquinerei": "inquinare",
    "inquineremmo": "inquinare",
    "inquineremo": "inquinare",
    "inquinereste": "inquinare",
    "inquineresti": "inquinare",
    "inquinerete": "inquinare",
    "inquinerà": "inquinare",
    "inquinerò": "inquinare",
    "inquini": "inquinare",
    "inquiniamo": "inquinare",
    "inquiniate": "inquinare",
    "inquinin": "inquinare",
    "inquinino": "inquinare",
    "inquino": "inquinare",
    "inquinò": "inquinare",
    "inquirenti": "inquirente",
    "inquisa": "inquisire",
    "inquisan": "inquisire",
    "inquisano": "inquisire",
    "inquise": "inquisire",
    "inquisendo": "inquisire",
    "inquisente": "inquisire",
    "inquisenti": "inquisire",
    "inquisi": "inquisire",
    "inquisiamo": "inquisire",
    "inquisiate": "inquisire",
    "inquisii": "inquisire",
    "inquisimmo": "inquisire",
    "inquisir": "inquisire",
    "inquisirai": "inquisire",
    "inquisiran": "inquisire",
    "inquisiranno": "inquisire",
    "inquisirebbe": "inquisire",
    "inquisirebber": "inquisire",
    "inquisirebbero": "inquisire",
    "inquisirei": "inquisire",
    "inquisiremmo": "inquisire",
    "inquisiremo": "inquisire",
    "inquisireste": "inquisire",
    "inquisiresti": "inquisire",
    "inquisirete": "inquisire",
    "inquisiron": "inquisire",
    "inquisirono": "inquisire",
    "inquisirà": "inquisire",
    "inquisirò": "inquisire",
    "inquisisse": "inquisire",
    "inquisisser": "inquisire",
    "inquisissero": "inquisire",
    "inquisissi": "inquisire",
    "inquisissimo": "inquisire",
    "inquisiste": "inquisire",
    "inquisisti": "inquisire",
    "inquisita": "inquisire",
    "inquisite": "inquisire",
    "inquisiti": "inquisito",
    "inquisito": "inquisire",
    "inquisitori": "inquisitorio",
    "inquisitoria": "inquisitorio",
    "inquisitorie": "inquisitorio",
    "inquisitrice": "inquisitore",
    "inquisitrici": "inquisitore",
    "inquisiva": "inquisire",
    "inquisivamo": "inquisire",
    "inquisivan": "inquisire",
    "inquisivano": "inquisire",
    "inquisivate": "inquisire",
    "inquisivi": "inquisire",
    "inquisivo": "inquisire",
    "inquisizioni": "inquisizione",
    "inquiso": "inquisire",
    "inquison": "inquisire",
    "inquisono": "inquisire",
    "inquisì": "inquisire",
    "insabbi": "insabbiare",
    "insabbia": "insabbiare",
    "insabbiai": "insabbiare",
    "insabbiamenti": "insabbiamento",
    "insabbiammo": "insabbiare",
    "insabbiamo": "insabbiare",
    "insabbian": "insabbiare",
    "insabbiando": "insabbiare",
    "insabbiano": "insabbiare",
    "insabbiante": "insabbiare",
    "insabbianti": "insabbiare",
    "insabbiar": "insabbiare",
    "insabbiaron": "insabbiare",
    "insabbiarono": "insabbiare",
    "insabbiasse": "insabbiare",
    "insabbiasser": "insabbiare",
    "insabbiassero": "insabbiare",
    "insabbiassi": "insabbiare",
    "insabbiassimo": "insabbiare",
    "insabbiaste": "insabbiare",
    "insabbiasti": "insabbiare",
    "insabbiata": "insabbiare",
    "insabbiate": "insabbiare",
    "insabbiati": "insabbiare",
    "insabbiato": "insabbiare",
    "insabbiatori": "insabbiatore",
    "insabbiava": "insabbiare",
    "insabbiavamo": "insabbiare",
    "insabbiavan": "insabbiare",
    "insabbiavano": "insabbiare",
    "insabbiavate": "insabbiare",
    "insabbiavi": "insabbiare",
    "insabbiavo": "insabbiare",
    "insabbierai": "insabbiare",
    "insabbieran": "insabbiare",
    "insabbieranno": "insabbiare",
    "insabbierebbe": "insabbiare",
    "insabbierebber": "insabbiare",
    "insabbierebbero": "insabbiare",
    "insabbierei": "insabbiare",
    "insabbieremmo": "insabbiare",
    "insabbieremo": "insabbiare",
    "insabbiereste": "insabbiare",
    "insabbieresti": "insabbiare",
    "insabbierete": "insabbiare",
    "insabbierà": "insabbiare",
    "insabbierò": "insabbiare",
    "insabbin": "insabbiare",
    "insabbino": "insabbiare",
    "insabbio": "insabbiare",
    "insabbiò": "insabbiare",
    "insacca": "insaccare",
    "insaccai": "insaccare",
    "insaccammo": "insaccare",
    "insaccan": "insaccare",
    "insaccando": "insaccare",
    "insaccano": "insaccare",
    "insaccante": "insaccare",
    "insaccanti": "insaccare",
    "insaccar": "insaccare",
    "insaccaron": "insaccare",
    "insaccarono": "insaccare",
    "insaccasse": "insaccare",
    "insaccasser": "insaccare",
    "insaccassero": "insaccare",
    "insaccassi": "insaccare",
    "insaccassimo": "insaccare",
    "insaccaste": "insaccare",
    "insaccasti": "insaccare",
    "insaccata": "insaccare",
    "insaccate": "insaccare",
    "insaccati": "insaccare",
    "insaccato": "insaccare",
    "insaccava": "insaccare",
    "insaccavamo": "insaccare",
    "insaccavan": "insaccare",
    "insaccavano": "insaccare",
    "insaccavate": "insaccare",
    "insaccavi": "insaccare",
    "insaccavo": "insaccare",
    "insaccherai": "insaccare",
    "insaccheran": "insaccare",
    "insaccheranno": "insaccare",
    "insaccherebbe": "insaccare",
    "insaccherebber": "insaccare",
    "insaccherebbero": "insaccare",
    "insaccherei": "insaccare",
    "insaccheremmo": "insaccare",
    "insaccheremo": "insaccare",
    "insacchereste": "insaccare",
    "insaccheresti": "insaccare",
    "insaccherete": "insaccare",
    "insaccherà": "insaccare",
    "insaccherò": "insaccare",
    "insacchi": "insaccare",
    "insacchiamo": "insaccare",
    "insacchiate": "insaccare",
    "insacchin": "insaccare",
    "insacchino": "insaccare",
    "insacco": "insaccare",
    "insaccò": "insaccare",
    "insalate": "insalata",
    "insalatine": "insalatina",
    "insaliva": "insalivare",
    "insalivai": "insalivare",
    "insalivammo": "insalivare",
    "insalivan": "insalivare",
    "insalivando": "insalivare",
    "insalivano": "insalivare",
    "insalivante": "insalivare",
    "insalivanti": "insalivare",
    "insalivar": "insalivare",
    "insalivaron": "insalivare",
    "insalivarono": "insalivare",
    "insalivasse": "insalivare",
    "insalivasser": "insalivare",
    "insalivassero": "insalivare",
    "insalivassi": "insalivare",
    "insalivassimo": "insalivare",
    "insalivaste": "insalivare",
    "insalivasti": "insalivare",
    "insalivata": "insalivare",
    "insalivate": "insalivare",
    "insalivati": "insalivare",
    "insalivato": "insalivare",
    "insalivava": "insalivare",
    "insalivavamo": "insalivare",
    "insalivavan": "insalivare",
    "insalivavano": "insalivare",
    "insalivavate": "insalivare",
    "insalivavi": "insalivare",
    "insalivavo": "insalivare",
    "insaliverai": "insalivare",
    "insaliveran": "insalivare",
    "insaliveranno": "insalivare",
    "insaliverebbe": "insalivare",
    "insaliverebber": "insalivare",
    "insaliverebbero": "insalivare",
    "insaliverei": "insalivare",
    "insaliveremmo": "insalivare",
    "insaliveremo": "insalivare",
    "insalivereste": "insalivare",
    "insaliveresti": "insalivare",
    "insaliverete": "insalivare",
    "insaliverà": "insalivare",
    "insaliverò": "insalivare",
    "insalivi": "insalivare",
    "insaliviamo": "insalivare",
    "insaliviate": "insalivare",
    "insalivin": "insalivare",
    "insalivino": "insalivare",
    "insalivo": "insalivare",
    "insalivò": "insalivare",
    "insalubri": "insalubre",
    "insalutata": "insalutato",
    "insalutate": "insalutato",
    "insalutati": "insalutato",
    "insana": "insano",
    "insanabili": "insanabile",
    "insanan": "insanire",
    "insanano": "insanire",
    "insane": "insano",
    "insanendo": "insanire",
    "insanente": "insanire",
    "insanenti": "insanire",
    "insanguina": "insanguinare",
    "insanguinai": "insanguinare",
    "insanguinammo": "insanguinare",
    "insanguinan": "insanguinare",
    "insanguinando": "insanguinare",
    "insanguinano": "insanguinare",
    "insanguinante": "insanguinare",
    "insanguinanti": "insanguinare",
    "insanguinar": "insanguinare",
    "insanguinaron": "insanguinare",
    "insanguinarono": "insanguinare",
    "insanguinasse": "insanguinare",
    "insanguinasser": "insanguinare",
    "insanguinassero": "insanguinare",
    "insanguinassi": "insanguinare",
    "insanguinassimo": "insanguinare",
    "insanguinaste": "insanguinare",
    "insanguinasti": "insanguinare",
    "insanguinata": "insanguinare",
    "insanguinate": "insanguinare",
    "insanguinati": "insanguinare",
    "insanguinato": "insanguinare",
    "insanguinava": "insanguinare",
    "insanguinavamo": "insanguinare",
    "insanguinavan": "insanguinare",
    "insanguinavano": "insanguinare",
    "insanguinavate": "insanguinare",
    "insanguinavi": "insanguinare",
    "insanguinavo": "insanguinare",
    "insanguinerai": "insanguinare",
    "insanguineran": "insanguinare",
    "insanguineranno": "insanguinare",
    "insanguinerebbe": "insanguinare",
    "insanguinerebber": "insanguinare",
    "insanguinerebbero": "insanguinare",
    "insanguinerei": "insanguinare",
    "insanguineremmo": "insanguinare",
    "insanguineremo": "insanguinare",
    "insanguinereste": "insanguinare",
    "insanguineresti": "insanguinare",
    "insanguinerete": "insanguinare",
    "insanguinerà": "insanguinare",
    "insanguinerò": "insanguinare",
    "insanguini": "insanguinare",
    "insanguiniamo": "insanguinare",
    "insanguiniate": "insanguinare",
    "insanguinin": "insanguinare",
    "insanguinino": "insanguinare",
    "insanguino": "insanguinare",
    "insanguinò": "insanguinare",
    "insani": "insano",
    "insaniamo": "insanire",
    "insaniate": "insanire",
    "insanii": "insanire",
    "insanimmo": "insanire",
    "insanir": "insanire",
    "insanirai": "insanire",
    "insaniran": "insanire",
    "insaniranno": "insanire",
    "insanirebbe": "insanire",
    "insanirebber": "insanire",
    "insanirebbero": "insanire",
    "insanirei": "insanire",
    "insaniremmo": "insanire",
    "insaniremo": "insanire",
    "insanireste": "insanire",
    "insaniresti": "insanire",
    "insanirete": "insanire",
    "insaniron": "insanire",
    "insanirono": "insanire",
    "insanirà": "insanire",
    "insanirò": "insanire",
    "insanisse": "insanire",
    "insanisser": "insanire",
    "insanissero": "insanire",
    "insanissi": "insanire",
    "insanissimo": "insanire",
    "insaniste": "insanire",
    "insanisti": "insanire",
    "insanita": "insanire",
    "insanite": "insanire",
    "insaniti": "insanire",
    "insanito": "insanire",
    "insaniva": "insanire",
    "insanivamo": "insanire",
    "insanivan": "insanire",
    "insanivano": "insanire",
    "insanivate": "insanire",
    "insanivi": "insanire",
    "insanivo": "insanire",
    "insano": "insanire",
    "insanon": "insanire",
    "insanono": "insanire",
    "insanì": "insanire",
    "insapona": "insaponare",
    "insaponai": "insaponare",
    "insaponammo": "insaponare",
    "insaponan": "insaponare",
    "insaponando": "insaponare",
    "insaponano": "insaponare",
    "insaponante": "insaponare",
    "insaponanti": "insaponare",
    "insaponar": "insaponare",
    "insaponaron": "insaponare",
    "insaponarono": "insaponare",
    "insaponasse": "insaponare",
    "insaponasser": "insaponare",
    "insaponassero": "insaponare",
    "insaponassi": "insaponare",
    "insaponassimo": "insaponare",
    "insaponaste": "insaponare",
    "insaponasti": "insaponare",
    "insaponata": "insaponare",
    "insaponate": "insaponare",
    "insaponati": "insaponare",
    "insaponato": "insaponare",
    "insaponava": "insaponare",
    "insaponavamo": "insaponare",
    "insaponavan": "insaponare",
    "insaponavano": "insaponare",
    "insaponavate": "insaponare",
    "insaponavi": "insaponare",
    "insaponavo": "insaponare",
    "insaponerai": "insaponare",
    "insaponeran": "insaponare",
    "insaponeranno": "insaponare",
    "insaponerebbe": "insaponare",
    "insaponerebber": "insaponare",
    "insaponerebbero": "insaponare",
    "insaponerei": "insaponare",
    "insaponeremmo": "insaponare",
    "insaponeremo": "insaponare",
    "insaponereste": "insaponare",
    "insaponeresti": "insaponare",
    "insaponerete": "insaponare",
    "insaponerà": "insaponare",
    "insaponerò": "insaponare",
    "insaponi": "insaponare",
    "insaponiamo": "insaponare",
    "insaponiate": "insaponare",
    "insaponin": "insaponare",
    "insaponino": "insaponare",
    "insapono": "insaponare",
    "insaponò": "insaponare",
    "insapora": "insaporo",
    "insapore": "insaporo",
    "insaporendo": "insaporire",
    "insaporente": "insaporire",
    "insaporenti": "insaporire",
    "insapori": "insaporo",
    "insaporiamo": "insaporire",
    "insaporiate": "insaporire",
    "insaporii": "insaporire",
    "insaporimmo": "insaporire",
    "insaporir": "insaporire",
    "insaporirai": "insaporire",
    "insaporiran": "insaporire",
    "insaporiranno": "insaporire",
    "insaporirebbe": "insaporire",
    "insaporirebber": "insaporire",
    "insaporirebbero": "insaporire",
    "insaporirei": "insaporire",
    "insaporiremmo": "insaporire",
    "insaporiremo": "insaporire",
    "insaporireste": "insaporire",
    "insaporiresti": "insaporire",
    "insaporirete": "insaporire",
    "insaporiron": "insaporire",
    "insaporirono": "insaporire",
    "insaporirà": "insaporire",
    "insaporirò": "insaporire",
    "insaporisca": "insaporire",
    "insaporiscan": "insaporire",
    "insaporiscano": "insaporire",
    "insaporisce": "insaporire",
    "insaporisci": "insaporire",
    "insaporisco": "insaporire",
    "insaporiscon": "insaporire",
    "insaporiscono": "insaporire",
    "insaporisse": "insaporire",
    "insaporisser": "insaporire",
    "insaporissero": "insaporire",
    "insaporissi": "insaporire",
    "insaporissimo": "insaporire",
    "insaporiste": "insaporire",
    "insaporisti": "insaporire",
    "insaporita": "insaporire",
    "insaporite": "insaporire",
    "insaporiti": "insaporire",
    "insaporito": "insaporire",
    "insaporiva": "insaporire",
    "insaporivamo": "insaporire",
    "insaporivan": "insaporire",
    "insaporivano": "insaporire",
    "insaporivate": "insaporire",
    "insaporivi": "insaporire",
    "insaporivo": "insaporire",
    "insaporì": "insaporire",
    "insaziabili": "insaziabile",
    "inscatola": "inscatolare",
    "inscatolai": "inscatolare",
    "inscatolammo": "inscatolare",
    "inscatolan": "inscatolare",
    "inscatolando": "inscatolare",
    "inscatolano": "inscatolare",
    "inscatolante": "inscatolare",
    "inscatolanti": "inscatolare",
    "inscatolar": "inscatolare",
    "inscatolaron": "inscatolare",
    "inscatolarono": "inscatolare",
    "inscatolasse": "inscatolare",
    "inscatolasser": "inscatolare",
    "inscatolassero": "inscatolare",
    "inscatolassi": "inscatolare",
    "inscatolassimo": "inscatolare",
    "inscatolaste": "inscatolare",
    "inscatolasti": "inscatolare",
    "inscatolata": "inscatolare",
    "inscatolate": "inscatolare",
    "inscatolati": "inscatolare",
    "inscatolato": "inscatolare",
    "inscatolava": "inscatolare",
    "inscatolavamo": "inscatolare",
    "inscatolavan": "inscatolare",
    "inscatolavano": "inscatolare",
    "inscatolavate": "inscatolare",
    "inscatolavi": "inscatolare",
    "inscatolavo": "inscatolare",
    "inscatolerai": "inscatolare",
    "inscatoleran": "inscatolare",
    "inscatoleranno": "inscatolare",
    "inscatolerebbe": "inscatolare",
    "inscatolerebber": "inscatolare",
    "inscatolerebbero": "inscatolare",
    "inscatolerei": "inscatolare",
    "inscatoleremmo": "inscatolare",
    "inscatoleremo": "inscatolare",
    "inscatolereste": "inscatolare",
    "inscatoleresti": "inscatolare",
    "inscatolerete": "inscatolare",
    "inscatolerà": "inscatolare",
    "inscatolerò": "inscatolare",
    "inscatoli": "inscatolare",
    "inscatoliamo": "inscatolare",
    "inscatoliate": "inscatolare",
    "inscatolin": "inscatolare",
    "inscatolino": "inscatolare",
    "inscatolo": "inscatolare",
    "inscatolò": "inscatolare",
    "inscena": "inscenare",
    "inscenai": "inscenare",
    "inscenammo": "inscenare",
    "inscenan": "inscenare",
    "inscenando": "inscenare",
    "inscenano": "inscenare",
    "inscenante": "inscenare",
    "inscenanti": "inscenare",
    "inscenar": "inscenare",
    "inscenaron": "inscenare",
    "inscenarono": "inscenare",
    "inscenasse": "inscenare",
    "inscenasser": "inscenare",
    "inscenassero": "inscenare",
    "inscenassi": "inscenare",
    "inscenassimo": "inscenare",
    "inscenaste": "inscenare",
    "inscenasti": "inscenare",
    "inscenata": "inscenare",
    "inscenate": "inscenare",
    "inscenati": "inscenare",
    "inscenato": "inscenare",
    "inscenava": "inscenare",
    "inscenavamo": "inscenare",
    "inscenavan": "inscenare",
    "inscenavano": "inscenare",
    "inscenavate": "inscenare",
    "inscenavi": "inscenare",
    "inscenavo": "inscenare",
    "inscenerai": "inscenare",
    "insceneran": "inscenare",
    "insceneranno": "inscenare",
    "inscenerebbe": "inscenare",
    "inscenerebber": "inscenare",
    "inscenerebbero": "inscenare",
    "inscenerei": "inscenare",
    "insceneremmo": "inscenare",
    "insceneremo": "inscenare",
    "inscenereste": "inscenare",
    "insceneresti": "inscenare",
    "inscenerete": "inscenare",
    "inscenerà": "inscenare",
    "inscenerò": "inscenare",
    "insceni": "inscenare",
    "insceniamo": "inscenare",
    "insceniate": "inscenare",
    "inscenin": "inscenare",
    "inscenino": "inscenare",
    "insceno": "inscenare",
    "inscenò": "inscenare",
    "inscindibili": "inscindibile",
    "inscrisse": "inscrivere",
    "inscrisser": "inscrivere",
    "inscrissero": "inscrivere",
    "inscrissi": "inscrivere",
    "inscritta": "inscrivere",
    "inscritte": "inscrivere",
    "inscritti": "inscrivere",
    "inscritto": "inscrivere",
    "inscriva": "inscrivere",
    "inscrivan": "inscrivere",
    "inscrivano": "inscrivere",
    "inscrive": "inscrivere",
    "inscrivemmo": "inscrivere",
    "inscrivendo": "inscrivere",
    "inscrivente": "inscrivere",
    "inscriventi": "inscrivere",
    "inscriver": "inscrivere",
    "inscriverai": "inscrivere",
    "inscriveran": "inscrivere",
    "inscriveranno": "inscrivere",
    "inscriverebbe": "inscrivere",
    "inscriverebber": "inscrivere",
    "inscriverebbero": "inscrivere",
    "inscriverei": "inscrivere",
    "inscriveremmo": "inscrivere",
    "inscriveremo": "inscrivere",
    "inscrivereste": "inscrivere",
    "inscriveresti": "inscrivere",
    "inscriverete": "inscrivere",
    "inscriverà": "inscrivere",
    "inscriverò": "inscrivere",
    "inscrivesse": "inscrivere",
    "inscrivesser": "inscrivere",
    "inscrivessero": "inscrivere",
    "inscrivessi": "inscrivere",
    "inscrivessimo": "inscrivere",
    "inscriveste": "inscrivere",
    "inscrivesti": "inscrivere",
    "inscrivete": "inscrivere",
    "inscriveva": "inscrivere",
    "inscrivevamo": "inscrivere",
    "inscrivevan": "inscrivere",
    "inscrivevano": "inscrivere",
    "inscrivevate": "inscrivere",
    "inscrivevi": "inscrivere",
    "inscrivevo": "inscrivere",
    "inscrivi": "inscrivere",
    "inscriviamo": "inscrivere",
    "inscriviate": "inscrivere",
    "inscrivo": "inscrivere",
    "inscrivon": "inscrivere",
    "inscrivono": "inscrivere",
    "inseccha": "insecchire",
    "insecchan": "insecchire",
    "insecchano": "insecchire",
    "insecche": "insecchire",
    "insecchendo": "insecchire",
    "insecchente": "insecchire",
    "insecchenti": "insecchire",
    "insecchi": "insecchire",
    "insecchiamo": "insecchire",
    "insecchiate": "insecchire",
    "insecchii": "insecchire",
    "insecchimmo": "insecchire",
    "insecchir": "insecchire",
    "insecchirai": "insecchire",
    "insecchiran": "insecchire",
    "insecchiranno": "insecchire",
    "insecchirebbe": "insecchire",
    "insecchirebber": "insecchire",
    "insecchirebbero": "insecchire",
    "insecchirei": "insecchire",
    "insecchiremmo": "insecchire",
    "insecchiremo": "insecchire",
    "insecchireste": "insecchire",
    "insecchiresti": "insecchire",
    "insecchirete": "insecchire",
    "insecchiron": "insecchire",
    "insecchirono": "insecchire",
    "insecchirà": "insecchire",
    "insecchirò": "insecchire",
    "insecchisse": "insecchire",
    "insecchisser": "insecchire",
    "insecchissero": "insecchire",
    "insecchissi": "insecchire",
    "insecchissimo": "insecchire",
    "insecchiste": "insecchire",
    "insecchisti": "insecchire",
    "insecchita": "insecchire",
    "insecchite": "insecchire",
    "insecchiti": "insecchire",
    "insecchito": "insecchire",
    "insecchiva": "insecchire",
    "insecchivamo": "insecchire",
    "insecchivan": "insecchire",
    "insecchivano": "insecchire",
    "insecchivate": "insecchire",
    "insecchivi": "insecchire",
    "insecchivo": "insecchire",
    "inseccho": "insecchire",
    "insecchon": "insecchire",
    "insecchono": "insecchire",
    "insecchì": "insecchire",
    "insedi": "insediare",
    "insedia": "insediare",
    "insediai": "insediare",
    "insediamenti": "insediamento",
    "insediammo": "insediare",
    "insediamo": "insediare",
    "insedian": "insediare",
    "insediando": "insediare",
    "insediano": "insediare",
    "insediante": "insediare",
    "insedianti": "insediare",
    "insediar": "insediare",
    "insediaron": "insediare",
    "insediarono": "insediare",
    "insediasse": "insediare",
    "insediasser": "insediare",
    "insediassero": "insediare",
    "insediassi": "insediare",
    "insediassimo": "insediare",
    "insediaste": "insediare",
    "insediasti": "insediare",
    "insediata": "insediare",
    "insediate": "insediare",
    "insediati": "insediare",
    "insediato": "insediare",
    "insediava": "insediare",
    "insediavamo": "insediare",
    "insediavan": "insediare",
    "insediavano": "insediare",
    "insediavate": "insediare",
    "insediavi": "insediare",
    "insediavo": "insediare",
    "insedierai": "insediare",
    "insedieran": "insediare",
    "insedieranno": "insediare",
    "insedierebbe": "insediare",
    "insedierebber": "insediare",
    "insedierebbero": "insediare",
    "insedierei": "insediare",
    "insedieremmo": "insediare",
    "insedieremo": "insediare",
    "insediereste": "insediare",
    "insedieresti": "insediare",
    "insedierete": "insediare",
    "insedierà": "insediare",
    "insedierò": "insediare",
    "insedin": "insediare",
    "insedino": "insediare",
    "insedio": "insediare",
    "insediò": "insediare",
    "insegna": "insegnare",
    "insegnai": "insegnare",
    "insegnamenti": "insegnamento",
    "insegnammo": "insegnare",
    "insegnan": "insegnare",
    "insegnando": "insegnare",
    "insegnano": "insegnare",
    "insegnante": "insegnare",
    "insegnanti": "insegnare",
    "insegnar": "insegnare",
    "insegnaron": "insegnare",
    "insegnarono": "insegnare",
    "insegnasse": "insegnare",
    "insegnasser": "insegnare",
    "insegnassero": "insegnare",
    "insegnassi": "insegnare",
    "insegnassimo": "insegnare",
    "insegnaste": "insegnare",
    "insegnasti": "insegnare",
    "insegnata": "insegnare",
    "insegnate": "insegnare",
    "insegnati": "insegnare",
    "insegnato": "insegnare",
    "insegnava": "insegnare",
    "insegnavamo": "insegnare",
    "insegnavan": "insegnare",
    "insegnavano": "insegnare",
    "insegnavate": "insegnare",
    "insegnavi": "insegnare",
    "insegnavo": "insegnare",
    "insegne": "insegna",
    "insegnerai": "insegnare",
    "insegneran": "insegnare",
    "insegneranno": "insegnare",
    "insegnerebbe": "insegnare",
    "insegnerebber": "insegnare",
    "insegnerebbero": "insegnare",
    "insegnerei": "insegnare",
    "insegneremmo": "insegnare",
    "insegneremo": "insegnare",
    "insegnereste": "insegnare",
    "insegneresti": "insegnare",
    "insegnerete": "insegnare",
    "insegnerà": "insegnare",
    "insegnerò": "insegnare",
    "insegni": "insegnare",
    "insegniamo": "insegnare",
    "insegniate": "insegnare",
    "insegnin": "insegnare",
    "insegnino": "insegnare",
    "insegno": "insegnare",
    "insegnò": "insegnare",
    "insegua": "inseguire",
    "inseguan": "inseguire",
    "inseguano": "inseguire",
    "insegue": "inseguire",
    "inseguendo": "inseguire",
    "inseguente": "inseguire",
    "inseguenti": "inseguire",
    "insegui": "inseguire",
    "inseguiamo": "inseguire",
    "inseguiate": "inseguire",
    "inseguii": "inseguire",
    "inseguimenti": "inseguimento",
    "inseguimmo": "inseguire",
    "inseguir": "inseguire",
    "inseguirai": "inseguire",
    "inseguiran": "inseguire",
    "inseguiranno": "inseguire",
    "inseguirebbe": "inseguire",
    "inseguirebber": "inseguire",
    "inseguirebbero": "inseguire",
    "inseguirei": "inseguire",
    "inseguiremmo": "inseguire",
    "inseguiremo": "inseguire",
    "inseguireste": "inseguire",
    "inseguiresti": "inseguire",
    "inseguirete": "inseguire",
    "inseguiron": "inseguire",
    "inseguirono": "inseguire",
    "inseguirà": "inseguire",
    "inseguirò": "inseguire",
    "inseguisse": "inseguire",
    "inseguisser": "inseguire",
    "inseguissero": "inseguire",
    "inseguissi": "inseguire",
    "inseguissimo": "inseguire",
    "inseguiste": "inseguire",
    "inseguisti": "inseguire",
    "inseguita": "inseguire",
    "inseguite": "inseguire",
    "inseguiti": "inseguire",
    "inseguito": "inseguire",
    "inseguitori": "inseguitore",
    "inseguitrice": "inseguitore",
    "inseguitrici": "inseguitrice",
    "inseguiva": "inseguire",
    "inseguivamo": "inseguire",
    "inseguivan": "inseguire",
    "inseguivano": "inseguire",
    "inseguivate": "inseguire",
    "inseguivi": "inseguire",
    "inseguivo": "inseguire",
    "inseguo": "inseguire",
    "inseguon": "inseguire",
    "inseguono": "inseguire",
    "inseguì": "inseguire",
    "insella": "insellare",
    "insellai": "insellare",
    "insellammo": "insellare",
    "insellan": "insellare",
    "insellando": "insellare",
    "insellano": "insellare",
    "insellante": "insellare",
    "insellanti": "insellare",
    "insellar": "insellare",
    "insellaron": "insellare",
    "insellarono": "insellare",
    "insellasse": "insellare",
    "insellasser": "insellare",
    "insellassero": "insellare",
    "insellassi": "insellare",
    "insellassimo": "insellare",
    "insellaste": "insellare",
    "insellasti": "insellare",
    "insellata": "insellare",
    "insellate": "insellare",
    "insellati": "insellare",
    "insellato": "insellare",
    "insellava": "insellare",
    "insellavamo": "insellare",
    "insellavan": "insellare",
    "insellavano": "insellare",
    "insellavate": "insellare",
    "insellavi": "insellare",
    "insellavo": "insellare",
    "insellerai": "insellare",
    "inselleran": "insellare",
    "inselleranno": "insellare",
    "insellerebbe": "insellare",
    "insellerebber": "insellare",
    "insellerebbero": "insellare",
    "insellerei": "insellare",
    "inselleremmo": "insellare",
    "inselleremo": "insellare",
    "insellereste": "insellare",
    "inselleresti": "insellare",
    "insellerete": "insellare",
    "insellerà": "insellare",
    "insellerò": "insellare",
    "inselli": "insellare",
    "inselliamo": "insellare",
    "inselliate": "insellare",
    "insellin": "insellare",
    "insellino": "insellare",
    "insello": "insellare",
    "insellò": "insellare",
    "inselvaticha": "inselvatichire",
    "inselvatichan": "inselvatichire",
    "inselvatichano": "inselvatichire",
    "inselvatiche": "inselvatichire",
    "inselvatichendo": "inselvatichire",
    "inselvatichente": "inselvatichire",
    "inselvatichenti": "inselvatichire",
    "inselvatichi": "inselvatichire",
    "inselvatichiamo": "inselvatichire",
    "inselvatichiate": "inselvatichire",
    "inselvatichii": "inselvatichire",
    "inselvatichimmo": "inselvatichire",
    "inselvatichir": "inselvatichire",
    "inselvatichirai": "inselvatichire",
    "inselvatichiran": "inselvatichire",
    "inselvatichiranno": "inselvatichire",
    "inselvatichirebbe": "inselvatichire",
    "inselvatichirebber": "inselvatichire",
    "inselvatichirebbero": "inselvatichire",
    "inselvatichirei": "inselvatichire",
    "inselvatichiremmo": "inselvatichire",
    "inselvatichiremo": "inselvatichire",
    "inselvatichireste": "inselvatichire",
    "inselvatichiresti": "inselvatichire",
    "inselvatichirete": "inselvatichire",
    "inselvatichiron": "inselvatichire",
    "inselvatichirono": "inselvatichire",
    "inselvatichirà": "inselvatichire",
    "inselvatichirò": "inselvatichire",
    "inselvatichisse": "inselvatichire",
    "inselvatichisser": "inselvatichire",
    "inselvatichissero": "inselvatichire",
    "inselvatichissi": "inselvatichire",
    "inselvatichissimo": "inselvatichire",
    "inselvatichiste": "inselvatichire",
    "inselvatichisti": "inselvatichire",
    "inselvatichita": "inselvatichire",
    "inselvatichite": "inselvatichire",
    "inselvatichiti": "inselvatichire",
    "inselvatichito": "inselvatichire",
    "inselvatichiva": "inselvatichire",
    "inselvatichivamo": "inselvatichire",
    "inselvatichivan": "inselvatichire",
    "inselvatichivano": "inselvatichire",
    "inselvatichivate": "inselvatichire",
    "inselvatichivi": "inselvatichire",
    "inselvatichivo": "inselvatichire",
    "inselvaticho": "inselvatichire",
    "inselvatichon": "inselvatichire",
    "inselvatichono": "inselvatichire",
    "inselvatichì": "inselvatichire",
    "inseminazioni": "inseminazione",
    "insenature": "insenatura",
    "insensata": "insensato",
    "insensate": "insensato",
    "insensatezze": "insensatezza",
    "insensati": "insensato",
    "insensibili": "insensibile",
    "inseparabili": "inseparabile",
    "insepolta": "insepolto",
    "insepolte": "insepolto",
    "insepolti": "insepolto",
    "inserendo": "inserire",
    "inserente": "inserire",
    "inserenti": "inserire",
    "inseriamo": "inserire",
    "inseriate": "inserire",
    "inserii": "inserire",
    "inserimenti": "inserimento",
    "inserimmo": "inserire",
    "inserir": "inserire",
    "inserirai": "inserire",
    "inseriran": "inserire",
    "inseriranno": "inserire",
    "inserirebbe": "inserire",
    "inserirebber": "inserire",
    "inserirebbero": "inserire",
    "inserirei": "inserire",
    "inseriremmo": "inserire",
    "inseriremo": "inserire",
    "inserireste": "inserire",
    "inseriresti": "inserire",
    "inserirete": "inserire",
    "inseriron": "inserire",
    "inserirono": "inserire",
    "inserirà": "inserire",
    "inserirò": "inserire",
    "inserisca": "inserire",
    "inseriscan": "inserire",
    "inseriscano": "inserire",
    "inserisce": "inserire",
    "inserisci": "inserire",
    "inserisco": "inserire",
    "inseriscon": "inserire",
    "inseriscono": "inserire",
    "inserisse": "inserire",
    "inserisser": "inserire",
    "inserissero": "inserire",
    "inserissi": "inserire",
    "inserissimo": "inserire",
    "inseriste": "inserire",
    "inseristi": "inserire",
    "inserita": "inserito",
    "inserite": "inserito",
    "inseriti": "inserito",
    "inserito": "inserire",
    "inseriva": "inserire",
    "inserivamo": "inserire",
    "inserivan": "inserire",
    "inserivano": "inserire",
    "inserivate": "inserire",
    "inserivi": "inserire",
    "inserivo": "inserire",
    "inserti": "inserto",
    "inservibili": "inservibile",
    "inservienti": "inserviente",
    "inserzioni": "inserzione",
    "inserzionisti": "inserzionista",
    "inserì": "inserire",
    "insetti": "insetto",
    "insetticide": "insetticida",
    "insetticidi": "insetticida",
    "insicura": "insicuro",
    "insicure": "insicuro",
    "insicurezze": "insicurezza",
    "insicuri": "insicuro",
    "insidi": "insidiare",
    "insidia": "insidiare",
    "insidiai": "insidiare",
    "insidiammo": "insidiare",
    "insidiamo": "insidiare",
    "insidian": "insidiare",
    "insidiando": "insidiare",
    "insidiano": "insidiare",
    "insidiante": "insidiare",
    "insidianti": "insidiare",
    "insidiar": "insidiare",
    "insidiaron": "insidiare",
    "insidiarono": "insidiare",
    "insidiasse": "insidiare",
    "insidiasser": "insidiare",
    "insidiassero": "insidiare",
    "insidiassi": "insidiare",
    "insidiassimo": "insidiare",
    "insidiaste": "insidiare",
    "insidiasti": "insidiare",
    "insidiata": "insidiare",
    "insidiate": "insidiare",
    "insidiati": "insidiare",
    "insidiato": "insidiare",
    "insidiava": "insidiare",
    "insidiavamo": "insidiare",
    "insidiavan": "insidiare",
    "insidiavano": "insidiare",
    "insidiavate": "insidiare",
    "insidiavi": "insidiare",
    "insidiavo": "insidiare",
    "insidie": "insidia",
    "insidierai": "insidiare",
    "insidieran": "insidiare",
    "insidieranno": "insidiare",
    "insidierebbe": "insidiare",
    "insidierebber": "insidiare",
    "insidierebbero": "insidiare",
    "insidierei": "insidiare",
    "insidieremmo": "insidiare",
    "insidieremo": "insidiare",
    "insidiereste": "insidiare",
    "insidieresti": "insidiare",
    "insidierete": "insidiare",
    "insidierà": "insidiare",
    "insidierò": "insidiare",
    "insidin": "insidiare",
    "insidino": "insidiare",
    "insidio": "insidiare",
    "insidiosa": "insidioso",
    "insidiose": "insidioso",
    "insidiosi": "insidioso",
    "insidiò": "insidiare",
    "insiemi": "insieme",
    "insigna": "insignire",
    "insignan": "insignire",
    "insignano": "insignire",
    "insigne": "insignire",
    "insignendo": "insignire",
    "insignente": "insignire",
    "insignenti": "insignire",
    "insigni": "insignire",
    "insigniamo": "insignire",
    "insigniate": "insignire",
    "insignificanti": "insignificante",
    "insignii": "insignire",
    "insignimmo": "insignire",
    "insignir": "insignire",
    "insignirai": "insignire",
    "insigniran": "insignire",
    "insigniranno": "insignire",
    "insignirebbe": "insignire",
    "insignirebber": "insignire",
    "insignirebbero": "insignire",
    "insignirei": "insignire",
    "insigniremmo": "insignire",
    "insigniremo": "insignire",
    "insignireste": "insignire",
    "insigniresti": "insignire",
    "insignirete": "insignire",
    "insigniron": "insignire",
    "insignirono": "insignire",
    "insignirà": "insignire",
    "insignirò": "insignire",
    "insignisse": "insignire",
    "insignisser": "insignire",
    "insignissero": "insignire",
    "insignissi": "insignire",
    "insignissimo": "insignire",
    "insigniste": "insignire",
    "insignisti": "insignire",
    "insignita": "insignire",
    "insignite": "insignire",
    "insigniti": "insignire",
    "insignito": "insignire",
    "insigniva": "insignire",
    "insignivamo": "insignire",
    "insignivan": "insignire",
    "insignivano": "insignire",
    "insignivate": "insignire",
    "insignivi": "insignire",
    "insignivo": "insignire",
    "insigno": "insignire",
    "insignon": "insignire",
    "insignono": "insignire",
    "insignì": "insignire",
    "insila": "insilare",
    "insilai": "insilare",
    "insilammo": "insilare",
    "insilan": "insilare",
    "insilando": "insilare",
    "insilano": "insilare",
    "insilante": "insilare",
    "insilanti": "insilare",
    "insilar": "insilare",
    "insilaron": "insilare",
    "insilarono": "insilare",
    "insilasse": "insilare",
    "insilasser": "insilare",
    "insilassero": "insilare",
    "insilassi": "insilare",
    "insilassimo": "insilare",
    "insilaste": "insilare",
    "insilasti": "insilare",
    "insilata": "insilare",
    "insilate": "insilare",
    "insilati": "insilare",
    "insilato": "insilare",
    "insilava": "insilare",
    "insilavamo": "insilare",
    "insilavan": "insilare",
    "insilavano": "insilare",
    "insilavate": "insilare",
    "insilavi": "insilare",
    "insilavo": "insilare",
    "insilerai": "insilare",
    "insileran": "insilare",
    "insileranno": "insilare",
    "insilerebbe": "insilare",
    "insilerebber": "insilare",
    "insilerebbero": "insilare",
    "insilerei": "insilare",
    "insileremmo": "insilare",
    "insileremo": "insilare",
    "insilereste": "insilare",
    "insileresti": "insilare",
    "insilerete": "insilare",
    "insilerà": "insilare",
    "insilerò": "insilare",
    "insili": "insilare",
    "insiliamo": "insilare",
    "insiliate": "insilare",
    "insilin": "insilare",
    "insilino": "insilare",
    "insilo": "insilare",
    "insilò": "insilare",
    "insincera": "insincero",
    "insincere": "insincero",
    "insinceri": "insincero",
    "insindacabili": "insindacabile",
    "insinua": "insinuare",
    "insinuai": "insinuare",
    "insinuammo": "insinuare",
    "insinuan": "insinuare",
    "insinuando": "insinuare",
    "insinuano": "insinuare",
    "insinuante": "insinuare",
    "insinuanti": "insinuare",
    "insinuar": "insinuare",
    "insinuaron": "insinuare",
    "insinuarono": "insinuare",
    "insinuasse": "insinuare",
    "insinuasser": "insinuare",
    "insinuassero": "insinuare",
    "insinuassi": "insinuare",
    "insinuassimo": "insinuare",
    "insinuaste": "insinuare",
    "insinuasti": "insinuare",
    "insinuata": "insinuare",
    "insinuate": "insinuare",
    "insinuati": "insinuare",
    "insinuato": "insinuare",
    "insinuava": "insinuare",
    "insinuavamo": "insinuare",
    "insinuavan": "insinuare",
    "insinuavano": "insinuare",
    "insinuavate": "insinuare",
    "insinuavi": "insinuare",
    "insinuavo": "insinuare",
    "insinuazioni": "insinuazione",
    "insinuerai": "insinuare",
    "insinueran": "insinuare",
    "insinueranno": "insinuare",
    "insinuerebbe": "insinuare",
    "insinuerebber": "insinuare",
    "insinuerebbero": "insinuare",
    "insinuerei": "insinuare",
    "insinueremmo": "insinuare",
    "insinueremo": "insinuare",
    "insinuereste": "insinuare",
    "insinueresti": "insinuare",
    "insinuerete": "insinuare",
    "insinuerà": "insinuare",
    "insinuerò": "insinuare",
    "insinui": "insinuare",
    "insinuiamo": "insinuare",
    "insinuiate": "insinuare",
    "insinuin": "insinuare",
    "insinuino": "insinuare",
    "insinuo": "insinuare",
    "insinuò": "insinuare",
    "insipida": "insipido",
    "insipide": "insipido",
    "insipidi": "insipido",
    "insipienti": "insipiente",
    "insipienze": "insipienza",
    "insista": "insistere",
    "insistan": "insistere",
    "insistano": "insistere",
    "insiste": "insistere",
    "insistei": "insistere",
    "insistemmo": "insistere",
    "insistendo": "insistere",
    "insistente": "insistere",
    "insistenti": "insistere",
    "insistenze": "insistenza",
    "insister": "insistere",
    "insisterai": "insistere",
    "insisteran": "insistere",
    "insisteranno": "insistere",
    "insisterebbe": "insistere",
    "insisterebber": "insistere",
    "insisterebbero": "insistere",
    "insisterei": "insistere",
    "insisteremmo": "insistere",
    "insisteremo": "insistere",
    "insistereste": "insistere",
    "insisteresti": "insistere",
    "insisterete": "insistere",
    "insisteron": "insistere",
    "insisterono": "insistere",
    "insisterà": "insistere",
    "insisterò": "insistere",
    "insistesse": "insistere",
    "insistesser": "insistere",
    "insistessero": "insistere",
    "insistessi": "insistere",
    "insistessimo": "insistere",
    "insisteste": "insistere",
    "insistesti": "insistere",
    "insistete": "insistere",
    "insisteva": "insistere",
    "insistevamo": "insistere",
    "insistevan": "insistere",
    "insistevano": "insistere",
    "insistevate": "insistere",
    "insistevi": "insistere",
    "insistevo": "insistere",
    "insisti": "insistere",
    "insistiamo": "insistere",
    "insistiate": "insistere",
    "insisto": "insistere",
    "insiston": "insistere",
    "insistono": "insistere",
    "insistuta": "insistere",
    "insistute": "insistere",
    "insistuti": "insistere",
    "insistuto": "insistere",
    "insistè": "insistere",
    "insita": "insito",
    "insite": "insito",
    "insiti": "insito",
    "insoddisfacenti": "insoddisfacente",
    "insoddisfatta": "insoddisfatto",
    "insoddisfatte": "insoddisfatto",
    "insoddisfatti": "insoddisfatto",
    "insoddisfazioni": "insoddisfazione",
    "insofferenti": "insofferente",
    "insofferenze": "insofferenza",
    "insolenta": "insolentire",
    "insolentan": "insolentire",
    "insolentano": "insolentire",
    "insolente": "insolentire",
    "insolentendo": "insolentire",
    "insolentente": "insolentire",
    "insolententi": "insolentire",
    "insolenti": "insolentire",
    "insolentiamo": "insolentire",
    "insolentiate": "insolentire",
    "insolentii": "insolentire",
    "insolentimmo": "insolentire",
    "insolentir": "insolentire",
    "insolentirai": "insolentire",
    "insolentiran": "insolentire",
    "insolentiranno": "insolentire",
    "insolentirebbe": "insolentire",
    "insolentirebber": "insolentire",
    "insolentirebbero": "insolentire",
    "insolentirei": "insolentire",
    "insolentiremmo": "insolentire",
    "insolentiremo": "insolentire",
    "insolentireste": "insolentire",
    "insolentiresti": "insolentire",
    "insolentirete": "insolentire",
    "insolentiron": "insolentire",
    "insolentirono": "insolentire",
    "insolentirà": "insolentire",
    "insolentirò": "insolentire",
    "insolentisse": "insolentire",
    "insolentisser": "insolentire",
    "insolentissero": "insolentire",
    "insolentissi": "insolentire",
    "insolentissimo": "insolentire",
    "insolentiste": "insolentire",
    "insolentisti": "insolentire",
    "insolentita": "insolentire",
    "insolentite": "insolentire",
    "insolentiti": "insolentire",
    "insolentito": "insolentire",
    "insolentiva": "insolentire",
    "insolentivamo": "insolentire",
    "insolentivan": "insolentire",
    "insolentivano": "insolentire",
    "insolentivate": "insolentire",
    "insolentivi": "insolentire",
    "insolentivo": "insolentire",
    "insolento": "insolentire",
    "insolenton": "insolentire",
    "insolentono": "insolentire",
    "insolentì": "insolentire",
    "insolenze": "insolenza",
    "insolita": "insolito",
    "insolite": "insolito",
    "insoliti": "insolito",
    "insolubili": "insolubile",
    "insoluta": "insoluto",
    "insolute": "insoluto",
    "insoluti": "insoluto",
    "insolventi": "insolvente",
    "insolvenze": "insolvenza",
    "insondabili": "insondabile",
    "insonni": "insonne",
    "insonnie": "insonnia",
    "insonnolita": "insonnolito",
    "insonnolite": "insonnolito",
    "insonnoliti": "insonnolito",
    "insonorizza": "insonorizzare",
    "insonorizzai": "insonorizzare",
    "insonorizzammo": "insonorizzare",
    "insonorizzan": "insonorizzare",
    "insonorizzando": "insonorizzare",
    "insonorizzano": "insonorizzare",
    "insonorizzante": "insonorizzare",
    "insonorizzanti": "insonorizzare",
    "insonorizzar": "insonorizzare",
    "insonorizzaron": "insonorizzare",
    "insonorizzarono": "insonorizzare",
    "insonorizzasse": "insonorizzare",
    "insonorizzasser": "insonorizzare",
    "insonorizzassero": "insonorizzare",
    "insonorizzassi": "insonorizzare",
    "insonorizzassimo": "insonorizzare",
    "insonorizzaste": "insonorizzare",
    "insonorizzasti": "insonorizzare",
    "insonorizzata": "insonorizzare",
    "insonorizzate": "insonorizzare",
    "insonorizzati": "insonorizzare",
    "insonorizzato": "insonorizzare",
    "insonorizzava": "insonorizzare",
    "insonorizzavamo": "insonorizzare",
    "insonorizzavan": "insonorizzare",
    "insonorizzavano": "insonorizzare",
    "insonorizzavate": "insonorizzare",
    "insonorizzavi": "insonorizzare",
    "insonorizzavo": "insonorizzare",
    "insonorizzerai": "insonorizzare",
    "insonorizzeran": "insonorizzare",
    "insonorizzeranno": "insonorizzare",
    "insonorizzerebbe": "insonorizzare",
    "insonorizzerebber": "insonorizzare",
    "insonorizzerebbero": "insonorizzare",
    "insonorizzerei": "insonorizzare",
    "insonorizzeremmo": "insonorizzare",
    "insonorizzeremo": "insonorizzare",
    "insonorizzereste": "insonorizzare",
    "insonorizzeresti": "insonorizzare",
    "insonorizzerete": "insonorizzare",
    "insonorizzerà": "insonorizzare",
    "insonorizzerò": "insonorizzare",
    "insonorizzi": "insonorizzare",
    "insonorizziamo": "insonorizzare",
    "insonorizziate": "insonorizzare",
    "insonorizzin": "insonorizzare",
    "insonorizzino": "insonorizzare",
    "insonorizzo": "insonorizzare",
    "insonorizzò": "insonorizzare",
    "insopportabili": "insopportabile",
    "insopprimibili": "insopprimibile",
    "insorga": "insorgere",
    "insorgan": "insorgere",
    "insorgano": "insorgere",
    "insorge": "insorgere",
    "insorgemmo": "insorgere",
    "insorgendo": "insorgere",
    "insorgente": "insorgere",
    "insorgenti": "insorgere",
    "insorgenze": "insorgenza",
    "insorger": "insorgere",
    "insorgerai": "insorgere",
    "insorgeran": "insorgere",
    "insorgeranno": "insorgere",
    "insorgerebbe": "insorgere",
    "insorgerebber": "insorgere",
    "insorgerebbero": "insorgere",
    "insorgerei": "insorgere",
    "insorgeremmo": "insorgere",
    "insorgeremo": "insorgere",
    "insorgereste": "insorgere",
    "insorgeresti": "insorgere",
    "insorgerete": "insorgere",
    "insorgerà": "insorgere",
    "insorgerò": "insorgere",
    "insorgesse": "insorgere",
    "insorgesser": "insorgere",
    "insorgessero": "insorgere",
    "insorgessi": "insorgere",
    "insorgessimo": "insorgere",
    "insorgeste": "insorgere",
    "insorgesti": "insorgere",
    "insorgete": "insorgere",
    "insorgeva": "insorgere",
    "insorgevamo": "insorgere",
    "insorgevan": "insorgere",
    "insorgevano": "insorgere",
    "insorgevate": "insorgere",
    "insorgevi": "insorgere",
    "insorgevo": "insorgere",
    "insorgi": "insorgere",
    "insorgiamo": "insorgere",
    "insorgiate": "insorgere",
    "insorgo": "insorgere",
    "insorgon": "insorgere",
    "insorgono": "insorgere",
    "insormontabili": "insormontabile",
    "insorse": "insorgere",
    "insorser": "insorgere",
    "insorsero": "insorgere",
    "insorsi": "insorgere",
    "insorta": "insorto",
    "insorte": "insorto",
    "insorti": "insorto",
    "insorto": "insorgere",
    "insospettabili": "insospettabile",
    "insospettendo": "insospettire",
    "insospettente": "insospettire",
    "insospettenti": "insospettire",
    "insospettiamo": "insospettire",
    "insospettiate": "insospettire",
    "insospettii": "insospettire",
    "insospettimmo": "insospettire",
    "insospettir": "insospettire",
    "insospettirai": "insospettire",
    "insospettiran": "insospettire",
    "insospettiranno": "insospettire",
    "insospettirebbe": "insospettire",
    "insospettirebber": "insospettire",
    "insospettirebbero": "insospettire",
    "insospettirei": "insospettire",
    "insospettiremmo": "insospettire",
    "insospettiremo": "insospettire",
    "insospettireste": "insospettire",
    "insospettiresti": "insospettire",
    "insospettirete": "insospettire",
    "insospettiron": "insospettire",
    "insospettirono": "insospettire",
    "insospettirà": "insospettire",
    "insospettirò": "insospettire",
    "insospettisca": "insospettire",
    "insospettiscan": "insospettire",
    "insospettiscano": "insospettire",
    "insospettisce": "insospettire",
    "insospettisci": "insospettire",
    "insospettisco": "insospettire",
    "insospettiscon": "insospettire",
    "insospettiscono": "insospettire",
    "insospettisse": "insospettire",
    "insospettisser": "insospettire",
    "insospettissero": "insospettire",
    "insospettissi": "insospettire",
    "insospettissimo": "insospettire",
    "insospettiste": "insospettire",
    "insospettisti": "insospettire",
    "insospettita": "insospettire",
    "insospettite": "insospettire",
    "insospettiti": "insospettire",
    "insospettito": "insospettire",
    "insospettiva": "insospettire",
    "insospettivamo": "insospettire",
    "insospettivan": "insospettire",
    "insospettivano": "insospettire",
    "insospettivate": "insospettire",
    "insospettivi": "insospettire",
    "insospettivo": "insospettire",
    "insospettì": "insospettire",
    "insostenibili": "insostenibile",
    "insostituibili": "insostituibile",
    "insozza": "insozzare",
    "insozzai": "insozzare",
    "insozzammo": "insozzare",
    "insozzan": "insozzare",
    "insozzando": "insozzare",
    "insozzano": "insozzare",
    "insozzante": "insozzare",
    "insozzanti": "insozzare",
    "insozzar": "insozzare",
    "insozzaron": "insozzare",
    "insozzarono": "insozzare",
    "insozzasse": "insozzare",
    "insozzasser": "insozzare",
    "insozzassero": "insozzare",
    "insozzassi": "insozzare",
    "insozzassimo": "insozzare",
    "insozzaste": "insozzare",
    "insozzasti": "insozzare",
    "insozzata": "insozzare",
    "insozzate": "insozzare",
    "insozzati": "insozzare",
    "insozzato": "insozzare",
    "insozzava": "insozzare",
    "insozzavamo": "insozzare",
    "insozzavan": "insozzare",
    "insozzavano": "insozzare",
    "insozzavate": "insozzare",
    "insozzavi": "insozzare",
    "insozzavo": "insozzare",
    "insozzerai": "insozzare",
    "insozzeran": "insozzare",
    "insozzeranno": "insozzare",
    "insozzerebbe": "insozzare",
    "insozzerebber": "insozzare",
    "insozzerebbero": "insozzare",
    "insozzerei": "insozzare",
    "insozzeremmo": "insozzare",
    "insozzeremo": "insozzare",
    "insozzereste": "insozzare",
    "insozzeresti": "insozzare",
    "insozzerete": "insozzare",
    "insozzerà": "insozzare",
    "insozzerò": "insozzare",
    "insozzi": "insozzare",
    "insozziamo": "insozzare",
    "insozziate": "insozzare",
    "insozzin": "insozzare",
    "insozzino": "insozzare",
    "insozzo": "insozzare",
    "insozzò": "insozzare",
    "insperabili": "insperabile",
    "insperata": "insperato",
    "insperate": "insperato",
    "insperati": "insperato",
    "inspiegabili": "inspiegabile",
    "inspira": "inspirare",
    "inspirai": "inspirare",
    "inspirammo": "inspirare",
    "inspiran": "inspirare",
    "inspirando": "inspirare",
    "inspirano": "inspirare",
    "inspirante": "inspirare",
    "inspiranti": "inspirare",
    "inspirar": "inspirare",
    "inspiraron": "inspirare",
    "inspirarono": "inspirare",
    "inspirasse": "inspirare",
    "inspirasser": "inspirare",
    "inspirassero": "inspirare",
    "inspirassi": "inspirare",
    "inspirassimo": "inspirare",
    "inspiraste": "inspirare",
    "inspirasti": "inspirare",
    "inspirata": "inspirare",
    "inspirate": "inspirare",
    "inspirati": "inspirare",
    "inspirato": "inspirare",
    "inspirava": "inspirare",
    "inspiravamo": "inspirare",
    "inspiravan": "inspirare",
    "inspiravano": "inspirare",
    "inspiravate": "inspirare",
    "inspiravi": "inspirare",
    "inspiravo": "inspirare",
    "inspirerai": "inspirare",
    "inspireran": "inspirare",
    "inspireranno": "inspirare",
    "inspirerebbe": "inspirare",
    "inspirerebber": "inspirare",
    "inspirerebbero": "inspirare",
    "inspirerei": "inspirare",
    "inspireremmo": "inspirare",
    "inspireremo": "inspirare",
    "inspirereste": "inspirare",
    "inspireresti": "inspirare",
    "inspirerete": "inspirare",
    "inspirerà": "inspirare",
    "inspirerò": "inspirare",
    "inspiri": "inspirare",
    "inspiriamo": "inspirare",
    "inspiriate": "inspirare",
    "inspirin": "inspirare",
    "inspirino": "inspirare",
    "inspiro": "inspirare",
    "inspirò": "inspirare",
    "insta": "instare",
    "instabili": "instabile",
    "instai": "instare",
    "installa": "installare",
    "installai": "installare",
    "installammo": "installare",
    "installan": "installare",
    "installando": "installare",
    "installano": "installare",
    "installante": "installare",
    "installanti": "installare",
    "installar": "installare",
    "installaron": "installare",
    "installarono": "installare",
    "installasse": "installare",
    "installasser": "installare",
    "installassero": "installare",
    "installassi": "installare",
    "installassimo": "installare",
    "installaste": "installare",
    "installasti": "installare",
    "installata": "installare",
    "installate": "installare",
    "installati": "installare",
    "installato": "installare",
    "installatori": "installatore",
    "installava": "installare",
    "installavamo": "installare",
    "installavan": "installare",
    "installavano": "installare",
    "installavate": "installare",
    "installavi": "installare",
    "installavo": "installare",
    "installazioni": "installazione",
    "installerai": "installare",
    "installeran": "installare",
    "installeranno": "installare",
    "installerebbe": "installare",
    "installerebber": "installare",
    "installerebbero": "installare",
    "installerei": "installare",
    "installeremmo": "installare",
    "installeremo": "installare",
    "installereste": "installare",
    "installeresti": "installare",
    "installerete": "installare",
    "installerà": "installare",
    "installerò": "installare",
    "installi": "installare",
    "installiamo": "installare",
    "installiate": "installare",
    "installin": "installare",
    "installino": "installare",
    "installo": "installare",
    "installò": "installare",
    "instammo": "instare",
    "instan": "instare",
    "instancabili": "instancabile",
    "instando": "instare",
    "instano": "instare",
    "instante": "instare",
    "instanti": "instare",
    "instar": "instare",
    "instaron": "instare",
    "instarono": "instare",
    "instasse": "instare",
    "instasser": "instare",
    "instassero": "instare",
    "instassi": "instare",
    "instassimo": "instare",
    "instaste": "instare",
    "instasti": "instare",
    "instata": "instare",
    "instate": "instare",
    "instati": "instare",
    "instato": "instare",
    "instaura": "instaurare",
    "instaurai": "instaurare",
    "instaurammo": "instaurare",
    "instauran": "instaurare",
    "instaurando": "instaurare",
    "instaurano": "instaurare",
    "instaurante": "instaurare",
    "instauranti": "instaurare",
    "instaurar": "instaurare",
    "instauraron": "instaurare",
    "instaurarono": "instaurare",
    "instaurasse": "instaurare",
    "instaurasser": "instaurare",
    "instaurassero": "instaurare",
    "instaurassi": "instaurare",
    "instaurassimo": "instaurare",
    "instauraste": "instaurare",
    "instaurasti": "instaurare",
    "instaurata": "instaurare",
    "instaurate": "instaurare",
    "instaurati": "instaurare",
    "instaurato": "instaurare",
    "instaurava": "instaurare",
    "instauravamo": "instaurare",
    "instauravan": "instaurare",
    "instauravano": "instaurare",
    "instauravate": "instaurare",
    "instauravi": "instaurare",
    "instauravo": "instaurare",
    "instaurerai": "instaurare",
    "instaureran": "instaurare",
    "instaureranno": "instaurare",
    "instaurerebbe": "instaurare",
    "instaurerebber": "instaurare",
    "instaurerebbero": "instaurare",
    "instaurerei": "instaurare",
    "instaureremmo": "instaurare",
    "instaureremo": "instaurare",
    "instaurereste": "instaurare",
    "instaureresti": "instaurare",
    "instaurerete": "instaurare",
    "instaurerà": "instaurare",
    "instaurerò": "instaurare",
    "instauri": "instaurare",
    "instauriamo": "instaurare",
    "instauriate": "instaurare",
    "instaurin": "instaurare",
    "instaurino": "instaurare",
    "instauro": "instaurare",
    "instaurò": "instaurare",
    "instava": "instare",
    "instavamo": "instare",
    "instavan": "instare",
    "instavano": "instare",
    "instavate": "instare",
    "instavi": "instare",
    "instavo": "instare",
    "insterai": "instare",
    "insteran": "instare",
    "insteranno": "instare",
    "insterebbe": "instare",
    "insterebber": "instare",
    "insterebbero": "instare",
    "insterei": "instare",
    "insteremmo": "instare",
    "insteremo": "instare",
    "instereste": "instare",
    "insteresti": "instare",
    "insterete": "instare",
    "insterà": "instare",
    "insterò": "instare",
    "insti": "instare",
    "instiamo": "instare",
    "instiate": "instare",
    "instilla": "instillare",
    "instillai": "instillare",
    "instillammo": "instillare",
    "instillan": "instillare",
    "instillando": "instillare",
    "instillano": "instillare",
    "instillante": "instillare",
    "instillanti": "instillare",
    "instillar": "instillare",
    "instillaron": "instillare",
    "instillarono": "instillare",
    "instillasse": "instillare",
    "instillasser": "instillare",
    "instillassero": "instillare",
    "instillassi": "instillare",
    "instillassimo": "instillare",
    "instillaste": "instillare",
    "instillasti": "instillare",
    "instillata": "instillare",
    "instillate": "instillare",
    "instillati": "instillare",
    "instillato": "instillare",
    "instillava": "instillare",
    "instillavamo": "instillare",
    "instillavan": "instillare",
    "instillavano": "instillare",
    "instillavate": "instillare",
    "instillavi": "instillare",
    "instillavo": "instillare",
    "instillerai": "instillare",
    "instilleran": "instillare",
    "instilleranno": "instillare",
    "instillerebbe": "instillare",
    "instillerebber": "instillare",
    "instillerebbero": "instillare",
    "instillerei": "instillare",
    "instilleremmo": "instillare",
    "instilleremo": "instillare",
    "instillereste": "instillare",
    "instilleresti": "instillare",
    "instillerete": "instillare",
    "instillerà": "instillare",
    "instillerò": "instillare",
    "instilli": "instillare",
    "instilliamo": "instillare",
    "instilliate": "instillare",
    "instillin": "instillare",
    "instillino": "instillare",
    "instillo": "instillare",
    "instillò": "instillare",
    "instin": "instare",
    "instino": "instare",
    "insto": "instare",
    "instrada": "instradare",
    "instradai": "instradare",
    "instradammo": "instradare",
    "instradan": "instradare",
    "instradando": "instradare",
    "instradano": "instradare",
    "instradante": "instradare",
    "instradanti": "instradare",
    "instradar": "instradare",
    "instradaron": "instradare",
    "instradarono": "instradare",
    "instradasse": "instradare",
    "instradasser": "instradare",
    "instradassero": "instradare",
    "instradassi": "instradare",
    "instradassimo": "instradare",
    "instradaste": "instradare",
    "instradasti": "instradare",
    "instradata": "instradare",
    "instradate": "instradare",
    "instradati": "instradare",
    "instradato": "instradare",
    "instradava": "instradare",
    "instradavamo": "instradare",
    "instradavan": "instradare",
    "instradavano": "instradare",
    "instradavate": "instradare",
    "instradavi": "instradare",
    "instradavo": "instradare",
    "instraderai": "instradare",
    "instraderan": "instradare",
    "instraderanno": "instradare",
    "instraderebbe": "instradare",
    "instraderebber": "instradare",
    "instraderebbero": "instradare",
    "instraderei": "instradare",
    "instraderemmo": "instradare",
    "instraderemo": "instradare",
    "instradereste": "instradare",
    "instraderesti": "instradare",
    "instraderete": "instradare",
    "instraderà": "instradare",
    "instraderò": "instradare",
    "instradi": "instradare",
    "instradiamo": "instradare",
    "instradiate": "instradare",
    "instradin": "instradare",
    "instradino": "instradare",
    "instrado": "instradare",
    "instradò": "instradare",
    "instò": "instare",
    "insubordinazioni": "insubordinazione",
    "insuccessi": "insuccesso",
    "insudicerai": "insudiciare",
    "insudiceran": "insudiciare",
    "insudiceranno": "insudiciare",
    "insudicerebbe": "insudiciare",
    "insudicerebber": "insudiciare",
    "insudicerebbero": "insudiciare",
    "insudicerei": "insudiciare",
    "insudiceremmo": "insudiciare",
    "insudiceremo": "insudiciare",
    "insudicereste": "insudiciare",
    "insudiceresti": "insudiciare",
    "insudicerete": "insudiciare",
    "insudicerà": "insudiciare",
    "insudicerò": "insudiciare",
    "insudici": "insudiciare",
    "insudicia": "insudiciare",
    "insudiciai": "insudiciare",
    "insudiciammo": "insudiciare",
    "insudiciamo": "insudiciare",
    "insudician": "insudiciare",
    "insudiciando": "insudiciare",
    "insudiciano": "insudiciare",
    "insudiciante": "insudiciare",
    "insudicianti": "insudiciare",
    "insudiciar": "insudiciare",
    "insudiciaron": "insudiciare",
    "insudiciarono": "insudiciare",
    "insudiciasse": "insudiciare",
    "insudiciasser": "insudiciare",
    "insudiciassero": "insudiciare",
    "insudiciassi": "insudiciare",
    "insudiciassimo": "insudiciare",
    "insudiciaste": "insudiciare",
    "insudiciasti": "insudiciare",
    "insudiciata": "insudiciare",
    "insudiciate": "insudiciare",
    "insudiciati": "insudiciare",
    "insudiciato": "insudiciare",
    "insudiciava": "insudiciare",
    "insudiciavamo": "insudiciare",
    "insudiciavan": "insudiciare",
    "insudiciavano": "insudiciare",
    "insudiciavate": "insudiciare",
    "insudiciavi": "insudiciare",
    "insudiciavo": "insudiciare",
    "insudicin": "insudiciare",
    "insudicino": "insudiciare",
    "insudicio": "insudiciare",
    "insudiciò": "insudiciare",
    "insufficienti": "insufficiente",
    "insufficienze": "insufficienza",
    "insuffla": "insufflare",
    "insufflai": "insufflare",
    "insufflammo": "insufflare",
    "insufflan": "insufflare",
    "insufflando": "insufflare",
    "insufflano": "insufflare",
    "insufflante": "insufflare",
    "insufflanti": "insufflare",
    "insufflar": "insufflare",
    "insufflaron": "insufflare",
    "insufflarono": "insufflare",
    "insufflasse": "insufflare",
    "insufflasser": "insufflare",
    "insufflassero": "insufflare",
    "insufflassi": "insufflare",
    "insufflassimo": "insufflare",
    "insufflaste": "insufflare",
    "insufflasti": "insufflare",
    "insufflata": "insufflare",
    "insufflate": "insufflare",
    "insufflati": "insufflare",
    "insufflato": "insufflare",
    "insufflava": "insufflare",
    "insufflavamo": "insufflare",
    "insufflavan": "insufflare",
    "insufflavano": "insufflare",
    "insufflavate": "insufflare",
    "insufflavi": "insufflare",
    "insufflavo": "insufflare",
    "insufflerai": "insufflare",
    "insuffleran": "insufflare",
    "insuffleranno": "insufflare",
    "insufflerebbe": "insufflare",
    "insufflerebber": "insufflare",
    "insufflerebbero": "insufflare",
    "insufflerei": "insufflare",
    "insuffleremmo": "insufflare",
    "insuffleremo": "insufflare",
    "insufflereste": "insufflare",
    "insuffleresti": "insufflare",
    "insufflerete": "insufflare",
    "insufflerà": "insufflare",
    "insufflerò": "insufflare",
    "insuffli": "insufflare",
    "insuffliamo": "insufflare",
    "insuffliate": "insufflare",
    "insufflin": "insufflare",
    "insufflino": "insufflare",
    "insufflo": "insufflare",
    "insufflò": "insufflare",
    "insulari": "insulare",
    "insulsa": "insulso",
    "insulse": "insulso",
    "insulsi": "insulso",
    "insulta": "insultare",
    "insultai": "insultare",
    "insultammo": "insultare",
    "insultan": "insultare",
    "insultando": "insultare",
    "insultano": "insultare",
    "insultante": "insultare",
    "insultanti": "insultare",
    "insultar": "insultare",
    "insultaron": "insultare",
    "insultarono": "insultare",
    "insultasse": "insultare",
    "insultasser": "insultare",
    "insultassero": "insultare",
    "insultassi": "insultare",
    "insultassimo": "insultare",
    "insultaste": "insultare",
    "insultasti": "insultare",
    "insultata": "insultare",
    "insultate": "insultare",
    "insultati": "insultare",
    "insultato": "insultare",
    "insultava": "insultare",
    "insultavamo": "insultare",
    "insultavan": "insultare",
    "insultavano": "insultare",
    "insultavate": "insultare",
    "insultavi": "insultare",
    "insultavo": "insultare",
    "insulterai": "insultare",
    "insulteran": "insultare",
    "insulteranno": "insultare",
    "insulterebbe": "insultare",
    "insulterebber": "insultare",
    "insulterebbero": "insultare",
    "insulterei": "insultare",
    "insulteremmo": "insultare",
    "insulteremo": "insultare",
    "insultereste": "insultare",
    "insulteresti": "insultare",
    "insulterete": "insultare",
    "insulterà": "insultare",
    "insulterò": "insultare",
    "insulti": "insulto",
    "insultiamo": "insultare",
    "insultiate": "insultare",
    "insultin": "insultare",
    "insultino": "insultare",
    "insulto": "insultare",
    "insultò": "insultare",
    "insuperabili": "insuperabile",
    "insuperata": "insuperato",
    "insuperate": "insuperato",
    "insuperati": "insuperato",
    "insuperba": "insuperbire",
    "insuperban": "insuperbire",
    "insuperbano": "insuperbire",
    "insuperbe": "insuperbire",
    "insuperbendo": "insuperbire",
    "insuperbente": "insuperbire",
    "insuperbenti": "insuperbire",
    "insuperbi": "insuperbire",
    "insuperbiamo": "insuperbire",
    "insuperbiate": "insuperbire",
    "insuperbii": "insuperbire",
    "insuperbimmo": "insuperbire",
    "insuperbir": "insuperbire",
    "insuperbirai": "insuperbire",
    "insuperbiran": "insuperbire",
    "insuperbiranno": "insuperbire",
    "insuperbirebbe": "insuperbire",
    "insuperbirebber": "insuperbire",
    "insuperbirebbero": "insuperbire",
    "insuperbirei": "insuperbire",
    "insuperbiremmo": "insuperbire",
    "insuperbiremo": "insuperbire",
    "insuperbireste": "insuperbire",
    "insuperbiresti": "insuperbire",
    "insuperbirete": "insuperbire",
    "insuperbiron": "insuperbire",
    "insuperbirono": "insuperbire",
    "insuperbirà": "insuperbire",
    "insuperbirò": "insuperbire",
    "insuperbisse": "insuperbire",
    "insuperbisser": "insuperbire",
    "insuperbissero": "insuperbire",
    "insuperbissi": "insuperbire",
    "insuperbissimo": "insuperbire",
    "insuperbiste": "insuperbire",
    "insuperbisti": "insuperbire",
    "insuperbita": "insuperbire",
    "insuperbite": "insuperbire",
    "insuperbiti": "insuperbire",
    "insuperbito": "insuperbire",
    "insuperbiva": "insuperbire",
    "insuperbivamo": "insuperbire",
    "insuperbivan": "insuperbire",
    "insuperbivano": "insuperbire",
    "insuperbivate": "insuperbire",
    "insuperbivi": "insuperbire",
    "insuperbivo": "insuperbire",
    "insuperbo": "insuperbire",
    "insuperbon": "insuperbire",
    "insuperbono": "insuperbire",
    "insuperbì": "insuperbire",
    "insurrezionali": "insurrezionale",
    "insurrezioni": "insurrezione",
    "insussistenti": "insussistente",
    "intabarra": "intabarrare",
    "intabarrai": "intabarrare",
    "intabarrammo": "intabarrare",
    "intabarran": "intabarrare",
    "intabarrando": "intabarrare",
    "intabarrano": "intabarrare",
    "intabarrante": "intabarrare",
    "intabarranti": "intabarrare",
    "intabarrar": "intabarrare",
    "intabarraron": "intabarrare",
    "intabarrarono": "intabarrare",
    "intabarrasse": "intabarrare",
    "intabarrasser": "intabarrare",
    "intabarrassero": "intabarrare",
    "intabarrassi": "intabarrare",
    "intabarrassimo": "intabarrare",
    "intabarraste": "intabarrare",
    "intabarrasti": "intabarrare",
    "intabarrata": "intabarrare",
    "intabarrate": "intabarrare",
    "intabarrati": "intabarrare",
    "intabarrato": "intabarrare",
    "intabarrava": "intabarrare",
    "intabarravamo": "intabarrare",
    "intabarravan": "intabarrare",
    "intabarravano": "intabarrare",
    "intabarravate": "intabarrare",
    "intabarravi": "intabarrare",
    "intabarravo": "intabarrare",
    "intabarrerai": "intabarrare",
    "intabarreran": "intabarrare",
    "intabarreranno": "intabarrare",
    "intabarrerebbe": "intabarrare",
    "intabarrerebber": "intabarrare",
    "intabarrerebbero": "intabarrare",
    "intabarrerei": "intabarrare",
    "intabarreremmo": "intabarrare",
    "intabarreremo": "intabarrare",
    "intabarrereste": "intabarrare",
    "intabarreresti": "intabarrare",
    "intabarrerete": "intabarrare",
    "intabarrerà": "intabarrare",
    "intabarrerò": "intabarrare",
    "intabarri": "intabarrare",
    "intabarriamo": "intabarrare",
    "intabarriate": "intabarrare",
    "intabarrin": "intabarrare",
    "intabarrino": "intabarrare",
    "intabarro": "intabarrare",
    "intabarrò": "intabarrare",
    "intacca": "intaccare",
    "intaccabili": "intaccabile",
    "intaccai": "intaccare",
    "intaccammo": "intaccare",
    "intaccan": "intaccare",
    "intaccando": "intaccare",
    "intaccano": "intaccare",
    "intaccante": "intaccare",
    "intaccanti": "intaccare",
    "intaccar": "intaccare",
    "intaccaron": "intaccare",
    "intaccarono": "intaccare",
    "intaccasse": "intaccare",
    "intaccasser": "intaccare",
    "intaccassero": "intaccare",
    "intaccassi": "intaccare",
    "intaccassimo": "intaccare",
    "intaccaste": "intaccare",
    "intaccasti": "intaccare",
    "intaccata": "intaccare",
    "intaccate": "intaccare",
    "intaccati": "intaccare",
    "intaccato": "intaccare",
    "intaccava": "intaccare",
    "intaccavamo": "intaccare",
    "intaccavan": "intaccare",
    "intaccavano": "intaccare",
    "intaccavate": "intaccare",
    "intaccavi": "intaccare",
    "intaccavo": "intaccare",
    "intaccherai": "intaccare",
    "intaccheran": "intaccare",
    "intaccheranno": "intaccare",
    "intaccherebbe": "intaccare",
    "intaccherebber": "intaccare",
    "intaccherebbero": "intaccare",
    "intaccherei": "intaccare",
    "intaccheremmo": "intaccare",
    "intaccheremo": "intaccare",
    "intacchereste": "intaccare",
    "intaccheresti": "intaccare",
    "intaccherete": "intaccare",
    "intaccherà": "intaccare",
    "intaccherò": "intaccare",
    "intacchi": "intaccare",
    "intacchiamo": "intaccare",
    "intacchiate": "intaccare",
    "intacchin": "intaccare",
    "intacchino": "intaccare",
    "intacco": "intaccare",
    "intaccò": "intaccare",
    "intagli": "intagliare",
    "intaglia": "intagliare",
    "intagliai": "intagliare",
    "intagliammo": "intagliare",
    "intagliamo": "intagliare",
    "intaglian": "intagliare",
    "intagliando": "intagliare",
    "intagliano": "intagliare",
    "intagliante": "intagliare",
    "intaglianti": "intagliare",
    "intagliar": "intagliare",
    "intagliaron": "intagliare",
    "intagliarono": "intagliare",
    "intagliasse": "intagliare",
    "intagliasser": "intagliare",
    "intagliassero": "intagliare",
    "intagliassi": "intagliare",
    "intagliassimo": "intagliare",
    "intagliaste": "intagliare",
    "intagliasti": "intagliare",
    "intagliata": "intagliare",
    "intagliate": "intagliare",
    "intagliati": "intagliare",
    "intagliato": "intagliare",
    "intagliatori": "intagliatore",
    "intagliava": "intagliare",
    "intagliavamo": "intagliare",
    "intagliavan": "intagliare",
    "intagliavano": "intagliare",
    "intagliavate": "intagliare",
    "intagliavi": "intagliare",
    "intagliavo": "intagliare",
    "intaglierai": "intagliare",
    "intaglieran": "intagliare",
    "intaglieranno": "intagliare",
    "intaglierebbe": "intagliare",
    "intaglierebber": "intagliare",
    "intaglierebbero": "intagliare",
    "intaglierei": "intagliare",
    "intaglieremmo": "intagliare",
    "intaglieremo": "intagliare",
    "intagliereste": "intagliare",
    "intaglieresti": "intagliare",
    "intaglierete": "intagliare",
    "intaglierà": "intagliare",
    "intaglierò": "intagliare",
    "intaglin": "intagliare",
    "intaglino": "intagliare",
    "intaglio": "intagliare",
    "intagliò": "intagliare",
    "intangibili": "intangibile",
    "intarsi": "intarsiare",
    "intarsia": "intarsiare",
    "intarsiai": "intarsiare",
    "intarsiammo": "intarsiare",
    "intarsiamo": "intarsiare",
    "intarsian": "intarsiare",
    "intarsiando": "intarsiare",
    "intarsiano": "intarsiare",
    "intarsiante": "intarsiare",
    "intarsianti": "intarsiare",
    "intarsiar": "intarsiare",
    "intarsiaron": "intarsiare",
    "intarsiarono": "intarsiare",
    "intarsiasse": "intarsiare",
    "intarsiasser": "intarsiare",
    "intarsiassero": "intarsiare",
    "intarsiassi": "intarsiare",
    "intarsiassimo": "intarsiare",
    "intarsiaste": "intarsiare",
    "intarsiasti": "intarsiare",
    "intarsiata": "intarsiare",
    "intarsiate": "intarsiare",
    "intarsiati": "intarsiare",
    "intarsiato": "intarsiare",
    "intarsiava": "intarsiare",
    "intarsiavamo": "intarsiare",
    "intarsiavan": "intarsiare",
    "intarsiavano": "intarsiare",
    "intarsiavate": "intarsiare",
    "intarsiavi": "intarsiare",
    "intarsiavo": "intarsiare",
    "intarsierai": "intarsiare",
    "intarsieran": "intarsiare",
    "intarsieranno": "intarsiare",
    "intarsierebbe": "intarsiare",
    "intarsierebber": "intarsiare",
    "intarsierebbero": "intarsiare",
    "intarsierei": "intarsiare",
    "intarsieremmo": "intarsiare",
    "intarsieremo": "intarsiare",
    "intarsiereste": "intarsiare",
    "intarsieresti": "intarsiare",
    "intarsierete": "intarsiare",
    "intarsierà": "intarsiare",
    "intarsierò": "intarsiare",
    "intarsin": "intarsiare",
    "intarsino": "intarsiare",
    "intarsio": "intarsiare",
    "intarsiò": "intarsiare",
    "intasa": "intasare",
    "intasai": "intasare",
    "intasamenti": "intasamento",
    "intasammo": "intasare",
    "intasan": "intasare",
    "intasando": "intasare",
    "intasano": "intasare",
    "intasante": "intasare",
    "intasanti": "intasare",
    "intasar": "intasare",
    "intasaron": "intasare",
    "intasarono": "intasare",
    "intasasse": "intasare",
    "intasasser": "intasare",
    "intasassero": "intasare",
    "intasassi": "intasare",
    "intasassimo": "intasare",
    "intasaste": "intasare",
    "intasasti": "intasare",
    "intasata": "intasare",
    "intasate": "intasare",
    "intasati": "intasare",
    "intasato": "intasare",
    "intasava": "intasare",
    "intasavamo": "intasare",
    "intasavan": "intasare",
    "intasavano": "intasare",
    "intasavate": "intasare",
    "intasavi": "intasare",
    "intasavo": "intasare",
    "intasca": "intascare",
    "intascai": "intascare",
    "intascammo": "intascare",
    "intascan": "intascare",
    "intascando": "intascare",
    "intascano": "intascare",
    "intascante": "intascare",
    "intascanti": "intascare",
    "intascar": "intascare",
    "intascaron": "intascare",
    "intascarono": "intascare",
    "intascasse": "intascare",
    "intascasser": "intascare",
    "intascassero": "intascare",
    "intascassi": "intascare",
    "intascassimo": "intascare",
    "intascaste": "intascare",
    "intascasti": "intascare",
    "intascata": "intascare",
    "intascate": "intascare",
    "intascati": "intascare",
    "intascato": "intascare",
    "intascava": "intascare",
    "intascavamo": "intascare",
    "intascavan": "intascare",
    "intascavano": "intascare",
    "intascavate": "intascare",
    "intascavi": "intascare",
    "intascavo": "intascare",
    "intascherai": "intascare",
    "intascheran": "intascare",
    "intascheranno": "intascare",
    "intascherebbe": "intascare",
    "intascherebber": "intascare",
    "intascherebbero": "intascare",
    "intascherei": "intascare",
    "intascheremmo": "intascare",
    "intascheremo": "intascare",
    "intaschereste": "intascare",
    "intascheresti": "intascare",
    "intascherete": "intascare",
    "intascherà": "intascare",
    "intascherò": "intascare",
    "intaschi": "intascare",
    "intaschiamo": "intascare",
    "intaschiate": "intascare",
    "intaschin": "intascare",
    "intaschino": "intascare",
    "intasco": "intascare",
    "intascò": "intascare",
    "intaserai": "intasare",
    "intaseran": "intasare",
    "intaseranno": "intasare",
    "intaserebbe": "intasare",
    "intaserebber": "intasare",
    "intaserebbero": "intasare",
    "intaserei": "intasare",
    "intaseremmo": "intasare",
    "intaseremo": "intasare",
    "intasereste": "intasare",
    "intaseresti": "intasare",
    "intaserete": "intasare",
    "intaserà": "intasare",
    "intaserò": "intasare",
    "intasi": "intasare",
    "intasiamo": "intasare",
    "intasiate": "intasare",
    "intasin": "intasare",
    "intasino": "intasare",
    "intaso": "intasare",
    "intasò": "intasare",
    "intatta": "intatto",
    "intatte": "intatto",
    "intatti": "intatto",
    "intavola": "intavolare",
    "intavolai": "intavolare",
    "intavolammo": "intavolare",
    "intavolan": "intavolare",
    "intavolando": "intavolare",
    "intavolano": "intavolare",
    "intavolante": "intavolare",
    "intavolanti": "intavolare",
    "intavolar": "intavolare",
    "intavolaron": "intavolare",
    "intavolarono": "intavolare",
    "intavolasse": "intavolare",
    "intavolasser": "intavolare",
    "intavolassero": "intavolare",
    "intavolassi": "intavolare",
    "intavolassimo": "intavolare",
    "intavolaste": "intavolare",
    "intavolasti": "intavolare",
    "intavolata": "intavolare",
    "intavolate": "intavolare",
    "intavolati": "intavolare",
    "intavolato": "intavolare",
    "intavolava": "intavolare",
    "intavolavamo": "intavolare",
    "intavolavan": "intavolare",
    "intavolavano": "intavolare",
    "intavolavate": "intavolare",
    "intavolavi": "intavolare",
    "intavolavo": "intavolare",
    "intavolerai": "intavolare",
    "intavoleran": "intavolare",
    "intavoleranno": "intavolare",
    "intavolerebbe": "intavolare",
    "intavolerebber": "intavolare",
    "intavolerebbero": "intavolare",
    "intavolerei": "intavolare",
    "intavoleremmo": "intavolare",
    "intavoleremo": "intavolare",
    "intavolereste": "intavolare",
    "intavoleresti": "intavolare",
    "intavolerete": "intavolare",
    "intavolerà": "intavolare",
    "intavolerò": "intavolare",
    "intavoli": "intavolare",
    "intavoliamo": "intavolare",
    "intavoliate": "intavolare",
    "intavolin": "intavolare",
    "intavolino": "intavolare",
    "intavolo": "intavolare",
    "intavolò": "intavolare",
    "integerrima": "integerrimo",
    "integerrime": "integerrimo",
    "integerrimi": "integerrimo",
    "integra": "integro",
    "integrabili": "integrabile",
    "integrai": "integrare",
    "integrali": "integrale",
    "integralismi": "integralismo",
    "integraliste": "integralista",
    "integralisti": "integralista",
    "integrammo": "integrare",
    "integran": "integrare",
    "integrando": "integrare",
    "integrano": "integrare",
    "integrante": "integrare",
    "integranti": "integrare",
    "integrar": "integrare",
    "integraron": "integrare",
    "integrarono": "integrare",
    "integrasse": "integrare",
    "integrasser": "integrare",
    "integrassero": "integrare",
    "integrassi": "integrare",
    "integrassimo": "integrare",
    "integraste": "integrare",
    "integrasti": "integrare",
    "integrata": "integrato",
    "integrate": "integrato",
    "integrati": "integrato",
    "integrativa": "integrativo",
    "integrative": "integrativo",
    "integrativi": "integrativo",
    "integrato": "integrare",
    "integratori": "integratore",
    "integrava": "integrare",
    "integravamo": "integrare",
    "integravan": "integrare",
    "integravano": "integrare",
    "integravate": "integrare",
    "integravi": "integrare",
    "integravo": "integrare",
    "integrazioni": "integrazione",
    "integre": "integro",
    "integrerai": "integrare",
    "integreran": "integrare",
    "integreranno": "integrare",
    "integrerebbe": "integrare",
    "integrerebber": "integrare",
    "integrerebbero": "integrare",
    "integrerei": "integrare",
    "integreremmo": "integrare",
    "integreremo": "integrare",
    "integrereste": "integrare",
    "integreresti": "integrare",
    "integrerete": "integrare",
    "integrerà": "integrare",
    "integrerò": "integrare",
    "integri": "integro",
    "integriamo": "integrare",
    "integriate": "integrare",
    "integrin": "integrare",
    "integrino": "integrare",
    "integrismi": "integrismo",
    "integro": "integrare",
    "integrò": "integrare",
    "intelai": "intelaiare",
    "intelaia": "intelaiare",
    "intelaiai": "intelaiare",
    "intelaiammo": "intelaiare",
    "intelaiamo": "intelaiare",
    "intelaian": "intelaiare",
    "intelaiando": "intelaiare",
    "intelaiano": "intelaiare",
    "intelaiante": "intelaiare",
    "intelaianti": "intelaiare",
    "intelaiar": "intelaiare",
    "intelaiaron": "intelaiare",
    "intelaiarono": "intelaiare",
    "intelaiasse": "intelaiare",
    "intelaiasser": "intelaiare",
    "intelaiassero": "intelaiare",
    "intelaiassi": "intelaiare",
    "intelaiassimo": "intelaiare",
    "intelaiaste": "intelaiare",
    "intelaiasti": "intelaiare",
    "intelaiata": "intelaiare",
    "intelaiate": "intelaiare",
    "intelaiati": "intelaiare",
    "intelaiato": "intelaiare",
    "intelaiature": "intelaiatura",
    "intelaiava": "intelaiare",
    "intelaiavamo": "intelaiare",
    "intelaiavan": "intelaiare",
    "intelaiavano": "intelaiare",
    "intelaiavate": "intelaiare",
    "intelaiavi": "intelaiare",
    "intelaiavo": "intelaiare",
    "intelaierai": "intelaiare",
    "intelaieran": "intelaiare",
    "intelaieranno": "intelaiare",
    "intelaierebbe": "intelaiare",
    "intelaierebber": "intelaiare",
    "intelaierebbero": "intelaiare",
    "intelaierei": "intelaiare",
    "intelaieremmo": "intelaiare",
    "intelaieremo": "intelaiare",
    "intelaiereste": "intelaiare",
    "intelaieresti": "intelaiare",
    "intelaierete": "intelaiare",
    "intelaierà": "intelaiare",
    "intelaierò": "intelaiare",
    "intelain": "intelaiare",
    "intelaino": "intelaiare",
    "intelaio": "intelaiare",
    "intelaiò": "intelaiare",
    "intelletti": "intelletto",
    "intellettiva": "intellettivo",
    "intellettive": "intellettivo",
    "intellettivi": "intellettivo",
    "intellettuali": "intellettuale",
    "intellettualismi": "intellettualismo",
    "intellettualistica": "intellettualistico",
    "intellettualistiche": "intellettualistico",
    "intellettualistici": "intellettualistico",
    "intellettualizza": "intellettualizzare",
    "intellettualizzai": "intellettualizzare",
    "intellettualizzammo": "intellettualizzare",
    "intellettualizzan": "intellettualizzare",
    "intellettualizzando": "intellettualizzare",
    "intellettualizzano": "intellettualizzare",
    "intellettualizzante": "intellettualizzare",
    "intellettualizzanti": "intellettualizzare",
    "intellettualizzar": "intellettualizzare",
    "intellettualizzaron": "intellettualizzare",
    "intellettualizzarono": "intellettualizzare",
    "intellettualizzasse": "intellettualizzare",
    "intellettualizzasser": "intellettualizzare",
    "intellettualizzassero": "intellettualizzare",
    "intellettualizzassi": "intellettualizzare",
    "intellettualizzassimo": "intellettualizzare",
    "intellettualizzaste": "intellettualizzare",
    "intellettualizzasti": "intellettualizzare",
    "intellettualizzata": "intellettualizzare",
    "intellettualizzate": "intellettualizzare",
    "intellettualizzati": "intellettualizzare",
    "intellettualizzato": "intellettualizzare",
    "intellettualizzava": "intellettualizzare",
    "intellettualizzavamo": "intellettualizzare",
    "intellettualizzavan": "intellettualizzare",
    "intellettualizzavano": "intellettualizzare",
    "intellettualizzavate": "intellettualizzare",
    "intellettualizzavi": "intellettualizzare",
    "intellettualizzavo": "intellettualizzare",
    "intellettualizzerai": "intellettualizzare",
    "intellettualizzeran": "intellettualizzare",
    "intellettualizzeranno": "intellettualizzare",
    "intellettualizzerebbe": "intellettualizzare",
    "intellettualizzerebber": "intellettualizzare",
    "intellettualizzerebbero": "intellettualizzare",
    "intellettualizzerei": "intellettualizzare",
    "intellettualizzeremmo": "intellettualizzare",
    "intellettualizzeremo": "intellettualizzare",
    "intellettualizzereste": "intellettualizzare",
    "intellettualizzeresti": "intellettualizzare",
    "intellettualizzerete": "intellettualizzare",
    "intellettualizzerà": "intellettualizzare",
    "intellettualizzerò": "intellettualizzare",
    "intellettualizzi": "intellettualizzare",
    "intellettualizziamo": "intellettualizzare",
    "intellettualizziate": "intellettualizzare",
    "intellettualizzin": "intellettualizzare",
    "intellettualizzino": "intellettualizzare",
    "intellettualizzo": "intellettualizzare",
    "intellettualizzò": "intellettualizzare",
    "intelligenti": "intelligente",
    "intelligenze": "intelligenza",
    "intellighentie": "intellighentia",
    "intellighenzie": "intellighenzia",
    "intemerata": "intemerato",
    "intemerate": "intemerato",
    "intemerati": "intemerato",
    "intemperanti": "intemperante",
    "intemperanze": "intemperanza",
    "intemperie": "intemperia",
    "intempestiva": "intempestivo",
    "intempestive": "intempestivo",
    "intempestivi": "intempestivo",
    "intenda": "intendere",
    "intendan": "intendere",
    "intendano": "intendere",
    "intende": "intendere",
    "intendemmo": "intendere",
    "intendendo": "intendere",
    "intendente": "intendere",
    "intendenti": "intendere",
    "intendenze": "intendenza",
    "intender": "intendere",
    "intenderai": "intendere",
    "intenderan": "intendere",
    "intenderanno": "intendere",
    "intenderebbe": "intendere",
    "intenderebber": "intendere",
    "intenderebbero": "intendere",
    "intenderei": "intendere",
    "intenderemmo": "intendere",
    "intenderemo": "intendere",
    "intendereste": "intendere",
    "intenderesti": "intendere",
    "intenderete": "intendere",
    "intenderà": "intendere",
    "intenderò": "intendere",
    "intendesse": "intendere",
    "intendesser": "intendere",
    "intendessero": "intendere",
    "intendessi": "intendere",
    "intendessimo": "intendere",
    "intendeste": "intendere",
    "intendesti": "intendere",
    "intendete": "intendere",
    "intendeva": "intendere",
    "intendevamo": "intendere",
    "intendevan": "intendere",
    "intendevano": "intendere",
    "intendevate": "intendere",
    "intendevi": "intendere",
    "intendevo": "intendere",
    "intendi": "intendere",
    "intendiamo": "intendere",
    "intendiate": "intendere",
    "intendimenti": "intendimento",
    "intenditori": "intenditore",
    "intendo": "intendere",
    "intendon": "intendere",
    "intendono": "intendere",
    "intenerendo": "intenerire",
    "intenerente": "intenerire",
    "intenerenti": "intenerire",
    "inteneriamo": "intenerire",
    "inteneriate": "intenerire",
    "intenerii": "intenerire",
    "intenerimmo": "intenerire",
    "intenerir": "intenerire",
    "intenerirai": "intenerire",
    "inteneriran": "intenerire",
    "inteneriranno": "intenerire",
    "intenerirebbe": "intenerire",
    "intenerirebber": "intenerire",
    "intenerirebbero": "intenerire",
    "intenerirei": "intenerire",
    "inteneriremmo": "intenerire",
    "inteneriremo": "intenerire",
    "intenerireste": "intenerire",
    "inteneriresti": "intenerire",
    "intenerirete": "intenerire",
    "inteneriron": "intenerire",
    "intenerirono": "intenerire",
    "intenerirà": "intenerire",
    "intenerirò": "intenerire",
    "intenerisca": "intenerire",
    "inteneriscan": "intenerire",
    "inteneriscano": "intenerire",
    "intenerisce": "intenerire",
    "intenerisci": "intenerire",
    "intenerisco": "intenerire",
    "inteneriscon": "intenerire",
    "inteneriscono": "intenerire",
    "intenerisse": "intenerire",
    "intenerisser": "intenerire",
    "intenerissero": "intenerire",
    "intenerissi": "intenerire",
    "intenerissimo": "intenerire",
    "inteneriste": "intenerire",
    "inteneristi": "intenerire",
    "intenerita": "intenerire",
    "intenerite": "intenerire",
    "inteneriti": "intenerire",
    "intenerito": "intenerire",
    "inteneriva": "intenerire",
    "intenerivamo": "intenerire",
    "intenerivan": "intenerire",
    "intenerivano": "intenerire",
    "intenerivate": "intenerire",
    "intenerivi": "intenerire",
    "intenerivo": "intenerire",
    "intenerì": "intenerire",
    "intensa": "intenso",
    "intense": "intenso",
    "intensi": "intenso",
    "intensifica": "intensificare",
    "intensificai": "intensificare",
    "intensificammo": "intensificare",
    "intensifican": "intensificare",
    "intensificando": "intensificare",
    "intensificano": "intensificare",
    "intensificante": "intensificare",
    "intensificanti": "intensificare",
    "intensificar": "intensificare",
    "intensificaron": "intensificare",
    "intensificarono": "intensificare",
    "intensificasse": "intensificare",
    "intensificasser": "intensificare",
    "intensificassero": "intensificare",
    "intensificassi": "intensificare",
    "intensificassimo": "intensificare",
    "intensificaste": "intensificare",
    "intensificasti": "intensificare",
    "intensificata": "intensificare",
    "intensificate": "intensificare",
    "intensificati": "intensificare",
    "intensificato": "intensificare",
    "intensificava": "intensificare",
    "intensificavamo": "intensificare",
    "intensificavan": "intensificare",
    "intensificavano": "intensificare",
    "intensificavate": "intensificare",
    "intensificavi": "intensificare",
    "intensificavo": "intensificare",
    "intensificazioni": "intensificazione",
    "intensificherai": "intensificare",
    "intensificheran": "intensificare",
    "intensificheranno": "intensificare",
    "intensificherebbe": "intensificare",
    "intensificherebber": "intensificare",
    "intensificherebbero": "intensificare",
    "intensificherei": "intensificare",
    "intensificheremmo": "intensificare",
    "intensificheremo": "intensificare",
    "intensifichereste": "intensificare",
    "intensificheresti": "intensificare",
    "intensificherete": "intensificare",
    "intensificherà": "intensificare",
    "intensificherò": "intensificare",
    "intensifichi": "intensificare",
    "intensifichiamo": "intensificare",
    "intensifichiate": "intensificare",
    "intensifichin": "intensificare",
    "intensifichino": "intensificare",
    "intensifico": "intensificare",
    "intensificò": "intensificare",
    "intensiva": "intensivo",
    "intensive": "intensivo",
    "intensivi": "intensivo",
    "intenta": "intento",
    "intentai": "intentare",
    "intentammo": "intentare",
    "intentan": "intentare",
    "intentando": "intentare",
    "intentano": "intentare",
    "intentante": "intentare",
    "intentanti": "intentare",
    "intentar": "intentare",
    "intentaron": "intentare",
    "intentarono": "intentare",
    "intentasse": "intentare",
    "intentasser": "intentare",
    "intentassero": "intentare",
    "intentassi": "intentare",
    "intentassimo": "intentare",
    "intentaste": "intentare",
    "intentasti": "intentare",
    "intentata": "intentato",
    "intentate": "intentato",
    "intentati": "intentato",
    "intentato": "intentare",
    "intentava": "intentare",
    "intentavamo": "intentare",
    "intentavan": "intentare",
    "intentavano": "intentare",
    "intentavate": "intentare",
    "intentavi": "intentare",
    "intentavo": "intentare",
    "intente": "intento",
    "intenterai": "intentare",
    "intenteran": "intentare",
    "intenteranno": "intentare",
    "intenterebbe": "intentare",
    "intenterebber": "intentare",
    "intenterebbero": "intentare",
    "intenterei": "intentare",
    "intenteremmo": "intentare",
    "intenteremo": "intentare",
    "intentereste": "intentare",
    "intenteresti": "intentare",
    "intenterete": "intentare",
    "intenterà": "intentare",
    "intenterò": "intentare",
    "intenti": "intento",
    "intentiamo": "intentare",
    "intentiate": "intentare",
    "intentin": "intentare",
    "intentino": "intentare",
    "intento": "intentare",
    "intentò": "intentare",
    "intenzionali": "intenzionale",
    "intenzionata": "intenzionato",
    "intenzionate": "intenzionato",
    "intenzionati": "intenzionato",
    "intenzioni": "intenzione",
    "intepretazioni": "intepretazione",
    "inter-comunitari": "inter-comunitario",
    "inter-comunitaria": "inter-comunitario",
    "inter-comunitarie": "inter-comunitario",
    "inter-generazionali": "inter-generazionale",
    "intera": "intero",
    "interagendo": "interagire",
    "interagente": "interagire",
    "interagenti": "interagire",
    "interagiamo": "interagire",
    "interagiate": "interagire",
    "interagii": "interagire",
    "interagimmo": "interagire",
    "interagir": "interagire",
    "interagirai": "interagire",
    "interagiran": "interagire",
    "interagiranno": "interagire",
    "interagirebbe": "interagire",
    "interagirebber": "interagire",
    "interagirebbero": "interagire",
    "interagirei": "interagire",
    "interagiremmo": "interagire",
    "interagiremo": "interagire",
    "interagireste": "interagire",
    "interagiresti": "interagire",
    "interagirete": "interagire",
    "interagiron": "interagire",
    "interagirono": "interagire",
    "interagirà": "interagire",
    "interagirò": "interagire",
    "interagisca": "interagire",
    "interagiscan": "interagire",
    "interagiscano": "interagire",
    "interagisce": "interagire",
    "interagisci": "interagire",
    "interagisco": "interagire",
    "interagiscon": "interagire",
    "interagiscono": "interagire",
    "interagisse": "interagire",
    "interagisser": "interagire",
    "interagissero": "interagire",
    "interagissi": "interagire",
    "interagissimo": "interagire",
    "interagiste": "interagire",
    "interagisti": "interagire",
    "interagita": "interagire",
    "interagite": "interagire",
    "interagiti": "interagire",
    "interagito": "interagire",
    "interagiva": "interagire",
    "interagivamo": "interagire",
    "interagivan": "interagire",
    "interagivano": "interagire",
    "interagivate": "interagire",
    "interagivi": "interagire",
    "interagivo": "interagire",
    "interagì": "interagire",
    "interaziendali": "interaziendale",
    "interazioni": "interazione",
    "interbancari": "interbancario",
    "interbancaria": "interbancario",
    "interbancarie": "interbancario",
    "intercala": "intercalare",
    "intercalai": "intercalare",
    "intercalammo": "intercalare",
    "intercalan": "intercalare",
    "intercalando": "intercalare",
    "intercalano": "intercalare",
    "intercalante": "intercalare",
    "intercalanti": "intercalare",
    "intercalar": "intercalare",
    "intercalaron": "intercalare",
    "intercalarono": "intercalare",
    "intercalasse": "intercalare",
    "intercalasser": "intercalare",
    "intercalassero": "intercalare",
    "intercalassi": "intercalare",
    "intercalassimo": "intercalare",
    "intercalaste": "intercalare",
    "intercalasti": "intercalare",
    "intercalata": "intercalare",
    "intercalate": "intercalare",
    "intercalati": "intercalare",
    "intercalato": "intercalare",
    "intercalava": "intercalare",
    "intercalavamo": "intercalare",
    "intercalavan": "intercalare",
    "intercalavano": "intercalare",
    "intercalavate": "intercalare",
    "intercalavi": "intercalare",
    "intercalavo": "intercalare",
    "intercalerai": "intercalare",
    "intercaleran": "intercalare",
    "intercaleranno": "intercalare",
    "intercalerebbe": "intercalare",
    "intercalerebber": "intercalare",
    "intercalerebbero": "intercalare",
    "intercalerei": "intercalare",
    "intercaleremmo": "intercalare",
    "intercaleremo": "intercalare",
    "intercalereste": "intercalare",
    "intercaleresti": "intercalare",
    "intercalerete": "intercalare",
    "intercalerà": "intercalare",
    "intercalerò": "intercalare",
    "intercali": "intercalare",
    "intercaliamo": "intercalare",
    "intercaliate": "intercalare",
    "intercalin": "intercalare",
    "intercalino": "intercalare",
    "intercalo": "intercalare",
    "intercalò": "intercalare",
    "intercambiabili": "intercambiabile",
    "intercapedini": "intercapedine",
    "interceda": "intercedere",
    "intercedan": "intercedere",
    "intercedano": "intercedere",
    "intercede": "intercedere",
    "intercedei": "intercedere",
    "intercedemmo": "intercedere",
    "intercedendo": "intercedere",
    "intercedente": "intercedere",
    "intercedenti": "intercedere",
    "interceder": "intercedere",
    "intercederai": "intercedere",
    "intercederan": "intercedere",
    "intercederanno": "intercedere",
    "intercederebbe": "intercedere",
    "intercederebber": "intercedere",
    "intercederebbero": "intercedere",
    "intercederei": "intercedere",
    "intercederemmo": "intercedere",
    "intercederemo": "intercedere",
    "intercedereste": "intercedere",
    "intercederesti": "intercedere",
    "intercederete": "intercedere",
    "intercederon": "intercedere",
    "intercederono": "intercedere",
    "intercederà": "intercedere",
    "intercederò": "intercedere",
    "intercedesse": "intercedere",
    "intercedesser": "intercedere",
    "intercedessero": "intercedere",
    "intercedessi": "intercedere",
    "intercedessimo": "intercedere",
    "intercedeste": "intercedere",
    "intercedesti": "intercedere",
    "intercedete": "intercedere",
    "intercedeva": "intercedere",
    "intercedevamo": "intercedere",
    "intercedevan": "intercedere",
    "intercedevano": "intercedere",
    "intercedevate": "intercedere",
    "intercedevi": "intercedere",
    "intercedevo": "intercedere",
    "intercedi": "intercedere",
    "intercediamo": "intercedere",
    "intercediate": "intercedere",
    "intercedo": "intercedere",
    "intercedon": "intercedere",
    "intercedono": "intercedere",
    "interceduta": "intercedere",
    "intercedute": "intercedere",
    "interceduti": "intercedere",
    "interceduto": "intercedere",
    "intercedè": "intercedere",
    "intercessioni": "intercessione",
    "intercetta": "intercettare",
    "intercettai": "intercettare",
    "intercettammo": "intercettare",
    "intercettan": "intercettare",
    "intercettando": "intercettare",
    "intercettano": "intercettare",
    "intercettante": "intercettare",
    "intercettanti": "intercettare",
    "intercettar": "intercettare",
    "intercettaron": "intercettare",
    "intercettarono": "intercettare",
    "intercettasse": "intercettare",
    "intercettasser": "intercettare",
    "intercettassero": "intercettare",
    "intercettassi": "intercettare",
    "intercettassimo": "intercettare",
    "intercettaste": "intercettare",
    "intercettasti": "intercettare",
    "intercettata": "intercettare",
    "intercettate": "intercettare",
    "intercettati": "intercettare",
    "intercettato": "intercettare",
    "intercettava": "intercettare",
    "intercettavamo": "intercettare",
    "intercettavan": "intercettare",
    "intercettavano": "intercettare",
    "intercettavate": "intercettare",
    "intercettavi": "intercettare",
    "intercettavo": "intercettare",
    "intercettazioni": "intercettazione",
    "intercetterai": "intercettare",
    "intercetteran": "intercettare",
    "intercetteranno": "intercettare",
    "intercetterebbe": "intercettare",
    "intercetterebber": "intercettare",
    "intercetterebbero": "intercettare",
    "intercetterei": "intercettare",
    "intercetteremmo": "intercettare",
    "intercetteremo": "intercettare",
    "intercettereste": "intercettare",
    "intercetteresti": "intercettare",
    "intercetterete": "intercettare",
    "intercetterà": "intercettare",
    "intercetterò": "intercettare",
    "intercetti": "intercettare",
    "intercettiamo": "intercettare",
    "intercettiate": "intercettare",
    "intercettin": "intercettare",
    "intercettino": "intercettare",
    "intercetto": "intercettare",
    "intercettò": "intercettare",
    "interclassiste": "interclassista",
    "interclassisti": "interclassista",
    "intercollega": "intercollegare",
    "intercollegai": "intercollegare",
    "intercollegammo": "intercollegare",
    "intercollegan": "intercollegare",
    "intercollegando": "intercollegare",
    "intercollegano": "intercollegare",
    "intercollegante": "intercollegare",
    "intercolleganti": "intercollegare",
    "intercollegar": "intercollegare",
    "intercollegaron": "intercollegare",
    "intercollegarono": "intercollegare",
    "intercollegasse": "intercollegare",
    "intercollegasser": "intercollegare",
    "intercollegassero": "intercollegare",
    "intercollegassi": "intercollegare",
    "intercollegassimo": "intercollegare",
    "intercollegaste": "intercollegare",
    "intercollegasti": "intercollegare",
    "intercollegata": "intercollegare",
    "intercollegate": "intercollegare",
    "intercollegati": "intercollegare",
    "intercollegato": "intercollegare",
    "intercollegava": "intercollegare",
    "intercollegavamo": "intercollegare",
    "intercollegavan": "intercollegare",
    "intercollegavano": "intercollegare",
    "intercollegavate": "intercollegare",
    "intercollegavi": "intercollegare",
    "intercollegavo": "intercollegare",
    "intercollegherai": "intercollegare",
    "intercollegheran": "intercollegare",
    "intercollegheranno": "intercollegare",
    "intercollegherebbe": "intercollegare",
    "intercollegherebber": "intercollegare",
    "intercollegherebbero": "intercollegare",
    "intercollegherei": "intercollegare",
    "intercollegheremmo": "intercollegare",
    "intercollegheremo": "intercollegare",
    "intercolleghereste": "intercollegare",
    "intercollegheresti": "intercollegare",
    "intercollegherete": "intercollegare",
    "intercollegherà": "intercollegare",
    "intercollegherò": "intercollegare",
    "intercolleghi": "intercollegare",
    "intercolleghiamo": "intercollegare",
    "intercolleghiate": "intercollegare",
    "intercolleghin": "intercollegare",
    "intercolleghino": "intercollegare",
    "intercollego": "intercollegare",
    "intercollegò": "intercollegare",
    "intercomunali": "intercomunale",
    "interconfederali": "interconfederale",
    "interconnessioni": "interconnessione",
    "interconnetta": "interconnettere",
    "interconnettan": "interconnettere",
    "interconnettano": "interconnettere",
    "interconnette": "interconnettere",
    "interconnettei": "interconnettere",
    "interconnettemmo": "interconnettere",
    "interconnettendo": "interconnettere",
    "interconnettente": "interconnettere",
    "interconnettenti": "interconnettere",
    "interconnetter": "interconnettere",
    "interconnetterai": "interconnettere",
    "interconnetteran": "interconnettere",
    "interconnetteranno": "interconnettere",
    "interconnetterebbe": "interconnettere",
    "interconnetterebber": "interconnettere",
    "interconnetterebbero": "interconnettere",
    "interconnetterei": "interconnettere",
    "interconnetteremmo": "interconnettere",
    "interconnetteremo": "interconnettere",
    "interconnettereste": "interconnettere",
    "interconnetteresti": "interconnettere",
    "interconnetterete": "interconnettere",
    "interconnetteron": "interconnettere",
    "interconnetterono": "interconnettere",
    "interconnetterà": "interconnettere",
    "interconnetterò": "interconnettere",
    "interconnettesse": "interconnettere",
    "interconnettesser": "interconnettere",
    "interconnettessero": "interconnettere",
    "interconnettessi": "interconnettere",
    "interconnettessimo": "interconnettere",
    "interconnetteste": "interconnettere",
    "interconnettesti": "interconnettere",
    "interconnettete": "interconnettere",
    "interconnetteva": "interconnettere",
    "interconnettevamo": "interconnettere",
    "interconnettevan": "interconnettere",
    "interconnettevano": "interconnettere",
    "interconnettevate": "interconnettere",
    "interconnettevi": "interconnettere",
    "interconnettevo": "interconnettere",
    "interconnetti": "interconnettere",
    "interconnettiamo": "interconnettere",
    "interconnettiate": "interconnettere",
    "interconnetto": "interconnettere",
    "interconnetton": "interconnettere",
    "interconnettono": "interconnettere",
    "interconnettuta": "interconnettere",
    "interconnettute": "interconnettere",
    "interconnettuti": "interconnettere",
    "interconnettuto": "interconnettere",
    "interconnettè": "interconnettere",
    "intercontinentali": "intercontinentale",
    "intercorra": "intercorrere",
    "intercorran": "intercorrere",
    "intercorrano": "intercorrere",
    "intercorre": "intercorrere",
    "intercorremmo": "intercorrere",
    "intercorrendo": "intercorrere",
    "intercorrente": "intercorrere",
    "intercorrenti": "intercorrere",
    "intercorrer": "intercorrere",
    "intercorrerai": "intercorrere",
    "intercorreran": "intercorrere",
    "intercorreranno": "intercorrere",
    "intercorrerebbe": "intercorrere",
    "intercorrerebber": "intercorrere",
    "intercorrerebbero": "intercorrere",
    "intercorrerei": "intercorrere",
    "intercorreremmo": "intercorrere",
    "intercorreremo": "intercorrere",
    "intercorrereste": "intercorrere",
    "intercorreresti": "intercorrere",
    "intercorrerete": "intercorrere",
    "intercorrerà": "intercorrere",
    "intercorrerò": "intercorrere",
    "intercorresse": "intercorrere",
    "intercorresser": "intercorrere",
    "intercorressero": "intercorrere",
    "intercorressi": "intercorrere",
    "intercorressimo": "intercorrere",
    "intercorreste": "intercorrere",
    "intercorresti": "intercorrere",
    "intercorrete": "intercorrere",
    "intercorreva": "intercorrere",
    "intercorrevamo": "intercorrere",
    "intercorrevan": "intercorrere",
    "intercorrevano": "intercorrere",
    "intercorrevate": "intercorrere",
    "intercorrevi": "intercorrere",
    "intercorrevo": "intercorrere",
    "intercorri": "intercorrere",
    "intercorriamo": "intercorrere",
    "intercorriate": "intercorrere",
    "intercorro": "intercorrere",
    "intercorron": "intercorrere",
    "intercorrono": "intercorrere",
    "intercorsa": "intercorrere",
    "intercorse": "intercorrere",
    "intercorser": "intercorrere",
    "intercorsero": "intercorrere",
    "intercorsi": "intercorrere",
    "intercorso": "intercorrere",
    "interdendo": "interdire",
    "interdente": "interdire",
    "interdenti": "interdire",
    "interdetta": "interdetto",
    "interdette": "interdetto",
    "interdetti": "interdetto",
    "interdiamo": "interdire",
    "interdiate": "interdire",
    "interdii": "interdire",
    "interdimmo": "interdire",
    "interdipendenti": "interdipendente",
    "interdipendenze": "interdipendenza",
    "interdir": "interdire",
    "interdirai": "interdire",
    "interdiran": "interdire",
    "interdiranno": "interdire",
    "interdirebbe": "interdire",
    "interdirebber": "interdire",
    "interdirebbero": "interdire",
    "interdirei": "interdire",
    "interdiremmo": "interdire",
    "interdiremo": "interdire",
    "interdireste": "interdire",
    "interdiresti": "interdire",
    "interdirete": "interdire",
    "interdiron": "interdire",
    "interdirono": "interdire",
    "interdirà": "interdire",
    "interdirò": "interdire",
    "interdisca": "interdire",
    "interdiscan": "interdire",
    "interdiscano": "interdire",
    "interdisce": "interdire",
    "interdisci": "interdire",
    "interdisciplina": "interdisciplinare",
    "interdisciplinai": "interdisciplinare",
    "interdisciplinammo": "interdisciplinare",
    "interdisciplinan": "interdisciplinare",
    "interdisciplinando": "interdisciplinare",
    "interdisciplinano": "interdisciplinare",
    "interdisciplinante": "interdisciplinare",
    "interdisciplinanti": "interdisciplinare",
    "interdisciplinar": "interdisciplinare",
    "interdisciplinari": "interdisciplinare",
    "interdisciplinaron": "interdisciplinare",
    "interdisciplinarono": "interdisciplinare",
    "interdisciplinasse": "interdisciplinare",
    "interdisciplinasser": "interdisciplinare",
    "interdisciplinassero": "interdisciplinare",
    "interdisciplinassi": "interdisciplinare",
    "interdisciplinassimo": "interdisciplinare",
    "interdisciplinaste": "interdisciplinare",
    "interdisciplinasti": "interdisciplinare",
    "interdisciplinata": "interdisciplinare",
    "interdisciplinate": "interdisciplinare",
    "interdisciplinati": "interdisciplinare",
    "interdisciplinato": "interdisciplinare",
    "interdisciplinava": "interdisciplinare",
    "interdisciplinavamo": "interdisciplinare",
    "interdisciplinavan": "interdisciplinare",
    "interdisciplinavano": "interdisciplinare",
    "interdisciplinavate": "interdisciplinare",
    "interdisciplinavi": "interdisciplinare",
    "interdisciplinavo": "interdisciplinare",
    "interdisciplinerai": "interdisciplinare",
    "interdisciplineran": "interdisciplinare",
    "interdisciplineranno": "interdisciplinare",
    "interdisciplinerebbe": "interdisciplinare",
    "interdisciplinerebber": "interdisciplinare",
    "interdisciplinerebbero": "interdisciplinare",
    "interdisciplinerei": "interdisciplinare",
    "interdisciplineremmo": "interdisciplinare",
    "interdisciplineremo": "interdisciplinare",
    "interdisciplinereste": "interdisciplinare",
    "interdisciplineresti": "interdisciplinare",
    "interdisciplinerete": "interdisciplinare",
    "interdisciplinerà": "interdisciplinare",
    "interdisciplinerò": "interdisciplinare",
    "interdisciplini": "interdisciplinare",
    "interdiscipliniamo": "interdisciplinare",
    "interdiscipliniate": "interdisciplinare",
    "interdisciplinin": "interdisciplinare",
    "interdisciplinino": "interdisciplinare",
    "interdisciplino": "interdisciplinare",
    "interdisciplinò": "interdisciplinare",
    "interdisco": "interdire",
    "interdiscon": "interdire",
    "interdiscono": "interdire",
    "interdisse": "interdire",
    "interdisser": "interdire",
    "interdissero": "interdire",
    "interdissi": "interdire",
    "interdissimo": "interdire",
    "interdiste": "interdire",
    "interdisti": "interdire",
    "interdita": "interdire",
    "interdite": "interdire",
    "interditi": "interdire",
    "interdito": "interdire",
    "interdiva": "interdire",
    "interdivamo": "interdire",
    "interdivan": "interdire",
    "interdivano": "interdire",
    "interdivate": "interdire",
    "interdivi": "interdire",
    "interdivo": "interdire",
    "interdizioni": "interdizione",
    "interdì": "interdire",
    "intere": "intero",
    "interessa": "interessare",
    "interessai": "interessare",
    "interessamenti": "interessamento",
    "interessammo": "interessare",
    "interessan": "interessare",
    "interessando": "interessare",
    "interessano": "interessare",
    "interessante": "interessare",
    "interessanti": "interessare",
    "interessar": "interessare",
    "interessaron": "interessare",
    "interessarono": "interessare",
    "interessasse": "interessare",
    "interessasser": "interessare",
    "interessassero": "interessare",
    "interessassi": "interessare",
    "interessassimo": "interessare",
    "interessaste": "interessare",
    "interessasti": "interessare",
    "interessata": "interessato",
    "interessate": "interessato",
    "interessati": "interessato",
    "interessato": "interessare",
    "interessava": "interessare",
    "interessavamo": "interessare",
    "interessavan": "interessare",
    "interessavano": "interessare",
    "interessavate": "interessare",
    "interessavi": "interessare",
    "interessavo": "interessare",
    "interesserai": "interessare",
    "interesseran": "interessare",
    "interesseranno": "interessare",
    "interesserebbe": "interessare",
    "interesserebber": "interessare",
    "interesserebbero": "interessare",
    "interesserei": "interessare",
    "interesseremmo": "interessare",
    "interesseremo": "interessare",
    "interessereste": "interessare",
    "interesseresti": "interessare",
    "interesserete": "interessare",
    "interesserà": "interessare",
    "interesserò": "interessare",
    "interessi": "interesse",
    "interessiamo": "interessare",
    "interessiate": "interessare",
    "interessin": "interessare",
    "interessino": "interessare",
    "interesso": "interessare",
    "interessò": "interessare",
    "interetnica": "interetnico",
    "interetniche": "interetnico",
    "interetnici": "interetnico",
    "interezze": "interezza",
    "interfacce": "interfaccia",
    "interfaccerai": "interfacciare",
    "interfacceran": "interfacciare",
    "interfacceranno": "interfacciare",
    "interfaccerebbe": "interfacciare",
    "interfaccerebber": "interfacciare",
    "interfaccerebbero": "interfacciare",
    "interfaccerei": "interfacciare",
    "interfacceremmo": "interfacciare",
    "interfacceremo": "interfacciare",
    "interfaccereste": "interfacciare",
    "interfacceresti": "interfacciare",
    "interfaccerete": "interfacciare",
    "interfaccerà": "interfacciare",
    "interfaccerò": "interfacciare",
    "interfacci": "interfacciare",
    "interfaccia": "interfacciare",
    "interfacciai": "interfacciare",
    "interfacciammo": "interfacciare",
    "interfacciamo": "interfacciare",
    "interfaccian": "interfacciare",
    "interfacciando": "interfacciare",
    "interfacciano": "interfacciare",
    "interfacciante": "interfacciare",
    "interfaccianti": "interfacciare",
    "interfacciar": "interfacciare",
    "interfacciaron": "interfacciare",
    "interfacciarono": "interfacciare",
    "interfacciasse": "interfacciare",
    "interfacciasser": "interfacciare",
    "interfacciassero": "interfacciare",
    "interfacciassi": "interfacciare",
    "interfacciassimo": "interfacciare",
    "interfacciaste": "interfacciare",
    "interfacciasti": "interfacciare",
    "interfacciata": "interfacciare",
    "interfacciate": "interfacciare",
    "interfacciati": "interfacciare",
    "interfacciato": "interfacciare",
    "interfacciava": "interfacciare",
    "interfacciavamo": "interfacciare",
    "interfacciavan": "interfacciare",
    "interfacciavano": "interfacciare",
    "interfacciavate": "interfacciare",
    "interfacciavi": "interfacciare",
    "interfacciavo": "interfacciare",
    "interfaccin": "interfacciare",
    "interfaccino": "interfacciare",
    "interfaccio": "interfacciare",
    "interfacciò": "interfacciare",
    "interferendo": "interferire",
    "interferente": "interferire",
    "interferenti": "interferire",
    "interferenze": "interferenza",
    "interferiamo": "interferire",
    "interferiate": "interferire",
    "interferii": "interferire",
    "interferimmo": "interferire",
    "interferir": "interferire",
    "interferirai": "interferire",
    "interferiran": "interferire",
    "interferiranno": "interferire",
    "interferirebbe": "interferire",
    "interferirebber": "interferire",
    "interferirebbero": "interferire",
    "interferirei": "interferire",
    "interferiremmo": "interferire",
    "interferiremo": "interferire",
    "interferireste": "interferire",
    "interferiresti": "interferire",
    "interferirete": "interferire",
    "interferiron": "interferire",
    "interferirono": "interferire",
    "interferirà": "interferire",
    "interferirò": "interferire",
    "interferisca": "interferire",
    "interferiscan": "interferire",
    "interferiscano": "interferire",
    "interferisce": "interferire",
    "interferisci": "interferire",
    "interferisco": "interferire",
    "interferiscon": "interferire",
    "interferiscono": "interferire",
    "interferisse": "interferire",
    "interferisser": "interferire",
    "interferissero": "interferire",
    "interferissi": "interferire",
    "interferissimo": "interferire",
    "interferiste": "interferire",
    "interferisti": "interferire",
    "interferita": "interferire",
    "interferite": "interferire",
    "interferiti": "interferire",
    "interferito": "interferire",
    "interferiva": "interferire",
    "interferivamo": "interferire",
    "interferivan": "interferire",
    "interferivano": "interferire",
    "interferivate": "interferire",
    "interferivi": "interferire",
    "interferivo": "interferire",
    "interferì": "interferire",
    "intergovernativa": "intergovernativo",
    "intergovernative": "intergovernativo",
    "intergovernativi": "intergovernativo",
    "interi": "intero",
    "interiezioni": "interiezione",
    "interinali": "interinale",
    "interiori": "interiore",
    "interiorizza": "interiorizzare",
    "interiorizzai": "interiorizzare",
    "interiorizzammo": "interiorizzare",
    "interiorizzan": "interiorizzare",
    "interiorizzando": "interiorizzare",
    "interiorizzano": "interiorizzare",
    "interiorizzante": "interiorizzare",
    "interiorizzanti": "interiorizzare",
    "interiorizzar": "interiorizzare",
    "interiorizzaron": "interiorizzare",
    "interiorizzarono": "interiorizzare",
    "interiorizzasse": "interiorizzare",
    "interiorizzasser": "interiorizzare",
    "interiorizzassero": "interiorizzare",
    "interiorizzassi": "interiorizzare",
    "interiorizzassimo": "interiorizzare",
    "interiorizzaste": "interiorizzare",
    "interiorizzasti": "interiorizzare",
    "interiorizzata": "interiorizzare",
    "interiorizzate": "interiorizzare",
    "interiorizzati": "interiorizzare",
    "interiorizzato": "interiorizzare",
    "interiorizzava": "interiorizzare",
    "interiorizzavamo": "interiorizzare",
    "interiorizzavan": "interiorizzare",
    "interiorizzavano": "interiorizzare",
    "interiorizzavate": "interiorizzare",
    "interiorizzavi": "interiorizzare",
    "interiorizzavo": "interiorizzare",
    "interiorizzerai": "interiorizzare",
    "interiorizzeran": "interiorizzare",
    "interiorizzeranno": "interiorizzare",
    "interiorizzerebbe": "interiorizzare",
    "interiorizzerebber": "interiorizzare",
    "interiorizzerebbero": "interiorizzare",
    "interiorizzerei": "interiorizzare",
    "interiorizzeremmo": "interiorizzare",
    "interiorizzeremo": "interiorizzare",
    "interiorizzereste": "interiorizzare",
    "interiorizzeresti": "interiorizzare",
    "interiorizzerete": "interiorizzare",
    "interiorizzerà": "interiorizzare",
    "interiorizzerò": "interiorizzare",
    "interiorizzi": "interiorizzare",
    "interiorizziamo": "interiorizzare",
    "interiorizziate": "interiorizzare",
    "interiorizzin": "interiorizzare",
    "interiorizzino": "interiorizzare",
    "interiorizzo": "interiorizzare",
    "interiorizzò": "interiorizzare",
    "interiste": "interista",
    "interisti": "interista",
    "interlinea": "interlineare",
    "interlineai": "interlineare",
    "interlineammo": "interlineare",
    "interlinean": "interlineare",
    "interlineando": "interlineare",
    "interlineano": "interlineare",
    "interlineante": "interlineare",
    "interlineanti": "interlineare",
    "interlinear": "interlineare",
    "interlinearon": "interlineare",
    "interlinearono": "interlineare",
    "interlineasse": "interlineare",
    "interlineasser": "interlineare",
    "interlineassero": "interlineare",
    "interlineassi": "interlineare",
    "interlineassimo": "interlineare",
    "interlineaste": "interlineare",
    "interlineasti": "interlineare",
    "interlineata": "interlineare",
    "interlineate": "interlineare",
    "interlineati": "interlineare",
    "interlineato": "interlineare",
    "interlineava": "interlineare",
    "interlineavamo": "interlineare",
    "interlineavan": "interlineare",
    "interlineavano": "interlineare",
    "interlineavate": "interlineare",
    "interlineavi": "interlineare",
    "interlineavo": "interlineare",
    "interlineerai": "interlineare",
    "interlineeran": "interlineare",
    "interlineeranno": "interlineare",
    "interlineerebbe": "interlineare",
    "interlineerebber": "interlineare",
    "interlineerebbero": "interlineare",
    "interlineerei": "interlineare",
    "interlineeremmo": "interlineare",
    "interlineeremo": "interlineare",
    "interlineereste": "interlineare",
    "interlineeresti": "interlineare",
    "interlineerete": "interlineare",
    "interlineerà": "interlineare",
    "interlineerò": "interlineare",
    "interlinei": "interlineare",
    "interlineiamo": "interlineare",
    "interlineiate": "interlineare",
    "interlinein": "interlineare",
    "interlineino": "interlineare",
    "interlineo": "interlineare",
    "interlineò": "interlineare",
    "interlocutori": "interlocutorio",
    "interlocutoria": "interlocutorio",
    "interlocutorie": "interlocutorio",
    "interlocutrice": "interlocutore",
    "interlocutrici": "interlocutrice",
    "interloquendo": "interloquire",
    "interloquente": "interloquire",
    "interloquenti": "interloquire",
    "interloquiamo": "interloquire",
    "interloquiate": "interloquire",
    "interloquii": "interloquire",
    "interloquimmo": "interloquire",
    "interloquir": "interloquire",
    "interloquirai": "interloquire",
    "interloquiran": "interloquire",
    "interloquiranno": "interloquire",
    "interloquirebbe": "interloquire",
    "interloquirebber": "interloquire",
    "interloquirebbero": "interloquire",
    "interloquirei": "interloquire",
    "interloquiremmo": "interloquire",
    "interloquiremo": "interloquire",
    "interloquireste": "interloquire",
    "interloquiresti": "interloquire",
    "interloquirete": "interloquire",
    "interloquiron": "interloquire",
    "interloquirono": "interloquire",
    "interloquirà": "interloquire",
    "interloquirò": "interloquire",
    "interloquisca": "interloquire",
    "interloquiscan": "interloquire",
    "interloquiscano": "interloquire",
    "interloquisce": "interloquire",
    "interloquisci": "interloquire",
    "interloquisco": "interloquire",
    "interloquiscon": "interloquire",
    "interloquiscono": "interloquire",
    "interloquisse": "interloquire",
    "interloquisser": "interloquire",
    "interloquissero": "interloquire",
    "interloquissi": "interloquire",
    "interloquissimo": "interloquire",
    "interloquiste": "interloquire",
    "interloquisti": "interloquire",
    "interloquita": "interloquire",
    "interloquite": "interloquire",
    "interloquiti": "interloquire",
    "interloquito": "interloquire",
    "interloquiva": "interloquire",
    "interloquivamo": "interloquire",
    "interloquivan": "interloquire",
    "interloquivano": "interloquire",
    "interloquivate": "interloquire",
    "interloquivi": "interloquire",
    "interloquivo": "interloquire",
    "interloquì": "interloquire",
    "interludi": "interludio",
    "intermedi": "intermedio",
    "intermedia": "intermedio",
    "intermediai": "intermediare",
    "intermediammo": "intermediare",
    "intermediamo": "intermediare",
    "intermedian": "intermediare",
    "intermediando": "intermediare",
    "intermediano": "intermediare",
    "intermediante": "intermediare",
    "intermedianti": "intermediare",
    "intermediar": "intermediare",
    "intermediari": "intermediario",
    "intermediaria": "intermediario",
    "intermediarie": "intermediario",
    "intermediaron": "intermediare",
    "intermediarono": "intermediare",
    "intermediasse": "intermediare",
    "intermediasser": "intermediare",
    "intermediassero": "intermediare",
    "intermediassi": "intermediare",
    "intermediassimo": "intermediare",
    "intermediaste": "intermediare",
    "intermediasti": "intermediare",
    "intermediata": "intermediare",
    "intermediate": "intermediare",
    "intermediati": "intermediare",
    "intermediato": "intermediare",
    "intermediava": "intermediare",
    "intermediavamo": "intermediare",
    "intermediavan": "intermediare",
    "intermediavano": "intermediare",
    "intermediavate": "intermediare",
    "intermediavi": "intermediare",
    "intermediavo": "intermediare",
    "intermediazioni": "intermediazione",
    "intermedie": "intermedio",
    "intermedierai": "intermediare",
    "intermedieran": "intermediare",
    "intermedieranno": "intermediare",
    "intermedierebbe": "intermediare",
    "intermedierebber": "intermediare",
    "intermedierebbero": "intermediare",
    "intermedierei": "intermediare",
    "intermedieremmo": "intermediare",
    "intermedieremo": "intermediare",
    "intermediereste": "intermediare",
    "intermedieresti": "intermediare",
    "intermedierete": "intermediare",
    "intermedierà": "intermediare",
    "intermedierò": "intermediare",
    "intermedin": "intermediare",
    "intermedino": "intermediare",
    "intermedio": "intermediare",
    "intermediò": "intermediare",
    "intermezzi": "intermezzo",
    "interminabili": "interminabile",
    "interministeriali": "interministeriale",
    "intermittenti": "intermittente",
    "intermittenze": "intermittenza",
    "intermodali": "intermodale",
    "interna": "interno",
    "internai": "internare",
    "internalizza": "internalizzare",
    "internalizzai": "internalizzare",
    "internalizzammo": "internalizzare",
    "internalizzan": "internalizzare",
    "internalizzando": "internalizzare",
    "internalizzano": "internalizzare",
    "internalizzante": "internalizzare",
    "internalizzanti": "internalizzare",
    "internalizzar": "internalizzare",
    "internalizzaron": "internalizzare",
    "internalizzarono": "internalizzare",
    "internalizzasse": "internalizzare",
    "internalizzasser": "internalizzare",
    "internalizzassero": "internalizzare",
    "internalizzassi": "internalizzare",
    "internalizzassimo": "internalizzare",
    "internalizzaste": "internalizzare",
    "internalizzasti": "internalizzare",
    "internalizzata": "internalizzare",
    "internalizzate": "internalizzare",
    "internalizzati": "internalizzare",
    "internalizzato": "internalizzare",
    "internalizzava": "internalizzare",
    "internalizzavamo": "internalizzare",
    "internalizzavan": "internalizzare",
    "internalizzavano": "internalizzare",
    "internalizzavate": "internalizzare",
    "internalizzavi": "internalizzare",
    "internalizzavo": "internalizzare",
    "internalizzerai": "internalizzare",
    "internalizzeran": "internalizzare",
    "internalizzeranno": "internalizzare",
    "internalizzerebbe": "internalizzare",
    "internalizzerebber": "internalizzare",
    "internalizzerebbero": "internalizzare",
    "internalizzerei": "internalizzare",
    "internalizzeremmo": "internalizzare",
    "internalizzeremo": "internalizzare",
    "internalizzereste": "internalizzare",
    "internalizzeresti": "internalizzare",
    "internalizzerete": "internalizzare",
    "internalizzerà": "internalizzare",
    "internalizzerò": "internalizzare",
    "internalizzi": "internalizzare",
    "internalizziamo": "internalizzare",
    "internalizziate": "internalizzare",
    "internalizzin": "internalizzare",
    "internalizzino": "internalizzare",
    "internalizzo": "internalizzare",
    "internalizzò": "internalizzare",
    "internamenti": "internamento",
    "internammo": "internare",
    "internan": "internare",
    "internando": "internare",
    "internano": "internare",
    "internante": "internare",
    "internanti": "internare",
    "internar": "internare",
    "internaron": "internare",
    "internarono": "internare",
    "internasse": "internare",
    "internasser": "internare",
    "internassero": "internare",
    "internassi": "internare",
    "internassimo": "internare",
    "internaste": "internare",
    "internasti": "internare",
    "internata": "internato",
    "internate": "internato",
    "internati": "internato",
    "internato": "internare",
    "internava": "internare",
    "internavamo": "internare",
    "internavan": "internare",
    "internavano": "internare",
    "internavate": "internare",
    "internavi": "internare",
    "internavo": "internare",
    "internazionali": "internazionale",
    "internazionalista": "internazionalisto",
    "internazionaliste": "internazionalisto",
    "internazionalisti": "internazionalisto",
    "internazionalizza": "internazionalizzare",
    "internazionalizzai": "internazionalizzare",
    "internazionalizzammo": "internazionalizzare",
    "internazionalizzan": "internazionalizzare",
    "internazionalizzando": "internazionalizzare",
    "internazionalizzano": "internazionalizzare",
    "internazionalizzante": "internazionalizzare",
    "internazionalizzanti": "internazionalizzare",
    "internazionalizzar": "internazionalizzare",
    "internazionalizzaron": "internazionalizzare",
    "internazionalizzarono": "internazionalizzare",
    "internazionalizzasse": "internazionalizzare",
    "internazionalizzasser": "internazionalizzare",
    "internazionalizzassero": "internazionalizzare",
    "internazionalizzassi": "internazionalizzare",
    "internazionalizzassimo": "internazionalizzare",
    "internazionalizzaste": "internazionalizzare",
    "internazionalizzasti": "internazionalizzare",
    "internazionalizzata": "internazionalizzare",
    "internazionalizzate": "internazionalizzare",
    "internazionalizzati": "internazionalizzare",
    "internazionalizzato": "internazionalizzare",
    "internazionalizzava": "internazionalizzare",
    "internazionalizzavamo": "internazionalizzare",
    "internazionalizzavan": "internazionalizzare",
    "internazionalizzavano": "internazionalizzare",
    "internazionalizzavate": "internazionalizzare",
    "internazionalizzavi": "internazionalizzare",
    "internazionalizzavo": "internazionalizzare",
    "internazionalizzazioni": "internazionalizzazione",
    "internazionalizzerai": "internazionalizzare",
    "internazionalizzeran": "internazionalizzare",
    "internazionalizzeranno": "internazionalizzare",
    "internazionalizzerebbe": "internazionalizzare",
    "internazionalizzerebber": "internazionalizzare",
    "internazionalizzerebbero": "internazionalizzare",
    "internazionalizzerei": "internazionalizzare",
    "internazionalizzeremmo": "internazionalizzare",
    "internazionalizzeremo": "internazionalizzare",
    "internazionalizzereste": "internazionalizzare",
    "internazionalizzeresti": "internazionalizzare",
    "internazionalizzerete": "internazionalizzare",
    "internazionalizzerà": "internazionalizzare",
    "internazionalizzerò": "internazionalizzare",
    "internazionalizzi": "internazionalizzare",
    "internazionalizziamo": "internazionalizzare",
    "internazionalizziate": "internazionalizzare",
    "internazionalizzin": "internazionalizzare",
    "internazionalizzino": "internazionalizzare",
    "internazionalizzo": "internazionalizzare",
    "internazionalizzò": "internazionalizzare",
    "interne": "interno",
    "internerai": "internare",
    "interneran": "internare",
    "interneranno": "internare",
    "internerebbe": "internare",
    "internerebber": "internare",
    "internerebbero": "internare",
    "internerei": "internare",
    "interneremmo": "internare",
    "interneremo": "internare",
    "internereste": "internare",
    "interneresti": "internare",
    "internerete": "internare",
    "internerà": "internare",
    "internerò": "internare",
    "interni": "interno",
    "interniamo": "internare",
    "interniate": "internare",
    "internin": "internare",
    "internino": "internare",
    "interno": "internare",
    "internò": "internare",
    "interparlamentari": "interparlamentare",
    "interpella": "interpellare",
    "interpellai": "interpellare",
    "interpellammo": "interpellare",
    "interpellan": "interpellare",
    "interpellando": "interpellare",
    "interpellano": "interpellare",
    "interpellante": "interpellare",
    "interpellanti": "interpellare",
    "interpellanze": "interpellanza",
    "interpellar": "interpellare",
    "interpellaron": "interpellare",
    "interpellarono": "interpellare",
    "interpellasse": "interpellare",
    "interpellasser": "interpellare",
    "interpellassero": "interpellare",
    "interpellassi": "interpellare",
    "interpellassimo": "interpellare",
    "interpellaste": "interpellare",
    "interpellasti": "interpellare",
    "interpellata": "interpellare",
    "interpellate": "interpellare",
    "interpellati": "interpellato",
    "interpellato": "interpellare",
    "interpellava": "interpellare",
    "interpellavamo": "interpellare",
    "interpellavan": "interpellare",
    "interpellavano": "interpellare",
    "interpellavate": "interpellare",
    "interpellavi": "interpellare",
    "interpellavo": "interpellare",
    "interpellerai": "interpellare",
    "interpelleran": "interpellare",
    "interpelleranno": "interpellare",
    "interpellerebbe": "interpellare",
    "interpellerebber": "interpellare",
    "interpellerebbero": "interpellare",
    "interpellerei": "interpellare",
    "interpelleremmo": "interpellare",
    "interpelleremo": "interpellare",
    "interpellereste": "interpellare",
    "interpelleresti": "interpellare",
    "interpellerete": "interpellare",
    "interpellerà": "interpellare",
    "interpellerò": "interpellare",
    "interpelli": "interpellare",
    "interpelliamo": "interpellare",
    "interpelliate": "interpellare",
    "interpellin": "interpellare",
    "interpellino": "interpellare",
    "interpello": "interpellare",
    "interpellò": "interpellare",
    "interpersonali": "interpersonale",
    "interpetrazioni": "interpetrazione",
    "interplanetari": "interplanetario",
    "interplanetaria": "interplanetario",
    "interplanetarie": "interplanetario",
    "interpola": "interpolare",
    "interpolai": "interpolare",
    "interpolammo": "interpolare",
    "interpolan": "interpolare",
    "interpolando": "interpolare",
    "interpolano": "interpolare",
    "interpolante": "interpolare",
    "interpolanti": "interpolare",
    "interpolar": "interpolare",
    "interpolaron": "interpolare",
    "interpolarono": "interpolare",
    "interpolasse": "interpolare",
    "interpolasser": "interpolare",
    "interpolassero": "interpolare",
    "interpolassi": "interpolare",
    "interpolassimo": "interpolare",
    "interpolaste": "interpolare",
    "interpolasti": "interpolare",
    "interpolata": "interpolare",
    "interpolate": "interpolare",
    "interpolati": "interpolare",
    "interpolato": "interpolare",
    "interpolava": "interpolare",
    "interpolavamo": "interpolare",
    "interpolavan": "interpolare",
    "interpolavano": "interpolare",
    "interpolavate": "interpolare",
    "interpolavi": "interpolare",
    "interpolavo": "interpolare",
    "interpolazioni": "interpolazione",
    "interpolerai": "interpolare",
    "interpoleran": "interpolare",
    "interpoleranno": "interpolare",
    "interpolerebbe": "interpolare",
    "interpolerebber": "interpolare",
    "interpolerebbero": "interpolare",
    "interpolerei": "interpolare",
    "interpoleremmo": "interpolare",
    "interpoleremo": "interpolare",
    "interpolereste": "interpolare",
    "interpoleresti": "interpolare",
    "interpolerete": "interpolare",
    "interpolerà": "interpolare",
    "interpolerò": "interpolare",
    "interpoli": "interpolare",
    "interpoliamo": "interpolare",
    "interpoliate": "interpolare",
    "interpolin": "interpolare",
    "interpolino": "interpolare",
    "interpolo": "interpolare",
    "interpolò": "interpolare",
    "interpone": "interporre",
    "interponemmo": "interporre",
    "interponendo": "interporre",
    "interponente": "interporre",
    "interponenti": "interporre",
    "interponesse": "interporre",
    "interponesser": "interporre",
    "interponessero": "interporre",
    "interponessi": "interporre",
    "interponessimo": "interporre",
    "interponeste": "interporre",
    "interponesti": "interporre",
    "interponete": "interporre",
    "interponeva": "interporre",
    "interponevamo": "interporre",
    "interponevan": "interporre",
    "interponevano": "interporre",
    "interponevate": "interporre",
    "interponevi": "interporre",
    "interponevo": "interporre",
    "interponga": "interporre",
    "interpongan": "interporre",
    "interpongano": "interporre",
    "interpongo": "interporre",
    "interpongon": "interporre",
    "interpongono": "interporre",
    "interponi": "interporre",
    "interponiamo": "interporre",
    "interponiate": "interporre",
    "interporr": "interporre",
    "interporrai": "interporre",
    "interporran": "interporre",
    "interporranno": "interporre",
    "interporrebbe": "interporre",
    "interporrebber": "interporre",
    "interporrebbero": "interporre",
    "interporrei": "interporre",
    "interporremmo": "interporre",
    "interporremo": "interporre",
    "interporreste": "interporre",
    "interporresti": "interporre",
    "interporrete": "interporre",
    "interporrà": "interporre",
    "interporrò": "interporre",
    "interporti": "interporto",
    "interpose": "interporre",
    "interposer": "interporre",
    "interposero": "interporre",
    "interposi": "interporre",
    "interposta": "interporre",
    "interposte": "interporre",
    "interposti": "interporre",
    "interposto": "interporre",
    "interpreta": "interpretare",
    "interpretabili": "interpretabile",
    "interpretai": "interpretare",
    "interpretammo": "interpretare",
    "interpretan": "interpretare",
    "interpretando": "interpretare",
    "interpretano": "interpretare",
    "interpretante": "interpretare",
    "interpretanti": "interpretare",
    "interpretar": "interpretare",
    "interpretaron": "interpretare",
    "interpretarono": "interpretare",
    "interpretasse": "interpretare",
    "interpretasser": "interpretare",
    "interpretassero": "interpretare",
    "interpretassi": "interpretare",
    "interpretassimo": "interpretare",
    "interpretaste": "interpretare",
    "interpretasti": "interpretare",
    "interpretata": "interpretare",
    "interpretate": "interpretare",
    "interpretati": "interpretare",
    "interpretativa": "interpretativo",
    "interpretative": "interpretativo",
    "interpretativi": "interpretativo",
    "interpretato": "interpretare",
    "interpretava": "interpretare",
    "interpretavamo": "interpretare",
    "interpretavan": "interpretare",
    "interpretavano": "interpretare",
    "interpretavate": "interpretare",
    "interpretavi": "interpretare",
    "interpretavo": "interpretare",
    "interpretazioni": "interpretazione",
    "interpreterai": "interpretare",
    "interpreteran": "interpretare",
    "interpreteranno": "interpretare",
    "interpreterebbe": "interpretare",
    "interpreterebber": "interpretare",
    "interpreterebbero": "interpretare",
    "interpreterei": "interpretare",
    "interpreteremmo": "interpretare",
    "interpreteremo": "interpretare",
    "interpretereste": "interpretare",
    "interpreteresti": "interpretare",
    "interpreterete": "interpretare",
    "interpreterà": "interpretare",
    "interpreterò": "interpretare",
    "interpreti": "interprete",
    "interpretiamo": "interpretare",
    "interpretiate": "interpretare",
    "interpretin": "interpretare",
    "interpretino": "interpretare",
    "interpreto": "interpretare",
    "interpretò": "interpretare",
    "interprovinciali": "interprovinciale",
    "interra": "interrare",
    "interrai": "interrare",
    "interrammo": "interrare",
    "interran": "interrare",
    "interrando": "interrare",
    "interrano": "interrare",
    "interrante": "interrare",
    "interranti": "interrare",
    "interrar": "interrare",
    "interraron": "interrare",
    "interrarono": "interrare",
    "interrasse": "interrare",
    "interrasser": "interrare",
    "interrassero": "interrare",
    "interrassi": "interrare",
    "interrassimo": "interrare",
    "interraste": "interrare",
    "interrasti": "interrare",
    "interrata": "interrare",
    "interrate": "interrare",
    "interrati": "interrare",
    "interrato": "interrare",
    "interrava": "interrare",
    "interravamo": "interrare",
    "interravan": "interrare",
    "interravano": "interrare",
    "interravate": "interrare",
    "interravi": "interrare",
    "interravo": "interrare",
    "interregionali": "interregionale",
    "interregni": "interregno",
    "interrelata": "interrelato",
    "interrelate": "interrelato",
    "interrelati": "interrelato",
    "interrelazioni": "interrelazione",
    "interreligiosa": "interreligioso",
    "interreligiose": "interreligioso",
    "interreligiosi": "interreligioso",
    "interrerai": "interrare",
    "interreran": "interrare",
    "interreranno": "interrare",
    "interrerebbe": "interrare",
    "interrerebber": "interrare",
    "interrerebbero": "interrare",
    "interrerei": "interrare",
    "interreremmo": "interrare",
    "interreremo": "interrare",
    "interrereste": "interrare",
    "interreresti": "interrare",
    "interrerete": "interrare",
    "interrerà": "interrare",
    "interrerò": "interrare",
    "interri": "interrare",
    "interriamo": "interrare",
    "interriate": "interrare",
    "interrin": "interrare",
    "interrino": "interrare",
    "interro": "interrare",
    "interroga": "interrogare",
    "interrogai": "interrogare",
    "interrogammo": "interrogare",
    "interrogan": "interrogare",
    "interrogando": "interrogare",
    "interrogano": "interrogare",
    "interrogante": "interrogare",
    "interroganti": "interrogare",
    "interrogar": "interrogare",
    "interrogaron": "interrogare",
    "interrogarono": "interrogare",
    "interrogasse": "interrogare",
    "interrogasser": "interrogare",
    "interrogassero": "interrogare",
    "interrogassi": "interrogare",
    "interrogassimo": "interrogare",
    "interrogaste": "interrogare",
    "interrogasti": "interrogare",
    "interrogata": "interrogato",
    "interrogate": "interrogato",
    "interrogati": "interrogato",
    "interrogativa": "interrogativo",
    "interrogative": "interrogativo",
    "interrogativi": "interrogativo",
    "interrogato": "interrogare",
    "interrogatori": "interrogatorio",
    "interrogatoria": "interrogatorio",
    "interrogatorie": "interrogatorio",
    "interrogatrice": "interrogatore",
    "interrogatrici": "interrogatore",
    "interrogava": "interrogare",
    "interrogavamo": "interrogare",
    "interrogavan": "interrogare",
    "interrogavano": "interrogare",
    "interrogavate": "interrogare",
    "interrogavi": "interrogare",
    "interrogavo": "interrogare",
    "interrogazioni": "interrogazione",
    "interrogherai": "interrogare",
    "interrogheran": "interrogare",
    "interrogheranno": "interrogare",
    "interrogherebbe": "interrogare",
    "interrogherebber": "interrogare",
    "interrogherebbero": "interrogare",
    "interrogherei": "interrogare",
    "interrogheremmo": "interrogare",
    "interrogheremo": "interrogare",
    "interroghereste": "interrogare",
    "interrogheresti": "interrogare",
    "interrogherete": "interrogare",
    "interrogherà": "interrogare",
    "interrogherò": "interrogare",
    "interroghi": "interrogare",
    "interroghiamo": "interrogare",
    "interroghiate": "interrogare",
    "interroghin": "interrogare",
    "interroghino": "interrogare",
    "interrogo": "interrogare",
    "interrogò": "interrogare",
    "interrompa": "interrompere",
    "interrompan": "interrompere",
    "interrompano": "interrompere",
    "interrompe": "interrompere",
    "interrompemmo": "interrompere",
    "interrompendo": "interrompere",
    "interrompente": "interrompere",
    "interrompenti": "interrompere",
    "interromper": "interrompere",
    "interromperai": "interrompere",
    "interromperan": "interrompere",
    "interromperanno": "interrompere",
    "interromperebbe": "interrompere",
    "interromperebber": "interrompere",
    "interromperebbero": "interrompere",
    "interromperei": "interrompere",
    "interromperemmo": "interrompere",
    "interromperemo": "interrompere",
    "interrompereste": "interrompere",
    "interromperesti": "interrompere",
    "interromperete": "interrompere",
    "interromperà": "interrompere",
    "interromperò": "interrompere",
    "interrompesse": "interrompere",
    "interrompesser": "interrompere",
    "interrompessero": "interrompere",
    "interrompessi": "interrompere",
    "interrompessimo": "interrompere",
    "interrompeste": "interrompere",
    "interrompesti": "interrompere",
    "interrompete": "interrompere",
    "interrompeva": "interrompere",
    "interrompevamo": "interrompere",
    "interrompevan": "interrompere",
    "interrompevano": "interrompere",
    "interrompevate": "interrompere",
    "interrompevi": "interrompere",
    "interrompevo": "interrompere",
    "interrompi": "interrompere",
    "interrompiamo": "interrompere",
    "interrompiate": "interrompere",
    "interrompo": "interrompere",
    "interrompon": "interrompere",
    "interrompono": "interrompere",
    "interrotta": "interrompere",
    "interrotte": "interrompere",
    "interrotti": "interrompere",
    "interrotto": "interrompere",
    "interruppe": "interrompere",
    "interrupper": "interrompere",
    "interruppero": "interrompere",
    "interruppi": "interrompere",
    "interruttori": "interruttore",
    "interruzioni": "interruzione",
    "interrò": "interrare",
    "interscambi": "interscambio",
    "interseca": "intersecare",
    "intersecai": "intersecare",
    "intersecammo": "intersecare",
    "intersecan": "intersecare",
    "intersecando": "intersecare",
    "intersecano": "intersecare",
    "intersecante": "intersecare",
    "intersecanti": "intersecare",
    "intersecar": "intersecare",
    "intersecaron": "intersecare",
    "intersecarono": "intersecare",
    "intersecasse": "intersecare",
    "intersecasser": "intersecare",
    "intersecassero": "intersecare",
    "intersecassi": "intersecare",
    "intersecassimo": "intersecare",
    "intersecaste": "intersecare",
    "intersecasti": "intersecare",
    "intersecata": "intersecare",
    "intersecate": "intersecare",
    "intersecati": "intersecare",
    "intersecato": "intersecare",
    "intersecava": "intersecare",
    "intersecavamo": "intersecare",
    "intersecavan": "intersecare",
    "intersecavano": "intersecare",
    "intersecavate": "intersecare",
    "intersecavi": "intersecare",
    "intersecavo": "intersecare",
    "intersecherai": "intersecare",
    "intersecheran": "intersecare",
    "intersecheranno": "intersecare",
    "intersecherebbe": "intersecare",
    "intersecherebber": "intersecare",
    "intersecherebbero": "intersecare",
    "intersecherei": "intersecare",
    "intersecheremmo": "intersecare",
    "intersecheremo": "intersecare",
    "intersechereste": "intersecare",
    "intersecheresti": "intersecare",
    "intersecherete": "intersecare",
    "intersecherà": "intersecare",
    "intersecherò": "intersecare",
    "intersechi": "intersecare",
    "intersechiamo": "intersecare",
    "intersechiate": "intersecare",
    "intersechin": "intersecare",
    "intersechino": "intersecare",
    "interseco": "intersecare",
    "intersecò": "intersecare",
    "intersezioni": "intersezione",
    "interstella": "interstellare",
    "interstellai": "interstellare",
    "interstellammo": "interstellare",
    "interstellan": "interstellare",
    "interstellando": "interstellare",
    "interstellano": "interstellare",
    "interstellante": "interstellare",
    "interstellanti": "interstellare",
    "interstellar": "interstellare",
    "interstellari": "interstellare",
    "interstellaron": "interstellare",
    "interstellarono": "interstellare",
    "interstellasse": "interstellare",
    "interstellasser": "interstellare",
    "interstellassero": "interstellare",
    "interstellassi": "interstellare",
    "interstellassimo": "interstellare",
    "interstellaste": "interstellare",
    "interstellasti": "interstellare",
    "interstellata": "interstellare",
    "interstellate": "interstellare",
    "interstellati": "interstellare",
    "interstellato": "interstellare",
    "interstellava": "interstellare",
    "interstellavamo": "interstellare",
    "interstellavan": "interstellare",
    "interstellavano": "interstellare",
    "interstellavate": "interstellare",
    "interstellavi": "interstellare",
    "interstellavo": "interstellare",
    "interstellerai": "interstellare",
    "interstelleran": "interstellare",
    "interstelleranno": "interstellare",
    "interstellerebbe": "interstellare",
    "interstellerebber": "interstellare",
    "interstellerebbero": "interstellare",
    "interstellerei": "interstellare",
    "interstelleremmo": "interstellare",
    "interstelleremo": "interstellare",
    "interstellereste": "interstellare",
    "interstelleresti": "interstellare",
    "interstellerete": "interstellare",
    "interstellerà": "interstellare",
    "interstellerò": "interstellare",
    "interstelli": "interstellare",
    "interstelliamo": "interstellare",
    "interstelliate": "interstellare",
    "interstellin": "interstellare",
    "interstellino": "interstellare",
    "interstello": "interstellare",
    "interstellò": "interstellare",
    "interstizi": "interstizio",
    "interurbana": "interurbano",
    "interurbane": "interurbano",
    "interurbani": "interurbano",
    "intervalla": "intervallare",
    "intervallai": "intervallare",
    "intervallammo": "intervallare",
    "intervallan": "intervallare",
    "intervallando": "intervallare",
    "intervallano": "intervallare",
    "intervallante": "intervallare",
    "intervallanti": "intervallare",
    "intervallar": "intervallare",
    "intervallaron": "intervallare",
    "intervallarono": "intervallare",
    "intervallasse": "intervallare",
    "intervallasser": "intervallare",
    "intervallassero": "intervallare",
    "intervallassi": "intervallare",
    "intervallassimo": "intervallare",
    "intervallaste": "intervallare",
    "intervallasti": "intervallare",
    "intervallata": "intervallare",
    "intervallate": "intervallare",
    "intervallati": "intervallare",
    "intervallato": "intervallare",
    "intervallava": "intervallare",
    "intervallavamo": "intervallare",
    "intervallavan": "intervallare",
    "intervallavano": "intervallare",
    "intervallavate": "intervallare",
    "intervallavi": "intervallare",
    "intervallavo": "intervallare",
    "intervallerai": "intervallare",
    "intervalleran": "intervallare",
    "intervalleranno": "intervallare",
    "intervallerebbe": "intervallare",
    "intervallerebber": "intervallare",
    "intervallerebbero": "intervallare",
    "intervallerei": "intervallare",
    "intervalleremmo": "intervallare",
    "intervalleremo": "intervallare",
    "intervallereste": "intervallare",
    "intervalleresti": "intervallare",
    "intervallerete": "intervallare",
    "intervallerà": "intervallare",
    "intervallerò": "intervallare",
    "intervalli": "intervallo",
    "intervalliamo": "intervallare",
    "intervalliate": "intervallare",
    "intervallin": "intervallare",
    "intervallino": "intervallare",
    "intervallo": "intervallare",
    "intervallò": "intervallare",
    "intervenendo": "intervenire",
    "intervenente": "intervenire",
    "intervenenti": "intervenire",
    "intervenga": "intervenire",
    "intervengan": "intervenire",
    "intervengano": "intervenire",
    "intervengo": "intervenire",
    "intervengon": "intervenire",
    "intervengono": "intervenire",
    "interveniamo": "intervenire",
    "interveniate": "intervenire",
    "intervenimmo": "intervenire",
    "intervenir": "intervenire",
    "intervenisse": "intervenire",
    "intervenisser": "intervenire",
    "intervenissero": "intervenire",
    "intervenissi": "intervenire",
    "intervenissimo": "intervenire",
    "interveniste": "intervenire",
    "intervenisti": "intervenire",
    "intervenite": "intervenire",
    "interveniva": "intervenire",
    "intervenivamo": "intervenire",
    "intervenivan": "intervenire",
    "intervenivano": "intervenire",
    "intervenivate": "intervenire",
    "intervenivi": "intervenire",
    "intervenivo": "intervenire",
    "intervenne": "intervenire",
    "intervenner": "intervenire",
    "intervennero": "intervenire",
    "intervenni": "intervenire",
    "interventi": "intervento",
    "interventismi": "interventismo",
    "interventiste": "interventista",
    "interventisti": "interventista",
    "intervenuta": "intervenuto",
    "intervenute": "intervenuto",
    "intervenuti": "intervenuto",
    "intervenuto": "intervenire",
    "interverrai": "intervenire",
    "interverran": "intervenire",
    "interverranno": "intervenire",
    "interverrebbe": "intervenire",
    "interverrebber": "intervenire",
    "interverrebbero": "intervenire",
    "interverrei": "intervenire",
    "interverremmo": "intervenire",
    "interverremo": "intervenire",
    "interverreste": "intervenire",
    "interverresti": "intervenire",
    "interverrete": "intervenire",
    "interverrà": "intervenire",
    "interverrò": "intervenire",
    "interviene": "intervenire",
    "intervieni": "intervenire",
    "intervista": "intervistare",
    "intervistai": "intervistare",
    "intervistammo": "intervistare",
    "intervistan": "intervistare",
    "intervistando": "intervistare",
    "intervistano": "intervistare",
    "intervistante": "intervistare",
    "intervistanti": "intervistare",
    "intervistar": "intervistare",
    "intervistaron": "intervistare",
    "intervistarono": "intervistare",
    "intervistasse": "intervistare",
    "intervistasser": "intervistare",
    "intervistassero": "intervistare",
    "intervistassi": "intervistare",
    "intervistassimo": "intervistare",
    "intervistaste": "intervistare",
    "intervistasti": "intervistare",
    "intervistata": "intervistato",
    "intervistate": "intervistato",
    "intervistati": "intervistato",
    "intervistato": "intervistare",
    "intervistatori": "intervistatore",
    "intervistatrici": "intervistatrice",
    "intervistava": "intervistare",
    "intervistavamo": "intervistare",
    "intervistavan": "intervistare",
    "intervistavano": "intervistare",
    "intervistavate": "intervistare",
    "intervistavi": "intervistare",
    "intervistavo": "intervistare",
    "interviste": "intervista",
    "intervisterai": "intervistare",
    "intervisteran": "intervistare",
    "intervisteranno": "intervistare",
    "intervisterebbe": "intervistare",
    "intervisterebber": "intervistare",
    "intervisterebbero": "intervistare",
    "intervisterei": "intervistare",
    "intervisteremmo": "intervistare",
    "intervisteremo": "intervistare",
    "intervistereste": "intervistare",
    "intervisteresti": "intervistare",
    "intervisterete": "intervistare",
    "intervisterà": "intervistare",
    "intervisterò": "intervistare",
    "intervisti": "intervistare",
    "intervistiamo": "intervistare",
    "intervistiate": "intervistare",
    "intervistin": "intervistare",
    "intervistino": "intervistare",
    "intervisto": "intervistare",
    "intervistò": "intervistare",
    "intesa": "inteso",
    "intese": "inteso",
    "inteser": "intendere",
    "intesero": "intendere",
    "intesi": "inteso",
    "inteso": "intendere",
    "intessa": "intessere",
    "intessan": "intessere",
    "intessano": "intessere",
    "intesse": "intessere",
    "intessei": "intessere",
    "intessemmo": "intessere",
    "intessendo": "intessere",
    "intessente": "intessere",
    "intessenti": "intessere",
    "intesser": "intessere",
    "intesserai": "intessere",
    "intesseran": "intessere",
    "intesseranno": "intessere",
    "intesserebbe": "intessere",
    "intesserebber": "intessere",
    "intesserebbero": "intessere",
    "intesserei": "intessere",
    "intesseremmo": "intessere",
    "intesseremo": "intessere",
    "intessereste": "intessere",
    "intesseresti": "intessere",
    "intesserete": "intessere",
    "intesseron": "intessere",
    "intesserono": "intessere",
    "intesserà": "intessere",
    "intesserò": "intessere",
    "intessesse": "intessere",
    "intessesser": "intessere",
    "intessessero": "intessere",
    "intessessi": "intessere",
    "intessessimo": "intessere",
    "intesseste": "intessere",
    "intessesti": "intessere",
    "intessete": "intessere",
    "intesseva": "intessere",
    "intessevamo": "intessere",
    "intessevan": "intessere",
    "intessevano": "intessere",
    "intessevate": "intessere",
    "intessevi": "intessere",
    "intessevo": "intessere",
    "intessi": "intessere",
    "intessiamo": "intessere",
    "intessiate": "intessere",
    "intesso": "intessere",
    "intesson": "intessere",
    "intessono": "intessere",
    "intessuta": "intessere",
    "intessute": "intessere",
    "intessuti": "intessere",
    "intessuto": "intessere",
    "intessè": "intessere",
    "intesta": "intestare",
    "intestai": "intestare",
    "intestammo": "intestare",
    "intestan": "intestare",
    "intestando": "intestare",
    "intestano": "intestare",
    "intestante": "intestare",
    "intestanti": "intestare",
    "intestar": "intestare",
    "intestardendo": "intestardire",
    "intestardiamo": "intestardire",
    "intestardiate": "intestardire",
    "intestardii": "intestardire",
    "intestardimmo": "intestardire",
    "intestardir": "intestardire",
    "intestardirai": "intestardire",
    "intestardiran": "intestardire",
    "intestardiranno": "intestardire",
    "intestardirebbe": "intestardire",
    "intestardirebber": "intestardire",
    "intestardirebbero": "intestardire",
    "intestardirei": "intestardire",
    "intestardiremmo": "intestardire",
    "intestardiremo": "intestardire",
    "intestardireste": "intestardire",
    "intestardiresti": "intestardire",
    "intestardirete": "intestardire",
    "intestardiron": "intestardire",
    "intestardirono": "intestardire",
    "intestardirà": "intestardire",
    "intestardirò": "intestardire",
    "intestardisca": "intestardire",
    "intestardiscan": "intestardire",
    "intestardiscano": "intestardire",
    "intestardisce": "intestardire",
    "intestardisci": "intestardire",
    "intestardisco": "intestardire",
    "intestardiscon": "intestardire",
    "intestardiscono": "intestardire",
    "intestardisse": "intestardire",
    "intestardisser": "intestardire",
    "intestardissero": "intestardire",
    "intestardissi": "intestardire",
    "intestardissimo": "intestardire",
    "intestardiste": "intestardire",
    "intestardisti": "intestardire",
    "intestardita": "intestardire",
    "intestardite": "intestardire",
    "intestarditi": "intestardire",
    "intestardito": "intestardire",
    "intestardiva": "intestardire",
    "intestardivamo": "intestardire",
    "intestardivan": "intestardire",
    "intestardivano": "intestardire",
    "intestardivate": "intestardire",
    "intestardivi": "intestardire",
    "intestardivo": "intestardire",
    "intestardì": "intestardire",
    "intestaron": "intestare",
    "intestarono": "intestare",
    "intestasse": "intestare",
    "intestasser": "intestare",
    "intestassero": "intestare",
    "intestassi": "intestare",
    "intestassimo": "intestare",
    "intestaste": "intestare",
    "intestasti": "intestare",
    "intestata": "intestato",
    "intestatari": "intestatario",
    "intestate": "intestato",
    "intestati": "intestato",
    "intestato": "intestare",
    "intestava": "intestare",
    "intestavamo": "intestare",
    "intestavan": "intestare",
    "intestavano": "intestare",
    "intestavate": "intestare",
    "intestavi": "intestare",
    "intestavo": "intestare",
    "intestazioni": "intestazione",
    "intesterai": "intestare",
    "intesteran": "intestare",
    "intesteranno": "intestare",
    "intesterebbe": "intestare",
    "intesterebber": "intestare",
    "intesterebbero": "intestare",
    "intesterei": "intestare",
    "intesteremmo": "intestare",
    "intesteremo": "intestare",
    "intestereste": "intestare",
    "intesteresti": "intestare",
    "intesterete": "intestare",
    "intesterà": "intestare",
    "intesterò": "intestare",
    "intesti": "intestare",
    "intestiamo": "intestare",
    "intestiate": "intestare",
    "intestin": "intestare",
    "intestina": "intestino",
    "intestinali": "intestinale",
    "intestine": "intestino",
    "intestini": "intestino",
    "intestino": "intestare",
    "intesto": "intestare",
    "intestò": "intestare",
    "intesè": "intendere",
    "inteventi": "intevento",
    "intezioni": "intezione",
    "intiepida": "intiepidire",
    "intiepidan": "intiepidire",
    "intiepidano": "intiepidire",
    "intiepide": "intiepidire",
    "intiepidendo": "intiepidire",
    "intiepidente": "intiepidire",
    "intiepidenti": "intiepidire",
    "intiepidi": "intiepidire",
    "intiepidiamo": "intiepidire",
    "intiepidiate": "intiepidire",
    "intiepidii": "intiepidire",
    "intiepidimmo": "intiepidire",
    "intiepidir": "intiepidire",
    "intiepidirai": "intiepidire",
    "intiepidiran": "intiepidire",
    "intiepidiranno": "intiepidire",
    "intiepidirebbe": "intiepidire",
    "intiepidirebber": "intiepidire",
    "intiepidirebbero": "intiepidire",
    "intiepidirei": "intiepidire",
    "intiepidiremmo": "intiepidire",
    "intiepidiremo": "intiepidire",
    "intiepidireste": "intiepidire",
    "intiepidiresti": "intiepidire",
    "intiepidirete": "intiepidire",
    "intiepidiron": "intiepidire",
    "intiepidirono": "intiepidire",
    "intiepidirà": "intiepidire",
    "intiepidirò": "intiepidire",
    "intiepidisse": "intiepidire",
    "intiepidisser": "intiepidire",
    "intiepidissero": "intiepidire",
    "intiepidissi": "intiepidire",
    "intiepidissimo": "intiepidire",
    "intiepidiste": "intiepidire",
    "intiepidisti": "intiepidire",
    "intiepidita": "intiepidire",
    "intiepidite": "intiepidire",
    "intiepiditi": "intiepidire",
    "intiepidito": "intiepidire",
    "intiepidiva": "intiepidire",
    "intiepidivamo": "intiepidire",
    "intiepidivan": "intiepidire",
    "intiepidivano": "intiepidire",
    "intiepidivate": "intiepidire",
    "intiepidivi": "intiepidire",
    "intiepidivo": "intiepidire",
    "intiepido": "intiepidire",
    "intiepidon": "intiepidire",
    "intiepidono": "intiepidire",
    "intiepidì": "intiepidire",
    "intiera": "intiero",
    "intiere": "intiero",
    "intieri": "intiero",
    "intifade": "intifada",
    "intima": "intimo",
    "intimai": "intimare",
    "intimammo": "intimare",
    "intiman": "intimare",
    "intimando": "intimare",
    "intimano": "intimare",
    "intimante": "intimare",
    "intimanti": "intimare",
    "intimar": "intimare",
    "intimaron": "intimare",
    "intimarono": "intimare",
    "intimasse": "intimare",
    "intimasser": "intimare",
    "intimassero": "intimare",
    "intimassi": "intimare",
    "intimassimo": "intimare",
    "intimaste": "intimare",
    "intimasti": "intimare",
    "intimata": "intimare",
    "intimate": "intimare",
    "intimati": "intimare",
    "intimato": "intimare",
    "intimava": "intimare",
    "intimavamo": "intimare",
    "intimavan": "intimare",
    "intimavano": "intimare",
    "intimavate": "intimare",
    "intimavi": "intimare",
    "intimavo": "intimare",
    "intimazioni": "intimazione",
    "intime": "intimo",
    "intimerai": "intimare",
    "intimeran": "intimare",
    "intimeranno": "intimare",
    "intimerebbe": "intimare",
    "intimerebber": "intimare",
    "intimerebbero": "intimare",
    "intimerei": "intimare",
    "intimeremmo": "intimare",
    "intimeremo": "intimare",
    "intimereste": "intimare",
    "intimeresti": "intimare",
    "intimerete": "intimare",
    "intimerà": "intimare",
    "intimerò": "intimare",
    "intimi": "intimo",
    "intimiamo": "intimare",
    "intimiate": "intimare",
    "intimidatori": "intimidatorio",
    "intimidatoria": "intimidatorio",
    "intimidatorie": "intimidatorio",
    "intimidazioni": "intimidazione",
    "intimidendo": "intimidire",
    "intimidente": "intimidire",
    "intimidenti": "intimidire",
    "intimidiamo": "intimidire",
    "intimidiate": "intimidire",
    "intimidii": "intimidire",
    "intimidimmo": "intimidire",
    "intimidir": "intimidire",
    "intimidirai": "intimidire",
    "intimidiran": "intimidire",
    "intimidiranno": "intimidire",
    "intimidirebbe": "intimidire",
    "intimidirebber": "intimidire",
    "intimidirebbero": "intimidire",
    "intimidirei": "intimidire",
    "intimidiremmo": "intimidire",
    "intimidiremo": "intimidire",
    "intimidireste": "intimidire",
    "intimidiresti": "intimidire",
    "intimidirete": "intimidire",
    "intimidiron": "intimidire",
    "intimidirono": "intimidire",
    "intimidirà": "intimidire",
    "intimidirò": "intimidire",
    "intimidisca": "intimidire",
    "intimidiscan": "intimidire",
    "intimidiscano": "intimidire",
    "intimidisce": "intimidire",
    "intimidisci": "intimidire",
    "intimidisco": "intimidire",
    "intimidiscon": "intimidire",
    "intimidiscono": "intimidire",
    "intimidisse": "intimidire",
    "intimidisser": "intimidire",
    "intimidissero": "intimidire",
    "intimidissi": "intimidire",
    "intimidissimo": "intimidire",
    "intimidiste": "intimidire",
    "intimidisti": "intimidire",
    "intimidita": "intimidire",
    "intimidite": "intimidire",
    "intimiditi": "intimidire",
    "intimidito": "intimidire",
    "intimidiva": "intimidire",
    "intimidivamo": "intimidire",
    "intimidivan": "intimidire",
    "intimidivano": "intimidire",
    "intimidivate": "intimidire",
    "intimidivi": "intimidire",
    "intimidivo": "intimidire",
    "intimidì": "intimidire",
    "intimin": "intimare",
    "intimino": "intimare",
    "intimismi": "intimismo",
    "intimiste": "intimista",
    "intimisti": "intimista",
    "intimistica": "intimistico",
    "intimistiche": "intimistico",
    "intimistici": "intimistico",
    "intimo": "intimare",
    "intimorendo": "intimorire",
    "intimorente": "intimorire",
    "intimorenti": "intimorire",
    "intimoriamo": "intimorire",
    "intimoriate": "intimorire",
    "intimorii": "intimorire",
    "intimorimmo": "intimorire",
    "intimorir": "intimorire",
    "intimorirai": "intimorire",
    "intimoriran": "intimorire",
    "intimoriranno": "intimorire",
    "intimorirebbe": "intimorire",
    "intimorirebber": "intimorire",
    "intimorirebbero": "intimorire",
    "intimorirei": "intimorire",
    "intimoriremmo": "intimorire",
    "intimoriremo": "intimorire",
    "intimorireste": "intimorire",
    "intimoriresti": "intimorire",
    "intimorirete": "intimorire",
    "intimoriron": "intimorire",
    "intimorirono": "intimorire",
    "intimorirà": "intimorire",
    "intimorirò": "intimorire",
    "intimorisca": "intimorire",
    "intimoriscan": "intimorire",
    "intimoriscano": "intimorire",
    "intimorisce": "intimorire",
    "intimorisci": "intimorire",
    "intimorisco": "intimorire",
    "intimoriscon": "intimorire",
    "intimoriscono": "intimorire",
    "intimorisse": "intimorire",
    "intimorisser": "intimorire",
    "intimorissero": "intimorire",
    "intimorissi": "intimorire",
    "intimorissimo": "intimorire",
    "intimoriste": "intimorire",
    "intimoristi": "intimorire",
    "intimorita": "intimorire",
    "intimorite": "intimorire",
    "intimoriti": "intimorire",
    "intimorito": "intimorire",
    "intimoriva": "intimorire",
    "intimorivamo": "intimorire",
    "intimorivan": "intimorire",
    "intimorivano": "intimorire",
    "intimorivate": "intimorire",
    "intimorivi": "intimorire",
    "intimorivo": "intimorire",
    "intimorì": "intimorire",
    "intimò": "intimare",
    "intinga": "intingere",
    "intingan": "intingere",
    "intingano": "intingere",
    "intinge": "intingere",
    "intingemmo": "intingere",
    "intingendo": "intingere",
    "intingente": "intingere",
    "intingenti": "intingere",
    "intinger": "intingere",
    "intingerai": "intingere",
    "intingeran": "intingere",
    "intingeranno": "intingere",
    "intingerebbe": "intingere",
    "intingerebber": "intingere",
    "intingerebbero": "intingere",
    "intingerei": "intingere",
    "intingeremmo": "intingere",
    "intingeremo": "intingere",
    "intingereste": "intingere",
    "intingeresti": "intingere",
    "intingerete": "intingere",
    "intingerà": "intingere",
    "intingerò": "intingere",
    "intingesse": "intingere",
    "intingesser": "intingere",
    "intingessero": "intingere",
    "intingessi": "intingere",
    "intingessimo": "intingere",
    "intingeste": "intingere",
    "intingesti": "intingere",
    "intingete": "intingere",
    "intingeva": "intingere",
    "intingevamo": "intingere",
    "intingevan": "intingere",
    "intingevano": "intingere",
    "intingevate": "intingere",
    "intingevi": "intingere",
    "intingevo": "intingere",
    "intingi": "intingere",
    "intingiamo": "intingere",
    "intingiate": "intingere",
    "intingo": "intingere",
    "intingon": "intingere",
    "intingono": "intingere",
    "intinse": "intingere",
    "intinser": "intingere",
    "intinsero": "intingere",
    "intinsi": "intingere",
    "intinta": "intingere",
    "intinte": "intingere",
    "intinti": "intingere",
    "intinto": "intingere",
    "intitola": "intitolare",
    "intitolai": "intitolare",
    "intitolammo": "intitolare",
    "intitolan": "intitolare",
    "intitolando": "intitolare",
    "intitolano": "intitolare",
    "intitolante": "intitolare",
    "intitolanti": "intitolare",
    "intitolar": "intitolare",
    "intitolaron": "intitolare",
    "intitolarono": "intitolare",
    "intitolasse": "intitolare",
    "intitolasser": "intitolare",
    "intitolassero": "intitolare",
    "intitolassi": "intitolare",
    "intitolassimo": "intitolare",
    "intitolaste": "intitolare",
    "intitolasti": "intitolare",
    "intitolata": "intitolare",
    "intitolate": "intitolare",
    "intitolati": "intitolare",
    "intitolato": "intitolare",
    "intitolava": "intitolare",
    "intitolavamo": "intitolare",
    "intitolavan": "intitolare",
    "intitolavano": "intitolare",
    "intitolavate": "intitolare",
    "intitolavi": "intitolare",
    "intitolavo": "intitolare",
    "intitolerai": "intitolare",
    "intitoleran": "intitolare",
    "intitoleranno": "intitolare",
    "intitolerebbe": "intitolare",
    "intitolerebber": "intitolare",
    "intitolerebbero": "intitolare",
    "intitolerei": "intitolare",
    "intitoleremmo": "intitolare",
    "intitoleremo": "intitolare",
    "intitolereste": "intitolare",
    "intitoleresti": "intitolare",
    "intitolerete": "intitolare",
    "intitolerà": "intitolare",
    "intitolerò": "intitolare",
    "intitoli": "intitolare",
    "intitoliamo": "intitolare",
    "intitoliate": "intitolare",
    "intitolin": "intitolare",
    "intitolino": "intitolare",
    "intitolo": "intitolare",
    "intitolò": "intitolare",
    "intoccabili": "intoccabile",
    "intollerabili": "intollerabile",
    "intolleranti": "intollerante",
    "intolleranze": "intolleranza",
    "intona": "intonare",
    "intonaca": "intonacare",
    "intonacai": "intonacare",
    "intonacammo": "intonacare",
    "intonacan": "intonacare",
    "intonacando": "intonacare",
    "intonacano": "intonacare",
    "intonacante": "intonacare",
    "intonacanti": "intonacare",
    "intonacar": "intonacare",
    "intonacaron": "intonacare",
    "intonacarono": "intonacare",
    "intonacasse": "intonacare",
    "intonacasser": "intonacare",
    "intonacassero": "intonacare",
    "intonacassi": "intonacare",
    "intonacassimo": "intonacare",
    "intonacaste": "intonacare",
    "intonacasti": "intonacare",
    "intonacata": "intonacare",
    "intonacate": "intonacare",
    "intonacati": "intonacare",
    "intonacato": "intonacare",
    "intonacava": "intonacare",
    "intonacavamo": "intonacare",
    "intonacavan": "intonacare",
    "intonacavano": "intonacare",
    "intonacavate": "intonacare",
    "intonacavi": "intonacare",
    "intonacavo": "intonacare",
    "intonacherai": "intonacare",
    "intonacheran": "intonacare",
    "intonacheranno": "intonacare",
    "intonacherebbe": "intonacare",
    "intonacherebber": "intonacare",
    "intonacherebbero": "intonacare",
    "intonacherei": "intonacare",
    "intonacheremmo": "intonacare",
    "intonacheremo": "intonacare",
    "intonachereste": "intonacare",
    "intonacheresti": "intonacare",
    "intonacherete": "intonacare",
    "intonacherà": "intonacare",
    "intonacherò": "intonacare",
    "intonachi": "intonacare",
    "intonachiamo": "intonacare",
    "intonachiate": "intonacare",
    "intonachin": "intonacare",
    "intonachino": "intonacare",
    "intonaci": "intonaco",
    "intonaco": "intonacare",
    "intonacò": "intonacare",
    "intonai": "intonare",
    "intonammo": "intonare",
    "intonan": "intonare",
    "intonando": "intonare",
    "intonano": "intonare",
    "intonante": "intonare",
    "intonanti": "intonare",
    "intonar": "intonare",
    "intonaron": "intonare",
    "intonarono": "intonare",
    "intonasse": "intonare",
    "intonasser": "intonare",
    "intonassero": "intonare",
    "intonassi": "intonare",
    "intonassimo": "intonare",
    "intonaste": "intonare",
    "intonasti": "intonare",
    "intonata": "intonare",
    "intonate": "intonare",
    "intonati": "intonare",
    "intonato": "intonare",
    "intonava": "intonare",
    "intonavamo": "intonare",
    "intonavan": "intonare",
    "intonavano": "intonare",
    "intonavate": "intonare",
    "intonavi": "intonare",
    "intonavo": "intonare",
    "intonazioni": "intonazione",
    "intonerai": "intonare",
    "intoneran": "intonare",
    "intoneranno": "intonare",
    "intonerebbe": "intonare",
    "intonerebber": "intonare",
    "intonerebbero": "intonare",
    "intonerei": "intonare",
    "intoneremmo": "intonare",
    "intoneremo": "intonare",
    "intonereste": "intonare",
    "intoneresti": "intonare",
    "intonerete": "intonare",
    "intonerà": "intonare",
    "intonerò": "intonare",
    "intoni": "intonare",
    "intoniamo": "intonare",
    "intoniate": "intonare",
    "intonin": "intonare",
    "intonino": "intonare",
    "intono": "intonare",
    "intonsa": "intonso",
    "intonse": "intonso",
    "intonsi": "intonso",
    "intontendo": "intontire",
    "intontente": "intontire",
    "intontenti": "intontire",
    "intontiamo": "intontire",
    "intontiate": "intontire",
    "intontii": "intontire",
    "intontimmo": "intontire",
    "intontir": "intontire",
    "intontirai": "intontire",
    "intontiran": "intontire",
    "intontiranno": "intontire",
    "intontirebbe": "intontire",
    "intontirebber": "intontire",
    "intontirebbero": "intontire",
    "intontirei": "intontire",
    "intontiremmo": "intontire",
    "intontiremo": "intontire",
    "intontireste": "intontire",
    "intontiresti": "intontire",
    "intontirete": "intontire",
    "intontiron": "intontire",
    "intontirono": "intontire",
    "intontirà": "intontire",
    "intontirò": "intontire",
    "intontisca": "intontire",
    "intontiscan": "intontire",
    "intontiscano": "intontire",
    "intontisce": "intontire",
    "intontisci": "intontire",
    "intontisco": "intontire",
    "intontiscon": "intontire",
    "intontiscono": "intontire",
    "intontisse": "intontire",
    "intontisser": "intontire",
    "intontissero": "intontire",
    "intontissi": "intontire",
    "intontissimo": "intontire",
    "intontiste": "intontire",
    "intontisti": "intontire",
    "intontita": "intontire",
    "intontite": "intontire",
    "intontiti": "intontire",
    "intontito": "intontire",
    "intontiva": "intontire",
    "intontivamo": "intontire",
    "intontivan": "intontire",
    "intontivano": "intontire",
    "intontivate": "intontire",
    "intontivi": "intontire",
    "intontivo": "intontire",
    "intontì": "intontire",
    "intonò": "intonare",
    "intoppa": "intoppare",
    "intoppai": "intoppare",
    "intoppammo": "intoppare",
    "intoppan": "intoppare",
    "intoppando": "intoppare",
    "intoppano": "intoppare",
    "intoppante": "intoppare",
    "intoppanti": "intoppare",
    "intoppar": "intoppare",
    "intopparon": "intoppare",
    "intopparono": "intoppare",
    "intoppasse": "intoppare",
    "intoppasser": "intoppare",
    "intoppassero": "intoppare",
    "intoppassi": "intoppare",
    "intoppassimo": "intoppare",
    "intoppaste": "intoppare",
    "intoppasti": "intoppare",
    "intoppata": "intoppare",
    "intoppate": "intoppare",
    "intoppati": "intoppare",
    "intoppato": "intoppare",
    "intoppava": "intoppare",
    "intoppavamo": "intoppare",
    "intoppavan": "intoppare",
    "intoppavano": "intoppare",
    "intoppavate": "intoppare",
    "intoppavi": "intoppare",
    "intoppavo": "intoppare",
    "intopperai": "intoppare",
    "intopperan": "intoppare",
    "intopperanno": "intoppare",
    "intopperebbe": "intoppare",
    "intopperebber": "intoppare",
    "intopperebbero": "intoppare",
    "intopperei": "intoppare",
    "intopperemmo": "intoppare",
    "intopperemo": "intoppare",
    "intoppereste": "intoppare",
    "intopperesti": "intoppare",
    "intopperete": "intoppare",
    "intopperà": "intoppare",
    "intopperò": "intoppare",
    "intoppi": "intoppo",
    "intoppiamo": "intoppare",
    "intoppiate": "intoppare",
    "intoppin": "intoppare",
    "intoppino": "intoppare",
    "intoppo": "intoppare",
    "intoppò": "intoppare",
    "intorbida": "intorbidare",
    "intorbidai": "intorbidare",
    "intorbidammo": "intorbidare",
    "intorbidan": "intorbidare",
    "intorbidando": "intorbidare",
    "intorbidano": "intorbidare",
    "intorbidante": "intorbidare",
    "intorbidanti": "intorbidare",
    "intorbidar": "intorbidare",
    "intorbidaron": "intorbidare",
    "intorbidarono": "intorbidare",
    "intorbidasse": "intorbidare",
    "intorbidasser": "intorbidare",
    "intorbidassero": "intorbidare",
    "intorbidassi": "intorbidare",
    "intorbidassimo": "intorbidare",
    "intorbidaste": "intorbidare",
    "intorbidasti": "intorbidare",
    "intorbidata": "intorbidare",
    "intorbidate": "intorbidare",
    "intorbidati": "intorbidare",
    "intorbidato": "intorbidare",
    "intorbidava": "intorbidare",
    "intorbidavamo": "intorbidare",
    "intorbidavan": "intorbidare",
    "intorbidavano": "intorbidare",
    "intorbidavate": "intorbidare",
    "intorbidavi": "intorbidare",
    "intorbidavo": "intorbidare",
    "intorbiderai": "intorbidare",
    "intorbideran": "intorbidare",
    "intorbideranno": "intorbidare",
    "intorbiderebbe": "intorbidare",
    "intorbiderebber": "intorbidare",
    "intorbiderebbero": "intorbidare",
    "intorbiderei": "intorbidare",
    "intorbideremmo": "intorbidare",
    "intorbideremo": "intorbidare",
    "intorbidereste": "intorbidare",
    "intorbideresti": "intorbidare",
    "intorbiderete": "intorbidare",
    "intorbiderà": "intorbidare",
    "intorbiderò": "intorbidare",
    "intorbidi": "intorbidare",
    "intorbidiamo": "intorbidare",
    "intorbidiate": "intorbidare",
    "intorbidin": "intorbidare",
    "intorbidino": "intorbidare",
    "intorbido": "intorbidare",
    "intorbidò": "intorbidare",
    "intorpida": "intorpidire",
    "intorpidan": "intorpidire",
    "intorpidano": "intorpidire",
    "intorpide": "intorpidire",
    "intorpidendo": "intorpidire",
    "intorpidente": "intorpidire",
    "intorpidenti": "intorpidire",
    "intorpidi": "intorpidire",
    "intorpidiamo": "intorpidire",
    "intorpidiate": "intorpidire",
    "intorpidii": "intorpidire",
    "intorpidimmo": "intorpidire",
    "intorpidir": "intorpidire",
    "intorpidirai": "intorpidire",
    "intorpidiran": "intorpidire",
    "intorpidiranno": "intorpidire",
    "intorpidirebbe": "intorpidire",
    "intorpidirebber": "intorpidire",
    "intorpidirebbero": "intorpidire",
    "intorpidirei": "intorpidire",
    "intorpidiremmo": "intorpidire",
    "intorpidiremo": "intorpidire",
    "intorpidireste": "intorpidire",
    "intorpidiresti": "intorpidire",
    "intorpidirete": "intorpidire",
    "intorpidiron": "intorpidire",
    "intorpidirono": "intorpidire",
    "intorpidirà": "intorpidire",
    "intorpidirò": "intorpidire",
    "intorpidisse": "intorpidire",
    "intorpidisser": "intorpidire",
    "intorpidissero": "intorpidire",
    "intorpidissi": "intorpidire",
    "intorpidissimo": "intorpidire",
    "intorpidiste": "intorpidire",
    "intorpidisti": "intorpidire",
    "intorpidita": "intorpidire",
    "intorpidite": "intorpidire",
    "intorpiditi": "intorpidire",
    "intorpidito": "intorpidire",
    "intorpidiva": "intorpidire",
    "intorpidivamo": "intorpidire",
    "intorpidivan": "intorpidire",
    "intorpidivano": "intorpidire",
    "intorpidivate": "intorpidire",
    "intorpidivi": "intorpidire",
    "intorpidivo": "intorpidire",
    "intorpido": "intorpidire",
    "intorpidon": "intorpidire",
    "intorpidono": "intorpidire",
    "intorpidì": "intorpidire",
    "intossica": "intossicare",
    "intossicai": "intossicare",
    "intossicammo": "intossicare",
    "intossican": "intossicare",
    "intossicando": "intossicare",
    "intossicano": "intossicare",
    "intossicante": "intossicare",
    "intossicanti": "intossicare",
    "intossicar": "intossicare",
    "intossicaron": "intossicare",
    "intossicarono": "intossicare",
    "intossicasse": "intossicare",
    "intossicasser": "intossicare",
    "intossicassero": "intossicare",
    "intossicassi": "intossicare",
    "intossicassimo": "intossicare",
    "intossicaste": "intossicare",
    "intossicasti": "intossicare",
    "intossicata": "intossicato",
    "intossicate": "intossicato",
    "intossicati": "intossicato",
    "intossicato": "intossicare",
    "intossicava": "intossicare",
    "intossicavamo": "intossicare",
    "intossicavan": "intossicare",
    "intossicavano": "intossicare",
    "intossicavate": "intossicare",
    "intossicavi": "intossicare",
    "intossicavo": "intossicare",
    "intossicazioni": "intossicazione",
    "intossicherai": "intossicare",
    "intossicheran": "intossicare",
    "intossicheranno": "intossicare",
    "intossicherebbe": "intossicare",
    "intossicherebber": "intossicare",
    "intossicherebbero": "intossicare",
    "intossicherei": "intossicare",
    "intossicheremmo": "intossicare",
    "intossicheremo": "intossicare",
    "intossichereste": "intossicare",
    "intossicheresti": "intossicare",
    "intossicherete": "intossicare",
    "intossicherà": "intossicare",
    "intossicherò": "intossicare",
    "intossichi": "intossicare",
    "intossichiamo": "intossicare",
    "intossichiate": "intossicare",
    "intossichin": "intossicare",
    "intossichino": "intossicare",
    "intossico": "intossicare",
    "intossicò": "intossicare",
    "intraducibili": "intraducibile",
    "intralcerai": "intralciare",
    "intralceran": "intralciare",
    "intralceranno": "intralciare",
    "intralcerebbe": "intralciare",
    "intralcerebber": "intralciare",
    "intralcerebbero": "intralciare",
    "intralcerei": "intralciare",
    "intralceremmo": "intralciare",
    "intralceremo": "intralciare",
    "intralcereste": "intralciare",
    "intralceresti": "intralciare",
    "intralcerete": "intralciare",
    "intralcerà": "intralciare",
    "intralcerò": "intralciare",
    "intralci": "intralcio",
    "intralcia": "intralciare",
    "intralciai": "intralciare",
    "intralciammo": "intralciare",
    "intralciamo": "intralciare",
    "intralcian": "intralciare",
    "intralciando": "intralciare",
    "intralciano": "intralciare",
    "intralciante": "intralciare",
    "intralcianti": "intralciare",
    "intralciar": "intralciare",
    "intralciaron": "intralciare",
    "intralciarono": "intralciare",
    "intralciasse": "intralciare",
    "intralciasser": "intralciare",
    "intralciassero": "intralciare",
    "intralciassi": "intralciare",
    "intralciassimo": "intralciare",
    "intralciaste": "intralciare",
    "intralciasti": "intralciare",
    "intralciata": "intralciare",
    "intralciate": "intralciare",
    "intralciati": "intralciare",
    "intralciato": "intralciare",
    "intralciava": "intralciare",
    "intralciavamo": "intralciare",
    "intralciavan": "intralciare",
    "intralciavano": "intralciare",
    "intralciavate": "intralciare",
    "intralciavi": "intralciare",
    "intralciavo": "intralciare",
    "intralcin": "intralciare",
    "intralcino": "intralciare",
    "intralcio": "intralciare",
    "intralciò": "intralciare",
    "intrallazza": "intrallazzare",
    "intrallazzai": "intrallazzare",
    "intrallazzammo": "intrallazzare",
    "intrallazzan": "intrallazzare",
    "intrallazzando": "intrallazzare",
    "intrallazzano": "intrallazzare",
    "intrallazzante": "intrallazzare",
    "intrallazzanti": "intrallazzare",
    "intrallazzar": "intrallazzare",
    "intrallazzaron": "intrallazzare",
    "intrallazzarono": "intrallazzare",
    "intrallazzasse": "intrallazzare",
    "intrallazzasser": "intrallazzare",
    "intrallazzassero": "intrallazzare",
    "intrallazzassi": "intrallazzare",
    "intrallazzassimo": "intrallazzare",
    "intrallazzaste": "intrallazzare",
    "intrallazzasti": "intrallazzare",
    "intrallazzata": "intrallazzare",
    "intrallazzate": "intrallazzare",
    "intrallazzati": "intrallazzare",
    "intrallazzato": "intrallazzare",
    "intrallazzatori": "intrallazzatore",
    "intrallazzava": "intrallazzare",
    "intrallazzavamo": "intrallazzare",
    "intrallazzavan": "intrallazzare",
    "intrallazzavano": "intrallazzare",
    "intrallazzavate": "intrallazzare",
    "intrallazzavi": "intrallazzare",
    "intrallazzavo": "intrallazzare",
    "intrallazzerai": "intrallazzare",
    "intrallazzeran": "intrallazzare",
    "intrallazzeranno": "intrallazzare",
    "intrallazzerebbe": "intrallazzare",
    "intrallazzerebber": "intrallazzare",
    "intrallazzerebbero": "intrallazzare",
    "intrallazzerei": "intrallazzare",
    "intrallazzeremmo": "intrallazzare",
    "intrallazzeremo": "intrallazzare",
    "intrallazzereste": "intrallazzare",
    "intrallazzeresti": "intrallazzare",
    "intrallazzerete": "intrallazzare",
    "intrallazzerà": "intrallazzare",
    "intrallazzerò": "intrallazzare",
    "intrallazzi": "intrallazzo",
    "intrallazziamo": "intrallazzare",
    "intrallazziate": "intrallazzare",
    "intrallazzin": "intrallazzare",
    "intrallazzino": "intrallazzare",
    "intrallazzo": "intrallazzare",
    "intrallazzò": "intrallazzare",
    "intramezza": "intramezzare",
    "intramezzai": "intramezzare",
    "intramezzammo": "intramezzare",
    "intramezzan": "intramezzare",
    "intramezzando": "intramezzare",
    "intramezzano": "intramezzare",
    "intramezzante": "intramezzare",
    "intramezzanti": "intramezzare",
    "intramezzar": "intramezzare",
    "intramezzaron": "intramezzare",
    "intramezzarono": "intramezzare",
    "intramezzasse": "intramezzare",
    "intramezzasser": "intramezzare",
    "intramezzassero": "intramezzare",
    "intramezzassi": "intramezzare",
    "intramezzassimo": "intramezzare",
    "intramezzaste": "intramezzare",
    "intramezzasti": "intramezzare",
    "intramezzata": "intramezzare",
    "intramezzate": "intramezzare",
    "intramezzati": "intramezzare",
    "intramezzato": "intramezzare",
    "intramezzava": "intramezzare",
    "intramezzavamo": "intramezzare",
    "intramezzavan": "intramezzare",
    "intramezzavano": "intramezzare",
    "intramezzavate": "intramezzare",
    "intramezzavi": "intramezzare",
    "intramezzavo": "intramezzare",
    "intramezzerai": "intramezzare",
    "intramezzeran": "intramezzare",
    "intramezzeranno": "intramezzare",
    "intramezzerebbe": "intramezzare",
    "intramezzerebber": "intramezzare",
    "intramezzerebbero": "intramezzare",
    "intramezzerei": "intramezzare",
    "intramezzeremmo": "intramezzare",
    "intramezzeremo": "intramezzare",
    "intramezzereste": "intramezzare",
    "intramezzeresti": "intramezzare",
    "intramezzerete": "intramezzare",
    "intramezzerà": "intramezzare",
    "intramezzerò": "intramezzare",
    "intramezzi": "intramezzare",
    "intramezziamo": "intramezzare",
    "intramezziate": "intramezzare",
    "intramezzin": "intramezzare",
    "intramezzino": "intramezzare",
    "intramezzo": "intramezzare",
    "intramezzò": "intramezzare",
    "intramontabili": "intramontabile",
    "intramuscolari": "intramuscolare",
    "intransigenti": "intransigente",
    "intransigenze": "intransigenza",
    "intransitabili": "intransitabile",
    "intrappola": "intrappolare",
    "intrappolai": "intrappolare",
    "intrappolammo": "intrappolare",
    "intrappolan": "intrappolare",
    "intrappolando": "intrappolare",
    "intrappolano": "intrappolare",
    "intrappolante": "intrappolare",
    "intrappolanti": "intrappolare",
    "intrappolar": "intrappolare",
    "intrappolaron": "intrappolare",
    "intrappolarono": "intrappolare",
    "intrappolasse": "intrappolare",
    "intrappolasser": "intrappolare",
    "intrappolassero": "intrappolare",
    "intrappolassi": "intrappolare",
    "intrappolassimo": "intrappolare",
    "intrappolaste": "intrappolare",
    "intrappolasti": "intrappolare",
    "intrappolata": "intrappolare",
    "intrappolate": "intrappolare",
    "intrappolati": "intrappolare",
    "intrappolato": "intrappolare",
    "intrappolava": "intrappolare",
    "intrappolavamo": "intrappolare",
    "intrappolavan": "intrappolare",
    "intrappolavano": "intrappolare",
    "intrappolavate": "intrappolare",
    "intrappolavi": "intrappolare",
    "intrappolavo": "intrappolare",
    "intrappolerai": "intrappolare",
    "intrappoleran": "intrappolare",
    "intrappoleranno": "intrappolare",
    "intrappolerebbe": "intrappolare",
    "intrappolerebber": "intrappolare",
    "intrappolerebbero": "intrappolare",
    "intrappolerei": "intrappolare",
    "intrappoleremmo": "intrappolare",
    "intrappoleremo": "intrappolare",
    "intrappolereste": "intrappolare",
    "intrappoleresti": "intrappolare",
    "intrappolerete": "intrappolare",
    "intrappolerà": "intrappolare",
    "intrappolerò": "intrappolare",
    "intrappoli": "intrappolare",
    "intrappoliamo": "intrappolare",
    "intrappoliate": "intrappolare",
    "intrappolin": "intrappolare",
    "intrappolino": "intrappolare",
    "intrappolo": "intrappolare",
    "intrappolò": "intrappolare",
    "intraprenda": "intraprendere",
    "intraprendan": "intraprendere",
    "intraprendano": "intraprendere",
    "intraprende": "intraprendere",
    "intraprendemmo": "intraprendere",
    "intraprendendo": "intraprendere",
    "intraprendente": "intraprendere",
    "intraprendenti": "intraprendere",
    "intraprendenze": "intraprendenza",
    "intraprender": "intraprendere",
    "intraprenderai": "intraprendere",
    "intraprenderan": "intraprendere",
    "intraprenderanno": "intraprendere",
    "intraprenderebbe": "intraprendere",
    "intraprenderebber": "intraprendere",
    "intraprenderebbero": "intraprendere",
    "intraprenderei": "intraprendere",
    "intraprenderemmo": "intraprendere",
    "intraprenderemo": "intraprendere",
    "intraprendereste": "intraprendere",
    "intraprenderesti": "intraprendere",
    "intraprenderete": "intraprendere",
    "intraprenderà": "intraprendere",
    "intraprenderò": "intraprendere",
    "intraprendesse": "intraprendere",
    "intraprendesser": "intraprendere",
    "intraprendessero": "intraprendere",
    "intraprendessi": "intraprendere",
    "intraprendessimo": "intraprendere",
    "intraprendeste": "intraprendere",
    "intraprendesti": "intraprendere",
    "intraprendete": "intraprendere",
    "intraprendeva": "intraprendere",
    "intraprendevamo": "intraprendere",
    "intraprendevan": "intraprendere",
    "intraprendevano": "intraprendere",
    "intraprendevate": "intraprendere",
    "intraprendevi": "intraprendere",
    "intraprendevo": "intraprendere",
    "intraprendi": "intraprendere",
    "intraprendiamo": "intraprendere",
    "intraprendiate": "intraprendere",
    "intraprendo": "intraprendere",
    "intraprendon": "intraprendere",
    "intraprendono": "intraprendere",
    "intrapresa": "intraprendere",
    "intraprese": "intraprendere",
    "intrapreser": "intraprendere",
    "intrapresero": "intraprendere",
    "intrapresi": "intraprendere",
    "intrapreso": "intraprendere",
    "intrapresè": "intraprendere",
    "intrasferibili": "intrasferibile",
    "intrattabili": "intrattabile",
    "intrattenemmo": "intrattenere",
    "intrattenendo": "intrattenere",
    "intrattenente": "intrattenere",
    "intrattenenti": "intrattenere",
    "intrattener": "intrattenere",
    "intrattenesse": "intrattenere",
    "intrattenesser": "intrattenere",
    "intrattenessero": "intrattenere",
    "intrattenessi": "intrattenere",
    "intrattenessimo": "intrattenere",
    "intratteneste": "intrattenere",
    "intrattenesti": "intrattenere",
    "intrattenete": "intrattenere",
    "intratteneva": "intrattenere",
    "intrattenevamo": "intrattenere",
    "intrattenevan": "intrattenere",
    "intrattenevano": "intrattenere",
    "intrattenevate": "intrattenere",
    "intrattenevi": "intrattenere",
    "intrattenevo": "intrattenere",
    "intrattenga": "intrattenere",
    "intrattengan": "intrattenere",
    "intrattengano": "intrattenere",
    "intrattengo": "intrattenere",
    "intrattengon": "intrattenere",
    "intrattengono": "intrattenere",
    "intratteniamo": "intrattenere",
    "intratteniate": "intrattenere",
    "intrattenimenti": "intrattenimento",
    "intrattenitori": "intrattenitore",
    "intrattenne": "intrattenere",
    "intrattenner": "intrattenere",
    "intrattennero": "intrattenere",
    "intrattenni": "intrattenere",
    "intrattenuta": "intrattenere",
    "intrattenute": "intrattenere",
    "intrattenuti": "intrattenere",
    "intrattenuto": "intrattenere",
    "intratterrai": "intrattenere",
    "intratterran": "intrattenere",
    "intratterranno": "intrattenere",
    "intratterrebbe": "intrattenere",
    "intratterrebber": "intrattenere",
    "intratterrebbero": "intrattenere",
    "intratterrei": "intrattenere",
    "intratterremmo": "intrattenere",
    "intratterremo": "intrattenere",
    "intratterreste": "intrattenere",
    "intratterresti": "intrattenere",
    "intratterrete": "intrattenere",
    "intratterrà": "intrattenere",
    "intratterrò": "intrattenere",
    "intrattiene": "intrattenere",
    "intrattieni": "intrattenere",
    "intraveda": "intravedere",
    "intravedan": "intravedere",
    "intravedano": "intravedere",
    "intravede": "intravedere",
    "intravedemmo": "intravedere",
    "intravedendo": "intravedere",
    "intravedente": "intravedere",
    "intravedenti": "intravedere",
    "intraveder": "intravedere",
    "intravedesse": "intravedere",
    "intravedesser": "intravedere",
    "intravedessero": "intravedere",
    "intravedessi": "intravedere",
    "intravedessimo": "intravedere",
    "intravedeste": "intravedere",
    "intravedesti": "intravedere",
    "intravedete": "intravedere",
    "intravedeva": "intravedere",
    "intravedevamo": "intravedere",
    "intravedevan": "intravedere",
    "intravedevano": "intravedere",
    "intravedevate": "intravedere",
    "intravedevi": "intravedere",
    "intravedevo": "intravedere",
    "intravedi": "intravedere",
    "intravediamo": "intravedere",
    "intravediate": "intravedere",
    "intravedo": "intravedere",
    "intravedon": "intravedere",
    "intravedono": "intravedere",
    "intravedrai": "intravedere",
    "intravedran": "intravedere",
    "intravedranno": "intravedere",
    "intravedrebbe": "intravedere",
    "intravedrebber": "intravedere",
    "intravedrebbero": "intravedere",
    "intravedrei": "intravedere",
    "intravedremmo": "intravedere",
    "intravedremo": "intravedere",
    "intravedreste": "intravedere",
    "intravedresti": "intravedere",
    "intravedrete": "intravedere",
    "intravedrà": "intravedere",
    "intravedrò": "intravedere",
    "intraveduta": "intravedere",
    "intravedute": "intravedere",
    "intraveduti": "intravedere",
    "intraveduto": "intravedere",
    "intravide": "intravedere",
    "intravider": "intravedere",
    "intravidero": "intravedere",
    "intravidi": "intravedere",
    "intravveda": "intravvedere",
    "intravvedan": "intravvedere",
    "intravvedano": "intravvedere",
    "intravvede": "intravvedere",
    "intravvedei": "intravvedere",
    "intravvedemmo": "intravvedere",
    "intravvedendo": "intravvedere",
    "intravvedente": "intravvedere",
    "intravvedenti": "intravvedere",
    "intravveder": "intravvedere",
    "intravvederai": "intravvedere",
    "intravvederan": "intravvedere",
    "intravvederanno": "intravvedere",
    "intravvederebbe": "intravvedere",
    "intravvederebber": "intravvedere",
    "intravvederebbero": "intravvedere",
    "intravvederei": "intravvedere",
    "intravvederemmo": "intravvedere",
    "intravvederemo": "intravvedere",
    "intravvedereste": "intravvedere",
    "intravvederesti": "intravvedere",
    "intravvederete": "intravvedere",
    "intravvederon": "intravvedere",
    "intravvederono": "intravvedere",
    "intravvederà": "intravvedere",
    "intravvederò": "intravvedere",
    "intravvedesse": "intravvedere",
    "intravvedesser": "intravvedere",
    "intravvedessero": "intravvedere",
    "intravvedessi": "intravvedere",
    "intravvedessimo": "intravvedere",
    "intravvedeste": "intravvedere",
    "intravvedesti": "intravvedere",
    "intravvedete": "intravvedere",
    "intravvedeva": "intravvedere",
    "intravvedevamo": "intravvedere",
    "intravvedevan": "intravvedere",
    "intravvedevano": "intravvedere",
    "intravvedevate": "intravvedere",
    "intravvedevi": "intravvedere",
    "intravvedevo": "intravvedere",
    "intravvedi": "intravvedere",
    "intravvediamo": "intravvedere",
    "intravvediate": "intravvedere",
    "intravvedo": "intravvedere",
    "intravvedon": "intravvedere",
    "intravvedono": "intravvedere",
    "intravveduta": "intravvedere",
    "intravvedute": "intravvedere",
    "intravveduti": "intravvedere",
    "intravveduto": "intravvedere",
    "intravvedè": "intravvedere",
    "intreccerai": "intrecciare",
    "intrecceran": "intrecciare",
    "intrecceranno": "intrecciare",
    "intreccerebbe": "intrecciare",
    "intreccerebber": "intrecciare",
    "intreccerebbero": "intrecciare",
    "intreccerei": "intrecciare",
    "intrecceremmo": "intrecciare",
    "intrecceremo": "intrecciare",
    "intreccereste": "intrecciare",
    "intrecceresti": "intrecciare",
    "intreccerete": "intrecciare",
    "intreccerà": "intrecciare",
    "intreccerò": "intrecciare",
    "intrecci": "intreccio",
    "intreccia": "intrecciare",
    "intrecciai": "intrecciare",
    "intrecciammo": "intrecciare",
    "intrecciamo": "intrecciare",
    "intreccian": "intrecciare",
    "intrecciando": "intrecciare",
    "intrecciano": "intrecciare",
    "intrecciante": "intrecciare",
    "intreccianti": "intrecciare",
    "intrecciar": "intrecciare",
    "intrecciaron": "intrecciare",
    "intrecciarono": "intrecciare",
    "intrecciasse": "intrecciare",
    "intrecciasser": "intrecciare",
    "intrecciassero": "intrecciare",
    "intrecciassi": "intrecciare",
    "intrecciassimo": "intrecciare",
    "intrecciaste": "intrecciare",
    "intrecciasti": "intrecciare",
    "intrecciata": "intrecciare",
    "intrecciate": "intrecciare",
    "intrecciati": "intrecciare",
    "intrecciato": "intrecciare",
    "intrecciava": "intrecciare",
    "intrecciavamo": "intrecciare",
    "intrecciavan": "intrecciare",
    "intrecciavano": "intrecciare",
    "intrecciavate": "intrecciare",
    "intrecciavi": "intrecciare",
    "intrecciavo": "intrecciare",
    "intreccin": "intrecciare",
    "intreccino": "intrecciare",
    "intreccio": "intrecciare",
    "intrecciò": "intrecciare",
    "intrepida": "intrepido",
    "intrepide": "intrepido",
    "intrepidi": "intrepido",
    "intrica": "intricare",
    "intricai": "intricare",
    "intricammo": "intricare",
    "intrican": "intricare",
    "intricando": "intricare",
    "intricano": "intricare",
    "intricante": "intricare",
    "intricanti": "intricare",
    "intricar": "intricare",
    "intricaron": "intricare",
    "intricarono": "intricare",
    "intricasse": "intricare",
    "intricasser": "intricare",
    "intricassero": "intricare",
    "intricassi": "intricare",
    "intricassimo": "intricare",
    "intricaste": "intricare",
    "intricasti": "intricare",
    "intricata": "intricato",
    "intricate": "intricato",
    "intricati": "intricato",
    "intricato": "intricare",
    "intricava": "intricare",
    "intricavamo": "intricare",
    "intricavan": "intricare",
    "intricavano": "intricare",
    "intricavate": "intricare",
    "intricavi": "intricare",
    "intricavo": "intricare",
    "intricherai": "intricare",
    "intricheran": "intricare",
    "intricheranno": "intricare",
    "intricherebbe": "intricare",
    "intricherebber": "intricare",
    "intricherebbero": "intricare",
    "intricherei": "intricare",
    "intricheremmo": "intricare",
    "intricheremo": "intricare",
    "intrichereste": "intricare",
    "intricheresti": "intricare",
    "intricherete": "intricare",
    "intricherà": "intricare",
    "intricherò": "intricare",
    "intrichi": "intrico",
    "intrichiamo": "intricare",
    "intrichiate": "intricare",
    "intrichin": "intricare",
    "intrichino": "intricare",
    "intrico": "intricare",
    "intricò": "intricare",
    "intrida": "intridere",
    "intridan": "intridere",
    "intridano": "intridere",
    "intride": "intridere",
    "intridei": "intridere",
    "intridemmo": "intridere",
    "intridendo": "intridere",
    "intridente": "intridere",
    "intridenti": "intridere",
    "intrider": "intridere",
    "intriderai": "intridere",
    "intrideran": "intridere",
    "intrideranno": "intridere",
    "intriderebbe": "intridere",
    "intriderebber": "intridere",
    "intriderebbero": "intridere",
    "intriderei": "intridere",
    "intrideremmo": "intridere",
    "intrideremo": "intridere",
    "intridereste": "intridere",
    "intrideresti": "intridere",
    "intriderete": "intridere",
    "intrideron": "intridere",
    "intriderono": "intridere",
    "intriderà": "intridere",
    "intriderò": "intridere",
    "intridesse": "intridere",
    "intridesser": "intridere",
    "intridessero": "intridere",
    "intridessi": "intridere",
    "intridessimo": "intridere",
    "intrideste": "intridere",
    "intridesti": "intridere",
    "intridete": "intridere",
    "intrideva": "intridere",
    "intridevamo": "intridere",
    "intridevan": "intridere",
    "intridevano": "intridere",
    "intridevate": "intridere",
    "intridevi": "intridere",
    "intridevo": "intridere",
    "intridi": "intridere",
    "intridiamo": "intridere",
    "intridiate": "intridere",
    "intrido": "intridere",
    "intridon": "intridere",
    "intridono": "intridere",
    "intriduta": "intridere",
    "intridute": "intridere",
    "intriduti": "intridere",
    "intriduto": "intridere",
    "intridè": "intridere",
    "intriga": "intrigare",
    "intrigai": "intrigare",
    "intrigammo": "intrigare",
    "intrigan": "intrigare",
    "intrigando": "intrigare",
    "intrigano": "intrigare",
    "intrigante": "intrigare",
    "intriganti": "intrigare",
    "intrigar": "intrigare",
    "intrigaron": "intrigare",
    "intrigarono": "intrigare",
    "intrigasse": "intrigare",
    "intrigasser": "intrigare",
    "intrigassero": "intrigare",
    "intrigassi": "intrigare",
    "intrigassimo": "intrigare",
    "intrigaste": "intrigare",
    "intrigasti": "intrigare",
    "intrigata": "intrigare",
    "intrigate": "intrigare",
    "intrigati": "intrigare",
    "intrigato": "intrigare",
    "intrigava": "intrigare",
    "intrigavamo": "intrigare",
    "intrigavan": "intrigare",
    "intrigavano": "intrigare",
    "intrigavate": "intrigare",
    "intrigavi": "intrigare",
    "intrigavo": "intrigare",
    "intrigherai": "intrigare",
    "intrigheran": "intrigare",
    "intrigheranno": "intrigare",
    "intrigherebbe": "intrigare",
    "intrigherebber": "intrigare",
    "intrigherebbero": "intrigare",
    "intrigherei": "intrigare",
    "intrigheremmo": "intrigare",
    "intrigheremo": "intrigare",
    "intrighereste": "intrigare",
    "intrigheresti": "intrigare",
    "intrigherete": "intrigare",
    "intrigherà": "intrigare",
    "intrigherò": "intrigare",
    "intrighi": "intrigo",
    "intrighiamo": "intrigare",
    "intrighiate": "intrigare",
    "intrighin": "intrigare",
    "intrighino": "intrigare",
    "intrigo": "intrigare",
    "intrigò": "intrigare",
    "intrinseca": "intrinseco",
    "intrinseche": "intrinseco",
    "intrinseci": "intrinseco",
    "intrisa": "intriso",
    "intrise": "intriso",
    "intrisi": "intriso",
    "intristendo": "intristire",
    "intristente": "intristire",
    "intristenti": "intristire",
    "intristiamo": "intristire",
    "intristiate": "intristire",
    "intristii": "intristire",
    "intristimmo": "intristire",
    "intristir": "intristire",
    "intristirai": "intristire",
    "intristiran": "intristire",
    "intristiranno": "intristire",
    "intristirebbe": "intristire",
    "intristirebber": "intristire",
    "intristirebbero": "intristire",
    "intristirei": "intristire",
    "intristiremmo": "intristire",
    "intristiremo": "intristire",
    "intristireste": "intristire",
    "intristiresti": "intristire",
    "intristirete": "intristire",
    "intristiron": "intristire",
    "intristirono": "intristire",
    "intristirà": "intristire",
    "intristirò": "intristire",
    "intristisca": "intristire",
    "intristiscan": "intristire",
    "intristiscano": "intristire",
    "intristisce": "intristire",
    "intristisci": "intristire",
    "intristisco": "intristire",
    "intristiscon": "intristire",
    "intristiscono": "intristire",
    "intristisse": "intristire",
    "intristisser": "intristire",
    "intristissero": "intristire",
    "intristissi": "intristire",
    "intristissimo": "intristire",
    "intrististe": "intristire",
    "intrististi": "intristire",
    "intristita": "intristire",
    "intristite": "intristire",
    "intristiti": "intristire",
    "intristito": "intristire",
    "intristiva": "intristire",
    "intristivamo": "intristire",
    "intristivan": "intristire",
    "intristivano": "intristire",
    "intristivate": "intristire",
    "intristivi": "intristire",
    "intristivo": "intristire",
    "intristì": "intristire",
    "introdotta": "introdurre",
    "introdotte": "introdurre",
    "introdotti": "introdurre",
    "introdotto": "introdurre",
    "introduca": "introdurre",
    "introducan": "introdurre",
    "introducano": "introdurre",
    "introduce": "introdurre",
    "introducemmo": "introdurre",
    "introducendo": "introdurre",
    "introducente": "introdurre",
    "introducenti": "introdurre",
    "introducesse": "introdurre",
    "introducesser": "introdurre",
    "introducessero": "introdurre",
    "introducessi": "introdurre",
    "introducessimo": "introdurre",
    "introduceste": "introdurre",
    "introducesti": "introdurre",
    "introducete": "introdurre",
    "introduceva": "introdurre",
    "introducevamo": "introdurre",
    "introducevan": "introdurre",
    "introducevano": "introdurre",
    "introducevate": "introdurre",
    "introducevi": "introdurre",
    "introducevo": "introdurre",
    "introduci": "introdurre",
    "introduciamo": "introdurre",
    "introduciate": "introdurre",
    "introducibili": "introducibile",
    "introduco": "introdurre",
    "introducon": "introdurre",
    "introducono": "introdurre",
    "introdurr": "introdurre",
    "introdurrai": "introdurre",
    "introdurran": "introdurre",
    "introdurranno": "introdurre",
    "introdurrebbe": "introdurre",
    "introdurrebber": "introdurre",
    "introdurrebbero": "introdurre",
    "introdurrei": "introdurre",
    "introdurremmo": "introdurre",
    "introdurremo": "introdurre",
    "introdurreste": "introdurre",
    "introdurresti": "introdurre",
    "introdurrete": "introdurre",
    "introdurrà": "introdurre",
    "introdurrò": "introdurre",
    "introdusse": "introdurre",
    "introdusser": "introdurre",
    "introdussero": "introdurre",
    "introdussi": "introdurre",
    "introduttiva": "introduttivo",
    "introduttive": "introduttivo",
    "introduttivi": "introduttivo",
    "introduzioni": "introduzione",
    "introita": "introitare",
    "introitai": "introitare",
    "introitammo": "introitare",
    "introitan": "introitare",
    "introitando": "introitare",
    "introitano": "introitare",
    "introitante": "introitare",
    "introitanti": "introitare",
    "introitar": "introitare",
    "introitaron": "introitare",
    "introitarono": "introitare",
    "introitasse": "introitare",
    "introitasser": "introitare",
    "introitassero": "introitare",
    "introitassi": "introitare",
    "introitassimo": "introitare",
    "introitaste": "introitare",
    "introitasti": "introitare",
    "introitata": "introitare",
    "introitate": "introitare",
    "introitati": "introitare",
    "introitato": "introitare",
    "introitava": "introitare",
    "introitavamo": "introitare",
    "introitavan": "introitare",
    "introitavano": "introitare",
    "introitavate": "introitare",
    "introitavi": "introitare",
    "introitavo": "introitare",
    "introiterai": "introitare",
    "introiteran": "introitare",
    "introiteranno": "introitare",
    "introiterebbe": "introitare",
    "introiterebber": "introitare",
    "introiterebbero": "introitare",
    "introiterei": "introitare",
    "introiteremmo": "introitare",
    "introiteremo": "introitare",
    "introitereste": "introitare",
    "introiteresti": "introitare",
    "introiterete": "introitare",
    "introiterà": "introitare",
    "introiterò": "introitare",
    "introiti": "introito",
    "introitiamo": "introitare",
    "introitiate": "introitare",
    "introitin": "introitare",
    "introitino": "introitare",
    "introito": "introitare",
    "introitò": "introitare",
    "intrometta": "intromettere",
    "intromettan": "intromettere",
    "intromettano": "intromettere",
    "intromette": "intromettere",
    "intromettei": "intromettere",
    "intromettemmo": "intromettere",
    "intromettendo": "intromettere",
    "intromettente": "intromettere",
    "intromettenti": "intromettere",
    "intrometter": "intromettere",
    "intrometterai": "intromettere",
    "intrometteran": "intromettere",
    "intrometteranno": "intromettere",
    "intrometterebbe": "intromettere",
    "intrometterebber": "intromettere",
    "intrometterebbero": "intromettere",
    "intrometterei": "intromettere",
    "intrometteremmo": "intromettere",
    "intrometteremo": "intromettere",
    "intromettereste": "intromettere",
    "intrometteresti": "intromettere",
    "intrometterete": "intromettere",
    "intrometteron": "intromettere",
    "intrometterono": "intromettere",
    "intrometterà": "intromettere",
    "intrometterò": "intromettere",
    "intromettesse": "intromettere",
    "intromettesser": "intromettere",
    "intromettessero": "intromettere",
    "intromettessi": "intromettere",
    "intromettessimo": "intromettere",
    "intrometteste": "intromettere",
    "intromettesti": "intromettere",
    "intromettete": "intromettere",
    "intrometteva": "intromettere",
    "intromettevamo": "intromettere",
    "intromettevan": "intromettere",
    "intromettevano": "intromettere",
    "intromettevate": "intromettere",
    "intromettevi": "intromettere",
    "intromettevo": "intromettere",
    "intrometti": "intromettere",
    "intromettiamo": "intromettere",
    "intromettiate": "intromettere",
    "intrometto": "intromettere",
    "intrometton": "intromettere",
    "intromettono": "intromettere",
    "intromettuta": "intromettere",
    "intromettute": "intromettere",
    "intromettuti": "intromettere",
    "intromettuto": "intromettere",
    "intromettè": "intromettere",
    "intromissioni": "intromissione",
    "introna": "intronare",
    "intronai": "intronare",
    "intronammo": "intronare",
    "intronan": "intronare",
    "intronando": "intronare",
    "intronano": "intronare",
    "intronante": "intronare",
    "intronanti": "intronare",
    "intronar": "intronare",
    "intronaron": "intronare",
    "intronarono": "intronare",
    "intronasse": "intronare",
    "intronasser": "intronare",
    "intronassero": "intronare",
    "intronassi": "intronare",
    "intronassimo": "intronare",
    "intronaste": "intronare",
    "intronasti": "intronare",
    "intronata": "intronare",
    "intronate": "intronare",
    "intronati": "intronare",
    "intronato": "intronare",
    "intronava": "intronare",
    "intronavamo": "intronare",
    "intronavan": "intronare",
    "intronavano": "intronare",
    "intronavate": "intronare",
    "intronavi": "intronare",
    "intronavo": "intronare",
    "intronerai": "intronare",
    "introneran": "intronare",
    "introneranno": "intronare",
    "intronerebbe": "intronare",
    "intronerebber": "intronare",
    "intronerebbero": "intronare",
    "intronerei": "intronare",
    "introneremmo": "intronare",
    "introneremo": "intronare",
    "intronereste": "intronare",
    "introneresti": "intronare",
    "intronerete": "intronare",
    "intronerà": "intronare",
    "intronerò": "intronare",
    "introni": "intronare",
    "introniamo": "intronare",
    "introniate": "intronare",
    "intronin": "intronare",
    "intronino": "intronare",
    "introno": "intronare",
    "intronò": "intronare",
    "introspettiva": "introspettivo",
    "introspettive": "introspettivo",
    "introspettivi": "introspettivo",
    "introspezioni": "introspezione",
    "introvabili": "introvabile",
    "introversa": "introverso",
    "introverse": "introverso",
    "introversi": "introverso",
    "introversioni": "introversione",
    "intruda": "intrudere",
    "intrudan": "intrudere",
    "intrudano": "intrudere",
    "intrude": "intrudere",
    "intrudei": "intrudere",
    "intrudemmo": "intrudere",
    "intrudendo": "intrudere",
    "intrudente": "intrudere",
    "intrudenti": "intrudere",
    "intruder": "intrudere",
    "intruderai": "intrudere",
    "intruderan": "intrudere",
    "intruderanno": "intrudere",
    "intruderebbe": "intrudere",
    "intruderebber": "intrudere",
    "intruderebbero": "intrudere",
    "intruderei": "intrudere",
    "intruderemmo": "intrudere",
    "intruderemo": "intrudere",
    "intrudereste": "intrudere",
    "intruderesti": "intrudere",
    "intruderete": "intrudere",
    "intruderon": "intrudere",
    "intruderono": "intrudere",
    "intruderà": "intrudere",
    "intruderò": "intrudere",
    "intrudesse": "intrudere",
    "intrudesser": "intrudere",
    "intrudessero": "intrudere",
    "intrudessi": "intrudere",
    "intrudessimo": "intrudere",
    "intrudeste": "intrudere",
    "intrudesti": "intrudere",
    "intrudete": "intrudere",
    "intrudeva": "intrudere",
    "intrudevamo": "intrudere",
    "intrudevan": "intrudere",
    "intrudevano": "intrudere",
    "intrudevate": "intrudere",
    "intrudevi": "intrudere",
    "intrudevo": "intrudere",
    "intrudi": "intrudere",
    "intrudiamo": "intrudere",
    "intrudiate": "intrudere",
    "intrudo": "intrudere",
    "intrudon": "intrudere",
    "intrudono": "intrudere",
    "intruduta": "intrudere",
    "intrudute": "intrudere",
    "intruduti": "intrudere",
    "intruduto": "intrudere",
    "intrudè": "intrudere",
    "intrufola": "intrufolare",
    "intrufolai": "intrufolare",
    "intrufolammo": "intrufolare",
    "intrufolan": "intrufolare",
    "intrufolando": "intrufolare",
    "intrufolano": "intrufolare",
    "intrufolante": "intrufolare",
    "intrufolanti": "intrufolare",
    "intrufolar": "intrufolare",
    "intrufolaron": "intrufolare",
    "intrufolarono": "intrufolare",
    "intrufolasse": "intrufolare",
    "intrufolasser": "intrufolare",
    "intrufolassero": "intrufolare",
    "intrufolassi": "intrufolare",
    "intrufolassimo": "intrufolare",
    "intrufolaste": "intrufolare",
    "intrufolasti": "intrufolare",
    "intrufolata": "intrufolare",
    "intrufolate": "intrufolare",
    "intrufolati": "intrufolare",
    "intrufolato": "intrufolare",
    "intrufolava": "intrufolare",
    "intrufolavamo": "intrufolare",
    "intrufolavan": "intrufolare",
    "intrufolavano": "intrufolare",
    "intrufolavate": "intrufolare",
    "intrufolavi": "intrufolare",
    "intrufolavo": "intrufolare",
    "intrufolerai": "intrufolare",
    "intrufoleran": "intrufolare",
    "intrufoleranno": "intrufolare",
    "intrufolerebbe": "intrufolare",
    "intrufolerebber": "intrufolare",
    "intrufolerebbero": "intrufolare",
    "intrufolerei": "intrufolare",
    "intrufoleremmo": "intrufolare",
    "intrufoleremo": "intrufolare",
    "intrufolereste": "intrufolare",
    "intrufoleresti": "intrufolare",
    "intrufolerete": "intrufolare",
    "intrufolerà": "intrufolare",
    "intrufolerò": "intrufolare",
    "intrufoli": "intrufolare",
    "intrufoliamo": "intrufolare",
    "intrufoliate": "intrufolare",
    "intrufolin": "intrufolare",
    "intrufolino": "intrufolare",
    "intrufolo": "intrufolare",
    "intrufolò": "intrufolare",
    "intrugli": "intruglio",
    "intruglia": "intrugliare",
    "intrugliai": "intrugliare",
    "intrugliammo": "intrugliare",
    "intrugliamo": "intrugliare",
    "intruglian": "intrugliare",
    "intrugliando": "intrugliare",
    "intrugliano": "intrugliare",
    "intrugliante": "intrugliare",
    "intruglianti": "intrugliare",
    "intrugliar": "intrugliare",
    "intrugliaron": "intrugliare",
    "intrugliarono": "intrugliare",
    "intrugliasse": "intrugliare",
    "intrugliasser": "intrugliare",
    "intrugliassero": "intrugliare",
    "intrugliassi": "intrugliare",
    "intrugliassimo": "intrugliare",
    "intrugliaste": "intrugliare",
    "intrugliasti": "intrugliare",
    "intrugliata": "intrugliare",
    "intrugliate": "intrugliare",
    "intrugliati": "intrugliare",
    "intrugliato": "intrugliare",
    "intrugliava": "intrugliare",
    "intrugliavamo": "intrugliare",
    "intrugliavan": "intrugliare",
    "intrugliavano": "intrugliare",
    "intrugliavate": "intrugliare",
    "intrugliavi": "intrugliare",
    "intrugliavo": "intrugliare",
    "intruglierai": "intrugliare",
    "intruglieran": "intrugliare",
    "intruglieranno": "intrugliare",
    "intruglierebbe": "intrugliare",
    "intruglierebber": "intrugliare",
    "intruglierebbero": "intrugliare",
    "intruglierei": "intrugliare",
    "intruglieremmo": "intrugliare",
    "intruglieremo": "intrugliare",
    "intrugliereste": "intrugliare",
    "intruglieresti": "intrugliare",
    "intruglierete": "intrugliare",
    "intruglierà": "intrugliare",
    "intruglierò": "intrugliare",
    "intruglin": "intrugliare",
    "intruglino": "intrugliare",
    "intruglio": "intrugliare",
    "intrugliò": "intrugliare",
    "intrusa": "intruso",
    "intruse": "intruso",
    "intrusi": "intruso",
    "intrusioni": "intrusione",
    "intuendo": "intuire",
    "intuente": "intuire",
    "intuenti": "intuire",
    "intuiamo": "intuire",
    "intuiate": "intuire",
    "intuibili": "intuibile",
    "intuii": "intuire",
    "intuimmo": "intuire",
    "intuir": "intuire",
    "intuirai": "intuire",
    "intuiran": "intuire",
    "intuiranno": "intuire",
    "intuirebbe": "intuire",
    "intuirebber": "intuire",
    "intuirebbero": "intuire",
    "intuirei": "intuire",
    "intuiremmo": "intuire",
    "intuiremo": "intuire",
    "intuireste": "intuire",
    "intuiresti": "intuire",
    "intuirete": "intuire",
    "intuiron": "intuire",
    "intuirono": "intuire",
    "intuirà": "intuire",
    "intuirò": "intuire",
    "intuisca": "intuire",
    "intuiscan": "intuire",
    "intuiscano": "intuire",
    "intuisce": "intuire",
    "intuisci": "intuire",
    "intuisco": "intuire",
    "intuiscon": "intuire",
    "intuiscono": "intuire",
    "intuisse": "intuire",
    "intuisser": "intuire",
    "intuissero": "intuire",
    "intuissi": "intuire",
    "intuissimo": "intuire",
    "intuiste": "intuire",
    "intuisti": "intuire",
    "intuita": "intuire",
    "intuite": "intuire",
    "intuiti": "intuito",
    "intuitiva": "intuitivo",
    "intuitive": "intuitivo",
    "intuitivi": "intuitivo",
    "intuito": "intuire",
    "intuiva": "intuire",
    "intuivamo": "intuire",
    "intuivan": "intuire",
    "intuivano": "intuire",
    "intuivate": "intuire",
    "intuivi": "intuire",
    "intuivo": "intuire",
    "intuizioni": "intuizione",
    "inturgidendo": "inturgidire",
    "inturgidente": "inturgidire",
    "inturgidenti": "inturgidire",
    "inturgidiamo": "inturgidire",
    "inturgidiate": "inturgidire",
    "inturgidii": "inturgidire",
    "inturgidimmo": "inturgidire",
    "inturgidir": "inturgidire",
    "inturgidirai": "inturgidire",
    "inturgidiran": "inturgidire",
    "inturgidiranno": "inturgidire",
    "inturgidirebbe": "inturgidire",
    "inturgidirebber": "inturgidire",
    "inturgidirebbero": "inturgidire",
    "inturgidirei": "inturgidire",
    "inturgidiremmo": "inturgidire",
    "inturgidiremo": "inturgidire",
    "inturgidireste": "inturgidire",
    "inturgidiresti": "inturgidire",
    "inturgidirete": "inturgidire",
    "inturgidiron": "inturgidire",
    "inturgidirono": "inturgidire",
    "inturgidirà": "inturgidire",
    "inturgidirò": "inturgidire",
    "inturgidisca": "inturgidire",
    "inturgidiscan": "inturgidire",
    "inturgidiscano": "inturgidire",
    "inturgidisce": "inturgidire",
    "inturgidisci": "inturgidire",
    "inturgidisco": "inturgidire",
    "inturgidiscon": "inturgidire",
    "inturgidiscono": "inturgidire",
    "inturgidisse": "inturgidire",
    "inturgidisser": "inturgidire",
    "inturgidissero": "inturgidire",
    "inturgidissi": "inturgidire",
    "inturgidissimo": "inturgidire",
    "inturgidiste": "inturgidire",
    "inturgidisti": "inturgidire",
    "inturgidita": "inturgidire",
    "inturgidite": "inturgidire",
    "inturgiditi": "inturgidire",
    "inturgidito": "inturgidire",
    "inturgidiva": "inturgidire",
    "inturgidivamo": "inturgidire",
    "inturgidivan": "inturgidire",
    "inturgidivano": "inturgidire",
    "inturgidivate": "inturgidire",
    "inturgidivi": "inturgidire",
    "inturgidivo": "inturgidire",
    "inturgidì": "inturgidire",
    "intuì": "intuire",
    "inuma": "inumare",
    "inumai": "inumare",
    "inumammo": "inumare",
    "inuman": "inumare",
    "inumando": "inumare",
    "inumano": "inumare",
    "inumante": "inumare",
    "inumanti": "inumare",
    "inumar": "inumare",
    "inumaron": "inumare",
    "inumarono": "inumare",
    "inumasse": "inumare",
    "inumasser": "inumare",
    "inumassero": "inumare",
    "inumassi": "inumare",
    "inumassimo": "inumare",
    "inumaste": "inumare",
    "inumasti": "inumare",
    "inumata": "inumare",
    "inumate": "inumare",
    "inumati": "inumare",
    "inumato": "inumare",
    "inumava": "inumare",
    "inumavamo": "inumare",
    "inumavan": "inumare",
    "inumavano": "inumare",
    "inumavate": "inumare",
    "inumavi": "inumare",
    "inumavo": "inumare",
    "inumerai": "inumare",
    "inumeran": "inumare",
    "inumeranno": "inumare",
    "inumerebbe": "inumare",
    "inumerebber": "inumare",
    "inumerebbero": "inumare",
    "inumerei": "inumare",
    "inumeremmo": "inumare",
    "inumeremo": "inumare",
    "inumereste": "inumare",
    "inumeresti": "inumare",
    "inumerete": "inumare",
    "inumerà": "inumare",
    "inumerò": "inumare",
    "inumi": "inumare",
    "inumiamo": "inumare",
    "inumiate": "inumare",
    "inumidendo": "inumidire",
    "inumidente": "inumidire",
    "inumidenti": "inumidire",
    "inumidiamo": "inumidire",
    "inumidiate": "inumidire",
    "inumidii": "inumidire",
    "inumidimmo": "inumidire",
    "inumidir": "inumidire",
    "inumidirai": "inumidire",
    "inumidiran": "inumidire",
    "inumidiranno": "inumidire",
    "inumidirebbe": "inumidire",
    "inumidirebber": "inumidire",
    "inumidirebbero": "inumidire",
    "inumidirei": "inumidire",
    "inumidiremmo": "inumidire",
    "inumidiremo": "inumidire",
    "inumidireste": "inumidire",
    "inumidiresti": "inumidire",
    "inumidirete": "inumidire",
    "inumidiron": "inumidire",
    "inumidirono": "inumidire",
    "inumidirà": "inumidire",
    "inumidirò": "inumidire",
    "inumidisca": "inumidire",
    "inumidiscan": "inumidire",
    "inumidiscano": "inumidire",
    "inumidisce": "inumidire",
    "inumidisci": "inumidire",
    "inumidisco": "inumidire",
    "inumidiscon": "inumidire",
    "inumidiscono": "inumidire",
    "inumidisse": "inumidire",
    "inumidisser": "inumidire",
    "inumidissero": "inumidire",
    "inumidissi": "inumidire",
    "inumidissimo": "inumidire",
    "inumidiste": "inumidire",
    "inumidisti": "inumidire",
    "inumidita": "inumidire",
    "inumidite": "inumidire",
    "inumiditi": "inumidire",
    "inumidito": "inumidire",
    "inumidiva": "inumidire",
    "inumidivamo": "inumidire",
    "inumidivan": "inumidire",
    "inumidivano": "inumidire",
    "inumidivate": "inumidire",
    "inumidivi": "inumidire",
    "inumidivo": "inumidire",
    "inumidì": "inumidire",
    "inumin": "inumare",
    "inumino": "inumare",
    "inumo": "inumare",
    "inumò": "inumare",
    "inurba": "inurbare",
    "inurbai": "inurbare",
    "inurbammo": "inurbare",
    "inurban": "inurbare",
    "inurbana": "inurbano",
    "inurbando": "inurbare",
    "inurbane": "inurbano",
    "inurbani": "inurbano",
    "inurbano": "inurbare",
    "inurbar": "inurbare",
    "inurbaron": "inurbare",
    "inurbarono": "inurbare",
    "inurbasse": "inurbare",
    "inurbasser": "inurbare",
    "inurbassero": "inurbare",
    "inurbassi": "inurbare",
    "inurbassimo": "inurbare",
    "inurbaste": "inurbare",
    "inurbasti": "inurbare",
    "inurbata": "inurbare",
    "inurbate": "inurbare",
    "inurbati": "inurbare",
    "inurbato": "inurbare",
    "inurbava": "inurbare",
    "inurbavamo": "inurbare",
    "inurbavan": "inurbare",
    "inurbavano": "inurbare",
    "inurbavate": "inurbare",
    "inurbavi": "inurbare",
    "inurbavo": "inurbare",
    "inurberai": "inurbare",
    "inurberan": "inurbare",
    "inurberanno": "inurbare",
    "inurberebbe": "inurbare",
    "inurberebber": "inurbare",
    "inurberebbero": "inurbare",
    "inurberei": "inurbare",
    "inurberemmo": "inurbare",
    "inurberemo": "inurbare",
    "inurbereste": "inurbare",
    "inurberesti": "inurbare",
    "inurberete": "inurbare",
    "inurberà": "inurbare",
    "inurberò": "inurbare",
    "inurbi": "inurbare",
    "inurbiamo": "inurbare",
    "inurbiate": "inurbare",
    "inurbin": "inurbare",
    "inurbino": "inurbare",
    "inurbo": "inurbare",
    "inurbò": "inurbare",
    "inusitata": "inusitato",
    "inusitate": "inusitato",
    "inusitati": "inusitato",
    "inutili": "inutile",
    "inutilizza": "inutilizzare",
    "inutilizzabili": "inutilizzabile",
    "inutilizzai": "inutilizzare",
    "inutilizzammo": "inutilizzare",
    "inutilizzan": "inutilizzare",
    "inutilizzando": "inutilizzare",
    "inutilizzano": "inutilizzare",
    "inutilizzante": "inutilizzare",
    "inutilizzanti": "inutilizzare",
    "inutilizzar": "inutilizzare",
    "inutilizzaron": "inutilizzare",
    "inutilizzarono": "inutilizzare",
    "inutilizzasse": "inutilizzare",
    "inutilizzasser": "inutilizzare",
    "inutilizzassero": "inutilizzare",
    "inutilizzassi": "inutilizzare",
    "inutilizzassimo": "inutilizzare",
    "inutilizzaste": "inutilizzare",
    "inutilizzasti": "inutilizzare",
    "inutilizzata": "inutilizzato",
    "inutilizzate": "inutilizzato",
    "inutilizzati": "inutilizzato",
    "inutilizzato": "inutilizzare",
    "inutilizzava": "inutilizzare",
    "inutilizzavamo": "inutilizzare",
    "inutilizzavan": "inutilizzare",
    "inutilizzavano": "inutilizzare",
    "inutilizzavate": "inutilizzare",
    "inutilizzavi": "inutilizzare",
    "inutilizzavo": "inutilizzare",
    "inutilizzerai": "inutilizzare",
    "inutilizzeran": "inutilizzare",
    "inutilizzeranno": "inutilizzare",
    "inutilizzerebbe": "inutilizzare",
    "inutilizzerebber": "inutilizzare",
    "inutilizzerebbero": "inutilizzare",
    "inutilizzerei": "inutilizzare",
    "inutilizzeremmo": "inutilizzare",
    "inutilizzeremo": "inutilizzare",
    "inutilizzereste": "inutilizzare",
    "inutilizzeresti": "inutilizzare",
    "inutilizzerete": "inutilizzare",
    "inutilizzerà": "inutilizzare",
    "inutilizzerò": "inutilizzare",
    "inutilizzi": "inutilizzare",
    "inutilizziamo": "inutilizzare",
    "inutilizziate": "inutilizzare",
    "inutilizzin": "inutilizzare",
    "inutilizzino": "inutilizzare",
    "inutilizzo": "inutilizzare",
    "inutilizzò": "inutilizzare",
    "invada": "invadere",
    "invadan": "invadere",
    "invadano": "invadere",
    "invade": "invadere",
    "invademmo": "invadere",
    "invadendo": "invadere",
    "invadente": "invadere",
    "invadenti": "invadere",
    "invadenze": "invadenza",
    "invader": "invadere",
    "invaderai": "invadere",
    "invaderan": "invadere",
    "invaderanno": "invadere",
    "invaderebbe": "invadere",
    "invaderebber": "invadere",
    "invaderebbero": "invadere",
    "invaderei": "invadere",
    "invaderemmo": "invadere",
    "invaderemo": "invadere",
    "invadereste": "invadere",
    "invaderesti": "invadere",
    "invaderete": "invadere",
    "invaderà": "invadere",
    "invaderò": "invadere",
    "invadesse": "invadere",
    "invadesser": "invadere",
    "invadessero": "invadere",
    "invadessi": "invadere",
    "invadessimo": "invadere",
    "invadeste": "invadere",
    "invadesti": "invadere",
    "invadete": "invadere",
    "invadeva": "invadere",
    "invadevamo": "invadere",
    "invadevan": "invadere",
    "invadevano": "invadere",
    "invadevate": "invadere",
    "invadevi": "invadere",
    "invadevo": "invadere",
    "invadi": "invadere",
    "invadiamo": "invadere",
    "invadiate": "invadere",
    "invado": "invadere",
    "invadon": "invadere",
    "invadono": "invadere",
    "invaghendo": "invaghire",
    "invaghente": "invaghire",
    "invaghenti": "invaghire",
    "invaghiamo": "invaghire",
    "invaghiate": "invaghire",
    "invaghii": "invaghire",
    "invaghimmo": "invaghire",
    "invaghir": "invaghire",
    "invaghirai": "invaghire",
    "invaghiran": "invaghire",
    "invaghiranno": "invaghire",
    "invaghirebbe": "invaghire",
    "invaghirebber": "invaghire",
    "invaghirebbero": "invaghire",
    "invaghirei": "invaghire",
    "invaghiremmo": "invaghire",
    "invaghiremo": "invaghire",
    "invaghireste": "invaghire",
    "invaghiresti": "invaghire",
    "invaghirete": "invaghire",
    "invaghiron": "invaghire",
    "invaghirono": "invaghire",
    "invaghirà": "invaghire",
    "invaghirò": "invaghire",
    "invaghisca": "invaghire",
    "invaghiscan": "invaghire",
    "invaghiscano": "invaghire",
    "invaghisce": "invaghire",
    "invaghisci": "invaghire",
    "invaghisco": "invaghire",
    "invaghiscon": "invaghire",
    "invaghiscono": "invaghire",
    "invaghisse": "invaghire",
    "invaghisser": "invaghire",
    "invaghissero": "invaghire",
    "invaghissi": "invaghire",
    "invaghissimo": "invaghire",
    "invaghiste": "invaghire",
    "invaghisti": "invaghire",
    "invaghita": "invaghire",
    "invaghite": "invaghire",
    "invaghiti": "invaghire",
    "invaghito": "invaghire",
    "invaghiva": "invaghire",
    "invaghivamo": "invaghire",
    "invaghivan": "invaghire",
    "invaghivano": "invaghire",
    "invaghivate": "invaghire",
    "invaghivi": "invaghire",
    "invaghivo": "invaghire",
    "invaghì": "invaghire",
    "invala": "invalere",
    "invalan": "invalere",
    "invalano": "invalere",
    "invale": "invalere",
    "invalei": "invalere",
    "invalemmo": "invalere",
    "invalendo": "invalere",
    "invalente": "invalere",
    "invalenti": "invalere",
    "invaler": "invalere",
    "invalerai": "invalere",
    "invaleran": "invalere",
    "invaleranno": "invalere",
    "invalerebbe": "invalere",
    "invalerebber": "invalere",
    "invalerebbero": "invalere",
    "invalerei": "invalere",
    "invaleremmo": "invalere",
    "invaleremo": "invalere",
    "invalereste": "invalere",
    "invaleresti": "invalere",
    "invalerete": "invalere",
    "invaleron": "invalere",
    "invalerono": "invalere",
    "invalerà": "invalere",
    "invalerò": "invalere",
    "invalesse": "invalere",
    "invalesser": "invalere",
    "invalessero": "invalere",
    "invalessi": "invalere",
    "invalessimo": "invalere",
    "invaleste": "invalere",
    "invalesti": "invalere",
    "invalete": "invalere",
    "invaleva": "invalere",
    "invalevamo": "invalere",
    "invalevan": "invalere",
    "invalevano": "invalere",
    "invalevate": "invalere",
    "invalevi": "invalere",
    "invalevo": "invalere",
    "invali": "invalere",
    "invaliamo": "invalere",
    "invaliate": "invalere",
    "invalicabili": "invalicabile",
    "invalida": "invalido",
    "invalidai": "invalidare",
    "invalidammo": "invalidare",
    "invalidan": "invalidare",
    "invalidando": "invalidare",
    "invalidano": "invalidare",
    "invalidante": "invalidare",
    "invalidanti": "invalidare",
    "invalidar": "invalidare",
    "invalidaron": "invalidare",
    "invalidarono": "invalidare",
    "invalidasse": "invalidare",
    "invalidasser": "invalidare",
    "invalidassero": "invalidare",
    "invalidassi": "invalidare",
    "invalidassimo": "invalidare",
    "invalidaste": "invalidare",
    "invalidasti": "invalidare",
    "invalidata": "invalidare",
    "invalidate": "invalidare",
    "invalidati": "invalidare",
    "invalidato": "invalidare",
    "invalidava": "invalidare",
    "invalidavamo": "invalidare",
    "invalidavan": "invalidare",
    "invalidavano": "invalidare",
    "invalidavate": "invalidare",
    "invalidavi": "invalidare",
    "invalidavo": "invalidare",
    "invalide": "invalido",
    "invaliderai": "invalidare",
    "invalideran": "invalidare",
    "invalideranno": "invalidare",
    "invaliderebbe": "invalidare",
    "invaliderebber": "invalidare",
    "invaliderebbero": "invalidare",
    "invaliderei": "invalidare",
    "invalideremmo": "invalidare",
    "invalideremo": "invalidare",
    "invalidereste": "invalidare",
    "invalideresti": "invalidare",
    "invaliderete": "invalidare",
    "invaliderà": "invalidare",
    "invaliderò": "invalidare",
    "invalidi": "invalido",
    "invalidiamo": "invalidare",
    "invalidiate": "invalidare",
    "invalidin": "invalidare",
    "invalidino": "invalidare",
    "invalido": "invalidare",
    "invalidò": "invalidare",
    "invalo": "invalere",
    "invalon": "invalere",
    "invalono": "invalere",
    "invalsa": "invalso",
    "invalse": "invalso",
    "invalsi": "invalso",
    "invaluta": "invalere",
    "invalute": "invalere",
    "invaluti": "invalere",
    "invaluto": "invalere",
    "invalè": "invalere",
    "invariabili": "invariabile",
    "invarianti": "invariante",
    "invariata": "invariato",
    "invariate": "invariato",
    "invariati": "invariato",
    "invasa": "invaso",
    "invasai": "invasare",
    "invasammo": "invasare",
    "invasan": "invasare",
    "invasando": "invasare",
    "invasano": "invasare",
    "invasante": "invasare",
    "invasanti": "invasare",
    "invasar": "invasare",
    "invasaron": "invasare",
    "invasarono": "invasare",
    "invasasse": "invasare",
    "invasasser": "invasare",
    "invasassero": "invasare",
    "invasassi": "invasare",
    "invasassimo": "invasare",
    "invasaste": "invasare",
    "invasasti": "invasare",
    "invasata": "invasato",
    "invasate": "invasato",
    "invasati": "invasato",
    "invasato": "invasare",
    "invasava": "invasare",
    "invasavamo": "invasare",
    "invasavan": "invasare",
    "invasavano": "invasare",
    "invasavate": "invasare",
    "invasavi": "invasare",
    "invasavo": "invasare",
    "invase": "invaso",
    "invaser": "invadere",
    "invaserai": "invasare",
    "invaseran": "invasare",
    "invaseranno": "invasare",
    "invaserebbe": "invasare",
    "invaserebber": "invasare",
    "invaserebbero": "invasare",
    "invaserei": "invasare",
    "invaseremmo": "invasare",
    "invaseremo": "invasare",
    "invasereste": "invasare",
    "invaseresti": "invasare",
    "invaserete": "invasare",
    "invasero": "invadere",
    "invaserà": "invasare",
    "invaserò": "invasare",
    "invasi": "invaso",
    "invasiamo": "invasare",
    "invasiate": "invasare",
    "invasin": "invasare",
    "invasino": "invasare",
    "invasioni": "invasione",
    "invaso": "invasare",
    "invasori": "invasore",
    "invasò": "invasare",
    "invecchi": "invecchiare",
    "invecchia": "invecchiare",
    "invecchiai": "invecchiare",
    "invecchiamenti": "invecchiamento",
    "invecchiammo": "invecchiare",
    "invecchiamo": "invecchiare",
    "invecchian": "invecchiare",
    "invecchiando": "invecchiare",
    "invecchiano": "invecchiare",
    "invecchiante": "invecchiare",
    "invecchianti": "invecchiare",
    "invecchiar": "invecchiare",
    "invecchiaron": "invecchiare",
    "invecchiarono": "invecchiare",
    "invecchiasse": "invecchiare",
    "invecchiasser": "invecchiare",
    "invecchiassero": "invecchiare",
    "invecchiassi": "invecchiare",
    "invecchiassimo": "invecchiare",
    "invecchiaste": "invecchiare",
    "invecchiasti": "invecchiare",
    "invecchiata": "invecchiare",
    "invecchiate": "invecchiare",
    "invecchiati": "invecchiare",
    "invecchiato": "invecchiare",
    "invecchiava": "invecchiare",
    "invecchiavamo": "invecchiare",
    "invecchiavan": "invecchiare",
    "invecchiavano": "invecchiare",
    "invecchiavate": "invecchiare",
    "invecchiavi": "invecchiare",
    "invecchiavo": "invecchiare",
    "invecchierai": "invecchiare",
    "invecchieran": "invecchiare",
    "invecchieranno": "invecchiare",
    "invecchierebbe": "invecchiare",
    "invecchierebber": "invecchiare",
    "invecchierebbero": "invecchiare",
    "invecchierei": "invecchiare",
    "invecchieremmo": "invecchiare",
    "invecchieremo": "invecchiare",
    "invecchiereste": "invecchiare",
    "invecchieresti": "invecchiare",
    "invecchierete": "invecchiare",
    "invecchierà": "invecchiare",
    "invecchierò": "invecchiare",
    "invecchin": "invecchiare",
    "invecchino": "invecchiare",
    "invecchio": "invecchiare",
    "invecchiò": "invecchiare",
    "inveendo": "inveire",
    "inveente": "inveire",
    "inveenti": "inveire",
    "inveiamo": "inveire",
    "inveiate": "inveire",
    "inveii": "inveire",
    "inveimmo": "inveire",
    "inveir": "inveire",
    "inveirai": "inveire",
    "inveiran": "inveire",
    "inveiranno": "inveire",
    "inveirebbe": "inveire",
    "inveirebber": "inveire",
    "inveirebbero": "inveire",
    "inveirei": "inveire",
    "inveiremmo": "inveire",
    "inveiremo": "inveire",
    "inveireste": "inveire",
    "inveiresti": "inveire",
    "inveirete": "inveire",
    "inveiron": "inveire",
    "inveirono": "inveire",
    "inveirà": "inveire",
    "inveirò": "inveire",
    "inveisca": "inveire",
    "inveiscan": "inveire",
    "inveiscano": "inveire",
    "inveisce": "inveire",
    "inveisci": "inveire",
    "inveisco": "inveire",
    "inveiscon": "inveire",
    "inveiscono": "inveire",
    "inveisse": "inveire",
    "inveisser": "inveire",
    "inveissero": "inveire",
    "inveissi": "inveire",
    "inveissimo": "inveire",
    "inveiste": "inveire",
    "inveisti": "inveire",
    "inveita": "inveire",
    "inveite": "inveire",
    "inveiti": "inveire",
    "inveito": "inveire",
    "inveiva": "inveire",
    "inveivamo": "inveire",
    "inveivan": "inveire",
    "inveivano": "inveire",
    "inveivate": "inveire",
    "inveivi": "inveire",
    "inveivo": "inveire",
    "invelena": "invelenire",
    "invelenan": "invelenire",
    "invelenano": "invelenire",
    "invelene": "invelenire",
    "invelenendo": "invelenire",
    "invelenente": "invelenire",
    "invelenenti": "invelenire",
    "inveleni": "invelenire",
    "inveleniamo": "invelenire",
    "inveleniate": "invelenire",
    "invelenii": "invelenire",
    "invelenimmo": "invelenire",
    "invelenir": "invelenire",
    "invelenirai": "invelenire",
    "inveleniran": "invelenire",
    "inveleniranno": "invelenire",
    "invelenirebbe": "invelenire",
    "invelenirebber": "invelenire",
    "invelenirebbero": "invelenire",
    "invelenirei": "invelenire",
    "inveleniremmo": "invelenire",
    "inveleniremo": "invelenire",
    "invelenireste": "invelenire",
    "inveleniresti": "invelenire",
    "invelenirete": "invelenire",
    "inveleniron": "invelenire",
    "invelenirono": "invelenire",
    "invelenirà": "invelenire",
    "invelenirò": "invelenire",
    "invelenisse": "invelenire",
    "invelenisser": "invelenire",
    "invelenissero": "invelenire",
    "invelenissi": "invelenire",
    "invelenissimo": "invelenire",
    "inveleniste": "invelenire",
    "invelenisti": "invelenire",
    "invelenita": "invelenire",
    "invelenite": "invelenire",
    "inveleniti": "invelenire",
    "invelenito": "invelenire",
    "inveleniva": "invelenire",
    "invelenivamo": "invelenire",
    "invelenivan": "invelenire",
    "invelenivano": "invelenire",
    "invelenivate": "invelenire",
    "invelenivi": "invelenire",
    "invelenivo": "invelenire",
    "inveleno": "invelenire",
    "invelenon": "invelenire",
    "invelenono": "invelenire",
    "invelenì": "invelenire",
    "invendibili": "invendibile",
    "invenduta": "invenduto",
    "invendute": "invenduto",
    "invenduti": "invenduto",
    "inventa": "inventare",
    "inventai": "inventare",
    "inventammo": "inventare",
    "inventan": "inventare",
    "inventando": "inventare",
    "inventano": "inventare",
    "inventante": "inventare",
    "inventanti": "inventare",
    "inventar": "inventare",
    "inventari": "inventario",
    "inventaria": "inventariare",
    "inventariai": "inventariare",
    "inventariammo": "inventariare",
    "inventariamo": "inventariare",
    "inventarian": "inventariare",
    "inventariando": "inventariare",
    "inventariano": "inventariare",
    "inventariante": "inventariare",
    "inventarianti": "inventariare",
    "inventariar": "inventariare",
    "inventariaron": "inventariare",
    "inventariarono": "inventariare",
    "inventariasse": "inventariare",
    "inventariasser": "inventariare",
    "inventariassero": "inventariare",
    "inventariassi": "inventariare",
    "inventariassimo": "inventariare",
    "inventariaste": "inventariare",
    "inventariasti": "inventariare",
    "inventariata": "inventariare",
    "inventariate": "inventariare",
    "inventariati": "inventariare",
    "inventariato": "inventariare",
    "inventariava": "inventariare",
    "inventariavamo": "inventariare",
    "inventariavan": "inventariare",
    "inventariavano": "inventariare",
    "inventariavate": "inventariare",
    "inventariavi": "inventariare",
    "inventariavo": "inventariare",
    "inventarierai": "inventariare",
    "inventarieran": "inventariare",
    "inventarieranno": "inventariare",
    "inventarierebbe": "inventariare",
    "inventarierebber": "inventariare",
    "inventarierebbero": "inventariare",
    "inventarierei": "inventariare",
    "inventarieremmo": "inventariare",
    "inventarieremo": "inventariare",
    "inventariereste": "inventariare",
    "inventarieresti": "inventariare",
    "inventarierete": "inventariare",
    "inventarierà": "inventariare",
    "inventarierò": "inventariare",
    "inventarin": "inventariare",
    "inventarino": "inventariare",
    "inventario": "inventariare",
    "inventariò": "inventariare",
    "inventaron": "inventare",
    "inventarono": "inventare",
    "inventasse": "inventare",
    "inventasser": "inventare",
    "inventassero": "inventare",
    "inventassi": "inventare",
    "inventassimo": "inventare",
    "inventaste": "inventare",
    "inventasti": "inventare",
    "inventata": "inventato",
    "inventate": "inventato",
    "inventati": "inventato",
    "inventato": "inventare",
    "inventava": "inventare",
    "inventavamo": "inventare",
    "inventavan": "inventare",
    "inventavano": "inventare",
    "inventavate": "inventare",
    "inventavi": "inventare",
    "inventavo": "inventare",
    "inventerai": "inventare",
    "inventeran": "inventare",
    "inventeranno": "inventare",
    "inventerebbe": "inventare",
    "inventerebber": "inventare",
    "inventerebbero": "inventare",
    "inventerei": "inventare",
    "inventeremmo": "inventare",
    "inventeremo": "inventare",
    "inventereste": "inventare",
    "inventeresti": "inventare",
    "inventerete": "inventare",
    "inventerà": "inventare",
    "inventerò": "inventare",
    "inventi": "inventare",
    "inventiamo": "inventare",
    "inventiate": "inventare",
    "inventin": "inventare",
    "inventino": "inventare",
    "inventiva": "inventivo",
    "inventive": "inventivo",
    "inventivi": "inventivo",
    "invento": "inventare",
    "inventori": "inventore",
    "inventò": "inventare",
    "invenzioni": "invenzione",
    "inverda": "inverdire",
    "inverdan": "inverdire",
    "inverdano": "inverdire",
    "inverde": "inverdire",
    "inverdendo": "inverdire",
    "inverdente": "inverdire",
    "inverdenti": "inverdire",
    "inverdi": "inverdire",
    "inverdiamo": "inverdire",
    "inverdiate": "inverdire",
    "inverdii": "inverdire",
    "inverdimmo": "inverdire",
    "inverdir": "inverdire",
    "inverdirai": "inverdire",
    "inverdiran": "inverdire",
    "inverdiranno": "inverdire",
    "inverdirebbe": "inverdire",
    "inverdirebber": "inverdire",
    "inverdirebbero": "inverdire",
    "inverdirei": "inverdire",
    "inverdiremmo": "inverdire",
    "inverdiremo": "inverdire",
    "inverdireste": "inverdire",
    "inverdiresti": "inverdire",
    "inverdirete": "inverdire",
    "inverdiron": "inverdire",
    "inverdirono": "inverdire",
    "inverdirà": "inverdire",
    "inverdirò": "inverdire",
    "inverdisse": "inverdire",
    "inverdisser": "inverdire",
    "inverdissero": "inverdire",
    "inverdissi": "inverdire",
    "inverdissimo": "inverdire",
    "inverdiste": "inverdire",
    "inverdisti": "inverdire",
    "inverdita": "inverdire",
    "inverdite": "inverdire",
    "inverditi": "inverdire",
    "inverdito": "inverdire",
    "inverdiva": "inverdire",
    "inverdivamo": "inverdire",
    "inverdivan": "inverdire",
    "inverdivano": "inverdire",
    "inverdivate": "inverdire",
    "inverdivi": "inverdire",
    "inverdivo": "inverdire",
    "inverdo": "inverdire",
    "inverdon": "inverdire",
    "inverdono": "inverdire",
    "inverdì": "inverdire",
    "invereconda": "inverecondo",
    "invereconde": "inverecondo",
    "inverecondi": "inverecondo",
    "invernali": "invernale",
    "inverni": "inverno",
    "inverosimiglianze": "inverosimiglianza",
    "inverosimili": "inverosimile",
    "inversa": "inverso",
    "inverse": "inverso",
    "inversi": "inverso",
    "inversioni": "inversione",
    "inverta": "invertire",
    "invertan": "invertire",
    "invertano": "invertire",
    "inverte": "invertire",
    "invertendo": "invertire",
    "invertente": "invertire",
    "invertenti": "invertire",
    "inverti": "invertire",
    "invertiamo": "invertire",
    "invertiate": "invertire",
    "invertii": "invertire",
    "invertimmo": "invertire",
    "invertir": "invertire",
    "invertirai": "invertire",
    "invertiran": "invertire",
    "invertiranno": "invertire",
    "invertirebbe": "invertire",
    "invertirebber": "invertire",
    "invertirebbero": "invertire",
    "invertirei": "invertire",
    "invertiremmo": "invertire",
    "invertiremo": "invertire",
    "invertireste": "invertire",
    "invertiresti": "invertire",
    "invertirete": "invertire",
    "invertiron": "invertire",
    "invertirono": "invertire",
    "invertirà": "invertire",
    "invertirò": "invertire",
    "invertisse": "invertire",
    "invertisser": "invertire",
    "invertissero": "invertire",
    "invertissi": "invertire",
    "invertissimo": "invertire",
    "invertiste": "invertire",
    "invertisti": "invertire",
    "invertita": "invertito",
    "invertite": "invertito",
    "invertiti": "invertito",
    "invertito": "invertire",
    "invertiva": "invertire",
    "invertivamo": "invertire",
    "invertivan": "invertire",
    "invertivano": "invertire",
    "invertivate": "invertire",
    "invertivi": "invertire",
    "invertivo": "invertire",
    "inverto": "invertire",
    "inverton": "invertire",
    "invertono": "invertire",
    "invertì": "invertire",
    "investa": "investire",
    "investan": "investire",
    "investano": "investire",
    "investe": "investire",
    "investendo": "investire",
    "investente": "investire",
    "investenti": "investire",
    "investi": "investire",
    "investiamo": "investire",
    "investiate": "investire",
    "investibili": "investibile",
    "investiga": "investigare",
    "investigai": "investigare",
    "investigammo": "investigare",
    "investigan": "investigare",
    "investigando": "investigare",
    "investigano": "investigare",
    "investigante": "investigare",
    "investiganti": "investigare",
    "investigar": "investigare",
    "investigaron": "investigare",
    "investigarono": "investigare",
    "investigasse": "investigare",
    "investigasser": "investigare",
    "investigassero": "investigare",
    "investigassi": "investigare",
    "investigassimo": "investigare",
    "investigaste": "investigare",
    "investigasti": "investigare",
    "investigata": "investigare",
    "investigate": "investigare",
    "investigati": "investigare",
    "investigativa": "investigativo",
    "investigative": "investigativo",
    "investigativi": "investigativo",
    "investigato": "investigare",
    "investigatori": "investigatore",
    "investigava": "investigare",
    "investigavamo": "investigare",
    "investigavan": "investigare",
    "investigavano": "investigare",
    "investigavate": "investigare",
    "investigavi": "investigare",
    "investigavo": "investigare",
    "investigazioni": "investigazione",
    "investigherai": "investigare",
    "investigheran": "investigare",
    "investigheranno": "investigare",
    "investigherebbe": "investigare",
    "investigherebber": "investigare",
    "investigherebbero": "investigare",
    "investigherei": "investigare",
    "investigheremmo": "investigare",
    "investigheremo": "investigare",
    "investighereste": "investigare",
    "investigheresti": "investigare",
    "investigherete": "investigare",
    "investigherà": "investigare",
    "investigherò": "investigare",
    "investighi": "investigare",
    "investighiamo": "investigare",
    "investighiate": "investigare",
    "investighin": "investigare",
    "investighino": "investigare",
    "investigo": "investigare",
    "investigò": "investigare",
    "investii": "investire",
    "investimenti": "investimento",
    "investimmo": "investire",
    "investir": "investire",
    "investirai": "investire",
    "investiran": "investire",
    "investiranno": "investire",
    "investirebbe": "investire",
    "investirebber": "investire",
    "investirebbero": "investire",
    "investirei": "investire",
    "investiremmo": "investire",
    "investiremo": "investire",
    "investireste": "investire",
    "investiresti": "investire",
    "investirete": "investire",
    "investiron": "investire",
    "investirono": "investire",
    "investirà": "investire",
    "investirò": "investire",
    "investisse": "investire",
    "investisser": "investire",
    "investissero": "investire",
    "investissi": "investire",
    "investissimo": "investire",
    "investiste": "investire",
    "investisti": "investire",
    "investita": "investire",
    "investite": "investire",
    "investiti": "investire",
    "investito": "investire",
    "investitori": "investitore",
    "investitrice": "investitore",
    "investitrici": "investitore",
    "investiture": "investitura",
    "investiva": "investire",
    "investivamo": "investire",
    "investivan": "investire",
    "investivano": "investire",
    "investivate": "investire",
    "investivi": "investire",
    "investivo": "investire",
    "investo": "investire",
    "investon": "investire",
    "investono": "investire",
    "investì": "investire",
    "inveterata": "inveterato",
    "inveterate": "inveterato",
    "inveterati": "inveterato",
    "invettive": "invettiva",
    "inveì": "inveire",
    "invia": "inviare",
    "inviai": "inviare",
    "inviammo": "inviare",
    "inviamo": "inviare",
    "invian": "inviare",
    "inviando": "inviare",
    "inviano": "inviare",
    "inviante": "inviare",
    "invianti": "inviare",
    "inviar": "inviare",
    "inviaron": "inviare",
    "inviarono": "inviare",
    "inviasse": "inviare",
    "inviasser": "inviare",
    "inviassero": "inviare",
    "inviassi": "inviare",
    "inviassimo": "inviare",
    "inviaste": "inviare",
    "inviasti": "inviare",
    "inviata": "inviato",
    "inviate": "inviato",
    "inviati": "inviato",
    "inviato": "inviare",
    "inviava": "inviare",
    "inviavamo": "inviare",
    "inviavan": "inviare",
    "inviavano": "inviare",
    "inviavate": "inviare",
    "inviavi": "inviare",
    "inviavo": "inviare",
    "invida": "invido",
    "invide": "invido",
    "invidi": "invido",
    "invidia": "invidiare",
    "invidiabili": "invidiabile",
    "invidiai": "invidiare",
    "invidiammo": "invidiare",
    "invidiamo": "invidiare",
    "invidian": "invidiare",
    "invidiando": "invidiare",
    "invidiano": "invidiare",
    "invidiante": "invidiare",
    "invidianti": "invidiare",
    "invidiar": "invidiare",
    "invidiaron": "invidiare",
    "invidiarono": "invidiare",
    "invidiasse": "invidiare",
    "invidiasser": "invidiare",
    "invidiassero": "invidiare",
    "invidiassi": "invidiare",
    "invidiassimo": "invidiare",
    "invidiaste": "invidiare",
    "invidiasti": "invidiare",
    "invidiata": "invidiare",
    "invidiate": "invidiare",
    "invidiati": "invidiare",
    "invidiato": "invidiare",
    "invidiava": "invidiare",
    "invidiavamo": "invidiare",
    "invidiavan": "invidiare",
    "invidiavano": "invidiare",
    "invidiavate": "invidiare",
    "invidiavi": "invidiare",
    "invidiavo": "invidiare",
    "invidie": "invidia",
    "invidierai": "invidiare",
    "invidieran": "invidiare",
    "invidieranno": "invidiare",
    "invidierebbe": "invidiare",
    "invidierebber": "invidiare",
    "invidierebbero": "invidiare",
    "invidierei": "invidiare",
    "invidieremmo": "invidiare",
    "invidieremo": "invidiare",
    "invidiereste": "invidiare",
    "invidieresti": "invidiare",
    "invidierete": "invidiare",
    "invidierà": "invidiare",
    "invidierò": "invidiare",
    "invidin": "invidiare",
    "invidino": "invidiare",
    "invidio": "invidiare",
    "invidiosa": "invidioso",
    "invidiose": "invidioso",
    "invidiosi": "invidioso",
    "invidiò": "invidiare",
    "invierai": "inviare",
    "invieran": "inviare",
    "invieranno": "inviare",
    "invierebbe": "inviare",
    "invierebber": "inviare",
    "invierebbero": "inviare",
    "invierei": "inviare",
    "invieremmo": "inviare",
    "invieremo": "inviare",
    "inviereste": "inviare",
    "invieresti": "inviare",
    "invierete": "inviare",
    "invierà": "inviare",
    "invierò": "inviare",
    "invii": "invio",
    "inviin": "inviare",
    "inviino": "inviare",
    "invila": "invilire",
    "invilan": "invilire",
    "invilano": "invilire",
    "invile": "invilire",
    "invilendo": "invilire",
    "invilente": "invilire",
    "invilenti": "invilire",
    "invili": "invilire",
    "inviliamo": "invilire",
    "inviliate": "invilire",
    "invilii": "invilire",
    "invilimmo": "invilire",
    "invilir": "invilire",
    "invilirai": "invilire",
    "inviliran": "invilire",
    "inviliranno": "invilire",
    "invilirebbe": "invilire",
    "invilirebber": "invilire",
    "invilirebbero": "invilire",
    "invilirei": "invilire",
    "inviliremmo": "invilire",
    "inviliremo": "invilire",
    "invilireste": "invilire",
    "inviliresti": "invilire",
    "invilirete": "invilire",
    "inviliron": "invilire",
    "invilirono": "invilire",
    "invilirà": "invilire",
    "invilirò": "invilire",
    "invilisse": "invilire",
    "invilisser": "invilire",
    "invilissero": "invilire",
    "invilissi": "invilire",
    "invilissimo": "invilire",
    "inviliste": "invilire",
    "invilisti": "invilire",
    "invilita": "invilire",
    "invilite": "invilire",
    "inviliti": "invilire",
    "invilito": "invilire",
    "inviliva": "invilire",
    "invilivamo": "invilire",
    "invilivan": "invilire",
    "invilivano": "invilire",
    "invilivate": "invilire",
    "invilivi": "invilire",
    "invilivo": "invilire",
    "invilo": "invilire",
    "invilon": "invilire",
    "invilono": "invilire",
    "inviluppa": "inviluppare",
    "inviluppai": "inviluppare",
    "inviluppammo": "inviluppare",
    "inviluppan": "inviluppare",
    "inviluppando": "inviluppare",
    "inviluppano": "inviluppare",
    "inviluppante": "inviluppare",
    "inviluppanti": "inviluppare",
    "inviluppar": "inviluppare",
    "invilupparon": "inviluppare",
    "invilupparono": "inviluppare",
    "inviluppasse": "inviluppare",
    "inviluppasser": "inviluppare",
    "inviluppassero": "inviluppare",
    "inviluppassi": "inviluppare",
    "inviluppassimo": "inviluppare",
    "inviluppaste": "inviluppare",
    "inviluppasti": "inviluppare",
    "inviluppata": "inviluppare",
    "inviluppate": "inviluppare",
    "inviluppati": "inviluppare",
    "inviluppato": "inviluppare",
    "inviluppava": "inviluppare",
    "inviluppavamo": "inviluppare",
    "inviluppavan": "inviluppare",
    "inviluppavano": "inviluppare",
    "inviluppavate": "inviluppare",
    "inviluppavi": "inviluppare",
    "inviluppavo": "inviluppare",
    "invilupperai": "inviluppare",
    "invilupperan": "inviluppare",
    "invilupperanno": "inviluppare",
    "invilupperebbe": "inviluppare",
    "invilupperebber": "inviluppare",
    "invilupperebbero": "inviluppare",
    "invilupperei": "inviluppare",
    "invilupperemmo": "inviluppare",
    "invilupperemo": "inviluppare",
    "inviluppereste": "inviluppare",
    "invilupperesti": "inviluppare",
    "invilupperete": "inviluppare",
    "invilupperà": "inviluppare",
    "invilupperò": "inviluppare",
    "inviluppi": "inviluppare",
    "inviluppiamo": "inviluppare",
    "inviluppiate": "inviluppare",
    "inviluppin": "inviluppare",
    "inviluppino": "inviluppare",
    "inviluppo": "inviluppare",
    "inviluppò": "inviluppare",
    "invilì": "invilire",
    "invincibili": "invincibile",
    "invio": "inviare",
    "inviolabili": "inviolabile",
    "inviolata": "inviolato",
    "inviolate": "inviolato",
    "inviolati": "inviolato",
    "invipera": "inviperire",
    "inviperan": "inviperire",
    "inviperano": "inviperire",
    "invipere": "inviperire",
    "inviperendo": "inviperire",
    "inviperente": "inviperire",
    "inviperenti": "inviperire",
    "inviperi": "inviperire",
    "inviperiamo": "inviperire",
    "inviperiate": "inviperire",
    "inviperii": "inviperire",
    "inviperimmo": "inviperire",
    "inviperir": "inviperire",
    "inviperirai": "inviperire",
    "inviperiran": "inviperire",
    "inviperiranno": "inviperire",
    "inviperirebbe": "inviperire",
    "inviperirebber": "inviperire",
    "inviperirebbero": "inviperire",
    "inviperirei": "inviperire",
    "inviperiremmo": "inviperire",
    "inviperiremo": "inviperire",
    "inviperireste": "inviperire",
    "inviperiresti": "inviperire",
    "inviperirete": "inviperire",
    "inviperiron": "inviperire",
    "inviperirono": "inviperire",
    "inviperirà": "inviperire",
    "inviperirò": "inviperire",
    "inviperisse": "inviperire",
    "inviperisser": "inviperire",
    "inviperissero": "inviperire",
    "inviperissi": "inviperire",
    "inviperissimo": "inviperire",
    "inviperiste": "inviperire",
    "inviperisti": "inviperire",
    "inviperita": "inviperire",
    "inviperite": "inviperire",
    "inviperiti": "inviperire",
    "inviperito": "inviperire",
    "inviperiva": "inviperire",
    "inviperivamo": "inviperire",
    "inviperivan": "inviperire",
    "inviperivano": "inviperire",
    "inviperivate": "inviperire",
    "inviperivi": "inviperire",
    "inviperivo": "inviperire",
    "invipero": "inviperire",
    "inviperon": "inviperire",
    "inviperono": "inviperire",
    "inviperì": "inviperire",
    "invisa": "inviso",
    "invischi": "invischiare",
    "invischia": "invischiare",
    "invischiai": "invischiare",
    "invischiammo": "invischiare",
    "invischiamo": "invischiare",
    "invischian": "invischiare",
    "invischiando": "invischiare",
    "invischiano": "invischiare",
    "invischiante": "invischiare",
    "invischianti": "invischiare",
    "invischiar": "invischiare",
    "invischiaron": "invischiare",
    "invischiarono": "invischiare",
    "invischiasse": "invischiare",
    "invischiasser": "invischiare",
    "invischiassero": "invischiare",
    "invischiassi": "invischiare",
    "invischiassimo": "invischiare",
    "invischiaste": "invischiare",
    "invischiasti": "invischiare",
    "invischiata": "invischiare",
    "invischiate": "invischiare",
    "invischiati": "invischiare",
    "invischiato": "invischiare",
    "invischiava": "invischiare",
    "invischiavamo": "invischiare",
    "invischiavan": "invischiare",
    "invischiavano": "invischiare",
    "invischiavate": "invischiare",
    "invischiavi": "invischiare",
    "invischiavo": "invischiare",
    "invischierai": "invischiare",
    "invischieran": "invischiare",
    "invischieranno": "invischiare",
    "invischierebbe": "invischiare",
    "invischierebber": "invischiare",
    "invischierebbero": "invischiare",
    "invischierei": "invischiare",
    "invischieremmo": "invischiare",
    "invischieremo": "invischiare",
    "invischiereste": "invischiare",
    "invischieresti": "invischiare",
    "invischierete": "invischiare",
    "invischierà": "invischiare",
    "invischierò": "invischiare",
    "invischin": "invischiare",
    "invischino": "invischiare",
    "invischio": "invischiare",
    "invischiò": "invischiare",
    "invise": "inviso",
    "invisi": "inviso",
    "invisibili": "invisibile",
    "invita": "invitare",
    "invitai": "invitare",
    "invitammo": "invitare",
    "invitan": "invitare",
    "invitando": "invitare",
    "invitano": "invitare",
    "invitante": "invitare",
    "invitanti": "invitare",
    "invitar": "invitare",
    "invitaron": "invitare",
    "invitarono": "invitare",
    "invitasse": "invitare",
    "invitasser": "invitare",
    "invitassero": "invitare",
    "invitassi": "invitare",
    "invitassimo": "invitare",
    "invitaste": "invitare",
    "invitasti": "invitare",
    "invitata": "invitato",
    "invitate": "invitato",
    "invitati": "invitato",
    "invitato": "invitare",
    "invitava": "invitare",
    "invitavamo": "invitare",
    "invitavan": "invitare",
    "invitavano": "invitare",
    "invitavate": "invitare",
    "invitavi": "invitare",
    "invitavo": "invitare",
    "inviterai": "invitare",
    "inviteran": "invitare",
    "inviteranno": "invitare",
    "inviterebbe": "invitare",
    "inviterebber": "invitare",
    "inviterebbero": "invitare",
    "inviterei": "invitare",
    "inviteremmo": "invitare",
    "inviteremo": "invitare",
    "invitereste": "invitare",
    "inviteresti": "invitare",
    "inviterete": "invitare",
    "inviterà": "invitare",
    "inviterò": "invitare",
    "inviti": "invito",
    "invitiamo": "invitare",
    "invitiate": "invitare",
    "invitin": "invitare",
    "invitino": "invitare",
    "invito": "invitare",
    "invitta": "invitto",
    "invitte": "invitto",
    "invitti": "invitto",
    "invitò": "invitare",
    "invivibili": "invivibile",
    "inviò": "inviare",
    "invoca": "invocare",
    "invocai": "invocare",
    "invocammo": "invocare",
    "invocan": "invocare",
    "invocando": "invocare",
    "invocano": "invocare",
    "invocante": "invocare",
    "invocanti": "invocare",
    "invocar": "invocare",
    "invocaron": "invocare",
    "invocarono": "invocare",
    "invocasse": "invocare",
    "invocasser": "invocare",
    "invocassero": "invocare",
    "invocassi": "invocare",
    "invocassimo": "invocare",
    "invocaste": "invocare",
    "invocasti": "invocare",
    "invocata": "invocare",
    "invocate": "invocare",
    "invocati": "invocare",
    "invocato": "invocare",
    "invocava": "invocare",
    "invocavamo": "invocare",
    "invocavan": "invocare",
    "invocavano": "invocare",
    "invocavate": "invocare",
    "invocavi": "invocare",
    "invocavo": "invocare",
    "invocazioni": "invocazione",
    "invocherai": "invocare",
    "invocheran": "invocare",
    "invocheranno": "invocare",
    "invocherebbe": "invocare",
    "invocherebber": "invocare",
    "invocherebbero": "invocare",
    "invocherei": "invocare",
    "invocheremmo": "invocare",
    "invocheremo": "invocare",
    "invochereste": "invocare",
    "invocheresti": "invocare",
    "invocherete": "invocare",
    "invocherà": "invocare",
    "invocherò": "invocare",
    "invochi": "invocare",
    "invochiamo": "invocare",
    "invochiate": "invocare",
    "invochin": "invocare",
    "invochino": "invocare",
    "invoco": "invocare",
    "invocò": "invocare",
    "invogli": "invogliare",
    "invoglia": "invogliare",
    "invogliai": "invogliare",
    "invogliammo": "invogliare",
    "invogliamo": "invogliare",
    "invoglian": "invogliare",
    "invogliando": "invogliare",
    "invogliano": "invogliare",
    "invogliante": "invogliare",
    "invoglianti": "invogliare",
    "invogliar": "invogliare",
    "invogliaron": "invogliare",
    "invogliarono": "invogliare",
    "invogliasse": "invogliare",
    "invogliasser": "invogliare",
    "invogliassero": "invogliare",
    "invogliassi": "invogliare",
    "invogliassimo": "invogliare",
    "invogliaste": "invogliare",
    "invogliasti": "invogliare",
    "invogliata": "invogliare",
    "invogliate": "invogliare",
    "invogliati": "invogliare",
    "invogliato": "invogliare",
    "invogliava": "invogliare",
    "invogliavamo": "invogliare",
    "invogliavan": "invogliare",
    "invogliavano": "invogliare",
    "invogliavate": "invogliare",
    "invogliavi": "invogliare",
    "invogliavo": "invogliare",
    "invoglierai": "invogliare",
    "invoglieran": "invogliare",
    "invoglieranno": "invogliare",
    "invoglierebbe": "invogliare",
    "invoglierebber": "invogliare",
    "invoglierebbero": "invogliare",
    "invoglierei": "invogliare",
    "invoglieremmo": "invogliare",
    "invoglieremo": "invogliare",
    "invogliereste": "invogliare",
    "invoglieresti": "invogliare",
    "invoglierete": "invogliare",
    "invoglierà": "invogliare",
    "invoglierò": "invogliare",
    "invoglin": "invogliare",
    "invoglino": "invogliare",
    "invoglio": "invogliare",
    "invogliò": "invogliare",
    "invola": "involare",
    "involai": "involare",
    "involammo": "involare",
    "involan": "involare",
    "involando": "involare",
    "involano": "involare",
    "involante": "involare",
    "involanti": "involare",
    "involar": "involare",
    "involaron": "involare",
    "involarono": "involare",
    "involasse": "involare",
    "involasser": "involare",
    "involassero": "involare",
    "involassi": "involare",
    "involassimo": "involare",
    "involaste": "involare",
    "involasti": "involare",
    "involata": "involare",
    "involate": "involare",
    "involati": "involare",
    "involato": "involare",
    "involava": "involare",
    "involavamo": "involare",
    "involavan": "involare",
    "involavano": "involare",
    "involavate": "involare",
    "involavi": "involare",
    "involavo": "involare",
    "involerai": "involare",
    "involeran": "involare",
    "involeranno": "involare",
    "involerebbe": "involare",
    "involerebber": "involare",
    "involerebbero": "involare",
    "involerei": "involare",
    "involeremmo": "involare",
    "involeremo": "involare",
    "involereste": "involare",
    "involeresti": "involare",
    "involerete": "involare",
    "involerà": "involare",
    "involerò": "involare",
    "involga": "involgere",
    "involgan": "involgere",
    "involgano": "involgere",
    "involgara": "involgarire",
    "involgaran": "involgarire",
    "involgarano": "involgarire",
    "involgare": "involgarire",
    "involgarendo": "involgarire",
    "involgarente": "involgarire",
    "involgarenti": "involgarire",
    "involgari": "involgarire",
    "involgariamo": "involgarire",
    "involgariate": "involgarire",
    "involgarii": "involgarire",
    "involgarimmo": "involgarire",
    "involgarir": "involgarire",
    "involgarirai": "involgarire",
    "involgariran": "involgarire",
    "involgariranno": "involgarire",
    "involgarirebbe": "involgarire",
    "involgarirebber": "involgarire",
    "involgarirebbero": "involgarire",
    "involgarirei": "involgarire",
    "involgariremmo": "involgarire",
    "involgariremo": "involgarire",
    "involgarireste": "involgarire",
    "involgariresti": "involgarire",
    "involgarirete": "involgarire",
    "involgariron": "involgarire",
    "involgarirono": "involgarire",
    "involgarirà": "involgarire",
    "involgarirò": "involgarire",
    "involgarisse": "involgarire",
    "involgarisser": "involgarire",
    "involgarissero": "involgarire",
    "involgarissi": "involgarire",
    "involgarissimo": "involgarire",
    "involgariste": "involgarire",
    "involgaristi": "involgarire",
    "involgarita": "involgarire",
    "involgarite": "involgarire",
    "involgariti": "involgarire",
    "involgarito": "involgarire",
    "involgariva": "involgarire",
    "involgarivamo": "involgarire",
    "involgarivan": "involgarire",
    "involgarivano": "involgarire",
    "involgarivate": "involgarire",
    "involgarivi": "involgarire",
    "involgarivo": "involgarire",
    "involgaro": "involgarire",
    "involgaron": "involgarire",
    "involgarono": "involgarire",
    "involgarì": "involgarire",
    "involge": "involgere",
    "involgei": "involgere",
    "involgemmo": "involgere",
    "involgendo": "involgere",
    "involgente": "involgere",
    "involgenti": "involgere",
    "involger": "involgere",
    "involgerai": "involgere",
    "involgeran": "involgere",
    "involgeranno": "involgere",
    "involgerebbe": "involgere",
    "involgerebber": "involgere",
    "involgerebbero": "involgere",
    "involgerei": "involgere",
    "involgeremmo": "involgere",
    "involgeremo": "involgere",
    "involgereste": "involgere",
    "involgeresti": "involgere",
    "involgerete": "involgere",
    "involgeron": "involgere",
    "involgerono": "involgere",
    "involgerà": "involgere",
    "involgerò": "involgere",
    "involgesse": "involgere",
    "involgesser": "involgere",
    "involgessero": "involgere",
    "involgessi": "involgere",
    "involgessimo": "involgere",
    "involgeste": "involgere",
    "involgesti": "involgere",
    "involgete": "involgere",
    "involgeva": "involgere",
    "involgevamo": "involgere",
    "involgevan": "involgere",
    "involgevano": "involgere",
    "involgevate": "involgere",
    "involgevi": "involgere",
    "involgevo": "involgere",
    "involgi": "involgere",
    "involgiamo": "involgere",
    "involgiate": "involgere",
    "involgo": "involgere",
    "involgon": "involgere",
    "involgono": "involgere",
    "involgè": "involgere",
    "involi": "involare",
    "involiamo": "involare",
    "involiate": "involare",
    "involin": "involare",
    "involino": "involare",
    "involo": "involare",
    "involontari": "involontario",
    "involontaria": "involontario",
    "involontarie": "involontario",
    "involta": "involtare",
    "involtai": "involtare",
    "involtammo": "involtare",
    "involtan": "involtare",
    "involtando": "involtare",
    "involtano": "involtare",
    "involtante": "involtare",
    "involtanti": "involtare",
    "involtar": "involtare",
    "involtaron": "involtare",
    "involtarono": "involtare",
    "involtasse": "involtare",
    "involtasser": "involtare",
    "involtassero": "involtare",
    "involtassi": "involtare",
    "involtassimo": "involtare",
    "involtaste": "involtare",
    "involtasti": "involtare",
    "involtata": "involtare",
    "involtate": "involtare",
    "involtati": "involtare",
    "involtato": "involtare",
    "involtava": "involtare",
    "involtavamo": "involtare",
    "involtavan": "involtare",
    "involtavano": "involtare",
    "involtavate": "involtare",
    "involtavi": "involtare",
    "involtavo": "involtare",
    "involte": "involgere",
    "involterai": "involtare",
    "involteran": "involtare",
    "involteranno": "involtare",
    "involterebbe": "involtare",
    "involterebber": "involtare",
    "involterebbero": "involtare",
    "involterei": "involtare",
    "involteremmo": "involtare",
    "involteremo": "involtare",
    "involtereste": "involtare",
    "involteresti": "involtare",
    "involterete": "involtare",
    "involterà": "involtare",
    "involterò": "involtare",
    "involti": "involtare",
    "involtiamo": "involtare",
    "involtiate": "involtare",
    "involtin": "involtare",
    "involtini": "involtino",
    "involtino": "involtare",
    "involto": "involtare",
    "involtò": "involtare",
    "involucri": "involucro",
    "involuta": "involuto",
    "involute": "involuto",
    "involuti": "involuto",
    "involutiva": "involutivo",
    "involutive": "involutivo",
    "involutivi": "involutivo",
    "involuzioni": "involuzione",
    "involva": "involvere",
    "involvan": "involvere",
    "involvano": "involvere",
    "involve": "involvere",
    "involvei": "involvere",
    "involvemmo": "involvere",
    "involvendo": "involvere",
    "involvente": "involvere",
    "involventi": "involvere",
    "involver": "involvere",
    "involverai": "involvere",
    "involveran": "involvere",
    "involveranno": "involvere",
    "involverebbe": "involvere",
    "involverebber": "involvere",
    "involverebbero": "involvere",
    "involverei": "involvere",
    "involveremmo": "involvere",
    "involveremo": "involvere",
    "involvereste": "involvere",
    "involveresti": "involvere",
    "involverete": "involvere",
    "involveron": "involvere",
    "involverono": "involvere",
    "involverà": "involvere",
    "involverò": "involvere",
    "involvesse": "involvere",
    "involvesser": "involvere",
    "involvessero": "involvere",
    "involvessi": "involvere",
    "involvessimo": "involvere",
    "involveste": "involvere",
    "involvesti": "involvere",
    "involvete": "involvere",
    "involveva": "involvere",
    "involvevamo": "involvere",
    "involvevan": "involvere",
    "involvevano": "involvere",
    "involvevate": "involvere",
    "involvevi": "involvere",
    "involvevo": "involvere",
    "involvi": "involvere",
    "involviamo": "involvere",
    "involviate": "involvere",
    "involvo": "involvere",
    "involvon": "involvere",
    "involvono": "involvere",
    "involvuta": "involvere",
    "involvute": "involvere",
    "involvuti": "involvere",
    "involvuto": "involvere",
    "involvè": "involvere",
    "involò": "involare",
    "invulnerabili": "invulnerabile",
    "inzacchera": "inzaccherare",
    "inzaccherai": "inzaccherare",
    "inzaccherammo": "inzaccherare",
    "inzaccheran": "inzaccherare",
    "inzaccherando": "inzaccherare",
    "inzaccherano": "inzaccherare",
    "inzaccherante": "inzaccherare",
    "inzaccheranti": "inzaccherare",
    "inzaccherar": "inzaccherare",
    "inzaccheraron": "inzaccherare",
    "inzaccherarono": "inzaccherare",
    "inzaccherasse": "inzaccherare",
    "inzaccherasser": "inzaccherare",
    "inzaccherassero": "inzaccherare",
    "inzaccherassi": "inzaccherare",
    "inzaccherassimo": "inzaccherare",
    "inzaccheraste": "inzaccherare",
    "inzaccherasti": "inzaccherare",
    "inzaccherata": "inzaccherare",
    "inzaccherate": "inzaccherare",
    "inzaccherati": "inzaccherare",
    "inzaccherato": "inzaccherare",
    "inzaccherava": "inzaccherare",
    "inzaccheravamo": "inzaccherare",
    "inzaccheravan": "inzaccherare",
    "inzaccheravano": "inzaccherare",
    "inzaccheravate": "inzaccherare",
    "inzaccheravi": "inzaccherare",
    "inzaccheravo": "inzaccherare",
    "inzacchererai": "inzaccherare",
    "inzacchereran": "inzaccherare",
    "inzacchereranno": "inzaccherare",
    "inzacchererebbe": "inzaccherare",
    "inzacchererebber": "inzaccherare",
    "inzacchererebbero": "inzaccherare",
    "inzacchererei": "inzaccherare",
    "inzacchereremmo": "inzaccherare",
    "inzacchereremo": "inzaccherare",
    "inzaccherereste": "inzaccherare",
    "inzacchereresti": "inzaccherare",
    "inzacchererete": "inzaccherare",
    "inzacchererà": "inzaccherare",
    "inzacchererò": "inzaccherare",
    "inzaccheri": "inzaccherare",
    "inzaccheriamo": "inzaccherare",
    "inzaccheriate": "inzaccherare",
    "inzaccherin": "inzaccherare",
    "inzaccherino": "inzaccherare",
    "inzacchero": "inzaccherare",
    "inzaccherò": "inzaccherare",
    "inzavorra": "inzavorrare",
    "inzavorrai": "inzavorrare",
    "inzavorrammo": "inzavorrare",
    "inzavorran": "inzavorrare",
    "inzavorrando": "inzavorrare",
    "inzavorrano": "inzavorrare",
    "inzavorrante": "inzavorrare",
    "inzavorranti": "inzavorrare",
    "inzavorrar": "inzavorrare",
    "inzavorraron": "inzavorrare",
    "inzavorrarono": "inzavorrare",
    "inzavorrasse": "inzavorrare",
    "inzavorrasser": "inzavorrare",
    "inzavorrassero": "inzavorrare",
    "inzavorrassi": "inzavorrare",
    "inzavorrassimo": "inzavorrare",
    "inzavorraste": "inzavorrare",
    "inzavorrasti": "inzavorrare",
    "inzavorrata": "inzavorrare",
    "inzavorrate": "inzavorrare",
    "inzavorrati": "inzavorrare",
    "inzavorrato": "inzavorrare",
    "inzavorrava": "inzavorrare",
    "inzavorravamo": "inzavorrare",
    "inzavorravan": "inzavorrare",
    "inzavorravano": "inzavorrare",
    "inzavorravate": "inzavorrare",
    "inzavorravi": "inzavorrare",
    "inzavorravo": "inzavorrare",
    "inzavorrerai": "inzavorrare",
    "inzavorreran": "inzavorrare",
    "inzavorreranno": "inzavorrare",
    "inzavorrerebbe": "inzavorrare",
    "inzavorrerebber": "inzavorrare",
    "inzavorrerebbero": "inzavorrare",
    "inzavorrerei": "inzavorrare",
    "inzavorreremmo": "inzavorrare",
    "inzavorreremo": "inzavorrare",
    "inzavorrereste": "inzavorrare",
    "inzavorreresti": "inzavorrare",
    "inzavorrerete": "inzavorrare",
    "inzavorrerà": "inzavorrare",
    "inzavorrerò": "inzavorrare",
    "inzavorri": "inzavorrare",
    "inzavorriamo": "inzavorrare",
    "inzavorriate": "inzavorrare",
    "inzavorrin": "inzavorrare",
    "inzavorrino": "inzavorrare",
    "inzavorro": "inzavorrare",
    "inzavorrò": "inzavorrare",
    "inzeppa": "inzeppare",
    "inzeppai": "inzeppare",
    "inzeppammo": "inzeppare",
    "inzeppan": "inzeppare",
    "inzeppando": "inzeppare",
    "inzeppano": "inzeppare",
    "inzeppante": "inzeppare",
    "inzeppanti": "inzeppare",
    "inzeppar": "inzeppare",
    "inzepparon": "inzeppare",
    "inzepparono": "inzeppare",
    "inzeppasse": "inzeppare",
    "inzeppasser": "inzeppare",
    "inzeppassero": "inzeppare",
    "inzeppassi": "inzeppare",
    "inzeppassimo": "inzeppare",
    "inzeppaste": "inzeppare",
    "inzeppasti": "inzeppare",
    "inzeppata": "inzeppare",
    "inzeppate": "inzeppare",
    "inzeppati": "inzeppare",
    "inzeppato": "inzeppare",
    "inzeppava": "inzeppare",
    "inzeppavamo": "inzeppare",
    "inzeppavan": "inzeppare",
    "inzeppavano": "inzeppare",
    "inzeppavate": "inzeppare",
    "inzeppavi": "inzeppare",
    "inzeppavo": "inzeppare",
    "inzepperai": "inzeppare",
    "inzepperan": "inzeppare",
    "inzepperanno": "inzeppare",
    "inzepperebbe": "inzeppare",
    "inzepperebber": "inzeppare",
    "inzepperebbero": "inzeppare",
    "inzepperei": "inzeppare",
    "inzepperemmo": "inzeppare",
    "inzepperemo": "inzeppare",
    "inzeppereste": "inzeppare",
    "inzepperesti": "inzeppare",
    "inzepperete": "inzeppare",
    "inzepperà": "inzeppare",
    "inzepperò": "inzeppare",
    "inzeppi": "inzeppare",
    "inzeppiamo": "inzeppare",
    "inzeppiate": "inzeppare",
    "inzeppin": "inzeppare",
    "inzeppino": "inzeppare",
    "inzeppo": "inzeppare",
    "inzeppò": "inzeppare",
    "inziative": "inziativa",
    "inzucchera": "inzuccherare",
    "inzuccherai": "inzuccherare",
    "inzuccherammo": "inzuccherare",
    "inzuccheran": "inzuccherare",
    "inzuccherando": "inzuccherare",
    "inzuccherano": "inzuccherare",
    "inzuccherante": "inzuccherare",
    "inzuccheranti": "inzuccherare",
    "inzuccherar": "inzuccherare",
    "inzuccheraron": "inzuccherare",
    "inzuccherarono": "inzuccherare",
    "inzuccherasse": "inzuccherare",
    "inzuccherasser": "inzuccherare",
    "inzuccherassero": "inzuccherare",
    "inzuccherassi": "inzuccherare",
    "inzuccherassimo": "inzuccherare",
    "inzuccheraste": "inzuccherare",
    "inzuccherasti": "inzuccherare",
    "inzuccherata": "inzuccherare",
    "inzuccherate": "inzuccherare",
    "inzuccherati": "inzuccherare",
    "inzuccherato": "inzuccherare",
    "inzuccherava": "inzuccherare",
    "inzuccheravamo": "inzuccherare",
    "inzuccheravan": "inzuccherare",
    "inzuccheravano": "inzuccherare",
    "inzuccheravate": "inzuccherare",
    "inzuccheravi": "inzuccherare",
    "inzuccheravo": "inzuccherare",
    "inzucchererai": "inzuccherare",
    "inzucchereran": "inzuccherare",
    "inzucchereranno": "inzuccherare",
    "inzucchererebbe": "inzuccherare",
    "inzucchererebber": "inzuccherare",
    "inzucchererebbero": "inzuccherare",
    "inzucchererei": "inzuccherare",
    "inzucchereremmo": "inzuccherare",
    "inzucchereremo": "inzuccherare",
    "inzuccherereste": "inzuccherare",
    "inzucchereresti": "inzuccherare",
    "inzucchererete": "inzuccherare",
    "inzucchererà": "inzuccherare",
    "inzucchererò": "inzuccherare",
    "inzuccheri": "inzuccherare",
    "inzuccheriamo": "inzuccherare",
    "inzuccheriate": "inzuccherare",
    "inzuccherin": "inzuccherare",
    "inzuccherino": "inzuccherare",
    "inzucchero": "inzuccherare",
    "inzuccherò": "inzuccherare",
    "inzuppa": "inzuppare",
    "inzuppai": "inzuppare",
    "inzuppammo": "inzuppare",
    "inzuppan": "inzuppare",
    "inzuppando": "inzuppare",
    "inzuppano": "inzuppare",
    "inzuppante": "inzuppare",
    "inzuppanti": "inzuppare",
    "inzuppar": "inzuppare",
    "inzupparon": "inzuppare",
    "inzupparono": "inzuppare",
    "inzuppasse": "inzuppare",
    "inzuppasser": "inzuppare",
    "inzuppassero": "inzuppare",
    "inzuppassi": "inzuppare",
    "inzuppassimo": "inzuppare",
    "inzuppaste": "inzuppare",
    "inzuppasti": "inzuppare",
    "inzuppata": "inzuppare",
    "inzuppate": "inzuppare",
    "inzuppati": "inzuppare",
    "inzuppato": "inzuppare",
    "inzuppava": "inzuppare",
    "inzuppavamo": "inzuppare",
    "inzuppavan": "inzuppare",
    "inzuppavano": "inzuppare",
    "inzuppavate": "inzuppare",
    "inzuppavi": "inzuppare",
    "inzuppavo": "inzuppare",
    "inzupperai": "inzuppare",
    "inzupperan": "inzuppare",
    "inzupperanno": "inzuppare",
    "inzupperebbe": "inzuppare",
    "inzupperebber": "inzuppare",
    "inzupperebbero": "inzuppare",
    "inzupperei": "inzuppare",
    "inzupperemmo": "inzuppare",
    "inzupperemo": "inzuppare",
    "inzuppereste": "inzuppare",
    "inzupperesti": "inzuppare",
    "inzupperete": "inzuppare",
    "inzupperà": "inzuppare",
    "inzupperò": "inzuppare",
    "inzuppi": "inzuppare",
    "inzuppiamo": "inzuppare",
    "inzuppiate": "inzuppare",
    "inzuppin": "inzuppare",
    "inzuppino": "inzuppare",
    "inzuppo": "inzuppare",
    "inzuppò": "inzuppare",
    "iodii": "iodio",
    "ioni": "ionio",
    "ionia": "ionio",
    "ionica": "ionico",
    "ioniche": "ionico",
    "ionici": "ionico",
    "ionie": "ionio",
    "ionizza": "ionizzare",
    "ionizzai": "ionizzare",
    "ionizzammo": "ionizzare",
    "ionizzan": "ionizzare",
    "ionizzando": "ionizzare",
    "ionizzano": "ionizzare",
    "ionizzante": "ionizzare",
    "ionizzanti": "ionizzare",
    "ionizzar": "ionizzare",
    "ionizzaron": "ionizzare",
    "ionizzarono": "ionizzare",
    "ionizzasse": "ionizzare",
    "ionizzasser": "ionizzare",
    "ionizzassero": "ionizzare",
    "ionizzassi": "ionizzare",
    "ionizzassimo": "ionizzare",
    "ionizzaste": "ionizzare",
    "ionizzasti": "ionizzare",
    "ionizzata": "ionizzare",
    "ionizzate": "ionizzare",
    "ionizzati": "ionizzare",
    "ionizzato": "ionizzare",
    "ionizzava": "ionizzare",
    "ionizzavamo": "ionizzare",
    "ionizzavan": "ionizzare",
    "ionizzavano": "ionizzare",
    "ionizzavate": "ionizzare",
    "ionizzavi": "ionizzare",
    "ionizzavo": "ionizzare",
    "ionizzerai": "ionizzare",
    "ionizzeran": "ionizzare",
    "ionizzeranno": "ionizzare",
    "ionizzerebbe": "ionizzare",
    "ionizzerebber": "ionizzare",
    "ionizzerebbero": "ionizzare",
    "ionizzerei": "ionizzare",
    "ionizzeremmo": "ionizzare",
    "ionizzeremo": "ionizzare",
    "ionizzereste": "ionizzare",
    "ionizzeresti": "ionizzare",
    "ionizzerete": "ionizzare",
    "ionizzerà": "ionizzare",
    "ionizzerò": "ionizzare",
    "ionizzi": "ionizzare",
    "ionizziamo": "ionizzare",
    "ionizziate": "ionizzare",
    "ionizzin": "ionizzare",
    "ionizzino": "ionizzare",
    "ionizzo": "ionizzare",
    "ionizzò": "ionizzare",
    "iper-teatrali": "iper-teatrale",
    "iperboli": "iperbole",
    "iperbolica": "iperbolico",
    "iperboliche": "iperbolico",
    "iperbolici": "iperbolico",
    "ipermercati": "ipermercato",
    "iperrealiste": "iperrealista",
    "iperrealisti": "iperrealista",
    "ipersensibili": "ipersensibile",
    "ipertecnologica": "ipertecnologico",
    "ipertecnologiche": "ipertecnologico",
    "ipertecnologici": "ipertecnologico",
    "ipertensioni": "ipertensione",
    "ipertensiva": "ipertensivo",
    "ipertensive": "ipertensivo",
    "ipertensivi": "ipertensivo",
    "ipertesa": "iperteso",
    "ipertese": "iperteso",
    "ipertesi": "iperteso",
    "ipertrofica": "ipertrofico",
    "ipertrofiche": "ipertrofico",
    "ipertrofici": "ipertrofico",
    "ipertrofie": "ipertrofia",
    "ipnotica": "ipnotico",
    "ipnotiche": "ipnotico",
    "ipnotici": "ipnotico",
    "ipnotizza": "ipnotizzare",
    "ipnotizzai": "ipnotizzare",
    "ipnotizzammo": "ipnotizzare",
    "ipnotizzan": "ipnotizzare",
    "ipnotizzando": "ipnotizzare",
    "ipnotizzano": "ipnotizzare",
    "ipnotizzante": "ipnotizzare",
    "ipnotizzanti": "ipnotizzare",
    "ipnotizzar": "ipnotizzare",
    "ipnotizzaron": "ipnotizzare",
    "ipnotizzarono": "ipnotizzare",
    "ipnotizzasse": "ipnotizzare",
    "ipnotizzasser": "ipnotizzare",
    "ipnotizzassero": "ipnotizzare",
    "ipnotizzassi": "ipnotizzare",
    "ipnotizzassimo": "ipnotizzare",
    "ipnotizzaste": "ipnotizzare",
    "ipnotizzasti": "ipnotizzare",
    "ipnotizzata": "ipnotizzare",
    "ipnotizzate": "ipnotizzare",
    "ipnotizzati": "ipnotizzare",
    "ipnotizzato": "ipnotizzare",
    "ipnotizzatori": "ipnotizzatore",
    "ipnotizzava": "ipnotizzare",
    "ipnotizzavamo": "ipnotizzare",
    "ipnotizzavan": "ipnotizzare",
    "ipnotizzavano": "ipnotizzare",
    "ipnotizzavate": "ipnotizzare",
    "ipnotizzavi": "ipnotizzare",
    "ipnotizzavo": "ipnotizzare",
    "ipnotizzerai": "ipnotizzare",
    "ipnotizzeran": "ipnotizzare",
    "ipnotizzeranno": "ipnotizzare",
    "ipnotizzerebbe": "ipnotizzare",
    "ipnotizzerebber": "ipnotizzare",
    "ipnotizzerebbero": "ipnotizzare",
    "ipnotizzerei": "ipnotizzare",
    "ipnotizzeremmo": "ipnotizzare",
    "ipnotizzeremo": "ipnotizzare",
    "ipnotizzereste": "ipnotizzare",
    "ipnotizzeresti": "ipnotizzare",
    "ipnotizzerete": "ipnotizzare",
    "ipnotizzerà": "ipnotizzare",
    "ipnotizzerò": "ipnotizzare",
    "ipnotizzi": "ipnotizzare",
    "ipnotizziamo": "ipnotizzare",
    "ipnotizziate": "ipnotizzare",
    "ipnotizzin": "ipnotizzare",
    "ipnotizzino": "ipnotizzare",
    "ipnotizzo": "ipnotizzare",
    "ipnotizzò": "ipnotizzare",
    "ipocondriaca": "ipocondriaco",
    "ipocondriache": "ipocondriaco",
    "ipocondriaci": "ipocondriaco",
    "ipocrisie": "ipocrisia",
    "ipocrite": "ipocrita",
    "ipocriti": "ipocrita",
    "ipogea": "ipogeo",
    "ipogee": "ipogeo",
    "ipogei": "ipogeo",
    "ipoteca": "ipotecare",
    "ipotecai": "ipotecare",
    "ipotecammo": "ipotecare",
    "ipotecan": "ipotecare",
    "ipotecando": "ipotecare",
    "ipotecano": "ipotecare",
    "ipotecante": "ipotecare",
    "ipotecanti": "ipotecare",
    "ipotecar": "ipotecare",
    "ipotecari": "ipotecario",
    "ipotecaria": "ipotecario",
    "ipotecarie": "ipotecario",
    "ipotecaron": "ipotecare",
    "ipotecarono": "ipotecare",
    "ipotecasse": "ipotecare",
    "ipotecasser": "ipotecare",
    "ipotecassero": "ipotecare",
    "ipotecassi": "ipotecare",
    "ipotecassimo": "ipotecare",
    "ipotecaste": "ipotecare",
    "ipotecasti": "ipotecare",
    "ipotecata": "ipotecare",
    "ipotecate": "ipotecare",
    "ipotecati": "ipotecare",
    "ipotecato": "ipotecare",
    "ipotecava": "ipotecare",
    "ipotecavamo": "ipotecare",
    "ipotecavan": "ipotecare",
    "ipotecavano": "ipotecare",
    "ipotecavate": "ipotecare",
    "ipotecavi": "ipotecare",
    "ipotecavo": "ipotecare",
    "ipoteche": "ipoteca",
    "ipotecherai": "ipotecare",
    "ipotecheran": "ipotecare",
    "ipotecheranno": "ipotecare",
    "ipotecherebbe": "ipotecare",
    "ipotecherebber": "ipotecare",
    "ipotecherebbero": "ipotecare",
    "ipotecherei": "ipotecare",
    "ipotecheremmo": "ipotecare",
    "ipotecheremo": "ipotecare",
    "ipotechereste": "ipotecare",
    "ipotecheresti": "ipotecare",
    "ipotecherete": "ipotecare",
    "ipotecherà": "ipotecare",
    "ipotecherò": "ipotecare",
    "ipotechi": "ipotecare",
    "ipotechiamo": "ipotecare",
    "ipotechiate": "ipotecare",
    "ipotechin": "ipotecare",
    "ipotechino": "ipotecare",
    "ipoteco": "ipotecare",
    "ipotecò": "ipotecare",
    "ipotesa": "ipoteso",
    "ipotese": "ipoteso",
    "ipotesi": "ipoteso",
    "ipotetica": "ipotetico",
    "ipotetiche": "ipotetico",
    "ipotetici": "ipotetico",
    "ipotizza": "ipotizzare",
    "ipotizzabili": "ipotizzabile",
    "ipotizzai": "ipotizzare",
    "ipotizzammo": "ipotizzare",
    "ipotizzan": "ipotizzare",
    "ipotizzando": "ipotizzare",
    "ipotizzano": "ipotizzare",
    "ipotizzante": "ipotizzare",
    "ipotizzanti": "ipotizzare",
    "ipotizzar": "ipotizzare",
    "ipotizzaron": "ipotizzare",
    "ipotizzarono": "ipotizzare",
    "ipotizzasse": "ipotizzare",
    "ipotizzasser": "ipotizzare",
    "ipotizzassero": "ipotizzare",
    "ipotizzassi": "ipotizzare",
    "ipotizzassimo": "ipotizzare",
    "ipotizzaste": "ipotizzare",
    "ipotizzasti": "ipotizzare",
    "ipotizzata": "ipotizzare",
    "ipotizzate": "ipotizzare",
    "ipotizzati": "ipotizzare",
    "ipotizzato": "ipotizzare",
    "ipotizzava": "ipotizzare",
    "ipotizzavamo": "ipotizzare",
    "ipotizzavan": "ipotizzare",
    "ipotizzavano": "ipotizzare",
    "ipotizzavate": "ipotizzare",
    "ipotizzavi": "ipotizzare",
    "ipotizzavo": "ipotizzare",
    "ipotizzerai": "ipotizzare",
    "ipotizzeran": "ipotizzare",
    "ipotizzeranno": "ipotizzare",
    "ipotizzerebbe": "ipotizzare",
    "ipotizzerebber": "ipotizzare",
    "ipotizzerebbero": "ipotizzare",
    "ipotizzerei": "ipotizzare",
    "ipotizzeremmo": "ipotizzare",
    "ipotizzeremo": "ipotizzare",
    "ipotizzereste": "ipotizzare",
    "ipotizzeresti": "ipotizzare",
    "ipotizzerete": "ipotizzare",
    "ipotizzerà": "ipotizzare",
    "ipotizzerò": "ipotizzare",
    "ipotizzi": "ipotizzare",
    "ipotizziamo": "ipotizzare",
    "ipotizziate": "ipotizzare",
    "ipotizzin": "ipotizzare",
    "ipotizzino": "ipotizzare",
    "ipotizzo": "ipotizzare",
    "ipotizzò": "ipotizzare",
    "ippica": "ippico",
    "ippiche": "ippico",
    "ippici": "ippico",
    "ippodromi": "ippodromo",
    "ippopotami": "ippopotamo",
    "irachena": "iracheno",
    "irachene": "iracheno",
    "iracheni": "iracheno",
    "iraconda": "iracondo",
    "iraconde": "iracondo",
    "iracondi": "iracondo",
    "irakena": "irakeno",
    "irakene": "irakeno",
    "irakeni": "irakeno",
    "iraniana": "iraniano",
    "iraniane": "iraniano",
    "iraniani": "iraniano",
    "iranica": "iranico",
    "iraniche": "iranico",
    "iranici": "iranico",
    "irascibili": "irascibile",
    "irata": "irato",
    "irate": "irato",
    "irati": "irato",
    "ire": "ira",
    "irida": "iridare",
    "iridai": "iridare",
    "iridammo": "iridare",
    "iridan": "iridare",
    "iridando": "iridare",
    "iridano": "iridare",
    "iridante": "iridare",
    "iridanti": "iridare",
    "iridar": "iridare",
    "iridaron": "iridare",
    "iridarono": "iridare",
    "iridasse": "iridare",
    "iridasser": "iridare",
    "iridassero": "iridare",
    "iridassi": "iridare",
    "iridassimo": "iridare",
    "iridaste": "iridare",
    "iridasti": "iridare",
    "iridata": "iridato",
    "iridate": "iridato",
    "iridati": "iridato",
    "iridato": "iridare",
    "iridava": "iridare",
    "iridavamo": "iridare",
    "iridavan": "iridare",
    "iridavano": "iridare",
    "iridavate": "iridare",
    "iridavi": "iridare",
    "iridavo": "iridare",
    "iriderai": "iridare",
    "irideran": "iridare",
    "irideranno": "iridare",
    "iriderebbe": "iridare",
    "iriderebber": "iridare",
    "iriderebbero": "iridare",
    "iriderei": "iridare",
    "irideremmo": "iridare",
    "irideremo": "iridare",
    "iridereste": "iridare",
    "irideresti": "iridare",
    "iriderete": "iridare",
    "iriderà": "iridare",
    "iriderò": "iridare",
    "iridescenti": "iridescente",
    "iridescenze": "iridescenza",
    "iridi": "iridare",
    "iridiamo": "iridare",
    "iridiate": "iridare",
    "iridin": "iridare",
    "iridino": "iridare",
    "irido": "iridare",
    "iridò": "iridare",
    "irizza": "irizzare",
    "irizzai": "irizzare",
    "irizzammo": "irizzare",
    "irizzan": "irizzare",
    "irizzando": "irizzare",
    "irizzano": "irizzare",
    "irizzante": "irizzare",
    "irizzanti": "irizzare",
    "irizzar": "irizzare",
    "irizzaron": "irizzare",
    "irizzarono": "irizzare",
    "irizzasse": "irizzare",
    "irizzasser": "irizzare",
    "irizzassero": "irizzare",
    "irizzassi": "irizzare",
    "irizzassimo": "irizzare",
    "irizzaste": "irizzare",
    "irizzasti": "irizzare",
    "irizzata": "irizzare",
    "irizzate": "irizzare",
    "irizzati": "irizzare",
    "irizzato": "irizzare",
    "irizzava": "irizzare",
    "irizzavamo": "irizzare",
    "irizzavan": "irizzare",
    "irizzavano": "irizzare",
    "irizzavate": "irizzare",
    "irizzavi": "irizzare",
    "irizzavo": "irizzare",
    "irizzerai": "irizzare",
    "irizzeran": "irizzare",
    "irizzeranno": "irizzare",
    "irizzerebbe": "irizzare",
    "irizzerebber": "irizzare",
    "irizzerebbero": "irizzare",
    "irizzerei": "irizzare",
    "irizzeremmo": "irizzare",
    "irizzeremo": "irizzare",
    "irizzereste": "irizzare",
    "irizzeresti": "irizzare",
    "irizzerete": "irizzare",
    "irizzerà": "irizzare",
    "irizzerò": "irizzare",
    "irizzi": "irizzare",
    "irizziamo": "irizzare",
    "irizziate": "irizzare",
    "irizzin": "irizzare",
    "irizzino": "irizzare",
    "irizzo": "irizzare",
    "irizzò": "irizzare",
    "irlandesi": "irlandese",
    "ironica": "ironico",
    "ironiche": "ironico",
    "ironici": "ironico",
    "ironie": "ironia",
    "ironizza": "ironizzare",
    "ironizzai": "ironizzare",
    "ironizzammo": "ironizzare",
    "ironizzan": "ironizzare",
    "ironizzando": "ironizzare",
    "ironizzano": "ironizzare",
    "ironizzante": "ironizzare",
    "ironizzanti": "ironizzare",
    "ironizzar": "ironizzare",
    "ironizzaron": "ironizzare",
    "ironizzarono": "ironizzare",
    "ironizzasse": "ironizzare",
    "ironizzasser": "ironizzare",
    "ironizzassero": "ironizzare",
    "ironizzassi": "ironizzare",
    "ironizzassimo": "ironizzare",
    "ironizzaste": "ironizzare",
    "ironizzasti": "ironizzare",
    "ironizzata": "ironizzare",
    "ironizzate": "ironizzare",
    "ironizzati": "ironizzare",
    "ironizzato": "ironizzare",
    "ironizzava": "ironizzare",
    "ironizzavamo": "ironizzare",
    "ironizzavan": "ironizzare",
    "ironizzavano": "ironizzare",
    "ironizzavate": "ironizzare",
    "ironizzavi": "ironizzare",
    "ironizzavo": "ironizzare",
    "ironizzerai": "ironizzare",
    "ironizzeran": "ironizzare",
    "ironizzeranno": "ironizzare",
    "ironizzerebbe": "ironizzare",
    "ironizzerebber": "ironizzare",
    "ironizzerebbero": "ironizzare",
    "ironizzerei": "ironizzare",
    "ironizzeremmo": "ironizzare",
    "ironizzeremo": "ironizzare",
    "ironizzereste": "ironizzare",
    "ironizzeresti": "ironizzare",
    "ironizzerete": "ironizzare",
    "ironizzerà": "ironizzare",
    "ironizzerò": "ironizzare",
    "ironizzi": "ironizzare",
    "ironizziamo": "ironizzare",
    "ironizziate": "ironizzare",
    "ironizzin": "ironizzare",
    "ironizzino": "ironizzare",
    "ironizzo": "ironizzare",
    "ironizzò": "ironizzare",
    "irosa": "iroso",
    "irose": "iroso",
    "irosi": "iroso",
    "irpini": "irpino",
    "irradi": "irradiare",
    "irradia": "irradiare",
    "irradiai": "irradiare",
    "irradiammo": "irradiare",
    "irradiamo": "irradiare",
    "irradian": "irradiare",
    "irradiando": "irradiare",
    "irradiano": "irradiare",
    "irradiante": "irradiare",
    "irradianti": "irradiare",
    "irradiar": "irradiare",
    "irradiaron": "irradiare",
    "irradiarono": "irradiare",
    "irradiasse": "irradiare",
    "irradiasser": "irradiare",
    "irradiassero": "irradiare",
    "irradiassi": "irradiare",
    "irradiassimo": "irradiare",
    "irradiaste": "irradiare",
    "irradiasti": "irradiare",
    "irradiata": "irradiare",
    "irradiate": "irradiare",
    "irradiati": "irradiare",
    "irradiato": "irradiare",
    "irradiava": "irradiare",
    "irradiavamo": "irradiare",
    "irradiavan": "irradiare",
    "irradiavano": "irradiare",
    "irradiavate": "irradiare",
    "irradiavi": "irradiare",
    "irradiavo": "irradiare",
    "irradiazioni": "irradiazione",
    "irradierai": "irradiare",
    "irradieran": "irradiare",
    "irradieranno": "irradiare",
    "irradierebbe": "irradiare",
    "irradierebber": "irradiare",
    "irradierebbero": "irradiare",
    "irradierei": "irradiare",
    "irradieremmo": "irradiare",
    "irradieremo": "irradiare",
    "irradiereste": "irradiare",
    "irradieresti": "irradiare",
    "irradierete": "irradiare",
    "irradierà": "irradiare",
    "irradierò": "irradiare",
    "irradin": "irradiare",
    "irradino": "irradiare",
    "irradio": "irradiare",
    "irradiò": "irradiare",
    "irraggerai": "irraggiare",
    "irraggeran": "irraggiare",
    "irraggeranno": "irraggiare",
    "irraggerebbe": "irraggiare",
    "irraggerebber": "irraggiare",
    "irraggerebbero": "irraggiare",
    "irraggerei": "irraggiare",
    "irraggeremmo": "irraggiare",
    "irraggeremo": "irraggiare",
    "irraggereste": "irraggiare",
    "irraggeresti": "irraggiare",
    "irraggerete": "irraggiare",
    "irraggerà": "irraggiare",
    "irraggerò": "irraggiare",
    "irraggi": "irraggiare",
    "irraggia": "irraggiare",
    "irraggiai": "irraggiare",
    "irraggiammo": "irraggiare",
    "irraggiamo": "irraggiare",
    "irraggian": "irraggiare",
    "irraggiando": "irraggiare",
    "irraggiano": "irraggiare",
    "irraggiante": "irraggiare",
    "irraggianti": "irraggiare",
    "irraggiar": "irraggiare",
    "irraggiaron": "irraggiare",
    "irraggiarono": "irraggiare",
    "irraggiasse": "irraggiare",
    "irraggiasser": "irraggiare",
    "irraggiassero": "irraggiare",
    "irraggiassi": "irraggiare",
    "irraggiassimo": "irraggiare",
    "irraggiaste": "irraggiare",
    "irraggiasti": "irraggiare",
    "irraggiata": "irraggiare",
    "irraggiate": "irraggiare",
    "irraggiati": "irraggiare",
    "irraggiato": "irraggiare",
    "irraggiava": "irraggiare",
    "irraggiavamo": "irraggiare",
    "irraggiavan": "irraggiare",
    "irraggiavano": "irraggiare",
    "irraggiavate": "irraggiare",
    "irraggiavi": "irraggiare",
    "irraggiavo": "irraggiare",
    "irraggin": "irraggiare",
    "irraggino": "irraggiare",
    "irraggio": "irraggiare",
    "irraggiungibili": "irraggiungibile",
    "irraggiò": "irraggiare",
    "irragionevoli": "irragionevole",
    "irrancida": "irrancidire",
    "irrancidan": "irrancidire",
    "irrancidano": "irrancidire",
    "irrancide": "irrancidire",
    "irrancidendo": "irrancidire",
    "irrancidente": "irrancidire",
    "irrancidenti": "irrancidire",
    "irrancidi": "irrancidire",
    "irrancidiamo": "irrancidire",
    "irrancidiate": "irrancidire",
    "irrancidii": "irrancidire",
    "irrancidimmo": "irrancidire",
    "irrancidir": "irrancidire",
    "irrancidirai": "irrancidire",
    "irrancidiran": "irrancidire",
    "irrancidiranno": "irrancidire",
    "irrancidirebbe": "irrancidire",
    "irrancidirebber": "irrancidire",
    "irrancidirebbero": "irrancidire",
    "irrancidirei": "irrancidire",
    "irrancidiremmo": "irrancidire",
    "irrancidiremo": "irrancidire",
    "irrancidireste": "irrancidire",
    "irrancidiresti": "irrancidire",
    "irrancidirete": "irrancidire",
    "irrancidiron": "irrancidire",
    "irrancidirono": "irrancidire",
    "irrancidirà": "irrancidire",
    "irrancidirò": "irrancidire",
    "irrancidisse": "irrancidire",
    "irrancidisser": "irrancidire",
    "irrancidissero": "irrancidire",
    "irrancidissi": "irrancidire",
    "irrancidissimo": "irrancidire",
    "irrancidiste": "irrancidire",
    "irrancidisti": "irrancidire",
    "irrancidita": "irrancidire",
    "irrancidite": "irrancidire",
    "irranciditi": "irrancidire",
    "irrancidito": "irrancidire",
    "irrancidiva": "irrancidire",
    "irrancidivamo": "irrancidire",
    "irrancidivan": "irrancidire",
    "irrancidivano": "irrancidire",
    "irrancidivate": "irrancidire",
    "irrancidivi": "irrancidire",
    "irrancidivo": "irrancidire",
    "irrancido": "irrancidire",
    "irrancidon": "irrancidire",
    "irrancidono": "irrancidire",
    "irrancidì": "irrancidire",
    "irrazionali": "irrazionale",
    "irrazionalismi": "irrazionalismo",
    "irreali": "irreale",
    "irrealistica": "irrealistico",
    "irrealistiche": "irrealistico",
    "irrealistici": "irrealistico",
    "irrealizzabili": "irrealizzabile",
    "irrecuperabili": "irrecuperabile",
    "irredenta": "irredento",
    "irredente": "irredento",
    "irredenti": "irredento",
    "irredentismi": "irredentismo",
    "irredentiste": "irredentista",
    "irredentisti": "irredentista",
    "irredentistica": "irredentistico",
    "irredentistiche": "irredentistico",
    "irredentistici": "irredentistico",
    "irrefrenabili": "irrefrenabile",
    "irrefutabili": "irrefutabile",
    "irreggimenta": "irreggimentare",
    "irreggimentai": "irreggimentare",
    "irreggimentammo": "irreggimentare",
    "irreggimentan": "irreggimentare",
    "irreggimentando": "irreggimentare",
    "irreggimentano": "irreggimentare",
    "irreggimentante": "irreggimentare",
    "irreggimentanti": "irreggimentare",
    "irreggimentar": "irreggimentare",
    "irreggimentaron": "irreggimentare",
    "irreggimentarono": "irreggimentare",
    "irreggimentasse": "irreggimentare",
    "irreggimentasser": "irreggimentare",
    "irreggimentassero": "irreggimentare",
    "irreggimentassi": "irreggimentare",
    "irreggimentassimo": "irreggimentare",
    "irreggimentaste": "irreggimentare",
    "irreggimentasti": "irreggimentare",
    "irreggimentata": "irreggimentare",
    "irreggimentate": "irreggimentare",
    "irreggimentati": "irreggimentare",
    "irreggimentato": "irreggimentare",
    "irreggimentava": "irreggimentare",
    "irreggimentavamo": "irreggimentare",
    "irreggimentavan": "irreggimentare",
    "irreggimentavano": "irreggimentare",
    "irreggimentavate": "irreggimentare",
    "irreggimentavi": "irreggimentare",
    "irreggimentavo": "irreggimentare",
    "irreggimenterai": "irreggimentare",
    "irreggimenteran": "irreggimentare",
    "irreggimenteranno": "irreggimentare",
    "irreggimenterebbe": "irreggimentare",
    "irreggimenterebber": "irreggimentare",
    "irreggimenterebbero": "irreggimentare",
    "irreggimenterei": "irreggimentare",
    "irreggimenteremmo": "irreggimentare",
    "irreggimenteremo": "irreggimentare",
    "irreggimentereste": "irreggimentare",
    "irreggimenteresti": "irreggimentare",
    "irreggimenterete": "irreggimentare",
    "irreggimenterà": "irreggimentare",
    "irreggimenterò": "irreggimentare",
    "irreggimenti": "irreggimentare",
    "irreggimentiamo": "irreggimentare",
    "irreggimentiate": "irreggimentare",
    "irreggimentin": "irreggimentare",
    "irreggimentino": "irreggimentare",
    "irreggimento": "irreggimentare",
    "irreggimentò": "irreggimentare",
    "irregola": "irregolare",
    "irregolai": "irregolare",
    "irregolammo": "irregolare",
    "irregolan": "irregolare",
    "irregolando": "irregolare",
    "irregolano": "irregolare",
    "irregolante": "irregolare",
    "irregolanti": "irregolare",
    "irregolar": "irregolare",
    "irregolari": "irregolare",
    "irregolaron": "irregolare",
    "irregolarono": "irregolare",
    "irregolasse": "irregolare",
    "irregolasser": "irregolare",
    "irregolassero": "irregolare",
    "irregolassi": "irregolare",
    "irregolassimo": "irregolare",
    "irregolaste": "irregolare",
    "irregolasti": "irregolare",
    "irregolata": "irregolare",
    "irregolate": "irregolare",
    "irregolati": "irregolare",
    "irregolato": "irregolare",
    "irregolava": "irregolare",
    "irregolavamo": "irregolare",
    "irregolavan": "irregolare",
    "irregolavano": "irregolare",
    "irregolavate": "irregolare",
    "irregolavi": "irregolare",
    "irregolavo": "irregolare",
    "irregolerai": "irregolare",
    "irregoleran": "irregolare",
    "irregoleranno": "irregolare",
    "irregolerebbe": "irregolare",
    "irregolerebber": "irregolare",
    "irregolerebbero": "irregolare",
    "irregolerei": "irregolare",
    "irregoleremmo": "irregolare",
    "irregoleremo": "irregolare",
    "irregolereste": "irregolare",
    "irregoleresti": "irregolare",
    "irregolerete": "irregolare",
    "irregolerà": "irregolare",
    "irregolerò": "irregolare",
    "irregoli": "irregolare",
    "irregoliamo": "irregolare",
    "irregoliate": "irregolare",
    "irregolin": "irregolare",
    "irregolino": "irregolare",
    "irregolo": "irregolare",
    "irregolò": "irregolare",
    "irrelata": "irrelato",
    "irrelate": "irrelato",
    "irrelati": "irrelato",
    "irremovibili": "irremovibile",
    "irreparabili": "irreparabile",
    "irreperibili": "irreperibile",
    "irreprensibili": "irreprensibile",
    "irrequieta": "irrequieto",
    "irrequiete": "irrequieto",
    "irrequietezze": "irrequietezza",
    "irrequieti": "irrequieto",
    "irresistibili": "irresistibile",
    "irresolubili": "irresolubile",
    "irresoluta": "irresoluto",
    "irresolute": "irresoluto",
    "irresoluti": "irresoluto",
    "irrespirabili": "irrespirabile",
    "irresponsabili": "irresponsabile",
    "irreta": "irretire",
    "irretan": "irretire",
    "irretano": "irretire",
    "irrete": "irretire",
    "irretendo": "irretire",
    "irretente": "irretire",
    "irretenti": "irretire",
    "irreti": "irretire",
    "irretiamo": "irretire",
    "irretiate": "irretire",
    "irretii": "irretire",
    "irretimmo": "irretire",
    "irretir": "irretire",
    "irretirai": "irretire",
    "irretiran": "irretire",
    "irretiranno": "irretire",
    "irretirebbe": "irretire",
    "irretirebber": "irretire",
    "irretirebbero": "irretire",
    "irretirei": "irretire",
    "irretiremmo": "irretire",
    "irretiremo": "irretire",
    "irretireste": "irretire",
    "irretiresti": "irretire",
    "irretirete": "irretire",
    "irretiron": "irretire",
    "irretirono": "irretire",
    "irretirà": "irretire",
    "irretirò": "irretire",
    "irretisse": "irretire",
    "irretisser": "irretire",
    "irretissero": "irretire",
    "irretissi": "irretire",
    "irretissimo": "irretire",
    "irretiste": "irretire",
    "irretisti": "irretire",
    "irretita": "irretire",
    "irretite": "irretire",
    "irretiti": "irretire",
    "irretito": "irretire",
    "irretiva": "irretire",
    "irretivamo": "irretire",
    "irretivan": "irretire",
    "irretivano": "irretire",
    "irretivate": "irretire",
    "irretivi": "irretire",
    "irretivo": "irretire",
    "irreto": "irretire",
    "irreton": "irretire",
    "irretono": "irretire",
    "irretì": "irretire",
    "irreversibili": "irreversibile",
    "irrevocabili": "irrevocabile",
    "irricevibili": "irricevibile",
    "irriconoscibili": "irriconoscibile",
    "irrida": "irridire",
    "irridan": "irridire",
    "irridano": "irridire",
    "irride": "irridire",
    "irridei": "irridere",
    "irridemmo": "irridere",
    "irridendo": "irridire",
    "irridente": "irridire",
    "irridenti": "irridire",
    "irrider": "irridere",
    "irriderai": "irridere",
    "irrideran": "irridere",
    "irrideranno": "irridere",
    "irriderebbe": "irridere",
    "irriderebber": "irridere",
    "irriderebbero": "irridere",
    "irriderei": "irridere",
    "irrideremmo": "irridere",
    "irrideremo": "irridere",
    "irridereste": "irridere",
    "irrideresti": "irridere",
    "irriderete": "irridere",
    "irrideron": "irridere",
    "irriderono": "irridere",
    "irriderà": "irridere",
    "irriderò": "irridere",
    "irridesse": "irridere",
    "irridesser": "irridere",
    "irridessero": "irridere",
    "irridessi": "irridere",
    "irridessimo": "irridere",
    "irrideste": "irridere",
    "irridesti": "irridere",
    "irridete": "irridere",
    "irrideva": "irridere",
    "irridevamo": "irridere",
    "irridevan": "irridere",
    "irridevano": "irridere",
    "irridevate": "irridere",
    "irridevi": "irridere",
    "irridevo": "irridere",
    "irridi": "irridire",
    "irridiamo": "irridire",
    "irridiate": "irridire",
    "irridii": "irridire",
    "irridimmo": "irridire",
    "irridir": "irridire",
    "irridirai": "irridire",
    "irridiran": "irridire",
    "irridiranno": "irridire",
    "irridirebbe": "irridire",
    "irridirebber": "irridire",
    "irridirebbero": "irridire",
    "irridirei": "irridire",
    "irridiremmo": "irridire",
    "irridiremo": "irridire",
    "irridireste": "irridire",
    "irridiresti": "irridire",
    "irridirete": "irridire",
    "irridiron": "irridire",
    "irridirono": "irridire",
    "irridirà": "irridire",
    "irridirò": "irridire",
    "irridisse": "irridire",
    "irridisser": "irridire",
    "irridissero": "irridire",
    "irridissi": "irridire",
    "irridissimo": "irridire",
    "irridiste": "irridire",
    "irridisti": "irridire",
    "irridita": "irridire",
    "irridite": "irridire",
    "irriditi": "irridire",
    "irridito": "irridire",
    "irridiva": "irridire",
    "irridivamo": "irridire",
    "irridivan": "irridire",
    "irridivano": "irridire",
    "irridivate": "irridire",
    "irridivi": "irridire",
    "irridivo": "irridire",
    "irrido": "irridire",
    "irridon": "irridire",
    "irridono": "irridire",
    "irriducibili": "irriducibile",
    "irriduta": "irridere",
    "irridute": "irridere",
    "irriduti": "irridere",
    "irriduto": "irridere",
    "irridè": "irridere",
    "irridì": "irridire",
    "irriga": "irrigare",
    "irrigai": "irrigare",
    "irrigammo": "irrigare",
    "irrigan": "irrigare",
    "irrigando": "irrigare",
    "irrigano": "irrigare",
    "irrigante": "irrigare",
    "irriganti": "irrigare",
    "irrigar": "irrigare",
    "irrigaron": "irrigare",
    "irrigarono": "irrigare",
    "irrigasse": "irrigare",
    "irrigasser": "irrigare",
    "irrigassero": "irrigare",
    "irrigassi": "irrigare",
    "irrigassimo": "irrigare",
    "irrigaste": "irrigare",
    "irrigasti": "irrigare",
    "irrigata": "irrigare",
    "irrigate": "irrigare",
    "irrigati": "irrigare",
    "irrigato": "irrigare",
    "irrigava": "irrigare",
    "irrigavamo": "irrigare",
    "irrigavan": "irrigare",
    "irrigavano": "irrigare",
    "irrigavate": "irrigare",
    "irrigavi": "irrigare",
    "irrigavo": "irrigare",
    "irrigazioni": "irrigazione",
    "irrigherai": "irrigare",
    "irrigheran": "irrigare",
    "irrigheranno": "irrigare",
    "irrigherebbe": "irrigare",
    "irrigherebber": "irrigare",
    "irrigherebbero": "irrigare",
    "irrigherei": "irrigare",
    "irrigheremmo": "irrigare",
    "irrigheremo": "irrigare",
    "irrighereste": "irrigare",
    "irrigheresti": "irrigare",
    "irrigherete": "irrigare",
    "irrigherà": "irrigare",
    "irrigherò": "irrigare",
    "irrighi": "irrigare",
    "irrighiamo": "irrigare",
    "irrighiate": "irrigare",
    "irrighin": "irrigare",
    "irrighino": "irrigare",
    "irrigidendo": "irrigidire",
    "irrigidente": "irrigidire",
    "irrigidenti": "irrigidire",
    "irrigidiamo": "irrigidire",
    "irrigidiate": "irrigidire",
    "irrigidii": "irrigidire",
    "irrigidimenti": "irrigidimento",
    "irrigidimmo": "irrigidire",
    "irrigidir": "irrigidire",
    "irrigidirai": "irrigidire",
    "irrigidiran": "irrigidire",
    "irrigidiranno": "irrigidire",
    "irrigidirebbe": "irrigidire",
    "irrigidirebber": "irrigidire",
    "irrigidirebbero": "irrigidire",
    "irrigidirei": "irrigidire",
    "irrigidiremmo": "irrigidire",
    "irrigidiremo": "irrigidire",
    "irrigidireste": "irrigidire",
    "irrigidiresti": "irrigidire",
    "irrigidirete": "irrigidire",
    "irrigidiron": "irrigidire",
    "irrigidirono": "irrigidire",
    "irrigidirà": "irrigidire",
    "irrigidirò": "irrigidire",
    "irrigidisca": "irrigidire",
    "irrigidiscan": "irrigidire",
    "irrigidiscano": "irrigidire",
    "irrigidisce": "irrigidire",
    "irrigidisci": "irrigidire",
    "irrigidisco": "irrigidire",
    "irrigidiscon": "irrigidire",
    "irrigidiscono": "irrigidire",
    "irrigidisse": "irrigidire",
    "irrigidisser": "irrigidire",
    "irrigidissero": "irrigidire",
    "irrigidissi": "irrigidire",
    "irrigidissimo": "irrigidire",
    "irrigidiste": "irrigidire",
    "irrigidisti": "irrigidire",
    "irrigidita": "irrigidire",
    "irrigidite": "irrigidire",
    "irrigiditi": "irrigidire",
    "irrigidito": "irrigidire",
    "irrigidiva": "irrigidire",
    "irrigidivamo": "irrigidire",
    "irrigidivan": "irrigidire",
    "irrigidivano": "irrigidire",
    "irrigidivate": "irrigidire",
    "irrigidivi": "irrigidire",
    "irrigidivo": "irrigidire",
    "irrigidì": "irrigidire",
    "irrigo": "irrigare",
    "irrigua": "irriguo",
    "irriguardosa": "irriguardoso",
    "irriguardose": "irriguardoso",
    "irriguardosi": "irriguardoso",
    "irrigue": "irriguo",
    "irrigui": "irriguo",
    "irrigò": "irrigare",
    "irrilevanti": "irrilevante",
    "irrimediabili": "irrimediabile",
    "irrinunciabili": "irrinunciabile",
    "irripetibili": "irripetibile",
    "irrisioni": "irrisione",
    "irrisolta": "irrisolto",
    "irrisolte": "irrisolto",
    "irrisolti": "irrisolto",
    "irrisolvibili": "irrisolvibile",
    "irrisori": "irrisorio",
    "irrisoria": "irrisorio",
    "irrisorie": "irrisorio",
    "irrispettosa": "irrispettoso",
    "irrispettose": "irrispettoso",
    "irrispettosi": "irrispettoso",
    "irrita": "irrito",
    "irritabili": "irritabile",
    "irritai": "irritare",
    "irritammo": "irritare",
    "irritan": "irritare",
    "irritando": "irritare",
    "irritano": "irritare",
    "irritante": "irritare",
    "irritanti": "irritare",
    "irritar": "irritare",
    "irritaron": "irritare",
    "irritarono": "irritare",
    "irritasse": "irritare",
    "irritasser": "irritare",
    "irritassero": "irritare",
    "irritassi": "irritare",
    "irritassimo": "irritare",
    "irritaste": "irritare",
    "irritasti": "irritare",
    "irritata": "irritare",
    "irritate": "irritare",
    "irritati": "irritare",
    "irritato": "irritare",
    "irritava": "irritare",
    "irritavamo": "irritare",
    "irritavan": "irritare",
    "irritavano": "irritare",
    "irritavate": "irritare",
    "irritavi": "irritare",
    "irritavo": "irritare",
    "irritazioni": "irritazione",
    "irrite": "irrito",
    "irriterai": "irritare",
    "irriteran": "irritare",
    "irriteranno": "irritare",
    "irriterebbe": "irritare",
    "irriterebber": "irritare",
    "irriterebbero": "irritare",
    "irriterei": "irritare",
    "irriteremmo": "irritare",
    "irriteremo": "irritare",
    "irritereste": "irritare",
    "irriteresti": "irritare",
    "irriterete": "irritare",
    "irriterà": "irritare",
    "irriterò": "irritare",
    "irriti": "irrito",
    "irritiamo": "irritare",
    "irritiate": "irritare",
    "irritin": "irritare",
    "irritino": "irritare",
    "irrito": "irritare",
    "irritò": "irritare",
    "irriverenti": "irriverente",
    "irriverenze": "irriverenza",
    "irrobustendo": "irrobustire",
    "irrobustente": "irrobustire",
    "irrobustenti": "irrobustire",
    "irrobustiamo": "irrobustire",
    "irrobustiate": "irrobustire",
    "irrobustii": "irrobustire",
    "irrobustimmo": "irrobustire",
    "irrobustir": "irrobustire",
    "irrobustirai": "irrobustire",
    "irrobustiran": "irrobustire",
    "irrobustiranno": "irrobustire",
    "irrobustirebbe": "irrobustire",
    "irrobustirebber": "irrobustire",
    "irrobustirebbero": "irrobustire",
    "irrobustirei": "irrobustire",
    "irrobustiremmo": "irrobustire",
    "irrobustiremo": "irrobustire",
    "irrobustireste": "irrobustire",
    "irrobustiresti": "irrobustire",
    "irrobustirete": "irrobustire",
    "irrobustiron": "irrobustire",
    "irrobustirono": "irrobustire",
    "irrobustirà": "irrobustire",
    "irrobustirò": "irrobustire",
    "irrobustisca": "irrobustire",
    "irrobustiscan": "irrobustire",
    "irrobustiscano": "irrobustire",
    "irrobustisce": "irrobustire",
    "irrobustisci": "irrobustire",
    "irrobustisco": "irrobustire",
    "irrobustiscon": "irrobustire",
    "irrobustiscono": "irrobustire",
    "irrobustisse": "irrobustire",
    "irrobustisser": "irrobustire",
    "irrobustissero": "irrobustire",
    "irrobustissi": "irrobustire",
    "irrobustissimo": "irrobustire",
    "irrobustiste": "irrobustire",
    "irrobustisti": "irrobustire",
    "irrobustita": "irrobustire",
    "irrobustite": "irrobustire",
    "irrobustiti": "irrobustire",
    "irrobustito": "irrobustire",
    "irrobustiva": "irrobustire",
    "irrobustivamo": "irrobustire",
    "irrobustivan": "irrobustire",
    "irrobustivano": "irrobustire",
    "irrobustivate": "irrobustire",
    "irrobustivi": "irrobustire",
    "irrobustivo": "irrobustire",
    "irrobustì": "irrobustire",
    "irroga": "irrogare",
    "irrogai": "irrogare",
    "irrogammo": "irrogare",
    "irrogan": "irrogare",
    "irrogando": "irrogare",
    "irrogano": "irrogare",
    "irrogante": "irrogare",
    "irroganti": "irrogare",
    "irrogar": "irrogare",
    "irrogaron": "irrogare",
    "irrogarono": "irrogare",
    "irrogasse": "irrogare",
    "irrogasser": "irrogare",
    "irrogassero": "irrogare",
    "irrogassi": "irrogare",
    "irrogassimo": "irrogare",
    "irrogaste": "irrogare",
    "irrogasti": "irrogare",
    "irrogata": "irrogare",
    "irrogate": "irrogare",
    "irrogati": "irrogare",
    "irrogato": "irrogare",
    "irrogava": "irrogare",
    "irrogavamo": "irrogare",
    "irrogavan": "irrogare",
    "irrogavano": "irrogare",
    "irrogavate": "irrogare",
    "irrogavi": "irrogare",
    "irrogavo": "irrogare",
    "irrogherai": "irrogare",
    "irrogheran": "irrogare",
    "irrogheranno": "irrogare",
    "irrogherebbe": "irrogare",
    "irrogherebber": "irrogare",
    "irrogherebbero": "irrogare",
    "irrogherei": "irrogare",
    "irrogheremmo": "irrogare",
    "irrogheremo": "irrogare",
    "irroghereste": "irrogare",
    "irrogheresti": "irrogare",
    "irrogherete": "irrogare",
    "irrogherà": "irrogare",
    "irrogherò": "irrogare",
    "irroghi": "irrogare",
    "irroghiamo": "irrogare",
    "irroghiate": "irrogare",
    "irroghin": "irrogare",
    "irroghino": "irrogare",
    "irrogo": "irrogare",
    "irrogò": "irrogare",
    "irrompa": "irrompere",
    "irrompan": "irrompere",
    "irrompano": "irrompere",
    "irrompe": "irrompere",
    "irrompemmo": "irrompere",
    "irrompendo": "irrompere",
    "irrompente": "irrompere",
    "irrompenti": "irrompere",
    "irromper": "irrompere",
    "irromperai": "irrompere",
    "irromperan": "irrompere",
    "irromperanno": "irrompere",
    "irromperebbe": "irrompere",
    "irromperebber": "irrompere",
    "irromperebbero": "irrompere",
    "irromperei": "irrompere",
    "irromperemmo": "irrompere",
    "irromperemo": "irrompere",
    "irrompereste": "irrompere",
    "irromperesti": "irrompere",
    "irromperete": "irrompere",
    "irromperà": "irrompere",
    "irromperò": "irrompere",
    "irrompesse": "irrompere",
    "irrompesser": "irrompere",
    "irrompessero": "irrompere",
    "irrompessi": "irrompere",
    "irrompessimo": "irrompere",
    "irrompeste": "irrompere",
    "irrompesti": "irrompere",
    "irrompete": "irrompere",
    "irrompeva": "irrompere",
    "irrompevamo": "irrompere",
    "irrompevan": "irrompere",
    "irrompevano": "irrompere",
    "irrompevate": "irrompere",
    "irrompevi": "irrompere",
    "irrompevo": "irrompere",
    "irrompi": "irrompere",
    "irrompiamo": "irrompere",
    "irrompiate": "irrompere",
    "irrompo": "irrompere",
    "irrompon": "irrompere",
    "irrompono": "irrompere",
    "irrora": "irrorare",
    "irrorai": "irrorare",
    "irrorammo": "irrorare",
    "irroran": "irrorare",
    "irrorando": "irrorare",
    "irrorano": "irrorare",
    "irrorante": "irrorare",
    "irroranti": "irrorare",
    "irrorar": "irrorare",
    "irroraron": "irrorare",
    "irrorarono": "irrorare",
    "irrorasse": "irrorare",
    "irrorasser": "irrorare",
    "irrorassero": "irrorare",
    "irrorassi": "irrorare",
    "irrorassimo": "irrorare",
    "irroraste": "irrorare",
    "irrorasti": "irrorare",
    "irrorata": "irrorare",
    "irrorate": "irrorare",
    "irrorati": "irrorare",
    "irrorato": "irrorare",
    "irrorava": "irrorare",
    "irroravamo": "irrorare",
    "irroravan": "irrorare",
    "irroravano": "irrorare",
    "irroravate": "irrorare",
    "irroravi": "irrorare",
    "irroravo": "irrorare",
    "irrorerai": "irrorare",
    "irroreran": "irrorare",
    "irroreranno": "irrorare",
    "irrorerebbe": "irrorare",
    "irrorerebber": "irrorare",
    "irrorerebbero": "irrorare",
    "irrorerei": "irrorare",
    "irroreremmo": "irrorare",
    "irroreremo": "irrorare",
    "irrorereste": "irrorare",
    "irroreresti": "irrorare",
    "irrorerete": "irrorare",
    "irrorerà": "irrorare",
    "irrorerò": "irrorare",
    "irrori": "irrorare",
    "irroriamo": "irrorare",
    "irroriate": "irrorare",
    "irrorin": "irrorare",
    "irrorino": "irrorare",
    "irroro": "irrorare",
    "irrorò": "irrorare",
    "irrotta": "irrompere",
    "irrotte": "irrompere",
    "irrotti": "irrompere",
    "irrotto": "irrompere",
    "irruenta": "irruento",
    "irruente": "irruento",
    "irruenti": "irruento",
    "irruenze": "irruenza",
    "irruppe": "irrompere",
    "irrupper": "irrompere",
    "irruppero": "irrompere",
    "irruppi": "irrompere",
    "irruvida": "irruvidire",
    "irruvidan": "irruvidire",
    "irruvidano": "irruvidire",
    "irruvide": "irruvidire",
    "irruvidendo": "irruvidire",
    "irruvidente": "irruvidire",
    "irruvidenti": "irruvidire",
    "irruvidi": "irruvidire",
    "irruvidiamo": "irruvidire",
    "irruvidiate": "irruvidire",
    "irruvidii": "irruvidire",
    "irruvidimmo": "irruvidire",
    "irruvidir": "irruvidire",
    "irruvidirai": "irruvidire",
    "irruvidiran": "irruvidire",
    "irruvidiranno": "irruvidire",
    "irruvidirebbe": "irruvidire",
    "irruvidirebber": "irruvidire",
    "irruvidirebbero": "irruvidire",
    "irruvidirei": "irruvidire",
    "irruvidiremmo": "irruvidire",
    "irruvidiremo": "irruvidire",
    "irruvidireste": "irruvidire",
    "irruvidiresti": "irruvidire",
    "irruvidirete": "irruvidire",
    "irruvidiron": "irruvidire",
    "irruvidirono": "irruvidire",
    "irruvidirà": "irruvidire",
    "irruvidirò": "irruvidire",
    "irruvidisse": "irruvidire",
    "irruvidisser": "irruvidire",
    "irruvidissero": "irruvidire",
    "irruvidissi": "irruvidire",
    "irruvidissimo": "irruvidire",
    "irruvidiste": "irruvidire",
    "irruvidisti": "irruvidire",
    "irruvidita": "irruvidire",
    "irruvidite": "irruvidire",
    "irruviditi": "irruvidire",
    "irruvidito": "irruvidire",
    "irruvidiva": "irruvidire",
    "irruvidivamo": "irruvidire",
    "irruvidivan": "irruvidire",
    "irruvidivano": "irruvidire",
    "irruvidivate": "irruvidire",
    "irruvidivi": "irruvidire",
    "irruvidivo": "irruvidire",
    "irruvido": "irruvidire",
    "irruvidon": "irruvidire",
    "irruvidono": "irruvidire",
    "irruvidì": "irruvidire",
    "irruzioni": "irruzione",
    "irsuta": "irsuto",
    "irsute": "irsuto",
    "irsuti": "irsuto",
    "irta": "irto",
    "irte": "irto",
    "irti": "irto",
    "isbe": "isba",
    "ischeletra": "ischeletrire",
    "ischeletran": "ischeletrire",
    "ischeletrano": "ischeletrire",
    "ischeletre": "ischeletrire",
    "ischeletrendo": "ischeletrire",
    "ischeletrente": "ischeletrire",
    "ischeletrenti": "ischeletrire",
    "ischeletri": "ischeletrire",
    "ischeletriamo": "ischeletrire",
    "ischeletriate": "ischeletrire",
    "ischeletrii": "ischeletrire",
    "ischeletrimmo": "ischeletrire",
    "ischeletrir": "ischeletrire",
    "ischeletrirai": "ischeletrire",
    "ischeletriran": "ischeletrire",
    "ischeletriranno": "ischeletrire",
    "ischeletrirebbe": "ischeletrire",
    "ischeletrirebber": "ischeletrire",
    "ischeletrirebbero": "ischeletrire",
    "ischeletrirei": "ischeletrire",
    "ischeletriremmo": "ischeletrire",
    "ischeletriremo": "ischeletrire",
    "ischeletrireste": "ischeletrire",
    "ischeletriresti": "ischeletrire",
    "ischeletrirete": "ischeletrire",
    "ischeletriron": "ischeletrire",
    "ischeletrirono": "ischeletrire",
    "ischeletrirà": "ischeletrire",
    "ischeletrirò": "ischeletrire",
    "ischeletrisse": "ischeletrire",
    "ischeletrisser": "ischeletrire",
    "ischeletrissero": "ischeletrire",
    "ischeletrissi": "ischeletrire",
    "ischeletrissimo": "ischeletrire",
    "ischeletriste": "ischeletrire",
    "ischeletristi": "ischeletrire",
    "ischeletrita": "ischeletrire",
    "ischeletrite": "ischeletrire",
    "ischeletriti": "ischeletrire",
    "ischeletrito": "ischeletrire",
    "ischeletriva": "ischeletrire",
    "ischeletrivamo": "ischeletrire",
    "ischeletrivan": "ischeletrire",
    "ischeletrivano": "ischeletrire",
    "ischeletrivate": "ischeletrire",
    "ischeletrivi": "ischeletrire",
    "ischeletrivo": "ischeletrire",
    "ischeletro": "ischeletrire",
    "ischeletron": "ischeletrire",
    "ischeletrono": "ischeletrire",
    "ischeletrì": "ischeletrire",
    "ischemie": "ischemia",
    "ischitana": "ischitano",
    "ischitane": "ischitano",
    "ischitani": "ischitano",
    "iscrisse": "iscrivere",
    "iscrisser": "iscrivere",
    "iscrissero": "iscrivere",
    "iscrissi": "iscrivere",
    "iscritta": "iscrivere",
    "iscritte": "iscrivere",
    "iscritti": "iscrivere",
    "iscritto": "iscrivere",
    "iscriva": "iscrivere",
    "iscrivan": "iscrivere",
    "iscrivano": "iscrivere",
    "iscrive": "iscrivere",
    "iscrivemmo": "iscrivere",
    "iscrivendo": "iscrivere",
    "iscrivente": "iscrivere",
    "iscriventi": "iscrivere",
    "iscriver": "iscrivere",
    "iscriverai": "iscrivere",
    "iscriveran": "iscrivere",
    "iscriveranno": "iscrivere",
    "iscriverebbe": "iscrivere",
    "iscriverebber": "iscrivere",
    "iscriverebbero": "iscrivere",
    "iscriverei": "iscrivere",
    "iscriveremmo": "iscrivere",
    "iscriveremo": "iscrivere",
    "iscrivereste": "iscrivere",
    "iscriveresti": "iscrivere",
    "iscriverete": "iscrivere",
    "iscriverà": "iscrivere",
    "iscriverò": "iscrivere",
    "iscrivesse": "iscrivere",
    "iscrivesser": "iscrivere",
    "iscrivessero": "iscrivere",
    "iscrivessi": "iscrivere",
    "iscrivessimo": "iscrivere",
    "iscriveste": "iscrivere",
    "iscrivesti": "iscrivere",
    "iscrivete": "iscrivere",
    "iscriveva": "iscrivere",
    "iscrivevamo": "iscrivere",
    "iscrivevan": "iscrivere",
    "iscrivevano": "iscrivere",
    "iscrivevate": "iscrivere",
    "iscrivevi": "iscrivere",
    "iscrivevo": "iscrivere",
    "iscrivi": "iscrivere",
    "iscriviamo": "iscrivere",
    "iscriviate": "iscrivere",
    "iscrivo": "iscrivere",
    "iscrivon": "iscrivere",
    "iscrivono": "iscrivere",
    "iscrizioni": "iscrizione",
    "islamica": "islamico",
    "islamiche": "islamico",
    "islamici": "islamico",
    "islamisti": "islamista",
    "islamizza": "islamizzare",
    "islamizzai": "islamizzare",
    "islamizzammo": "islamizzare",
    "islamizzan": "islamizzare",
    "islamizzando": "islamizzare",
    "islamizzano": "islamizzare",
    "islamizzante": "islamizzare",
    "islamizzanti": "islamizzare",
    "islamizzar": "islamizzare",
    "islamizzaron": "islamizzare",
    "islamizzarono": "islamizzare",
    "islamizzasse": "islamizzare",
    "islamizzasser": "islamizzare",
    "islamizzassero": "islamizzare",
    "islamizzassi": "islamizzare",
    "islamizzassimo": "islamizzare",
    "islamizzaste": "islamizzare",
    "islamizzasti": "islamizzare",
    "islamizzata": "islamizzare",
    "islamizzate": "islamizzare",
    "islamizzati": "islamizzare",
    "islamizzato": "islamizzare",
    "islamizzava": "islamizzare",
    "islamizzavamo": "islamizzare",
    "islamizzavan": "islamizzare",
    "islamizzavano": "islamizzare",
    "islamizzavate": "islamizzare",
    "islamizzavi": "islamizzare",
    "islamizzavo": "islamizzare",
    "islamizzerai": "islamizzare",
    "islamizzeran": "islamizzare",
    "islamizzeranno": "islamizzare",
    "islamizzerebbe": "islamizzare",
    "islamizzerebber": "islamizzare",
    "islamizzerebbero": "islamizzare",
    "islamizzerei": "islamizzare",
    "islamizzeremmo": "islamizzare",
    "islamizzeremo": "islamizzare",
    "islamizzereste": "islamizzare",
    "islamizzeresti": "islamizzare",
    "islamizzerete": "islamizzare",
    "islamizzerà": "islamizzare",
    "islamizzerò": "islamizzare",
    "islamizzi": "islamizzare",
    "islamizziamo": "islamizzare",
    "islamizziate": "islamizzare",
    "islamizzin": "islamizzare",
    "islamizzino": "islamizzare",
    "islamizzo": "islamizzare",
    "islamizzò": "islamizzare",
    "islandesi": "islandese",
    "isola": "isolare",
    "isolai": "isolare",
    "isolamenti": "isolamento",
    "isolammo": "isolare",
    "isolan": "isolare",
    "isolana": "isolano",
    "isolando": "isolare",
    "isolane": "isolano",
    "isolani": "isolano",
    "isolano": "isolare",
    "isolante": "isolare",
    "isolanti": "isolare",
    "isolar": "isolare",
    "isolaron": "isolare",
    "isolarono": "isolare",
    "isolasse": "isolare",
    "isolasser": "isolare",
    "isolassero": "isolare",
    "isolassi": "isolare",
    "isolassimo": "isolare",
    "isolaste": "isolare",
    "isolasti": "isolare",
    "isolata": "isolato",
    "isolate": "isolato",
    "isolati": "isolato",
    "isolato": "isolare",
    "isolatori": "isolatore",
    "isolatrice": "isolatore",
    "isolatrici": "isolatore",
    "isolava": "isolare",
    "isolavamo": "isolare",
    "isolavan": "isolare",
    "isolavano": "isolare",
    "isolavate": "isolare",
    "isolavi": "isolare",
    "isolavo": "isolare",
    "isolazioniste": "isolazionista",
    "isolazionisti": "isolazionista",
    "isole": "isola",
    "isolerai": "isolare",
    "isoleran": "isolare",
    "isoleranno": "isolare",
    "isolerebbe": "isolare",
    "isolerebber": "isolare",
    "isolerebbero": "isolare",
    "isolerei": "isolare",
    "isoleremmo": "isolare",
    "isoleremo": "isolare",
    "isolereste": "isolare",
    "isoleresti": "isolare",
    "isolerete": "isolare",
    "isolerà": "isolare",
    "isolerò": "isolare",
    "isolette": "isoletta",
    "isoli": "isolare",
    "isoliamo": "isolare",
    "isoliate": "isolare",
    "isolin": "isolare",
    "isolino": "isolare",
    "isolo": "isolare",
    "isolotti": "isolotto",
    "isolò": "isolare",
    "isotopa": "isotopo",
    "isotope": "isotopo",
    "isotopi": "isotopo",
    "ispanica": "ispanico",
    "ispaniche": "ispanico",
    "ispanici": "ispanico",
    "ispano-marocchina": "ispano-marocchino",
    "ispano-marocchine": "ispano-marocchino",
    "ispano-marocchini": "ispano-marocchino",
    "ispessendo": "ispessire",
    "ispessente": "ispessire",
    "ispessenti": "ispessire",
    "ispessiamo": "ispessire",
    "ispessiate": "ispessire",
    "ispessii": "ispessire",
    "ispessimmo": "ispessire",
    "ispessir": "ispessire",
    "ispessirai": "ispessire",
    "ispessiran": "ispessire",
    "ispessiranno": "ispessire",
    "ispessirebbe": "ispessire",
    "ispessirebber": "ispessire",
    "ispessirebbero": "ispessire",
    "ispessirei": "ispessire",
    "ispessiremmo": "ispessire",
    "ispessiremo": "ispessire",
    "ispessireste": "ispessire",
    "ispessiresti": "ispessire",
    "ispessirete": "ispessire",
    "ispessiron": "ispessire",
    "ispessirono": "ispessire",
    "ispessirà": "ispessire",
    "ispessirò": "ispessire",
    "ispessisca": "ispessire",
    "ispessiscan": "ispessire",
    "ispessiscano": "ispessire",
    "ispessisce": "ispessire",
    "ispessisci": "ispessire",
    "ispessisco": "ispessire",
    "ispessiscon": "ispessire",
    "ispessiscono": "ispessire",
    "ispessisse": "ispessire",
    "ispessisser": "ispessire",
    "ispessissero": "ispessire",
    "ispessissi": "ispessire",
    "ispessissimo": "ispessire",
    "ispessiste": "ispessire",
    "ispessisti": "ispessire",
    "ispessita": "ispessire",
    "ispessite": "ispessire",
    "ispessiti": "ispessire",
    "ispessito": "ispessire",
    "ispessiva": "ispessire",
    "ispessivamo": "ispessire",
    "ispessivan": "ispessire",
    "ispessivano": "ispessire",
    "ispessivate": "ispessire",
    "ispessivi": "ispessire",
    "ispessivo": "ispessire",
    "ispessì": "ispessire",
    "ispettiva": "ispettivo",
    "ispettive": "ispettivo",
    "ispettivi": "ispettivo",
    "ispettorati": "ispettorato",
    "ispettori": "ispettore",
    "ispettrici": "ispettrice",
    "ispeziona": "ispezionare",
    "ispezionai": "ispezionare",
    "ispezionammo": "ispezionare",
    "ispezionan": "ispezionare",
    "ispezionando": "ispezionare",
    "ispezionano": "ispezionare",
    "ispezionante": "ispezionare",
    "ispezionanti": "ispezionare",
    "ispezionar": "ispezionare",
    "ispezionaron": "ispezionare",
    "ispezionarono": "ispezionare",
    "ispezionasse": "ispezionare",
    "ispezionasser": "ispezionare",
    "ispezionassero": "ispezionare",
    "ispezionassi": "ispezionare",
    "ispezionassimo": "ispezionare",
    "ispezionaste": "ispezionare",
    "ispezionasti": "ispezionare",
    "ispezionata": "ispezionare",
    "ispezionate": "ispezionare",
    "ispezionati": "ispezionare",
    "ispezionato": "ispezionare",
    "ispezionava": "ispezionare",
    "ispezionavamo": "ispezionare",
    "ispezionavan": "ispezionare",
    "ispezionavano": "ispezionare",
    "ispezionavate": "ispezionare",
    "ispezionavi": "ispezionare",
    "ispezionavo": "ispezionare",
    "ispezionerai": "ispezionare",
    "ispezioneran": "ispezionare",
    "ispezioneranno": "ispezionare",
    "ispezionerebbe": "ispezionare",
    "ispezionerebber": "ispezionare",
    "ispezionerebbero": "ispezionare",
    "ispezionerei": "ispezionare",
    "ispezioneremmo": "ispezionare",
    "ispezioneremo": "ispezionare",
    "ispezionereste": "ispezionare",
    "ispezioneresti": "ispezionare",
    "ispezionerete": "ispezionare",
    "ispezionerà": "ispezionare",
    "ispezionerò": "ispezionare",
    "ispezioni": "ispezione",
    "ispezioniamo": "ispezionare",
    "ispezioniate": "ispezionare",
    "ispezionin": "ispezionare",
    "ispezionino": "ispezionare",
    "ispeziono": "ispezionare",
    "ispezionò": "ispezionare",
    "ispida": "ispido",
    "ispide": "ispido",
    "ispidi": "ispido",
    "ispira": "ispirare",
    "ispirai": "ispirare",
    "ispirammo": "ispirare",
    "ispiran": "ispirare",
    "ispirando": "ispirare",
    "ispirano": "ispirare",
    "ispirante": "ispirare",
    "ispiranti": "ispirare",
    "ispirar": "ispirare",
    "ispiraron": "ispirare",
    "ispirarono": "ispirare",
    "ispirasse": "ispirare",
    "ispirasser": "ispirare",
    "ispirassero": "ispirare",
    "ispirassi": "ispirare",
    "ispirassimo": "ispirare",
    "ispiraste": "ispirare",
    "ispirasti": "ispirare",
    "ispirata": "ispirato",
    "ispirate": "ispirato",
    "ispirati": "ispirato",
    "ispirato": "ispirare",
    "ispiratori": "ispiratore",
    "ispiratrice": "ispiratore",
    "ispiratrici": "ispiratore",
    "ispirava": "ispirare",
    "ispiravamo": "ispirare",
    "ispiravan": "ispirare",
    "ispiravano": "ispirare",
    "ispiravate": "ispirare",
    "ispiravi": "ispirare",
    "ispiravo": "ispirare",
    "ispirazioni": "ispirazione",
    "ispirerai": "ispirare",
    "ispireran": "ispirare",
    "ispireranno": "ispirare",
    "ispirerebbe": "ispirare",
    "ispirerebber": "ispirare",
    "ispirerebbero": "ispirare",
    "ispirerei": "ispirare",
    "ispireremmo": "ispirare",
    "ispireremo": "ispirare",
    "ispirereste": "ispirare",
    "ispireresti": "ispirare",
    "ispirerete": "ispirare",
    "ispirerà": "ispirare",
    "ispirerò": "ispirare",
    "ispiri": "ispirare",
    "ispiriamo": "ispirare",
    "ispiriate": "ispirare",
    "ispirin": "ispirare",
    "ispirino": "ispirare",
    "ispiro": "ispirare",
    "ispirò": "ispirare",
    "israeliana": "israeliano",
    "israeliane": "israeliano",
    "israeliani": "israeliano",
    "israeliti": "israelita",
    "israelitica": "israelitico",
    "israelitiche": "israelitico",
    "israelitici": "israelitico",
    "israelo-palestinesi": "israelo-palestinese",
    "issa": "issare",
    "issai": "issare",
    "issammo": "issare",
    "issan": "issare",
    "issando": "issare",
    "issano": "issare",
    "issante": "issare",
    "issanti": "issare",
    "issar": "issare",
    "issaron": "issare",
    "issarono": "issare",
    "issasse": "issare",
    "issasser": "issare",
    "issassero": "issare",
    "issassi": "issare",
    "issassimo": "issare",
    "issaste": "issare",
    "issasti": "issare",
    "issata": "issare",
    "issate": "issare",
    "issati": "issare",
    "issato": "issare",
    "issava": "issare",
    "issavamo": "issare",
    "issavan": "issare",
    "issavano": "issare",
    "issavate": "issare",
    "issavi": "issare",
    "issavo": "issare",
    "isserai": "issare",
    "isseran": "issare",
    "isseranno": "issare",
    "isserebbe": "issare",
    "isserebber": "issare",
    "isserebbero": "issare",
    "isserei": "issare",
    "isseremmo": "issare",
    "isseremo": "issare",
    "issereste": "issare",
    "isseresti": "issare",
    "isserete": "issare",
    "isserà": "issare",
    "isserò": "issare",
    "issi": "issare",
    "issiamo": "issare",
    "issiate": "issare",
    "issin": "issare",
    "issino": "issare",
    "isso": "issare",
    "issò": "issare",
    "istalla": "istallare",
    "istallai": "istallare",
    "istallammo": "istallare",
    "istallan": "istallare",
    "istallando": "istallare",
    "istallano": "istallare",
    "istallante": "istallare",
    "istallanti": "istallare",
    "istallar": "istallare",
    "istallaron": "istallare",
    "istallarono": "istallare",
    "istallasse": "istallare",
    "istallasser": "istallare",
    "istallassero": "istallare",
    "istallassi": "istallare",
    "istallassimo": "istallare",
    "istallaste": "istallare",
    "istallasti": "istallare",
    "istallata": "istallare",
    "istallate": "istallare",
    "istallati": "istallare",
    "istallato": "istallare",
    "istallava": "istallare",
    "istallavamo": "istallare",
    "istallavan": "istallare",
    "istallavano": "istallare",
    "istallavate": "istallare",
    "istallavi": "istallare",
    "istallavo": "istallare",
    "istallazioni": "istallazione",
    "istallerai": "istallare",
    "istalleran": "istallare",
    "istalleranno": "istallare",
    "istallerebbe": "istallare",
    "istallerebber": "istallare",
    "istallerebbero": "istallare",
    "istallerei": "istallare",
    "istalleremmo": "istallare",
    "istalleremo": "istallare",
    "istallereste": "istallare",
    "istalleresti": "istallare",
    "istallerete": "istallare",
    "istallerà": "istallare",
    "istallerò": "istallare",
    "istalli": "istallare",
    "istalliamo": "istallare",
    "istalliate": "istallare",
    "istallin": "istallare",
    "istallino": "istallare",
    "istallo": "istallare",
    "istallò": "istallare",
    "istantanea": "istantaneo",
    "istantanee": "istantaneo",
    "istantanei": "istantaneo",
    "istanti": "istante",
    "istanze": "istanza",
    "isterica": "isterico",
    "isteriche": "isterico",
    "isterici": "isterico",
    "isterie": "isteria",
    "isterila": "isterilire",
    "isterilan": "isterilire",
    "isterilano": "isterilire",
    "isterile": "isterilire",
    "isterilendo": "isterilire",
    "isterilente": "isterilire",
    "isterilenti": "isterilire",
    "isterili": "isterilire",
    "isteriliamo": "isterilire",
    "isteriliate": "isterilire",
    "isterilii": "isterilire",
    "isterilimmo": "isterilire",
    "isterilir": "isterilire",
    "isterilirai": "isterilire",
    "isteriliran": "isterilire",
    "isteriliranno": "isterilire",
    "isterilirebbe": "isterilire",
    "isterilirebber": "isterilire",
    "isterilirebbero": "isterilire",
    "isterilirei": "isterilire",
    "isteriliremmo": "isterilire",
    "isteriliremo": "isterilire",
    "isterilireste": "isterilire",
    "isteriliresti": "isterilire",
    "isterilirete": "isterilire",
    "isteriliron": "isterilire",
    "isterilirono": "isterilire",
    "isterilirà": "isterilire",
    "isterilirò": "isterilire",
    "isterilisse": "isterilire",
    "isterilisser": "isterilire",
    "isterilissero": "isterilire",
    "isterilissi": "isterilire",
    "isterilissimo": "isterilire",
    "isteriliste": "isterilire",
    "isterilisti": "isterilire",
    "isterilita": "isterilire",
    "isterilite": "isterilire",
    "isteriliti": "isterilire",
    "isterilito": "isterilire",
    "isteriliva": "isterilire",
    "isterilivamo": "isterilire",
    "isterilivan": "isterilire",
    "isterilivano": "isterilire",
    "isterilivate": "isterilire",
    "isterilivi": "isterilire",
    "isterilivo": "isterilire",
    "isterilo": "isterilire",
    "isterilon": "isterilire",
    "isterilono": "isterilire",
    "isterilì": "isterilire",
    "isterismi": "isterismo",
    "istiga": "istigare",
    "istigai": "istigare",
    "istigammo": "istigare",
    "istigan": "istigare",
    "istigando": "istigare",
    "istigano": "istigare",
    "istigante": "istigare",
    "istiganti": "istigare",
    "istigar": "istigare",
    "istigaron": "istigare",
    "istigarono": "istigare",
    "istigasse": "istigare",
    "istigasser": "istigare",
    "istigassero": "istigare",
    "istigassi": "istigare",
    "istigassimo": "istigare",
    "istigaste": "istigare",
    "istigasti": "istigare",
    "istigata": "istigare",
    "istigate": "istigare",
    "istigati": "istigare",
    "istigato": "istigare",
    "istigatori": "istigatore",
    "istigava": "istigare",
    "istigavamo": "istigare",
    "istigavan": "istigare",
    "istigavano": "istigare",
    "istigavate": "istigare",
    "istigavi": "istigare",
    "istigavo": "istigare",
    "istigazioni": "istigazione",
    "istigherai": "istigare",
    "istigheran": "istigare",
    "istigheranno": "istigare",
    "istigherebbe": "istigare",
    "istigherebber": "istigare",
    "istigherebbero": "istigare",
    "istigherei": "istigare",
    "istigheremmo": "istigare",
    "istigheremo": "istigare",
    "istighereste": "istigare",
    "istigheresti": "istigare",
    "istigherete": "istigare",
    "istigherà": "istigare",
    "istigherò": "istigare",
    "istighi": "istigare",
    "istighiamo": "istigare",
    "istighiate": "istigare",
    "istighin": "istigare",
    "istighino": "istigare",
    "istigo": "istigare",
    "istigò": "istigare",
    "istilla": "istillare",
    "istillai": "istillare",
    "istillammo": "istillare",
    "istillan": "istillare",
    "istillando": "istillare",
    "istillano": "istillare",
    "istillante": "istillare",
    "istillanti": "istillare",
    "istillar": "istillare",
    "istillaron": "istillare",
    "istillarono": "istillare",
    "istillasse": "istillare",
    "istillasser": "istillare",
    "istillassero": "istillare",
    "istillassi": "istillare",
    "istillassimo": "istillare",
    "istillaste": "istillare",
    "istillasti": "istillare",
    "istillata": "istillare",
    "istillate": "istillare",
    "istillati": "istillare",
    "istillato": "istillare",
    "istillava": "istillare",
    "istillavamo": "istillare",
    "istillavan": "istillare",
    "istillavano": "istillare",
    "istillavate": "istillare",
    "istillavi": "istillare",
    "istillavo": "istillare",
    "istillerai": "istillare",
    "istilleran": "istillare",
    "istilleranno": "istillare",
    "istillerebbe": "istillare",
    "istillerebber": "istillare",
    "istillerebbero": "istillare",
    "istillerei": "istillare",
    "istilleremmo": "istillare",
    "istilleremo": "istillare",
    "istillereste": "istillare",
    "istilleresti": "istillare",
    "istillerete": "istillare",
    "istillerà": "istillare",
    "istillerò": "istillare",
    "istilli": "istillare",
    "istilliamo": "istillare",
    "istilliate": "istillare",
    "istillin": "istillare",
    "istillino": "istillare",
    "istillo": "istillare",
    "istillò": "istillare",
    "istinti": "istinto",
    "istintiva": "istintivo",
    "istintive": "istintivo",
    "istintivi": "istintivo",
    "istituendo": "istituire",
    "istituente": "istituire",
    "istituenti": "istituire",
    "istituiamo": "istituire",
    "istituiate": "istituire",
    "istituii": "istituire",
    "istituimmo": "istituire",
    "istituir": "istituire",
    "istituirai": "istituire",
    "istituiran": "istituire",
    "istituiranno": "istituire",
    "istituirebbe": "istituire",
    "istituirebber": "istituire",
    "istituirebbero": "istituire",
    "istituirei": "istituire",
    "istituiremmo": "istituire",
    "istituiremo": "istituire",
    "istituireste": "istituire",
    "istituiresti": "istituire",
    "istituirete": "istituire",
    "istituiron": "istituire",
    "istituirono": "istituire",
    "istituirà": "istituire",
    "istituirò": "istituire",
    "istituisca": "istituire",
    "istituiscan": "istituire",
    "istituiscano": "istituire",
    "istituisce": "istituire",
    "istituisci": "istituire",
    "istituisco": "istituire",
    "istituiscon": "istituire",
    "istituiscono": "istituire",
    "istituisse": "istituire",
    "istituisser": "istituire",
    "istituissero": "istituire",
    "istituissi": "istituire",
    "istituissimo": "istituire",
    "istituiste": "istituire",
    "istituisti": "istituire",
    "istituita": "istituire",
    "istituite": "istituire",
    "istituiti": "istituire",
    "istituito": "istituire",
    "istituiva": "istituire",
    "istituivamo": "istituire",
    "istituivan": "istituire",
    "istituivano": "istituire",
    "istituivate": "istituire",
    "istituivi": "istituire",
    "istituivo": "istituire",
    "istituti": "istituto",
    "istitutiva": "istitutivo",
    "istitutive": "istitutivo",
    "istitutivi": "istitutivo",
    "istitutori": "istitutore",
    "istitutrici": "istitutrice",
    "istituzionali": "istituzionale",
    "istituzionalizza": "istituzionalizzare",
    "istituzionalizzai": "istituzionalizzare",
    "istituzionalizzammo": "istituzionalizzare",
    "istituzionalizzan": "istituzionalizzare",
    "istituzionalizzando": "istituzionalizzare",
    "istituzionalizzano": "istituzionalizzare",
    "istituzionalizzante": "istituzionalizzare",
    "istituzionalizzanti": "istituzionalizzare",
    "istituzionalizzar": "istituzionalizzare",
    "istituzionalizzaron": "istituzionalizzare",
    "istituzionalizzarono": "istituzionalizzare",
    "istituzionalizzasse": "istituzionalizzare",
    "istituzionalizzasser": "istituzionalizzare",
    "istituzionalizzassero": "istituzionalizzare",
    "istituzionalizzassi": "istituzionalizzare",
    "istituzionalizzassimo": "istituzionalizzare",
    "istituzionalizzaste": "istituzionalizzare",
    "istituzionalizzasti": "istituzionalizzare",
    "istituzionalizzata": "istituzionalizzare",
    "istituzionalizzate": "istituzionalizzare",
    "istituzionalizzati": "istituzionalizzare",
    "istituzionalizzato": "istituzionalizzare",
    "istituzionalizzava": "istituzionalizzare",
    "istituzionalizzavamo": "istituzionalizzare",
    "istituzionalizzavan": "istituzionalizzare",
    "istituzionalizzavano": "istituzionalizzare",
    "istituzionalizzavate": "istituzionalizzare",
    "istituzionalizzavi": "istituzionalizzare",
    "istituzionalizzavo": "istituzionalizzare",
    "istituzionalizzerai": "istituzionalizzare",
    "istituzionalizzeran": "istituzionalizzare",
    "istituzionalizzeranno": "istituzionalizzare",
    "istituzionalizzerebbe": "istituzionalizzare",
    "istituzionalizzerebber": "istituzionalizzare",
    "istituzionalizzerebbero": "istituzionalizzare",
    "istituzionalizzerei": "istituzionalizzare",
    "istituzionalizzeremmo": "istituzionalizzare",
    "istituzionalizzeremo": "istituzionalizzare",
    "istituzionalizzereste": "istituzionalizzare",
    "istituzionalizzeresti": "istituzionalizzare",
    "istituzionalizzerete": "istituzionalizzare",
    "istituzionalizzerà": "istituzionalizzare",
    "istituzionalizzerò": "istituzionalizzare",
    "istituzionalizzi": "istituzionalizzare",
    "istituzionalizziamo": "istituzionalizzare",
    "istituzionalizziate": "istituzionalizzare",
    "istituzionalizzin": "istituzionalizzare",
    "istituzionalizzino": "istituzionalizzare",
    "istituzionalizzo": "istituzionalizzare",
    "istituzionalizzò": "istituzionalizzare",
    "istituzioni": "istituzione",
    "istituì": "istituire",
    "istmica": "istmico",
    "istmiche": "istmico",
    "istmici": "istmico",
    "istologica": "istologico",
    "istologiche": "istologico",
    "istologici": "istologico",
    "istori": "istoriare",
    "istoria": "istoriare",
    "istoriai": "istoriare",
    "istoriammo": "istoriare",
    "istoriamo": "istoriare",
    "istorian": "istoriare",
    "istoriando": "istoriare",
    "istoriano": "istoriare",
    "istoriante": "istoriare",
    "istorianti": "istoriare",
    "istoriar": "istoriare",
    "istoriaron": "istoriare",
    "istoriarono": "istoriare",
    "istoriasse": "istoriare",
    "istoriasser": "istoriare",
    "istoriassero": "istoriare",
    "istoriassi": "istoriare",
    "istoriassimo": "istoriare",
    "istoriaste": "istoriare",
    "istoriasti": "istoriare",
    "istoriata": "istoriare",
    "istoriate": "istoriare",
    "istoriati": "istoriare",
    "istoriato": "istoriare",
    "istoriava": "istoriare",
    "istoriavamo": "istoriare",
    "istoriavan": "istoriare",
    "istoriavano": "istoriare",
    "istoriavate": "istoriare",
    "istoriavi": "istoriare",
    "istoriavo": "istoriare",
    "istorierai": "istoriare",
    "istorieran": "istoriare",
    "istorieranno": "istoriare",
    "istorierebbe": "istoriare",
    "istorierebber": "istoriare",
    "istorierebbero": "istoriare",
    "istorierei": "istoriare",
    "istorieremmo": "istoriare",
    "istorieremo": "istoriare",
    "istoriereste": "istoriare",
    "istorieresti": "istoriare",
    "istorierete": "istoriare",
    "istorierà": "istoriare",
    "istorierò": "istoriare",
    "istorin": "istoriare",
    "istorino": "istoriare",
    "istorio": "istoriare",
    "istoriò": "istoriare",
    "istrada": "istradare",
    "istradai": "istradare",
    "istradammo": "istradare",
    "istradan": "istradare",
    "istradando": "istradare",
    "istradano": "istradare",
    "istradante": "istradare",
    "istradanti": "istradare",
    "istradar": "istradare",
    "istradaron": "istradare",
    "istradarono": "istradare",
    "istradasse": "istradare",
    "istradasser": "istradare",
    "istradassero": "istradare",
    "istradassi": "istradare",
    "istradassimo": "istradare",
    "istradaste": "istradare",
    "istradasti": "istradare",
    "istradata": "istradare",
    "istradate": "istradare",
    "istradati": "istradare",
    "istradato": "istradare",
    "istradava": "istradare",
    "istradavamo": "istradare",
    "istradavan": "istradare",
    "istradavano": "istradare",
    "istradavate": "istradare",
    "istradavi": "istradare",
    "istradavo": "istradare",
    "istraderai": "istradare",
    "istraderan": "istradare",
    "istraderanno": "istradare",
    "istraderebbe": "istradare",
    "istraderebber": "istradare",
    "istraderebbero": "istradare",
    "istraderei": "istradare",
    "istraderemmo": "istradare",
    "istraderemo": "istradare",
    "istradereste": "istradare",
    "istraderesti": "istradare",
    "istraderete": "istradare",
    "istraderà": "istradare",
    "istraderò": "istradare",
    "istradi": "istradare",
    "istradiamo": "istradare",
    "istradiate": "istradare",
    "istradin": "istradare",
    "istradino": "istradare",
    "istrado": "istradare",
    "istradò": "istradare",
    "istriana": "istriano",
    "istriane": "istriano",
    "istriani": "istriano",
    "istrioni": "istrione",
    "istrionica": "istrionico",
    "istrioniche": "istrionico",
    "istrionici": "istrionico",
    "istrionismi": "istrionismo",
    "istruendo": "istruire",
    "istruente": "istruire",
    "istruenti": "istruire",
    "istruiamo": "istruire",
    "istruiate": "istruire",
    "istruii": "istruire",
    "istruimmo": "istruire",
    "istruir": "istruire",
    "istruirai": "istruire",
    "istruiran": "istruire",
    "istruiranno": "istruire",
    "istruirebbe": "istruire",
    "istruirebber": "istruire",
    "istruirebbero": "istruire",
    "istruirei": "istruire",
    "istruiremmo": "istruire",
    "istruiremo": "istruire",
    "istruireste": "istruire",
    "istruiresti": "istruire",
    "istruirete": "istruire",
    "istruiron": "istruire",
    "istruirono": "istruire",
    "istruirà": "istruire",
    "istruirò": "istruire",
    "istruisca": "istruire",
    "istruiscan": "istruire",
    "istruiscano": "istruire",
    "istruisce": "istruire",
    "istruisci": "istruire",
    "istruisco": "istruire",
    "istruiscon": "istruire",
    "istruiscono": "istruire",
    "istruisse": "istruire",
    "istruisser": "istruire",
    "istruissero": "istruire",
    "istruissi": "istruire",
    "istruissimo": "istruire",
    "istruiste": "istruire",
    "istruisti": "istruire",
    "istruita": "istruire",
    "istruite": "istruire",
    "istruiti": "istruire",
    "istruito": "istruire",
    "istruiva": "istruire",
    "istruivamo": "istruire",
    "istruivan": "istruire",
    "istruivano": "istruire",
    "istruivate": "istruire",
    "istruivi": "istruire",
    "istruivo": "istruire",
    "istruttiva": "istruttivo",
    "istruttive": "istruttivo",
    "istruttivi": "istruttivo",
    "istruttori": "istruttorio",
    "istruttoria": "istruttorio",
    "istruttorie": "istruttorio",
    "istruttrice": "istruttore",
    "istruttrici": "istruttore",
    "istruzioni": "istruzione",
    "istruì": "istruire",
    "istupidendo": "istupidire",
    "istupidente": "istupidire",
    "istupidenti": "istupidire",
    "istupidiamo": "istupidire",
    "istupidiate": "istupidire",
    "istupidii": "istupidire",
    "istupidimmo": "istupidire",
    "istupidir": "istupidire",
    "istupidirai": "istupidire",
    "istupidiran": "istupidire",
    "istupidiranno": "istupidire",
    "istupidirebbe": "istupidire",
    "istupidirebber": "istupidire",
    "istupidirebbero": "istupidire",
    "istupidirei": "istupidire",
    "istupidiremmo": "istupidire",
    "istupidiremo": "istupidire",
    "istupidireste": "istupidire",
    "istupidiresti": "istupidire",
    "istupidirete": "istupidire",
    "istupidiron": "istupidire",
    "istupidirono": "istupidire",
    "istupidirà": "istupidire",
    "istupidirò": "istupidire",
    "istupidisca": "istupidire",
    "istupidiscan": "istupidire",
    "istupidiscano": "istupidire",
    "istupidisce": "istupidire",
    "istupidisci": "istupidire",
    "istupidisco": "istupidire",
    "istupidiscon": "istupidire",
    "istupidiscono": "istupidire",
    "istupidisse": "istupidire",
    "istupidisser": "istupidire",
    "istupidissero": "istupidire",
    "istupidissi": "istupidire",
    "istupidissimo": "istupidire",
    "istupidiste": "istupidire",
    "istupidisti": "istupidire",
    "istupidita": "istupidire",
    "istupidite": "istupidire",
    "istupiditi": "istupidire",
    "istupidito": "istupidire",
    "istupidiva": "istupidire",
    "istupidivamo": "istupidire",
    "istupidivan": "istupidire",
    "istupidivano": "istupidire",
    "istupidivate": "istupidire",
    "istupidivi": "istupidire",
    "istupidivo": "istupidire",
    "istupidì": "istupidire",
    "itala": "italo",
    "itale": "italo",
    "itali": "italo",
    "italiana": "italiano",
    "italiane": "italiano",
    "italiani": "italiano",
    "italianisti": "italianista",
    "italianizza": "italianizzare",
    "italianizzai": "italianizzare",
    "italianizzammo": "italianizzare",
    "italianizzan": "italianizzare",
    "italianizzando": "italianizzare",
    "italianizzano": "italianizzare",
    "italianizzante": "italianizzare",
    "italianizzanti": "italianizzare",
    "italianizzar": "italianizzare",
    "italianizzaron": "italianizzare",
    "italianizzarono": "italianizzare",
    "italianizzasse": "italianizzare",
    "italianizzasser": "italianizzare",
    "italianizzassero": "italianizzare",
    "italianizzassi": "italianizzare",
    "italianizzassimo": "italianizzare",
    "italianizzaste": "italianizzare",
    "italianizzasti": "italianizzare",
    "italianizzata": "italianizzare",
    "italianizzate": "italianizzare",
    "italianizzati": "italianizzare",
    "italianizzato": "italianizzare",
    "italianizzava": "italianizzare",
    "italianizzavamo": "italianizzare",
    "italianizzavan": "italianizzare",
    "italianizzavano": "italianizzare",
    "italianizzavate": "italianizzare",
    "italianizzavi": "italianizzare",
    "italianizzavo": "italianizzare",
    "italianizzerai": "italianizzare",
    "italianizzeran": "italianizzare",
    "italianizzeranno": "italianizzare",
    "italianizzerebbe": "italianizzare",
    "italianizzerebber": "italianizzare",
    "italianizzerebbero": "italianizzare",
    "italianizzerei": "italianizzare",
    "italianizzeremmo": "italianizzare",
    "italianizzeremo": "italianizzare",
    "italianizzereste": "italianizzare",
    "italianizzeresti": "italianizzare",
    "italianizzerete": "italianizzare",
    "italianizzerà": "italianizzare",
    "italianizzerò": "italianizzare",
    "italianizzi": "italianizzare",
    "italianizziamo": "italianizzare",
    "italianizziate": "italianizzare",
    "italianizzin": "italianizzare",
    "italianizzino": "italianizzare",
    "italianizzo": "italianizzare",
    "italianizzò": "italianizzare",
    "italica": "italico",
    "italiche": "italico",
    "italici": "italico",
    "italiote": "italiota",
    "italioti": "italiota",
    "italo-americana": "italo-americano",
    "italo-americane": "italo-americano",
    "italo-americani": "italo-americano",
    "italo-austriaca": "italo-austriaco",
    "italo-austriache": "italo-austriaco",
    "italo-austriaci": "italo-austriaco",
    "italo-francesi": "italo-francese",
    "italo-svizzera": "italo-svizzero",
    "italo-svizzere": "italo-svizzero",
    "italo-svizzeri": "italo-svizzero",
    "italo-tedesca": "italo-tedesco",
    "italo-tedesche": "italo-tedesco",
    "italo-tedeschi": "italo-tedesco",
    "italoamericana": "italoamericano",
    "italoamericane": "italoamericano",
    "italoamericani": "italoamericano",
    "itera": "iterare",
    "iterai": "iterare",
    "iterammo": "iterare",
    "iteran": "iterare",
    "iterando": "iterare",
    "iterano": "iterare",
    "iterante": "iterare",
    "iteranti": "iterare",
    "iterar": "iterare",
    "iteraron": "iterare",
    "iterarono": "iterare",
    "iterasse": "iterare",
    "iterasser": "iterare",
    "iterassero": "iterare",
    "iterassi": "iterare",
    "iterassimo": "iterare",
    "iteraste": "iterare",
    "iterasti": "iterare",
    "iterata": "iterare",
    "iterate": "iterare",
    "iterati": "iterare",
    "iterativa": "iterativo",
    "iterative": "iterativo",
    "iterativi": "iterativo",
    "iterato": "iterare",
    "iterava": "iterare",
    "iteravamo": "iterare",
    "iteravan": "iterare",
    "iteravano": "iterare",
    "iteravate": "iterare",
    "iteravi": "iterare",
    "iteravo": "iterare",
    "iterazioni": "iterazione",
    "itererai": "iterare",
    "itereran": "iterare",
    "itereranno": "iterare",
    "itererebbe": "iterare",
    "itererebber": "iterare",
    "itererebbero": "iterare",
    "itererei": "iterare",
    "itereremmo": "iterare",
    "itereremo": "iterare",
    "iterereste": "iterare",
    "itereresti": "iterare",
    "itererete": "iterare",
    "itererà": "iterare",
    "itererò": "iterare",
    "iteri": "iterare",
    "iteriamo": "iterare",
    "iteriate": "iterare",
    "iterin": "iterare",
    "iterino": "iterare",
    "itero": "iterare",
    "iterò": "iterare",
    "itineranti": "itinerante",
    "itinerari": "itinerario",
    "ittica": "ittico",
    "ittiche": "ittico",
    "ittici": "ittico",
    "iugoslava": "iugoslavo",
    "iugoslave": "iugoslavo",
    "iugoslavi": "iugoslavo",
    "iugula": "iugulare",
    "iugulai": "iugulare",
    "iugulammo": "iugulare",
    "iugulan": "iugulare",
    "iugulando": "iugulare",
    "iugulano": "iugulare",
    "iugulante": "iugulare",
    "iugulanti": "iugulare",
    "iugular": "iugulare",
    "iugularon": "iugulare",
    "iugularono": "iugulare",
    "iugulasse": "iugulare",
    "iugulasser": "iugulare",
    "iugulassero": "iugulare",
    "iugulassi": "iugulare",
    "iugulassimo": "iugulare",
    "iugulaste": "iugulare",
    "iugulasti": "iugulare",
    "iugulata": "iugulare",
    "iugulate": "iugulare",
    "iugulati": "iugulare",
    "iugulato": "iugulare",
    "iugulava": "iugulare",
    "iugulavamo": "iugulare",
    "iugulavan": "iugulare",
    "iugulavano": "iugulare",
    "iugulavate": "iugulare",
    "iugulavi": "iugulare",
    "iugulavo": "iugulare",
    "iugulerai": "iugulare",
    "iuguleran": "iugulare",
    "iuguleranno": "iugulare",
    "iugulerebbe": "iugulare",
    "iugulerebber": "iugulare",
    "iugulerebbero": "iugulare",
    "iugulerei": "iugulare",
    "iuguleremmo": "iugulare",
    "iuguleremo": "iugulare",
    "iugulereste": "iugulare",
    "iuguleresti": "iugulare",
    "iugulerete": "iugulare",
    "iugulerà": "iugulare",
    "iugulerò": "iugulare",
    "iuguli": "iugulare",
    "iuguliamo": "iugulare",
    "iuguliate": "iugulare",
    "iugulin": "iugulare",
    "iugulino": "iugulare",
    "iugulo": "iugulare",
    "iugulò": "iugulare",
    "jamesiana": "jamesiano",
    "jamesiane": "jamesiano",
    "jamesiani": "jamesiano",
    "jatture": "jattura",
    "jazzisti": "jazzista",
    "jazzistica": "jazzistico",
    "jazzistiche": "jazzistico",
    "jazzistici": "jazzistico",
    "jeanserie": "jeanseria",
    "jelle": "jella",
    "jene": "jena",
    "joint-ventures": "joint-venture",
    "jospiniana": "jospiniano",
    "jospiniane": "jospiniano",
    "jospiniani": "jospiniano",
    "jugoslava": "jugoslavo",
    "jugoslave": "jugoslavo",
    "jugoslavi": "jugoslavo",
    "jungle": "jungla",
    "juventina": "juventino",
    "juventine": "juventino",
    "juventini": "juventino",
    "kafkiana": "kafkiano",
    "kafkiane": "kafkiano",
    "kafkiani": "kafkiano",
    "kantiana": "kantiano",
    "kantiane": "kantiano",
    "kantiani": "kantiano",
    "kazaki": "kazako",
    "keniana": "keniano",
    "keniane": "keniano",
    "keniani": "keniano",
    "keniote": "keniota",
    "kenioti": "keniota",
    "kennedyana": "kennedyano",
    "kennedyane": "kennedyano",
    "kennedyani": "kennedyano",
    "kentuckiana": "kentuckiano",
    "kentuckiane": "kentuckiano",
    "kentuckiani": "kentuckiano",
    "kenyana": "kenyano",
    "kenyane": "kenyano",
    "kenyani": "kenyano",
    "keynesiana": "keynesiano",
    "keynesiane": "keynesiano",
    "keynesiani": "keynesiano",
    "khatamiste": "khatamista",
    "khatamisti": "khatamista",
    "khomeinismi": "khomeinismo",
    "khomeiniste": "khomeinista",
    "khomeinisti": "khomeinista",
    "killers": "killer",
    "kosovara": "kosovaro",
    "kosovare": "kosovaro",
    "kosovari": "kosovaro",
    "kuwaitiana": "kuwaitiano",
    "kuwaitiane": "kuwaitiano",
    "kuwaitiani": "kuwaitiano",
    "l'": "lo",
    "labbra": "labbro",
    "labbroni": "labbrone",
    "labili": "labile",
    "labirinti": "labirinto",
    "labirintica": "labirintico",
    "labirintiche": "labirintico",
    "labirintici": "labirintico",
    "laboratori": "laboratorio",
    "laboriosa": "laborioso",
    "laboriose": "laborioso",
    "laboriosi": "laborioso",
    "laburismi": "laburismo",
    "laburiste": "laburista",
    "laburisti": "laburista",
    "lacca": "laccare",
    "laccai": "laccare",
    "laccammo": "laccare",
    "laccan": "laccare",
    "laccando": "laccare",
    "laccano": "laccare",
    "laccante": "laccare",
    "laccanti": "laccare",
    "laccar": "laccare",
    "laccaron": "laccare",
    "laccarono": "laccare",
    "laccasse": "laccare",
    "laccasser": "laccare",
    "laccassero": "laccare",
    "laccassi": "laccare",
    "laccassimo": "laccare",
    "laccaste": "laccare",
    "laccasti": "laccare",
    "laccata": "laccare",
    "laccate": "laccare",
    "laccati": "laccare",
    "laccato": "laccare",
    "laccava": "laccare",
    "laccavamo": "laccare",
    "laccavan": "laccare",
    "laccavano": "laccare",
    "laccavate": "laccare",
    "laccavi": "laccare",
    "laccavo": "laccare",
    "lacche": "lacca",
    "laccherai": "laccare",
    "laccheran": "laccare",
    "laccheranno": "laccare",
    "laccherebbe": "laccare",
    "laccherebber": "laccare",
    "laccherebbero": "laccare",
    "laccherei": "laccare",
    "laccheremmo": "laccare",
    "laccheremo": "laccare",
    "lacchereste": "laccare",
    "laccheresti": "laccare",
    "laccherete": "laccare",
    "laccherà": "laccare",
    "laccherò": "laccare",
    "lacchi": "laccare",
    "lacchiamo": "laccare",
    "lacchiate": "laccare",
    "lacchin": "laccare",
    "lacchino": "laccare",
    "lacci": "laccio",
    "lacciuoli": "lacciuolo",
    "lacco": "laccare",
    "laccò": "laccare",
    "lacera": "lacero",
    "lacerai": "lacerare",
    "lacerammo": "lacerare",
    "laceran": "lacerare",
    "lacerando": "lacerare",
    "lacerano": "lacerare",
    "lacerante": "lacerare",
    "laceranti": "lacerare",
    "lacerar": "lacerare",
    "laceraron": "lacerare",
    "lacerarono": "lacerare",
    "lacerasse": "lacerare",
    "lacerasser": "lacerare",
    "lacerassero": "lacerare",
    "lacerassi": "lacerare",
    "lacerassimo": "lacerare",
    "laceraste": "lacerare",
    "lacerasti": "lacerare",
    "lacerata": "lacerare",
    "lacerate": "lacerare",
    "lacerati": "lacerare",
    "lacerato": "lacerare",
    "lacerava": "lacerare",
    "laceravamo": "lacerare",
    "laceravan": "lacerare",
    "laceravano": "lacerare",
    "laceravate": "lacerare",
    "laceravi": "lacerare",
    "laceravo": "lacerare",
    "lacerazioni": "lacerazione",
    "lacere": "lacero",
    "lacererai": "lacerare",
    "lacereran": "lacerare",
    "lacereranno": "lacerare",
    "lacererebbe": "lacerare",
    "lacererebber": "lacerare",
    "lacererebbero": "lacerare",
    "lacererei": "lacerare",
    "lacereremmo": "lacerare",
    "lacereremo": "lacerare",
    "lacerereste": "lacerare",
    "lacereresti": "lacerare",
    "lacererete": "lacerare",
    "lacererà": "lacerare",
    "lacererò": "lacerare",
    "laceri": "lacero",
    "laceriamo": "lacerare",
    "laceriate": "lacerare",
    "lacerin": "lacerare",
    "lacerino": "lacerare",
    "lacero": "lacerare",
    "lacerò": "lacerare",
    "laconica": "laconico",
    "laconiche": "laconico",
    "laconici": "laconico",
    "lacrima": "lacrimare",
    "lacrimai": "lacrimare",
    "lacrimali": "lacrimale",
    "lacrimammo": "lacrimare",
    "lacriman": "lacrimare",
    "lacrimando": "lacrimare",
    "lacrimano": "lacrimare",
    "lacrimante": "lacrimare",
    "lacrimanti": "lacrimare",
    "lacrimar": "lacrimare",
    "lacrimaron": "lacrimare",
    "lacrimarono": "lacrimare",
    "lacrimasse": "lacrimare",
    "lacrimasser": "lacrimare",
    "lacrimassero": "lacrimare",
    "lacrimassi": "lacrimare",
    "lacrimassimo": "lacrimare",
    "lacrimaste": "lacrimare",
    "lacrimasti": "lacrimare",
    "lacrimata": "lacrimare",
    "lacrimate": "lacrimare",
    "lacrimati": "lacrimare",
    "lacrimato": "lacrimare",
    "lacrimava": "lacrimare",
    "lacrimavamo": "lacrimare",
    "lacrimavan": "lacrimare",
    "lacrimavano": "lacrimare",
    "lacrimavate": "lacrimare",
    "lacrimavi": "lacrimare",
    "lacrimavo": "lacrimare",
    "lacrimazioni": "lacrimazione",
    "lacrime": "lacrima",
    "lacrimerai": "lacrimare",
    "lacrimeran": "lacrimare",
    "lacrimeranno": "lacrimare",
    "lacrimerebbe": "lacrimare",
    "lacrimerebber": "lacrimare",
    "lacrimerebbero": "lacrimare",
    "lacrimerei": "lacrimare",
    "lacrimeremmo": "lacrimare",
    "lacrimeremo": "lacrimare",
    "lacrimereste": "lacrimare",
    "lacrimeresti": "lacrimare",
    "lacrimerete": "lacrimare",
    "lacrimerà": "lacrimare",
    "lacrimerò": "lacrimare",
    "lacrimevoli": "lacrimevole",
    "lacrimi": "lacrimare",
    "lacrimiamo": "lacrimare",
    "lacrimiate": "lacrimare",
    "lacrimin": "lacrimare",
    "lacrimino": "lacrimare",
    "lacrimo": "lacrimare",
    "lacrimogena": "lacrimogeno",
    "lacrimogene": "lacrimogeno",
    "lacrimogeni": "lacrimogeno",
    "lacrimosa": "lacrimoso",
    "lacrimose": "lacrimoso",
    "lacrimosi": "lacrimoso",
    "lacrimucce": "lacrimuccia",
    "lacrimò": "lacrimare",
    "lacuna": "lacunare",
    "lacunai": "lacunare",
    "lacunammo": "lacunare",
    "lacunan": "lacunare",
    "lacunando": "lacunare",
    "lacunano": "lacunare",
    "lacunante": "lacunare",
    "lacunanti": "lacunare",
    "lacunar": "lacunare",
    "lacunaron": "lacunare",
    "lacunarono": "lacunare",
    "lacunasse": "lacunare",
    "lacunasser": "lacunare",
    "lacunassero": "lacunare",
    "lacunassi": "lacunare",
    "lacunassimo": "lacunare",
    "lacunaste": "lacunare",
    "lacunasti": "lacunare",
    "lacunata": "lacunare",
    "lacunate": "lacunare",
    "lacunati": "lacunare",
    "lacunato": "lacunare",
    "lacunava": "lacunare",
    "lacunavamo": "lacunare",
    "lacunavan": "lacunare",
    "lacunavano": "lacunare",
    "lacunavate": "lacunare",
    "lacunavi": "lacunare",
    "lacunavo": "lacunare",
    "lacune": "lacuna",
    "lacunerai": "lacunare",
    "lacuneran": "lacunare",
    "lacuneranno": "lacunare",
    "lacunerebbe": "lacunare",
    "lacunerebber": "lacunare",
    "lacunerebbero": "lacunare",
    "lacunerei": "lacunare",
    "lacuneremmo": "lacunare",
    "lacuneremo": "lacunare",
    "lacunereste": "lacunare",
    "lacuneresti": "lacunare",
    "lacunerete": "lacunare",
    "lacunerà": "lacunare",
    "lacunerò": "lacunare",
    "lacuni": "lacunare",
    "lacuniamo": "lacunare",
    "lacuniate": "lacunare",
    "lacunin": "lacunare",
    "lacunino": "lacunare",
    "lacuno": "lacunare",
    "lacunosa": "lacunoso",
    "lacunose": "lacunoso",
    "lacunosi": "lacunoso",
    "lacunò": "lacunare",
    "lacustri": "lacustre",
    "ladina": "ladino",
    "ladine": "ladino",
    "ladini": "ladino",
    "ladra": "ladro",
    "ladre": "ladro",
    "ladri": "ladro",
    "ladroni": "ladrone",
    "ladruncoli": "ladruncolo",
    "laghetti": "laghetto",
    "laghi": "lago",
    "lagna": "lagnare",
    "lagnai": "lagnare",
    "lagnammo": "lagnare",
    "lagnan": "lagnare",
    "lagnando": "lagnare",
    "lagnano": "lagnare",
    "lagnanze": "lagnanza",
    "lagnar": "lagnare",
    "lagnaron": "lagnare",
    "lagnarono": "lagnare",
    "lagnasse": "lagnare",
    "lagnasser": "lagnare",
    "lagnassero": "lagnare",
    "lagnassi": "lagnare",
    "lagnassimo": "lagnare",
    "lagnaste": "lagnare",
    "lagnasti": "lagnare",
    "lagnata": "lagnare",
    "lagnate": "lagnare",
    "lagnati": "lagnare",
    "lagnato": "lagnare",
    "lagnava": "lagnare",
    "lagnavamo": "lagnare",
    "lagnavan": "lagnare",
    "lagnavano": "lagnare",
    "lagnavate": "lagnare",
    "lagnavi": "lagnare",
    "lagnavo": "lagnare",
    "lagne": "lagna",
    "lagnerai": "lagnare",
    "lagneran": "lagnare",
    "lagneranno": "lagnare",
    "lagnerebbe": "lagnare",
    "lagnerebber": "lagnare",
    "lagnerebbero": "lagnare",
    "lagnerei": "lagnare",
    "lagneremmo": "lagnare",
    "lagneremo": "lagnare",
    "lagnereste": "lagnare",
    "lagneresti": "lagnare",
    "lagnerete": "lagnare",
    "lagnerà": "lagnare",
    "lagnerò": "lagnare",
    "lagni": "lagnare",
    "lagniamo": "lagnare",
    "lagniate": "lagnare",
    "lagnin": "lagnare",
    "lagnino": "lagnare",
    "lagno": "lagnare",
    "lagnosa": "lagnoso",
    "lagnose": "lagnoso",
    "lagnosi": "lagnoso",
    "lagnò": "lagnare",
    "lagrime": "lagrima",
    "lagunari": "lagunare",
    "lagune": "laguna",
    "laica": "laico",
    "laicali": "laicale",
    "laicati": "laicato",
    "laiche": "laico",
    "laici": "laico",
    "laicismi": "laicismo",
    "laicista": "laicisto",
    "laiciste": "laicisto",
    "laicisti": "laicisto",
    "laicizza": "laicizzare",
    "laicizzai": "laicizzare",
    "laicizzammo": "laicizzare",
    "laicizzan": "laicizzare",
    "laicizzando": "laicizzare",
    "laicizzano": "laicizzare",
    "laicizzante": "laicizzare",
    "laicizzanti": "laicizzare",
    "laicizzar": "laicizzare",
    "laicizzaron": "laicizzare",
    "laicizzarono": "laicizzare",
    "laicizzasse": "laicizzare",
    "laicizzasser": "laicizzare",
    "laicizzassero": "laicizzare",
    "laicizzassi": "laicizzare",
    "laicizzassimo": "laicizzare",
    "laicizzaste": "laicizzare",
    "laicizzasti": "laicizzare",
    "laicizzata": "laicizzare",
    "laicizzate": "laicizzare",
    "laicizzati": "laicizzare",
    "laicizzato": "laicizzare",
    "laicizzava": "laicizzare",
    "laicizzavamo": "laicizzare",
    "laicizzavan": "laicizzare",
    "laicizzavano": "laicizzare",
    "laicizzavate": "laicizzare",
    "laicizzavi": "laicizzare",
    "laicizzavo": "laicizzare",
    "laicizzazioni": "laicizzazione",
    "laicizzerai": "laicizzare",
    "laicizzeran": "laicizzare",
    "laicizzeranno": "laicizzare",
    "laicizzerebbe": "laicizzare",
    "laicizzerebber": "laicizzare",
    "laicizzerebbero": "laicizzare",
    "laicizzerei": "laicizzare",
    "laicizzeremmo": "laicizzare",
    "laicizzeremo": "laicizzare",
    "laicizzereste": "laicizzare",
    "laicizzeresti": "laicizzare",
    "laicizzerete": "laicizzare",
    "laicizzerà": "laicizzare",
    "laicizzerò": "laicizzare",
    "laicizzi": "laicizzare",
    "laicizziamo": "laicizzare",
    "laicizziate": "laicizzare",
    "laicizzin": "laicizzare",
    "laicizzino": "laicizzare",
    "laicizzo": "laicizzare",
    "laicizzò": "laicizzare",
    "laico-socialiste": "laico-socialista",
    "laico-socialisti": "laico-socialista",
    "laida": "laido",
    "laide": "laido",
    "laidi": "laido",
    "lambendo": "lambire",
    "lambente": "lambire",
    "lambenti": "lambire",
    "lambiamo": "lambire",
    "lambiate": "lambire",
    "lambicca": "lambiccare",
    "lambiccai": "lambiccare",
    "lambiccammo": "lambiccare",
    "lambiccan": "lambiccare",
    "lambiccando": "lambiccare",
    "lambiccano": "lambiccare",
    "lambiccante": "lambiccare",
    "lambiccanti": "lambiccare",
    "lambiccar": "lambiccare",
    "lambiccaron": "lambiccare",
    "lambiccarono": "lambiccare",
    "lambiccasse": "lambiccare",
    "lambiccasser": "lambiccare",
    "lambiccassero": "lambiccare",
    "lambiccassi": "lambiccare",
    "lambiccassimo": "lambiccare",
    "lambiccaste": "lambiccare",
    "lambiccasti": "lambiccare",
    "lambiccata": "lambiccare",
    "lambiccate": "lambiccare",
    "lambiccati": "lambiccare",
    "lambiccato": "lambiccare",
    "lambiccava": "lambiccare",
    "lambiccavamo": "lambiccare",
    "lambiccavan": "lambiccare",
    "lambiccavano": "lambiccare",
    "lambiccavate": "lambiccare",
    "lambiccavi": "lambiccare",
    "lambiccavo": "lambiccare",
    "lambiccherai": "lambiccare",
    "lambiccheran": "lambiccare",
    "lambiccheranno": "lambiccare",
    "lambiccherebbe": "lambiccare",
    "lambiccherebber": "lambiccare",
    "lambiccherebbero": "lambiccare",
    "lambiccherei": "lambiccare",
    "lambiccheremmo": "lambiccare",
    "lambiccheremo": "lambiccare",
    "lambicchereste": "lambiccare",
    "lambiccheresti": "lambiccare",
    "lambiccherete": "lambiccare",
    "lambiccherà": "lambiccare",
    "lambiccherò": "lambiccare",
    "lambicchi": "lambiccare",
    "lambicchiamo": "lambiccare",
    "lambicchiate": "lambiccare",
    "lambicchin": "lambiccare",
    "lambicchino": "lambiccare",
    "lambicco": "lambiccare",
    "lambiccò": "lambiccare",
    "lambii": "lambire",
    "lambimmo": "lambire",
    "lambir": "lambire",
    "lambirai": "lambire",
    "lambiran": "lambire",
    "lambiranno": "lambire",
    "lambirebbe": "lambire",
    "lambirebber": "lambire",
    "lambirebbero": "lambire",
    "lambirei": "lambire",
    "lambiremmo": "lambire",
    "lambiremo": "lambire",
    "lambireste": "lambire",
    "lambiresti": "lambire",
    "lambirete": "lambire",
    "lambiron": "lambire",
    "lambirono": "lambire",
    "lambirà": "lambire",
    "lambirò": "lambire",
    "lambisca": "lambire",
    "lambiscan": "lambire",
    "lambiscano": "lambire",
    "lambisce": "lambire",
    "lambisci": "lambire",
    "lambisco": "lambire",
    "lambiscon": "lambire",
    "lambiscono": "lambire",
    "lambisse": "lambire",
    "lambisser": "lambire",
    "lambissero": "lambire",
    "lambissi": "lambire",
    "lambissimo": "lambire",
    "lambiste": "lambire",
    "lambisti": "lambire",
    "lambita": "lambire",
    "lambite": "lambire",
    "lambiti": "lambire",
    "lambito": "lambire",
    "lambiva": "lambire",
    "lambivamo": "lambire",
    "lambivan": "lambire",
    "lambivano": "lambire",
    "lambivate": "lambire",
    "lambivi": "lambire",
    "lambivo": "lambire",
    "lambì": "lambire",
    "lame": "lama",
    "lamenta": "lamentare",
    "lamentai": "lamentare",
    "lamentammo": "lamentare",
    "lamentan": "lamentare",
    "lamentando": "lamentare",
    "lamentano": "lamentare",
    "lamentante": "lamentare",
    "lamentanti": "lamentare",
    "lamentar": "lamentare",
    "lamentaron": "lamentare",
    "lamentarono": "lamentare",
    "lamentasse": "lamentare",
    "lamentasser": "lamentare",
    "lamentassero": "lamentare",
    "lamentassi": "lamentare",
    "lamentassimo": "lamentare",
    "lamentaste": "lamentare",
    "lamentasti": "lamentare",
    "lamentata": "lamentare",
    "lamentate": "lamentare",
    "lamentati": "lamentare",
    "lamentato": "lamentare",
    "lamentava": "lamentare",
    "lamentavamo": "lamentare",
    "lamentavan": "lamentare",
    "lamentavano": "lamentare",
    "lamentavate": "lamentare",
    "lamentavi": "lamentare",
    "lamentavo": "lamentare",
    "lamentazioni": "lamentazione",
    "lamentele": "lamentela",
    "lamenterai": "lamentare",
    "lamenteran": "lamentare",
    "lamenteranno": "lamentare",
    "lamenterebbe": "lamentare",
    "lamenterebber": "lamentare",
    "lamenterebbero": "lamentare",
    "lamenterei": "lamentare",
    "lamenteremmo": "lamentare",
    "lamenteremo": "lamentare",
    "lamentereste": "lamentare",
    "lamenteresti": "lamentare",
    "lamenterete": "lamentare",
    "lamenterà": "lamentare",
    "lamenterò": "lamentare",
    "lamentevoli": "lamentevole",
    "lamenti": "lamento",
    "lamentiamo": "lamentare",
    "lamentiate": "lamentare",
    "lamentin": "lamentare",
    "lamentino": "lamentare",
    "lamento": "lamentare",
    "lamentosa": "lamentoso",
    "lamentose": "lamentoso",
    "lamentosi": "lamentoso",
    "lamentò": "lamentare",
    "lametina": "lametino",
    "lametine": "lametino",
    "lametini": "lametino",
    "lamette": "lametta",
    "lamiere": "lamiera",
    "lamina": "laminare",
    "laminai": "laminare",
    "laminammo": "laminare",
    "laminan": "laminare",
    "laminando": "laminare",
    "laminano": "laminare",
    "laminante": "laminare",
    "laminanti": "laminare",
    "laminar": "laminare",
    "laminaron": "laminare",
    "laminarono": "laminare",
    "laminasse": "laminare",
    "laminasser": "laminare",
    "laminassero": "laminare",
    "laminassi": "laminare",
    "laminassimo": "laminare",
    "laminaste": "laminare",
    "laminasti": "laminare",
    "laminata": "laminato",
    "laminate": "laminato",
    "laminati": "laminato",
    "laminato": "laminare",
    "laminatoi": "laminatoio",
    "laminava": "laminare",
    "laminavamo": "laminare",
    "laminavan": "laminare",
    "laminavano": "laminare",
    "laminavate": "laminare",
    "laminavi": "laminare",
    "laminavo": "laminare",
    "lamine": "lamina",
    "laminerai": "laminare",
    "lamineran": "laminare",
    "lamineranno": "laminare",
    "laminerebbe": "laminare",
    "laminerebber": "laminare",
    "laminerebbero": "laminare",
    "laminerei": "laminare",
    "lamineremmo": "laminare",
    "lamineremo": "laminare",
    "laminereste": "laminare",
    "lamineresti": "laminare",
    "laminerete": "laminare",
    "laminerà": "laminare",
    "laminerò": "laminare",
    "lamini": "laminare",
    "laminiamo": "laminare",
    "laminiate": "laminare",
    "laminin": "laminare",
    "laminino": "laminare",
    "lamino": "laminare",
    "laminò": "laminare",
    "lampadari": "lampadario",
    "lampade": "lampada",
    "lampadine": "lampadina",
    "lampanti": "lampante",
    "lampeggerai": "lampeggiare",
    "lampeggeran": "lampeggiare",
    "lampeggeranno": "lampeggiare",
    "lampeggerebbe": "lampeggiare",
    "lampeggerebber": "lampeggiare",
    "lampeggerebbero": "lampeggiare",
    "lampeggerei": "lampeggiare",
    "lampeggeremmo": "lampeggiare",
    "lampeggeremo": "lampeggiare",
    "lampeggereste": "lampeggiare",
    "lampeggeresti": "lampeggiare",
    "lampeggerete": "lampeggiare",
    "lampeggerà": "lampeggiare",
    "lampeggerò": "lampeggiare",
    "lampeggi": "lampeggiare",
    "lampeggia": "lampeggiare",
    "lampeggiai": "lampeggiare",
    "lampeggiammo": "lampeggiare",
    "lampeggiamo": "lampeggiare",
    "lampeggian": "lampeggiare",
    "lampeggiando": "lampeggiare",
    "lampeggiano": "lampeggiare",
    "lampeggiante": "lampeggiare",
    "lampeggianti": "lampeggiare",
    "lampeggiar": "lampeggiare",
    "lampeggiaron": "lampeggiare",
    "lampeggiarono": "lampeggiare",
    "lampeggiasse": "lampeggiare",
    "lampeggiasser": "lampeggiare",
    "lampeggiassero": "lampeggiare",
    "lampeggiassi": "lampeggiare",
    "lampeggiassimo": "lampeggiare",
    "lampeggiaste": "lampeggiare",
    "lampeggiasti": "lampeggiare",
    "lampeggiata": "lampeggiare",
    "lampeggiate": "lampeggiare",
    "lampeggiati": "lampeggiare",
    "lampeggiato": "lampeggiare",
    "lampeggiatori": "lampeggiatore",
    "lampeggiava": "lampeggiare",
    "lampeggiavamo": "lampeggiare",
    "lampeggiavan": "lampeggiare",
    "lampeggiavano": "lampeggiare",
    "lampeggiavate": "lampeggiare",
    "lampeggiavi": "lampeggiare",
    "lampeggiavo": "lampeggiare",
    "lampeggin": "lampeggiare",
    "lampeggino": "lampeggiare",
    "lampeggio": "lampeggiare",
    "lampeggiò": "lampeggiare",
    "lampi": "lampo",
    "lampioni": "lampione",
    "lamponi": "lampone",
    "lance": "lancia",
    "lancerai": "lanciare",
    "lanceran": "lanciare",
    "lanceranno": "lanciare",
    "lancerebbe": "lanciare",
    "lancerebber": "lanciare",
    "lancerebbero": "lanciare",
    "lancerei": "lanciare",
    "lanceremmo": "lanciare",
    "lanceremo": "lanciare",
    "lancereste": "lanciare",
    "lanceresti": "lanciare",
    "lancerete": "lanciare",
    "lancerà": "lanciare",
    "lancerò": "lanciare",
    "lancette": "lancetta",
    "lanci": "lancio",
    "lancia": "lanciare",
    "lanciai": "lanciare",
    "lanciammo": "lanciare",
    "lanciamo": "lanciare",
    "lancian": "lanciare",
    "lanciando": "lanciare",
    "lanciano": "lanciare",
    "lanciante": "lanciare",
    "lancianti": "lanciare",
    "lanciar": "lanciare",
    "lanciaron": "lanciare",
    "lanciarono": "lanciare",
    "lanciasse": "lanciare",
    "lanciasser": "lanciare",
    "lanciassero": "lanciare",
    "lanciassi": "lanciare",
    "lanciassimo": "lanciare",
    "lanciaste": "lanciare",
    "lanciasti": "lanciare",
    "lanciata": "lanciato",
    "lanciate": "lanciato",
    "lanciati": "lanciato",
    "lanciato": "lanciare",
    "lanciatori": "lanciatore",
    "lanciava": "lanciare",
    "lanciavamo": "lanciare",
    "lanciavan": "lanciare",
    "lanciavano": "lanciare",
    "lanciavate": "lanciare",
    "lanciavi": "lanciare",
    "lanciavo": "lanciare",
    "lancin": "lanciare",
    "lancinanti": "lancinante",
    "lancino": "lanciare",
    "lancio": "lanciare",
    "lanciò": "lanciare",
    "lande": "landa",
    "lane": "lana",
    "languendo": "languire",
    "languente": "languire",
    "languenti": "languire",
    "languiamo": "languire",
    "languiate": "languire",
    "languida": "languido",
    "languide": "languido",
    "languidi": "languido",
    "languii": "languire",
    "languimmo": "languire",
    "languir": "languire",
    "languirai": "languire",
    "languiran": "languire",
    "languiranno": "languire",
    "languirebbe": "languire",
    "languirebber": "languire",
    "languirebbero": "languire",
    "languirei": "languire",
    "languiremmo": "languire",
    "languiremo": "languire",
    "languireste": "languire",
    "languiresti": "languire",
    "languirete": "languire",
    "languiron": "languire",
    "languirono": "languire",
    "languirà": "languire",
    "languirò": "languire",
    "languisca": "languire",
    "languiscan": "languire",
    "languiscano": "languire",
    "languisce": "languire",
    "languisci": "languire",
    "languisco": "languire",
    "languiscon": "languire",
    "languiscono": "languire",
    "languisse": "languire",
    "languisser": "languire",
    "languissero": "languire",
    "languissi": "languire",
    "languissimo": "languire",
    "languiste": "languire",
    "languisti": "languire",
    "languita": "languire",
    "languite": "languire",
    "languiti": "languire",
    "languito": "languire",
    "languiva": "languire",
    "languivamo": "languire",
    "languivan": "languire",
    "languivano": "languire",
    "languivate": "languire",
    "languivi": "languire",
    "languivo": "languire",
    "languori": "languore",
    "languì": "languire",
    "laniera": "laniero",
    "laniere": "laniero",
    "lanieri": "laniero",
    "lanifici": "lanificio",
    "lanosa": "lanoso",
    "lanose": "lanoso",
    "lanosi": "lanoso",
    "lanzichenecchi": "lanzichenecco",
    "laocoontica": "laocoontico",
    "laocoontiche": "laocoontico",
    "laocoontici": "laocoontico",
    "lapalissiana": "lapalissiano",
    "lapalissiane": "lapalissiano",
    "lapalissiani": "lapalissiano",
    "laparoscopica": "laparoscopico",
    "laparoscopiche": "laparoscopico",
    "laparoscopici": "laparoscopico",
    "lapida": "lapidare",
    "lapidai": "lapidare",
    "lapidammo": "lapidare",
    "lapidan": "lapidare",
    "lapidando": "lapidare",
    "lapidano": "lapidare",
    "lapidante": "lapidare",
    "lapidanti": "lapidare",
    "lapidar": "lapidare",
    "lapidari": "lapidario",
    "lapidaria": "lapidario",
    "lapidarie": "lapidario",
    "lapidaron": "lapidare",
    "lapidarono": "lapidare",
    "lapidasse": "lapidare",
    "lapidasser": "lapidare",
    "lapidassero": "lapidare",
    "lapidassi": "lapidare",
    "lapidassimo": "lapidare",
    "lapidaste": "lapidare",
    "lapidasti": "lapidare",
    "lapidata": "lapidare",
    "lapidate": "lapidare",
    "lapidati": "lapidare",
    "lapidato": "lapidare",
    "lapidava": "lapidare",
    "lapidavamo": "lapidare",
    "lapidavan": "lapidare",
    "lapidavano": "lapidare",
    "lapidavate": "lapidare",
    "lapidavi": "lapidare",
    "lapidavo": "lapidare",
    "lapidazioni": "lapidazione",
    "lapidea": "lapideo",
    "lapidee": "lapideo",
    "lapidei": "lapideo",
    "lapiderai": "lapidare",
    "lapideran": "lapidare",
    "lapideranno": "lapidare",
    "lapiderebbe": "lapidare",
    "lapiderebber": "lapidare",
    "lapiderebbero": "lapidare",
    "lapiderei": "lapidare",
    "lapideremmo": "lapidare",
    "lapideremo": "lapidare",
    "lapidereste": "lapidare",
    "lapideresti": "lapidare",
    "lapiderete": "lapidare",
    "lapiderà": "lapidare",
    "lapiderò": "lapidare",
    "lapidi": "lapide",
    "lapidiamo": "lapidare",
    "lapidiate": "lapidare",
    "lapidin": "lapidare",
    "lapidino": "lapidare",
    "lapido": "lapidare",
    "lapidò": "lapidare",
    "lappa": "lappare",
    "lappai": "lappare",
    "lappammo": "lappare",
    "lappan": "lappare",
    "lappando": "lappare",
    "lappano": "lappare",
    "lappante": "lappare",
    "lappanti": "lappare",
    "lappar": "lappare",
    "lapparon": "lappare",
    "lapparono": "lappare",
    "lappasse": "lappare",
    "lappasser": "lappare",
    "lappassero": "lappare",
    "lappassi": "lappare",
    "lappassimo": "lappare",
    "lappaste": "lappare",
    "lappasti": "lappare",
    "lappata": "lappare",
    "lappate": "lappare",
    "lappati": "lappare",
    "lappato": "lappare",
    "lappava": "lappare",
    "lappavamo": "lappare",
    "lappavan": "lappare",
    "lappavano": "lappare",
    "lappavate": "lappare",
    "lappavi": "lappare",
    "lappavo": "lappare",
    "lapperai": "lappare",
    "lapperan": "lappare",
    "lapperanno": "lappare",
    "lapperebbe": "lappare",
    "lapperebber": "lappare",
    "lapperebbero": "lappare",
    "lapperei": "lappare",
    "lapperemmo": "lappare",
    "lapperemo": "lappare",
    "lappereste": "lappare",
    "lapperesti": "lappare",
    "lapperete": "lappare",
    "lapperà": "lappare",
    "lapperò": "lappare",
    "lappi": "lappare",
    "lappiamo": "lappare",
    "lappiate": "lappare",
    "lappin": "lappare",
    "lappino": "lappare",
    "lappo": "lappare",
    "lappò": "lappare",
    "lardella": "lardellare",
    "lardellai": "lardellare",
    "lardellammo": "lardellare",
    "lardellan": "lardellare",
    "lardellando": "lardellare",
    "lardellano": "lardellare",
    "lardellante": "lardellare",
    "lardellanti": "lardellare",
    "lardellar": "lardellare",
    "lardellaron": "lardellare",
    "lardellarono": "lardellare",
    "lardellasse": "lardellare",
    "lardellasser": "lardellare",
    "lardellassero": "lardellare",
    "lardellassi": "lardellare",
    "lardellassimo": "lardellare",
    "lardellaste": "lardellare",
    "lardellasti": "lardellare",
    "lardellata": "lardellare",
    "lardellate": "lardellare",
    "lardellati": "lardellare",
    "lardellato": "lardellare",
    "lardellava": "lardellare",
    "lardellavamo": "lardellare",
    "lardellavan": "lardellare",
    "lardellavano": "lardellare",
    "lardellavate": "lardellare",
    "lardellavi": "lardellare",
    "lardellavo": "lardellare",
    "lardellerai": "lardellare",
    "lardelleran": "lardellare",
    "lardelleranno": "lardellare",
    "lardellerebbe": "lardellare",
    "lardellerebber": "lardellare",
    "lardellerebbero": "lardellare",
    "lardellerei": "lardellare",
    "lardelleremmo": "lardellare",
    "lardelleremo": "lardellare",
    "lardellereste": "lardellare",
    "lardelleresti": "lardellare",
    "lardellerete": "lardellare",
    "lardellerà": "lardellare",
    "lardellerò": "lardellare",
    "lardelli": "lardellare",
    "lardelliamo": "lardellare",
    "lardelliate": "lardellare",
    "lardellin": "lardellare",
    "lardellino": "lardellare",
    "lardello": "lardellare",
    "lardellò": "lardellare",
    "lardi": "lardo",
    "larga": "largo",
    "largan": "largire",
    "largano": "largire",
    "large": "largire",
    "largendo": "largire",
    "largente": "largire",
    "largenti": "largire",
    "larghe": "largo",
    "largheggerai": "largheggiare",
    "largheggeran": "largheggiare",
    "largheggeranno": "largheggiare",
    "largheggerebbe": "largheggiare",
    "largheggerebber": "largheggiare",
    "largheggerebbero": "largheggiare",
    "largheggerei": "largheggiare",
    "largheggeremmo": "largheggiare",
    "largheggeremo": "largheggiare",
    "largheggereste": "largheggiare",
    "largheggeresti": "largheggiare",
    "largheggerete": "largheggiare",
    "largheggerà": "largheggiare",
    "largheggerò": "largheggiare",
    "largheggi": "largheggiare",
    "largheggia": "largheggiare",
    "largheggiai": "largheggiare",
    "largheggiammo": "largheggiare",
    "largheggiamo": "largheggiare",
    "largheggian": "largheggiare",
    "largheggiando": "largheggiare",
    "largheggiano": "largheggiare",
    "largheggiante": "largheggiare",
    "largheggianti": "largheggiare",
    "largheggiar": "largheggiare",
    "largheggiaron": "largheggiare",
    "largheggiarono": "largheggiare",
    "largheggiasse": "largheggiare",
    "largheggiasser": "largheggiare",
    "largheggiassero": "largheggiare",
    "largheggiassi": "largheggiare",
    "largheggiassimo": "largheggiare",
    "largheggiaste": "largheggiare",
    "largheggiasti": "largheggiare",
    "largheggiata": "largheggiare",
    "largheggiate": "largheggiare",
    "largheggiati": "largheggiare",
    "largheggiato": "largheggiare",
    "largheggiava": "largheggiare",
    "largheggiavamo": "largheggiare",
    "largheggiavan": "largheggiare",
    "largheggiavano": "largheggiare",
    "largheggiavate": "largheggiare",
    "largheggiavi": "largheggiare",
    "largheggiavo": "largheggiare",
    "largheggin": "largheggiare",
    "largheggino": "largheggiare",
    "largheggio": "largheggiare",
    "largheggiò": "largheggiare",
    "larghezze": "larghezza",
    "larghi": "largo",
    "largi": "largire",
    "largiamo": "largire",
    "largiate": "largire",
    "largii": "largire",
    "largimmo": "largire",
    "largir": "largire",
    "largirai": "largire",
    "largiran": "largire",
    "largiranno": "largire",
    "largirebbe": "largire",
    "largirebber": "largire",
    "largirebbero": "largire",
    "largirei": "largire",
    "largiremmo": "largire",
    "largiremo": "largire",
    "largireste": "largire",
    "largiresti": "largire",
    "largirete": "largire",
    "largiron": "largire",
    "largirono": "largire",
    "largirà": "largire",
    "largirò": "largire",
    "largisse": "largire",
    "largisser": "largire",
    "largissero": "largire",
    "largissi": "largire",
    "largissimo": "largire",
    "largiste": "largire",
    "largisti": "largire",
    "largita": "largire",
    "largite": "largire",
    "largiti": "largire",
    "largito": "largire",
    "largiva": "largire",
    "largivamo": "largire",
    "largivan": "largire",
    "largivano": "largire",
    "largivate": "largire",
    "largivi": "largire",
    "largivo": "largire",
    "largo": "largire",
    "largon": "largire",
    "largono": "largire",
    "largì": "largire",
    "lariana": "lariano",
    "lariane": "lariano",
    "lariani": "lariano",
    "larici": "larice",
    "laringiti": "laringite",
    "larvali": "larvale",
    "larvata": "larvato",
    "larvate": "larvato",
    "larvati": "larvato",
    "larve": "larva",
    "lasagne": "lasagna",
    "lascerai": "lasciare",
    "lasceran": "lasciare",
    "lasceranno": "lasciare",
    "lascerebbe": "lasciare",
    "lascerebber": "lasciare",
    "lascerebbero": "lasciare",
    "lascerei": "lasciare",
    "lasceremmo": "lasciare",
    "lasceremo": "lasciare",
    "lascereste": "lasciare",
    "lasceresti": "lasciare",
    "lascerete": "lasciare",
    "lascerà": "lasciare",
    "lascerò": "lasciare",
    "lasci": "lasciare",
    "lascia": "lasciare",
    "lasciai": "lasciare",
    "lasciammo": "lasciare",
    "lasciamo": "lasciare",
    "lascian": "lasciare",
    "lasciando": "lasciare",
    "lasciano": "lasciare",
    "lasciante": "lasciare",
    "lascianti": "lasciare",
    "lasciar": "lasciare",
    "lasciaron": "lasciare",
    "lasciarono": "lasciare",
    "lasciasse": "lasciare",
    "lasciasser": "lasciare",
    "lasciassero": "lasciare",
    "lasciassi": "lasciare",
    "lasciassimo": "lasciare",
    "lasciaste": "lasciare",
    "lasciasti": "lasciare",
    "lasciata": "lasciare",
    "lasciate": "lasciata",
    "lasciati": "lasciare",
    "lasciato": "lasciare",
    "lasciava": "lasciare",
    "lasciavamo": "lasciare",
    "lasciavan": "lasciare",
    "lasciavano": "lasciare",
    "lasciavate": "lasciare",
    "lasciavi": "lasciare",
    "lasciavo": "lasciare",
    "lascin": "lasciare",
    "lascino": "lasciare",
    "lascio": "lasciare",
    "lasciti": "lascito",
    "lasciva": "lascivo",
    "lascive": "lascivo",
    "lascivi": "lascivo",
    "lasciò": "lasciare",
    "lassa": "lasso",
    "lassativi": "lassativo",
    "lasse": "lasso",
    "lassi": "lasso",
    "lassismi": "lassismo",
    "lassiste": "lassista",
    "lassisti": "lassista",
    "lastre": "lastra",
    "lastrica": "lastricare",
    "lastricai": "lastricare",
    "lastricammo": "lastricare",
    "lastrican": "lastricare",
    "lastricando": "lastricare",
    "lastricano": "lastricare",
    "lastricante": "lastricare",
    "lastricanti": "lastricare",
    "lastricar": "lastricare",
    "lastricaron": "lastricare",
    "lastricarono": "lastricare",
    "lastricasse": "lastricare",
    "lastricasser": "lastricare",
    "lastricassero": "lastricare",
    "lastricassi": "lastricare",
    "lastricassimo": "lastricare",
    "lastricaste": "lastricare",
    "lastricasti": "lastricare",
    "lastricata": "lastricato",
    "lastricate": "lastricato",
    "lastricati": "lastricato",
    "lastricato": "lastricare",
    "lastricava": "lastricare",
    "lastricavamo": "lastricare",
    "lastricavan": "lastricare",
    "lastricavano": "lastricare",
    "lastricavate": "lastricare",
    "lastricavi": "lastricare",
    "lastricavo": "lastricare",
    "lastricherai": "lastricare",
    "lastricheran": "lastricare",
    "lastricheranno": "lastricare",
    "lastricherebbe": "lastricare",
    "lastricherebber": "lastricare",
    "lastricherebbero": "lastricare",
    "lastricherei": "lastricare",
    "lastricheremmo": "lastricare",
    "lastricheremo": "lastricare",
    "lastrichereste": "lastricare",
    "lastricheresti": "lastricare",
    "lastricherete": "lastricare",
    "lastricherà": "lastricare",
    "lastricherò": "lastricare",
    "lastrichi": "lastricare",
    "lastrichiamo": "lastricare",
    "lastrichiate": "lastricare",
    "lastrichin": "lastricare",
    "lastrichino": "lastricare",
    "lastrico": "lastricare",
    "lastricò": "lastricare",
    "lastroni": "lastrone",
    "latenti": "latente",
    "laterali": "laterale",
    "lati": "lato",
    "latifondi": "latifondo",
    "latifondisti": "latifondista",
    "latina": "latino",
    "latine": "latino",
    "latineggerai": "latineggiare",
    "latineggeran": "latineggiare",
    "latineggeranno": "latineggiare",
    "latineggerebbe": "latineggiare",
    "latineggerebber": "latineggiare",
    "latineggerebbero": "latineggiare",
    "latineggerei": "latineggiare",
    "latineggeremmo": "latineggiare",
    "latineggeremo": "latineggiare",
    "latineggereste": "latineggiare",
    "latineggeresti": "latineggiare",
    "latineggerete": "latineggiare",
    "latineggerà": "latineggiare",
    "latineggerò": "latineggiare",
    "latineggi": "latineggiare",
    "latineggia": "latineggiare",
    "latineggiai": "latineggiare",
    "latineggiammo": "latineggiare",
    "latineggiamo": "latineggiare",
    "latineggian": "latineggiare",
    "latineggiando": "latineggiare",
    "latineggiano": "latineggiare",
    "latineggiante": "latineggiare",
    "latineggianti": "latineggiare",
    "latineggiar": "latineggiare",
    "latineggiaron": "latineggiare",
    "latineggiarono": "latineggiare",
    "latineggiasse": "latineggiare",
    "latineggiasser": "latineggiare",
    "latineggiassero": "latineggiare",
    "latineggiassi": "latineggiare",
    "latineggiassimo": "latineggiare",
    "latineggiaste": "latineggiare",
    "latineggiasti": "latineggiare",
    "latineggiata": "latineggiare",
    "latineggiate": "latineggiare",
    "latineggiati": "latineggiare",
    "latineggiato": "latineggiare",
    "latineggiava": "latineggiare",
    "latineggiavamo": "latineggiare",
    "latineggiavan": "latineggiare",
    "latineggiavano": "latineggiare",
    "latineggiavate": "latineggiare",
    "latineggiavi": "latineggiare",
    "latineggiavo": "latineggiare",
    "latineggin": "latineggiare",
    "latineggino": "latineggiare",
    "latineggio": "latineggiare",
    "latineggiò": "latineggiare",
    "latini": "latino",
    "latinisti": "latinista",
    "latinizza": "latinizzare",
    "latinizzai": "latinizzare",
    "latinizzammo": "latinizzare",
    "latinizzan": "latinizzare",
    "latinizzando": "latinizzare",
    "latinizzano": "latinizzare",
    "latinizzante": "latinizzare",
    "latinizzanti": "latinizzare",
    "latinizzar": "latinizzare",
    "latinizzaron": "latinizzare",
    "latinizzarono": "latinizzare",
    "latinizzasse": "latinizzare",
    "latinizzasser": "latinizzare",
    "latinizzassero": "latinizzare",
    "latinizzassi": "latinizzare",
    "latinizzassimo": "latinizzare",
    "latinizzaste": "latinizzare",
    "latinizzasti": "latinizzare",
    "latinizzata": "latinizzare",
    "latinizzate": "latinizzare",
    "latinizzati": "latinizzare",
    "latinizzato": "latinizzare",
    "latinizzava": "latinizzare",
    "latinizzavamo": "latinizzare",
    "latinizzavan": "latinizzare",
    "latinizzavano": "latinizzare",
    "latinizzavate": "latinizzare",
    "latinizzavi": "latinizzare",
    "latinizzavo": "latinizzare",
    "latinizzerai": "latinizzare",
    "latinizzeran": "latinizzare",
    "latinizzeranno": "latinizzare",
    "latinizzerebbe": "latinizzare",
    "latinizzerebber": "latinizzare",
    "latinizzerebbero": "latinizzare",
    "latinizzerei": "latinizzare",
    "latinizzeremmo": "latinizzare",
    "latinizzeremo": "latinizzare",
    "latinizzereste": "latinizzare",
    "latinizzeresti": "latinizzare",
    "latinizzerete": "latinizzare",
    "latinizzerà": "latinizzare",
    "latinizzerò": "latinizzare",
    "latinizzi": "latinizzare",
    "latinizziamo": "latinizzare",
    "latinizziate": "latinizzare",
    "latinizzin": "latinizzare",
    "latinizzino": "latinizzare",
    "latinizzo": "latinizzare",
    "latinizzò": "latinizzare",
    "latino-americana": "latino-americano",
    "latino-americane": "latino-americano",
    "latino-americani": "latino-americano",
    "latinoamericana": "latinoamericano",
    "latinoamericane": "latinoamericano",
    "latinoamericani": "latinoamericano",
    "latita": "latitare",
    "latitai": "latitare",
    "latitammo": "latitare",
    "latitan": "latitare",
    "latitando": "latitare",
    "latitano": "latitare",
    "latitante": "latitare",
    "latitanti": "latitare",
    "latitanze": "latitanza",
    "latitar": "latitare",
    "latitaron": "latitare",
    "latitarono": "latitare",
    "latitasse": "latitare",
    "latitasser": "latitare",
    "latitassero": "latitare",
    "latitassi": "latitare",
    "latitassimo": "latitare",
    "latitaste": "latitare",
    "latitasti": "latitare",
    "latitata": "latitare",
    "latitate": "latitare",
    "latitati": "latitare",
    "latitato": "latitare",
    "latitava": "latitare",
    "latitavamo": "latitare",
    "latitavan": "latitare",
    "latitavano": "latitare",
    "latitavate": "latitare",
    "latitavi": "latitare",
    "latitavo": "latitare",
    "latiterai": "latitare",
    "latiteran": "latitare",
    "latiteranno": "latitare",
    "latiterebbe": "latitare",
    "latiterebber": "latitare",
    "latiterebbero": "latitare",
    "latiterei": "latitare",
    "latiteremmo": "latitare",
    "latiteremo": "latitare",
    "latitereste": "latitare",
    "latiteresti": "latitare",
    "latiterete": "latitare",
    "latiterà": "latitare",
    "latiterò": "latitare",
    "latiti": "latitare",
    "latitiamo": "latitare",
    "latitiate": "latitare",
    "latitin": "latitare",
    "latitino": "latitare",
    "latito": "latitare",
    "latitudini": "latitudine",
    "latitò": "latitare",
    "latra": "latrare",
    "latrai": "latrare",
    "latrammo": "latrare",
    "latran": "latrare",
    "latrando": "latrare",
    "latrano": "latrare",
    "latrante": "latrare",
    "latranti": "latrare",
    "latrar": "latrare",
    "latraron": "latrare",
    "latrarono": "latrare",
    "latrasse": "latrare",
    "latrasser": "latrare",
    "latrassero": "latrare",
    "latrassi": "latrare",
    "latrassimo": "latrare",
    "latraste": "latrare",
    "latrasti": "latrare",
    "latrata": "latrare",
    "latrate": "latrare",
    "latrati": "latrato",
    "latrato": "latrare",
    "latrava": "latrare",
    "latravamo": "latrare",
    "latravan": "latrare",
    "latravano": "latrare",
    "latravate": "latrare",
    "latravi": "latrare",
    "latravo": "latrare",
    "latrerai": "latrare",
    "latreran": "latrare",
    "latreranno": "latrare",
    "latrerebbe": "latrare",
    "latrerebber": "latrare",
    "latrerebbero": "latrare",
    "latrerei": "latrare",
    "latreremmo": "latrare",
    "latreremo": "latrare",
    "latrereste": "latrare",
    "latreresti": "latrare",
    "latrerete": "latrare",
    "latrerà": "latrare",
    "latrerò": "latrare",
    "latri": "latrare",
    "latriamo": "latrare",
    "latriate": "latrare",
    "latrin": "latrare",
    "latrine": "latrina",
    "latrino": "latrare",
    "latro": "latrare",
    "latrò": "latrare",
    "lattai": "lattaio",
    "lattanti": "lattante",
    "latte": "latta",
    "lattea": "latteo",
    "lattee": "latteo",
    "lattei": "latteo",
    "latterie": "latteria",
    "latti": "latte",
    "lattica": "lattico",
    "lattiche": "lattico",
    "lattici": "lattico",
    "latticini": "latticino",
    "lattiera": "lattiero",
    "lattiere": "lattiero",
    "lattieri": "lattiero",
    "lattiero-caseari": "lattiero-caseario",
    "lattiero-casearia": "lattiero-caseario",
    "lattiero-casearie": "lattiero-caseario",
    "lattiginosa": "lattiginoso",
    "lattiginose": "lattiginoso",
    "lattiginosi": "lattiginoso",
    "lattine": "lattina",
    "laudi": "laude",
    "laurea": "laureare",
    "laureai": "laureare",
    "laureammo": "laureare",
    "laurean": "laureare",
    "laureanda": "laureando",
    "laureande": "laureando",
    "laureandi": "laureando",
    "laureando": "laureare",
    "laureano": "laureare",
    "laureante": "laureare",
    "laureanti": "laureare",
    "laurear": "laureare",
    "laurearon": "laureare",
    "laurearono": "laureare",
    "laureasse": "laureare",
    "laureasser": "laureare",
    "laureassero": "laureare",
    "laureassi": "laureare",
    "laureassimo": "laureare",
    "laureaste": "laureare",
    "laureasti": "laureare",
    "laureata": "laureato",
    "laureate": "laureato",
    "laureati": "laureato",
    "laureato": "laureare",
    "laureava": "laureare",
    "laureavamo": "laureare",
    "laureavan": "laureare",
    "laureavano": "laureare",
    "laureavate": "laureare",
    "laureavi": "laureare",
    "laureavo": "laureare",
    "lauree": "laurea",
    "laureerai": "laureare",
    "laureeran": "laureare",
    "laureeranno": "laureare",
    "laureerebbe": "laureare",
    "laureerebber": "laureare",
    "laureerebbero": "laureare",
    "laureerei": "laureare",
    "laureeremmo": "laureare",
    "laureeremo": "laureare",
    "laureereste": "laureare",
    "laureeresti": "laureare",
    "laureerete": "laureare",
    "laureerà": "laureare",
    "laureerò": "laureare",
    "laurei": "laureare",
    "laureiamo": "laureare",
    "laureiate": "laureare",
    "laurein": "laureare",
    "laureino": "laureare",
    "laureo": "laureare",
    "laureò": "laureare",
    "lauta": "lauto",
    "laute": "lauto",
    "lauti": "lauto",
    "lava": "lavare",
    "lavaggi": "lavaggio",
    "lavagne": "lavagna",
    "lavai": "lavare",
    "lavammo": "lavare",
    "lavan": "lavare",
    "lavandaie": "lavandaia",
    "lavande": "lavanda",
    "lavanderie": "lavanderia",
    "lavandini": "lavandino",
    "lavando": "lavare",
    "lavano": "lavare",
    "lavante": "lavare",
    "lavanti": "lavare",
    "lavar": "lavare",
    "lavaron": "lavare",
    "lavarono": "lavare",
    "lavasse": "lavare",
    "lavasser": "lavare",
    "lavassero": "lavare",
    "lavassi": "lavare",
    "lavassimo": "lavare",
    "lavaste": "lavare",
    "lavasti": "lavare",
    "lavata": "lavare",
    "lavate": "lavare",
    "lavati": "lavare",
    "lavativi": "lavativo",
    "lavato": "lavare",
    "lavatoi": "lavatoio",
    "lavatrici": "lavatrice",
    "lavava": "lavare",
    "lavavamo": "lavare",
    "lavavan": "lavare",
    "lavavano": "lavare",
    "lavavate": "lavare",
    "lavavi": "lavare",
    "lavavo": "lavare",
    "lave": "lava",
    "laverai": "lavare",
    "laveran": "lavare",
    "laveranno": "lavare",
    "laverebbe": "lavare",
    "laverebber": "lavare",
    "laverebbero": "lavare",
    "laverei": "lavare",
    "laveremmo": "lavare",
    "laveremo": "lavare",
    "lavereste": "lavare",
    "laveresti": "lavare",
    "laverete": "lavare",
    "laverà": "lavare",
    "laverò": "lavare",
    "lavi": "lavare",
    "laviamo": "lavare",
    "laviate": "lavare",
    "lavica": "lavico",
    "laviche": "lavico",
    "lavici": "lavico",
    "lavin": "lavare",
    "lavino": "lavare",
    "lavo": "lavare",
    "lavora": "lavorare",
    "lavoracci": "lavoraccio",
    "lavorai": "lavorare",
    "lavorammo": "lavorare",
    "lavoran": "lavorare",
    "lavorando": "lavorare",
    "lavorano": "lavorare",
    "lavorante": "lavorare",
    "lavoranti": "lavorare",
    "lavorar": "lavorare",
    "lavoraron": "lavorare",
    "lavorarono": "lavorare",
    "lavorasse": "lavorare",
    "lavorasser": "lavorare",
    "lavorassero": "lavorare",
    "lavorassi": "lavorare",
    "lavorassimo": "lavorare",
    "lavoraste": "lavorare",
    "lavorasti": "lavorare",
    "lavorata": "lavorato",
    "lavorate": "lavorato",
    "lavorati": "lavorato",
    "lavorativa": "lavorativo",
    "lavorative": "lavorativo",
    "lavorativi": "lavorativo",
    "lavorato": "lavorare",
    "lavoratori": "lavoratore",
    "lavoratrici": "lavoratrice",
    "lavorava": "lavorare",
    "lavoravamo": "lavorare",
    "lavoravan": "lavorare",
    "lavoravano": "lavorare",
    "lavoravate": "lavorare",
    "lavoravi": "lavorare",
    "lavoravo": "lavorare",
    "lavorazioni": "lavorazione",
    "lavorerai": "lavorare",
    "lavoreran": "lavorare",
    "lavoreranno": "lavorare",
    "lavorerebbe": "lavorare",
    "lavorerebber": "lavorare",
    "lavorerebbero": "lavorare",
    "lavorerei": "lavorare",
    "lavoreremmo": "lavorare",
    "lavoreremo": "lavorare",
    "lavorereste": "lavorare",
    "lavoreresti": "lavorare",
    "lavorerete": "lavorare",
    "lavorerà": "lavorare",
    "lavorerò": "lavorare",
    "lavoretti": "lavoretto",
    "lavori": "lavoro",
    "lavoriamo": "lavorare",
    "lavoriate": "lavorare",
    "lavoricchi": "lavoricchiare",
    "lavoricchia": "lavoricchiare",
    "lavoricchiai": "lavoricchiare",
    "lavoricchiammo": "lavoricchiare",
    "lavoricchiamo": "lavoricchiare",
    "lavoricchian": "lavoricchiare",
    "lavoricchiando": "lavoricchiare",
    "lavoricchiano": "lavoricchiare",
    "lavoricchiante": "lavoricchiare",
    "lavoricchianti": "lavoricchiare",
    "lavoricchiar": "lavoricchiare",
    "lavoricchiaron": "lavoricchiare",
    "lavoricchiarono": "lavoricchiare",
    "lavoricchiasse": "lavoricchiare",
    "lavoricchiasser": "lavoricchiare",
    "lavoricchiassero": "lavoricchiare",
    "lavoricchiassi": "lavoricchiare",
    "lavoricchiassimo": "lavoricchiare",
    "lavoricchiaste": "lavoricchiare",
    "lavoricchiasti": "lavoricchiare",
    "lavoricchiata": "lavoricchiare",
    "lavoricchiate": "lavoricchiare",
    "lavoricchiati": "lavoricchiare",
    "lavoricchiato": "lavoricchiare",
    "lavoricchiava": "lavoricchiare",
    "lavoricchiavamo": "lavoricchiare",
    "lavoricchiavan": "lavoricchiare",
    "lavoricchiavano": "lavoricchiare",
    "lavoricchiavate": "lavoricchiare",
    "lavoricchiavi": "lavoricchiare",
    "lavoricchiavo": "lavoricchiare",
    "lavoricchierai": "lavoricchiare",
    "lavoricchieran": "lavoricchiare",
    "lavoricchieranno": "lavoricchiare",
    "lavoricchierebbe": "lavoricchiare",
    "lavoricchierebber": "lavoricchiare",
    "lavoricchierebbero": "lavoricchiare",
    "lavoricchierei": "lavoricchiare",
    "lavoricchieremmo": "lavoricchiare",
    "lavoricchieremo": "lavoricchiare",
    "lavoricchiereste": "lavoricchiare",
    "lavoricchieresti": "lavoricchiare",
    "lavoricchierete": "lavoricchiare",
    "lavoricchierà": "lavoricchiare",
    "lavoricchierò": "lavoricchiare",
    "lavoricchin": "lavoricchiare",
    "lavoricchino": "lavoricchiare",
    "lavoricchio": "lavoricchiare",
    "lavoricchiò": "lavoricchiare",
    "lavorin": "lavorare",
    "lavorino": "lavorare",
    "lavoro": "lavorare",
    "lavorìi": "lavorìo",
    "lavorò": "lavorare",
    "lavò": "lavare",
    "laziali": "laziale",
    "lazza": "lazzo",
    "lazzaretti": "lazzaretto",
    "lazzaroni": "lazzarone",
    "lazze": "lazzo",
    "lazzi": "lazzo",
    "le": "la",
    "leaderini": "leaderino",
    "leaders": "leader",
    "leali": "leale",
    "lebbre": "lebbra",
    "lebbrosa": "lebbroso",
    "lebbrosari": "lebbrosario",
    "lebbrose": "lebbroso",
    "lebbrosi": "lebbroso",
    "lecca": "leccare",
    "leccai": "leccare",
    "leccammo": "leccare",
    "leccan": "leccare",
    "leccando": "leccare",
    "leccano": "leccare",
    "leccante": "leccare",
    "leccanti": "leccare",
    "leccar": "leccare",
    "leccaron": "leccare",
    "leccarono": "leccare",
    "leccasse": "leccare",
    "leccasser": "leccare",
    "leccassero": "leccare",
    "leccassi": "leccare",
    "leccassimo": "leccare",
    "leccaste": "leccare",
    "leccasti": "leccare",
    "leccata": "leccare",
    "leccate": "leccare",
    "leccati": "leccare",
    "leccato": "leccare",
    "leccava": "leccare",
    "leccavamo": "leccare",
    "leccavan": "leccare",
    "leccavano": "leccare",
    "leccavate": "leccare",
    "leccavi": "leccare",
    "leccavo": "leccare",
    "leccesi": "leccese",
    "leccherai": "leccare",
    "leccheran": "leccare",
    "leccheranno": "leccare",
    "leccherebbe": "leccare",
    "leccherebber": "leccare",
    "leccherebbero": "leccare",
    "leccherei": "leccare",
    "leccheremmo": "leccare",
    "leccheremo": "leccare",
    "lecchereste": "leccare",
    "leccheresti": "leccare",
    "leccherete": "leccare",
    "leccherà": "leccare",
    "leccherò": "leccare",
    "lecchesi": "lecchese",
    "lecchi": "leccare",
    "lecchiamo": "leccare",
    "lecchiate": "leccare",
    "lecchin": "leccare",
    "lecchino": "leccare",
    "lecci": "leccio",
    "lecco": "leccare",
    "leccornie": "leccornia",
    "leccò": "leccare",
    "lecita": "lecito",
    "lecite": "lecito",
    "leciti": "lecito",
    "leda": "ledere",
    "ledan": "ledere",
    "ledano": "ledere",
    "lede": "ledere",
    "ledei": "ledere",
    "ledemmo": "ledere",
    "ledendo": "ledere",
    "ledente": "ledere",
    "ledenti": "ledere",
    "leder": "ledere",
    "lederai": "ledere",
    "lederan": "ledere",
    "lederanno": "ledere",
    "lederebbe": "ledere",
    "lederebber": "ledere",
    "lederebbero": "ledere",
    "lederei": "ledere",
    "lederemmo": "ledere",
    "lederemo": "ledere",
    "ledereste": "ledere",
    "lederesti": "ledere",
    "lederete": "ledere",
    "lederon": "ledere",
    "lederono": "ledere",
    "lederà": "ledere",
    "lederò": "ledere",
    "ledesse": "ledere",
    "ledesser": "ledere",
    "ledessero": "ledere",
    "ledessi": "ledere",
    "ledessimo": "ledere",
    "ledeste": "ledere",
    "ledesti": "ledere",
    "ledete": "ledere",
    "ledeva": "ledere",
    "ledevamo": "ledere",
    "ledevan": "ledere",
    "ledevano": "ledere",
    "ledevate": "ledere",
    "ledevi": "ledere",
    "ledevo": "ledere",
    "ledi": "ledere",
    "lediamo": "ledere",
    "lediate": "ledere",
    "ledo": "ledere",
    "ledon": "ledere",
    "ledono": "ledere",
    "leduta": "ledere",
    "ledute": "ledere",
    "leduti": "ledere",
    "leduto": "ledere",
    "ledè": "ledere",
    "lega": "legare",
    "legacci": "legaccio",
    "legai": "legare",
    "legali": "legale",
    "legalitari": "legalitario",
    "legalitaria": "legalitario",
    "legalitarie": "legalitario",
    "legalizza": "legalizzare",
    "legalizzai": "legalizzare",
    "legalizzammo": "legalizzare",
    "legalizzan": "legalizzare",
    "legalizzando": "legalizzare",
    "legalizzano": "legalizzare",
    "legalizzante": "legalizzare",
    "legalizzanti": "legalizzare",
    "legalizzar": "legalizzare",
    "legalizzaron": "legalizzare",
    "legalizzarono": "legalizzare",
    "legalizzasse": "legalizzare",
    "legalizzasser": "legalizzare",
    "legalizzassero": "legalizzare",
    "legalizzassi": "legalizzare",
    "legalizzassimo": "legalizzare",
    "legalizzaste": "legalizzare",
    "legalizzasti": "legalizzare",
    "legalizzata": "legalizzare",
    "legalizzate": "legalizzare",
    "legalizzati": "legalizzare",
    "legalizzato": "legalizzare",
    "legalizzava": "legalizzare",
    "legalizzavamo": "legalizzare",
    "legalizzavan": "legalizzare",
    "legalizzavano": "legalizzare",
    "legalizzavate": "legalizzare",
    "legalizzavi": "legalizzare",
    "legalizzavo": "legalizzare",
    "legalizzazioni": "legalizzazione",
    "legalizzerai": "legalizzare",
    "legalizzeran": "legalizzare",
    "legalizzeranno": "legalizzare",
    "legalizzerebbe": "legalizzare",
    "legalizzerebber": "legalizzare",
    "legalizzerebbero": "legalizzare",
    "legalizzerei": "legalizzare",
    "legalizzeremmo": "legalizzare",
    "legalizzeremo": "legalizzare",
    "legalizzereste": "legalizzare",
    "legalizzeresti": "legalizzare",
    "legalizzerete": "legalizzare",
    "legalizzerà": "legalizzare",
    "legalizzerò": "legalizzare",
    "legalizzi": "legalizzare",
    "legalizziamo": "legalizzare",
    "legalizziate": "legalizzare",
    "legalizzin": "legalizzare",
    "legalizzino": "legalizzare",
    "legalizzo": "legalizzare",
    "legalizzò": "legalizzare",
    "legamenti": "legamento",
    "legami": "legame",
    "legammo": "legare",
    "legan": "legare",
    "legando": "legare",
    "legano": "legare",
    "legante": "legare",
    "leganti": "legare",
    "legar": "legare",
    "legaron": "legare",
    "legarono": "legare",
    "legasse": "legare",
    "legasser": "legare",
    "legassero": "legare",
    "legassi": "legare",
    "legassimo": "legare",
    "legaste": "legare",
    "legasti": "legare",
    "legata": "legato",
    "legate": "legato",
    "legati": "legato",
    "legato": "legare",
    "legature": "legatura",
    "legava": "legare",
    "legavamo": "legare",
    "legavan": "legare",
    "legavano": "legare",
    "legavate": "legare",
    "legavi": "legare",
    "legavo": "legare",
    "legazioni": "legazione",
    "legga": "leggere",
    "leggan": "leggere",
    "leggano": "leggere",
    "legge": "leggere",
    "leggemmo": "leggere",
    "leggendari": "leggendario",
    "leggendaria": "leggendario",
    "leggendarie": "leggendario",
    "leggende": "leggenda",
    "leggendo": "leggere",
    "leggente": "leggere",
    "leggenti": "leggere",
    "legger": "leggere",
    "leggera": "leggero",
    "leggerai": "leggere",
    "leggeran": "leggere",
    "leggeranno": "leggere",
    "leggere": "leggero",
    "leggerebbe": "leggere",
    "leggerebber": "leggere",
    "leggerebbero": "leggere",
    "leggerei": "leggere",
    "leggeremmo": "leggere",
    "leggeremo": "leggere",
    "leggereste": "leggere",
    "leggeresti": "leggere",
    "leggerete": "leggere",
    "leggerezze": "leggerezza",
    "leggeri": "leggero",
    "leggerina": "leggerino",
    "leggerine": "leggerino",
    "leggerini": "leggerino",
    "leggerà": "leggere",
    "leggerò": "leggere",
    "leggesse": "leggere",
    "leggesser": "leggere",
    "leggessero": "leggere",
    "leggessi": "leggere",
    "leggessimo": "leggere",
    "leggeste": "leggere",
    "leggesti": "leggere",
    "leggete": "leggere",
    "leggeva": "leggere",
    "leggevamo": "leggere",
    "leggevan": "leggere",
    "leggevano": "leggere",
    "leggevate": "leggere",
    "leggevi": "leggere",
    "leggevo": "leggere",
    "leggi": "leggere",
    "leggi-delega": "legge-delega",
    "leggi-quadro": "legge-quadro",
    "leggiadra": "leggiadro",
    "leggiadre": "leggiadro",
    "leggiadri": "leggiadro",
    "leggiamo": "leggere",
    "leggiate": "leggere",
    "leggibili": "leggibile",
    "leggicchi": "leggicchiare",
    "leggicchia": "leggicchiare",
    "leggicchiai": "leggicchiare",
    "leggicchiammo": "leggicchiare",
    "leggicchiamo": "leggicchiare",
    "leggicchian": "leggicchiare",
    "leggicchiando": "leggicchiare",
    "leggicchiano": "leggicchiare",
    "leggicchiante": "leggicchiare",
    "leggicchianti": "leggicchiare",
    "leggicchiar": "leggicchiare",
    "leggicchiaron": "leggicchiare",
    "leggicchiarono": "leggicchiare",
    "leggicchiasse": "leggicchiare",
    "leggicchiasser": "leggicchiare",
    "leggicchiassero": "leggicchiare",
    "leggicchiassi": "leggicchiare",
    "leggicchiassimo": "leggicchiare",
    "leggicchiaste": "leggicchiare",
    "leggicchiasti": "leggicchiare",
    "leggicchiata": "leggicchiare",
    "leggicchiate": "leggicchiare",
    "leggicchiati": "leggicchiare",
    "leggicchiato": "leggicchiare",
    "leggicchiava": "leggicchiare",
    "leggicchiavamo": "leggicchiare",
    "leggicchiavan": "leggicchiare",
    "leggicchiavano": "leggicchiare",
    "leggicchiavate": "leggicchiare",
    "leggicchiavi": "leggicchiare",
    "leggicchiavo": "leggicchiare",
    "leggicchierai": "leggicchiare",
    "leggicchieran": "leggicchiare",
    "leggicchieranno": "leggicchiare",
    "leggicchierebbe": "leggicchiare",
    "leggicchierebber": "leggicchiare",
    "leggicchierebbero": "leggicchiare",
    "leggicchierei": "leggicchiare",
    "leggicchieremmo": "leggicchiare",
    "leggicchieremo": "leggicchiare",
    "leggicchiereste": "leggicchiare",
    "leggicchieresti": "leggicchiare",
    "leggicchierete": "leggicchiare",
    "leggicchierà": "leggicchiare",
    "leggicchierò": "leggicchiare",
    "leggicchin": "leggicchiare",
    "leggicchino": "leggicchiare",
    "leggicchio": "leggicchiare",
    "leggicchiò": "leggicchiare",
    "leggii": "leggio",
    "leggine": "leggina",
    "leggiucchi": "leggiucchiare",
    "leggiucchia": "leggiucchiare",
    "leggiucchiai": "leggiucchiare",
    "leggiucchiammo": "leggiucchiare",
    "leggiucchiamo": "leggiucchiare",
    "leggiucchian": "leggiucchiare",
    "leggiucchiando": "leggiucchiare",
    "leggiucchiano": "leggiucchiare",
    "leggiucchiante": "leggiucchiare",
    "leggiucchianti": "leggiucchiare",
    "leggiucchiar": "leggiucchiare",
    "leggiucchiaron": "leggiucchiare",
    "leggiucchiarono": "leggiucchiare",
    "leggiucchiasse": "leggiucchiare",
    "leggiucchiasser": "leggiucchiare",
    "leggiucchiassero": "leggiucchiare",
    "leggiucchiassi": "leggiucchiare",
    "leggiucchiassimo": "leggiucchiare",
    "leggiucchiaste": "leggiucchiare",
    "leggiucchiasti": "leggiucchiare",
    "leggiucchiata": "leggiucchiare",
    "leggiucchiate": "leggiucchiare",
    "leggiucchiati": "leggiucchiare",
    "leggiucchiato": "leggiucchiare",
    "leggiucchiava": "leggiucchiare",
    "leggiucchiavamo": "leggiucchiare",
    "leggiucchiavan": "leggiucchiare",
    "leggiucchiavano": "leggiucchiare",
    "leggiucchiavate": "leggiucchiare",
    "leggiucchiavi": "leggiucchiare",
    "leggiucchiavo": "leggiucchiare",
    "leggiucchierai": "leggiucchiare",
    "leggiucchieran": "leggiucchiare",
    "leggiucchieranno": "leggiucchiare",
    "leggiucchierebbe": "leggiucchiare",
    "leggiucchierebber": "leggiucchiare",
    "leggiucchierebbero": "leggiucchiare",
    "leggiucchierei": "leggiucchiare",
    "leggiucchieremmo": "leggiucchiare",
    "leggiucchieremo": "leggiucchiare",
    "leggiucchiereste": "leggiucchiare",
    "leggiucchieresti": "leggiucchiare",
    "leggiucchierete": "leggiucchiare",
    "leggiucchierà": "leggiucchiare",
    "leggiucchierò": "leggiucchiare",
    "leggiucchin": "leggiucchiare",
    "leggiucchino": "leggiucchiare",
    "leggiucchio": "leggiucchiare",
    "leggiucchiò": "leggiucchiare",
    "leggo": "leggere",
    "leggon": "leggere",
    "leggono": "leggere",
    "leghe": "lega",
    "legherai": "legare",
    "legheran": "legare",
    "legheranno": "legare",
    "legherebbe": "legare",
    "legherebber": "legare",
    "legherebbero": "legare",
    "legherei": "legare",
    "legheremmo": "legare",
    "legheremo": "legare",
    "leghereste": "legare",
    "legheresti": "legare",
    "legherete": "legare",
    "legherà": "legare",
    "legherò": "legare",
    "leghi": "legare",
    "leghiamo": "legare",
    "leghiate": "legare",
    "leghin": "legare",
    "leghino": "legare",
    "leghismi": "leghismo",
    "leghiste": "leghista",
    "leghisti": "leghista",
    "legifera": "legiferare",
    "legiferai": "legiferare",
    "legiferammo": "legiferare",
    "legiferan": "legiferare",
    "legiferando": "legiferare",
    "legiferano": "legiferare",
    "legiferante": "legiferare",
    "legiferanti": "legiferare",
    "legiferar": "legiferare",
    "legiferaron": "legiferare",
    "legiferarono": "legiferare",
    "legiferasse": "legiferare",
    "legiferasser": "legiferare",
    "legiferassero": "legiferare",
    "legiferassi": "legiferare",
    "legiferassimo": "legiferare",
    "legiferaste": "legiferare",
    "legiferasti": "legiferare",
    "legiferata": "legiferare",
    "legiferate": "legiferare",
    "legiferati": "legiferare",
    "legiferato": "legiferare",
    "legiferava": "legiferare",
    "legiferavamo": "legiferare",
    "legiferavan": "legiferare",
    "legiferavano": "legiferare",
    "legiferavate": "legiferare",
    "legiferavi": "legiferare",
    "legiferavo": "legiferare",
    "legifererai": "legiferare",
    "legifereran": "legiferare",
    "legifereranno": "legiferare",
    "legifererebbe": "legiferare",
    "legifererebber": "legiferare",
    "legifererebbero": "legiferare",
    "legifererei": "legiferare",
    "legifereremmo": "legiferare",
    "legifereremo": "legiferare",
    "legiferereste": "legiferare",
    "legifereresti": "legiferare",
    "legifererete": "legiferare",
    "legifererà": "legiferare",
    "legifererò": "legiferare",
    "legiferi": "legiferare",
    "legiferiamo": "legiferare",
    "legiferiate": "legiferare",
    "legiferin": "legiferare",
    "legiferino": "legiferare",
    "legifero": "legiferare",
    "legiferò": "legiferare",
    "legionari": "legionario",
    "legionaria": "legionario",
    "legionarie": "legionario",
    "legioni": "legione",
    "legislativa": "legislativo",
    "legislative": "legislativo",
    "legislativi": "legislativo",
    "legislatori": "legislatore",
    "legislature": "legislatura",
    "legislazioni": "legislazione",
    "legittima": "legittimo",
    "legittimai": "legittimare",
    "legittimammo": "legittimare",
    "legittiman": "legittimare",
    "legittimando": "legittimare",
    "legittimano": "legittimare",
    "legittimante": "legittimare",
    "legittimanti": "legittimare",
    "legittimar": "legittimare",
    "legittimaron": "legittimare",
    "legittimarono": "legittimare",
    "legittimasse": "legittimare",
    "legittimasser": "legittimare",
    "legittimassero": "legittimare",
    "legittimassi": "legittimare",
    "legittimassimo": "legittimare",
    "legittimaste": "legittimare",
    "legittimasti": "legittimare",
    "legittimata": "legittimare",
    "legittimate": "legittimare",
    "legittimati": "legittimare",
    "legittimato": "legittimare",
    "legittimava": "legittimare",
    "legittimavamo": "legittimare",
    "legittimavan": "legittimare",
    "legittimavano": "legittimare",
    "legittimavate": "legittimare",
    "legittimavi": "legittimare",
    "legittimavo": "legittimare",
    "legittimazioni": "legittimazione",
    "legittime": "legittimo",
    "legittimerai": "legittimare",
    "legittimeran": "legittimare",
    "legittimeranno": "legittimare",
    "legittimerebbe": "legittimare",
    "legittimerebber": "legittimare",
    "legittimerebbero": "legittimare",
    "legittimerei": "legittimare",
    "legittimeremmo": "legittimare",
    "legittimeremo": "legittimare",
    "legittimereste": "legittimare",
    "legittimeresti": "legittimare",
    "legittimerete": "legittimare",
    "legittimerà": "legittimare",
    "legittimerò": "legittimare",
    "legittimi": "legittimo",
    "legittimiamo": "legittimare",
    "legittimiate": "legittimare",
    "legittimin": "legittimare",
    "legittimino": "legittimare",
    "legittimiste": "legittimista",
    "legittimisti": "legittimista",
    "legittimo": "legittimare",
    "legittimò": "legittimare",
    "legna": "legnare",
    "legnai": "legnare",
    "legnami": "legname",
    "legnammo": "legnare",
    "legnan": "legnare",
    "legnando": "legnare",
    "legnano": "legnare",
    "legnante": "legnare",
    "legnanti": "legnare",
    "legnar": "legnare",
    "legnaron": "legnare",
    "legnarono": "legnare",
    "legnasse": "legnare",
    "legnasser": "legnare",
    "legnassero": "legnare",
    "legnassi": "legnare",
    "legnassimo": "legnare",
    "legnaste": "legnare",
    "legnasti": "legnare",
    "legnata": "legnare",
    "legnate": "legnata",
    "legnati": "legnare",
    "legnato": "legnare",
    "legnava": "legnare",
    "legnavamo": "legnare",
    "legnavan": "legnare",
    "legnavano": "legnare",
    "legnavate": "legnare",
    "legnavi": "legnare",
    "legnavo": "legnare",
    "legne": "legna",
    "legnerai": "legnare",
    "legneran": "legnare",
    "legneranno": "legnare",
    "legnerebbe": "legnare",
    "legnerebber": "legnare",
    "legnerebbero": "legnare",
    "legnerei": "legnare",
    "legneremmo": "legnare",
    "legneremo": "legnare",
    "legnereste": "legnare",
    "legneresti": "legnare",
    "legnerete": "legnare",
    "legnerà": "legnare",
    "legnerò": "legnare",
    "legni": "legno",
    "legniamo": "legnare",
    "legniate": "legnare",
    "legnin": "legnare",
    "legnino": "legnare",
    "legno": "legnare",
    "legnò": "legnare",
    "lego": "legare",
    "legumi": "legume",
    "legò": "legare",
    "lembi": "lembo",
    "lemmi": "lemma",
    "lena": "leno",
    "lene": "leno",
    "leni": "leno",
    "leniamo": "lenire",
    "leniate": "lenire",
    "leniendo": "lenire",
    "leniente": "lenire",
    "lenienti": "lenire",
    "lenii": "lenire",
    "lenimmo": "lenire",
    "leninismi": "leninismo",
    "leniniste": "leninista",
    "leninisti": "leninista",
    "lenir": "lenire",
    "lenirai": "lenire",
    "leniran": "lenire",
    "leniranno": "lenire",
    "lenirebbe": "lenire",
    "lenirebber": "lenire",
    "lenirebbero": "lenire",
    "lenirei": "lenire",
    "leniremmo": "lenire",
    "leniremo": "lenire",
    "lenireste": "lenire",
    "leniresti": "lenire",
    "lenirete": "lenire",
    "leniron": "lenire",
    "lenirono": "lenire",
    "lenirà": "lenire",
    "lenirò": "lenire",
    "lenisca": "lenire",
    "leniscan": "lenire",
    "leniscano": "lenire",
    "lenisci": "lenire",
    "lenisco": "lenire",
    "leniscon": "lenire",
    "leniscono": "lenire",
    "lenisse": "lenire",
    "lenisser": "lenire",
    "lenissero": "lenire",
    "lenissi": "lenire",
    "lenissimo": "lenire",
    "leniste": "lenire",
    "lenisti": "lenire",
    "lenita": "lenire",
    "lenite": "lenire",
    "leniti": "lenire",
    "lenito": "lenire",
    "leniva": "lenire",
    "lenivamo": "lenire",
    "lenivan": "lenire",
    "lenivano": "lenire",
    "lenivate": "lenire",
    "lenivi": "lenire",
    "lenivo": "lenire",
    "lenocini": "lenocinio",
    "lenoni": "lenone",
    "lenta": "lento",
    "lente": "lento",
    "lentezze": "lentezza",
    "lenti": "lento",
    "lenticchie": "lenticchia",
    "lenticolari": "lenticolare",
    "lentigginosa": "lentigginoso",
    "lentigginose": "lentigginoso",
    "lentigginosi": "lentigginoso",
    "lenze": "lenza",
    "lenzuola": "lenzuolo",
    "lenzuoli": "lenzuolo",
    "lenì": "lenire",
    "leoncavallini": "leoncavallino",
    "leoncini": "leoncino",
    "leonesse": "leonessa",
    "leoni": "leone",
    "leopardi": "leopardo",
    "lepeniste": "lepenista",
    "lepenisti": "lepenista",
    "lepidezze": "lepidezza",
    "lepidotteri": "lepidottero",
    "lepri": "lepre",
    "lercerai": "lerciare",
    "lerceran": "lerciare",
    "lerceranno": "lerciare",
    "lercerebbe": "lerciare",
    "lercerebber": "lerciare",
    "lercerebbero": "lerciare",
    "lercerei": "lerciare",
    "lerceremmo": "lerciare",
    "lerceremo": "lerciare",
    "lercereste": "lerciare",
    "lerceresti": "lerciare",
    "lercerete": "lerciare",
    "lercerà": "lerciare",
    "lercerò": "lerciare",
    "lerci": "lerciare",
    "lercia": "lerciare",
    "lerciai": "lerciare",
    "lerciammo": "lerciare",
    "lerciamo": "lerciare",
    "lercian": "lerciare",
    "lerciando": "lerciare",
    "lerciano": "lerciare",
    "lerciante": "lerciare",
    "lercianti": "lerciare",
    "lerciar": "lerciare",
    "lerciaron": "lerciare",
    "lerciarono": "lerciare",
    "lerciasse": "lerciare",
    "lerciasser": "lerciare",
    "lerciassero": "lerciare",
    "lerciassi": "lerciare",
    "lerciassimo": "lerciare",
    "lerciaste": "lerciare",
    "lerciasti": "lerciare",
    "lerciata": "lerciare",
    "lerciate": "lerciare",
    "lerciati": "lerciare",
    "lerciato": "lerciare",
    "lerciava": "lerciare",
    "lerciavamo": "lerciare",
    "lerciavan": "lerciare",
    "lerciavano": "lerciare",
    "lerciavate": "lerciare",
    "lerciavi": "lerciare",
    "lerciavo": "lerciare",
    "lercin": "lerciare",
    "lercino": "lerciare",
    "lercio": "lerciare",
    "lerciò": "lerciare",
    "lesa": "leso",
    "lesbiche": "lesbica",
    "lese": "leso",
    "lesi": "leso",
    "lesina": "lesinare",
    "lesinai": "lesinare",
    "lesinammo": "lesinare",
    "lesinan": "lesinare",
    "lesinando": "lesinare",
    "lesinano": "lesinare",
    "lesinante": "lesinare",
    "lesinanti": "lesinare",
    "lesinar": "lesinare",
    "lesinaron": "lesinare",
    "lesinarono": "lesinare",
    "lesinasse": "lesinare",
    "lesinasser": "lesinare",
    "lesinassero": "lesinare",
    "lesinassi": "lesinare",
    "lesinassimo": "lesinare",
    "lesinaste": "lesinare",
    "lesinasti": "lesinare",
    "lesinata": "lesinare",
    "lesinate": "lesinare",
    "lesinati": "lesinare",
    "lesinato": "lesinare",
    "lesinava": "lesinare",
    "lesinavamo": "lesinare",
    "lesinavan": "lesinare",
    "lesinavano": "lesinare",
    "lesinavate": "lesinare",
    "lesinavi": "lesinare",
    "lesinavo": "lesinare",
    "lesinerai": "lesinare",
    "lesineran": "lesinare",
    "lesineranno": "lesinare",
    "lesinerebbe": "lesinare",
    "lesinerebber": "lesinare",
    "lesinerebbero": "lesinare",
    "lesinerei": "lesinare",
    "lesineremmo": "lesinare",
    "lesineremo": "lesinare",
    "lesinereste": "lesinare",
    "lesineresti": "lesinare",
    "lesinerete": "lesinare",
    "lesinerà": "lesinare",
    "lesinerò": "lesinare",
    "lesini": "lesinare",
    "lesiniamo": "lesinare",
    "lesiniate": "lesinare",
    "lesinin": "lesinare",
    "lesinino": "lesinare",
    "lesino": "lesinare",
    "lesinò": "lesinare",
    "lesiona": "lesionare",
    "lesionai": "lesionare",
    "lesionammo": "lesionare",
    "lesionan": "lesionare",
    "lesionando": "lesionare",
    "lesionano": "lesionare",
    "lesionante": "lesionare",
    "lesionanti": "lesionare",
    "lesionar": "lesionare",
    "lesionaron": "lesionare",
    "lesionarono": "lesionare",
    "lesionasse": "lesionare",
    "lesionasser": "lesionare",
    "lesionassero": "lesionare",
    "lesionassi": "lesionare",
    "lesionassimo": "lesionare",
    "lesionaste": "lesionare",
    "lesionasti": "lesionare",
    "lesionata": "lesionare",
    "lesionate": "lesionare",
    "lesionati": "lesionare",
    "lesionato": "lesionare",
    "lesionava": "lesionare",
    "lesionavamo": "lesionare",
    "lesionavan": "lesionare",
    "lesionavano": "lesionare",
    "lesionavate": "lesionare",
    "lesionavi": "lesionare",
    "lesionavo": "lesionare",
    "lesionerai": "lesionare",
    "lesioneran": "lesionare",
    "lesioneranno": "lesionare",
    "lesionerebbe": "lesionare",
    "lesionerebber": "lesionare",
    "lesionerebbero": "lesionare",
    "lesionerei": "lesionare",
    "lesioneremmo": "lesionare",
    "lesioneremo": "lesionare",
    "lesionereste": "lesionare",
    "lesioneresti": "lesionare",
    "lesionerete": "lesionare",
    "lesionerà": "lesionare",
    "lesionerò": "lesionare",
    "lesioni": "lesione",
    "lesioniamo": "lesionare",
    "lesioniate": "lesionare",
    "lesionin": "lesionare",
    "lesionino": "lesionare",
    "lesiono": "lesionare",
    "lesionò": "lesionare",
    "lesiva": "lesivo",
    "lesive": "lesivo",
    "lesivi": "lesivo",
    "lessa": "lesso",
    "lessai": "lessare",
    "lessammo": "lessare",
    "lessan": "lessare",
    "lessando": "lessare",
    "lessano": "lessare",
    "lessante": "lessare",
    "lessanti": "lessare",
    "lessar": "lessare",
    "lessaron": "lessare",
    "lessarono": "lessare",
    "lessasse": "lessare",
    "lessasser": "lessare",
    "lessassero": "lessare",
    "lessassi": "lessare",
    "lessassimo": "lessare",
    "lessaste": "lessare",
    "lessasti": "lessare",
    "lessata": "lessare",
    "lessate": "lessare",
    "lessati": "lessare",
    "lessato": "lessare",
    "lessava": "lessare",
    "lessavamo": "lessare",
    "lessavan": "lessare",
    "lessavano": "lessare",
    "lessavate": "lessare",
    "lessavi": "lessare",
    "lessavo": "lessare",
    "lesse": "lesso",
    "lesser": "leggere",
    "lesserai": "lessare",
    "lesseran": "lessare",
    "lesseranno": "lessare",
    "lesserebbe": "lessare",
    "lesserebber": "lessare",
    "lesserebbero": "lessare",
    "lesserei": "lessare",
    "lesseremmo": "lessare",
    "lesseremo": "lessare",
    "lessereste": "lessare",
    "lesseresti": "lessare",
    "lesserete": "lessare",
    "lessero": "leggere",
    "lesserà": "lessare",
    "lesserò": "lessare",
    "lessi": "lesso",
    "lessiamo": "lessare",
    "lessiate": "lessare",
    "lessicali": "lessicale",
    "lessici": "lessico",
    "lessicografi": "lessicografo",
    "lessin": "lessare",
    "lessino": "lessare",
    "lesso": "lessare",
    "lessò": "lessare",
    "lesta": "lesto",
    "leste": "lesto",
    "lesti": "lesto",
    "lestofanti": "lestofante",
    "letali": "letale",
    "letamai": "letamaio",
    "letami": "letame",
    "letarghi": "letargo",
    "letargica": "letargico",
    "letargiche": "letargico",
    "letargici": "letargico",
    "letica": "leticare",
    "leticai": "leticare",
    "leticammo": "leticare",
    "letican": "leticare",
    "leticando": "leticare",
    "leticano": "leticare",
    "leticante": "leticare",
    "leticanti": "leticare",
    "leticar": "leticare",
    "leticaron": "leticare",
    "leticarono": "leticare",
    "leticasse": "leticare",
    "leticasser": "leticare",
    "leticassero": "leticare",
    "leticassi": "leticare",
    "leticassimo": "leticare",
    "leticaste": "leticare",
    "leticasti": "leticare",
    "leticata": "leticare",
    "leticate": "leticare",
    "leticati": "leticare",
    "leticato": "leticare",
    "leticava": "leticare",
    "leticavamo": "leticare",
    "leticavan": "leticare",
    "leticavano": "leticare",
    "leticavate": "leticare",
    "leticavi": "leticare",
    "leticavo": "leticare",
    "leticherai": "leticare",
    "leticheran": "leticare",
    "leticheranno": "leticare",
    "leticherebbe": "leticare",
    "leticherebber": "leticare",
    "leticherebbero": "leticare",
    "leticherei": "leticare",
    "leticheremmo": "leticare",
    "leticheremo": "leticare",
    "letichereste": "leticare",
    "leticheresti": "leticare",
    "leticherete": "leticare",
    "leticherà": "leticare",
    "leticherò": "leticare",
    "letichi": "leticare",
    "letichiamo": "leticare",
    "letichiate": "leticare",
    "letichin": "leticare",
    "letichino": "leticare",
    "letico": "leticare",
    "leticò": "leticare",
    "letizie": "letizia",
    "letta": "letto",
    "lette": "letto",
    "letterali": "letterale",
    "letterari": "letterario",
    "letteraria": "letterario",
    "letterarie": "letterario",
    "letterata": "letterato",
    "letterate": "letterato",
    "letterati": "letterato",
    "letterature": "letteratura",
    "lettere": "lettera",
    "lettere-appello": "lettera-appello",
    "letterine": "letterina",
    "letti": "letto",
    "lettighe": "lettiga",
    "lettini": "lettino",
    "letto": "leggere",
    "lettoni": "lettone",
    "lettorata": "lettorato",
    "lettorate": "lettorato",
    "lettorati": "lettorato",
    "lettori": "lettore",
    "lettrici": "lettrice",
    "letture": "lettura",
    "leucemica": "leucemico",
    "leucemiche": "leucemico",
    "leucemici": "leucemico",
    "leucemie": "leucemia",
    "leva": "levare",
    "levai": "levare",
    "levammo": "levare",
    "levan": "levare",
    "levando": "levare",
    "levano": "levare",
    "levante": "levare",
    "levanti": "levare",
    "levantina": "levantino",
    "levantine": "levantino",
    "levantini": "levantino",
    "levar": "levare",
    "levaron": "levare",
    "levarono": "levare",
    "levasse": "levare",
    "levasser": "levare",
    "levassero": "levare",
    "levassi": "levare",
    "levassimo": "levare",
    "levaste": "levare",
    "levasti": "levare",
    "levata": "levare",
    "levatacce": "levataccia",
    "levate": "levare",
    "levati": "levare",
    "levato": "levare",
    "levatoi": "levatoio",
    "levatoia": "levatoio",
    "levatoie": "levatoio",
    "levatrici": "levatrice",
    "levature": "levatura",
    "levava": "levare",
    "levavamo": "levare",
    "levavan": "levare",
    "levavano": "levare",
    "levavate": "levare",
    "levavi": "levare",
    "levavo": "levare",
    "leve": "leva",
    "leverai": "levare",
    "leveran": "levare",
    "leveranno": "levare",
    "leverebbe": "levare",
    "leverebber": "levare",
    "leverebbero": "levare",
    "leverei": "levare",
    "leveremmo": "levare",
    "leveremo": "levare",
    "levereste": "levare",
    "leveresti": "levare",
    "leverete": "levare",
    "leverà": "levare",
    "leverò": "levare",
    "levi": "levare",
    "leviamo": "levare",
    "leviate": "levare",
    "leviga": "levigare",
    "levigai": "levigare",
    "levigammo": "levigare",
    "levigan": "levigare",
    "levigando": "levigare",
    "levigano": "levigare",
    "levigante": "levigare",
    "leviganti": "levigare",
    "levigar": "levigare",
    "levigaron": "levigare",
    "levigarono": "levigare",
    "levigasse": "levigare",
    "levigasser": "levigare",
    "levigassero": "levigare",
    "levigassi": "levigare",
    "levigassimo": "levigare",
    "levigaste": "levigare",
    "levigasti": "levigare",
    "levigata": "levigare",
    "levigate": "levigare",
    "levigati": "levigare",
    "levigato": "levigare",
    "levigava": "levigare",
    "levigavamo": "levigare",
    "levigavan": "levigare",
    "levigavano": "levigare",
    "levigavate": "levigare",
    "levigavi": "levigare",
    "levigavo": "levigare",
    "levigherai": "levigare",
    "levigheran": "levigare",
    "levigheranno": "levigare",
    "levigherebbe": "levigare",
    "levigherebber": "levigare",
    "levigherebbero": "levigare",
    "levigherei": "levigare",
    "levigheremmo": "levigare",
    "levigheremo": "levigare",
    "levighereste": "levigare",
    "levigheresti": "levigare",
    "levigherete": "levigare",
    "levigherà": "levigare",
    "levigherò": "levigare",
    "levighi": "levigare",
    "levighiamo": "levigare",
    "levighiate": "levigare",
    "levighin": "levigare",
    "levighino": "levigare",
    "levigo": "levigare",
    "levigò": "levigare",
    "levin": "levare",
    "levino": "levare",
    "levita": "levitare",
    "levitai": "levitare",
    "levitammo": "levitare",
    "levitan": "levitare",
    "levitando": "levitare",
    "levitano": "levitare",
    "levitante": "levitare",
    "levitanti": "levitare",
    "levitar": "levitare",
    "levitaron": "levitare",
    "levitarono": "levitare",
    "levitasse": "levitare",
    "levitasser": "levitare",
    "levitassero": "levitare",
    "levitassi": "levitare",
    "levitassimo": "levitare",
    "levitaste": "levitare",
    "levitasti": "levitare",
    "levitata": "levitare",
    "levitate": "levitare",
    "levitati": "levitare",
    "levitato": "levitare",
    "levitava": "levitare",
    "levitavamo": "levitare",
    "levitavan": "levitare",
    "levitavano": "levitare",
    "levitavate": "levitare",
    "levitavi": "levitare",
    "levitavo": "levitare",
    "levitazioni": "levitazione",
    "leviterai": "levitare",
    "leviteran": "levitare",
    "leviteranno": "levitare",
    "leviterebbe": "levitare",
    "leviterebber": "levitare",
    "leviterebbero": "levitare",
    "leviterei": "levitare",
    "leviteremmo": "levitare",
    "leviteremo": "levitare",
    "levitereste": "levitare",
    "leviteresti": "levitare",
    "leviterete": "levitare",
    "leviterà": "levitare",
    "leviterò": "levitare",
    "leviti": "levitare",
    "levitiamo": "levitare",
    "levitiate": "levitare",
    "levitin": "levitare",
    "levitino": "levitare",
    "levito": "levitare",
    "levitò": "levitare",
    "levo": "levare",
    "levrieri": "levriero",
    "levò": "levare",
    "lezioncine": "lezioncina",
    "lezioni": "lezione",
    "leziosa": "lezioso",
    "leziosaggini": "leziosaggine",
    "leziose": "lezioso",
    "leziosi": "lezioso",
    "lezzi": "lezzo",
    "liane": "liana",
    "liba": "libare",
    "libagioni": "libagione",
    "libai": "libare",
    "libammo": "libare",
    "liban": "libare",
    "libando": "libare",
    "libanesi": "libanese",
    "libano": "libare",
    "libante": "libare",
    "libanti": "libare",
    "libar": "libare",
    "libaron": "libare",
    "libarono": "libare",
    "libasse": "libare",
    "libasser": "libare",
    "libassero": "libare",
    "libassi": "libare",
    "libassimo": "libare",
    "libaste": "libare",
    "libasti": "libare",
    "libata": "libare",
    "libate": "libare",
    "libati": "libare",
    "libato": "libare",
    "libava": "libare",
    "libavamo": "libare",
    "libavan": "libare",
    "libavano": "libare",
    "libavate": "libare",
    "libavi": "libare",
    "libavo": "libare",
    "libecci": "libeccio",
    "libelli": "libello",
    "libera": "libero",
    "liberai": "liberare",
    "liberal-conservatori": "liberal-conservatore",
    "liberal-democratica": "liberal-democratico",
    "liberal-democratiche": "liberal-democratico",
    "liberal-democratici": "liberal-democratico",
    "liberaldemocratica": "liberaldemocratico",
    "liberaldemocratiche": "liberaldemocratico",
    "liberaldemocratici": "liberaldemocratico",
    "liberaldemocrazie": "liberaldemocrazia",
    "liberali": "liberale",
    "liberalismi": "liberalismo",
    "liberalizza": "liberalizzare",
    "liberalizzai": "liberalizzare",
    "liberalizzammo": "liberalizzare",
    "liberalizzan": "liberalizzare",
    "liberalizzando": "liberalizzare",
    "liberalizzano": "liberalizzare",
    "liberalizzante": "liberalizzare",
    "liberalizzanti": "liberalizzare",
    "liberalizzar": "liberalizzare",
    "liberalizzaron": "liberalizzare",
    "liberalizzarono": "liberalizzare",
    "liberalizzasse": "liberalizzare",
    "liberalizzasser": "liberalizzare",
    "liberalizzassero": "liberalizzare",
    "liberalizzassi": "liberalizzare",
    "liberalizzassimo": "liberalizzare",
    "liberalizzaste": "liberalizzare",
    "liberalizzasti": "liberalizzare",
    "liberalizzata": "liberalizzare",
    "liberalizzate": "liberalizzare",
    "liberalizzati": "liberalizzare",
    "liberalizzato": "liberalizzare",
    "liberalizzava": "liberalizzare",
    "liberalizzavamo": "liberalizzare",
    "liberalizzavan": "liberalizzare",
    "liberalizzavano": "liberalizzare",
    "liberalizzavate": "liberalizzare",
    "liberalizzavi": "liberalizzare",
    "liberalizzavo": "liberalizzare",
    "liberalizzazioni": "liberalizzazione",
    "liberalizzerai": "liberalizzare",
    "liberalizzeran": "liberalizzare",
    "liberalizzeranno": "liberalizzare",
    "liberalizzerebbe": "liberalizzare",
    "liberalizzerebber": "liberalizzare",
    "liberalizzerebbero": "liberalizzare",
    "liberalizzerei": "liberalizzare",
    "liberalizzeremmo": "liberalizzare",
    "liberalizzeremo": "liberalizzare",
    "liberalizzereste": "liberalizzare",
    "liberalizzeresti": "liberalizzare",
    "liberalizzerete": "liberalizzare",
    "liberalizzerà": "liberalizzare",
    "liberalizzerò": "liberalizzare",
    "liberalizzi": "liberalizzare",
    "liberalizziamo": "liberalizzare",
    "liberalizziate": "liberalizzare",
    "liberalizzin": "liberalizzare",
    "liberalizzino": "liberalizzare",
    "liberalizzo": "liberalizzare",
    "liberalizzò": "liberalizzare",
    "liberammo": "liberare",
    "liberan": "liberare",
    "liberando": "liberare",
    "liberanno": "libare",
    "liberano": "liberare",
    "liberante": "liberare",
    "liberanti": "liberare",
    "liberar": "liberare",
    "liberaron": "liberare",
    "liberarono": "liberare",
    "liberasse": "liberare",
    "liberasser": "liberare",
    "liberassero": "liberare",
    "liberassi": "liberare",
    "liberassimo": "liberare",
    "liberaste": "liberare",
    "liberasti": "liberare",
    "liberata": "liberare",
    "liberate": "liberare",
    "liberati": "liberare",
    "liberato": "liberare",
    "liberatori": "liberatorio",
    "liberatoria": "liberatorio",
    "liberatorie": "liberatorio",
    "liberatrice": "liberatore",
    "liberatrici": "liberatore",
    "liberava": "liberare",
    "liberavamo": "liberare",
    "liberavan": "liberare",
    "liberavano": "liberare",
    "liberavate": "liberare",
    "liberavi": "liberare",
    "liberavo": "liberare",
    "liberazioni": "liberazione",
    "libere": "libero",
    "liberebbe": "libare",
    "liberebber": "libare",
    "liberebbero": "libare",
    "liberei": "libare",
    "liberemmo": "libare",
    "liberemo": "libare",
    "libererai": "liberare",
    "libereran": "liberare",
    "libereranno": "liberare",
    "libererebbe": "liberare",
    "libererebber": "liberare",
    "libererebbero": "liberare",
    "libererei": "liberare",
    "libereremmo": "liberare",
    "libereremo": "liberare",
    "liberereste": "liberare",
    "libereresti": "liberare",
    "libererete": "liberare",
    "libererà": "liberare",
    "libererò": "liberare",
    "libereste": "libare",
    "liberesti": "libare",
    "liberete": "libare",
    "liberi": "libero",
    "liberiamo": "liberare",
    "liberiana": "liberiano",
    "liberiane": "liberiano",
    "liberiani": "liberiano",
    "liberiate": "liberare",
    "liberin": "liberare",
    "liberino": "liberare",
    "liberismi": "liberismo",
    "liberiste": "liberista",
    "liberisti": "liberista",
    "libero": "liberare",
    "liberoscambiste": "liberoscambista",
    "liberoscambisti": "liberoscambista",
    "libertari": "libertario",
    "libertaria": "libertario",
    "libertarie": "libertario",
    "liberti": "liberto",
    "liberticide": "liberticida",
    "liberticidi": "liberticida",
    "libertina": "libertino",
    "libertinaggi": "libertinaggio",
    "libertine": "libertino",
    "libertini": "libertino",
    "liberà": "libare",
    "liberò": "liberare",
    "libi": "libare",
    "libiamo": "libare",
    "libiate": "libare",
    "libica": "libico",
    "libiche": "libico",
    "libici": "libico",
    "libidini": "libidine",
    "libidinosa": "libidinoso",
    "libidinose": "libidinoso",
    "libidinosi": "libidinoso",
    "libin": "libare",
    "libino": "libare",
    "libo": "libare",
    "libra": "librare",
    "librai": "librare",
    "librammo": "librare",
    "libran": "librare",
    "librando": "librare",
    "librano": "librare",
    "librante": "librare",
    "libranti": "librare",
    "librar": "librare",
    "librari": "librario",
    "libraria": "librario",
    "librarie": "librario",
    "libraron": "librare",
    "librarono": "librare",
    "librasse": "librare",
    "librasser": "librare",
    "librassero": "librare",
    "librassi": "librare",
    "librassimo": "librare",
    "libraste": "librare",
    "librasti": "librare",
    "librata": "librare",
    "librate": "librare",
    "librati": "librare",
    "librato": "librare",
    "librava": "librare",
    "libravamo": "librare",
    "libravan": "librare",
    "libravano": "librare",
    "libravate": "librare",
    "libravi": "librare",
    "libravo": "librare",
    "librerai": "librare",
    "libreran": "librare",
    "libreranno": "librare",
    "librerebbe": "librare",
    "librerebber": "librare",
    "librerebbero": "librare",
    "librerei": "librare",
    "libreremmo": "librare",
    "libreremo": "librare",
    "librereste": "librare",
    "libreresti": "librare",
    "librerete": "librare",
    "librerie": "libreria",
    "librerà": "librare",
    "librerò": "librare",
    "libresca": "libresco",
    "libresche": "libresco",
    "libreschi": "libresco",
    "libretti": "libretto",
    "librettisti": "librettista",
    "libri": "libro",
    "libri-intervista": "libro-intervista",
    "libriamo": "librare",
    "libriate": "librare",
    "libriccini": "libriccino",
    "libricini": "libricino",
    "librin": "librare",
    "librini": "librino",
    "librino": "librare",
    "libro": "librare",
    "libroni": "librone",
    "librò": "librare",
    "libò": "libare",
    "lica": "licere",
    "lican": "licere",
    "licano": "licere",
    "lice": "licere",
    "liceali": "liceale",
    "licei": "licere",
    "licemmo": "licere",
    "licendo": "licere",
    "licente": "licere",
    "licenti": "licere",
    "licenze": "licenza",
    "licenzi": "licenziare",
    "licenzia": "licenziare",
    "licenziai": "licenziare",
    "licenziamenti": "licenziamento",
    "licenziammo": "licenziare",
    "licenziamo": "licenziare",
    "licenzian": "licenziare",
    "licenziando": "licenziare",
    "licenziano": "licenziare",
    "licenziante": "licenziare",
    "licenzianti": "licenziare",
    "licenziar": "licenziare",
    "licenziaron": "licenziare",
    "licenziarono": "licenziare",
    "licenziasse": "licenziare",
    "licenziasser": "licenziare",
    "licenziassero": "licenziare",
    "licenziassi": "licenziare",
    "licenziassimo": "licenziare",
    "licenziaste": "licenziare",
    "licenziasti": "licenziare",
    "licenziata": "licenziato",
    "licenziatari": "licenziatario",
    "licenziate": "licenziato",
    "licenziati": "licenziato",
    "licenziato": "licenziare",
    "licenziava": "licenziare",
    "licenziavamo": "licenziare",
    "licenziavan": "licenziare",
    "licenziavano": "licenziare",
    "licenziavate": "licenziare",
    "licenziavi": "licenziare",
    "licenziavo": "licenziare",
    "licenzierai": "licenziare",
    "licenzieran": "licenziare",
    "licenzieranno": "licenziare",
    "licenzierebbe": "licenziare",
    "licenzierebber": "licenziare",
    "licenzierebbero": "licenziare",
    "licenzierei": "licenziare",
    "licenzieremmo": "licenziare",
    "licenzieremo": "licenziare",
    "licenziereste": "licenziare",
    "licenzieresti": "licenziare",
    "licenzierete": "licenziare",
    "licenzierà": "licenziare",
    "licenzierò": "licenziare",
    "licenzin": "licenziare",
    "licenzino": "licenziare",
    "licenzio": "licenziare",
    "licenziosa": "licenzioso",
    "licenziose": "licenzioso",
    "licenziosi": "licenzioso",
    "licenziò": "licenziare",
    "licer": "licere",
    "licerai": "licere",
    "liceran": "licere",
    "liceranno": "licere",
    "licerebbe": "licere",
    "licerebber": "licere",
    "licerebbero": "licere",
    "licerei": "licere",
    "liceremmo": "licere",
    "liceremo": "licere",
    "licereste": "licere",
    "liceresti": "licere",
    "licerete": "licere",
    "liceron": "licere",
    "licerono": "licere",
    "licerà": "licere",
    "licerò": "licere",
    "licesse": "licere",
    "licesser": "licere",
    "licessero": "licere",
    "licessi": "licere",
    "licessimo": "licere",
    "liceste": "licere",
    "licesti": "licere",
    "licete": "licere",
    "liceva": "licere",
    "licevamo": "licere",
    "licevan": "licere",
    "licevano": "licere",
    "licevate": "licere",
    "licevi": "licere",
    "licevo": "licere",
    "licheni": "lichene",
    "lici": "licere",
    "liciamo": "licere",
    "liciate": "licere",
    "licita": "licitare",
    "licitai": "licitare",
    "licitammo": "licitare",
    "licitan": "licitare",
    "licitando": "licitare",
    "licitano": "licitare",
    "licitante": "licitare",
    "licitanti": "licitare",
    "licitar": "licitare",
    "licitaron": "licitare",
    "licitarono": "licitare",
    "licitasse": "licitare",
    "licitasser": "licitare",
    "licitassero": "licitare",
    "licitassi": "licitare",
    "licitassimo": "licitare",
    "licitaste": "licitare",
    "licitasti": "licitare",
    "licitata": "licitare",
    "licitate": "licitare",
    "licitati": "licitare",
    "licitato": "licitare",
    "licitava": "licitare",
    "licitavamo": "licitare",
    "licitavan": "licitare",
    "licitavano": "licitare",
    "licitavate": "licitare",
    "licitavi": "licitare",
    "licitavo": "licitare",
    "licitazioni": "licitazione",
    "liciterai": "licitare",
    "liciteran": "licitare",
    "liciteranno": "licitare",
    "liciterebbe": "licitare",
    "liciterebber": "licitare",
    "liciterebbero": "licitare",
    "liciterei": "licitare",
    "liciteremmo": "licitare",
    "liciteremo": "licitare",
    "licitereste": "licitare",
    "liciteresti": "licitare",
    "liciterete": "licitare",
    "liciterà": "licitare",
    "liciterò": "licitare",
    "liciti": "licitare",
    "licitiamo": "licitare",
    "licitiate": "licitare",
    "licitin": "licitare",
    "licitino": "licitare",
    "licito": "licitare",
    "licitò": "licitare",
    "liciuta": "licere",
    "liciute": "licere",
    "liciuti": "licere",
    "liciuto": "licere",
    "lico": "licere",
    "licon": "licere",
    "licono": "licere",
    "licè": "licere",
    "lidi": "lido",
    "lieta": "lieto",
    "liete": "lieto",
    "lieti": "lieto",
    "lievi": "lieve",
    "lievita": "lievitare",
    "lievitai": "lievitare",
    "lievitammo": "lievitare",
    "lievitan": "lievitare",
    "lievitando": "lievitare",
    "lievitano": "lievitare",
    "lievitante": "lievitare",
    "lievitanti": "lievitare",
    "lievitar": "lievitare",
    "lievitaron": "lievitare",
    "lievitarono": "lievitare",
    "lievitasse": "lievitare",
    "lievitasser": "lievitare",
    "lievitassero": "lievitare",
    "lievitassi": "lievitare",
    "lievitassimo": "lievitare",
    "lievitaste": "lievitare",
    "lievitasti": "lievitare",
    "lievitata": "lievitare",
    "lievitate": "lievitare",
    "lievitati": "lievitare",
    "lievitato": "lievitare",
    "lievitava": "lievitare",
    "lievitavamo": "lievitare",
    "lievitavan": "lievitare",
    "lievitavano": "lievitare",
    "lievitavate": "lievitare",
    "lievitavi": "lievitare",
    "lievitavo": "lievitare",
    "lievitazioni": "lievitazione",
    "lieviterai": "lievitare",
    "lieviteran": "lievitare",
    "lieviteranno": "lievitare",
    "lieviterebbe": "lievitare",
    "lieviterebber": "lievitare",
    "lieviterebbero": "lievitare",
    "lieviterei": "lievitare",
    "lieviteremmo": "lievitare",
    "lieviteremo": "lievitare",
    "lievitereste": "lievitare",
    "lieviteresti": "lievitare",
    "lieviterete": "lievitare",
    "lieviterà": "lievitare",
    "lieviterò": "lievitare",
    "lieviti": "lievito",
    "lievitiamo": "lievitare",
    "lievitiate": "lievitare",
    "lievitin": "lievitare",
    "lievitino": "lievitare",
    "lievito": "lievitare",
    "lievitò": "lievitare",
    "ligi": "ligio",
    "ligia": "ligio",
    "ligie": "ligio",
    "lignaggi": "lignaggio",
    "lignea": "ligneo",
    "lignee": "ligneo",
    "lignei": "ligneo",
    "liguri": "ligure",
    "liliali": "liliale",
    "lillipuziana": "lillipuziano",
    "lillipuziane": "lillipuziano",
    "lillipuziani": "lillipuziano",
    "lima": "limare",
    "limacciosa": "limaccioso",
    "limacciose": "limaccioso",
    "limacciosi": "limaccioso",
    "limai": "limare",
    "limammo": "limare",
    "liman": "limare",
    "limando": "limare",
    "limano": "limare",
    "limante": "limare",
    "limanti": "limare",
    "limar": "limare",
    "limaron": "limare",
    "limarono": "limare",
    "limasse": "limare",
    "limasser": "limare",
    "limassero": "limare",
    "limassi": "limare",
    "limassimo": "limare",
    "limaste": "limare",
    "limasti": "limare",
    "limata": "limare",
    "limate": "limare",
    "limati": "limare",
    "limato": "limare",
    "limature": "limatura",
    "limava": "limare",
    "limavamo": "limare",
    "limavan": "limare",
    "limavano": "limare",
    "limavate": "limare",
    "limavi": "limare",
    "limavo": "limare",
    "limbi": "limbo",
    "limerai": "limare",
    "limeran": "limare",
    "limeranno": "limare",
    "limerebbe": "limare",
    "limerebber": "limare",
    "limerebbero": "limare",
    "limerei": "limare",
    "limeremmo": "limare",
    "limeremo": "limare",
    "limereste": "limare",
    "limeresti": "limare",
    "limerete": "limare",
    "limerà": "limare",
    "limerò": "limare",
    "limi": "limare",
    "limiamo": "limare",
    "limiate": "limare",
    "limin": "limare",
    "limino": "limare",
    "limita": "limitare",
    "limitai": "limitare",
    "limitammo": "limitare",
    "limitan": "limitare",
    "limitando": "limitare",
    "limitano": "limitare",
    "limitante": "limitare",
    "limitanti": "limitare",
    "limitar": "limitare",
    "limitaron": "limitare",
    "limitarono": "limitare",
    "limitasse": "limitare",
    "limitasser": "limitare",
    "limitassero": "limitare",
    "limitassi": "limitare",
    "limitassimo": "limitare",
    "limitaste": "limitare",
    "limitasti": "limitare",
    "limitata": "limitato",
    "limitate": "limitato",
    "limitatezze": "limitatezza",
    "limitati": "limitato",
    "limitativa": "limitativo",
    "limitative": "limitativo",
    "limitativi": "limitativo",
    "limitato": "limitare",
    "limitatori": "limitatore",
    "limitava": "limitare",
    "limitavamo": "limitare",
    "limitavan": "limitare",
    "limitavano": "limitare",
    "limitavate": "limitare",
    "limitavi": "limitare",
    "limitavo": "limitare",
    "limitazioni": "limitazione",
    "limiterai": "limitare",
    "limiteran": "limitare",
    "limiteranno": "limitare",
    "limiterebbe": "limitare",
    "limiterebber": "limitare",
    "limiterebbero": "limitare",
    "limiterei": "limitare",
    "limiteremmo": "limitare",
    "limiteremo": "limitare",
    "limitereste": "limitare",
    "limiteresti": "limitare",
    "limiterete": "limitare",
    "limiterà": "limitare",
    "limiterò": "limitare",
    "limiti": "limite",
    "limitiamo": "limitare",
    "limitiate": "limitare",
    "limitin": "limitare",
    "limitino": "limitare",
    "limito": "limitare",
    "limitrofa": "limitrofo",
    "limitrofe": "limitrofo",
    "limitrofi": "limitrofo",
    "limitò": "limitare",
    "limo": "limare",
    "limonate": "limonata",
    "limoni": "limone",
    "limosa": "limoso",
    "limose": "limoso",
    "limosi": "limoso",
    "limpida": "limpido",
    "limpide": "limpido",
    "limpidezze": "limpidezza",
    "limpidi": "limpido",
    "limò": "limare",
    "lincerai": "linciare",
    "linceran": "linciare",
    "linceranno": "linciare",
    "lincerebbe": "linciare",
    "lincerebber": "linciare",
    "lincerebbero": "linciare",
    "lincerei": "linciare",
    "linceremmo": "linciare",
    "linceremo": "linciare",
    "lincereste": "linciare",
    "linceresti": "linciare",
    "lincerete": "linciare",
    "lincerà": "linciare",
    "lincerò": "linciare",
    "linci": "linciare",
    "lincia": "linciare",
    "linciaggi": "linciaggio",
    "linciai": "linciare",
    "linciammo": "linciare",
    "linciamo": "linciare",
    "lincian": "linciare",
    "linciando": "linciare",
    "linciano": "linciare",
    "linciante": "linciare",
    "lincianti": "linciare",
    "linciar": "linciare",
    "linciaron": "linciare",
    "linciarono": "linciare",
    "linciasse": "linciare",
    "linciasser": "linciare",
    "linciassero": "linciare",
    "linciassi": "linciare",
    "linciassimo": "linciare",
    "linciaste": "linciare",
    "linciasti": "linciare",
    "linciata": "linciare",
    "linciate": "linciare",
    "linciati": "linciare",
    "linciato": "linciare",
    "linciava": "linciare",
    "linciavamo": "linciare",
    "linciavan": "linciare",
    "linciavano": "linciare",
    "linciavate": "linciare",
    "linciavi": "linciare",
    "linciavo": "linciare",
    "lincin": "linciare",
    "lincino": "linciare",
    "lincio": "linciare",
    "linciò": "linciare",
    "linda": "lindo",
    "linde": "lindo",
    "lindi": "lindo",
    "linea": "lineare",
    "lineai": "lineare",
    "lineamenti": "lineamento",
    "lineammo": "lineare",
    "linean": "lineare",
    "lineando": "lineare",
    "lineano": "lineare",
    "lineante": "lineare",
    "lineanti": "lineare",
    "linear": "lineare",
    "lineari": "lineare",
    "linearon": "lineare",
    "linearono": "lineare",
    "lineasse": "lineare",
    "lineasser": "lineare",
    "lineassero": "lineare",
    "lineassi": "lineare",
    "lineassimo": "lineare",
    "lineaste": "lineare",
    "lineasti": "lineare",
    "lineata": "lineare",
    "lineate": "lineare",
    "lineati": "lineare",
    "lineato": "lineare",
    "lineava": "lineare",
    "lineavamo": "lineare",
    "lineavan": "lineare",
    "lineavano": "lineare",
    "lineavate": "lineare",
    "lineavi": "lineare",
    "lineavo": "lineare",
    "linee": "linea",
    "linee-guida": "linea-guida",
    "lineerai": "lineare",
    "lineeran": "lineare",
    "lineeranno": "lineare",
    "lineerebbe": "lineare",
    "lineerebber": "lineare",
    "lineerebbero": "lineare",
    "lineerei": "lineare",
    "lineeremmo": "lineare",
    "lineeremo": "lineare",
    "lineereste": "lineare",
    "lineeresti": "lineare",
    "lineerete": "lineare",
    "lineerà": "lineare",
    "lineerò": "lineare",
    "linei": "lineare",
    "lineiamo": "lineare",
    "lineiate": "lineare",
    "linein": "lineare",
    "lineino": "lineare",
    "lineo": "lineare",
    "lineò": "lineare",
    "linfatica": "linfatico",
    "linfatiche": "linfatico",
    "linfatici": "linfatico",
    "linfe": "linfa",
    "linfociti": "linfocito",
    "linfomi": "linfoma",
    "linfonodi": "linfonodo",
    "lingotti": "lingotto",
    "linguacce": "linguaccia",
    "linguaggi": "linguaggio",
    "lingue": "lingua",
    "linguette": "linguetta",
    "linguisti": "linguista",
    "linguistica": "linguistico",
    "linguistiche": "linguistico",
    "linguistici": "linguistico",
    "lini": "lino",
    "liofilizza": "liofilizzare",
    "liofilizzai": "liofilizzare",
    "liofilizzammo": "liofilizzare",
    "liofilizzan": "liofilizzare",
    "liofilizzando": "liofilizzare",
    "liofilizzano": "liofilizzare",
    "liofilizzante": "liofilizzare",
    "liofilizzanti": "liofilizzare",
    "liofilizzar": "liofilizzare",
    "liofilizzaron": "liofilizzare",
    "liofilizzarono": "liofilizzare",
    "liofilizzasse": "liofilizzare",
    "liofilizzasser": "liofilizzare",
    "liofilizzassero": "liofilizzare",
    "liofilizzassi": "liofilizzare",
    "liofilizzassimo": "liofilizzare",
    "liofilizzaste": "liofilizzare",
    "liofilizzasti": "liofilizzare",
    "liofilizzata": "liofilizzare",
    "liofilizzate": "liofilizzare",
    "liofilizzati": "liofilizzare",
    "liofilizzato": "liofilizzare",
    "liofilizzava": "liofilizzare",
    "liofilizzavamo": "liofilizzare",
    "liofilizzavan": "liofilizzare",
    "liofilizzavano": "liofilizzare",
    "liofilizzavate": "liofilizzare",
    "liofilizzavi": "liofilizzare",
    "liofilizzavo": "liofilizzare",
    "liofilizzerai": "liofilizzare",
    "liofilizzeran": "liofilizzare",
    "liofilizzeranno": "liofilizzare",
    "liofilizzerebbe": "liofilizzare",
    "liofilizzerebber": "liofilizzare",
    "liofilizzerebbero": "liofilizzare",
    "liofilizzerei": "liofilizzare",
    "liofilizzeremmo": "liofilizzare",
    "liofilizzeremo": "liofilizzare",
    "liofilizzereste": "liofilizzare",
    "liofilizzeresti": "liofilizzare",
    "liofilizzerete": "liofilizzare",
    "liofilizzerà": "liofilizzare",
    "liofilizzerò": "liofilizzare",
    "liofilizzi": "liofilizzare",
    "liofilizziamo": "liofilizzare",
    "liofilizziate": "liofilizzare",
    "liofilizzin": "liofilizzare",
    "liofilizzino": "liofilizzare",
    "liofilizzo": "liofilizzare",
    "liofilizzò": "liofilizzare",
    "lionesi": "lionese",
    "liposuzioni": "liposuzione",
    "liquami": "liquame",
    "liquefa": "liquefare",
    "liquefa'": "liquefare",
    "liquefaccia": "liquefare",
    "liquefacciamo": "liquefare",
    "liquefaccian": "liquefare",
    "liquefacciano": "liquefare",
    "liquefacciate": "liquefare",
    "liquefaccio": "liquefare",
    "liquefacemmo": "liquefare",
    "liquefacendo": "liquefare",
    "liquefacente": "liquefare",
    "liquefacenti": "liquefare",
    "liquefacesse": "liquefare",
    "liquefacesser": "liquefare",
    "liquefacessero": "liquefare",
    "liquefacessi": "liquefare",
    "liquefacessimo": "liquefare",
    "liquefaceste": "liquefare",
    "liquefacesti": "liquefare",
    "liquefaceva": "liquefare",
    "liquefacevamo": "liquefare",
    "liquefacevan": "liquefare",
    "liquefacevano": "liquefare",
    "liquefacevate": "liquefare",
    "liquefacevi": "liquefare",
    "liquefacevo": "liquefare",
    "liquefai": "liquefare",
    "liquefan": "liquefare",
    "liquefanno": "liquefare",
    "liquefar": "liquefare",
    "liquefarai": "liquefare",
    "liquefaran": "liquefare",
    "liquefaranno": "liquefare",
    "liquefarebbe": "liquefare",
    "liquefarebber": "liquefare",
    "liquefarebbero": "liquefare",
    "liquefarei": "liquefare",
    "liquefaremmo": "liquefare",
    "liquefaremo": "liquefare",
    "liquefareste": "liquefare",
    "liquefaresti": "liquefare",
    "liquefarete": "liquefare",
    "liquefarà": "liquefare",
    "liquefarò": "liquefare",
    "liquefate": "liquefare",
    "liquefatta": "liquefare",
    "liquefatte": "liquefare",
    "liquefatti": "liquefare",
    "liquefatto": "liquefare",
    "liquefazioni": "liquefazione",
    "liquefece": "liquefare",
    "liquefecer": "liquefare",
    "liquefecero": "liquefare",
    "liquefeci": "liquefare",
    "liquida": "liquido",
    "liquidabili": "liquidabile",
    "liquidai": "liquidare",
    "liquidammo": "liquidare",
    "liquidan": "liquidare",
    "liquidando": "liquidare",
    "liquidano": "liquidare",
    "liquidante": "liquidare",
    "liquidanti": "liquidare",
    "liquidar": "liquidare",
    "liquidaron": "liquidare",
    "liquidarono": "liquidare",
    "liquidasse": "liquidare",
    "liquidasser": "liquidare",
    "liquidassero": "liquidare",
    "liquidassi": "liquidare",
    "liquidassimo": "liquidare",
    "liquidaste": "liquidare",
    "liquidasti": "liquidare",
    "liquidata": "liquidare",
    "liquidate": "liquidare",
    "liquidati": "liquidare",
    "liquidato": "liquidare",
    "liquidatori": "liquidatorio",
    "liquidatoria": "liquidatorio",
    "liquidatorie": "liquidatorio",
    "liquidatrice": "liquidatore",
    "liquidatrici": "liquidatore",
    "liquidava": "liquidare",
    "liquidavamo": "liquidare",
    "liquidavan": "liquidare",
    "liquidavano": "liquidare",
    "liquidavate": "liquidare",
    "liquidavi": "liquidare",
    "liquidavo": "liquidare",
    "liquidazioni": "liquidazione",
    "liquide": "liquido",
    "liquiderai": "liquidare",
    "liquideran": "liquidare",
    "liquideranno": "liquidare",
    "liquiderebbe": "liquidare",
    "liquiderebber": "liquidare",
    "liquiderebbero": "liquidare",
    "liquiderei": "liquidare",
    "liquideremmo": "liquidare",
    "liquideremo": "liquidare",
    "liquidereste": "liquidare",
    "liquideresti": "liquidare",
    "liquiderete": "liquidare",
    "liquiderà": "liquidare",
    "liquiderò": "liquidare",
    "liquidi": "liquido",
    "liquidiamo": "liquidare",
    "liquidiate": "liquidare",
    "liquidin": "liquidare",
    "liquidino": "liquidare",
    "liquido": "liquidare",
    "liquidò": "liquidare",
    "liquori": "liquore",
    "lire": "lira",
    "lirette": "liretta",
    "lirica": "lirico",
    "liriche": "lirico",
    "lirici": "lirico",
    "lirismi": "lirismo",
    "lisa": "liso",
    "lisce": "liscio",
    "liscerai": "lisciare",
    "lisceran": "lisciare",
    "lisceranno": "lisciare",
    "liscerebbe": "lisciare",
    "liscerebber": "lisciare",
    "liscerebbero": "lisciare",
    "liscerei": "lisciare",
    "lisceremmo": "lisciare",
    "lisceremo": "lisciare",
    "liscereste": "lisciare",
    "lisceresti": "lisciare",
    "liscerete": "lisciare",
    "liscerà": "lisciare",
    "liscerò": "lisciare",
    "lische": "lisca",
    "lisci": "liscio",
    "liscia": "liscio",
    "lisciai": "lisciare",
    "lisciammo": "lisciare",
    "lisciamo": "lisciare",
    "liscian": "lisciare",
    "lisciando": "lisciare",
    "lisciano": "lisciare",
    "lisciante": "lisciare",
    "liscianti": "lisciare",
    "lisciar": "lisciare",
    "lisciaron": "lisciare",
    "lisciarono": "lisciare",
    "lisciasse": "lisciare",
    "lisciasser": "lisciare",
    "lisciassero": "lisciare",
    "lisciassi": "lisciare",
    "lisciassimo": "lisciare",
    "lisciaste": "lisciare",
    "lisciasti": "lisciare",
    "lisciata": "lisciare",
    "lisciate": "lisciare",
    "lisciati": "lisciare",
    "lisciato": "lisciare",
    "lisciava": "lisciare",
    "lisciavamo": "lisciare",
    "lisciavan": "lisciare",
    "lisciavano": "lisciare",
    "lisciavate": "lisciare",
    "lisciavi": "lisciare",
    "lisciavo": "lisciare",
    "liscin": "lisciare",
    "liscino": "lisciare",
    "liscio": "lisciare",
    "liscivi": "lisciviare",
    "liscivia": "lisciviare",
    "lisciviai": "lisciviare",
    "lisciviammo": "lisciviare",
    "lisciviamo": "lisciviare",
    "liscivian": "lisciviare",
    "lisciviando": "lisciviare",
    "lisciviano": "lisciviare",
    "lisciviante": "lisciviare",
    "liscivianti": "lisciviare",
    "lisciviar": "lisciviare",
    "lisciviaron": "lisciviare",
    "lisciviarono": "lisciviare",
    "lisciviasse": "lisciviare",
    "lisciviasser": "lisciviare",
    "lisciviassero": "lisciviare",
    "lisciviassi": "lisciviare",
    "lisciviassimo": "lisciviare",
    "lisciviaste": "lisciviare",
    "lisciviasti": "lisciviare",
    "lisciviata": "lisciviare",
    "lisciviate": "lisciviare",
    "lisciviati": "lisciviare",
    "lisciviato": "lisciviare",
    "lisciviava": "lisciviare",
    "lisciviavamo": "lisciviare",
    "lisciviavan": "lisciviare",
    "lisciviavano": "lisciviare",
    "lisciviavate": "lisciviare",
    "lisciviavi": "lisciviare",
    "lisciviavo": "lisciviare",
    "liscivierai": "lisciviare",
    "liscivieran": "lisciviare",
    "liscivieranno": "lisciviare",
    "liscivierebbe": "lisciviare",
    "liscivierebber": "lisciviare",
    "liscivierebbero": "lisciviare",
    "liscivierei": "lisciviare",
    "liscivieremmo": "lisciviare",
    "liscivieremo": "lisciviare",
    "lisciviereste": "lisciviare",
    "liscivieresti": "lisciviare",
    "liscivierete": "lisciviare",
    "liscivierà": "lisciviare",
    "liscivierò": "lisciviare",
    "liscivin": "lisciviare",
    "liscivino": "lisciviare",
    "liscivio": "lisciviare",
    "lisciviò": "lisciviare",
    "lisciò": "lisciare",
    "lise": "liso",
    "lisi": "liso",
    "lista": "listare",
    "listai": "listare",
    "listammo": "listare",
    "listan": "listare",
    "listando": "listare",
    "listano": "listare",
    "listante": "listare",
    "listanti": "listare",
    "listar": "listare",
    "listaron": "listare",
    "listarono": "listare",
    "listasse": "listare",
    "listasser": "listare",
    "listassero": "listare",
    "listassi": "listare",
    "listassimo": "listare",
    "listaste": "listare",
    "listasti": "listare",
    "listata": "listare",
    "listate": "listare",
    "listati": "listare",
    "listato": "listare",
    "listava": "listare",
    "listavamo": "listare",
    "listavan": "listare",
    "listavano": "listare",
    "listavate": "listare",
    "listavi": "listare",
    "listavo": "listare",
    "liste": "lista",
    "listerai": "listare",
    "listeran": "listare",
    "listeranno": "listare",
    "listerebbe": "listare",
    "listerebber": "listare",
    "listerebbero": "listare",
    "listerei": "listare",
    "listeremmo": "listare",
    "listeremo": "listare",
    "listereste": "listare",
    "listeresti": "listare",
    "listerete": "listare",
    "listerà": "listare",
    "listerò": "listare",
    "listi": "listare",
    "listiamo": "listare",
    "listiate": "listare",
    "listin": "listare",
    "listini": "listino",
    "listino": "listare",
    "listo": "listare",
    "listoni": "listone",
    "listò": "listare",
    "litanie": "litania",
    "liti": "lite",
    "litiga": "litigare",
    "litigai": "litigare",
    "litigammo": "litigare",
    "litigan": "litigare",
    "litigando": "litigare",
    "litigano": "litigare",
    "litigante": "litigare",
    "litiganti": "litigare",
    "litigar": "litigare",
    "litigaron": "litigare",
    "litigarono": "litigare",
    "litigasse": "litigare",
    "litigasser": "litigare",
    "litigassero": "litigare",
    "litigassi": "litigare",
    "litigassimo": "litigare",
    "litigaste": "litigare",
    "litigasti": "litigare",
    "litigata": "litigare",
    "litigate": "litigata",
    "litigati": "litigare",
    "litigato": "litigare",
    "litigava": "litigare",
    "litigavamo": "litigare",
    "litigavan": "litigare",
    "litigavano": "litigare",
    "litigavate": "litigare",
    "litigavi": "litigare",
    "litigavo": "litigare",
    "litigherai": "litigare",
    "litigheran": "litigare",
    "litigheranno": "litigare",
    "litigherebbe": "litigare",
    "litigherebber": "litigare",
    "litigherebbero": "litigare",
    "litigherei": "litigare",
    "litigheremmo": "litigare",
    "litigheremo": "litigare",
    "litighereste": "litigare",
    "litigheresti": "litigare",
    "litigherete": "litigare",
    "litigherà": "litigare",
    "litigherò": "litigare",
    "litighi": "litigare",
    "litighiamo": "litigare",
    "litighiate": "litigare",
    "litighin": "litigare",
    "litighino": "litigare",
    "litigi": "litigio",
    "litigiosa": "litigioso",
    "litigiose": "litigioso",
    "litigiosi": "litigioso",
    "litigo": "litigare",
    "litigò": "litigare",
    "litografa": "litografare",
    "litografai": "litografare",
    "litografammo": "litografare",
    "litografan": "litografare",
    "litografando": "litografare",
    "litografano": "litografare",
    "litografante": "litografare",
    "litografanti": "litografare",
    "litografar": "litografare",
    "litografaron": "litografare",
    "litografarono": "litografare",
    "litografasse": "litografare",
    "litografasser": "litografare",
    "litografassero": "litografare",
    "litografassi": "litografare",
    "litografassimo": "litografare",
    "litografaste": "litografare",
    "litografasti": "litografare",
    "litografata": "litografare",
    "litografate": "litografare",
    "litografati": "litografare",
    "litografato": "litografare",
    "litografava": "litografare",
    "litografavamo": "litografare",
    "litografavan": "litografare",
    "litografavano": "litografare",
    "litografavate": "litografare",
    "litografavi": "litografare",
    "litografavo": "litografare",
    "litograferai": "litografare",
    "litograferan": "litografare",
    "litograferanno": "litografare",
    "litograferebbe": "litografare",
    "litograferebber": "litografare",
    "litograferebbero": "litografare",
    "litograferei": "litografare",
    "litograferemmo": "litografare",
    "litograferemo": "litografare",
    "litografereste": "litografare",
    "litograferesti": "litografare",
    "litograferete": "litografare",
    "litograferà": "litografare",
    "litograferò": "litografare",
    "litografi": "litografare",
    "litografiamo": "litografare",
    "litografiate": "litografare",
    "litografica": "litografico",
    "litografiche": "litografico",
    "litografici": "litografico",
    "litografie": "litografia",
    "litografin": "litografare",
    "litografino": "litografare",
    "litografo": "litografare",
    "litografò": "litografare",
    "litorali": "litorale",
    "litoranea": "litoraneo",
    "litoranee": "litoraneo",
    "litoranei": "litoraneo",
    "litri": "litro",
    "littori": "littorio",
    "littoria": "littorio",
    "littorie": "littorio",
    "lituani": "lituano",
    "liturgica": "liturgico",
    "liturgiche": "liturgico",
    "liturgici": "liturgico",
    "liturgie": "liturgia",
    "liutai": "liutaio",
    "liuti": "liuto",
    "livella": "livellare",
    "livellai": "livellare",
    "livellamenti": "livellamento",
    "livellammo": "livellare",
    "livellan": "livellare",
    "livellando": "livellare",
    "livellano": "livellare",
    "livellante": "livellare",
    "livellanti": "livellare",
    "livellar": "livellare",
    "livellaron": "livellare",
    "livellarono": "livellare",
    "livellasse": "livellare",
    "livellasser": "livellare",
    "livellassero": "livellare",
    "livellassi": "livellare",
    "livellassimo": "livellare",
    "livellaste": "livellare",
    "livellasti": "livellare",
    "livellata": "livellare",
    "livellate": "livellare",
    "livellati": "livellare",
    "livellato": "livellare",
    "livellatori": "livellatore",
    "livellatrice": "livellatore",
    "livellatrici": "livellatore",
    "livellava": "livellare",
    "livellavamo": "livellare",
    "livellavan": "livellare",
    "livellavano": "livellare",
    "livellavate": "livellare",
    "livellavi": "livellare",
    "livellavo": "livellare",
    "livellerai": "livellare",
    "livelleran": "livellare",
    "livelleranno": "livellare",
    "livellerebbe": "livellare",
    "livellerebber": "livellare",
    "livellerebbero": "livellare",
    "livellerei": "livellare",
    "livelleremmo": "livellare",
    "livelleremo": "livellare",
    "livellereste": "livellare",
    "livelleresti": "livellare",
    "livellerete": "livellare",
    "livellerà": "livellare",
    "livellerò": "livellare",
    "livelli": "livello",
    "livelliamo": "livellare",
    "livelliate": "livellare",
    "livellin": "livellare",
    "livellino": "livellare",
    "livello": "livellare",
    "livellò": "livellare",
    "livida": "livido",
    "livide": "livido",
    "lividi": "livido",
    "livori": "livore",
    "livornesi": "livornese",
    "livree": "livrea",
    "lo": "il",
    "lobbies": "lobby",
    "lobbisti": "lobbista",
    "lobbysti": "lobbysta",
    "lobi": "lobo",
    "loca": "locare",
    "locai": "locare",
    "locali": "locale",
    "localini": "localino",
    "localismi": "localismo",
    "localizza": "localizzare",
    "localizzabili": "localizzabile",
    "localizzai": "localizzare",
    "localizzammo": "localizzare",
    "localizzan": "localizzare",
    "localizzando": "localizzare",
    "localizzano": "localizzare",
    "localizzante": "localizzare",
    "localizzanti": "localizzare",
    "localizzar": "localizzare",
    "localizzaron": "localizzare",
    "localizzarono": "localizzare",
    "localizzasse": "localizzare",
    "localizzasser": "localizzare",
    "localizzassero": "localizzare",
    "localizzassi": "localizzare",
    "localizzassimo": "localizzare",
    "localizzaste": "localizzare",
    "localizzasti": "localizzare",
    "localizzata": "localizzato",
    "localizzate": "localizzato",
    "localizzati": "localizzato",
    "localizzato": "localizzare",
    "localizzava": "localizzare",
    "localizzavamo": "localizzare",
    "localizzavan": "localizzare",
    "localizzavano": "localizzare",
    "localizzavate": "localizzare",
    "localizzavi": "localizzare",
    "localizzavo": "localizzare",
    "localizzazioni": "localizzazione",
    "localizzerai": "localizzare",
    "localizzeran": "localizzare",
    "localizzeranno": "localizzare",
    "localizzerebbe": "localizzare",
    "localizzerebber": "localizzare",
    "localizzerebbero": "localizzare",
    "localizzerei": "localizzare",
    "localizzeremmo": "localizzare",
    "localizzeremo": "localizzare",
    "localizzereste": "localizzare",
    "localizzeresti": "localizzare",
    "localizzerete": "localizzare",
    "localizzerà": "localizzare",
    "localizzerò": "localizzare",
    "localizzi": "localizzare",
    "localizziamo": "localizzare",
    "localizziate": "localizzare",
    "localizzin": "localizzare",
    "localizzino": "localizzare",
    "localizzo": "localizzare",
    "localizzò": "localizzare",
    "locammo": "locare",
    "locan": "locare",
    "locande": "locanda",
    "locandiere": "locandiera",
    "locandine": "locandina",
    "locando": "locare",
    "locano": "locare",
    "locante": "locare",
    "locanti": "locare",
    "locar": "locare",
    "locaron": "locare",
    "locarono": "locare",
    "locasse": "locare",
    "locasser": "locare",
    "locassero": "locare",
    "locassi": "locare",
    "locassimo": "locare",
    "locaste": "locare",
    "locasti": "locare",
    "locata": "locare",
    "locatari": "locatario",
    "locate": "locare",
    "locati": "locare",
    "locativa": "locativo",
    "locative": "locativo",
    "locativi": "locativo",
    "locato": "locare",
    "locatori": "locatore",
    "locava": "locare",
    "locavamo": "locare",
    "locavan": "locare",
    "locavano": "locare",
    "locavate": "locare",
    "locavi": "locare",
    "locavo": "locare",
    "locazioni": "locazione",
    "locherai": "locare",
    "locheran": "locare",
    "locheranno": "locare",
    "locherebbe": "locare",
    "locherebber": "locare",
    "locherebbero": "locare",
    "locherei": "locare",
    "locheremmo": "locare",
    "locheremo": "locare",
    "lochereste": "locare",
    "locheresti": "locare",
    "locherete": "locare",
    "locherà": "locare",
    "locherò": "locare",
    "lochi": "locare",
    "lochiamo": "locare",
    "lochiate": "locare",
    "lochin": "locare",
    "lochino": "locare",
    "loco": "locare",
    "locomotive": "locomotiva",
    "locomotori": "locomotore",
    "locomotrice": "locomotore",
    "locomotrici": "locomotrice",
    "locupleta": "locupletare",
    "locupletai": "locupletare",
    "locupletammo": "locupletare",
    "locupletan": "locupletare",
    "locupletando": "locupletare",
    "locupletano": "locupletare",
    "locupletante": "locupletare",
    "locupletanti": "locupletare",
    "locupletar": "locupletare",
    "locupletaron": "locupletare",
    "locupletarono": "locupletare",
    "locupletasse": "locupletare",
    "locupletasser": "locupletare",
    "locupletassero": "locupletare",
    "locupletassi": "locupletare",
    "locupletassimo": "locupletare",
    "locupletaste": "locupletare",
    "locupletasti": "locupletare",
    "locupletata": "locupletare",
    "locupletate": "locupletare",
    "locupletati": "locupletare",
    "locupletato": "locupletare",
    "locupletava": "locupletare",
    "locupletavamo": "locupletare",
    "locupletavan": "locupletare",
    "locupletavano": "locupletare",
    "locupletavate": "locupletare",
    "locupletavi": "locupletare",
    "locupletavo": "locupletare",
    "locupleterai": "locupletare",
    "locupleteran": "locupletare",
    "locupleteranno": "locupletare",
    "locupleterebbe": "locupletare",
    "locupleterebber": "locupletare",
    "locupleterebbero": "locupletare",
    "locupleterei": "locupletare",
    "locupleteremmo": "locupletare",
    "locupleteremo": "locupletare",
    "locupletereste": "locupletare",
    "locupleteresti": "locupletare",
    "locupleterete": "locupletare",
    "locupleterà": "locupletare",
    "locupleterò": "locupletare",
    "locupleti": "locupletare",
    "locupletiamo": "locupletare",
    "locupletiate": "locupletare",
    "locupletin": "locupletare",
    "locupletino": "locupletare",
    "locupleto": "locupletare",
    "locupletò": "locupletare",
    "locuste": "locusta",
    "locuzioni": "locuzione",
    "locò": "locare",
    "loda": "lodare",
    "lodai": "lodare",
    "lodammo": "lodare",
    "lodan": "lodare",
    "lodando": "lodare",
    "lodano": "lodare",
    "lodante": "lodare",
    "lodanti": "lodare",
    "lodar": "lodare",
    "lodaron": "lodare",
    "lodarono": "lodare",
    "lodasse": "lodare",
    "lodasser": "lodare",
    "lodassero": "lodare",
    "lodassi": "lodare",
    "lodassimo": "lodare",
    "lodaste": "lodare",
    "lodasti": "lodare",
    "lodata": "lodare",
    "lodate": "lodare",
    "lodati": "lodare",
    "lodato": "lodare",
    "lodava": "lodare",
    "lodavamo": "lodare",
    "lodavan": "lodare",
    "lodavano": "lodare",
    "lodavate": "lodare",
    "lodavi": "lodare",
    "lodavo": "lodare",
    "loderai": "lodare",
    "loderan": "lodare",
    "loderanno": "lodare",
    "loderebbe": "lodare",
    "loderebber": "lodare",
    "loderebbero": "lodare",
    "loderei": "lodare",
    "loderemmo": "lodare",
    "loderemo": "lodare",
    "lodereste": "lodare",
    "loderesti": "lodare",
    "loderete": "lodare",
    "loderà": "lodare",
    "loderò": "lodare",
    "lodevoli": "lodevole",
    "lodi": "lodo",
    "lodiamo": "lodare",
    "lodiate": "lodare",
    "lodin": "lodare",
    "lodino": "lodare",
    "lodo": "lodare",
    "lodò": "lodare",
    "logge": "loggia",
    "loggiati": "loggiato",
    "loggioni": "loggione",
    "loggionisti": "loggionista",
    "loghi": "logo",
    "logica": "logico",
    "logiche": "logico",
    "logici": "logico",
    "logistica": "logistico",
    "logistiche": "logistico",
    "logistici": "logistico",
    "logoi": "logos",
    "logora": "logoro",
    "logorai": "logorare",
    "logoramenti": "logoramento",
    "logorammo": "logorare",
    "logoran": "logorare",
    "logorando": "logorare",
    "logorano": "logorare",
    "logorante": "logorare",
    "logoranti": "logorare",
    "logorar": "logorare",
    "logoraron": "logorare",
    "logorarono": "logorare",
    "logorasse": "logorare",
    "logorasser": "logorare",
    "logorassero": "logorare",
    "logorassi": "logorare",
    "logorassimo": "logorare",
    "logoraste": "logorare",
    "logorasti": "logorare",
    "logorata": "logorare",
    "logorate": "logorare",
    "logorati": "logorare",
    "logorato": "logorare",
    "logorava": "logorare",
    "logoravamo": "logorare",
    "logoravan": "logorare",
    "logoravano": "logorare",
    "logoravate": "logorare",
    "logoravi": "logorare",
    "logoravo": "logorare",
    "logore": "logoro",
    "logorerai": "logorare",
    "logoreran": "logorare",
    "logoreranno": "logorare",
    "logorerebbe": "logorare",
    "logorerebber": "logorare",
    "logorerebbero": "logorare",
    "logorerei": "logorare",
    "logoreremmo": "logorare",
    "logoreremo": "logorare",
    "logorereste": "logorare",
    "logoreresti": "logorare",
    "logorerete": "logorare",
    "logorerà": "logorare",
    "logorerò": "logorare",
    "logori": "logoro",
    "logoriamo": "logorare",
    "logoriate": "logorare",
    "logorin": "logorare",
    "logorino": "logorare",
    "logoro": "logorare",
    "logorree": "logorrea",
    "logorroica": "logorroico",
    "logorroiche": "logorroico",
    "logorroici": "logorroico",
    "logorò": "logorare",
    "lolite": "lolita",
    "lombarda": "lombardo",
    "lombarde": "lombardo",
    "lombardi": "lombardo",
    "lombari": "lombare",
    "lombi": "lombo",
    "lombrichi": "lombrico",
    "londinesi": "londinese",
    "longanima": "longanimo",
    "longanime": "longanimo",
    "longanimi": "longanimo",
    "longeva": "longevo",
    "longeve": "longevo",
    "longevi": "longevo",
    "longilinea": "longilineo",
    "longilinee": "longilineo",
    "longilinei": "longilineo",
    "longitudinali": "longitudinale",
    "longitudini": "longitudine",
    "longobarda": "longobardo",
    "longobarde": "longobardo",
    "longobardi": "longobardo",
    "lontana": "lontano",
    "lontananze": "lontananza",
    "lontane": "lontano",
    "lontani": "lontano",
    "lontre": "lontra",
    "loquaci": "loquace",
    "lorda": "lordo",
    "lordai": "lordare",
    "lordammo": "lordare",
    "lordan": "lordare",
    "lordando": "lordare",
    "lordano": "lordare",
    "lordante": "lordare",
    "lordanti": "lordare",
    "lordar": "lordare",
    "lordaron": "lordare",
    "lordarono": "lordare",
    "lordasse": "lordare",
    "lordasser": "lordare",
    "lordassero": "lordare",
    "lordassi": "lordare",
    "lordassimo": "lordare",
    "lordaste": "lordare",
    "lordasti": "lordare",
    "lordata": "lordare",
    "lordate": "lordare",
    "lordati": "lordare",
    "lordato": "lordare",
    "lordava": "lordare",
    "lordavamo": "lordare",
    "lordavan": "lordare",
    "lordavano": "lordare",
    "lordavate": "lordare",
    "lordavi": "lordare",
    "lordavo": "lordare",
    "lorde": "lordo",
    "lorderai": "lordare",
    "lorderan": "lordare",
    "lorderanno": "lordare",
    "lorderebbe": "lordare",
    "lorderebber": "lordare",
    "lorderebbero": "lordare",
    "lorderei": "lordare",
    "lorderemmo": "lordare",
    "lorderemo": "lordare",
    "lordereste": "lordare",
    "lorderesti": "lordare",
    "lorderete": "lordare",
    "lorderà": "lordare",
    "lorderò": "lordare",
    "lordi": "lordo",
    "lordiamo": "lordare",
    "lordiate": "lordare",
    "lordin": "lordare",
    "lordino": "lordare",
    "lordo": "lordare",
    "lordò": "lordare",
    "losca": "losco",
    "losche": "losco",
    "loschi": "losco",
    "lotta": "lottare",
    "lottai": "lottare",
    "lottammo": "lottare",
    "lottan": "lottare",
    "lottando": "lottare",
    "lottano": "lottare",
    "lottante": "lottare",
    "lottanti": "lottare",
    "lottar": "lottare",
    "lottaron": "lottare",
    "lottarono": "lottare",
    "lottasse": "lottare",
    "lottasser": "lottare",
    "lottassero": "lottare",
    "lottassi": "lottare",
    "lottassimo": "lottare",
    "lottaste": "lottare",
    "lottasti": "lottare",
    "lottata": "lottare",
    "lottate": "lottare",
    "lottati": "lottare",
    "lottato": "lottare",
    "lottatori": "lottatore",
    "lottava": "lottare",
    "lottavamo": "lottare",
    "lottavan": "lottare",
    "lottavano": "lottare",
    "lottavate": "lottare",
    "lottavi": "lottare",
    "lottavo": "lottare",
    "lotte": "lotta",
    "lotterai": "lottare",
    "lotteran": "lottare",
    "lotteranno": "lottare",
    "lotterebbe": "lottare",
    "lotterebber": "lottare",
    "lotterebbero": "lottare",
    "lotterei": "lottare",
    "lotteremmo": "lottare",
    "lotteremo": "lottare",
    "lottereste": "lottare",
    "lotteresti": "lottare",
    "lotterete": "lottare",
    "lotterie": "lotteria",
    "lotterà": "lottare",
    "lotterò": "lottare",
    "lotti": "lotto",
    "lottiamo": "lottare",
    "lottiate": "lottare",
    "lottin": "lottare",
    "lottino": "lottare",
    "lottizza": "lottizzare",
    "lottizzai": "lottizzare",
    "lottizzammo": "lottizzare",
    "lottizzan": "lottizzare",
    "lottizzando": "lottizzare",
    "lottizzano": "lottizzare",
    "lottizzante": "lottizzare",
    "lottizzanti": "lottizzare",
    "lottizzar": "lottizzare",
    "lottizzaron": "lottizzare",
    "lottizzarono": "lottizzare",
    "lottizzasse": "lottizzare",
    "lottizzasser": "lottizzare",
    "lottizzassero": "lottizzare",
    "lottizzassi": "lottizzare",
    "lottizzassimo": "lottizzare",
    "lottizzaste": "lottizzare",
    "lottizzasti": "lottizzare",
    "lottizzata": "lottizzare",
    "lottizzate": "lottizzare",
    "lottizzati": "lottizzato",
    "lottizzato": "lottizzare",
    "lottizzatori": "lottizzatore",
    "lottizzava": "lottizzare",
    "lottizzavamo": "lottizzare",
    "lottizzavan": "lottizzare",
    "lottizzavano": "lottizzare",
    "lottizzavate": "lottizzare",
    "lottizzavi": "lottizzare",
    "lottizzavo": "lottizzare",
    "lottizzazioni": "lottizzazione",
    "lottizzerai": "lottizzare",
    "lottizzeran": "lottizzare",
    "lottizzeranno": "lottizzare",
    "lottizzerebbe": "lottizzare",
    "lottizzerebber": "lottizzare",
    "lottizzerebbero": "lottizzare",
    "lottizzerei": "lottizzare",
    "lottizzeremmo": "lottizzare",
    "lottizzeremo": "lottizzare",
    "lottizzereste": "lottizzare",
    "lottizzeresti": "lottizzare",
    "lottizzerete": "lottizzare",
    "lottizzerà": "lottizzare",
    "lottizzerò": "lottizzare",
    "lottizzi": "lottizzare",
    "lottizziamo": "lottizzare",
    "lottizziate": "lottizzare",
    "lottizzin": "lottizzare",
    "lottizzino": "lottizzare",
    "lottizzo": "lottizzare",
    "lottizzò": "lottizzare",
    "lotto": "lottare",
    "lottò": "lottare",
    "love-stories": "love-story",
    "lozioni": "lozione",
    "lubrica": "lubrico",
    "lubriche": "lubrico",
    "lubrici": "lubrico",
    "lubrifica": "lubrificare",
    "lubrificai": "lubrificare",
    "lubrificammo": "lubrificare",
    "lubrifican": "lubrificare",
    "lubrificando": "lubrificare",
    "lubrificano": "lubrificare",
    "lubrificante": "lubrificare",
    "lubrificanti": "lubrificare",
    "lubrificar": "lubrificare",
    "lubrificaron": "lubrificare",
    "lubrificarono": "lubrificare",
    "lubrificasse": "lubrificare",
    "lubrificasser": "lubrificare",
    "lubrificassero": "lubrificare",
    "lubrificassi": "lubrificare",
    "lubrificassimo": "lubrificare",
    "lubrificaste": "lubrificare",
    "lubrificasti": "lubrificare",
    "lubrificata": "lubrificare",
    "lubrificate": "lubrificare",
    "lubrificati": "lubrificare",
    "lubrificato": "lubrificare",
    "lubrificava": "lubrificare",
    "lubrificavamo": "lubrificare",
    "lubrificavan": "lubrificare",
    "lubrificavano": "lubrificare",
    "lubrificavate": "lubrificare",
    "lubrificavi": "lubrificare",
    "lubrificavo": "lubrificare",
    "lubrificherai": "lubrificare",
    "lubrificheran": "lubrificare",
    "lubrificheranno": "lubrificare",
    "lubrificherebbe": "lubrificare",
    "lubrificherebber": "lubrificare",
    "lubrificherebbero": "lubrificare",
    "lubrificherei": "lubrificare",
    "lubrificheremmo": "lubrificare",
    "lubrificheremo": "lubrificare",
    "lubrifichereste": "lubrificare",
    "lubrificheresti": "lubrificare",
    "lubrificherete": "lubrificare",
    "lubrificherà": "lubrificare",
    "lubrificherò": "lubrificare",
    "lubrifichi": "lubrificare",
    "lubrifichiamo": "lubrificare",
    "lubrifichiate": "lubrificare",
    "lubrifichin": "lubrificare",
    "lubrifichino": "lubrificare",
    "lubrifico": "lubrificare",
    "lubrificò": "lubrificare",
    "luca": "lucere",
    "lucan": "lucere",
    "lucana": "lucano",
    "lucane": "lucano",
    "lucani": "lucano",
    "lucano": "lucere",
    "lucchesi": "lucchese",
    "lucchetti": "lucchetto",
    "luccica": "luccicare",
    "luccicai": "luccicare",
    "luccicammo": "luccicare",
    "luccican": "luccicare",
    "luccicando": "luccicare",
    "luccicano": "luccicare",
    "luccicante": "luccicare",
    "luccicanti": "luccicare",
    "luccicar": "luccicare",
    "luccicaron": "luccicare",
    "luccicarono": "luccicare",
    "luccicasse": "luccicare",
    "luccicasser": "luccicare",
    "luccicassero": "luccicare",
    "luccicassi": "luccicare",
    "luccicassimo": "luccicare",
    "luccicaste": "luccicare",
    "luccicasti": "luccicare",
    "luccicata": "luccicare",
    "luccicate": "luccicare",
    "luccicati": "luccicare",
    "luccicato": "luccicare",
    "luccicava": "luccicare",
    "luccicavamo": "luccicare",
    "luccicavan": "luccicare",
    "luccicavano": "luccicare",
    "luccicavate": "luccicare",
    "luccicavi": "luccicare",
    "luccicavo": "luccicare",
    "luccicherai": "luccicare",
    "luccicheran": "luccicare",
    "luccicheranno": "luccicare",
    "luccicherebbe": "luccicare",
    "luccicherebber": "luccicare",
    "luccicherebbero": "luccicare",
    "luccicherei": "luccicare",
    "luccicheremmo": "luccicare",
    "luccicheremo": "luccicare",
    "luccichereste": "luccicare",
    "luccicheresti": "luccicare",
    "luccicherete": "luccicare",
    "luccicherà": "luccicare",
    "luccicherò": "luccicare",
    "luccichi": "luccicare",
    "luccichiamo": "luccicare",
    "luccichiate": "luccicare",
    "luccichii": "luccichio",
    "luccichin": "luccicare",
    "luccichino": "luccicare",
    "luccico": "luccicare",
    "lucciconi": "luccicone",
    "luccicò": "luccicare",
    "lucciole": "lucciola",
    "luce": "lucere",
    "lucei": "lucere",
    "lucemmo": "lucere",
    "lucendo": "lucere",
    "lucente": "lucere",
    "lucentezze": "lucentezza",
    "lucenti": "lucere",
    "lucer": "lucere",
    "lucerai": "lucere",
    "luceran": "lucere",
    "luceranno": "lucere",
    "lucerebbe": "lucere",
    "lucerebber": "lucere",
    "lucerebbero": "lucere",
    "lucerei": "lucere",
    "luceremmo": "lucere",
    "luceremo": "lucere",
    "lucereste": "lucere",
    "luceresti": "lucere",
    "lucerete": "lucere",
    "lucernai": "lucernaio",
    "lucernari": "lucernario",
    "luceron": "lucere",
    "lucerono": "lucere",
    "lucertole": "lucertola",
    "lucertoloni": "lucertolone",
    "lucerà": "lucere",
    "lucerò": "lucere",
    "lucesse": "lucere",
    "lucesser": "lucere",
    "lucessero": "lucere",
    "lucessi": "lucere",
    "lucessimo": "lucere",
    "luceste": "lucere",
    "lucesti": "lucere",
    "lucete": "lucere",
    "lucette": "lucetta",
    "luceva": "lucere",
    "lucevamo": "lucere",
    "lucevan": "lucere",
    "lucevano": "lucere",
    "lucevate": "lucere",
    "lucevi": "lucere",
    "lucevo": "lucere",
    "luci": "lucere",
    "luciamo": "lucere",
    "luciate": "lucere",
    "lucida": "lucido",
    "lucidai": "lucidare",
    "lucidammo": "lucidare",
    "lucidan": "lucidare",
    "lucidando": "lucidare",
    "lucidano": "lucidare",
    "lucidante": "lucidare",
    "lucidanti": "lucidare",
    "lucidar": "lucidare",
    "lucidaron": "lucidare",
    "lucidarono": "lucidare",
    "lucidasse": "lucidare",
    "lucidasser": "lucidare",
    "lucidassero": "lucidare",
    "lucidassi": "lucidare",
    "lucidassimo": "lucidare",
    "lucidaste": "lucidare",
    "lucidasti": "lucidare",
    "lucidata": "lucidare",
    "lucidate": "lucidare",
    "lucidati": "lucidare",
    "lucidato": "lucidare",
    "lucidava": "lucidare",
    "lucidavamo": "lucidare",
    "lucidavan": "lucidare",
    "lucidavano": "lucidare",
    "lucidavate": "lucidare",
    "lucidavi": "lucidare",
    "lucidavo": "lucidare",
    "lucide": "lucido",
    "luciderai": "lucidare",
    "lucideran": "lucidare",
    "lucideranno": "lucidare",
    "luciderebbe": "lucidare",
    "luciderebber": "lucidare",
    "luciderebbero": "lucidare",
    "luciderei": "lucidare",
    "lucideremmo": "lucidare",
    "lucideremo": "lucidare",
    "lucidereste": "lucidare",
    "lucideresti": "lucidare",
    "luciderete": "lucidare",
    "luciderà": "lucidare",
    "luciderò": "lucidare",
    "lucidi": "lucido",
    "lucidiamo": "lucidare",
    "lucidiate": "lucidare",
    "lucidin": "lucidare",
    "lucidino": "lucidare",
    "lucido": "lucidare",
    "lucidò": "lucidare",
    "lucine": "lucina",
    "luciuta": "lucere",
    "luciute": "lucere",
    "luciuti": "lucere",
    "luciuto": "lucere",
    "luco": "lucere",
    "lucon": "lucere",
    "lucono": "lucere",
    "lucra": "lucrare",
    "lucrai": "lucrare",
    "lucrammo": "lucrare",
    "lucran": "lucrare",
    "lucrando": "lucrare",
    "lucrano": "lucrare",
    "lucrante": "lucrare",
    "lucranti": "lucrare",
    "lucrar": "lucrare",
    "lucraron": "lucrare",
    "lucrarono": "lucrare",
    "lucrasse": "lucrare",
    "lucrasser": "lucrare",
    "lucrassero": "lucrare",
    "lucrassi": "lucrare",
    "lucrassimo": "lucrare",
    "lucraste": "lucrare",
    "lucrasti": "lucrare",
    "lucrata": "lucrare",
    "lucrate": "lucrare",
    "lucrati": "lucrare",
    "lucrativa": "lucrativo",
    "lucrative": "lucrativo",
    "lucrativi": "lucrativo",
    "lucrato": "lucrare",
    "lucrava": "lucrare",
    "lucravamo": "lucrare",
    "lucravan": "lucrare",
    "lucravano": "lucrare",
    "lucravate": "lucrare",
    "lucravi": "lucrare",
    "lucravo": "lucrare",
    "lucrerai": "lucrare",
    "lucreran": "lucrare",
    "lucreranno": "lucrare",
    "lucrerebbe": "lucrare",
    "lucrerebber": "lucrare",
    "lucrerebbero": "lucrare",
    "lucrerei": "lucrare",
    "lucreremmo": "lucrare",
    "lucreremo": "lucrare",
    "lucrereste": "lucrare",
    "lucreresti": "lucrare",
    "lucrerete": "lucrare",
    "lucrerà": "lucrare",
    "lucrerò": "lucrare",
    "lucri": "lucro",
    "lucriamo": "lucrare",
    "lucriate": "lucrare",
    "lucrin": "lucrare",
    "lucrino": "lucrare",
    "lucro": "lucrare",
    "lucrosa": "lucroso",
    "lucrose": "lucroso",
    "lucrosi": "lucroso",
    "lucrò": "lucrare",
    "luculliana": "luculliano",
    "luculliane": "luculliano",
    "luculliani": "luculliano",
    "lucè": "lucere",
    "ludibrii": "ludibrio",
    "ludica": "ludico",
    "ludiche": "ludico",
    "ludici": "ludico",
    "ludoteche": "ludoteca",
    "lugli": "luglio",
    "lugubri": "lugubre",
    "lumache": "lumaca",
    "lumeggerai": "lumeggiare",
    "lumeggeran": "lumeggiare",
    "lumeggeranno": "lumeggiare",
    "lumeggerebbe": "lumeggiare",
    "lumeggerebber": "lumeggiare",
    "lumeggerebbero": "lumeggiare",
    "lumeggerei": "lumeggiare",
    "lumeggeremmo": "lumeggiare",
    "lumeggeremo": "lumeggiare",
    "lumeggereste": "lumeggiare",
    "lumeggeresti": "lumeggiare",
    "lumeggerete": "lumeggiare",
    "lumeggerà": "lumeggiare",
    "lumeggerò": "lumeggiare",
    "lumeggi": "lumeggiare",
    "lumeggia": "lumeggiare",
    "lumeggiai": "lumeggiare",
    "lumeggiammo": "lumeggiare",
    "lumeggiamo": "lumeggiare",
    "lumeggian": "lumeggiare",
    "lumeggiando": "lumeggiare",
    "lumeggiano": "lumeggiare",
    "lumeggiante": "lumeggiare",
    "lumeggianti": "lumeggiare",
    "lumeggiar": "lumeggiare",
    "lumeggiaron": "lumeggiare",
    "lumeggiarono": "lumeggiare",
    "lumeggiasse": "lumeggiare",
    "lumeggiasser": "lumeggiare",
    "lumeggiassero": "lumeggiare",
    "lumeggiassi": "lumeggiare",
    "lumeggiassimo": "lumeggiare",
    "lumeggiaste": "lumeggiare",
    "lumeggiasti": "lumeggiare",
    "lumeggiata": "lumeggiare",
    "lumeggiate": "lumeggiare",
    "lumeggiati": "lumeggiare",
    "lumeggiato": "lumeggiare",
    "lumeggiava": "lumeggiare",
    "lumeggiavamo": "lumeggiare",
    "lumeggiavan": "lumeggiare",
    "lumeggiavano": "lumeggiare",
    "lumeggiavate": "lumeggiare",
    "lumeggiavi": "lumeggiare",
    "lumeggiavo": "lumeggiare",
    "lumeggin": "lumeggiare",
    "lumeggino": "lumeggiare",
    "lumeggio": "lumeggiare",
    "lumeggiò": "lumeggiare",
    "lumi": "lume",
    "lumicini": "lumicino",
    "lumina": "luminare",
    "luminai": "luminare",
    "luminammo": "luminare",
    "luminan": "luminare",
    "luminando": "luminare",
    "luminano": "luminare",
    "luminante": "luminare",
    "luminanti": "luminare",
    "luminar": "luminare",
    "luminari": "luminare",
    "luminarie": "luminaria",
    "luminaron": "luminare",
    "luminarono": "luminare",
    "luminasse": "luminare",
    "luminasser": "luminare",
    "luminassero": "luminare",
    "luminassi": "luminare",
    "luminassimo": "luminare",
    "luminaste": "luminare",
    "luminasti": "luminare",
    "luminata": "luminare",
    "luminate": "luminare",
    "luminati": "luminare",
    "luminato": "luminare",
    "luminava": "luminare",
    "luminavamo": "luminare",
    "luminavan": "luminare",
    "luminavano": "luminare",
    "luminavate": "luminare",
    "luminavi": "luminare",
    "luminavo": "luminare",
    "luminerai": "luminare",
    "lumineran": "luminare",
    "lumineranno": "luminare",
    "luminerebbe": "luminare",
    "luminerebber": "luminare",
    "luminerebbero": "luminare",
    "luminerei": "luminare",
    "lumineremmo": "luminare",
    "lumineremo": "luminare",
    "luminereste": "luminare",
    "lumineresti": "luminare",
    "luminerete": "luminare",
    "luminerà": "luminare",
    "luminerò": "luminare",
    "luminescenti": "luminescente",
    "luminescenze": "luminescenza",
    "lumini": "lumino",
    "luminiamo": "luminare",
    "luminiate": "luminare",
    "luminin": "luminare",
    "luminino": "luminare",
    "luministica": "luministico",
    "luministiche": "luministico",
    "luministici": "luministico",
    "lumino": "luminare",
    "luminosa": "luminoso",
    "luminose": "luminoso",
    "luminosi": "luminoso",
    "luminò": "luminare",
    "luna": "lunare",
    "lunai": "lunare",
    "lunammo": "lunare",
    "lunan": "lunare",
    "lunando": "lunare",
    "lunano": "lunare",
    "lunante": "lunare",
    "lunanti": "lunare",
    "lunar": "lunare",
    "lunari": "lunario",
    "lunaron": "lunare",
    "lunarono": "lunare",
    "lunasse": "lunare",
    "lunasser": "lunare",
    "lunassero": "lunare",
    "lunassi": "lunare",
    "lunassimo": "lunare",
    "lunaste": "lunare",
    "lunasti": "lunare",
    "lunata": "lunato",
    "lunate": "lunato",
    "lunati": "lunato",
    "lunatica": "lunatico",
    "lunatiche": "lunatico",
    "lunatici": "lunatico",
    "lunato": "lunare",
    "lunava": "lunare",
    "lunavamo": "lunare",
    "lunavan": "lunare",
    "lunavano": "lunare",
    "lunavate": "lunare",
    "lunavi": "lunare",
    "lunavo": "lunare",
    "lune": "luna",
    "lunerai": "lunare",
    "luneran": "lunare",
    "luneranno": "lunare",
    "lunerebbe": "lunare",
    "lunerebber": "lunare",
    "lunerebbero": "lunare",
    "lunerei": "lunare",
    "luneremmo": "lunare",
    "luneremo": "lunare",
    "lunereste": "lunare",
    "luneresti": "lunare",
    "lunerete": "lunare",
    "lunerà": "lunare",
    "lunerò": "lunare",
    "lunette": "lunetta",
    "lunga": "lungo",
    "lungaggini": "lungaggine",
    "lungagnoni": "lungagnone",
    "lungarni": "lungarno",
    "lunghe": "lungo",
    "lunghezze": "lunghezza",
    "lunghi": "lungo",
    "lungimiranti": "lungimirante",
    "lungodegenti": "lungodegente",
    "lungometraggi": "lungometraggio",
    "luni": "lunare",
    "luniamo": "lunare",
    "luniate": "lunare",
    "lunin": "lunare",
    "lunino": "lunare",
    "luno": "lunare",
    "lunotti": "lunotto",
    "lunò": "lunare",
    "luoghi": "luogo",
    "luogotenenti": "luogotenente",
    "lupanari": "lupanare",
    "lupare": "lupara",
    "lupe": "lupa",
    "lupesca": "lupesco",
    "lupesche": "lupesco",
    "lupeschi": "lupesco",
    "lupetti": "lupetto",
    "lupi": "lupo",
    "lurida": "lurido",
    "luride": "lurido",
    "luridi": "lurido",
    "lusinga": "lusingare",
    "lusingai": "lusingare",
    "lusingammo": "lusingare",
    "lusingan": "lusingare",
    "lusingando": "lusingare",
    "lusingano": "lusingare",
    "lusingante": "lusingare",
    "lusinganti": "lusingare",
    "lusingar": "lusingare",
    "lusingaron": "lusingare",
    "lusingarono": "lusingare",
    "lusingasse": "lusingare",
    "lusingasser": "lusingare",
    "lusingassero": "lusingare",
    "lusingassi": "lusingare",
    "lusingassimo": "lusingare",
    "lusingaste": "lusingare",
    "lusingasti": "lusingare",
    "lusingata": "lusingare",
    "lusingate": "lusingare",
    "lusingati": "lusingare",
    "lusingato": "lusingare",
    "lusingava": "lusingare",
    "lusingavamo": "lusingare",
    "lusingavan": "lusingare",
    "lusingavano": "lusingare",
    "lusingavate": "lusingare",
    "lusingavi": "lusingare",
    "lusingavo": "lusingare",
    "lusinghe": "lusinga",
    "lusingherai": "lusingare",
    "lusingheran": "lusingare",
    "lusingheranno": "lusingare",
    "lusingherebbe": "lusingare",
    "lusingherebber": "lusingare",
    "lusingherebbero": "lusingare",
    "lusingherei": "lusingare",
    "lusingheremmo": "lusingare",
    "lusingheremo": "lusingare",
    "lusinghereste": "lusingare",
    "lusingheresti": "lusingare",
    "lusingherete": "lusingare",
    "lusingherà": "lusingare",
    "lusingherò": "lusingare",
    "lusinghi": "lusingare",
    "lusinghiamo": "lusingare",
    "lusinghiate": "lusingare",
    "lusinghiera": "lusinghiero",
    "lusinghiere": "lusinghiero",
    "lusinghieri": "lusinghiero",
    "lusinghin": "lusingare",
    "lusinghino": "lusingare",
    "lusingo": "lusingare",
    "lusingò": "lusingare",
    "lusitana": "lusitano",
    "lusitane": "lusitano",
    "lusitani": "lusitano",
    "lussa": "lussare",
    "lussai": "lussare",
    "lussammo": "lussare",
    "lussan": "lussare",
    "lussando": "lussare",
    "lussano": "lussare",
    "lussante": "lussare",
    "lussanti": "lussare",
    "lussar": "lussare",
    "lussaron": "lussare",
    "lussarono": "lussare",
    "lussasse": "lussare",
    "lussasser": "lussare",
    "lussassero": "lussare",
    "lussassi": "lussare",
    "lussassimo": "lussare",
    "lussaste": "lussare",
    "lussasti": "lussare",
    "lussata": "lussare",
    "lussate": "lussare",
    "lussati": "lussare",
    "lussato": "lussare",
    "lussava": "lussare",
    "lussavamo": "lussare",
    "lussavan": "lussare",
    "lussavano": "lussare",
    "lussavate": "lussare",
    "lussavi": "lussare",
    "lussavo": "lussare",
    "lussazioni": "lussazione",
    "lussemburghesi": "lussemburghese",
    "lusserai": "lussare",
    "lusseran": "lussare",
    "lusseranno": "lussare",
    "lusserebbe": "lussare",
    "lusserebber": "lussare",
    "lusserebbero": "lussare",
    "lusserei": "lussare",
    "lusseremmo": "lussare",
    "lusseremo": "lussare",
    "lussereste": "lussare",
    "lusseresti": "lussare",
    "lusserete": "lussare",
    "lusserà": "lussare",
    "lusserò": "lussare",
    "lussi": "lusso",
    "lussiamo": "lussare",
    "lussiate": "lussare",
    "lussin": "lussare",
    "lussino": "lussare",
    "lusso": "lussare",
    "lussuosa": "lussuoso",
    "lussuose": "lussuoso",
    "lussuosi": "lussuoso",
    "lussureggerai": "lussureggiare",
    "lussureggeran": "lussureggiare",
    "lussureggeranno": "lussureggiare",
    "lussureggerebbe": "lussureggiare",
    "lussureggerebber": "lussureggiare",
    "lussureggerebbero": "lussureggiare",
    "lussureggerei": "lussureggiare",
    "lussureggeremmo": "lussureggiare",
    "lussureggeremo": "lussureggiare",
    "lussureggereste": "lussureggiare",
    "lussureggeresti": "lussureggiare",
    "lussureggerete": "lussureggiare",
    "lussureggerà": "lussureggiare",
    "lussureggerò": "lussureggiare",
    "lussureggi": "lussureggiare",
    "lussureggia": "lussureggiare",
    "lussureggiai": "lussureggiare",
    "lussureggiammo": "lussureggiare",
    "lussureggiamo": "lussureggiare",
    "lussureggian": "lussureggiare",
    "lussureggiando": "lussureggiare",
    "lussureggiano": "lussureggiare",
    "lussureggiante": "lussureggiare",
    "lussureggianti": "lussureggiare",
    "lussureggiar": "lussureggiare",
    "lussureggiaron": "lussureggiare",
    "lussureggiarono": "lussureggiare",
    "lussureggiasse": "lussureggiare",
    "lussureggiasser": "lussureggiare",
    "lussureggiassero": "lussureggiare",
    "lussureggiassi": "lussureggiare",
    "lussureggiassimo": "lussureggiare",
    "lussureggiaste": "lussureggiare",
    "lussureggiasti": "lussureggiare",
    "lussureggiata": "lussureggiare",
    "lussureggiate": "lussureggiare",
    "lussureggiati": "lussureggiare",
    "lussureggiato": "lussureggiare",
    "lussureggiava": "lussureggiare",
    "lussureggiavamo": "lussureggiare",
    "lussureggiavan": "lussureggiare",
    "lussureggiavano": "lussureggiare",
    "lussureggiavate": "lussureggiare",
    "lussureggiavi": "lussureggiare",
    "lussureggiavo": "lussureggiare",
    "lussureggin": "lussureggiare",
    "lussureggino": "lussureggiare",
    "lussureggio": "lussureggiare",
    "lussureggiò": "lussureggiare",
    "lussurie": "lussuria",
    "lussuriosa": "lussurioso",
    "lussuriose": "lussurioso",
    "lussuriosi": "lussurioso",
    "lussò": "lussare",
    "lustra": "lustro",
    "lustrai": "lustrare",
    "lustrali": "lustrale",
    "lustrammo": "lustrare",
    "lustran": "lustrare",
    "lustrando": "lustrare",
    "lustrano": "lustrare",
    "lustrante": "lustrare",
    "lustranti": "lustrare",
    "lustrar": "lustrare",
    "lustraron": "lustrare",
    "lustrarono": "lustrare",
    "lustrasse": "lustrare",
    "lustrasser": "lustrare",
    "lustrassero": "lustrare",
    "lustrassi": "lustrare",
    "lustrassimo": "lustrare",
    "lustraste": "lustrare",
    "lustrasti": "lustrare",
    "lustrata": "lustrare",
    "lustrate": "lustrare",
    "lustrati": "lustrare",
    "lustrato": "lustrare",
    "lustrava": "lustrare",
    "lustravamo": "lustrare",
    "lustravan": "lustrare",
    "lustravano": "lustrare",
    "lustravate": "lustrare",
    "lustravi": "lustrare",
    "lustravo": "lustrare",
    "lustre": "lustro",
    "lustrerai": "lustrare",
    "lustreran": "lustrare",
    "lustreranno": "lustrare",
    "lustrerebbe": "lustrare",
    "lustrerebber": "lustrare",
    "lustrerebbero": "lustrare",
    "lustrerei": "lustrare",
    "lustreremmo": "lustrare",
    "lustreremo": "lustrare",
    "lustrereste": "lustrare",
    "lustreresti": "lustrare",
    "lustrerete": "lustrare",
    "lustrerà": "lustrare",
    "lustrerò": "lustrare",
    "lustri": "lustro",
    "lustriamo": "lustrare",
    "lustriate": "lustrare",
    "lustrin": "lustrare",
    "lustrini": "lustrino",
    "lustrino": "lustrare",
    "lustro": "lustrare",
    "lustrò": "lustrare",
    "luterana": "luterano",
    "luterane": "luterano",
    "luterani": "luterano",
    "lutti": "lutto",
    "luttuosa": "luttuoso",
    "luttuose": "luttuoso",
    "luttuosi": "luttuoso",
    "m'": "mi",
    "macabra": "macabro",
    "macabre": "macabro",
    "macabri": "macabro",
    "macachi": "macaco",
    "maccartismi": "maccartismo",
    "maccheroni": "maccherone",
    "macchi": "macchiare",
    "macchia": "macchiare",
    "macchiai": "macchiare",
    "macchiammo": "macchiare",
    "macchiamo": "macchiare",
    "macchian": "macchiare",
    "macchiando": "macchiare",
    "macchiano": "macchiare",
    "macchiante": "macchiare",
    "macchianti": "macchiare",
    "macchiar": "macchiare",
    "macchiaron": "macchiare",
    "macchiarono": "macchiare",
    "macchiasse": "macchiare",
    "macchiasser": "macchiare",
    "macchiassero": "macchiare",
    "macchiassi": "macchiare",
    "macchiassimo": "macchiare",
    "macchiaste": "macchiare",
    "macchiasti": "macchiare",
    "macchiata": "macchiato",
    "macchiate": "macchiato",
    "macchiati": "macchiato",
    "macchiato": "macchiare",
    "macchiava": "macchiare",
    "macchiavamo": "macchiare",
    "macchiavan": "macchiare",
    "macchiavano": "macchiare",
    "macchiavate": "macchiare",
    "macchiavi": "macchiare",
    "macchiavo": "macchiare",
    "macchie": "macchia",
    "macchierai": "macchiare",
    "macchieran": "macchiare",
    "macchieranno": "macchiare",
    "macchierebbe": "macchiare",
    "macchierebber": "macchiare",
    "macchierebbero": "macchiare",
    "macchierei": "macchiare",
    "macchieremmo": "macchiare",
    "macchieremo": "macchiare",
    "macchiereste": "macchiare",
    "macchieresti": "macchiare",
    "macchierete": "macchiare",
    "macchierà": "macchiare",
    "macchierò": "macchiare",
    "macchietta": "macchiettare",
    "macchiettai": "macchiettare",
    "macchiettammo": "macchiettare",
    "macchiettan": "macchiettare",
    "macchiettando": "macchiettare",
    "macchiettano": "macchiettare",
    "macchiettante": "macchiettare",
    "macchiettanti": "macchiettare",
    "macchiettar": "macchiettare",
    "macchiettaron": "macchiettare",
    "macchiettarono": "macchiettare",
    "macchiettasse": "macchiettare",
    "macchiettasser": "macchiettare",
    "macchiettassero": "macchiettare",
    "macchiettassi": "macchiettare",
    "macchiettassimo": "macchiettare",
    "macchiettaste": "macchiettare",
    "macchiettasti": "macchiettare",
    "macchiettata": "macchiettare",
    "macchiettate": "macchiettare",
    "macchiettati": "macchiettare",
    "macchiettato": "macchiettare",
    "macchiettava": "macchiettare",
    "macchiettavamo": "macchiettare",
    "macchiettavan": "macchiettare",
    "macchiettavano": "macchiettare",
    "macchiettavate": "macchiettare",
    "macchiettavi": "macchiettare",
    "macchiettavo": "macchiettare",
    "macchiette": "macchietta",
    "macchietterai": "macchiettare",
    "macchietteran": "macchiettare",
    "macchietteranno": "macchiettare",
    "macchietterebbe": "macchiettare",
    "macchietterebber": "macchiettare",
    "macchietterebbero": "macchiettare",
    "macchietterei": "macchiettare",
    "macchietteremmo": "macchiettare",
    "macchietteremo": "macchiettare",
    "macchiettereste": "macchiettare",
    "macchietteresti": "macchiettare",
    "macchietterete": "macchiettare",
    "macchietterà": "macchiettare",
    "macchietterò": "macchiettare",
    "macchietti": "macchiettare",
    "macchiettiamo": "macchiettare",
    "macchiettiate": "macchiettare",
    "macchiettin": "macchiettare",
    "macchiettino": "macchiettare",
    "macchietto": "macchiettare",
    "macchiettò": "macchiettare",
    "macchin": "macchiare",
    "macchina": "macchinare",
    "macchinai": "macchinare",
    "macchinali": "macchinale",
    "macchinammo": "macchinare",
    "macchinan": "macchinare",
    "macchinando": "macchinare",
    "macchinano": "macchinare",
    "macchinante": "macchinare",
    "macchinanti": "macchinare",
    "macchinar": "macchinare",
    "macchinari": "macchinario",
    "macchinaron": "macchinare",
    "macchinarono": "macchinare",
    "macchinasse": "macchinare",
    "macchinasser": "macchinare",
    "macchinassero": "macchinare",
    "macchinassi": "macchinare",
    "macchinassimo": "macchinare",
    "macchinaste": "macchinare",
    "macchinasti": "macchinare",
    "macchinata": "macchinare",
    "macchinate": "macchinare",
    "macchinati": "macchinare",
    "macchinato": "macchinare",
    "macchinava": "macchinare",
    "macchinavamo": "macchinare",
    "macchinavan": "macchinare",
    "macchinavano": "macchinare",
    "macchinavate": "macchinare",
    "macchinavi": "macchinare",
    "macchinavo": "macchinare",
    "macchinazioni": "macchinazione",
    "macchine": "macchina",
    "macchinerai": "macchinare",
    "macchineran": "macchinare",
    "macchineranno": "macchinare",
    "macchinerebbe": "macchinare",
    "macchinerebber": "macchinare",
    "macchinerebbero": "macchinare",
    "macchinerei": "macchinare",
    "macchineremmo": "macchinare",
    "macchineremo": "macchinare",
    "macchinereste": "macchinare",
    "macchineresti": "macchinare",
    "macchinerete": "macchinare",
    "macchinerie": "macchineria",
    "macchinerà": "macchinare",
    "macchinerò": "macchinare",
    "macchinette": "macchinetta",
    "macchini": "macchinare",
    "macchiniamo": "macchinare",
    "macchiniate": "macchinare",
    "macchinin": "macchinare",
    "macchinine": "macchinina",
    "macchinino": "macchinare",
    "macchinisti": "macchinista",
    "macchino": "macchinare",
    "macchinone": "macchinona",
    "macchinoni": "macchinone",
    "macchinosa": "macchinoso",
    "macchinose": "macchinoso",
    "macchinosi": "macchinoso",
    "macchinò": "macchinare",
    "macchio": "macchiare",
    "macchioline": "macchiolina",
    "macchiò": "macchiare",
    "macedoni": "macedone",
    "macedonie": "macedonia",
    "macella": "macellare",
    "macellai": "macellare",
    "macellammo": "macellare",
    "macellan": "macellare",
    "macellando": "macellare",
    "macellano": "macellare",
    "macellante": "macellare",
    "macellanti": "macellare",
    "macellar": "macellare",
    "macellaron": "macellare",
    "macellarono": "macellare",
    "macellasse": "macellare",
    "macellasser": "macellare",
    "macellassero": "macellare",
    "macellassi": "macellare",
    "macellassimo": "macellare",
    "macellaste": "macellare",
    "macellasti": "macellare",
    "macellata": "macellare",
    "macellate": "macellare",
    "macellati": "macellare",
    "macellato": "macellare",
    "macellava": "macellare",
    "macellavamo": "macellare",
    "macellavan": "macellare",
    "macellavano": "macellare",
    "macellavate": "macellare",
    "macellavi": "macellare",
    "macellavo": "macellare",
    "macellazioni": "macellazione",
    "macellerai": "macellare",
    "macelleran": "macellare",
    "macelleranno": "macellare",
    "macellerebbe": "macellare",
    "macellerebber": "macellare",
    "macellerebbero": "macellare",
    "macellerei": "macellare",
    "macelleremmo": "macellare",
    "macelleremo": "macellare",
    "macellereste": "macellare",
    "macelleresti": "macellare",
    "macellerete": "macellare",
    "macellerie": "macelleria",
    "macellerà": "macellare",
    "macellerò": "macellare",
    "macelli": "macello",
    "macelliamo": "macellare",
    "macelliate": "macellare",
    "macellin": "macellare",
    "macellino": "macellare",
    "macello": "macellare",
    "macellò": "macellare",
    "macera": "macero",
    "macerai": "macerare",
    "macerammo": "macerare",
    "maceran": "macerare",
    "macerando": "macerare",
    "macerano": "macerare",
    "macerante": "macerare",
    "maceranti": "macerare",
    "macerar": "macerare",
    "maceraron": "macerare",
    "macerarono": "macerare",
    "macerasse": "macerare",
    "macerasser": "macerare",
    "macerassero": "macerare",
    "macerassi": "macerare",
    "macerassimo": "macerare",
    "maceraste": "macerare",
    "macerasti": "macerare",
    "macerata": "macerare",
    "macerate": "macerare",
    "macerati": "macerare",
    "macerato": "macerare",
    "macerava": "macerare",
    "maceravamo": "macerare",
    "maceravan": "macerare",
    "maceravano": "macerare",
    "maceravate": "macerare",
    "maceravi": "macerare",
    "maceravo": "macerare",
    "macerazioni": "macerazione",
    "macere": "macero",
    "macererai": "macerare",
    "macereran": "macerare",
    "macereranno": "macerare",
    "macererebbe": "macerare",
    "macererebber": "macerare",
    "macererebbero": "macerare",
    "macererei": "macerare",
    "macereremmo": "macerare",
    "macereremo": "macerare",
    "macerereste": "macerare",
    "macereresti": "macerare",
    "macererete": "macerare",
    "macererà": "macerare",
    "macererò": "macerare",
    "maceri": "macero",
    "maceriamo": "macerare",
    "maceriate": "macerare",
    "macerie": "maceria",
    "macerin": "macerare",
    "macerino": "macerare",
    "macero": "macerare",
    "macerò": "macerare",
    "machiavelliana": "machiavelliano",
    "machiavelliane": "machiavelliano",
    "machiavelliani": "machiavelliano",
    "machiavellica": "machiavellico",
    "machiavelliche": "machiavellico",
    "machiavellici": "machiavellico",
    "machiavellismi": "machiavellismo",
    "machismi": "machismo",
    "machos": "macho",
    "macigni": "macigno",
    "macilenta": "macilento",
    "macilente": "macilento",
    "macilenti": "macilento",
    "macina": "macinare",
    "macinai": "macinare",
    "macinammo": "macinare",
    "macinan": "macinare",
    "macinando": "macinare",
    "macinano": "macinare",
    "macinante": "macinare",
    "macinanti": "macinare",
    "macinar": "macinare",
    "macinaron": "macinare",
    "macinarono": "macinare",
    "macinasse": "macinare",
    "macinasser": "macinare",
    "macinassero": "macinare",
    "macinassi": "macinare",
    "macinassimo": "macinare",
    "macinaste": "macinare",
    "macinasti": "macinare",
    "macinata": "macinato",
    "macinate": "macinato",
    "macinati": "macinato",
    "macinato": "macinare",
    "macinava": "macinare",
    "macinavamo": "macinare",
    "macinavan": "macinare",
    "macinavano": "macinare",
    "macinavate": "macinare",
    "macinavi": "macinare",
    "macinavo": "macinare",
    "macine": "macina",
    "macinerai": "macinare",
    "macineran": "macinare",
    "macineranno": "macinare",
    "macinerebbe": "macinare",
    "macinerebber": "macinare",
    "macinerebbero": "macinare",
    "macinerei": "macinare",
    "macineremmo": "macinare",
    "macineremo": "macinare",
    "macinereste": "macinare",
    "macineresti": "macinare",
    "macinerete": "macinare",
    "macinerà": "macinare",
    "macinerò": "macinare",
    "macini": "macinare",
    "maciniamo": "macinare",
    "maciniate": "macinare",
    "macinin": "macinare",
    "macinino": "macinare",
    "macino": "macinare",
    "macinò": "macinare",
    "maciulla": "maciullare",
    "maciullai": "maciullare",
    "maciullammo": "maciullare",
    "maciullan": "maciullare",
    "maciullando": "maciullare",
    "maciullano": "maciullare",
    "maciullante": "maciullare",
    "maciullanti": "maciullare",
    "maciullar": "maciullare",
    "maciullaron": "maciullare",
    "maciullarono": "maciullare",
    "maciullasse": "maciullare",
    "maciullasser": "maciullare",
    "maciullassero": "maciullare",
    "maciullassi": "maciullare",
    "maciullassimo": "maciullare",
    "maciullaste": "maciullare",
    "maciullasti": "maciullare",
    "maciullata": "maciullare",
    "maciullate": "maciullare",
    "maciullati": "maciullare",
    "maciullato": "maciullare",
    "maciullava": "maciullare",
    "maciullavamo": "maciullare",
    "maciullavan": "maciullare",
    "maciullavano": "maciullare",
    "maciullavate": "maciullare",
    "maciullavi": "maciullare",
    "maciullavo": "maciullare",
    "maciullerai": "maciullare",
    "maciulleran": "maciullare",
    "maciulleranno": "maciullare",
    "maciullerebbe": "maciullare",
    "maciullerebber": "maciullare",
    "maciullerebbero": "maciullare",
    "maciullerei": "maciullare",
    "maciulleremmo": "maciullare",
    "maciulleremo": "maciullare",
    "maciullereste": "maciullare",
    "maciulleresti": "maciullare",
    "maciullerete": "maciullare",
    "maciullerà": "maciullare",
    "maciullerò": "maciullare",
    "maciulli": "maciullare",
    "maciulliamo": "maciullare",
    "maciulliate": "maciullare",
    "maciullin": "maciullare",
    "maciullino": "maciullare",
    "maciullo": "maciullare",
    "maciullò": "maciullare",
    "macra": "macro",
    "macre": "macro",
    "macri": "macro",
    "macrobiotica": "macrobiotico",
    "macrobiotiche": "macrobiotico",
    "macrobiotici": "macrobiotico",
    "macroeconomica": "macroeconomico",
    "macroeconomiche": "macroeconomico",
    "macroeconomici": "macroeconomico",
    "macroeconomie": "macroeconomia",
    "macromolecole": "macromolecola",
    "macroregioni": "macroregione",
    "macroscopica": "macroscopico",
    "macroscopiche": "macroscopico",
    "macroscopici": "macroscopico",
    "macrostrutture": "macrostruttura",
    "macula": "maculare",
    "maculai": "maculare",
    "maculammo": "maculare",
    "maculan": "maculare",
    "maculando": "maculare",
    "maculano": "maculare",
    "maculante": "maculare",
    "maculanti": "maculare",
    "macular": "maculare",
    "macularon": "maculare",
    "macularono": "maculare",
    "maculasse": "maculare",
    "maculasser": "maculare",
    "maculassero": "maculare",
    "maculassi": "maculare",
    "maculassimo": "maculare",
    "maculaste": "maculare",
    "maculasti": "maculare",
    "maculata": "maculato",
    "maculate": "maculato",
    "maculati": "maculato",
    "maculato": "maculare",
    "maculava": "maculare",
    "maculavamo": "maculare",
    "maculavan": "maculare",
    "maculavano": "maculare",
    "maculavate": "maculare",
    "maculavi": "maculare",
    "maculavo": "maculare",
    "maculerai": "maculare",
    "maculeran": "maculare",
    "maculeranno": "maculare",
    "maculerebbe": "maculare",
    "maculerebber": "maculare",
    "maculerebbero": "maculare",
    "maculerei": "maculare",
    "maculeremmo": "maculare",
    "maculeremo": "maculare",
    "maculereste": "maculare",
    "maculeresti": "maculare",
    "maculerete": "maculare",
    "maculerà": "maculare",
    "maculerò": "maculare",
    "maculi": "maculare",
    "maculiamo": "maculare",
    "maculiate": "maculare",
    "maculin": "maculare",
    "maculino": "maculare",
    "maculo": "maculare",
    "maculò": "maculare",
    "macumbe": "macumba",
    "madame": "madama",
    "madida": "madido",
    "madide": "madido",
    "madidi": "madido",
    "madonne": "madonna",
    "madonnine": "madonnina",
    "madornali": "madornale",
    "madrelingue": "madrelingua",
    "madrepatrie": "madrepatria",
    "madreperlata": "madreperlato",
    "madreperlate": "madreperlato",
    "madreperlati": "madreperlato",
    "madri": "madre",
    "madridisti": "madridista",
    "madrigali": "madrigale",
    "madrilena": "madrileno",
    "madrilene": "madrileno",
    "madrileni": "madrileno",
    "madrine": "madrina",
    "maestosa": "maestoso",
    "maestose": "maestoso",
    "maestosi": "maestoso",
    "maestra": "maestro",
    "maestrali": "maestrale",
    "maestranze": "maestranza",
    "maestre": "maestro",
    "maestri": "maestro",
    "maestrie": "maestria",
    "maestrine": "maestrina",
    "maestrini": "maestrino",
    "mafie": "mafia",
    "mafiologi": "mafiologo",
    "mafiosa": "mafioso",
    "mafiose": "mafioso",
    "mafiosi": "mafioso",
    "magagne": "magagna",
    "magazzini": "magazzino",
    "magazzinieri": "magazziniere",
    "maggi": "maggio",
    "maggiolini": "maggiolino",
    "maggiora": "maggiorare",
    "maggiorai": "maggiorare",
    "maggiorammo": "maggiorare",
    "maggioran": "maggiorare",
    "maggiorando": "maggiorare",
    "maggiorano": "maggiorare",
    "maggiorante": "maggiorare",
    "maggioranti": "maggiorare",
    "maggioranze": "maggioranza",
    "maggiorar": "maggiorare",
    "maggioraron": "maggiorare",
    "maggiorarono": "maggiorare",
    "maggiorasse": "maggiorare",
    "maggiorasser": "maggiorare",
    "maggiorassero": "maggiorare",
    "maggiorassi": "maggiorare",
    "maggiorassimo": "maggiorare",
    "maggioraste": "maggiorare",
    "maggiorasti": "maggiorare",
    "maggiorata": "maggiorato",
    "maggiorate": "maggiorato",
    "maggiorati": "maggiorato",
    "maggiorato": "maggiorare",
    "maggiorava": "maggiorare",
    "maggioravamo": "maggiorare",
    "maggioravan": "maggiorare",
    "maggioravano": "maggiorare",
    "maggioravate": "maggiorare",
    "maggioravi": "maggiorare",
    "maggioravo": "maggiorare",
    "maggiorazioni": "maggiorazione",
    "maggiordomi": "maggiordomo",
    "maggiore": "grande",
    "maggiorenni": "maggiorenne",
    "maggiorenti": "maggiorente",
    "maggiorerai": "maggiorare",
    "maggioreran": "maggiorare",
    "maggioreranno": "maggiorare",
    "maggiorerebbe": "maggiorare",
    "maggiorerebber": "maggiorare",
    "maggiorerebbero": "maggiorare",
    "maggiorerei": "maggiorare",
    "maggioreremmo": "maggiorare",
    "maggioreremo": "maggiorare",
    "maggiorereste": "maggiorare",
    "maggioreresti": "maggiorare",
    "maggiorerete": "maggiorare",
    "maggiorerà": "maggiorare",
    "maggiorerò": "maggiorare",
    "maggiori": "maggiore",
    "maggioriamo": "maggiorare",
    "maggioriate": "maggiorare",
    "maggiorin": "maggiorare",
    "maggiorino": "maggiorare",
    "maggioritari": "maggioritario",
    "maggioritaria": "maggioritario",
    "maggioritarie": "maggioritario",
    "maggioro": "maggiorare",
    "maggiorò": "maggiorare",
    "maghe": "maga",
    "maghi": "mago",
    "maghrebini": "maghrebino",
    "magi": "mago",
    "magiari": "magiaro",
    "magica": "magico",
    "magiche": "magico",
    "magici": "magico",
    "magie": "magia",
    "magioni": "magione",
    "magisteri": "magistero",
    "magistrali": "magistrale",
    "magistrati": "magistrato",
    "magistrature": "magistratura",
    "magliari": "magliaro",
    "maglie": "maglia",
    "maglierie": "maglieria",
    "magliette": "maglietta",
    "maglioncini": "maglioncino",
    "maglioni": "maglione",
    "magmatica": "magmatico",
    "magmatiche": "magmatico",
    "magmatici": "magmatico",
    "magmi": "magma",
    "magna": "magno",
    "magnanima": "magnanimo",
    "magnanime": "magnanimo",
    "magnanimi": "magnanimo",
    "magnati": "magnate",
    "magne": "magno",
    "magnetica": "magnetico",
    "magnetiche": "magnetico",
    "magnetici": "magnetico",
    "magnetismi": "magnetismo",
    "magnetizza": "magnetizzare",
    "magnetizzai": "magnetizzare",
    "magnetizzammo": "magnetizzare",
    "magnetizzan": "magnetizzare",
    "magnetizzando": "magnetizzare",
    "magnetizzano": "magnetizzare",
    "magnetizzante": "magnetizzare",
    "magnetizzanti": "magnetizzare",
    "magnetizzar": "magnetizzare",
    "magnetizzaron": "magnetizzare",
    "magnetizzarono": "magnetizzare",
    "magnetizzasse": "magnetizzare",
    "magnetizzasser": "magnetizzare",
    "magnetizzassero": "magnetizzare",
    "magnetizzassi": "magnetizzare",
    "magnetizzassimo": "magnetizzare",
    "magnetizzaste": "magnetizzare",
    "magnetizzasti": "magnetizzare",
    "magnetizzata": "magnetizzare",
    "magnetizzate": "magnetizzare",
    "magnetizzati": "magnetizzare",
    "magnetizzato": "magnetizzare",
    "magnetizzava": "magnetizzare",
    "magnetizzavamo": "magnetizzare",
    "magnetizzavan": "magnetizzare",
    "magnetizzavano": "magnetizzare",
    "magnetizzavate": "magnetizzare",
    "magnetizzavi": "magnetizzare",
    "magnetizzavo": "magnetizzare",
    "magnetizzerai": "magnetizzare",
    "magnetizzeran": "magnetizzare",
    "magnetizzeranno": "magnetizzare",
    "magnetizzerebbe": "magnetizzare",
    "magnetizzerebber": "magnetizzare",
    "magnetizzerebbero": "magnetizzare",
    "magnetizzerei": "magnetizzare",
    "magnetizzeremmo": "magnetizzare",
    "magnetizzeremo": "magnetizzare",
    "magnetizzereste": "magnetizzare",
    "magnetizzeresti": "magnetizzare",
    "magnetizzerete": "magnetizzare",
    "magnetizzerà": "magnetizzare",
    "magnetizzerò": "magnetizzare",
    "magnetizzi": "magnetizzare",
    "magnetizziamo": "magnetizzare",
    "magnetizziate": "magnetizzare",
    "magnetizzin": "magnetizzare",
    "magnetizzino": "magnetizzare",
    "magnetizzo": "magnetizzare",
    "magnetizzò": "magnetizzare",
    "magnetofoni": "magnetofono",
    "magni": "magno",
    "magnifica": "magnifico",
    "magnificai": "magnificare",
    "magnificammo": "magnificare",
    "magnifican": "magnificare",
    "magnificando": "magnificare",
    "magnificano": "magnificare",
    "magnificante": "magnificare",
    "magnificanti": "magnificare",
    "magnificar": "magnificare",
    "magnificaron": "magnificare",
    "magnificarono": "magnificare",
    "magnificasse": "magnificare",
    "magnificasser": "magnificare",
    "magnificassero": "magnificare",
    "magnificassi": "magnificare",
    "magnificassimo": "magnificare",
    "magnificaste": "magnificare",
    "magnificasti": "magnificare",
    "magnificata": "magnificare",
    "magnificate": "magnificare",
    "magnificati": "magnificare",
    "magnificato": "magnificare",
    "magnificava": "magnificare",
    "magnificavamo": "magnificare",
    "magnificavan": "magnificare",
    "magnificavano": "magnificare",
    "magnificavate": "magnificare",
    "magnificavi": "magnificare",
    "magnificavo": "magnificare",
    "magnificenze": "magnificenza",
    "magnifiche": "magnifico",
    "magnificherai": "magnificare",
    "magnificheran": "magnificare",
    "magnificheranno": "magnificare",
    "magnificherebbe": "magnificare",
    "magnificherebber": "magnificare",
    "magnificherebbero": "magnificare",
    "magnificherei": "magnificare",
    "magnificheremmo": "magnificare",
    "magnificheremo": "magnificare",
    "magnifichereste": "magnificare",
    "magnificheresti": "magnificare",
    "magnificherete": "magnificare",
    "magnificherà": "magnificare",
    "magnificherò": "magnificare",
    "magnifichi": "magnificare",
    "magnifichiamo": "magnificare",
    "magnifichiate": "magnificare",
    "magnifichin": "magnificare",
    "magnifichino": "magnificare",
    "magnifici": "magnifico",
    "magnifico": "magnificare",
    "magnificò": "magnificare",
    "magniloquenti": "magniloquente",
    "magniloquenze": "magniloquenza",
    "magnolie": "magnolia",
    "magoni": "magone",
    "magra": "magro",
    "magre": "magro",
    "magrebini": "magrebino",
    "magrezze": "magrezza",
    "magri": "magro",
    "magrolina": "magrolino",
    "magroline": "magrolino",
    "magrolini": "magrolino",
    "magìe": "magìa",
    "maiali": "maiale",
    "maialini": "maialino",
    "maiolicata": "maiolicato",
    "maiolicate": "maiolicato",
    "maiolicati": "maiolicato",
    "maioliche": "maiolica",
    "maionesi": "maionese",
    "maiuscola": "maiuscolo",
    "maiuscole": "maiuscolo",
    "maiuscoli": "maiuscolo",
    "majors": "major",
    "mal": "male",
    "mala": "malo",
    "malaffari": "malaffare",
    "malandata": "malandato",
    "malandate": "malandato",
    "malandati": "malandato",
    "malandrina": "malandrino",
    "malandrine": "malandrino",
    "malandrini": "malandrino",
    "malanni": "malanno",
    "malarica": "malarico",
    "malariche": "malarico",
    "malarici": "malarico",
    "malarie": "malaria",
    "malata": "malato",
    "malate": "malato",
    "malati": "malato",
    "malaticce": "malaticcio",
    "malaticci": "malaticcio",
    "malaticcia": "malaticcio",
    "malattie": "malattia",
    "malaugurata": "malaugurato",
    "malaugurate": "malaugurato",
    "malaugurati": "malaugurato",
    "malauguri": "malaugurio",
    "malavite": "malavita",
    "malavitosa": "malavitoso",
    "malavitose": "malavitoso",
    "malavitosi": "malavitoso",
    "malcapitata": "malcapitato",
    "malcapitate": "malcapitato",
    "malcapitati": "malcapitato",
    "malconce": "malconcio",
    "malconci": "malconcio",
    "malconcia": "malconcio",
    "malcontenta": "malcontento",
    "malcontente": "malcontento",
    "malcontenti": "malcontento",
    "malcostumi": "malcostume",
    "maldestra": "maldestro",
    "maldestre": "maldestro",
    "maldestri": "maldestro",
    "maldicenze": "maldicenza",
    "male": "malo",
    "maledetta": "maledire",
    "maledette": "maledire",
    "maledetti": "maledire",
    "maledetto": "maledire",
    "maledica": "maledire",
    "maledican": "maledire",
    "maledicano": "maledire",
    "maledice": "maledire",
    "maledicemmo": "maledire",
    "maledicendo": "maledire",
    "maledicente": "maledire",
    "maledicenti": "maledire",
    "maledicesse": "maledire",
    "maledicesser": "maledire",
    "maledicessero": "maledire",
    "maledicessi": "maledire",
    "maledicessimo": "maledire",
    "malediceste": "maledire",
    "maledicesti": "maledire",
    "malediceva": "maledire",
    "maledicevamo": "maledire",
    "maledicevan": "maledire",
    "maledicevano": "maledire",
    "maledicevate": "maledire",
    "maledicevi": "maledire",
    "maledicevo": "maledire",
    "maledici": "maledire",
    "malediciamo": "maledire",
    "malediciate": "maledire",
    "maledico": "maledire",
    "maledicon": "maledire",
    "maledicono": "maledire",
    "maledir": "maledire",
    "maledirai": "maledire",
    "malediran": "maledire",
    "malediranno": "maledire",
    "maledirebbe": "maledire",
    "maledirebber": "maledire",
    "maledirebbero": "maledire",
    "maledirei": "maledire",
    "malediremmo": "maledire",
    "malediremo": "maledire",
    "maledireste": "maledire",
    "malediresti": "maledire",
    "maledirete": "maledire",
    "maledirà": "maledire",
    "maledirò": "maledire",
    "maledisse": "maledire",
    "maledisser": "maledire",
    "maledissero": "maledire",
    "maledissi": "maledire",
    "maledite": "maledire",
    "maledizioni": "maledizione",
    "maleducata": "maleducato",
    "maleducate": "maleducato",
    "maleducati": "maleducato",
    "maleducazioni": "maleducazione",
    "malefatte": "malefatta",
    "malefica": "malefico",
    "malefiche": "malefico",
    "malefici": "malefico",
    "maleodoranti": "maleodorante",
    "malesanità": "malasanità",
    "malesi": "malese",
    "malesorti": "malasorte",
    "malesseri": "malessere",
    "malevola": "malevolo",
    "malevole": "malevolo",
    "malevolenze": "malevolenza",
    "malevoli": "malevolo",
    "malfa": "malfare",
    "malfa'": "malfare",
    "malfaccia": "malfare",
    "malfacciamo": "malfare",
    "malfaccian": "malfare",
    "malfacciano": "malfare",
    "malfacciate": "malfare",
    "malfaccio": "malfare",
    "malfacemmo": "malfare",
    "malfacendo": "malfare",
    "malfacente": "malfare",
    "malfacenti": "malfare",
    "malfacesse": "malfare",
    "malfacesser": "malfare",
    "malfacessero": "malfare",
    "malfacessi": "malfare",
    "malfacessimo": "malfare",
    "malfaceste": "malfare",
    "malfacesti": "malfare",
    "malfaceva": "malfare",
    "malfacevamo": "malfare",
    "malfacevan": "malfare",
    "malfacevano": "malfare",
    "malfacevate": "malfare",
    "malfacevi": "malfare",
    "malfacevo": "malfare",
    "malfai": "malfare",
    "malfamata": "malfamato",
    "malfamate": "malfamato",
    "malfamati": "malfamato",
    "malfan": "malfare",
    "malfanno": "malfare",
    "malfar": "malfare",
    "malfarai": "malfare",
    "malfaran": "malfare",
    "malfaranno": "malfare",
    "malfarebbe": "malfare",
    "malfarebber": "malfare",
    "malfarebbero": "malfare",
    "malfarei": "malfare",
    "malfaremmo": "malfare",
    "malfaremo": "malfare",
    "malfareste": "malfare",
    "malfaresti": "malfare",
    "malfarete": "malfare",
    "malfarà": "malfare",
    "malfarò": "malfare",
    "malfate": "malfare",
    "malfatta": "malfatto",
    "malfatte": "malfatto",
    "malfatti": "malfatto",
    "malfatto": "malfare",
    "malfattori": "malfattore",
    "malfece": "malfare",
    "malfecer": "malfare",
    "malfecero": "malfare",
    "malfeci": "malfare",
    "malferma": "malfermo",
    "malferme": "malfermo",
    "malfermi": "malfermo",
    "malfida": "malfido",
    "malfidata": "malfidato",
    "malfidate": "malfidato",
    "malfidati": "malfidato",
    "malfide": "malfido",
    "malfidi": "malfido",
    "malformata": "malformato",
    "malformate": "malformato",
    "malformati": "malformato",
    "malformazioni": "malformazione",
    "malfunzionamenti": "malfunzionamento",
    "malgiudica": "malgiudicare",
    "malgiudicai": "malgiudicare",
    "malgiudicammo": "malgiudicare",
    "malgiudican": "malgiudicare",
    "malgiudicando": "malgiudicare",
    "malgiudicano": "malgiudicare",
    "malgiudicante": "malgiudicare",
    "malgiudicanti": "malgiudicare",
    "malgiudicar": "malgiudicare",
    "malgiudicaron": "malgiudicare",
    "malgiudicarono": "malgiudicare",
    "malgiudicasse": "malgiudicare",
    "malgiudicasser": "malgiudicare",
    "malgiudicassero": "malgiudicare",
    "malgiudicassi": "malgiudicare",
    "malgiudicassimo": "malgiudicare",
    "malgiudicaste": "malgiudicare",
    "malgiudicasti": "malgiudicare",
    "malgiudicata": "malgiudicare",
    "malgiudicate": "malgiudicare",
    "malgiudicati": "malgiudicare",
    "malgiudicato": "malgiudicare",
    "malgiudicava": "malgiudicare",
    "malgiudicavamo": "malgiudicare",
    "malgiudicavan": "malgiudicare",
    "malgiudicavano": "malgiudicare",
    "malgiudicavate": "malgiudicare",
    "malgiudicavi": "malgiudicare",
    "malgiudicavo": "malgiudicare",
    "malgiudicherai": "malgiudicare",
    "malgiudicheran": "malgiudicare",
    "malgiudicheranno": "malgiudicare",
    "malgiudicherebbe": "malgiudicare",
    "malgiudicherebber": "malgiudicare",
    "malgiudicherebbero": "malgiudicare",
    "malgiudicherei": "malgiudicare",
    "malgiudicheremmo": "malgiudicare",
    "malgiudicheremo": "malgiudicare",
    "malgiudichereste": "malgiudicare",
    "malgiudicheresti": "malgiudicare",
    "malgiudicherete": "malgiudicare",
    "malgiudicherà": "malgiudicare",
    "malgiudicherò": "malgiudicare",
    "malgiudichi": "malgiudicare",
    "malgiudichiamo": "malgiudicare",
    "malgiudichiate": "malgiudicare",
    "malgiudichin": "malgiudicare",
    "malgiudichino": "malgiudicare",
    "malgiudico": "malgiudicare",
    "malgiudicò": "malgiudicare",
    "malgoverni": "malgoverno",
    "mali": "malo",
    "maliarda": "maliardo",
    "maliarde": "maliardo",
    "maliardi": "maliardo",
    "malie": "malia",
    "maligna": "maligno",
    "malignai": "malignare",
    "malignammo": "malignare",
    "malignan": "malignare",
    "malignando": "malignare",
    "malignano": "malignare",
    "malignante": "malignare",
    "malignanti": "malignare",
    "malignar": "malignare",
    "malignaron": "malignare",
    "malignarono": "malignare",
    "malignasse": "malignare",
    "malignasser": "malignare",
    "malignassero": "malignare",
    "malignassi": "malignare",
    "malignassimo": "malignare",
    "malignaste": "malignare",
    "malignasti": "malignare",
    "malignata": "malignare",
    "malignate": "malignare",
    "malignati": "malignare",
    "malignato": "malignare",
    "malignava": "malignare",
    "malignavamo": "malignare",
    "malignavan": "malignare",
    "malignavano": "malignare",
    "malignavate": "malignare",
    "malignavi": "malignare",
    "malignavo": "malignare",
    "maligne": "maligno",
    "malignerai": "malignare",
    "maligneran": "malignare",
    "maligneranno": "malignare",
    "malignerebbe": "malignare",
    "malignerebber": "malignare",
    "malignerebbero": "malignare",
    "malignerei": "malignare",
    "maligneremmo": "malignare",
    "maligneremo": "malignare",
    "malignereste": "malignare",
    "maligneresti": "malignare",
    "malignerete": "malignare",
    "malignerà": "malignare",
    "malignerò": "malignare",
    "maligni": "maligno",
    "maligniamo": "malignare",
    "maligniate": "malignare",
    "malignin": "malignare",
    "malignino": "malignare",
    "maligno": "malignare",
    "malignò": "malignare",
    "malinconica": "malinconico",
    "malinconiche": "malinconico",
    "malinconici": "malinconico",
    "malinconie": "malinconia",
    "malinformata": "malinformato",
    "malinformate": "malinformato",
    "malinformati": "malinformato",
    "malintenzionata": "malintenzionato",
    "malintenzionate": "malintenzionato",
    "malintenzionati": "malintenzionato",
    "malintesa": "malinteso",
    "malintese": "malinteso",
    "malintesi": "malinteso",
    "maliosa": "malioso",
    "maliose": "malioso",
    "maliosi": "malioso",
    "malizie": "malizia",
    "maliziosa": "malizioso",
    "maliziose": "malizioso",
    "maliziosi": "malizioso",
    "malleabili": "malleabile",
    "malloppi": "malloppo",
    "malmena": "malmenare",
    "malmenai": "malmenare",
    "malmenammo": "malmenare",
    "malmenan": "malmenare",
    "malmenando": "malmenare",
    "malmenano": "malmenare",
    "malmenante": "malmenare",
    "malmenanti": "malmenare",
    "malmenar": "malmenare",
    "malmenaron": "malmenare",
    "malmenarono": "malmenare",
    "malmenasse": "malmenare",
    "malmenasser": "malmenare",
    "malmenassero": "malmenare",
    "malmenassi": "malmenare",
    "malmenassimo": "malmenare",
    "malmenaste": "malmenare",
    "malmenasti": "malmenare",
    "malmenata": "malmenare",
    "malmenate": "malmenare",
    "malmenati": "malmenare",
    "malmenato": "malmenare",
    "malmenava": "malmenare",
    "malmenavamo": "malmenare",
    "malmenavan": "malmenare",
    "malmenavano": "malmenare",
    "malmenavate": "malmenare",
    "malmenavi": "malmenare",
    "malmenavo": "malmenare",
    "malmenerai": "malmenare",
    "malmeneran": "malmenare",
    "malmeneranno": "malmenare",
    "malmenerebbe": "malmenare",
    "malmenerebber": "malmenare",
    "malmenerebbero": "malmenare",
    "malmenerei": "malmenare",
    "malmeneremmo": "malmenare",
    "malmeneremo": "malmenare",
    "malmenereste": "malmenare",
    "malmeneresti": "malmenare",
    "malmenerete": "malmenare",
    "malmenerà": "malmenare",
    "malmenerò": "malmenare",
    "malmeni": "malmenare",
    "malmeniamo": "malmenare",
    "malmeniate": "malmenare",
    "malmenin": "malmenare",
    "malmenino": "malmenare",
    "malmeno": "malmenare",
    "malmenò": "malmenare",
    "malmessa": "malmesso",
    "malmesse": "malmesso",
    "malmessi": "malmesso",
    "malnutrita": "malnutrito",
    "malnutrite": "malnutrito",
    "malnutriti": "malnutrito",
    "malnutrizioni": "malnutrizione",
    "malocchi": "malocchio",
    "malori": "malore",
    "malridotta": "malridotto",
    "malridotte": "malridotto",
    "malridotti": "malridotto",
    "malsana": "malsano",
    "malsane": "malsano",
    "malsani": "malsano",
    "malsicura": "malsicuro",
    "malsicure": "malsicuro",
    "malsicuri": "malsicuro",
    "malte": "malta",
    "maltempi": "maltempo",
    "maltesi": "maltese",
    "maltolti": "maltolto",
    "maltratta": "maltrattare",
    "maltrattai": "maltrattare",
    "maltrattamenti": "maltrattamento",
    "maltrattammo": "maltrattare",
    "maltrattan": "maltrattare",
    "maltrattando": "maltrattare",
    "maltrattano": "maltrattare",
    "maltrattante": "maltrattare",
    "maltrattanti": "maltrattare",
    "maltrattar": "maltrattare",
    "maltrattaron": "maltrattare",
    "maltrattarono": "maltrattare",
    "maltrattasse": "maltrattare",
    "maltrattasser": "maltrattare",
    "maltrattassero": "maltrattare",
    "maltrattassi": "maltrattare",
    "maltrattassimo": "maltrattare",
    "maltrattaste": "maltrattare",
    "maltrattasti": "maltrattare",
    "maltrattata": "maltrattare",
    "maltrattate": "maltrattare",
    "maltrattati": "maltrattato",
    "maltrattato": "maltrattare",
    "maltrattava": "maltrattare",
    "maltrattavamo": "maltrattare",
    "maltrattavan": "maltrattare",
    "maltrattavano": "maltrattare",
    "maltrattavate": "maltrattare",
    "maltrattavi": "maltrattare",
    "maltrattavo": "maltrattare",
    "maltratterai": "maltrattare",
    "maltratteran": "maltrattare",
    "maltratteranno": "maltrattare",
    "maltratterebbe": "maltrattare",
    "maltratterebber": "maltrattare",
    "maltratterebbero": "maltrattare",
    "maltratterei": "maltrattare",
    "maltratteremmo": "maltrattare",
    "maltratteremo": "maltrattare",
    "maltrattereste": "maltrattare",
    "maltratteresti": "maltrattare",
    "maltratterete": "maltrattare",
    "maltratterà": "maltrattare",
    "maltratterò": "maltrattare",
    "maltratti": "maltrattare",
    "maltrattiamo": "maltrattare",
    "maltrattiate": "maltrattare",
    "maltrattin": "maltrattare",
    "maltrattino": "maltrattare",
    "maltratto": "maltrattare",
    "maltrattò": "maltrattare",
    "malumori": "malumore",
    "malvagi": "malvagio",
    "malvagia": "malvagio",
    "malvagie": "malvagio",
    "malversa": "malversare",
    "malversai": "malversare",
    "malversammo": "malversare",
    "malversan": "malversare",
    "malversando": "malversare",
    "malversano": "malversare",
    "malversante": "malversare",
    "malversanti": "malversare",
    "malversar": "malversare",
    "malversaron": "malversare",
    "malversarono": "malversare",
    "malversasse": "malversare",
    "malversasser": "malversare",
    "malversassero": "malversare",
    "malversassi": "malversare",
    "malversassimo": "malversare",
    "malversaste": "malversare",
    "malversasti": "malversare",
    "malversata": "malversare",
    "malversate": "malversare",
    "malversati": "malversare",
    "malversato": "malversare",
    "malversava": "malversare",
    "malversavamo": "malversare",
    "malversavan": "malversare",
    "malversavano": "malversare",
    "malversavate": "malversare",
    "malversavi": "malversare",
    "malversavo": "malversare",
    "malversazioni": "malversazione",
    "malverserai": "malversare",
    "malverseran": "malversare",
    "malverseranno": "malversare",
    "malverserebbe": "malversare",
    "malverserebber": "malversare",
    "malverserebbero": "malversare",
    "malverserei": "malversare",
    "malverseremmo": "malversare",
    "malverseremo": "malversare",
    "malversereste": "malversare",
    "malverseresti": "malversare",
    "malverserete": "malversare",
    "malverserà": "malversare",
    "malverserò": "malversare",
    "malversi": "malversare",
    "malversiamo": "malversare",
    "malversiate": "malversare",
    "malversin": "malversare",
    "malversino": "malversare",
    "malverso": "malversare",
    "malversò": "malversare",
    "malvestita": "malvestito",
    "malvestite": "malvestito",
    "malvestiti": "malvestito",
    "malvezzi": "malvezzo",
    "malvista": "malvisto",
    "malviste": "malvisto",
    "malvisti": "malvisto",
    "malviventi": "malvivente",
    "malvola": "malvolere",
    "malvolan": "malvolere",
    "malvolano": "malvolere",
    "malvole": "malvolere",
    "malvolei": "malvolere",
    "malvolemmo": "malvolere",
    "malvolendo": "malvolere",
    "malvolente": "malvolere",
    "malvolenti": "malvolere",
    "malvoler": "malvolere",
    "malvolerai": "malvolere",
    "malvoleran": "malvolere",
    "malvoleranno": "malvolere",
    "malvolerebbe": "malvolere",
    "malvolerebber": "malvolere",
    "malvolerebbero": "malvolere",
    "malvolerei": "malvolere",
    "malvoleremmo": "malvolere",
    "malvoleremo": "malvolere",
    "malvolereste": "malvolere",
    "malvoleresti": "malvolere",
    "malvolerete": "malvolere",
    "malvoleron": "malvolere",
    "malvolerono": "malvolere",
    "malvolerà": "malvolere",
    "malvolerò": "malvolere",
    "malvolesse": "malvolere",
    "malvolesser": "malvolere",
    "malvolessero": "malvolere",
    "malvolessi": "malvolere",
    "malvolessimo": "malvolere",
    "malvoleste": "malvolere",
    "malvolesti": "malvolere",
    "malvolete": "malvolere",
    "malvoleva": "malvolere",
    "malvolevamo": "malvolere",
    "malvolevan": "malvolere",
    "malvolevano": "malvolere",
    "malvolevate": "malvolere",
    "malvolevi": "malvolere",
    "malvolevo": "malvolere",
    "malvoli": "malvolere",
    "malvoliamo": "malvolere",
    "malvoliate": "malvolere",
    "malvolo": "malvolere",
    "malvolon": "malvolere",
    "malvolono": "malvolere",
    "malvoluta": "malvolere",
    "malvolute": "malvolere",
    "malvoluti": "malvolere",
    "malvoluto": "malvolere",
    "malvolè": "malvolere",
    "malìe": "malìa",
    "mambi": "mambo",
    "mammane": "mammana",
    "mamme": "mamma",
    "mammelle": "mammella",
    "mammifera": "mammifero",
    "mammifere": "mammifero",
    "mammiferi": "mammifero",
    "mammine": "mammina",
    "mammografie": "mammografia",
    "mammole": "mammola",
    "mammolette": "mammoletta",
    "mammoni": "mammone",
    "manageriali": "manageriale",
    "managers": "manager",
    "manate": "manata",
    "manca": "manco",
    "mancai": "mancare",
    "mancamenti": "mancamento",
    "mancammo": "mancare",
    "mancan": "mancare",
    "mancando": "mancare",
    "mancano": "mancare",
    "mancante": "mancare",
    "mancanti": "mancare",
    "mancanze": "mancanza",
    "mancar": "mancare",
    "mancaron": "mancare",
    "mancarono": "mancare",
    "mancasse": "mancare",
    "mancasser": "mancare",
    "mancassero": "mancare",
    "mancassi": "mancare",
    "mancassimo": "mancare",
    "mancaste": "mancare",
    "mancasti": "mancare",
    "mancata": "mancato",
    "mancate": "mancato",
    "mancati": "mancato",
    "mancato": "mancare",
    "mancava": "mancare",
    "mancavamo": "mancare",
    "mancavan": "mancare",
    "mancavano": "mancare",
    "mancavate": "mancare",
    "mancavi": "mancare",
    "mancavo": "mancare",
    "mance": "mancia",
    "manche": "manco",
    "mancherai": "mancare",
    "mancheran": "mancare",
    "mancheranno": "mancare",
    "mancherebbe": "mancare",
    "mancherebber": "mancare",
    "mancherebbero": "mancare",
    "mancherei": "mancare",
    "mancheremmo": "mancare",
    "mancheremo": "mancare",
    "manchereste": "mancare",
    "mancheresti": "mancare",
    "mancherete": "mancare",
    "mancherà": "mancare",
    "mancherò": "mancare",
    "manchevolezze": "manchevolezza",
    "manchevoli": "manchevole",
    "manchi": "manco",
    "manchiamo": "mancare",
    "manchiate": "mancare",
    "manchin": "mancare",
    "manchino": "mancare",
    "manciate": "manciata",
    "mancina": "mancino",
    "mancine": "mancino",
    "mancini": "mancino",
    "manco": "mancare",
    "mancò": "mancare",
    "manda": "mandare",
    "mandai": "mandare",
    "mandamentali": "mandamentale",
    "mandamenti": "mandamento",
    "mandammo": "mandare",
    "mandan": "mandare",
    "mandando": "mandare",
    "mandano": "mandare",
    "mandante": "mandare",
    "mandanti": "mandare",
    "mandar": "mandare",
    "mandarinati": "mandarinato",
    "mandarini": "mandarino",
    "mandaron": "mandare",
    "mandarono": "mandare",
    "mandasse": "mandare",
    "mandasser": "mandare",
    "mandassero": "mandare",
    "mandassi": "mandare",
    "mandassimo": "mandare",
    "mandaste": "mandare",
    "mandasti": "mandare",
    "mandata": "mandare",
    "mandatari": "mandatario",
    "mandate": "mandare",
    "mandati": "mandato",
    "mandato": "mandare",
    "mandava": "mandare",
    "mandavamo": "mandare",
    "mandavan": "mandare",
    "mandavano": "mandare",
    "mandavate": "mandare",
    "mandavi": "mandare",
    "mandavo": "mandare",
    "manderai": "mandare",
    "manderan": "mandare",
    "manderanno": "mandare",
    "manderebbe": "mandare",
    "manderebber": "mandare",
    "manderebbero": "mandare",
    "manderei": "mandare",
    "manderemmo": "mandare",
    "manderemo": "mandare",
    "mandereste": "mandare",
    "manderesti": "mandare",
    "manderete": "mandare",
    "manderà": "mandare",
    "manderò": "mandare",
    "mandi": "mandare",
    "mandiamo": "mandare",
    "mandiate": "mandare",
    "mandibolari": "mandibolare",
    "mandibole": "mandibola",
    "mandin": "mandare",
    "mandino": "mandare",
    "mando": "mandare",
    "mandolini": "mandolino",
    "mandrie": "mandria",
    "mandò": "mandare",
    "maneggerai": "maneggiare",
    "maneggeran": "maneggiare",
    "maneggeranno": "maneggiare",
    "maneggerebbe": "maneggiare",
    "maneggerebber": "maneggiare",
    "maneggerebbero": "maneggiare",
    "maneggerei": "maneggiare",
    "maneggeremmo": "maneggiare",
    "maneggeremo": "maneggiare",
    "maneggereste": "maneggiare",
    "maneggeresti": "maneggiare",
    "maneggerete": "maneggiare",
    "maneggerà": "maneggiare",
    "maneggerò": "maneggiare",
    "maneggevoli": "maneggevole",
    "maneggi": "maneggio",
    "maneggia": "maneggiare",
    "maneggiai": "maneggiare",
    "maneggiammo": "maneggiare",
    "maneggiamo": "maneggiare",
    "maneggian": "maneggiare",
    "maneggiando": "maneggiare",
    "maneggiano": "maneggiare",
    "maneggiante": "maneggiare",
    "maneggianti": "maneggiare",
    "maneggiar": "maneggiare",
    "maneggiaron": "maneggiare",
    "maneggiarono": "maneggiare",
    "maneggiasse": "maneggiare",
    "maneggiasser": "maneggiare",
    "maneggiassero": "maneggiare",
    "maneggiassi": "maneggiare",
    "maneggiassimo": "maneggiare",
    "maneggiaste": "maneggiare",
    "maneggiasti": "maneggiare",
    "maneggiata": "maneggiare",
    "maneggiate": "maneggiare",
    "maneggiati": "maneggiare",
    "maneggiato": "maneggiare",
    "maneggiava": "maneggiare",
    "maneggiavamo": "maneggiare",
    "maneggiavan": "maneggiare",
    "maneggiavano": "maneggiare",
    "maneggiavate": "maneggiare",
    "maneggiavi": "maneggiare",
    "maneggiavo": "maneggiare",
    "maneggin": "maneggiare",
    "maneggino": "maneggiare",
    "maneggio": "maneggiare",
    "maneggioni": "maneggione",
    "maneggiò": "maneggiare",
    "manesca": "manesco",
    "manesche": "manesco",
    "maneschi": "manesco",
    "manette": "manetta",
    "manfrine": "manfrina",
    "mangana": "manganare",
    "manganai": "manganare",
    "manganammo": "manganare",
    "manganan": "manganare",
    "manganando": "manganare",
    "manganano": "manganare",
    "manganante": "manganare",
    "mangananti": "manganare",
    "manganar": "manganare",
    "manganaron": "manganare",
    "manganarono": "manganare",
    "manganasse": "manganare",
    "manganasser": "manganare",
    "manganassero": "manganare",
    "manganassi": "manganare",
    "manganassimo": "manganare",
    "manganaste": "manganare",
    "manganasti": "manganare",
    "manganata": "manganare",
    "manganate": "manganare",
    "manganati": "manganare",
    "manganato": "manganare",
    "manganava": "manganare",
    "manganavamo": "manganare",
    "manganavan": "manganare",
    "manganavano": "manganare",
    "manganavate": "manganare",
    "manganavi": "manganare",
    "manganavo": "manganare",
    "manganella": "manganellare",
    "manganellai": "manganellare",
    "manganellammo": "manganellare",
    "manganellan": "manganellare",
    "manganellando": "manganellare",
    "manganellano": "manganellare",
    "manganellante": "manganellare",
    "manganellanti": "manganellare",
    "manganellar": "manganellare",
    "manganellaron": "manganellare",
    "manganellarono": "manganellare",
    "manganellasse": "manganellare",
    "manganellasser": "manganellare",
    "manganellassero": "manganellare",
    "manganellassi": "manganellare",
    "manganellassimo": "manganellare",
    "manganellaste": "manganellare",
    "manganellasti": "manganellare",
    "manganellata": "manganellare",
    "manganellate": "manganellata",
    "manganellati": "manganellare",
    "manganellato": "manganellare",
    "manganellava": "manganellare",
    "manganellavamo": "manganellare",
    "manganellavan": "manganellare",
    "manganellavano": "manganellare",
    "manganellavate": "manganellare",
    "manganellavi": "manganellare",
    "manganellavo": "manganellare",
    "manganellerai": "manganellare",
    "manganelleran": "manganellare",
    "manganelleranno": "manganellare",
    "manganellerebbe": "manganellare",
    "manganellerebber": "manganellare",
    "manganellerebbero": "manganellare",
    "manganellerei": "manganellare",
    "manganelleremmo": "manganellare",
    "manganelleremo": "manganellare",
    "manganellereste": "manganellare",
    "manganelleresti": "manganellare",
    "manganellerete": "manganellare",
    "manganellerà": "manganellare",
    "manganellerò": "manganellare",
    "manganelli": "manganello",
    "manganelliamo": "manganellare",
    "manganelliate": "manganellare",
    "manganellin": "manganellare",
    "manganellino": "manganellare",
    "manganello": "manganellare",
    "manganellò": "manganellare",
    "manganerai": "manganare",
    "manganeran": "manganare",
    "manganeranno": "manganare",
    "manganerebbe": "manganare",
    "manganerebber": "manganare",
    "manganerebbero": "manganare",
    "manganerei": "manganare",
    "manganeremmo": "manganare",
    "manganeremo": "manganare",
    "manganereste": "manganare",
    "manganeresti": "manganare",
    "manganerete": "manganare",
    "manganerà": "manganare",
    "manganerò": "manganare",
    "mangani": "manganare",
    "manganiamo": "manganare",
    "manganiate": "manganare",
    "manganin": "manganare",
    "manganino": "manganare",
    "mangano": "manganare",
    "manganò": "manganare",
    "mangerai": "mangiare",
    "mangeran": "mangiare",
    "mangeranno": "mangiare",
    "mangerebbe": "mangiare",
    "mangerebber": "mangiare",
    "mangerebbero": "mangiare",
    "mangerecce": "mangereccio",
    "mangerecci": "mangereccio",
    "mangereccia": "mangereccio",
    "mangerei": "mangiare",
    "mangeremmo": "mangiare",
    "mangeremo": "mangiare",
    "mangereste": "mangiare",
    "mangeresti": "mangiare",
    "mangerete": "mangiare",
    "mangerà": "mangiare",
    "mangerò": "mangiare",
    "manghi": "mango",
    "mangi": "mangiare",
    "mangia": "mangiare",
    "mangiai": "mangiare",
    "mangiammo": "mangiare",
    "mangiamo": "mangiare",
    "mangian": "mangiare",
    "mangiando": "mangiare",
    "mangiano": "mangiare",
    "mangiante": "mangiare",
    "mangianti": "mangiare",
    "mangiar": "mangiare",
    "mangiaron": "mangiare",
    "mangiarono": "mangiare",
    "mangiasse": "mangiare",
    "mangiasser": "mangiare",
    "mangiassero": "mangiare",
    "mangiassi": "mangiare",
    "mangiassimo": "mangiare",
    "mangiaste": "mangiare",
    "mangiasti": "mangiare",
    "mangiata": "mangiare",
    "mangiate": "mangiare",
    "mangiati": "mangiare",
    "mangiato": "mangiare",
    "mangiatoie": "mangiatoia",
    "mangiatori": "mangiatore",
    "mangiava": "mangiare",
    "mangiavamo": "mangiare",
    "mangiavan": "mangiare",
    "mangiavano": "mangiare",
    "mangiavate": "mangiare",
    "mangiavi": "mangiare",
    "mangiavo": "mangiare",
    "mangimi": "mangime",
    "mangimifici": "mangimificio",
    "mangimistica": "mangimistico",
    "mangimistiche": "mangimistico",
    "mangimistici": "mangimistico",
    "mangin": "mangiare",
    "mangino": "mangiare",
    "mangio": "mangiare",
    "mangiucchi": "mangiucchiare",
    "mangiucchia": "mangiucchiare",
    "mangiucchiai": "mangiucchiare",
    "mangiucchiammo": "mangiucchiare",
    "mangiucchiamo": "mangiucchiare",
    "mangiucchian": "mangiucchiare",
    "mangiucchiando": "mangiucchiare",
    "mangiucchiano": "mangiucchiare",
    "mangiucchiante": "mangiucchiare",
    "mangiucchianti": "mangiucchiare",
    "mangiucchiar": "mangiucchiare",
    "mangiucchiaron": "mangiucchiare",
    "mangiucchiarono": "mangiucchiare",
    "mangiucchiasse": "mangiucchiare",
    "mangiucchiasser": "mangiucchiare",
    "mangiucchiassero": "mangiucchiare",
    "mangiucchiassi": "mangiucchiare",
    "mangiucchiassimo": "mangiucchiare",
    "mangiucchiaste": "mangiucchiare",
    "mangiucchiasti": "mangiucchiare",
    "mangiucchiata": "mangiucchiare",
    "mangiucchiate": "mangiucchiare",
    "mangiucchiati": "mangiucchiare",
    "mangiucchiato": "mangiucchiare",
    "mangiucchiava": "mangiucchiare",
    "mangiucchiavamo": "mangiucchiare",
    "mangiucchiavan": "mangiucchiare",
    "mangiucchiavano": "mangiucchiare",
    "mangiucchiavate": "mangiucchiare",
    "mangiucchiavi": "mangiucchiare",
    "mangiucchiavo": "mangiucchiare",
    "mangiucchierai": "mangiucchiare",
    "mangiucchieran": "mangiucchiare",
    "mangiucchieranno": "mangiucchiare",
    "mangiucchierebbe": "mangiucchiare",
    "mangiucchierebber": "mangiucchiare",
    "mangiucchierebbero": "mangiucchiare",
    "mangiucchierei": "mangiucchiare",
    "mangiucchieremmo": "mangiucchiare",
    "mangiucchieremo": "mangiucchiare",
    "mangiucchiereste": "mangiucchiare",
    "mangiucchieresti": "mangiucchiare",
    "mangiucchierete": "mangiucchiare",
    "mangiucchierà": "mangiucchiare",
    "mangiucchierò": "mangiucchiare",
    "mangiucchin": "mangiucchiare",
    "mangiucchino": "mangiucchiare",
    "mangiucchio": "mangiucchiare",
    "mangiucchiò": "mangiucchiare",
    "mangiò": "mangiare",
    "mani": "mano",
    "maniaca": "maniaco",
    "maniacali": "maniacale",
    "maniache": "maniaco",
    "maniaci": "maniaco",
    "manicaretti": "manicaretto",
    "maniche": "manica",
    "manichea": "manicheo",
    "manichee": "manicheo",
    "manichei": "manicheo",
    "manicheismi": "manicheismo",
    "manichini": "manichino",
    "manici": "manico",
    "manicomi": "manicomio",
    "manicotti": "manicotto",
    "manie": "mania",
    "manierata": "manierato",
    "manierate": "manierato",
    "manierati": "manierato",
    "maniere": "maniera",
    "manieri": "maniero",
    "manierismi": "manierismo",
    "manieriste": "manierista",
    "manieristi": "manierista",
    "manierosa": "manieroso",
    "manierose": "manieroso",
    "manierosi": "manieroso",
    "manifattura": "manifatturare",
    "manifatturai": "manifatturare",
    "manifatturammo": "manifatturare",
    "manifatturan": "manifatturare",
    "manifatturando": "manifatturare",
    "manifatturano": "manifatturare",
    "manifatturante": "manifatturare",
    "manifatturanti": "manifatturare",
    "manifatturar": "manifatturare",
    "manifatturaron": "manifatturare",
    "manifatturarono": "manifatturare",
    "manifatturasse": "manifatturare",
    "manifatturasser": "manifatturare",
    "manifatturassero": "manifatturare",
    "manifatturassi": "manifatturare",
    "manifatturassimo": "manifatturare",
    "manifatturaste": "manifatturare",
    "manifatturasti": "manifatturare",
    "manifatturata": "manifatturare",
    "manifatturate": "manifatturare",
    "manifatturati": "manifatturare",
    "manifatturato": "manifatturare",
    "manifatturava": "manifatturare",
    "manifatturavamo": "manifatturare",
    "manifatturavan": "manifatturare",
    "manifatturavano": "manifatturare",
    "manifatturavate": "manifatturare",
    "manifatturavi": "manifatturare",
    "manifatturavo": "manifatturare",
    "manifatture": "manifattura",
    "manifatturerai": "manifatturare",
    "manifattureran": "manifatturare",
    "manifattureranno": "manifatturare",
    "manifatturerebbe": "manifatturare",
    "manifatturerebber": "manifatturare",
    "manifatturerebbero": "manifatturare",
    "manifatturerei": "manifatturare",
    "manifattureremmo": "manifatturare",
    "manifattureremo": "manifatturare",
    "manifatturereste": "manifatturare",
    "manifattureresti": "manifatturare",
    "manifatturerete": "manifatturare",
    "manifatturerà": "manifatturare",
    "manifatturerò": "manifatturare",
    "manifatturi": "manifatturare",
    "manifatturiamo": "manifatturare",
    "manifatturiate": "manifatturare",
    "manifatturiera": "manifatturiero",
    "manifatturiere": "manifatturiero",
    "manifatturieri": "manifatturiero",
    "manifatturin": "manifatturare",
    "manifatturino": "manifatturare",
    "manifatturo": "manifatturare",
    "manifatturò": "manifatturare",
    "manifesta": "manifesto",
    "manifestai": "manifestare",
    "manifestammo": "manifestare",
    "manifestan": "manifestare",
    "manifestando": "manifestare",
    "manifestano": "manifestare",
    "manifestante": "manifestare",
    "manifestanti": "manifestare",
    "manifestar": "manifestare",
    "manifestaron": "manifestare",
    "manifestarono": "manifestare",
    "manifestasse": "manifestare",
    "manifestasser": "manifestare",
    "manifestassero": "manifestare",
    "manifestassi": "manifestare",
    "manifestassimo": "manifestare",
    "manifestaste": "manifestare",
    "manifestasti": "manifestare",
    "manifestata": "manifestare",
    "manifestate": "manifestare",
    "manifestati": "manifestare",
    "manifestato": "manifestare",
    "manifestava": "manifestare",
    "manifestavamo": "manifestare",
    "manifestavan": "manifestare",
    "manifestavano": "manifestare",
    "manifestavate": "manifestare",
    "manifestavi": "manifestare",
    "manifestavo": "manifestare",
    "manifestazioni": "manifestazione",
    "manifeste": "manifesto",
    "manifesterai": "manifestare",
    "manifesteran": "manifestare",
    "manifesteranno": "manifestare",
    "manifesterebbe": "manifestare",
    "manifesterebber": "manifestare",
    "manifesterebbero": "manifestare",
    "manifesterei": "manifestare",
    "manifesteremmo": "manifestare",
    "manifesteremo": "manifestare",
    "manifestereste": "manifestare",
    "manifesteresti": "manifestare",
    "manifesterete": "manifestare",
    "manifesterà": "manifestare",
    "manifesterò": "manifestare",
    "manifesti": "manifesto",
    "manifestiamo": "manifestare",
    "manifestiate": "manifestare",
    "manifestin": "manifestare",
    "manifestini": "manifestino",
    "manifestino": "manifestare",
    "manifesto": "manifestare",
    "manifestò": "manifestare",
    "maniglie": "maniglia",
    "manimorte": "manomorta",
    "manine": "manina",
    "manipola": "manipolare",
    "manipolai": "manipolare",
    "manipolammo": "manipolare",
    "manipolan": "manipolare",
    "manipolando": "manipolare",
    "manipolano": "manipolare",
    "manipolante": "manipolare",
    "manipolanti": "manipolare",
    "manipolar": "manipolare",
    "manipolaron": "manipolare",
    "manipolarono": "manipolare",
    "manipolasse": "manipolare",
    "manipolasser": "manipolare",
    "manipolassero": "manipolare",
    "manipolassi": "manipolare",
    "manipolassimo": "manipolare",
    "manipolaste": "manipolare",
    "manipolasti": "manipolare",
    "manipolata": "manipolare",
    "manipolate": "manipolare",
    "manipolati": "manipolare",
    "manipolato": "manipolare",
    "manipolatori": "manipolatore",
    "manipolatrice": "manipolatore",
    "manipolatrici": "manipolatore",
    "manipolava": "manipolare",
    "manipolavamo": "manipolare",
    "manipolavan": "manipolare",
    "manipolavano": "manipolare",
    "manipolavate": "manipolare",
    "manipolavi": "manipolare",
    "manipolavo": "manipolare",
    "manipolazioni": "manipolazione",
    "manipolerai": "manipolare",
    "manipoleran": "manipolare",
    "manipoleranno": "manipolare",
    "manipolerebbe": "manipolare",
    "manipolerebber": "manipolare",
    "manipolerebbero": "manipolare",
    "manipolerei": "manipolare",
    "manipoleremmo": "manipolare",
    "manipoleremo": "manipolare",
    "manipolereste": "manipolare",
    "manipoleresti": "manipolare",
    "manipolerete": "manipolare",
    "manipolerà": "manipolare",
    "manipolerò": "manipolare",
    "manipoli": "manipolo",
    "manipoliamo": "manipolare",
    "manipoliate": "manipolare",
    "manipolin": "manipolare",
    "manipolino": "manipolare",
    "manipolo": "manipolare",
    "manipolò": "manipolare",
    "mannaie": "mannaia",
    "mannara": "mannaro",
    "mannare": "mannaro",
    "mannari": "mannaro",
    "manne": "manna",
    "manodopere": "manodopera",
    "manomessa": "manomettere",
    "manomesse": "manomettere",
    "manomessi": "manomettere",
    "manomesso": "manomettere",
    "manometta": "manomettere",
    "manomettan": "manomettere",
    "manomettano": "manomettere",
    "manomette": "manomettere",
    "manomettemmo": "manomettere",
    "manomettendo": "manomettere",
    "manomettente": "manomettere",
    "manomettenti": "manomettere",
    "manometter": "manomettere",
    "manometterai": "manomettere",
    "manometteran": "manomettere",
    "manometteranno": "manomettere",
    "manometterebbe": "manomettere",
    "manometterebber": "manomettere",
    "manometterebbero": "manomettere",
    "manometterei": "manomettere",
    "manometteremmo": "manomettere",
    "manometteremo": "manomettere",
    "manomettereste": "manomettere",
    "manometteresti": "manomettere",
    "manometterete": "manomettere",
    "manometterà": "manomettere",
    "manometterò": "manomettere",
    "manomettesse": "manomettere",
    "manomettesser": "manomettere",
    "manomettessero": "manomettere",
    "manomettessi": "manomettere",
    "manomettessimo": "manomettere",
    "manometteste": "manomettere",
    "manomettesti": "manomettere",
    "manomettete": "manomettere",
    "manometteva": "manomettere",
    "manomettevamo": "manomettere",
    "manomettevan": "manomettere",
    "manomettevano": "manomettere",
    "manomettevate": "manomettere",
    "manomettevi": "manomettere",
    "manomettevo": "manomettere",
    "manometti": "manomettere",
    "manomettiamo": "manomettere",
    "manomettiate": "manomettere",
    "manometto": "manomettere",
    "manometton": "manomettere",
    "manomettono": "manomettere",
    "manomise": "manomettere",
    "manomiser": "manomettere",
    "manomisero": "manomettere",
    "manomisi": "manomettere",
    "manomissioni": "manomissione",
    "manone": "manona",
    "manopole": "manopola",
    "manoscritta": "manoscritto",
    "manoscritte": "manoscritto",
    "manoscritti": "manoscritto",
    "manovalanze": "manovalanza",
    "manovali": "manovale",
    "manovelle": "manovella",
    "manovra": "manovrare",
    "manovrai": "manovrare",
    "manovrammo": "manovrare",
    "manovran": "manovrare",
    "manovrando": "manovrare",
    "manovrano": "manovrare",
    "manovrante": "manovrare",
    "manovranti": "manovrare",
    "manovrar": "manovrare",
    "manovraron": "manovrare",
    "manovrarono": "manovrare",
    "manovrasse": "manovrare",
    "manovrasser": "manovrare",
    "manovrassero": "manovrare",
    "manovrassi": "manovrare",
    "manovrassimo": "manovrare",
    "manovraste": "manovrare",
    "manovrasti": "manovrare",
    "manovrata": "manovrare",
    "manovrate": "manovrare",
    "manovrati": "manovrare",
    "manovrato": "manovrare",
    "manovratori": "manovratore",
    "manovratrice": "manovratore",
    "manovratrici": "manovratore",
    "manovrava": "manovrare",
    "manovravamo": "manovrare",
    "manovravan": "manovrare",
    "manovravano": "manovrare",
    "manovravate": "manovrare",
    "manovravi": "manovrare",
    "manovravo": "manovrare",
    "manovre": "manovra",
    "manovre-bis": "manovra-bis",
    "manovrerai": "manovrare",
    "manovreran": "manovrare",
    "manovreranno": "manovrare",
    "manovrerebbe": "manovrare",
    "manovrerebber": "manovrare",
    "manovrerebbero": "manovrare",
    "manovrerei": "manovrare",
    "manovreremmo": "manovrare",
    "manovreremo": "manovrare",
    "manovrereste": "manovrare",
    "manovreresti": "manovrare",
    "manovrerete": "manovrare",
    "manovrerà": "manovrare",
    "manovrerò": "manovrare",
    "manovri": "manovrare",
    "manovriamo": "manovrare",
    "manovriate": "manovrare",
    "manovrin": "manovrare",
    "manovrine": "manovrina",
    "manovrino": "manovrare",
    "manovro": "manovrare",
    "manovrò": "manovrare",
    "mansarde": "mansarda",
    "mansioni": "mansione",
    "mansuefa": "mansuefare",
    "mansuefai": "mansuefare",
    "mansuefammo": "mansuefare",
    "mansuefan": "mansuefare",
    "mansuefando": "mansuefare",
    "mansuefano": "mansuefare",
    "mansuefante": "mansuefare",
    "mansuefanti": "mansuefare",
    "mansuefar": "mansuefare",
    "mansuefaron": "mansuefare",
    "mansuefarono": "mansuefare",
    "mansuefasse": "mansuefare",
    "mansuefasser": "mansuefare",
    "mansuefassero": "mansuefare",
    "mansuefassi": "mansuefare",
    "mansuefassimo": "mansuefare",
    "mansuefaste": "mansuefare",
    "mansuefasti": "mansuefare",
    "mansuefata": "mansuefare",
    "mansuefate": "mansuefare",
    "mansuefati": "mansuefare",
    "mansuefato": "mansuefare",
    "mansuefava": "mansuefare",
    "mansuefavamo": "mansuefare",
    "mansuefavan": "mansuefare",
    "mansuefavano": "mansuefare",
    "mansuefavate": "mansuefare",
    "mansuefavi": "mansuefare",
    "mansuefavo": "mansuefare",
    "mansueferai": "mansuefare",
    "mansueferan": "mansuefare",
    "mansueferanno": "mansuefare",
    "mansueferebbe": "mansuefare",
    "mansueferebber": "mansuefare",
    "mansueferebbero": "mansuefare",
    "mansueferei": "mansuefare",
    "mansueferemmo": "mansuefare",
    "mansueferemo": "mansuefare",
    "mansuefereste": "mansuefare",
    "mansueferesti": "mansuefare",
    "mansueferete": "mansuefare",
    "mansueferà": "mansuefare",
    "mansueferò": "mansuefare",
    "mansuefi": "mansuefare",
    "mansuefiamo": "mansuefare",
    "mansuefiate": "mansuefare",
    "mansuefin": "mansuefare",
    "mansuefino": "mansuefare",
    "mansuefo": "mansuefare",
    "mansuefò": "mansuefare",
    "mansueta": "mansueto",
    "mansuete": "mansueto",
    "mansueti": "mansueto",
    "mantelle": "mantella",
    "mantelli": "mantello",
    "mantelline": "mantellina",
    "mantenemmo": "mantenere",
    "mantenendo": "mantenere",
    "mantenente": "mantenere",
    "mantenenti": "mantenere",
    "mantener": "mantenere",
    "mantenesse": "mantenere",
    "mantenesser": "mantenere",
    "mantenessero": "mantenere",
    "mantenessi": "mantenere",
    "mantenessimo": "mantenere",
    "manteneste": "mantenere",
    "mantenesti": "mantenere",
    "mantenete": "mantenere",
    "manteneva": "mantenere",
    "mantenevamo": "mantenere",
    "mantenevan": "mantenere",
    "mantenevano": "mantenere",
    "mantenevate": "mantenere",
    "mantenevi": "mantenere",
    "mantenevo": "mantenere",
    "mantenga": "mantenere",
    "mantengan": "mantenere",
    "mantengano": "mantenere",
    "mantengo": "mantenere",
    "mantengon": "mantenere",
    "mantengono": "mantenere",
    "manteniamo": "mantenere",
    "manteniate": "mantenere",
    "mantenimenti": "mantenimento",
    "mantenne": "mantenere",
    "mantenner": "mantenere",
    "mantennero": "mantenere",
    "mantenni": "mantenere",
    "mantenuta": "mantenuto",
    "mantenute": "mantenuto",
    "mantenuti": "mantenuto",
    "mantenuto": "mantenere",
    "manterrai": "mantenere",
    "manterran": "mantenere",
    "manterranno": "mantenere",
    "manterrebbe": "mantenere",
    "manterrebber": "mantenere",
    "manterrebbero": "mantenere",
    "manterrei": "mantenere",
    "manterremmo": "mantenere",
    "manterremo": "mantenere",
    "manterreste": "mantenere",
    "manterresti": "mantenere",
    "manterrete": "mantenere",
    "manterrà": "mantenere",
    "manterrò": "mantenere",
    "manti": "manto",
    "mantidi": "mantide",
    "mantiene": "mantenere",
    "mantieni": "mantenere",
    "mantovana": "mantovano",
    "mantovane": "mantovano",
    "mantovani": "mantovano",
    "manualetti": "manualetto",
    "manuali": "manuale",
    "manualistica": "manualistico",
    "manualistiche": "manualistico",
    "manualistici": "manualistico",
    "manualizza": "manualizzare",
    "manualizzai": "manualizzare",
    "manualizzammo": "manualizzare",
    "manualizzan": "manualizzare",
    "manualizzando": "manualizzare",
    "manualizzano": "manualizzare",
    "manualizzante": "manualizzare",
    "manualizzanti": "manualizzare",
    "manualizzar": "manualizzare",
    "manualizzaron": "manualizzare",
    "manualizzarono": "manualizzare",
    "manualizzasse": "manualizzare",
    "manualizzasser": "manualizzare",
    "manualizzassero": "manualizzare",
    "manualizzassi": "manualizzare",
    "manualizzassimo": "manualizzare",
    "manualizzaste": "manualizzare",
    "manualizzasti": "manualizzare",
    "manualizzata": "manualizzare",
    "manualizzate": "manualizzare",
    "manualizzati": "manualizzare",
    "manualizzato": "manualizzare",
    "manualizzava": "manualizzare",
    "manualizzavamo": "manualizzare",
    "manualizzavan": "manualizzare",
    "manualizzavano": "manualizzare",
    "manualizzavate": "manualizzare",
    "manualizzavi": "manualizzare",
    "manualizzavo": "manualizzare",
    "manualizzerai": "manualizzare",
    "manualizzeran": "manualizzare",
    "manualizzeranno": "manualizzare",
    "manualizzerebbe": "manualizzare",
    "manualizzerebber": "manualizzare",
    "manualizzerebbero": "manualizzare",
    "manualizzerei": "manualizzare",
    "manualizzeremmo": "manualizzare",
    "manualizzeremo": "manualizzare",
    "manualizzereste": "manualizzare",
    "manualizzeresti": "manualizzare",
    "manualizzerete": "manualizzare",
    "manualizzerà": "manualizzare",
    "manualizzerò": "manualizzare",
    "manualizzi": "manualizzare",
    "manualizziamo": "manualizzare",
    "manualizziate": "manualizzare",
    "manualizzin": "manualizzare",
    "manualizzino": "manualizzare",
    "manualizzo": "manualizzare",
    "manualizzò": "manualizzare",
    "manubri": "manubrio",
    "manufatta": "manufatto",
    "manufatte": "manufatto",
    "manufatti": "manufatto",
    "manutentori": "manutentore",
    "manutenzioni": "manutenzione",
    "manzi": "manzo",
    "manzoniana": "manzoniano",
    "manzoniane": "manzoniano",
    "manzoniani": "manzoniano",
    "manìe": "manìa",
    "maoismi": "maoismo",
    "maoiste": "maoista",
    "maoisti": "maoista",
    "mappamondi": "mappamondo",
    "mappature": "mappatura",
    "mappe": "mappa",
    "maquillages": "maquillage",
    "mar": "mare",
    "marachelle": "marachella",
    "marasmi": "marasma",
    "maratone": "maratona",
    "maratonete": "maratoneta",
    "maratoneti": "maratoneta",
    "marca": "marcare",
    "marcai": "marcare",
    "marcammo": "marcare",
    "marcan": "marcare",
    "marcando": "marcare",
    "marcano": "marcare",
    "marcante": "marcare",
    "marcanti": "marcare",
    "marcantoni": "marcantonio",
    "marcar": "marcare",
    "marcaron": "marcare",
    "marcarono": "marcare",
    "marcasse": "marcare",
    "marcasser": "marcare",
    "marcassero": "marcare",
    "marcassi": "marcare",
    "marcassimo": "marcare",
    "marcaste": "marcare",
    "marcasti": "marcare",
    "marcata": "marcato",
    "marcate": "marcato",
    "marcati": "marcato",
    "marcato": "marcare",
    "marcatori": "marcatore",
    "marcature": "marcatura",
    "marcava": "marcare",
    "marcavamo": "marcare",
    "marcavan": "marcare",
    "marcavano": "marcare",
    "marcavate": "marcare",
    "marcavi": "marcare",
    "marcavo": "marcare",
    "marce": "marcio",
    "marcendo": "marcire",
    "marcente": "marcire",
    "marcenti": "marcire",
    "marcerai": "marciare",
    "marceran": "marciare",
    "marceranno": "marciare",
    "marcerebbe": "marciare",
    "marcerebber": "marciare",
    "marcerebbero": "marciare",
    "marcerei": "marciare",
    "marceremmo": "marciare",
    "marceremo": "marciare",
    "marcereste": "marciare",
    "marceresti": "marciare",
    "marcerete": "marciare",
    "marcerà": "marciare",
    "marcerò": "marciare",
    "marcescenti": "marcescente",
    "marcette": "marcetta",
    "marche": "marca",
    "marcherai": "marcare",
    "marcheran": "marcare",
    "marcheranno": "marcare",
    "marcherebbe": "marcare",
    "marcherebber": "marcare",
    "marcherebbero": "marcare",
    "marcherei": "marcare",
    "marcheremmo": "marcare",
    "marcheremo": "marcare",
    "marchereste": "marcare",
    "marcheresti": "marcare",
    "marcherete": "marcare",
    "marcherà": "marcare",
    "marcherò": "marcare",
    "marchese": "marchesa",
    "marchesi": "marchese",
    "marchette": "marchetta",
    "marchi": "marco",
    "marchia": "marchiare",
    "marchiai": "marchiare",
    "marchiammo": "marchiare",
    "marchiamo": "marchiare",
    "marchian": "marchiare",
    "marchiana": "marchiano",
    "marchiando": "marchiare",
    "marchiane": "marchiano",
    "marchiani": "marchiano",
    "marchiano": "marchiare",
    "marchiante": "marchiare",
    "marchianti": "marchiare",
    "marchiar": "marchiare",
    "marchiaron": "marchiare",
    "marchiarono": "marchiare",
    "marchiasse": "marchiare",
    "marchiasser": "marchiare",
    "marchiassero": "marchiare",
    "marchiassi": "marchiare",
    "marchiassimo": "marchiare",
    "marchiaste": "marchiare",
    "marchiasti": "marchiare",
    "marchiata": "marchiare",
    "marchiate": "marchiare",
    "marchiati": "marchiare",
    "marchiato": "marchiare",
    "marchiava": "marchiare",
    "marchiavamo": "marchiare",
    "marchiavan": "marchiare",
    "marchiavano": "marchiare",
    "marchiavate": "marchiare",
    "marchiavi": "marchiare",
    "marchiavo": "marchiare",
    "marchierai": "marchiare",
    "marchieran": "marchiare",
    "marchieranno": "marchiare",
    "marchierebbe": "marchiare",
    "marchierebber": "marchiare",
    "marchierebbero": "marchiare",
    "marchierei": "marchiare",
    "marchieremmo": "marchiare",
    "marchieremo": "marchiare",
    "marchiereste": "marchiare",
    "marchieresti": "marchiare",
    "marchierete": "marchiare",
    "marchierà": "marchiare",
    "marchierò": "marchiare",
    "marchigiana": "marchigiano",
    "marchigiane": "marchigiano",
    "marchigiani": "marchigiano",
    "marchin": "marchiare",
    "marchingegni": "marchingegno",
    "marchino": "marchiare",
    "marchio": "marchiare",
    "marchionali": "marchionale",
    "marchiò": "marchiare",
    "marci": "marcio",
    "marcia": "marcio",
    "marciai": "marciare",
    "marciammo": "marciare",
    "marciamo": "marcire",
    "marcian": "marciare",
    "marciando": "marciare",
    "marciano": "marciare",
    "marciante": "marciare",
    "marcianti": "marciare",
    "marciapiedi": "marciapiede",
    "marciar": "marciare",
    "marciaron": "marciare",
    "marciarono": "marciare",
    "marciasse": "marciare",
    "marciasser": "marciare",
    "marciassero": "marciare",
    "marciassi": "marciare",
    "marciassimo": "marciare",
    "marciaste": "marciare",
    "marciasti": "marciare",
    "marciata": "marciare",
    "marciate": "marcire",
    "marciati": "marciare",
    "marciato": "marciare",
    "marciatori": "marciatore",
    "marciatrici": "marciatrice",
    "marciava": "marciare",
    "marciavamo": "marciare",
    "marciavan": "marciare",
    "marciavano": "marciare",
    "marciavate": "marciare",
    "marciavi": "marciare",
    "marciavo": "marciare",
    "marcii": "marcire",
    "marcimmo": "marcire",
    "marcin": "marciare",
    "marcino": "marciare",
    "marcio": "marciare",
    "marcir": "marcire",
    "marcirai": "marcire",
    "marciran": "marcire",
    "marciranno": "marcire",
    "marcirebbe": "marcire",
    "marcirebber": "marcire",
    "marcirebbero": "marcire",
    "marcirei": "marcire",
    "marciremmo": "marcire",
    "marciremo": "marcire",
    "marcireste": "marcire",
    "marciresti": "marcire",
    "marcirete": "marcire",
    "marciron": "marcire",
    "marcirono": "marcire",
    "marcirà": "marcire",
    "marcirò": "marcire",
    "marcisca": "marcire",
    "marciscan": "marcire",
    "marciscano": "marcire",
    "marcisce": "marcire",
    "marcisci": "marcire",
    "marcisco": "marcire",
    "marciscon": "marcire",
    "marciscono": "marcire",
    "marcisse": "marcire",
    "marcisser": "marcire",
    "marcissero": "marcire",
    "marcissi": "marcire",
    "marcissimo": "marcire",
    "marciste": "marcire",
    "marcisti": "marcire",
    "marcita": "marcire",
    "marcite": "marcire",
    "marciti": "marcire",
    "marcito": "marcire",
    "marciumi": "marciume",
    "marciva": "marcire",
    "marcivamo": "marcire",
    "marcivan": "marcire",
    "marcivano": "marcire",
    "marcivate": "marcire",
    "marcivi": "marcire",
    "marcivo": "marcire",
    "marciò": "marciare",
    "marco": "marcare",
    "marconisti": "marconista",
    "marcì": "marcire",
    "marcò": "marcare",
    "maree": "marea",
    "mareggerai": "mareggiare",
    "mareggeran": "mareggiare",
    "mareggeranno": "mareggiare",
    "mareggerebbe": "mareggiare",
    "mareggerebber": "mareggiare",
    "mareggerebbero": "mareggiare",
    "mareggerei": "mareggiare",
    "mareggeremmo": "mareggiare",
    "mareggeremo": "mareggiare",
    "mareggereste": "mareggiare",
    "mareggeresti": "mareggiare",
    "mareggerete": "mareggiare",
    "mareggerà": "mareggiare",
    "mareggerò": "mareggiare",
    "mareggi": "mareggiare",
    "mareggia": "mareggiare",
    "mareggiai": "mareggiare",
    "mareggiammo": "mareggiare",
    "mareggiamo": "mareggiare",
    "mareggian": "mareggiare",
    "mareggiando": "mareggiare",
    "mareggiano": "mareggiare",
    "mareggiante": "mareggiare",
    "mareggianti": "mareggiare",
    "mareggiar": "mareggiare",
    "mareggiaron": "mareggiare",
    "mareggiarono": "mareggiare",
    "mareggiasse": "mareggiare",
    "mareggiasser": "mareggiare",
    "mareggiassero": "mareggiare",
    "mareggiassi": "mareggiare",
    "mareggiassimo": "mareggiare",
    "mareggiaste": "mareggiare",
    "mareggiasti": "mareggiare",
    "mareggiata": "mareggiare",
    "mareggiate": "mareggiata",
    "mareggiati": "mareggiare",
    "mareggiato": "mareggiare",
    "mareggiava": "mareggiare",
    "mareggiavamo": "mareggiare",
    "mareggiavan": "mareggiare",
    "mareggiavano": "mareggiare",
    "mareggiavate": "mareggiare",
    "mareggiavi": "mareggiare",
    "mareggiavo": "mareggiare",
    "mareggin": "mareggiare",
    "mareggino": "mareggiare",
    "mareggio": "mareggiare",
    "mareggiò": "mareggiare",
    "maremmana": "maremmano",
    "maremmane": "maremmano",
    "maremmani": "maremmano",
    "maremoti": "maremoto",
    "marescialli": "maresciallo",
    "marette": "maretta",
    "marezza": "marezzare",
    "marezzai": "marezzare",
    "marezzammo": "marezzare",
    "marezzan": "marezzare",
    "marezzando": "marezzare",
    "marezzano": "marezzare",
    "marezzante": "marezzare",
    "marezzanti": "marezzare",
    "marezzar": "marezzare",
    "marezzaron": "marezzare",
    "marezzarono": "marezzare",
    "marezzasse": "marezzare",
    "marezzasser": "marezzare",
    "marezzassero": "marezzare",
    "marezzassi": "marezzare",
    "marezzassimo": "marezzare",
    "marezzaste": "marezzare",
    "marezzasti": "marezzare",
    "marezzata": "marezzato",
    "marezzate": "marezzato",
    "marezzati": "marezzato",
    "marezzato": "marezzare",
    "marezzava": "marezzare",
    "marezzavamo": "marezzare",
    "marezzavan": "marezzare",
    "marezzavano": "marezzare",
    "marezzavate": "marezzare",
    "marezzavi": "marezzare",
    "marezzavo": "marezzare",
    "marezzerai": "marezzare",
    "marezzeran": "marezzare",
    "marezzeranno": "marezzare",
    "marezzerebbe": "marezzare",
    "marezzerebber": "marezzare",
    "marezzerebbero": "marezzare",
    "marezzerei": "marezzare",
    "marezzeremmo": "marezzare",
    "marezzeremo": "marezzare",
    "marezzereste": "marezzare",
    "marezzeresti": "marezzare",
    "marezzerete": "marezzare",
    "marezzerà": "marezzare",
    "marezzerò": "marezzare",
    "marezzi": "marezzare",
    "marezziamo": "marezzare",
    "marezziate": "marezzare",
    "marezzin": "marezzare",
    "marezzino": "marezzare",
    "marezzo": "marezzare",
    "marezzò": "marezzare",
    "margherite": "margherita",
    "margina": "marginare",
    "marginai": "marginare",
    "marginali": "marginale",
    "marginalizzazioni": "marginalizzazione",
    "marginammo": "marginare",
    "marginan": "marginare",
    "marginando": "marginare",
    "marginano": "marginare",
    "marginante": "marginare",
    "marginanti": "marginare",
    "marginar": "marginare",
    "marginaron": "marginare",
    "marginarono": "marginare",
    "marginasse": "marginare",
    "marginasser": "marginare",
    "marginassero": "marginare",
    "marginassi": "marginare",
    "marginassimo": "marginare",
    "marginaste": "marginare",
    "marginasti": "marginare",
    "marginata": "marginare",
    "marginate": "marginare",
    "marginati": "marginare",
    "marginato": "marginare",
    "marginava": "marginare",
    "marginavamo": "marginare",
    "marginavan": "marginare",
    "marginavano": "marginare",
    "marginavate": "marginare",
    "marginavi": "marginare",
    "marginavo": "marginare",
    "marginerai": "marginare",
    "margineran": "marginare",
    "margineranno": "marginare",
    "marginerebbe": "marginare",
    "marginerebber": "marginare",
    "marginerebbero": "marginare",
    "marginerei": "marginare",
    "margineremmo": "marginare",
    "margineremo": "marginare",
    "marginereste": "marginare",
    "margineresti": "marginare",
    "marginerete": "marginare",
    "marginerà": "marginare",
    "marginerò": "marginare",
    "margini": "margine",
    "marginiamo": "marginare",
    "marginiate": "marginare",
    "marginin": "marginare",
    "marginino": "marginare",
    "margino": "marginare",
    "marginò": "marginare",
    "mari": "mare",
    "mariana": "mariano",
    "mariane": "mariano",
    "mariani": "mariano",
    "marijuane": "marijuana",
    "marina": "marino",
    "marinai": "marinare",
    "marinammo": "marinare",
    "marinan": "marinare",
    "marinando": "marinare",
    "marinano": "marinare",
    "marinante": "marinare",
    "marinanti": "marinare",
    "marinar": "marinare",
    "marinara": "marinaro",
    "marinare": "marinaro",
    "marinaresca": "marinaresco",
    "marinaresche": "marinaresco",
    "marinareschi": "marinaresco",
    "marinaretti": "marinaretto",
    "marinari": "marinaro",
    "marinaron": "marinare",
    "marinarono": "marinare",
    "marinasse": "marinare",
    "marinasser": "marinare",
    "marinassero": "marinare",
    "marinassi": "marinare",
    "marinassimo": "marinare",
    "marinaste": "marinare",
    "marinasti": "marinare",
    "marinata": "marinare",
    "marinate": "marinare",
    "marinati": "marinare",
    "marinato": "marinare",
    "marinava": "marinare",
    "marinavamo": "marinare",
    "marinavan": "marinare",
    "marinavano": "marinare",
    "marinavate": "marinare",
    "marinavi": "marinare",
    "marinavo": "marinare",
    "marine": "marino",
    "marinerai": "marinare",
    "marineran": "marinare",
    "marineranno": "marinare",
    "marinerebbe": "marinare",
    "marinerebber": "marinare",
    "marinerebbero": "marinare",
    "marinerei": "marinare",
    "marineremmo": "marinare",
    "marineremo": "marinare",
    "marinereste": "marinare",
    "marineresti": "marinare",
    "marinerete": "marinare",
    "marinerie": "marineria",
    "marinerà": "marinare",
    "marinerò": "marinare",
    "marines": "marine",
    "marini": "marino",
    "mariniamo": "marinare",
    "mariniate": "marinare",
    "marinin": "marinare",
    "marinino": "marinare",
    "marino": "marinare",
    "marinò": "marinare",
    "marioli": "mariolo",
    "marionette": "marionetta",
    "marita": "maritare",
    "maritai": "maritare",
    "maritali": "maritale",
    "maritammo": "maritare",
    "maritan": "maritare",
    "maritando": "maritare",
    "maritano": "maritare",
    "maritante": "maritare",
    "maritanti": "maritare",
    "maritar": "maritare",
    "maritaron": "maritare",
    "maritarono": "maritare",
    "maritasse": "maritare",
    "maritasser": "maritare",
    "maritassero": "maritare",
    "maritassi": "maritare",
    "maritassimo": "maritare",
    "maritaste": "maritare",
    "maritasti": "maritare",
    "maritata": "maritare",
    "maritate": "maritare",
    "maritati": "maritare",
    "maritato": "maritare",
    "maritava": "maritare",
    "maritavamo": "maritare",
    "maritavan": "maritare",
    "maritavano": "maritare",
    "maritavate": "maritare",
    "maritavi": "maritare",
    "maritavo": "maritare",
    "mariterai": "maritare",
    "mariteran": "maritare",
    "mariteranno": "maritare",
    "mariterebbe": "maritare",
    "mariterebber": "maritare",
    "mariterebbero": "maritare",
    "mariterei": "maritare",
    "mariteremmo": "maritare",
    "mariteremo": "maritare",
    "maritereste": "maritare",
    "mariteresti": "maritare",
    "mariterete": "maritare",
    "mariterà": "maritare",
    "mariterò": "maritare",
    "mariti": "marito",
    "maritiamo": "maritare",
    "maritiate": "maritare",
    "maritin": "maritare",
    "maritino": "maritare",
    "marito": "maritare",
    "marittima": "marittimo",
    "marittime": "marittimo",
    "marittimi": "marittimo",
    "maritò": "maritare",
    "mariuoli": "mariuolo",
    "marmellate": "marmellata",
    "marmi": "marmo",
    "marmifera": "marmifero",
    "marmifere": "marmifero",
    "marmiferi": "marmifero",
    "marmitte": "marmitta",
    "marmittoni": "marmittone",
    "marmorea": "marmoreo",
    "marmoree": "marmoreo",
    "marmorei": "marmoreo",
    "marmorizza": "marmorizzare",
    "marmorizzai": "marmorizzare",
    "marmorizzammo": "marmorizzare",
    "marmorizzan": "marmorizzare",
    "marmorizzando": "marmorizzare",
    "marmorizzano": "marmorizzare",
    "marmorizzante": "marmorizzare",
    "marmorizzanti": "marmorizzare",
    "marmorizzar": "marmorizzare",
    "marmorizzaron": "marmorizzare",
    "marmorizzarono": "marmorizzare",
    "marmorizzasse": "marmorizzare",
    "marmorizzasser": "marmorizzare",
    "marmorizzassero": "marmorizzare",
    "marmorizzassi": "marmorizzare",
    "marmorizzassimo": "marmorizzare",
    "marmorizzaste": "marmorizzare",
    "marmorizzasti": "marmorizzare",
    "marmorizzata": "marmorizzare",
    "marmorizzate": "marmorizzare",
    "marmorizzati": "marmorizzare",
    "marmorizzato": "marmorizzare",
    "marmorizzava": "marmorizzare",
    "marmorizzavamo": "marmorizzare",
    "marmorizzavan": "marmorizzare",
    "marmorizzavano": "marmorizzare",
    "marmorizzavate": "marmorizzare",
    "marmorizzavi": "marmorizzare",
    "marmorizzavo": "marmorizzare",
    "marmorizzerai": "marmorizzare",
    "marmorizzeran": "marmorizzare",
    "marmorizzeranno": "marmorizzare",
    "marmorizzerebbe": "marmorizzare",
    "marmorizzerebber": "marmorizzare",
    "marmorizzerebbero": "marmorizzare",
    "marmorizzerei": "marmorizzare",
    "marmorizzeremmo": "marmorizzare",
    "marmorizzeremo": "marmorizzare",
    "marmorizzereste": "marmorizzare",
    "marmorizzeresti": "marmorizzare",
    "marmorizzerete": "marmorizzare",
    "marmorizzerà": "marmorizzare",
    "marmorizzerò": "marmorizzare",
    "marmorizzi": "marmorizzare",
    "marmorizziamo": "marmorizzare",
    "marmorizziate": "marmorizzare",
    "marmorizzin": "marmorizzare",
    "marmorizzino": "marmorizzare",
    "marmorizzo": "marmorizzare",
    "marmorizzò": "marmorizzare",
    "marmotte": "marmotta",
    "marocchina": "marocchino",
    "marocchine": "marocchino",
    "marocchini": "marocchino",
    "maronite": "maronita",
    "maroniti": "maronita",
    "marpioni": "marpione",
    "marroni": "marrone",
    "marsala": "marsalare",
    "marsalai": "marsalare",
    "marsalammo": "marsalare",
    "marsalan": "marsalare",
    "marsalando": "marsalare",
    "marsalano": "marsalare",
    "marsalante": "marsalare",
    "marsalanti": "marsalare",
    "marsalar": "marsalare",
    "marsalaron": "marsalare",
    "marsalarono": "marsalare",
    "marsalasse": "marsalare",
    "marsalasser": "marsalare",
    "marsalassero": "marsalare",
    "marsalassi": "marsalare",
    "marsalassimo": "marsalare",
    "marsalaste": "marsalare",
    "marsalasti": "marsalare",
    "marsalata": "marsalare",
    "marsalate": "marsalare",
    "marsalati": "marsalare",
    "marsalato": "marsalare",
    "marsalava": "marsalare",
    "marsalavamo": "marsalare",
    "marsalavan": "marsalare",
    "marsalavano": "marsalare",
    "marsalavate": "marsalare",
    "marsalavi": "marsalare",
    "marsalavo": "marsalare",
    "marsalerai": "marsalare",
    "marsaleran": "marsalare",
    "marsaleranno": "marsalare",
    "marsalerebbe": "marsalare",
    "marsalerebber": "marsalare",
    "marsalerebbero": "marsalare",
    "marsalerei": "marsalare",
    "marsaleremmo": "marsalare",
    "marsaleremo": "marsalare",
    "marsalereste": "marsalare",
    "marsaleresti": "marsalare",
    "marsalerete": "marsalare",
    "marsalerà": "marsalare",
    "marsalerò": "marsalare",
    "marsali": "marsalare",
    "marsaliamo": "marsalare",
    "marsaliate": "marsalare",
    "marsalin": "marsalare",
    "marsalino": "marsalare",
    "marsalo": "marsalare",
    "marsalò": "marsalare",
    "marsigliesi": "marsigliese",
    "marsine": "marsina",
    "marsupi": "marsupio",
    "marsupia": "marsupio",
    "marsupiali": "marsupiale",
    "marsupie": "marsupio",
    "martella": "martellare",
    "martellai": "martellare",
    "martellamenti": "martellamento",
    "martellammo": "martellare",
    "martellan": "martellare",
    "martellando": "martellare",
    "martellano": "martellare",
    "martellante": "martellare",
    "martellanti": "martellare",
    "martellar": "martellare",
    "martellaron": "martellare",
    "martellarono": "martellare",
    "martellasse": "martellare",
    "martellasser": "martellare",
    "martellassero": "martellare",
    "martellassi": "martellare",
    "martellassimo": "martellare",
    "martellaste": "martellare",
    "martellasti": "martellare",
    "martellata": "martellare",
    "martellate": "martellata",
    "martellati": "martellare",
    "martellato": "martellare",
    "martellava": "martellare",
    "martellavamo": "martellare",
    "martellavan": "martellare",
    "martellavano": "martellare",
    "martellavate": "martellare",
    "martellavi": "martellare",
    "martellavo": "martellare",
    "martellerai": "martellare",
    "martelleran": "martellare",
    "martelleranno": "martellare",
    "martellerebbe": "martellare",
    "martellerebber": "martellare",
    "martellerebbero": "martellare",
    "martellerei": "martellare",
    "martelleremmo": "martellare",
    "martelleremo": "martellare",
    "martellereste": "martellare",
    "martelleresti": "martellare",
    "martellerete": "martellare",
    "martellerà": "martellare",
    "martellerò": "martellare",
    "martelletti": "martelletto",
    "martelli": "martello",
    "martelliamo": "martellare",
    "martelliani": "martelliano",
    "martelliate": "martellare",
    "martellin": "martellare",
    "martellino": "martellare",
    "martello": "martellare",
    "martellò": "martellare",
    "martingale": "martingala",
    "martiri": "martirio",
    "martirizza": "martirizzare",
    "martirizzai": "martirizzare",
    "martirizzammo": "martirizzare",
    "martirizzan": "martirizzare",
    "martirizzando": "martirizzare",
    "martirizzano": "martirizzare",
    "martirizzante": "martirizzare",
    "martirizzanti": "martirizzare",
    "martirizzar": "martirizzare",
    "martirizzaron": "martirizzare",
    "martirizzarono": "martirizzare",
    "martirizzasse": "martirizzare",
    "martirizzasser": "martirizzare",
    "martirizzassero": "martirizzare",
    "martirizzassi": "martirizzare",
    "martirizzassimo": "martirizzare",
    "martirizzaste": "martirizzare",
    "martirizzasti": "martirizzare",
    "martirizzata": "martirizzare",
    "martirizzate": "martirizzare",
    "martirizzati": "martirizzare",
    "martirizzato": "martirizzare",
    "martirizzava": "martirizzare",
    "martirizzavamo": "martirizzare",
    "martirizzavan": "martirizzare",
    "martirizzavano": "martirizzare",
    "martirizzavate": "martirizzare",
    "martirizzavi": "martirizzare",
    "martirizzavo": "martirizzare",
    "martirizzerai": "martirizzare",
    "martirizzeran": "martirizzare",
    "martirizzeranno": "martirizzare",
    "martirizzerebbe": "martirizzare",
    "martirizzerebber": "martirizzare",
    "martirizzerebbero": "martirizzare",
    "martirizzerei": "martirizzare",
    "martirizzeremmo": "martirizzare",
    "martirizzeremo": "martirizzare",
    "martirizzereste": "martirizzare",
    "martirizzeresti": "martirizzare",
    "martirizzerete": "martirizzare",
    "martirizzerà": "martirizzare",
    "martirizzerò": "martirizzare",
    "martirizzi": "martirizzare",
    "martirizziamo": "martirizzare",
    "martirizziate": "martirizzare",
    "martirizzin": "martirizzare",
    "martirizzino": "martirizzare",
    "martirizzo": "martirizzare",
    "martirizzò": "martirizzare",
    "martori": "martoriare",
    "martoria": "martoriare",
    "martoriai": "martoriare",
    "martoriammo": "martoriare",
    "martoriamo": "martoriare",
    "martorian": "martoriare",
    "martoriando": "martoriare",
    "martoriano": "martoriare",
    "martoriante": "martoriare",
    "martorianti": "martoriare",
    "martoriar": "martoriare",
    "martoriaron": "martoriare",
    "martoriarono": "martoriare",
    "martoriasse": "martoriare",
    "martoriasser": "martoriare",
    "martoriassero": "martoriare",
    "martoriassi": "martoriare",
    "martoriassimo": "martoriare",
    "martoriaste": "martoriare",
    "martoriasti": "martoriare",
    "martoriata": "martoriare",
    "martoriate": "martoriata",
    "martoriati": "martoriare",
    "martoriato": "martoriare",
    "martoriava": "martoriare",
    "martoriavamo": "martoriare",
    "martoriavan": "martoriare",
    "martoriavano": "martoriare",
    "martoriavate": "martoriare",
    "martoriavi": "martoriare",
    "martoriavo": "martoriare",
    "martorierai": "martoriare",
    "martorieran": "martoriare",
    "martorieranno": "martoriare",
    "martorierebbe": "martoriare",
    "martorierebber": "martoriare",
    "martorierebbero": "martoriare",
    "martorierei": "martoriare",
    "martorieremmo": "martoriare",
    "martorieremo": "martoriare",
    "martoriereste": "martoriare",
    "martorieresti": "martoriare",
    "martorierete": "martoriare",
    "martorierà": "martoriare",
    "martorierò": "martoriare",
    "martorin": "martoriare",
    "martorino": "martoriare",
    "martorio": "martoriare",
    "martoriò": "martoriare",
    "marxiana": "marxiano",
    "marxiane": "marxiano",
    "marxiani": "marxiano",
    "marxismi": "marxismo",
    "marxismi-leninismi": "marxismo-leninismo",
    "marxista-leniniste": "marxista-leninista",
    "marxista-leninisti": "marxista-leninista",
    "marxiste": "marxista",
    "marxisti": "marxista",
    "marzi": "marzo",
    "marzia": "marzio",
    "marziali": "marziale",
    "marziana": "marziano",
    "marziane": "marziano",
    "marziani": "marziano",
    "marzie": "marzio",
    "marzolina": "marzolino",
    "marzoline": "marzolino",
    "marzolini": "marzolino",
    "mascalzonate": "mascalzonata",
    "mascalzoni": "mascalzone",
    "mascarponi": "mascarpone",
    "mascelle": "mascella",
    "maschera": "mascherare",
    "mascherai": "mascherare",
    "mascheramenti": "mascheramento",
    "mascherammo": "mascherare",
    "mascheran": "mascherare",
    "mascherando": "mascherare",
    "mascherano": "mascherare",
    "mascherante": "mascherare",
    "mascheranti": "mascherare",
    "mascherar": "mascherare",
    "mascheraron": "mascherare",
    "mascherarono": "mascherare",
    "mascherasse": "mascherare",
    "mascherasser": "mascherare",
    "mascherassero": "mascherare",
    "mascherassi": "mascherare",
    "mascherassimo": "mascherare",
    "mascheraste": "mascherare",
    "mascherasti": "mascherare",
    "mascherata": "mascherare",
    "mascherate": "mascherare",
    "mascherati": "mascherare",
    "mascherato": "mascherare",
    "mascherature": "mascheratura",
    "mascherava": "mascherare",
    "mascheravamo": "mascherare",
    "mascheravan": "mascherare",
    "mascheravano": "mascherare",
    "mascheravate": "mascherare",
    "mascheravi": "mascherare",
    "mascheravo": "mascherare",
    "maschere": "maschera",
    "maschererai": "mascherare",
    "maschereran": "mascherare",
    "maschereranno": "mascherare",
    "maschererebbe": "mascherare",
    "maschererebber": "mascherare",
    "maschererebbero": "mascherare",
    "maschererei": "mascherare",
    "maschereremmo": "mascherare",
    "maschereremo": "mascherare",
    "mascherereste": "mascherare",
    "maschereresti": "mascherare",
    "maschererete": "mascherare",
    "maschererà": "mascherare",
    "maschererò": "mascherare",
    "mascheri": "mascherare",
    "mascheriamo": "mascherare",
    "mascheriate": "mascherare",
    "mascherin": "mascherare",
    "mascherine": "mascherina",
    "mascherino": "mascherare",
    "maschero": "mascherare",
    "mascheroni": "mascherone",
    "mascherò": "mascherare",
    "maschi": "maschio",
    "maschia": "maschio",
    "maschiacci": "maschiaccio",
    "maschiai": "maschiare",
    "maschiammo": "maschiare",
    "maschiamo": "maschiare",
    "maschian": "maschiare",
    "maschiando": "maschiare",
    "maschiano": "maschiare",
    "maschiante": "maschiare",
    "maschianti": "maschiare",
    "maschiar": "maschiare",
    "maschiaron": "maschiare",
    "maschiarono": "maschiare",
    "maschiasse": "maschiare",
    "maschiasser": "maschiare",
    "maschiassero": "maschiare",
    "maschiassi": "maschiare",
    "maschiassimo": "maschiare",
    "maschiaste": "maschiare",
    "maschiasti": "maschiare",
    "maschiata": "maschiare",
    "maschiate": "maschiare",
    "maschiati": "maschiare",
    "maschiato": "maschiare",
    "maschiava": "maschiare",
    "maschiavamo": "maschiare",
    "maschiavan": "maschiare",
    "maschiavano": "maschiare",
    "maschiavate": "maschiare",
    "maschiavi": "maschiare",
    "maschiavo": "maschiare",
    "maschie": "maschio",
    "maschierai": "maschiare",
    "maschieran": "maschiare",
    "maschieranno": "maschiare",
    "maschierebbe": "maschiare",
    "maschierebber": "maschiare",
    "maschierebbero": "maschiare",
    "maschierei": "maschiare",
    "maschieremmo": "maschiare",
    "maschieremo": "maschiare",
    "maschiereste": "maschiare",
    "maschieresti": "maschiare",
    "maschierete": "maschiare",
    "maschierà": "maschiare",
    "maschierò": "maschiare",
    "maschietti": "maschietto",
    "maschili": "maschile",
    "maschilismi": "maschilismo",
    "maschiliste": "maschilista",
    "maschilisti": "maschilista",
    "maschin": "maschiare",
    "maschino": "maschiare",
    "maschio": "maschiare",
    "maschioni": "maschione",
    "maschiò": "maschiare",
    "mascolina": "mascolino",
    "mascoline": "mascolino",
    "mascolini": "mascolino",
    "mascolinizza": "mascolinizzare",
    "mascolinizzai": "mascolinizzare",
    "mascolinizzammo": "mascolinizzare",
    "mascolinizzan": "mascolinizzare",
    "mascolinizzando": "mascolinizzare",
    "mascolinizzano": "mascolinizzare",
    "mascolinizzante": "mascolinizzare",
    "mascolinizzanti": "mascolinizzare",
    "mascolinizzar": "mascolinizzare",
    "mascolinizzaron": "mascolinizzare",
    "mascolinizzarono": "mascolinizzare",
    "mascolinizzasse": "mascolinizzare",
    "mascolinizzasser": "mascolinizzare",
    "mascolinizzassero": "mascolinizzare",
    "mascolinizzassi": "mascolinizzare",
    "mascolinizzassimo": "mascolinizzare",
    "mascolinizzaste": "mascolinizzare",
    "mascolinizzasti": "mascolinizzare",
    "mascolinizzata": "mascolinizzare",
    "mascolinizzate": "mascolinizzare",
    "mascolinizzati": "mascolinizzare",
    "mascolinizzato": "mascolinizzare",
    "mascolinizzava": "mascolinizzare",
    "mascolinizzavamo": "mascolinizzare",
    "mascolinizzavan": "mascolinizzare",
    "mascolinizzavano": "mascolinizzare",
    "mascolinizzavate": "mascolinizzare",
    "mascolinizzavi": "mascolinizzare",
    "mascolinizzavo": "mascolinizzare",
    "mascolinizzerai": "mascolinizzare",
    "mascolinizzeran": "mascolinizzare",
    "mascolinizzeranno": "mascolinizzare",
    "mascolinizzerebbe": "mascolinizzare",
    "mascolinizzerebber": "mascolinizzare",
    "mascolinizzerebbero": "mascolinizzare",
    "mascolinizzerei": "mascolinizzare",
    "mascolinizzeremmo": "mascolinizzare",
    "mascolinizzeremo": "mascolinizzare",
    "mascolinizzereste": "mascolinizzare",
    "mascolinizzeresti": "mascolinizzare",
    "mascolinizzerete": "mascolinizzare",
    "mascolinizzerà": "mascolinizzare",
    "mascolinizzerò": "mascolinizzare",
    "mascolinizzi": "mascolinizzare",
    "mascolinizziamo": "mascolinizzare",
    "mascolinizziate": "mascolinizzare",
    "mascolinizzin": "mascolinizzare",
    "mascolinizzino": "mascolinizzare",
    "mascolinizzo": "mascolinizzare",
    "mascolinizzò": "mascolinizzare",
    "masi": "maso",
    "masnade": "masnada",
    "masnadieri": "masnadiero",
    "masochismi": "masochismo",
    "masochiste": "masochista",
    "masochisti": "masochista",
    "massacra": "massacrare",
    "massacrai": "massacrare",
    "massacrammo": "massacrare",
    "massacran": "massacrare",
    "massacrando": "massacrare",
    "massacrano": "massacrare",
    "massacrante": "massacrare",
    "massacranti": "massacrare",
    "massacrar": "massacrare",
    "massacraron": "massacrare",
    "massacrarono": "massacrare",
    "massacrasse": "massacrare",
    "massacrasser": "massacrare",
    "massacrassero": "massacrare",
    "massacrassi": "massacrare",
    "massacrassimo": "massacrare",
    "massacraste": "massacrare",
    "massacrasti": "massacrare",
    "massacrata": "massacrare",
    "massacrate": "massacrare",
    "massacrati": "massacrare",
    "massacrato": "massacrare",
    "massacratori": "massacratore",
    "massacrava": "massacrare",
    "massacravamo": "massacrare",
    "massacravan": "massacrare",
    "massacravano": "massacrare",
    "massacravate": "massacrare",
    "massacravi": "massacrare",
    "massacravo": "massacrare",
    "massacrerai": "massacrare",
    "massacreran": "massacrare",
    "massacreranno": "massacrare",
    "massacrerebbe": "massacrare",
    "massacrerebber": "massacrare",
    "massacrerebbero": "massacrare",
    "massacrerei": "massacrare",
    "massacreremmo": "massacrare",
    "massacreremo": "massacrare",
    "massacrereste": "massacrare",
    "massacreresti": "massacrare",
    "massacrerete": "massacrare",
    "massacrerà": "massacrare",
    "massacrerò": "massacrare",
    "massacri": "massacro",
    "massacriamo": "massacrare",
    "massacriate": "massacrare",
    "massacrin": "massacrare",
    "massacrino": "massacrare",
    "massacro": "massacrare",
    "massacrò": "massacrare",
    "massaggerai": "massaggiare",
    "massaggeran": "massaggiare",
    "massaggeranno": "massaggiare",
    "massaggerebbe": "massaggiare",
    "massaggerebber": "massaggiare",
    "massaggerebbero": "massaggiare",
    "massaggerei": "massaggiare",
    "massaggeremmo": "massaggiare",
    "massaggeremo": "massaggiare",
    "massaggereste": "massaggiare",
    "massaggeresti": "massaggiare",
    "massaggerete": "massaggiare",
    "massaggerà": "massaggiare",
    "massaggerò": "massaggiare",
    "massaggi": "massaggio",
    "massaggia": "massaggiare",
    "massaggiai": "massaggiare",
    "massaggiammo": "massaggiare",
    "massaggiamo": "massaggiare",
    "massaggian": "massaggiare",
    "massaggiando": "massaggiare",
    "massaggiano": "massaggiare",
    "massaggiante": "massaggiare",
    "massaggianti": "massaggiare",
    "massaggiar": "massaggiare",
    "massaggiaron": "massaggiare",
    "massaggiarono": "massaggiare",
    "massaggiasse": "massaggiare",
    "massaggiasser": "massaggiare",
    "massaggiassero": "massaggiare",
    "massaggiassi": "massaggiare",
    "massaggiassimo": "massaggiare",
    "massaggiaste": "massaggiare",
    "massaggiasti": "massaggiare",
    "massaggiata": "massaggiare",
    "massaggiate": "massaggiare",
    "massaggiati": "massaggiare",
    "massaggiato": "massaggiare",
    "massaggiatori": "massaggiatore",
    "massaggiatrici": "massaggiatrice",
    "massaggiava": "massaggiare",
    "massaggiavamo": "massaggiare",
    "massaggiavan": "massaggiare",
    "massaggiavano": "massaggiare",
    "massaggiavate": "massaggiare",
    "massaggiavi": "massaggiare",
    "massaggiavo": "massaggiare",
    "massaggin": "massaggiare",
    "massaggino": "massaggiare",
    "massaggio": "massaggiare",
    "massaggiò": "massaggiare",
    "massaie": "massaia",
    "masse": "massa",
    "massella": "massellare",
    "massellai": "massellare",
    "massellammo": "massellare",
    "massellan": "massellare",
    "massellando": "massellare",
    "massellano": "massellare",
    "massellante": "massellare",
    "massellanti": "massellare",
    "massellar": "massellare",
    "massellaron": "massellare",
    "massellarono": "massellare",
    "massellasse": "massellare",
    "massellasser": "massellare",
    "massellassero": "massellare",
    "massellassi": "massellare",
    "massellassimo": "massellare",
    "massellaste": "massellare",
    "massellasti": "massellare",
    "massellata": "massellare",
    "massellate": "massellare",
    "massellati": "massellare",
    "massellato": "massellare",
    "massellava": "massellare",
    "massellavamo": "massellare",
    "massellavan": "massellare",
    "massellavano": "massellare",
    "massellavate": "massellare",
    "massellavi": "massellare",
    "massellavo": "massellare",
    "massellerai": "massellare",
    "masselleran": "massellare",
    "masselleranno": "massellare",
    "massellerebbe": "massellare",
    "massellerebber": "massellare",
    "massellerebbero": "massellare",
    "massellerei": "massellare",
    "masselleremmo": "massellare",
    "masselleremo": "massellare",
    "massellereste": "massellare",
    "masselleresti": "massellare",
    "massellerete": "massellare",
    "massellerà": "massellare",
    "massellerò": "massellare",
    "masselli": "massellare",
    "masselliamo": "massellare",
    "masselliate": "massellare",
    "massellin": "massellare",
    "massellino": "massellare",
    "massello": "massellare",
    "massellò": "massellare",
    "masserie": "masseria",
    "massi": "masso",
    "massicce": "massiccio",
    "massicci": "massiccio",
    "massiccia": "massiccio",
    "massicciate": "massicciata",
    "massifica": "massificare",
    "massificai": "massificare",
    "massificammo": "massificare",
    "massifican": "massificare",
    "massificando": "massificare",
    "massificano": "massificare",
    "massificante": "massificare",
    "massificanti": "massificare",
    "massificar": "massificare",
    "massificaron": "massificare",
    "massificarono": "massificare",
    "massificasse": "massificare",
    "massificasser": "massificare",
    "massificassero": "massificare",
    "massificassi": "massificare",
    "massificassimo": "massificare",
    "massificaste": "massificare",
    "massificasti": "massificare",
    "massificata": "massificare",
    "massificate": "massificare",
    "massificati": "massificare",
    "massificato": "massificare",
    "massificava": "massificare",
    "massificavamo": "massificare",
    "massificavan": "massificare",
    "massificavano": "massificare",
    "massificavate": "massificare",
    "massificavi": "massificare",
    "massificavo": "massificare",
    "massificazioni": "massificazione",
    "massificherai": "massificare",
    "massificheran": "massificare",
    "massificheranno": "massificare",
    "massificherebbe": "massificare",
    "massificherebber": "massificare",
    "massificherebbero": "massificare",
    "massificherei": "massificare",
    "massificheremmo": "massificare",
    "massificheremo": "massificare",
    "massifichereste": "massificare",
    "massificheresti": "massificare",
    "massificherete": "massificare",
    "massificherà": "massificare",
    "massificherò": "massificare",
    "massifichi": "massificare",
    "massifichiamo": "massificare",
    "massifichiate": "massificare",
    "massifichin": "massificare",
    "massifichino": "massificare",
    "massifico": "massificare",
    "massificò": "massificare",
    "massima": "massimo",
    "massimali": "massimale",
    "massimalismi": "massimalismo",
    "massimaliste": "massimalista",
    "massimalisti": "massimalista",
    "massimalistica": "massimalistico",
    "massimalistiche": "massimalistico",
    "massimalistici": "massimalistico",
    "massime": "massimo",
    "massimi": "massimo",
    "massimizza": "massimizzare",
    "massimizzai": "massimizzare",
    "massimizzammo": "massimizzare",
    "massimizzan": "massimizzare",
    "massimizzando": "massimizzare",
    "massimizzano": "massimizzare",
    "massimizzante": "massimizzare",
    "massimizzanti": "massimizzare",
    "massimizzar": "massimizzare",
    "massimizzaron": "massimizzare",
    "massimizzarono": "massimizzare",
    "massimizzasse": "massimizzare",
    "massimizzasser": "massimizzare",
    "massimizzassero": "massimizzare",
    "massimizzassi": "massimizzare",
    "massimizzassimo": "massimizzare",
    "massimizzaste": "massimizzare",
    "massimizzasti": "massimizzare",
    "massimizzata": "massimizzare",
    "massimizzate": "massimizzare",
    "massimizzati": "massimizzare",
    "massimizzato": "massimizzare",
    "massimizzava": "massimizzare",
    "massimizzavamo": "massimizzare",
    "massimizzavan": "massimizzare",
    "massimizzavano": "massimizzare",
    "massimizzavate": "massimizzare",
    "massimizzavi": "massimizzare",
    "massimizzavo": "massimizzare",
    "massimizzazioni": "massimizzazione",
    "massimizzerai": "massimizzare",
    "massimizzeran": "massimizzare",
    "massimizzeranno": "massimizzare",
    "massimizzerebbe": "massimizzare",
    "massimizzerebber": "massimizzare",
    "massimizzerebbero": "massimizzare",
    "massimizzerei": "massimizzare",
    "massimizzeremmo": "massimizzare",
    "massimizzeremo": "massimizzare",
    "massimizzereste": "massimizzare",
    "massimizzeresti": "massimizzare",
    "massimizzerete": "massimizzare",
    "massimizzerà": "massimizzare",
    "massimizzerò": "massimizzare",
    "massimizzi": "massimizzare",
    "massimizziamo": "massimizzare",
    "massimizziate": "massimizzare",
    "massimizzin": "massimizzare",
    "massimizzino": "massimizzare",
    "massimizzo": "massimizzare",
    "massimizzò": "massimizzare",
    "massimo": "grande",
    "massmediologi": "massmediologo",
    "massonerie": "massoneria",
    "massoni": "massone",
    "massonica": "massonico",
    "massoniche": "massonico",
    "massonici": "massonico",
    "mastica": "masticare",
    "masticai": "masticare",
    "masticammo": "masticare",
    "mastican": "masticare",
    "masticando": "masticare",
    "masticano": "masticare",
    "masticante": "masticare",
    "masticanti": "masticare",
    "masticar": "masticare",
    "masticaron": "masticare",
    "masticarono": "masticare",
    "masticasse": "masticare",
    "masticasser": "masticare",
    "masticassero": "masticare",
    "masticassi": "masticare",
    "masticassimo": "masticare",
    "masticaste": "masticare",
    "masticasti": "masticare",
    "masticata": "masticare",
    "masticate": "masticare",
    "masticati": "masticare",
    "masticato": "masticare",
    "masticava": "masticare",
    "masticavamo": "masticare",
    "masticavan": "masticare",
    "masticavano": "masticare",
    "masticavate": "masticare",
    "masticavi": "masticare",
    "masticavo": "masticare",
    "masticherai": "masticare",
    "masticheran": "masticare",
    "masticheranno": "masticare",
    "masticherebbe": "masticare",
    "masticherebber": "masticare",
    "masticherebbero": "masticare",
    "masticherei": "masticare",
    "masticheremmo": "masticare",
    "masticheremo": "masticare",
    "mastichereste": "masticare",
    "masticheresti": "masticare",
    "masticherete": "masticare",
    "masticherà": "masticare",
    "masticherò": "masticare",
    "mastichi": "masticare",
    "mastichiamo": "masticare",
    "mastichiate": "masticare",
    "mastichin": "masticare",
    "mastichino": "masticare",
    "mastici": "mastice",
    "mastico": "masticare",
    "masticò": "masticare",
    "mastini": "mastino",
    "mastodonti": "mastodonte",
    "mastodontica": "mastodontico",
    "mastodontiche": "mastodontico",
    "mastodontici": "mastodontico",
    "mastra": "mastro",
    "mastre": "mastro",
    "mastri": "mastro",
    "masturba": "masturbare",
    "masturbai": "masturbare",
    "masturbammo": "masturbare",
    "masturban": "masturbare",
    "masturbando": "masturbare",
    "masturbano": "masturbare",
    "masturbante": "masturbare",
    "masturbanti": "masturbare",
    "masturbar": "masturbare",
    "masturbaron": "masturbare",
    "masturbarono": "masturbare",
    "masturbasse": "masturbare",
    "masturbasser": "masturbare",
    "masturbassero": "masturbare",
    "masturbassi": "masturbare",
    "masturbassimo": "masturbare",
    "masturbaste": "masturbare",
    "masturbasti": "masturbare",
    "masturbata": "masturbare",
    "masturbate": "masturbare",
    "masturbati": "masturbare",
    "masturbato": "masturbare",
    "masturbava": "masturbare",
    "masturbavamo": "masturbare",
    "masturbavan": "masturbare",
    "masturbavano": "masturbare",
    "masturbavate": "masturbare",
    "masturbavi": "masturbare",
    "masturbavo": "masturbare",
    "masturbazioni": "masturbazione",
    "masturberai": "masturbare",
    "masturberan": "masturbare",
    "masturberanno": "masturbare",
    "masturberebbe": "masturbare",
    "masturberebber": "masturbare",
    "masturberebbero": "masturbare",
    "masturberei": "masturbare",
    "masturberemmo": "masturbare",
    "masturberemo": "masturbare",
    "masturbereste": "masturbare",
    "masturberesti": "masturbare",
    "masturberete": "masturbare",
    "masturberà": "masturbare",
    "masturberò": "masturbare",
    "masturbi": "masturbare",
    "masturbiamo": "masturbare",
    "masturbiate": "masturbare",
    "masturbin": "masturbare",
    "masturbino": "masturbare",
    "masturbo": "masturbare",
    "masturbò": "masturbare",
    "matasse": "matassa",
    "matematica": "matematico",
    "matematiche": "matematico",
    "matematici": "matematico",
    "materassi": "materasso",
    "materassini": "materassino",
    "materiali": "materiale",
    "materialismi": "materialismo",
    "materialiste": "materialista",
    "materialisti": "materialista",
    "materialistica": "materialistico",
    "materialistiche": "materialistico",
    "materialistici": "materialistico",
    "materializza": "materializzare",
    "materializzai": "materializzare",
    "materializzammo": "materializzare",
    "materializzan": "materializzare",
    "materializzando": "materializzare",
    "materializzano": "materializzare",
    "materializzante": "materializzare",
    "materializzanti": "materializzare",
    "materializzar": "materializzare",
    "materializzaron": "materializzare",
    "materializzarono": "materializzare",
    "materializzasse": "materializzare",
    "materializzasser": "materializzare",
    "materializzassero": "materializzare",
    "materializzassi": "materializzare",
    "materializzassimo": "materializzare",
    "materializzaste": "materializzare",
    "materializzasti": "materializzare",
    "materializzata": "materializzare",
    "materializzate": "materializzare",
    "materializzati": "materializzare",
    "materializzato": "materializzare",
    "materializzava": "materializzare",
    "materializzavamo": "materializzare",
    "materializzavan": "materializzare",
    "materializzavano": "materializzare",
    "materializzavate": "materializzare",
    "materializzavi": "materializzare",
    "materializzavo": "materializzare",
    "materializzazioni": "materializzazione",
    "materializzerai": "materializzare",
    "materializzeran": "materializzare",
    "materializzeranno": "materializzare",
    "materializzerebbe": "materializzare",
    "materializzerebber": "materializzare",
    "materializzerebbero": "materializzare",
    "materializzerei": "materializzare",
    "materializzeremmo": "materializzare",
    "materializzeremo": "materializzare",
    "materializzereste": "materializzare",
    "materializzeresti": "materializzare",
    "materializzerete": "materializzare",
    "materializzerà": "materializzare",
    "materializzerò": "materializzare",
    "materializzi": "materializzare",
    "materializziamo": "materializzare",
    "materializziate": "materializzare",
    "materializzin": "materializzare",
    "materializzino": "materializzare",
    "materializzo": "materializzare",
    "materializzò": "materializzare",
    "materica": "materico",
    "materiche": "materico",
    "materici": "materico",
    "materie": "materia",
    "materna": "materno",
    "materne": "materno",
    "materni": "materno",
    "matite": "matita",
    "matriarcali": "matriarcale",
    "matrici": "matrice",
    "matricola": "matricolare",
    "matricolai": "matricolare",
    "matricolammo": "matricolare",
    "matricolan": "matricolare",
    "matricolando": "matricolare",
    "matricolano": "matricolare",
    "matricolante": "matricolare",
    "matricolanti": "matricolare",
    "matricolar": "matricolare",
    "matricolaron": "matricolare",
    "matricolarono": "matricolare",
    "matricolasse": "matricolare",
    "matricolasser": "matricolare",
    "matricolassero": "matricolare",
    "matricolassi": "matricolare",
    "matricolassimo": "matricolare",
    "matricolaste": "matricolare",
    "matricolasti": "matricolare",
    "matricolata": "matricolare",
    "matricolate": "matricolare",
    "matricolati": "matricolare",
    "matricolato": "matricolare",
    "matricolava": "matricolare",
    "matricolavamo": "matricolare",
    "matricolavan": "matricolare",
    "matricolavano": "matricolare",
    "matricolavate": "matricolare",
    "matricolavi": "matricolare",
    "matricolavo": "matricolare",
    "matricole": "matricola",
    "matricolerai": "matricolare",
    "matricoleran": "matricolare",
    "matricoleranno": "matricolare",
    "matricolerebbe": "matricolare",
    "matricolerebber": "matricolare",
    "matricolerebbero": "matricolare",
    "matricolerei": "matricolare",
    "matricoleremmo": "matricolare",
    "matricoleremo": "matricolare",
    "matricolereste": "matricolare",
    "matricoleresti": "matricolare",
    "matricolerete": "matricolare",
    "matricolerà": "matricolare",
    "matricolerò": "matricolare",
    "matricoli": "matricolare",
    "matricoliamo": "matricolare",
    "matricoliate": "matricolare",
    "matricolin": "matricolare",
    "matricolino": "matricolare",
    "matricolo": "matricolare",
    "matricolò": "matricolare",
    "matrigne": "matrigna",
    "matrimoni": "matrimonio",
    "matrimoniali": "matrimoniale",
    "matrioske": "matrioska",
    "matronali": "matronale",
    "matrone": "matrona",
    "matta": "matto",
    "mattacchioni": "mattacchione",
    "mattane": "mattana",
    "mattanze": "mattanza",
    "mattatoi": "mattatoio",
    "mattatori": "mattatore",
    "matte": "matto",
    "matti": "matto",
    "mattinali": "mattinale",
    "mattinate": "mattinata",
    "mattine": "mattina",
    "mattini": "mattino",
    "mattiniera": "mattiniero",
    "mattiniere": "mattiniero",
    "mattinieri": "mattiniero",
    "mattocchi": "mattocchio",
    "mattona": "mattonare",
    "mattonai": "mattonare",
    "mattonammo": "mattonare",
    "mattonan": "mattonare",
    "mattonando": "mattonare",
    "mattonano": "mattonare",
    "mattonante": "mattonare",
    "mattonanti": "mattonare",
    "mattonar": "mattonare",
    "mattonaron": "mattonare",
    "mattonarono": "mattonare",
    "mattonasse": "mattonare",
    "mattonasser": "mattonare",
    "mattonassero": "mattonare",
    "mattonassi": "mattonare",
    "mattonassimo": "mattonare",
    "mattonaste": "mattonare",
    "mattonasti": "mattonare",
    "mattonata": "mattonare",
    "mattonate": "mattonare",
    "mattonati": "mattonare",
    "mattonato": "mattonare",
    "mattonava": "mattonare",
    "mattonavamo": "mattonare",
    "mattonavan": "mattonare",
    "mattonavano": "mattonare",
    "mattonavate": "mattonare",
    "mattonavi": "mattonare",
    "mattonavo": "mattonare",
    "mattoncini": "mattoncino",
    "mattonelle": "mattonella",
    "mattonerai": "mattonare",
    "mattoneran": "mattonare",
    "mattoneranno": "mattonare",
    "mattonerebbe": "mattonare",
    "mattonerebber": "mattonare",
    "mattonerebbero": "mattonare",
    "mattonerei": "mattonare",
    "mattoneremmo": "mattonare",
    "mattoneremo": "mattonare",
    "mattonereste": "mattonare",
    "mattoneresti": "mattonare",
    "mattonerete": "mattonare",
    "mattonerà": "mattonare",
    "mattonerò": "mattonare",
    "mattoni": "mattone",
    "mattoniamo": "mattonare",
    "mattoniate": "mattonare",
    "mattonin": "mattonare",
    "mattonino": "mattonare",
    "mattono": "mattonare",
    "mattonò": "mattonare",
    "mattutina": "mattutino",
    "mattutine": "mattutino",
    "mattutini": "mattutino",
    "matura": "maturo",
    "maturai": "maturare",
    "maturammo": "maturare",
    "maturan": "maturare",
    "maturandi": "maturando",
    "maturando": "maturare",
    "maturano": "maturare",
    "maturante": "maturare",
    "maturanti": "maturare",
    "maturar": "maturare",
    "maturaron": "maturare",
    "maturarono": "maturare",
    "maturasse": "maturare",
    "maturasser": "maturare",
    "maturassero": "maturare",
    "maturassi": "maturare",
    "maturassimo": "maturare",
    "maturaste": "maturare",
    "maturasti": "maturare",
    "maturata": "maturare",
    "maturate": "maturare",
    "maturati": "maturare",
    "maturato": "maturare",
    "maturava": "maturare",
    "maturavamo": "maturare",
    "maturavan": "maturare",
    "maturavano": "maturare",
    "maturavate": "maturare",
    "maturavi": "maturare",
    "maturavo": "maturare",
    "maturazioni": "maturazione",
    "mature": "maturo",
    "maturerai": "maturare",
    "matureran": "maturare",
    "matureranno": "maturare",
    "maturerebbe": "maturare",
    "maturerebber": "maturare",
    "maturerebbero": "maturare",
    "maturerei": "maturare",
    "matureremmo": "maturare",
    "matureremo": "maturare",
    "maturereste": "maturare",
    "matureresti": "maturare",
    "maturerete": "maturare",
    "maturerà": "maturare",
    "maturerò": "maturare",
    "maturi": "maturo",
    "maturiamo": "maturare",
    "maturiate": "maturare",
    "maturin": "maturare",
    "maturino": "maturare",
    "maturo": "maturare",
    "maturò": "maturare",
    "mausolei": "mausoleo",
    "maxi-aumenti": "maxi-aumento",
    "maxi-collocamenti": "maxi-collocamento",
    "maxi-decreti": "maxi-decreto",
    "maxi-emendamenti": "maxi-emendamento",
    "maxi-fusioni": "maxi-fusione",
    "maxi-inchieste": "maxi-inchiesta",
    "maxi-operazioni": "maxi-operazione",
    "maxi-processi": "maxi-processo",
    "maxi-schermi": "maxi-schermo",
    "maxi-tangenti": "maxi-tangente",
    "maxiaumenti": "maxiaumento",
    "maxiconcorsi": "maxiconcorso",
    "maxiemendamenti": "maxiemendamento",
    "maxifusioni": "maxifusione",
    "maximulte": "maximulta",
    "maxiprestiti": "maxiprestito",
    "maxiprocessi": "maxiprocesso",
    "maxischermi": "maxischermo",
    "maxitangenti": "maxitangente",
    "mazzate": "mazzata",
    "mazze": "mazza",
    "mazzette": "mazzetta",
    "mazzetti": "mazzetto",
    "mazzi": "mazzo",
    "mazzieri": "mazziere",
    "mazziniana": "mazziniano",
    "mazziniane": "mazziniano",
    "mazziniani": "mazziniano",
    "meandri": "meandro",
    "meccani": "meccano",
    "meccanica": "meccanico",
    "meccaniche": "meccanico",
    "meccanici": "meccanico",
    "meccanismi": "meccanismo",
    "meccanizza": "meccanizzare",
    "meccanizzai": "meccanizzare",
    "meccanizzammo": "meccanizzare",
    "meccanizzan": "meccanizzare",
    "meccanizzando": "meccanizzare",
    "meccanizzano": "meccanizzare",
    "meccanizzante": "meccanizzare",
    "meccanizzanti": "meccanizzare",
    "meccanizzar": "meccanizzare",
    "meccanizzaron": "meccanizzare",
    "meccanizzarono": "meccanizzare",
    "meccanizzasse": "meccanizzare",
    "meccanizzasser": "meccanizzare",
    "meccanizzassero": "meccanizzare",
    "meccanizzassi": "meccanizzare",
    "meccanizzassimo": "meccanizzare",
    "meccanizzaste": "meccanizzare",
    "meccanizzasti": "meccanizzare",
    "meccanizzata": "meccanizzato",
    "meccanizzate": "meccanizzato",
    "meccanizzati": "meccanizzato",
    "meccanizzato": "meccanizzare",
    "meccanizzava": "meccanizzare",
    "meccanizzavamo": "meccanizzare",
    "meccanizzavan": "meccanizzare",
    "meccanizzavano": "meccanizzare",
    "meccanizzavate": "meccanizzare",
    "meccanizzavi": "meccanizzare",
    "meccanizzavo": "meccanizzare",
    "meccanizzazioni": "meccanizzazione",
    "meccanizzerai": "meccanizzare",
    "meccanizzeran": "meccanizzare",
    "meccanizzeranno": "meccanizzare",
    "meccanizzerebbe": "meccanizzare",
    "meccanizzerebber": "meccanizzare",
    "meccanizzerebbero": "meccanizzare",
    "meccanizzerei": "meccanizzare",
    "meccanizzeremmo": "meccanizzare",
    "meccanizzeremo": "meccanizzare",
    "meccanizzereste": "meccanizzare",
    "meccanizzeresti": "meccanizzare",
    "meccanizzerete": "meccanizzare",
    "meccanizzerà": "meccanizzare",
    "meccanizzerò": "meccanizzare",
    "meccanizzi": "meccanizzare",
    "meccanizziamo": "meccanizzare",
    "meccanizziate": "meccanizzare",
    "meccanizzin": "meccanizzare",
    "meccanizzino": "meccanizzare",
    "meccanizzo": "meccanizzare",
    "meccanizzò": "meccanizzare",
    "meccanografica": "meccanografico",
    "meccanografiche": "meccanografico",
    "meccanografici": "meccanografico",
    "mecche": "mecca",
    "mecenati": "mecenate",
    "mecenatismi": "mecenatismo",
    "medaglie": "medaglia",
    "medaglieri": "medagliere",
    "medagliette": "medaglietta",
    "medaglioni": "medaglione",
    "medesima": "medesimo",
    "medesime": "medesimo",
    "medesimi": "medesimo",
    "medi": "medio",
    "media": "medio",
    "mediai": "mediare",
    "mediali": "mediale",
    "mediammo": "mediare",
    "mediamo": "mediare",
    "median": "mediare",
    "mediana": "mediano",
    "mediando": "mediare",
    "mediane": "mediano",
    "mediani": "mediano",
    "medianica": "medianico",
    "medianiche": "medianico",
    "medianici": "medianico",
    "mediano": "mediare",
    "mediante": "mediare",
    "medianti": "mediare",
    "mediar": "mediare",
    "mediaron": "mediare",
    "mediarono": "mediare",
    "mediasse": "mediare",
    "mediasser": "mediare",
    "mediassero": "mediare",
    "mediassi": "mediare",
    "mediassimo": "mediare",
    "mediaste": "mediare",
    "mediasti": "mediare",
    "mediata": "mediato",
    "mediate": "mediato",
    "mediati": "mediato",
    "mediatica": "mediatico",
    "mediatiche": "mediatico",
    "mediatici": "mediatico",
    "mediato": "mediare",
    "mediatori": "mediatore",
    "mediava": "mediare",
    "mediavamo": "mediare",
    "mediavan": "mediare",
    "mediavano": "mediare",
    "mediavate": "mediare",
    "mediavi": "mediare",
    "mediavo": "mediare",
    "mediazioni": "mediazione",
    "medica": "medico",
    "medicai": "medicare",
    "medicali": "medicale",
    "medicamenti": "medicamento",
    "medicamentosa": "medicamentoso",
    "medicamentose": "medicamentoso",
    "medicamentosi": "medicamentoso",
    "medicammo": "medicare",
    "medican": "medicare",
    "medicando": "medicare",
    "medicano": "medicare",
    "medicante": "medicare",
    "medicanti": "medicare",
    "medicar": "medicare",
    "medicaron": "medicare",
    "medicarono": "medicare",
    "medicasse": "medicare",
    "medicasser": "medicare",
    "medicassero": "medicare",
    "medicassi": "medicare",
    "medicassimo": "medicare",
    "medicaste": "medicare",
    "medicasti": "medicare",
    "medicata": "medicato",
    "medicate": "medicato",
    "medicati": "medicato",
    "medicato": "medicare",
    "medicava": "medicare",
    "medicavamo": "medicare",
    "medicavan": "medicare",
    "medicavano": "medicare",
    "medicavate": "medicare",
    "medicavi": "medicare",
    "medicavo": "medicare",
    "medicazioni": "medicazione",
    "mediche": "medico",
    "medicherai": "medicare",
    "medicheran": "medicare",
    "medicheranno": "medicare",
    "medicherebbe": "medicare",
    "medicherebber": "medicare",
    "medicherebbero": "medicare",
    "medicherei": "medicare",
    "medicheremmo": "medicare",
    "medicheremo": "medicare",
    "medichereste": "medicare",
    "medicheresti": "medicare",
    "medicherete": "medicare",
    "medicherà": "medicare",
    "medicherò": "medicare",
    "medichi": "medicare",
    "medichiamo": "medicare",
    "medichiate": "medicare",
    "medichin": "medicare",
    "medichino": "medicare",
    "medici": "medico",
    "medicinali": "medicinale",
    "medicine": "medicina",
    "medico": "medicare",
    "medico-legali": "medico-legale",
    "medicò": "medicare",
    "medie": "medio",
    "medierai": "mediare",
    "medieran": "mediare",
    "medieranno": "mediare",
    "medierebbe": "mediare",
    "medierebber": "mediare",
    "medierebbero": "mediare",
    "medierei": "mediare",
    "medieremmo": "mediare",
    "medieremo": "mediare",
    "mediereste": "mediare",
    "medieresti": "mediare",
    "medierete": "mediare",
    "medierà": "mediare",
    "medierò": "mediare",
    "medievali": "medievale",
    "medievisti": "medievista",
    "medin": "mediare",
    "medine": "medina",
    "medino": "mediare",
    "medio": "mediare",
    "medio-alta": "medio-alto",
    "medio-alte": "medio-alto",
    "medio-alti": "medio-alto",
    "medio-bassa": "medio-basso",
    "medio-basse": "medio-basso",
    "medio-bassi": "medio-basso",
    "medio-grandi": "medio-grande",
    "medio-lunga": "medio-lungo",
    "medio-lunghe": "medio-lungo",
    "medio-lunghi": "medio-lungo",
    "medio-orientali": "medio-orientale",
    "medio-piccola": "medio-piccolo",
    "medio-piccole": "medio-piccolo",
    "medio-piccoli": "medio-piccolo",
    "mediocrediti": "mediocredito",
    "mediocri": "mediocre",
    "medioevali": "medioevale",
    "medioevi": "medioevo",
    "mediometraggi": "mediometraggio",
    "mediorientali": "mediorientale",
    "medita": "meditare",
    "meditabonda": "meditabondo",
    "meditabonde": "meditabondo",
    "meditabondi": "meditabondo",
    "meditai": "meditare",
    "meditammo": "meditare",
    "meditan": "meditare",
    "meditando": "meditare",
    "meditano": "meditare",
    "meditante": "meditare",
    "meditanti": "meditare",
    "meditar": "meditare",
    "meditaron": "meditare",
    "meditarono": "meditare",
    "meditasse": "meditare",
    "meditasser": "meditare",
    "meditassero": "meditare",
    "meditassi": "meditare",
    "meditassimo": "meditare",
    "meditaste": "meditare",
    "meditasti": "meditare",
    "meditata": "meditato",
    "meditate": "meditato",
    "meditati": "meditato",
    "meditativa": "meditativo",
    "meditative": "meditativo",
    "meditativi": "meditativo",
    "meditato": "meditare",
    "meditava": "meditare",
    "meditavamo": "meditare",
    "meditavan": "meditare",
    "meditavano": "meditare",
    "meditavate": "meditare",
    "meditavi": "meditare",
    "meditavo": "meditare",
    "meditazioni": "meditazione",
    "mediterai": "meditare",
    "mediteran": "meditare",
    "mediteranno": "meditare",
    "mediterebbe": "meditare",
    "mediterebber": "meditare",
    "mediterebbero": "meditare",
    "mediterei": "meditare",
    "mediteremmo": "meditare",
    "mediteremo": "meditare",
    "meditereste": "meditare",
    "mediteresti": "meditare",
    "mediterete": "meditare",
    "mediterranea": "mediterraneo",
    "mediterranee": "mediterraneo",
    "mediterranei": "mediterraneo",
    "mediterà": "meditare",
    "mediterò": "meditare",
    "mediti": "meditare",
    "meditiamo": "meditare",
    "meditiate": "meditare",
    "meditin": "meditare",
    "meditino": "meditare",
    "medito": "meditare",
    "meditò": "meditare",
    "mediò": "mediare",
    "meduse": "medusa",
    "mefitica": "mefitico",
    "mefitiche": "mefitico",
    "mefitici": "mefitico",
    "mega-atenei": "mega-ateneo",
    "mega-concerti": "mega-concerto",
    "mega-fusioni": "mega-fusione",
    "mega-impianti": "mega-impianto",
    "mega-progetti": "mega-progetto",
    "megacentrali": "megacentrale",
    "megacentri": "megacentro",
    "megaconcerti": "megaconcerto",
    "megacontratti": "megacontratto",
    "megadirigenti": "megadirigente",
    "megadiscoteche": "megadiscoteca",
    "megafoni": "megafono",
    "megafusioni": "megafusione",
    "megaimpianti": "megaimpianto",
    "megalomani": "megalomane",
    "megalomanie": "megalomania",
    "megamulte": "megamulta",
    "megaproduzioni": "megaproduzione",
    "megaprogetti": "megaprogetto",
    "megaschermi": "megaschermo",
    "megastadi": "megastadio",
    "megastrutture": "megastruttura",
    "melanconica": "melanconico",
    "melanconiche": "melanconico",
    "melanconici": "melanconico",
    "melanconie": "melanconia",
    "melanomi": "melanoma",
    "melanzane": "melanzana",
    "melasse": "melassa",
    "melata": "melato",
    "melate": "melato",
    "melati": "melato",
    "melatonine": "melatonina",
    "mele": "mela",
    "melensa": "melenso",
    "melensaggini": "melensaggine",
    "melense": "melenso",
    "melensi": "melenso",
    "meli": "melo",
    "meline": "melina",
    "mellifera": "mellifero",
    "mellifere": "mellifero",
    "melliferi": "mellifero",
    "mellifica": "mellificare",
    "mellificai": "mellificare",
    "mellificammo": "mellificare",
    "mellifican": "mellificare",
    "mellificando": "mellificare",
    "mellificano": "mellificare",
    "mellificante": "mellificare",
    "mellificanti": "mellificare",
    "mellificar": "mellificare",
    "mellificaron": "mellificare",
    "mellificarono": "mellificare",
    "mellificasse": "mellificare",
    "mellificasser": "mellificare",
    "mellificassero": "mellificare",
    "mellificassi": "mellificare",
    "mellificassimo": "mellificare",
    "mellificaste": "mellificare",
    "mellificasti": "mellificare",
    "mellificata": "mellificare",
    "mellificate": "mellificare",
    "mellificati": "mellificare",
    "mellificato": "mellificare",
    "mellificava": "mellificare",
    "mellificavamo": "mellificare",
    "mellificavan": "mellificare",
    "mellificavano": "mellificare",
    "mellificavate": "mellificare",
    "mellificavi": "mellificare",
    "mellificavo": "mellificare",
    "mellificherai": "mellificare",
    "mellificheran": "mellificare",
    "mellificheranno": "mellificare",
    "mellificherebbe": "mellificare",
    "mellificherebber": "mellificare",
    "mellificherebbero": "mellificare",
    "mellificherei": "mellificare",
    "mellificheremmo": "mellificare",
    "mellificheremo": "mellificare",
    "mellifichereste": "mellificare",
    "mellificheresti": "mellificare",
    "mellificherete": "mellificare",
    "mellificherà": "mellificare",
    "mellificherò": "mellificare",
    "mellifichi": "mellificare",
    "mellifichiamo": "mellificare",
    "mellifichiate": "mellificare",
    "mellifichin": "mellificare",
    "mellifichino": "mellificare",
    "mellifico": "mellificare",
    "mellificò": "mellificare",
    "melliflua": "mellifluo",
    "melliflue": "mellifluo",
    "melliflui": "mellifluo",
    "melme": "melma",
    "melmosa": "melmoso",
    "melmose": "melmoso",
    "melmosi": "melmoso",
    "melodica": "melodico",
    "melodiche": "melodico",
    "melodici": "melodico",
    "melodie": "melodia",
    "melodiosa": "melodioso",
    "melodiose": "melodioso",
    "melodiosi": "melodioso",
    "melodrammatica": "melodrammatico",
    "melodrammatiche": "melodrammatico",
    "melodrammatici": "melodrammatico",
    "melodrammi": "melodramma",
    "melograni": "melograno",
    "melomani": "melomane",
    "meloni": "melone",
    "membrane": "membrana",
    "membri": "membro",
    "membruta": "membruto",
    "membrute": "membruto",
    "membruti": "membruto",
    "memorabili": "memorabile",
    "memori": "memore",
    "memoriali": "memoriale",
    "memorialisti": "memorialista",
    "memorie": "memoria",
    "memorizza": "memorizzare",
    "memorizzai": "memorizzare",
    "memorizzammo": "memorizzare",
    "memorizzan": "memorizzare",
    "memorizzando": "memorizzare",
    "memorizzano": "memorizzare",
    "memorizzante": "memorizzare",
    "memorizzanti": "memorizzare",
    "memorizzar": "memorizzare",
    "memorizzaron": "memorizzare",
    "memorizzarono": "memorizzare",
    "memorizzasse": "memorizzare",
    "memorizzasser": "memorizzare",
    "memorizzassero": "memorizzare",
    "memorizzassi": "memorizzare",
    "memorizzassimo": "memorizzare",
    "memorizzaste": "memorizzare",
    "memorizzasti": "memorizzare",
    "memorizzata": "memorizzare",
    "memorizzate": "memorizzare",
    "memorizzati": "memorizzare",
    "memorizzato": "memorizzare",
    "memorizzava": "memorizzare",
    "memorizzavamo": "memorizzare",
    "memorizzavan": "memorizzare",
    "memorizzavano": "memorizzare",
    "memorizzavate": "memorizzare",
    "memorizzavi": "memorizzare",
    "memorizzavo": "memorizzare",
    "memorizzerai": "memorizzare",
    "memorizzeran": "memorizzare",
    "memorizzeranno": "memorizzare",
    "memorizzerebbe": "memorizzare",
    "memorizzerebber": "memorizzare",
    "memorizzerebbero": "memorizzare",
    "memorizzerei": "memorizzare",
    "memorizzeremmo": "memorizzare",
    "memorizzeremo": "memorizzare",
    "memorizzereste": "memorizzare",
    "memorizzeresti": "memorizzare",
    "memorizzerete": "memorizzare",
    "memorizzerà": "memorizzare",
    "memorizzerò": "memorizzare",
    "memorizzi": "memorizzare",
    "memorizziamo": "memorizzare",
    "memorizziate": "memorizzare",
    "memorizzin": "memorizzare",
    "memorizzino": "memorizzare",
    "memorizzo": "memorizzare",
    "memorizzò": "memorizzare",
    "mena": "menare",
    "menai": "menare",
    "menammo": "menare",
    "menan": "menare",
    "menando": "menare",
    "menano": "menare",
    "menante": "menare",
    "menanti": "menare",
    "menar": "menare",
    "menaron": "menare",
    "menarono": "menare",
    "menasse": "menare",
    "menasser": "menare",
    "menassero": "menare",
    "menassi": "menare",
    "menassimo": "menare",
    "menaste": "menare",
    "menasti": "menare",
    "menata": "menare",
    "menate": "menata",
    "menati": "menare",
    "menato": "menare",
    "menava": "menare",
    "menavamo": "menare",
    "menavan": "menare",
    "menavano": "menare",
    "menavate": "menare",
    "menavi": "menare",
    "menavo": "menare",
    "mence": "mencio",
    "menci": "mencio",
    "mencia": "mencio",
    "mendica": "mendicare",
    "mendicai": "mendicare",
    "mendicammo": "mendicare",
    "mendican": "mendicare",
    "mendicando": "mendicare",
    "mendicano": "mendicare",
    "mendicante": "mendicare",
    "mendicanti": "mendicare",
    "mendicar": "mendicare",
    "mendicaron": "mendicare",
    "mendicarono": "mendicare",
    "mendicasse": "mendicare",
    "mendicasser": "mendicare",
    "mendicassero": "mendicare",
    "mendicassi": "mendicare",
    "mendicassimo": "mendicare",
    "mendicaste": "mendicare",
    "mendicasti": "mendicare",
    "mendicata": "mendicare",
    "mendicate": "mendicare",
    "mendicati": "mendicare",
    "mendicato": "mendicare",
    "mendicava": "mendicare",
    "mendicavamo": "mendicare",
    "mendicavan": "mendicare",
    "mendicavano": "mendicare",
    "mendicavate": "mendicare",
    "mendicavi": "mendicare",
    "mendicavo": "mendicare",
    "mendicherai": "mendicare",
    "mendicheran": "mendicare",
    "mendicheranno": "mendicare",
    "mendicherebbe": "mendicare",
    "mendicherebber": "mendicare",
    "mendicherebbero": "mendicare",
    "mendicherei": "mendicare",
    "mendicheremmo": "mendicare",
    "mendicheremo": "mendicare",
    "mendichereste": "mendicare",
    "mendicheresti": "mendicare",
    "mendicherete": "mendicare",
    "mendicherà": "mendicare",
    "mendicherò": "mendicare",
    "mendichi": "mendicare",
    "mendichiamo": "mendicare",
    "mendichiate": "mendicare",
    "mendichin": "mendicare",
    "mendichino": "mendicare",
    "mendico": "mendicare",
    "mendicò": "mendicare",
    "menefreghismi": "menefreghismo",
    "meneghina": "meneghino",
    "meneghine": "meneghino",
    "meneghini": "meneghino",
    "menerai": "menare",
    "meneran": "menare",
    "meneranno": "menare",
    "menerebbe": "menare",
    "menerebber": "menare",
    "menerebbero": "menare",
    "menerei": "menare",
    "meneremmo": "menare",
    "meneremo": "menare",
    "menereste": "menare",
    "meneresti": "menare",
    "menerete": "menare",
    "menerà": "menare",
    "menerò": "menare",
    "menestrelli": "menestrello",
    "meni": "menare",
    "meniamo": "menare",
    "meniate": "menare",
    "menin": "menare",
    "meningiti": "meningite",
    "menino": "menare",
    "menischi": "menisco",
    "meno": "menare",
    "menoma": "menomare",
    "menomai": "menomare",
    "menomammo": "menomare",
    "menoman": "menomare",
    "menomando": "menomare",
    "menomano": "menomare",
    "menomante": "menomare",
    "menomanti": "menomare",
    "menomar": "menomare",
    "menomaron": "menomare",
    "menomarono": "menomare",
    "menomasse": "menomare",
    "menomasser": "menomare",
    "menomassero": "menomare",
    "menomassi": "menomare",
    "menomassimo": "menomare",
    "menomaste": "menomare",
    "menomasti": "menomare",
    "menomata": "menomato",
    "menomate": "menomato",
    "menomati": "menomato",
    "menomato": "menomare",
    "menomava": "menomare",
    "menomavamo": "menomare",
    "menomavan": "menomare",
    "menomavano": "menomare",
    "menomavate": "menomare",
    "menomavi": "menomare",
    "menomavo": "menomare",
    "menomazioni": "menomazione",
    "menomerai": "menomare",
    "menomeran": "menomare",
    "menomeranno": "menomare",
    "menomerebbe": "menomare",
    "menomerebber": "menomare",
    "menomerebbero": "menomare",
    "menomerei": "menomare",
    "menomeremmo": "menomare",
    "menomeremo": "menomare",
    "menomereste": "menomare",
    "menomeresti": "menomare",
    "menomerete": "menomare",
    "menomerà": "menomare",
    "menomerò": "menomare",
    "menomi": "menomare",
    "menomiamo": "menomare",
    "menomiate": "menomare",
    "menomin": "menomare",
    "menomino": "menomare",
    "menomo": "menomare",
    "menomò": "menomare",
    "menopause": "menopausa",
    "menscevica": "menscevico",
    "mensceviche": "menscevico",
    "menscevici": "menscevico",
    "mense": "mensa",
    "mensili": "mensile",
    "mensole": "mensola",
    "menta": "mentire",
    "mentali": "mentale",
    "mentan": "mentire",
    "mentano": "mentire",
    "mente": "mentire",
    "mentecatta": "mentecatto",
    "mentecatte": "mentecatto",
    "mentecatti": "mentecatto",
    "mentendo": "mentire",
    "mentente": "mentire",
    "mententi": "mentire",
    "menti": "mento",
    "mentiamo": "mentire",
    "mentiate": "mentire",
    "mentii": "mentire",
    "mentimmo": "mentire",
    "mentir": "mentire",
    "mentirai": "mentire",
    "mentiran": "mentire",
    "mentiranno": "mentire",
    "mentirebbe": "mentire",
    "mentirebber": "mentire",
    "mentirebbero": "mentire",
    "mentirei": "mentire",
    "mentiremmo": "mentire",
    "mentiremo": "mentire",
    "mentireste": "mentire",
    "mentiresti": "mentire",
    "mentirete": "mentire",
    "mentiron": "mentire",
    "mentirono": "mentire",
    "mentirà": "mentire",
    "mentirò": "mentire",
    "mentisse": "mentire",
    "mentisser": "mentire",
    "mentissero": "mentire",
    "mentissi": "mentire",
    "mentissimo": "mentire",
    "mentiste": "mentire",
    "mentisti": "mentire",
    "mentita": "mentito",
    "mentite": "mentito",
    "mentiti": "mentito",
    "mentito": "mentire",
    "mentitori": "mentitore",
    "mentitrice": "mentitore",
    "mentitrici": "mentitore",
    "mentiva": "mentire",
    "mentivamo": "mentire",
    "mentivan": "mentire",
    "mentivano": "mentire",
    "mentivate": "mentire",
    "mentivi": "mentire",
    "mentivo": "mentire",
    "mento": "mentire",
    "menton": "mentire",
    "mentono": "mentire",
    "mentori": "mentore",
    "mentova": "mentovare",
    "mentovai": "mentovare",
    "mentovammo": "mentovare",
    "mentovan": "mentovare",
    "mentovando": "mentovare",
    "mentovano": "mentovare",
    "mentovante": "mentovare",
    "mentovanti": "mentovare",
    "mentovar": "mentovare",
    "mentovaron": "mentovare",
    "mentovarono": "mentovare",
    "mentovasse": "mentovare",
    "mentovasser": "mentovare",
    "mentovassero": "mentovare",
    "mentovassi": "mentovare",
    "mentovassimo": "mentovare",
    "mentovaste": "mentovare",
    "mentovasti": "mentovare",
    "mentovata": "mentovare",
    "mentovate": "mentovare",
    "mentovati": "mentovare",
    "mentovato": "mentovare",
    "mentovava": "mentovare",
    "mentovavamo": "mentovare",
    "mentovavan": "mentovare",
    "mentovavano": "mentovare",
    "mentovavate": "mentovare",
    "mentovavi": "mentovare",
    "mentovavo": "mentovare",
    "mentoverai": "mentovare",
    "mentoveran": "mentovare",
    "mentoveranno": "mentovare",
    "mentoverebbe": "mentovare",
    "mentoverebber": "mentovare",
    "mentoverebbero": "mentovare",
    "mentoverei": "mentovare",
    "mentoveremmo": "mentovare",
    "mentoveremo": "mentovare",
    "mentovereste": "mentovare",
    "mentoveresti": "mentovare",
    "mentoverete": "mentovare",
    "mentoverà": "mentovare",
    "mentoverò": "mentovare",
    "mentovi": "mentovare",
    "mentoviamo": "mentovare",
    "mentoviate": "mentovare",
    "mentovin": "mentovare",
    "mentovino": "mentovare",
    "mentovo": "mentovare",
    "mentovò": "mentovare",
    "mentì": "mentire",
    "menziona": "menzionare",
    "menzionai": "menzionare",
    "menzionammo": "menzionare",
    "menzionan": "menzionare",
    "menzionando": "menzionare",
    "menzionano": "menzionare",
    "menzionante": "menzionare",
    "menzionanti": "menzionare",
    "menzionar": "menzionare",
    "menzionaron": "menzionare",
    "menzionarono": "menzionare",
    "menzionasse": "menzionare",
    "menzionasser": "menzionare",
    "menzionassero": "menzionare",
    "menzionassi": "menzionare",
    "menzionassimo": "menzionare",
    "menzionaste": "menzionare",
    "menzionasti": "menzionare",
    "menzionata": "menzionare",
    "menzionate": "menzionare",
    "menzionati": "menzionare",
    "menzionato": "menzionare",
    "menzionava": "menzionare",
    "menzionavamo": "menzionare",
    "menzionavan": "menzionare",
    "menzionavano": "menzionare",
    "menzionavate": "menzionare",
    "menzionavi": "menzionare",
    "menzionavo": "menzionare",
    "menzionerai": "menzionare",
    "menzioneran": "menzionare",
    "menzioneranno": "menzionare",
    "menzionerebbe": "menzionare",
    "menzionerebber": "menzionare",
    "menzionerebbero": "menzionare",
    "menzionerei": "menzionare",
    "menzioneremmo": "menzionare",
    "menzioneremo": "menzionare",
    "menzionereste": "menzionare",
    "menzioneresti": "menzionare",
    "menzionerete": "menzionare",
    "menzionerà": "menzionare",
    "menzionerò": "menzionare",
    "menzioni": "menzione",
    "menzioniamo": "menzionare",
    "menzioniate": "menzionare",
    "menzionin": "menzionare",
    "menzionino": "menzionare",
    "menziono": "menzionare",
    "menzionò": "menzionare",
    "menzogne": "menzogna",
    "menzognera": "menzognero",
    "menzognere": "menzognero",
    "menzogneri": "menzognero",
    "menò": "menare",
    "mera": "mero",
    "meravigli": "meravigliare",
    "meraviglia": "meravigliare",
    "meravigliai": "meravigliare",
    "meravigliammo": "meravigliare",
    "meravigliamo": "meravigliare",
    "meraviglian": "meravigliare",
    "meravigliando": "meravigliare",
    "meravigliano": "meravigliare",
    "meravigliante": "meravigliare",
    "meraviglianti": "meravigliare",
    "meravigliar": "meravigliare",
    "meravigliaron": "meravigliare",
    "meravigliarono": "meravigliare",
    "meravigliasse": "meravigliare",
    "meravigliasser": "meravigliare",
    "meravigliassero": "meravigliare",
    "meravigliassi": "meravigliare",
    "meravigliassimo": "meravigliare",
    "meravigliaste": "meravigliare",
    "meravigliasti": "meravigliare",
    "meravigliata": "meravigliare",
    "meravigliate": "meravigliare",
    "meravigliati": "meravigliare",
    "meravigliato": "meravigliare",
    "meravigliava": "meravigliare",
    "meravigliavamo": "meravigliare",
    "meravigliavan": "meravigliare",
    "meravigliavano": "meravigliare",
    "meravigliavate": "meravigliare",
    "meravigliavi": "meravigliare",
    "meravigliavo": "meravigliare",
    "meraviglie": "meraviglia",
    "meraviglierai": "meravigliare",
    "meraviglieran": "meravigliare",
    "meraviglieranno": "meravigliare",
    "meraviglierebbe": "meravigliare",
    "meraviglierebber": "meravigliare",
    "meraviglierebbero": "meravigliare",
    "meraviglierei": "meravigliare",
    "meraviglieremmo": "meravigliare",
    "meraviglieremo": "meravigliare",
    "meravigliereste": "meravigliare",
    "meraviglieresti": "meravigliare",
    "meraviglierete": "meravigliare",
    "meraviglierà": "meravigliare",
    "meraviglierò": "meravigliare",
    "meraviglin": "meravigliare",
    "meraviglino": "meravigliare",
    "meraviglio": "meravigliare",
    "meravigliosa": "meraviglioso",
    "meravigliose": "meraviglioso",
    "meravigliosi": "meraviglioso",
    "meravigliò": "meravigliare",
    "mercanteggerai": "mercanteggiare",
    "mercanteggeran": "mercanteggiare",
    "mercanteggeranno": "mercanteggiare",
    "mercanteggerebbe": "mercanteggiare",
    "mercanteggerebber": "mercanteggiare",
    "mercanteggerebbero": "mercanteggiare",
    "mercanteggerei": "mercanteggiare",
    "mercanteggeremmo": "mercanteggiare",
    "mercanteggeremo": "mercanteggiare",
    "mercanteggereste": "mercanteggiare",
    "mercanteggeresti": "mercanteggiare",
    "mercanteggerete": "mercanteggiare",
    "mercanteggerà": "mercanteggiare",
    "mercanteggerò": "mercanteggiare",
    "mercanteggi": "mercanteggiare",
    "mercanteggia": "mercanteggiare",
    "mercanteggiai": "mercanteggiare",
    "mercanteggiamenti": "mercanteggiamento",
    "mercanteggiammo": "mercanteggiare",
    "mercanteggiamo": "mercanteggiare",
    "mercanteggian": "mercanteggiare",
    "mercanteggiando": "mercanteggiare",
    "mercanteggiano": "mercanteggiare",
    "mercanteggiante": "mercanteggiare",
    "mercanteggianti": "mercanteggiare",
    "mercanteggiar": "mercanteggiare",
    "mercanteggiaron": "mercanteggiare",
    "mercanteggiarono": "mercanteggiare",
    "mercanteggiasse": "mercanteggiare",
    "mercanteggiasser": "mercanteggiare",
    "mercanteggiassero": "mercanteggiare",
    "mercanteggiassi": "mercanteggiare",
    "mercanteggiassimo": "mercanteggiare",
    "mercanteggiaste": "mercanteggiare",
    "mercanteggiasti": "mercanteggiare",
    "mercanteggiata": "mercanteggiare",
    "mercanteggiate": "mercanteggiare",
    "mercanteggiati": "mercanteggiare",
    "mercanteggiato": "mercanteggiare",
    "mercanteggiava": "mercanteggiare",
    "mercanteggiavamo": "mercanteggiare",
    "mercanteggiavan": "mercanteggiare",
    "mercanteggiavano": "mercanteggiare",
    "mercanteggiavate": "mercanteggiare",
    "mercanteggiavi": "mercanteggiare",
    "mercanteggiavo": "mercanteggiare",
    "mercanteggin": "mercanteggiare",
    "mercanteggino": "mercanteggiare",
    "mercanteggio": "mercanteggiare",
    "mercanteggiò": "mercanteggiare",
    "mercanti": "mercante",
    "mercantili": "mercantile",
    "mercanzie": "mercanzia",
    "mercati": "mercato",
    "mercatini": "mercatino",
    "mercenari": "mercenario",
    "mercenaria": "mercenario",
    "mercenarie": "mercenario",
    "merceologica": "merceologico",
    "merceologiche": "merceologico",
    "merceologici": "merceologico",
    "mercerie": "merceria",
    "mercerizza": "mercerizzare",
    "mercerizzai": "mercerizzare",
    "mercerizzammo": "mercerizzare",
    "mercerizzan": "mercerizzare",
    "mercerizzando": "mercerizzare",
    "mercerizzano": "mercerizzare",
    "mercerizzante": "mercerizzare",
    "mercerizzanti": "mercerizzare",
    "mercerizzar": "mercerizzare",
    "mercerizzaron": "mercerizzare",
    "mercerizzarono": "mercerizzare",
    "mercerizzasse": "mercerizzare",
    "mercerizzasser": "mercerizzare",
    "mercerizzassero": "mercerizzare",
    "mercerizzassi": "mercerizzare",
    "mercerizzassimo": "mercerizzare",
    "mercerizzaste": "mercerizzare",
    "mercerizzasti": "mercerizzare",
    "mercerizzata": "mercerizzare",
    "mercerizzate": "mercerizzare",
    "mercerizzati": "mercerizzare",
    "mercerizzato": "mercerizzare",
    "mercerizzava": "mercerizzare",
    "mercerizzavamo": "mercerizzare",
    "mercerizzavan": "mercerizzare",
    "mercerizzavano": "mercerizzare",
    "mercerizzavate": "mercerizzare",
    "mercerizzavi": "mercerizzare",
    "mercerizzavo": "mercerizzare",
    "mercerizzerai": "mercerizzare",
    "mercerizzeran": "mercerizzare",
    "mercerizzeranno": "mercerizzare",
    "mercerizzerebbe": "mercerizzare",
    "mercerizzerebber": "mercerizzare",
    "mercerizzerebbero": "mercerizzare",
    "mercerizzerei": "mercerizzare",
    "mercerizzeremmo": "mercerizzare",
    "mercerizzeremo": "mercerizzare",
    "mercerizzereste": "mercerizzare",
    "mercerizzeresti": "mercerizzare",
    "mercerizzerete": "mercerizzare",
    "mercerizzerà": "mercerizzare",
    "mercerizzerò": "mercerizzare",
    "mercerizzi": "mercerizzare",
    "mercerizziamo": "mercerizzare",
    "mercerizziate": "mercerizzare",
    "mercerizzin": "mercerizzare",
    "mercerizzino": "mercerizzare",
    "mercerizzo": "mercerizzare",
    "mercerizzò": "mercerizzare",
    "merci": "merce",
    "mercifica": "mercificare",
    "mercificai": "mercificare",
    "mercificammo": "mercificare",
    "mercifican": "mercificare",
    "mercificando": "mercificare",
    "mercificano": "mercificare",
    "mercificante": "mercificare",
    "mercificanti": "mercificare",
    "mercificar": "mercificare",
    "mercificaron": "mercificare",
    "mercificarono": "mercificare",
    "mercificasse": "mercificare",
    "mercificasser": "mercificare",
    "mercificassero": "mercificare",
    "mercificassi": "mercificare",
    "mercificassimo": "mercificare",
    "mercificaste": "mercificare",
    "mercificasti": "mercificare",
    "mercificata": "mercificare",
    "mercificate": "mercificare",
    "mercificati": "mercificare",
    "mercificato": "mercificare",
    "mercificava": "mercificare",
    "mercificavamo": "mercificare",
    "mercificavan": "mercificare",
    "mercificavano": "mercificare",
    "mercificavate": "mercificare",
    "mercificavi": "mercificare",
    "mercificavo": "mercificare",
    "mercificazioni": "mercificazione",
    "mercificherai": "mercificare",
    "mercificheran": "mercificare",
    "mercificheranno": "mercificare",
    "mercificherebbe": "mercificare",
    "mercificherebber": "mercificare",
    "mercificherebbero": "mercificare",
    "mercificherei": "mercificare",
    "mercificheremmo": "mercificare",
    "mercificheremo": "mercificare",
    "mercifichereste": "mercificare",
    "mercificheresti": "mercificare",
    "mercificherete": "mercificare",
    "mercificherà": "mercificare",
    "mercificherò": "mercificare",
    "mercifichi": "mercificare",
    "mercifichiamo": "mercificare",
    "mercifichiate": "mercificare",
    "mercifichin": "mercificare",
    "mercifichino": "mercificare",
    "mercifico": "mercificare",
    "mercificò": "mercificare",
    "mercimoni": "mercimonio",
    "mercuri": "mercurio",
    "mercuriali": "mercuriale",
    "merde": "merda",
    "merdosa": "merdoso",
    "merdose": "merdoso",
    "merdosi": "merdoso",
    "mere": "mero",
    "merende": "merenda",
    "merendine": "merendina",
    "meretrici": "meretrice",
    "meri": "mero",
    "meridiana": "meridiano",
    "meridiane": "meridiano",
    "meridiani": "meridiano",
    "meridionali": "meridionale",
    "meridionalismi": "meridionalismo",
    "meridionaliste": "meridionalista",
    "meridionalisti": "meridionalista",
    "meridionalistica": "meridionalistico",
    "meridionalistiche": "meridionalistico",
    "meridionalistici": "meridionalistico",
    "meridioni": "meridione",
    "meriggerai": "meriggiare",
    "meriggeran": "meriggiare",
    "meriggeranno": "meriggiare",
    "meriggerebbe": "meriggiare",
    "meriggerebber": "meriggiare",
    "meriggerebbero": "meriggiare",
    "meriggerei": "meriggiare",
    "meriggeremmo": "meriggiare",
    "meriggeremo": "meriggiare",
    "meriggereste": "meriggiare",
    "meriggeresti": "meriggiare",
    "meriggerete": "meriggiare",
    "meriggerà": "meriggiare",
    "meriggerò": "meriggiare",
    "meriggi": "meriggio",
    "meriggia": "meriggiare",
    "meriggiai": "meriggiare",
    "meriggiammo": "meriggiare",
    "meriggiamo": "meriggiare",
    "meriggian": "meriggiare",
    "meriggiando": "meriggiare",
    "meriggiano": "meriggiare",
    "meriggiante": "meriggiare",
    "meriggianti": "meriggiare",
    "meriggiar": "meriggiare",
    "meriggiaron": "meriggiare",
    "meriggiarono": "meriggiare",
    "meriggiasse": "meriggiare",
    "meriggiasser": "meriggiare",
    "meriggiassero": "meriggiare",
    "meriggiassi": "meriggiare",
    "meriggiassimo": "meriggiare",
    "meriggiaste": "meriggiare",
    "meriggiasti": "meriggiare",
    "meriggiata": "meriggiare",
    "meriggiate": "meriggiare",
    "meriggiati": "meriggiare",
    "meriggiato": "meriggiare",
    "meriggiava": "meriggiare",
    "meriggiavamo": "meriggiare",
    "meriggiavan": "meriggiare",
    "meriggiavano": "meriggiare",
    "meriggiavate": "meriggiare",
    "meriggiavi": "meriggiare",
    "meriggiavo": "meriggiare",
    "meriggin": "meriggiare",
    "meriggino": "meriggiare",
    "meriggio": "meriggiare",
    "meriggiò": "meriggiare",
    "merina": "merino",
    "merine": "merino",
    "merini": "merino",
    "merita": "meritare",
    "meritai": "meritare",
    "meritammo": "meritare",
    "meritan": "meritare",
    "meritando": "meritare",
    "meritano": "meritare",
    "meritante": "meritare",
    "meritanti": "meritare",
    "meritar": "meritare",
    "meritaron": "meritare",
    "meritarono": "meritare",
    "meritasse": "meritare",
    "meritasser": "meritare",
    "meritassero": "meritare",
    "meritassi": "meritare",
    "meritassimo": "meritare",
    "meritaste": "meritare",
    "meritasti": "meritare",
    "meritata": "meritato",
    "meritate": "meritato",
    "meritati": "meritato",
    "meritato": "meritare",
    "meritava": "meritare",
    "meritavamo": "meritare",
    "meritavan": "meritare",
    "meritavano": "meritare",
    "meritavate": "meritare",
    "meritavi": "meritare",
    "meritavo": "meritare",
    "meriterai": "meritare",
    "meriteran": "meritare",
    "meriteranno": "meritare",
    "meriterebbe": "meritare",
    "meriterebber": "meritare",
    "meriterebbero": "meritare",
    "meriterei": "meritare",
    "meriteremmo": "meritare",
    "meriteremo": "meritare",
    "meritereste": "meritare",
    "meriteresti": "meritare",
    "meriterete": "meritare",
    "meriterà": "meritare",
    "meriterò": "meritare",
    "meritevoli": "meritevole",
    "meriti": "merito",
    "meritiamo": "meritare",
    "meritiate": "meritare",
    "meritin": "meritare",
    "meritino": "meritare",
    "merito": "meritare",
    "meritocratica": "meritocratico",
    "meritocratiche": "meritocratico",
    "meritocratici": "meritocratico",
    "meritocrazie": "meritocrazia",
    "meritori": "meritorio",
    "meritoria": "meritorio",
    "meritorie": "meritorio",
    "meritò": "meritare",
    "merlata": "merlato",
    "merlate": "merlato",
    "merlati": "merlato",
    "merletta": "merlettare",
    "merlettai": "merlettare",
    "merlettammo": "merlettare",
    "merlettan": "merlettare",
    "merlettando": "merlettare",
    "merlettano": "merlettare",
    "merlettante": "merlettare",
    "merlettanti": "merlettare",
    "merlettar": "merlettare",
    "merlettaron": "merlettare",
    "merlettarono": "merlettare",
    "merlettasse": "merlettare",
    "merlettasser": "merlettare",
    "merlettassero": "merlettare",
    "merlettassi": "merlettare",
    "merlettassimo": "merlettare",
    "merlettaste": "merlettare",
    "merlettasti": "merlettare",
    "merlettata": "merlettare",
    "merlettate": "merlettare",
    "merlettati": "merlettare",
    "merlettato": "merlettare",
    "merlettava": "merlettare",
    "merlettavamo": "merlettare",
    "merlettavan": "merlettare",
    "merlettavano": "merlettare",
    "merlettavate": "merlettare",
    "merlettavi": "merlettare",
    "merlettavo": "merlettare",
    "merletterai": "merlettare",
    "merletteran": "merlettare",
    "merletteranno": "merlettare",
    "merletterebbe": "merlettare",
    "merletterebber": "merlettare",
    "merletterebbero": "merlettare",
    "merletterei": "merlettare",
    "merletteremmo": "merlettare",
    "merletteremo": "merlettare",
    "merlettereste": "merlettare",
    "merletteresti": "merlettare",
    "merletterete": "merlettare",
    "merletterà": "merlettare",
    "merletterò": "merlettare",
    "merletti": "merletto",
    "merlettiamo": "merlettare",
    "merlettiate": "merlettare",
    "merlettin": "merlettare",
    "merlettino": "merlettare",
    "merletto": "merlettare",
    "merlettò": "merlettare",
    "merluzzi": "merluzzo",
    "mesca": "mescere",
    "mescan": "mescere",
    "mescano": "mescere",
    "mesce": "mescere",
    "mescei": "mescere",
    "mescemmo": "mescere",
    "mescendo": "mescere",
    "mescente": "mescere",
    "mescenti": "mescere",
    "mescer": "mescere",
    "mescerai": "mescere",
    "mesceran": "mescere",
    "mesceranno": "mescere",
    "mescerebbe": "mescere",
    "mescerebber": "mescere",
    "mescerebbero": "mescere",
    "mescerei": "mescere",
    "mesceremmo": "mescere",
    "mesceremo": "mescere",
    "mescereste": "mescere",
    "mesceresti": "mescere",
    "mescerete": "mescere",
    "mesceron": "mescere",
    "mescerono": "mescere",
    "mescerà": "mescere",
    "mescerò": "mescere",
    "mescesse": "mescere",
    "mescesser": "mescere",
    "mescessero": "mescere",
    "mescessi": "mescere",
    "mescessimo": "mescere",
    "mesceste": "mescere",
    "mescesti": "mescere",
    "mescete": "mescere",
    "mesceva": "mescere",
    "mescevamo": "mescere",
    "mescevan": "mescere",
    "mescevano": "mescere",
    "mescevate": "mescere",
    "mescevi": "mescere",
    "mescevo": "mescere",
    "meschina": "meschino",
    "meschine": "meschino",
    "meschinerie": "meschineria",
    "meschini": "meschino",
    "mesci": "mescere",
    "mesciamo": "mescere",
    "mesciate": "mescere",
    "mesciuta": "mescere",
    "mesciute": "mescere",
    "mesciuti": "mescere",
    "mesciuto": "mescere",
    "mesco": "mescere",
    "mescola": "mescolare",
    "mescolai": "mescolare",
    "mescolammo": "mescolare",
    "mescolan": "mescolare",
    "mescolando": "mescolare",
    "mescolano": "mescolare",
    "mescolante": "mescolare",
    "mescolanti": "mescolare",
    "mescolanze": "mescolanza",
    "mescolar": "mescolare",
    "mescolaron": "mescolare",
    "mescolarono": "mescolare",
    "mescolasse": "mescolare",
    "mescolasser": "mescolare",
    "mescolassero": "mescolare",
    "mescolassi": "mescolare",
    "mescolassimo": "mescolare",
    "mescolaste": "mescolare",
    "mescolasti": "mescolare",
    "mescolata": "mescolare",
    "mescolate": "mescolare",
    "mescolati": "mescolare",
    "mescolato": "mescolare",
    "mescolava": "mescolare",
    "mescolavamo": "mescolare",
    "mescolavan": "mescolare",
    "mescolavano": "mescolare",
    "mescolavate": "mescolare",
    "mescolavi": "mescolare",
    "mescolavo": "mescolare",
    "mescolerai": "mescolare",
    "mescoleran": "mescolare",
    "mescoleranno": "mescolare",
    "mescolerebbe": "mescolare",
    "mescolerebber": "mescolare",
    "mescolerebbero": "mescolare",
    "mescolerei": "mescolare",
    "mescoleremmo": "mescolare",
    "mescoleremo": "mescolare",
    "mescolereste": "mescolare",
    "mescoleresti": "mescolare",
    "mescolerete": "mescolare",
    "mescolerà": "mescolare",
    "mescolerò": "mescolare",
    "mescoli": "mescolare",
    "mescoliamo": "mescolare",
    "mescoliate": "mescolare",
    "mescolin": "mescolare",
    "mescolino": "mescolare",
    "mescolo": "mescolare",
    "mescolò": "mescolare",
    "mescon": "mescere",
    "mescono": "mescere",
    "mescè": "mescere",
    "mesi": "mese",
    "messa": "mettere",
    "messaggera": "messaggero",
    "messaggere": "messaggero",
    "messaggeri": "messaggero",
    "messaggerie": "messaggeria",
    "messaggi": "messaggio",
    "messagi": "messagio",
    "messali": "messale",
    "messe": "mettere",
    "messi": "mettere",
    "messianica": "messianico",
    "messianiche": "messianico",
    "messianici": "messianico",
    "messianismi": "messianismo",
    "messicana": "messicano",
    "messicane": "messicano",
    "messicani": "messicano",
    "messinesi": "messinese",
    "messinscene": "messinscena",
    "messo": "mettere",
    "mesta": "mesto",
    "mestai": "mestare",
    "mestammo": "mestare",
    "mestan": "mestare",
    "mestando": "mestare",
    "mestano": "mestare",
    "mestante": "mestare",
    "mestanti": "mestare",
    "mestar": "mestare",
    "mestaron": "mestare",
    "mestarono": "mestare",
    "mestasse": "mestare",
    "mestasser": "mestare",
    "mestassero": "mestare",
    "mestassi": "mestare",
    "mestassimo": "mestare",
    "mestaste": "mestare",
    "mestasti": "mestare",
    "mestata": "mestare",
    "mestate": "mestare",
    "mestati": "mestare",
    "mestato": "mestare",
    "mestatori": "mestatore",
    "mestava": "mestare",
    "mestavamo": "mestare",
    "mestavan": "mestare",
    "mestavano": "mestare",
    "mestavate": "mestare",
    "mestavi": "mestare",
    "mestavo": "mestare",
    "meste": "mesto",
    "mesterai": "mestare",
    "mesteran": "mestare",
    "mesteranno": "mestare",
    "mesterebbe": "mestare",
    "mesterebber": "mestare",
    "mesterebbero": "mestare",
    "mesterei": "mestare",
    "mesteremmo": "mestare",
    "mesteremo": "mestare",
    "mestereste": "mestare",
    "mesteresti": "mestare",
    "mesterete": "mestare",
    "mesterà": "mestare",
    "mesterò": "mestare",
    "mesti": "mesto",
    "mestiamo": "mestare",
    "mestiate": "mestare",
    "mestieranti": "mestierante",
    "mestieri": "mestiere",
    "mestin": "mestare",
    "mestino": "mestare",
    "mestizie": "mestizia",
    "mesto": "mestare",
    "mestoli": "mestolo",
    "mestrini": "mestrino",
    "mestruali": "mestruale",
    "mestruazioni": "mestruazione",
    "mestò": "mestare",
    "metabolica": "metabolico",
    "metaboliche": "metabolico",
    "metabolici": "metabolico",
    "metabolismi": "metabolismo",
    "metaboliti": "metabolita",
    "metadoni": "metadone",
    "metafisica": "metafisico",
    "metafisiche": "metafisico",
    "metafisici": "metafisico",
    "metafore": "metafora",
    "metaforica": "metaforico",
    "metaforiche": "metaforico",
    "metaforici": "metaforico",
    "metallari": "metallaro",
    "metalli": "metallo",
    "metallica": "metallico",
    "metalliche": "metallico",
    "metallici": "metallico",
    "metallifera": "metallifero",
    "metallifere": "metallifero",
    "metalliferi": "metallifero",
    "metallizza": "metallizzare",
    "metallizzai": "metallizzare",
    "metallizzammo": "metallizzare",
    "metallizzan": "metallizzare",
    "metallizzando": "metallizzare",
    "metallizzano": "metallizzare",
    "metallizzante": "metallizzare",
    "metallizzanti": "metallizzare",
    "metallizzar": "metallizzare",
    "metallizzaron": "metallizzare",
    "metallizzarono": "metallizzare",
    "metallizzasse": "metallizzare",
    "metallizzasser": "metallizzare",
    "metallizzassero": "metallizzare",
    "metallizzassi": "metallizzare",
    "metallizzassimo": "metallizzare",
    "metallizzaste": "metallizzare",
    "metallizzasti": "metallizzare",
    "metallizzata": "metallizzato",
    "metallizzate": "metallizzato",
    "metallizzati": "metallizzato",
    "metallizzato": "metallizzare",
    "metallizzava": "metallizzare",
    "metallizzavamo": "metallizzare",
    "metallizzavan": "metallizzare",
    "metallizzavano": "metallizzare",
    "metallizzavate": "metallizzare",
    "metallizzavi": "metallizzare",
    "metallizzavo": "metallizzare",
    "metallizzerai": "metallizzare",
    "metallizzeran": "metallizzare",
    "metallizzeranno": "metallizzare",
    "metallizzerebbe": "metallizzare",
    "metallizzerebber": "metallizzare",
    "metallizzerebbero": "metallizzare",
    "metallizzerei": "metallizzare",
    "metallizzeremmo": "metallizzare",
    "metallizzeremo": "metallizzare",
    "metallizzereste": "metallizzare",
    "metallizzeresti": "metallizzare",
    "metallizzerete": "metallizzare",
    "metallizzerà": "metallizzare",
    "metallizzerò": "metallizzare",
    "metallizzi": "metallizzare",
    "metallizziamo": "metallizzare",
    "metallizziate": "metallizzare",
    "metallizzin": "metallizzare",
    "metallizzino": "metallizzare",
    "metallizzo": "metallizzare",
    "metallizzò": "metallizzare",
    "metallurgica": "metallurgico",
    "metallurgiche": "metallurgico",
    "metallurgici": "metallurgico",
    "metallurgie": "metallurgia",
    "metalmeccanica": "metalmeccanico",
    "metalmeccanice": "metalmeccanica",
    "metalmeccaniche": "metalmeccanico",
    "metalmeccanici": "metalmeccanico",
    "metamorfica": "metamorfico",
    "metamorfiche": "metamorfico",
    "metamorfici": "metamorfico",
    "metani": "metano",
    "metaniera": "metaniero",
    "metaniere": "metaniero",
    "metanieri": "metaniero",
    "metanifera": "metanifero",
    "metanifere": "metanifero",
    "metaniferi": "metanifero",
    "metanizzazioni": "metanizzazione",
    "metanodotti": "metanodotto",
    "metanoli": "metanolo",
    "metapsichica": "metapsichico",
    "metapsichiche": "metapsichico",
    "metapsichici": "metapsichico",
    "mete": "meta",
    "meteore": "meteora",
    "meteoriti": "meteorite",
    "meteorologi": "meteorologo",
    "meteorologica": "meteorologico",
    "meteorologiche": "meteorologico",
    "meteorologici": "meteorologico",
    "meteorologie": "meteorologia",
    "metereologi": "metereologo",
    "meticci": "meticcio",
    "meticolosa": "meticoloso",
    "meticolose": "meticoloso",
    "meticolosi": "meticoloso",
    "metilica": "metilico",
    "metiliche": "metilico",
    "metilici": "metilico",
    "metodi": "metodo",
    "metodica": "metodico",
    "metodiche": "metodico",
    "metodici": "metodico",
    "metodiste": "metodista",
    "metodisti": "metodista",
    "metodologica": "metodologico",
    "metodologiche": "metodologico",
    "metodologici": "metodologico",
    "metodologie": "metodologia",
    "metri": "metro",
    "metrica": "metrico",
    "metriche": "metrico",
    "metrici": "metrico",
    "metronomi": "metronomo",
    "metropolitana": "metropolitano",
    "metropolitane": "metropolitano",
    "metropolitani": "metropolitano",
    "metropoliti": "metropolita",
    "metta": "mettere",
    "mettan": "mettere",
    "mettano": "mettere",
    "mette": "mettere",
    "mettemmo": "mettere",
    "mettendo": "mettere",
    "mettente": "mettere",
    "mettenti": "mettere",
    "metter": "mettere",
    "metterai": "mettere",
    "metteran": "mettere",
    "metteranno": "mettere",
    "metterebbe": "mettere",
    "metterebber": "mettere",
    "metterebbero": "mettere",
    "metterei": "mettere",
    "metteremmo": "mettere",
    "metteremo": "mettere",
    "mettereste": "mettere",
    "metteresti": "mettere",
    "metterete": "mettere",
    "metterà": "mettere",
    "metterò": "mettere",
    "mettesse": "mettere",
    "mettesser": "mettere",
    "mettessero": "mettere",
    "mettessi": "mettere",
    "mettessimo": "mettere",
    "metteste": "mettere",
    "mettesti": "mettere",
    "mettete": "mettere",
    "metteva": "mettere",
    "mettevamo": "mettere",
    "mettevan": "mettere",
    "mettevano": "mettere",
    "mettevate": "mettere",
    "mettevi": "mettere",
    "mettevo": "mettere",
    "metti": "mettere",
    "mettiamo": "mettere",
    "mettiate": "mettere",
    "metto": "mettere",
    "metton": "mettere",
    "mettono": "mettere",
    "mezza": "mezzo",
    "mezzadri": "mezzadro",
    "mezzadrili": "mezzadrile",
    "mezzale": "mezzala",
    "mezzalune": "mezzaluna",
    "mezzana": "mezzano",
    "mezzane": "mezzano",
    "mezzani": "mezzano",
    "mezzanini": "mezzanino",
    "mezze": "mezzo",
    "mezzenotti": "mezzanotte",
    "mezzi": "mezzo",
    "mezzibusti": "mezzibusto",
    "mezzobusti": "mezzobusto",
    "mezzofondi": "mezzofondo",
    "mezzofondiste": "mezzofondista",
    "mezzofondisti": "mezzofondista",
    "mezzogiorni": "mezzogiorno",
    "mezzore": "mezzora",
    "mezzosoprani": "mezzosoprano",
    "mezzucci": "mezzuccio",
    "mia": "mio",
    "miagola": "miagolare",
    "miagolai": "miagolare",
    "miagolammo": "miagolare",
    "miagolan": "miagolare",
    "miagolando": "miagolare",
    "miagolano": "miagolare",
    "miagolante": "miagolare",
    "miagolanti": "miagolare",
    "miagolar": "miagolare",
    "miagolaron": "miagolare",
    "miagolarono": "miagolare",
    "miagolasse": "miagolare",
    "miagolasser": "miagolare",
    "miagolassero": "miagolare",
    "miagolassi": "miagolare",
    "miagolassimo": "miagolare",
    "miagolaste": "miagolare",
    "miagolasti": "miagolare",
    "miagolata": "miagolare",
    "miagolate": "miagolare",
    "miagolati": "miagolare",
    "miagolato": "miagolare",
    "miagolava": "miagolare",
    "miagolavamo": "miagolare",
    "miagolavan": "miagolare",
    "miagolavano": "miagolare",
    "miagolavate": "miagolare",
    "miagolavi": "miagolare",
    "miagolavo": "miagolare",
    "miagolerai": "miagolare",
    "miagoleran": "miagolare",
    "miagoleranno": "miagolare",
    "miagolerebbe": "miagolare",
    "miagolerebber": "miagolare",
    "miagolerebbero": "miagolare",
    "miagolerei": "miagolare",
    "miagoleremmo": "miagolare",
    "miagoleremo": "miagolare",
    "miagolereste": "miagolare",
    "miagoleresti": "miagolare",
    "miagolerete": "miagolare",
    "miagolerà": "miagolare",
    "miagolerò": "miagolare",
    "miagoli": "miagolare",
    "miagoliamo": "miagolare",
    "miagoliate": "miagolare",
    "miagolii": "miagolio",
    "miagolin": "miagolare",
    "miagolino": "miagolare",
    "miagolo": "miagolare",
    "miagolò": "miagolare",
    "miasmi": "miasma",
    "micce": "miccia",
    "mici": "micio",
    "micidiali": "micidiale",
    "micro-imprese": "micro-impresa",
    "microbi": "microbo",
    "microbica": "microbico",
    "microbiche": "microbico",
    "microbici": "microbico",
    "microbiologi": "microbiologo",
    "microcircuiti": "microcircuito",
    "microcosmi": "microcosmo",
    "microfibre": "microfibra",
    "microfilma": "microfilmare",
    "microfilmai": "microfilmare",
    "microfilmammo": "microfilmare",
    "microfilman": "microfilmare",
    "microfilmando": "microfilmare",
    "microfilmano": "microfilmare",
    "microfilmante": "microfilmare",
    "microfilmanti": "microfilmare",
    "microfilmar": "microfilmare",
    "microfilmaron": "microfilmare",
    "microfilmarono": "microfilmare",
    "microfilmasse": "microfilmare",
    "microfilmasser": "microfilmare",
    "microfilmassero": "microfilmare",
    "microfilmassi": "microfilmare",
    "microfilmassimo": "microfilmare",
    "microfilmaste": "microfilmare",
    "microfilmasti": "microfilmare",
    "microfilmata": "microfilmare",
    "microfilmate": "microfilmare",
    "microfilmati": "microfilmare",
    "microfilmato": "microfilmare",
    "microfilmava": "microfilmare",
    "microfilmavamo": "microfilmare",
    "microfilmavan": "microfilmare",
    "microfilmavano": "microfilmare",
    "microfilmavate": "microfilmare",
    "microfilmavi": "microfilmare",
    "microfilmavo": "microfilmare",
    "microfilmerai": "microfilmare",
    "microfilmeran": "microfilmare",
    "microfilmeranno": "microfilmare",
    "microfilmerebbe": "microfilmare",
    "microfilmerebber": "microfilmare",
    "microfilmerebbero": "microfilmare",
    "microfilmerei": "microfilmare",
    "microfilmeremmo": "microfilmare",
    "microfilmeremo": "microfilmare",
    "microfilmereste": "microfilmare",
    "microfilmeresti": "microfilmare",
    "microfilmerete": "microfilmare",
    "microfilmerà": "microfilmare",
    "microfilmerò": "microfilmare",
    "microfilmi": "microfilmare",
    "microfilmiamo": "microfilmare",
    "microfilmiate": "microfilmare",
    "microfilmin": "microfilmare",
    "microfilmino": "microfilmare",
    "microfilmo": "microfilmare",
    "microfilmò": "microfilmare",
    "microfoni": "microfono",
    "microimprese": "microimpresa",
    "microorganismi": "microorganismo",
    "microprocessori": "microprocessore",
    "microrganismi": "microrganismo",
    "microscopi": "microscopio",
    "microscopica": "microscopico",
    "microscopiche": "microscopico",
    "microscopici": "microscopico",
    "microspie": "microspia",
    "microstorie": "microstoria",
    "microstrutture": "microstruttura",
    "microvetture": "microvettura",
    "midollari": "midollare",
    "midolli": "midollo",
    "mie": "mio",
    "miei": "mio",
    "mieli": "miele",
    "mieta": "mietere",
    "mietan": "mietere",
    "mietano": "mietere",
    "miete": "mietere",
    "mietei": "mietere",
    "mietemmo": "mietere",
    "mietendo": "mietere",
    "mietente": "mietere",
    "mietenti": "mietere",
    "mieter": "mietere",
    "mieterai": "mietere",
    "mieteran": "mietere",
    "mieteranno": "mietere",
    "mieterebbe": "mietere",
    "mieterebber": "mietere",
    "mieterebbero": "mietere",
    "mieterei": "mietere",
    "mieteremmo": "mietere",
    "mieteremo": "mietere",
    "mietereste": "mietere",
    "mieteresti": "mietere",
    "mieterete": "mietere",
    "mieteron": "mietere",
    "mieterono": "mietere",
    "mieterà": "mietere",
    "mieterò": "mietere",
    "mietesse": "mietere",
    "mietesser": "mietere",
    "mietessero": "mietere",
    "mietessi": "mietere",
    "mietessimo": "mietere",
    "mieteste": "mietere",
    "mietesti": "mietere",
    "mietete": "mietere",
    "mieteva": "mietere",
    "mietevamo": "mietere",
    "mietevan": "mietere",
    "mietevano": "mietere",
    "mietevate": "mietere",
    "mietevi": "mietere",
    "mietevo": "mietere",
    "mieti": "mietere",
    "mietiamo": "mietere",
    "mietiate": "mietere",
    "mietitori": "mietitore",
    "mieto": "mietere",
    "mieton": "mietere",
    "mietono": "mietere",
    "mietuta": "mietere",
    "mietute": "mietere",
    "mietuti": "mietere",
    "mietuto": "mietere",
    "mietè": "mietere",
    "miglia": "miglio",
    "migliaia": "migliaio",
    "migliora": "migliorare",
    "migliorai": "migliorare",
    "miglioramenti": "miglioramento",
    "migliorammo": "migliorare",
    "miglioran": "migliorare",
    "migliorando": "migliorare",
    "migliorano": "migliorare",
    "migliorante": "migliorare",
    "miglioranti": "migliorare",
    "migliorar": "migliorare",
    "miglioraron": "migliorare",
    "migliorarono": "migliorare",
    "migliorasse": "migliorare",
    "migliorasser": "migliorare",
    "migliorassero": "migliorare",
    "migliorassi": "migliorare",
    "migliorassimo": "migliorare",
    "miglioraste": "migliorare",
    "migliorasti": "migliorare",
    "migliorata": "migliorare",
    "migliorate": "migliorare",
    "migliorati": "migliorare",
    "migliorativa": "migliorativo",
    "migliorative": "migliorativo",
    "migliorativi": "migliorativo",
    "migliorato": "migliorare",
    "migliorava": "migliorare",
    "miglioravamo": "migliorare",
    "miglioravan": "migliorare",
    "miglioravano": "migliorare",
    "miglioravate": "migliorare",
    "miglioravi": "migliorare",
    "miglioravo": "migliorare",
    "migliore": "buono",
    "migliorerai": "migliorare",
    "miglioreran": "migliorare",
    "miglioreranno": "migliorare",
    "migliorerebbe": "migliorare",
    "migliorerebber": "migliorare",
    "migliorerebbero": "migliorare",
    "migliorerei": "migliorare",
    "miglioreremmo": "migliorare",
    "miglioreremo": "migliorare",
    "migliorereste": "migliorare",
    "miglioreresti": "migliorare",
    "migliorerete": "migliorare",
    "migliorerà": "migliorare",
    "migliorerò": "migliorare",
    "migliori": "migliorare",
    "miglioriamo": "migliorare",
    "miglioriate": "migliorare",
    "migliorie": "miglioria",
    "migliorin": "migliorare",
    "migliorino": "migliorare",
    "miglioriste": "migliorista",
    "miglioristi": "migliorista",
    "miglioro": "migliorare",
    "migliorò": "migliorare",
    "mignoli": "mignolo",
    "mignotte": "mignotta",
    "migra": "migrare",
    "migrai": "migrare",
    "migrammo": "migrare",
    "migran": "migrare",
    "migrando": "migrare",
    "migrano": "migrare",
    "migrante": "migrare",
    "migranti": "migrare",
    "migrar": "migrare",
    "migraron": "migrare",
    "migrarono": "migrare",
    "migrasse": "migrare",
    "migrasser": "migrare",
    "migrassero": "migrare",
    "migrassi": "migrare",
    "migrassimo": "migrare",
    "migraste": "migrare",
    "migrasti": "migrare",
    "migrata": "migrare",
    "migrate": "migrare",
    "migrati": "migrare",
    "migrato": "migrare",
    "migratori": "migratorio",
    "migratoria": "migratorio",
    "migratorie": "migratorio",
    "migratrice": "migratore",
    "migratrici": "migratore",
    "migrava": "migrare",
    "migravamo": "migrare",
    "migravan": "migrare",
    "migravano": "migrare",
    "migravate": "migrare",
    "migravi": "migrare",
    "migravo": "migrare",
    "migrazioni": "migrazione",
    "migrerai": "migrare",
    "migreran": "migrare",
    "migreranno": "migrare",
    "migrerebbe": "migrare",
    "migrerebber": "migrare",
    "migrerebbero": "migrare",
    "migrerei": "migrare",
    "migreremmo": "migrare",
    "migreremo": "migrare",
    "migrereste": "migrare",
    "migreresti": "migrare",
    "migrerete": "migrare",
    "migrerà": "migrare",
    "migrerò": "migrare",
    "migri": "migrare",
    "migriamo": "migrare",
    "migriate": "migrare",
    "migrin": "migrare",
    "migrino": "migrare",
    "migro": "migrare",
    "migrò": "migrare",
    "milanesi": "milanese",
    "milaniste": "milanista",
    "milanisti": "milanista",
    "milensa": "milenso",
    "milense": "milenso",
    "milensi": "milenso",
    "mili": "miliare",
    "milia": "miliare",
    "miliai": "miliare",
    "miliammo": "miliare",
    "miliamo": "miliare",
    "milian": "miliare",
    "miliando": "miliare",
    "miliano": "miliare",
    "miliante": "miliare",
    "milianti": "miliare",
    "miliar": "miliare",
    "miliardari": "miliardario",
    "miliardaria": "miliardario",
    "miliardarie": "miliardario",
    "miliardi": "miliardo",
    "miliari": "miliare",
    "miliaron": "miliare",
    "miliarono": "miliare",
    "miliasse": "miliare",
    "miliasser": "miliare",
    "miliassero": "miliare",
    "miliassi": "miliare",
    "miliassimo": "miliare",
    "miliaste": "miliare",
    "miliasti": "miliare",
    "miliata": "miliare",
    "miliate": "miliare",
    "miliati": "miliare",
    "miliato": "miliare",
    "miliava": "miliare",
    "miliavamo": "miliare",
    "miliavan": "miliare",
    "miliavano": "miliare",
    "miliavate": "miliare",
    "miliavi": "miliare",
    "miliavo": "miliare",
    "milierai": "miliare",
    "milieran": "miliare",
    "milieranno": "miliare",
    "milierebbe": "miliare",
    "milierebber": "miliare",
    "milierebbero": "miliare",
    "milierei": "miliare",
    "milieremmo": "miliare",
    "milieremo": "miliare",
    "miliereste": "miliare",
    "milieresti": "miliare",
    "milierete": "miliare",
    "milierà": "miliare",
    "milierò": "miliare",
    "milin": "miliare",
    "milino": "miliare",
    "milio": "miliare",
    "milionari": "milionario",
    "milionaria": "milionario",
    "milionarie": "milionario",
    "milioni": "milione",
    "milita": "militare",
    "militai": "militare",
    "militammo": "militare",
    "militan": "militare",
    "militando": "militare",
    "militano": "militare",
    "militante": "militare",
    "militanti": "militare",
    "militanze": "militanza",
    "militar": "militare",
    "militaresca": "militaresco",
    "militaresche": "militaresco",
    "militareschi": "militaresco",
    "militari": "militare",
    "militarismi": "militarismo",
    "militariste": "militarista",
    "militaristi": "militarista",
    "militarizza": "militarizzare",
    "militarizzai": "militarizzare",
    "militarizzammo": "militarizzare",
    "militarizzan": "militarizzare",
    "militarizzando": "militarizzare",
    "militarizzano": "militarizzare",
    "militarizzante": "militarizzare",
    "militarizzanti": "militarizzare",
    "militarizzar": "militarizzare",
    "militarizzaron": "militarizzare",
    "militarizzarono": "militarizzare",
    "militarizzasse": "militarizzare",
    "militarizzasser": "militarizzare",
    "militarizzassero": "militarizzare",
    "militarizzassi": "militarizzare",
    "militarizzassimo": "militarizzare",
    "militarizzaste": "militarizzare",
    "militarizzasti": "militarizzare",
    "militarizzata": "militarizzare",
    "militarizzate": "militarizzare",
    "militarizzati": "militarizzare",
    "militarizzato": "militarizzare",
    "militarizzava": "militarizzare",
    "militarizzavamo": "militarizzare",
    "militarizzavan": "militarizzare",
    "militarizzavano": "militarizzare",
    "militarizzavate": "militarizzare",
    "militarizzavi": "militarizzare",
    "militarizzavo": "militarizzare",
    "militarizzazioni": "militarizzazione",
    "militarizzerai": "militarizzare",
    "militarizzeran": "militarizzare",
    "militarizzeranno": "militarizzare",
    "militarizzerebbe": "militarizzare",
    "militarizzerebber": "militarizzare",
    "militarizzerebbero": "militarizzare",
    "militarizzerei": "militarizzare",
    "militarizzeremmo": "militarizzare",
    "militarizzeremo": "militarizzare",
    "militarizzereste": "militarizzare",
    "militarizzeresti": "militarizzare",
    "militarizzerete": "militarizzare",
    "militarizzerà": "militarizzare",
    "militarizzerò": "militarizzare",
    "militarizzi": "militarizzare",
    "militarizziamo": "militarizzare",
    "militarizziate": "militarizzare",
    "militarizzin": "militarizzare",
    "militarizzino": "militarizzare",
    "militarizzo": "militarizzare",
    "militarizzò": "militarizzare",
    "militaron": "militare",
    "militarono": "militare",
    "militasse": "militare",
    "militasser": "militare",
    "militassero": "militare",
    "militassi": "militare",
    "militassimo": "militare",
    "militaste": "militare",
    "militasti": "militare",
    "militata": "militare",
    "militate": "militare",
    "militati": "militare",
    "militato": "militare",
    "militava": "militare",
    "militavamo": "militare",
    "militavan": "militare",
    "militavano": "militare",
    "militavate": "militare",
    "militavi": "militare",
    "militavo": "militare",
    "militerai": "militare",
    "militeran": "militare",
    "militeranno": "militare",
    "militerebbe": "militare",
    "militerebber": "militare",
    "militerebbero": "militare",
    "militerei": "militare",
    "militeremmo": "militare",
    "militeremo": "militare",
    "militereste": "militare",
    "militeresti": "militare",
    "militerete": "militare",
    "militerà": "militare",
    "militerò": "militare",
    "militi": "milite",
    "militiamo": "militare",
    "militiate": "militare",
    "militin": "militare",
    "militino": "militare",
    "milito": "militare",
    "militò": "militare",
    "miliziani": "miliziano",
    "milizie": "milizia",
    "miliò": "miliare",
    "millanta": "millantare",
    "millantai": "millantare",
    "millantammo": "millantare",
    "millantan": "millantare",
    "millantando": "millantare",
    "millantano": "millantare",
    "millantante": "millantare",
    "millantanti": "millantare",
    "millantar": "millantare",
    "millantaron": "millantare",
    "millantarono": "millantare",
    "millantasse": "millantare",
    "millantasser": "millantare",
    "millantassero": "millantare",
    "millantassi": "millantare",
    "millantassimo": "millantare",
    "millantaste": "millantare",
    "millantasti": "millantare",
    "millantata": "millantato",
    "millantate": "millantato",
    "millantati": "millantato",
    "millantato": "millantare",
    "millantatori": "millantatore",
    "millantatrice": "millantatore",
    "millantatrici": "millantatore",
    "millantava": "millantare",
    "millantavamo": "millantare",
    "millantavan": "millantare",
    "millantavano": "millantare",
    "millantavate": "millantare",
    "millantavi": "millantare",
    "millantavo": "millantare",
    "millanterai": "millantare",
    "millanteran": "millantare",
    "millanteranno": "millantare",
    "millanterebbe": "millantare",
    "millanterebber": "millantare",
    "millanterebbero": "millantare",
    "millanterei": "millantare",
    "millanteremmo": "millantare",
    "millanteremo": "millantare",
    "millantereste": "millantare",
    "millanteresti": "millantare",
    "millanterete": "millantare",
    "millanterie": "millanteria",
    "millanterà": "millantare",
    "millanterò": "millantare",
    "millanti": "millantare",
    "millantiamo": "millantare",
    "millantiate": "millantare",
    "millantin": "millantare",
    "millantino": "millantare",
    "millanto": "millantare",
    "millantò": "millantare",
    "millenari": "millenario",
    "millenaria": "millenario",
    "millenarie": "millenario",
    "millenni": "millennio",
    "millesima": "millesimo",
    "millesime": "millesimo",
    "millesimi": "millesimo",
    "millimetra": "millimetrare",
    "millimetrai": "millimetrare",
    "millimetrammo": "millimetrare",
    "millimetran": "millimetrare",
    "millimetrando": "millimetrare",
    "millimetrano": "millimetrare",
    "millimetrante": "millimetrare",
    "millimetranti": "millimetrare",
    "millimetrar": "millimetrare",
    "millimetraron": "millimetrare",
    "millimetrarono": "millimetrare",
    "millimetrasse": "millimetrare",
    "millimetrasser": "millimetrare",
    "millimetrassero": "millimetrare",
    "millimetrassi": "millimetrare",
    "millimetrassimo": "millimetrare",
    "millimetraste": "millimetrare",
    "millimetrasti": "millimetrare",
    "millimetrata": "millimetrato",
    "millimetrate": "millimetrato",
    "millimetrati": "millimetrato",
    "millimetrato": "millimetrare",
    "millimetrava": "millimetrare",
    "millimetravamo": "millimetrare",
    "millimetravan": "millimetrare",
    "millimetravano": "millimetrare",
    "millimetravate": "millimetrare",
    "millimetravi": "millimetrare",
    "millimetravo": "millimetrare",
    "millimetrerai": "millimetrare",
    "millimetreran": "millimetrare",
    "millimetreranno": "millimetrare",
    "millimetrerebbe": "millimetrare",
    "millimetrerebber": "millimetrare",
    "millimetrerebbero": "millimetrare",
    "millimetrerei": "millimetrare",
    "millimetreremmo": "millimetrare",
    "millimetreremo": "millimetrare",
    "millimetrereste": "millimetrare",
    "millimetreresti": "millimetrare",
    "millimetrerete": "millimetrare",
    "millimetrerà": "millimetrare",
    "millimetrerò": "millimetrare",
    "millimetri": "millimetro",
    "millimetriamo": "millimetrare",
    "millimetriate": "millimetrare",
    "millimetrica": "millimetrico",
    "millimetriche": "millimetrico",
    "millimetrici": "millimetrico",
    "millimetrin": "millimetrare",
    "millimetrino": "millimetrare",
    "millimetro": "millimetrare",
    "millimetrò": "millimetrare",
    "milze": "milza",
    "mima": "mimare",
    "mimai": "mimare",
    "mimammo": "mimare",
    "miman": "mimare",
    "mimando": "mimare",
    "mimano": "mimare",
    "mimante": "mimare",
    "mimanti": "mimare",
    "mimar": "mimare",
    "mimaron": "mimare",
    "mimarono": "mimare",
    "mimasse": "mimare",
    "mimasser": "mimare",
    "mimassero": "mimare",
    "mimassi": "mimare",
    "mimassimo": "mimare",
    "mimaste": "mimare",
    "mimasti": "mimare",
    "mimata": "mimare",
    "mimate": "mimare",
    "mimati": "mimare",
    "mimato": "mimare",
    "mimava": "mimare",
    "mimavamo": "mimare",
    "mimavan": "mimare",
    "mimavano": "mimare",
    "mimavate": "mimare",
    "mimavi": "mimare",
    "mimavo": "mimare",
    "mimerai": "mimare",
    "mimeran": "mimare",
    "mimeranno": "mimare",
    "mimerebbe": "mimare",
    "mimerebber": "mimare",
    "mimerebbero": "mimare",
    "mimerei": "mimare",
    "mimeremmo": "mimare",
    "mimeremo": "mimare",
    "mimereste": "mimare",
    "mimeresti": "mimare",
    "mimerete": "mimare",
    "mimerà": "mimare",
    "mimerò": "mimare",
    "mimetica": "mimetico",
    "mimetiche": "mimetico",
    "mimetici": "mimetico",
    "mimetismi": "mimetismo",
    "mimetizza": "mimetizzare",
    "mimetizzai": "mimetizzare",
    "mimetizzammo": "mimetizzare",
    "mimetizzan": "mimetizzare",
    "mimetizzando": "mimetizzare",
    "mimetizzano": "mimetizzare",
    "mimetizzante": "mimetizzare",
    "mimetizzanti": "mimetizzare",
    "mimetizzar": "mimetizzare",
    "mimetizzaron": "mimetizzare",
    "mimetizzarono": "mimetizzare",
    "mimetizzasse": "mimetizzare",
    "mimetizzasser": "mimetizzare",
    "mimetizzassero": "mimetizzare",
    "mimetizzassi": "mimetizzare",
    "mimetizzassimo": "mimetizzare",
    "mimetizzaste": "mimetizzare",
    "mimetizzasti": "mimetizzare",
    "mimetizzata": "mimetizzare",
    "mimetizzate": "mimetizzare",
    "mimetizzati": "mimetizzare",
    "mimetizzato": "mimetizzare",
    "mimetizzava": "mimetizzare",
    "mimetizzavamo": "mimetizzare",
    "mimetizzavan": "mimetizzare",
    "mimetizzavano": "mimetizzare",
    "mimetizzavate": "mimetizzare",
    "mimetizzavi": "mimetizzare",
    "mimetizzavo": "mimetizzare",
    "mimetizzazioni": "mimetizzazione",
    "mimetizzerai": "mimetizzare",
    "mimetizzeran": "mimetizzare",
    "mimetizzeranno": "mimetizzare",
    "mimetizzerebbe": "mimetizzare",
    "mimetizzerebber": "mimetizzare",
    "mimetizzerebbero": "mimetizzare",
    "mimetizzerei": "mimetizzare",
    "mimetizzeremmo": "mimetizzare",
    "mimetizzeremo": "mimetizzare",
    "mimetizzereste": "mimetizzare",
    "mimetizzeresti": "mimetizzare",
    "mimetizzerete": "mimetizzare",
    "mimetizzerà": "mimetizzare",
    "mimetizzerò": "mimetizzare",
    "mimetizzi": "mimetizzare",
    "mimetizziamo": "mimetizzare",
    "mimetizziate": "mimetizzare",
    "mimetizzin": "mimetizzare",
    "mimetizzino": "mimetizzare",
    "mimetizzo": "mimetizzare",
    "mimetizzò": "mimetizzare",
    "mimi": "mimo",
    "mimiamo": "mimare",
    "mimiate": "mimare",
    "mimica": "mimico",
    "mimiche": "mimico",
    "mimici": "mimico",
    "mimin": "mimare",
    "mimino": "mimare",
    "mimo": "mimare",
    "mimò": "mimare",
    "mina": "minare",
    "minacce": "minaccia",
    "minaccerai": "minacciare",
    "minacceran": "minacciare",
    "minacceranno": "minacciare",
    "minaccerebbe": "minacciare",
    "minaccerebber": "minacciare",
    "minaccerebbero": "minacciare",
    "minaccerei": "minacciare",
    "minacceremmo": "minacciare",
    "minacceremo": "minacciare",
    "minaccereste": "minacciare",
    "minacceresti": "minacciare",
    "minaccerete": "minacciare",
    "minaccerà": "minacciare",
    "minaccerò": "minacciare",
    "minacci": "minacciare",
    "minaccia": "minacciare",
    "minacciai": "minacciare",
    "minacciammo": "minacciare",
    "minacciamo": "minacciare",
    "minaccian": "minacciare",
    "minacciando": "minacciare",
    "minacciano": "minacciare",
    "minacciante": "minacciare",
    "minaccianti": "minacciare",
    "minacciar": "minacciare",
    "minacciaron": "minacciare",
    "minacciarono": "minacciare",
    "minacciasse": "minacciare",
    "minacciasser": "minacciare",
    "minacciassero": "minacciare",
    "minacciassi": "minacciare",
    "minacciassimo": "minacciare",
    "minacciaste": "minacciare",
    "minacciasti": "minacciare",
    "minacciata": "minacciare",
    "minacciate": "minacciata",
    "minacciati": "minacciare",
    "minacciato": "minacciare",
    "minacciava": "minacciare",
    "minacciavamo": "minacciare",
    "minacciavan": "minacciare",
    "minacciavano": "minacciare",
    "minacciavate": "minacciare",
    "minacciavi": "minacciare",
    "minacciavo": "minacciare",
    "minaccie": "minaccia",
    "minaccin": "minacciare",
    "minaccino": "minacciare",
    "minaccio": "minacciare",
    "minacciosa": "minaccioso",
    "minacciose": "minaccioso",
    "minacciosi": "minaccioso",
    "minacciò": "minacciare",
    "minai": "minare",
    "minammo": "minare",
    "minan": "minare",
    "minando": "minare",
    "minano": "minare",
    "minante": "minare",
    "minanti": "minare",
    "minar": "minare",
    "minareti": "minareto",
    "minaron": "minare",
    "minarono": "minare",
    "minasse": "minare",
    "minasser": "minare",
    "minassero": "minare",
    "minassi": "minare",
    "minassimo": "minare",
    "minaste": "minare",
    "minasti": "minare",
    "minata": "minare",
    "minate": "minare",
    "minati": "minare",
    "minato": "minare",
    "minatori": "minatorio",
    "minatoria": "minatorio",
    "minatorie": "minatorio",
    "minatrice": "minatore",
    "minatrici": "minatore",
    "minava": "minare",
    "minavamo": "minare",
    "minavan": "minare",
    "minavano": "minare",
    "minavate": "minare",
    "minavi": "minare",
    "minavo": "minare",
    "minchiona": "minchionare",
    "minchionai": "minchionare",
    "minchionammo": "minchionare",
    "minchionan": "minchionare",
    "minchionando": "minchionare",
    "minchionano": "minchionare",
    "minchionante": "minchionare",
    "minchionanti": "minchionare",
    "minchionar": "minchionare",
    "minchionaron": "minchionare",
    "minchionarono": "minchionare",
    "minchionasse": "minchionare",
    "minchionasser": "minchionare",
    "minchionassero": "minchionare",
    "minchionassi": "minchionare",
    "minchionassimo": "minchionare",
    "minchionaste": "minchionare",
    "minchionasti": "minchionare",
    "minchionata": "minchionare",
    "minchionate": "minchionare",
    "minchionati": "minchionare",
    "minchionato": "minchionare",
    "minchionava": "minchionare",
    "minchionavamo": "minchionare",
    "minchionavan": "minchionare",
    "minchionavano": "minchionare",
    "minchionavate": "minchionare",
    "minchionavi": "minchionare",
    "minchionavo": "minchionare",
    "minchionerai": "minchionare",
    "minchioneran": "minchionare",
    "minchioneranno": "minchionare",
    "minchionerebbe": "minchionare",
    "minchionerebber": "minchionare",
    "minchionerebbero": "minchionare",
    "minchionerei": "minchionare",
    "minchioneremmo": "minchionare",
    "minchioneremo": "minchionare",
    "minchionereste": "minchionare",
    "minchioneresti": "minchionare",
    "minchionerete": "minchionare",
    "minchionerà": "minchionare",
    "minchionerò": "minchionare",
    "minchioni": "minchione",
    "minchioniamo": "minchionare",
    "minchioniate": "minchionare",
    "minchionin": "minchionare",
    "minchionino": "minchionare",
    "minchiono": "minchionare",
    "minchionò": "minchionare",
    "mine": "mina",
    "minerai": "minare",
    "minerali": "minerale",
    "mineralizza": "mineralizzare",
    "mineralizzai": "mineralizzare",
    "mineralizzammo": "mineralizzare",
    "mineralizzan": "mineralizzare",
    "mineralizzando": "mineralizzare",
    "mineralizzano": "mineralizzare",
    "mineralizzante": "mineralizzare",
    "mineralizzanti": "mineralizzare",
    "mineralizzar": "mineralizzare",
    "mineralizzaron": "mineralizzare",
    "mineralizzarono": "mineralizzare",
    "mineralizzasse": "mineralizzare",
    "mineralizzasser": "mineralizzare",
    "mineralizzassero": "mineralizzare",
    "mineralizzassi": "mineralizzare",
    "mineralizzassimo": "mineralizzare",
    "mineralizzaste": "mineralizzare",
    "mineralizzasti": "mineralizzare",
    "mineralizzata": "mineralizzare",
    "mineralizzate": "mineralizzare",
    "mineralizzati": "mineralizzare",
    "mineralizzato": "mineralizzare",
    "mineralizzava": "mineralizzare",
    "mineralizzavamo": "mineralizzare",
    "mineralizzavan": "mineralizzare",
    "mineralizzavano": "mineralizzare",
    "mineralizzavate": "mineralizzare",
    "mineralizzavi": "mineralizzare",
    "mineralizzavo": "mineralizzare",
    "mineralizzerai": "mineralizzare",
    "mineralizzeran": "mineralizzare",
    "mineralizzeranno": "mineralizzare",
    "mineralizzerebbe": "mineralizzare",
    "mineralizzerebber": "mineralizzare",
    "mineralizzerebbero": "mineralizzare",
    "mineralizzerei": "mineralizzare",
    "mineralizzeremmo": "mineralizzare",
    "mineralizzeremo": "mineralizzare",
    "mineralizzereste": "mineralizzare",
    "mineralizzeresti": "mineralizzare",
    "mineralizzerete": "mineralizzare",
    "mineralizzerà": "mineralizzare",
    "mineralizzerò": "mineralizzare",
    "mineralizzi": "mineralizzare",
    "mineralizziamo": "mineralizzare",
    "mineralizziate": "mineralizzare",
    "mineralizzin": "mineralizzare",
    "mineralizzino": "mineralizzare",
    "mineralizzo": "mineralizzare",
    "mineralizzò": "mineralizzare",
    "mineran": "minare",
    "mineranno": "minare",
    "minerari": "minerario",
    "mineraria": "minerario",
    "minerarie": "minerario",
    "minerebbe": "minare",
    "minerebber": "minare",
    "minerebbero": "minare",
    "minerei": "minare",
    "mineremmo": "minare",
    "mineremo": "minare",
    "minereste": "minare",
    "mineresti": "minare",
    "minerete": "minare",
    "minerà": "minare",
    "minerò": "minare",
    "minestre": "minestra",
    "minestrine": "minestrina",
    "minestroni": "minestrone",
    "minga": "mingere",
    "mingan": "mingere",
    "mingano": "mingere",
    "minge": "mingere",
    "mingemmo": "mingere",
    "mingendo": "mingere",
    "mingente": "mingere",
    "mingenti": "mingere",
    "minger": "mingere",
    "mingerai": "mingere",
    "mingeran": "mingere",
    "mingeranno": "mingere",
    "mingerebbe": "mingere",
    "mingerebber": "mingere",
    "mingerebbero": "mingere",
    "mingerei": "mingere",
    "mingeremmo": "mingere",
    "mingeremo": "mingere",
    "mingereste": "mingere",
    "mingeresti": "mingere",
    "mingerete": "mingere",
    "mingerà": "mingere",
    "mingerò": "mingere",
    "mingesse": "mingere",
    "mingesser": "mingere",
    "mingessero": "mingere",
    "mingessi": "mingere",
    "mingessimo": "mingere",
    "mingeste": "mingere",
    "mingesti": "mingere",
    "mingete": "mingere",
    "mingeva": "mingere",
    "mingevamo": "mingere",
    "mingevan": "mingere",
    "mingevano": "mingere",
    "mingevate": "mingere",
    "mingevi": "mingere",
    "mingevo": "mingere",
    "mingherlina": "mingherlino",
    "mingherline": "mingherlino",
    "mingherlini": "mingherlino",
    "mingi": "mingere",
    "mingiamo": "mingere",
    "mingiate": "mingere",
    "mingo": "mingere",
    "mingon": "mingere",
    "mingono": "mingere",
    "mini": "miniare",
    "mini-riforme": "mini-riforma",
    "mini-vertici": "mini-vertice",
    "minia": "miniare",
    "miniabiti": "miniabito",
    "miniai": "miniare",
    "miniammo": "miniare",
    "miniamo": "miniare",
    "minian": "miniare",
    "miniando": "miniare",
    "miniano": "miniare",
    "miniante": "miniare",
    "minianti": "miniare",
    "miniappartamenti": "miniappartamento",
    "miniar": "miniare",
    "miniaron": "miniare",
    "miniarono": "miniare",
    "miniasse": "miniare",
    "miniasser": "miniare",
    "miniassero": "miniare",
    "miniassi": "miniare",
    "miniassimo": "miniare",
    "miniaste": "miniare",
    "miniasti": "miniare",
    "miniata": "miniare",
    "miniate": "miniare",
    "miniati": "miniare",
    "miniato": "miniare",
    "miniatori": "miniatore",
    "miniature": "miniatura",
    "miniaturizza": "miniaturizzare",
    "miniaturizzai": "miniaturizzare",
    "miniaturizzammo": "miniaturizzare",
    "miniaturizzan": "miniaturizzare",
    "miniaturizzando": "miniaturizzare",
    "miniaturizzano": "miniaturizzare",
    "miniaturizzante": "miniaturizzare",
    "miniaturizzanti": "miniaturizzare",
    "miniaturizzar": "miniaturizzare",
    "miniaturizzaron": "miniaturizzare",
    "miniaturizzarono": "miniaturizzare",
    "miniaturizzasse": "miniaturizzare",
    "miniaturizzasser": "miniaturizzare",
    "miniaturizzassero": "miniaturizzare",
    "miniaturizzassi": "miniaturizzare",
    "miniaturizzassimo": "miniaturizzare",
    "miniaturizzaste": "miniaturizzare",
    "miniaturizzasti": "miniaturizzare",
    "miniaturizzata": "miniaturizzare",
    "miniaturizzate": "miniaturizzare",
    "miniaturizzati": "miniaturizzare",
    "miniaturizzato": "miniaturizzare",
    "miniaturizzava": "miniaturizzare",
    "miniaturizzavamo": "miniaturizzare",
    "miniaturizzavan": "miniaturizzare",
    "miniaturizzavano": "miniaturizzare",
    "miniaturizzavate": "miniaturizzare",
    "miniaturizzavi": "miniaturizzare",
    "miniaturizzavo": "miniaturizzare",
    "miniaturizzazioni": "miniaturizzazione",
    "miniaturizzerai": "miniaturizzare",
    "miniaturizzeran": "miniaturizzare",
    "miniaturizzeranno": "miniaturizzare",
    "miniaturizzerebbe": "miniaturizzare",
    "miniaturizzerebber": "miniaturizzare",
    "miniaturizzerebbero": "miniaturizzare",
    "miniaturizzerei": "miniaturizzare",
    "miniaturizzeremmo": "miniaturizzare",
    "miniaturizzeremo": "miniaturizzare",
    "miniaturizzereste": "miniaturizzare",
    "miniaturizzeresti": "miniaturizzare",
    "miniaturizzerete": "miniaturizzare",
    "miniaturizzerà": "miniaturizzare",
    "miniaturizzerò": "miniaturizzare",
    "miniaturizzi": "miniaturizzare",
    "miniaturizziamo": "miniaturizzare",
    "miniaturizziate": "miniaturizzare",
    "miniaturizzin": "miniaturizzare",
    "miniaturizzino": "miniaturizzare",
    "miniaturizzo": "miniaturizzare",
    "miniaturizzò": "miniaturizzare",
    "miniava": "miniare",
    "miniavamo": "miniare",
    "miniavan": "miniare",
    "miniavano": "miniare",
    "miniavate": "miniare",
    "miniavi": "miniare",
    "miniavo": "miniare",
    "minierai": "miniare",
    "minieran": "miniare",
    "minieranno": "miniare",
    "miniere": "miniera",
    "minierebbe": "miniare",
    "minierebber": "miniare",
    "minierebbero": "miniare",
    "minierei": "miniare",
    "minieremmo": "miniare",
    "minieremo": "miniare",
    "miniereste": "miniare",
    "minieresti": "miniare",
    "minierete": "miniare",
    "minierà": "miniare",
    "minierò": "miniare",
    "minigonne": "minigonna",
    "minima": "piccolo",
    "minimali": "minimale",
    "minimalismi": "minimalismo",
    "minimaliste": "minimalista",
    "minimalisti": "minimalista",
    "minime": "piccolo",
    "minimi": "piccolo",
    "minimizza": "minimizzare",
    "minimizzai": "minimizzare",
    "minimizzammo": "minimizzare",
    "minimizzan": "minimizzare",
    "minimizzando": "minimizzare",
    "minimizzano": "minimizzare",
    "minimizzante": "minimizzare",
    "minimizzanti": "minimizzare",
    "minimizzar": "minimizzare",
    "minimizzaron": "minimizzare",
    "minimizzarono": "minimizzare",
    "minimizzasse": "minimizzare",
    "minimizzasser": "minimizzare",
    "minimizzassero": "minimizzare",
    "minimizzassi": "minimizzare",
    "minimizzassimo": "minimizzare",
    "minimizzaste": "minimizzare",
    "minimizzasti": "minimizzare",
    "minimizzata": "minimizzare",
    "minimizzate": "minimizzare",
    "minimizzati": "minimizzare",
    "minimizzato": "minimizzare",
    "minimizzava": "minimizzare",
    "minimizzavamo": "minimizzare",
    "minimizzavan": "minimizzare",
    "minimizzavano": "minimizzare",
    "minimizzavate": "minimizzare",
    "minimizzavi": "minimizzare",
    "minimizzavo": "minimizzare",
    "minimizzazioni": "minimizzazione",
    "minimizzerai": "minimizzare",
    "minimizzeran": "minimizzare",
    "minimizzeranno": "minimizzare",
    "minimizzerebbe": "minimizzare",
    "minimizzerebber": "minimizzare",
    "minimizzerebbero": "minimizzare",
    "minimizzerei": "minimizzare",
    "minimizzeremmo": "minimizzare",
    "minimizzeremo": "minimizzare",
    "minimizzereste": "minimizzare",
    "minimizzeresti": "minimizzare",
    "minimizzerete": "minimizzare",
    "minimizzerà": "minimizzare",
    "minimizzerò": "minimizzare",
    "minimizzi": "minimizzare",
    "minimizziamo": "minimizzare",
    "minimizziate": "minimizzare",
    "minimizzin": "minimizzare",
    "minimizzino": "minimizzare",
    "minimizzo": "minimizzare",
    "minimizzò": "minimizzare",
    "minimo": "piccolo",
    "minin": "miniare",
    "minino": "miniare",
    "minio": "miniare",
    "miniriforme": "miniriforma",
    "ministeri": "ministero",
    "ministeriali": "ministeriale",
    "ministra": "ministrare",
    "ministrai": "ministrare",
    "ministrammo": "ministrare",
    "ministran": "ministrare",
    "ministrando": "ministrare",
    "ministrano": "ministrare",
    "ministrante": "ministrare",
    "ministranti": "ministrare",
    "ministrar": "ministrare",
    "ministraron": "ministrare",
    "ministrarono": "ministrare",
    "ministrasse": "ministrare",
    "ministrasser": "ministrare",
    "ministrassero": "ministrare",
    "ministrassi": "ministrare",
    "ministrassimo": "ministrare",
    "ministraste": "ministrare",
    "ministrasti": "ministrare",
    "ministrata": "ministrare",
    "ministrate": "ministrare",
    "ministrati": "ministrare",
    "ministrato": "ministrare",
    "ministrava": "ministrare",
    "ministravamo": "ministrare",
    "ministravan": "ministrare",
    "ministravano": "ministrare",
    "ministravate": "ministrare",
    "ministravi": "ministrare",
    "ministravo": "ministrare",
    "ministre": "ministra",
    "ministrerai": "ministrare",
    "ministreran": "ministrare",
    "ministreranno": "ministrare",
    "ministrerebbe": "ministrare",
    "ministrerebber": "ministrare",
    "ministrerebbero": "ministrare",
    "ministrerei": "ministrare",
    "ministreremmo": "ministrare",
    "ministreremo": "ministrare",
    "ministrereste": "ministrare",
    "ministreresti": "ministrare",
    "ministrerete": "ministrare",
    "ministrerà": "ministrare",
    "ministrerò": "ministrare",
    "ministri": "ministro",
    "ministri-ombra": "ministro-ombra",
    "ministriamo": "ministrare",
    "ministriate": "ministrare",
    "ministrin": "ministrare",
    "ministrino": "ministrare",
    "ministro": "ministrare",
    "ministrò": "ministrare",
    "minivertici": "minivertice",
    "miniò": "miniare",
    "mino": "minare",
    "minoica": "minoico",
    "minoiche": "minoico",
    "minoici": "minoico",
    "minora": "minorare",
    "minorai": "minorare",
    "minorammo": "minorare",
    "minoran": "minorare",
    "minorando": "minorare",
    "minorano": "minorare",
    "minorante": "minorare",
    "minoranti": "minorare",
    "minoranze": "minoranza",
    "minorar": "minorare",
    "minoraron": "minorare",
    "minorarono": "minorare",
    "minorasse": "minorare",
    "minorasser": "minorare",
    "minorassero": "minorare",
    "minorassi": "minorare",
    "minorassimo": "minorare",
    "minoraste": "minorare",
    "minorasti": "minorare",
    "minorata": "minorare",
    "minorate": "minorare",
    "minorati": "minorato",
    "minorato": "minorare",
    "minorava": "minorare",
    "minoravamo": "minorare",
    "minoravan": "minorare",
    "minoravano": "minorare",
    "minoravate": "minorare",
    "minoravi": "minorare",
    "minoravo": "minorare",
    "minorazioni": "minorazione",
    "minore": "piccolo",
    "minorenni": "minorenne",
    "minorerai": "minorare",
    "minoreran": "minorare",
    "minoreranno": "minorare",
    "minorerebbe": "minorare",
    "minorerebber": "minorare",
    "minorerebbero": "minorare",
    "minorerei": "minorare",
    "minoreremmo": "minorare",
    "minoreremo": "minorare",
    "minorereste": "minorare",
    "minoreresti": "minorare",
    "minorerete": "minorare",
    "minorerà": "minorare",
    "minorerò": "minorare",
    "minori": "piccolo",
    "minoriamo": "minorare",
    "minoriate": "minorare",
    "minorili": "minorile",
    "minorin": "minorare",
    "minorino": "minorare",
    "minoritari": "minoritario",
    "minoritaria": "minoritario",
    "minoritarie": "minoritario",
    "minoro": "minorare",
    "minorò": "minorare",
    "minser": "mingere",
    "minsero": "mingere",
    "minsi": "mingere",
    "minsè": "mingere",
    "minta": "mingere",
    "minte": "mingere",
    "minti": "mingere",
    "minto": "mingere",
    "minuetti": "minuetto",
    "minuscola": "minuscolo",
    "minuscole": "minuscolo",
    "minuscoli": "minuscolo",
    "minusvalenze": "minusvalenza",
    "minuta": "minuto",
    "minutaglie": "minutaglia",
    "minute": "minuto",
    "minuterie": "minuteria",
    "minuti": "minuto",
    "minuzie": "minuzia",
    "minuziosa": "minuzioso",
    "minuziose": "minuzioso",
    "minuziosi": "minuzioso",
    "minò": "minare",
    "miocardiopatie": "miocardiopatia",
    "miopi": "miope",
    "miopie": "miopia",
    "mira": "miro",
    "mirabili": "mirabile",
    "mirabolanti": "mirabolante",
    "miracolata": "miracolato",
    "miracolate": "miracolato",
    "miracolati": "miracolato",
    "miracoli": "miracolo",
    "miracolosa": "miracoloso",
    "miracolose": "miracoloso",
    "miracolosi": "miracoloso",
    "miraggi": "miraggio",
    "mirai": "mirare",
    "mirammo": "mirare",
    "miran": "mirare",
    "mirando": "mirare",
    "mirano": "mirare",
    "mirante": "mirare",
    "miranti": "mirare",
    "mirar": "mirare",
    "miraron": "mirare",
    "mirarono": "mirare",
    "mirasse": "mirare",
    "mirasser": "mirare",
    "mirassero": "mirare",
    "mirassi": "mirare",
    "mirassimo": "mirare",
    "miraste": "mirare",
    "mirasti": "mirare",
    "mirata": "mirato",
    "mirate": "mirato",
    "mirati": "mirato",
    "mirato": "mirare",
    "mirava": "mirare",
    "miravamo": "mirare",
    "miravan": "mirare",
    "miravano": "mirare",
    "miravate": "mirare",
    "miravi": "mirare",
    "miravo": "mirare",
    "mire": "miro",
    "mirerai": "mirare",
    "mireran": "mirare",
    "mireranno": "mirare",
    "mirerebbe": "mirare",
    "mirerebber": "mirare",
    "mirerebbero": "mirare",
    "mirerei": "mirare",
    "mireremmo": "mirare",
    "mireremo": "mirare",
    "mirereste": "mirare",
    "mireresti": "mirare",
    "mirerete": "mirare",
    "mirerà": "mirare",
    "mirerò": "mirare",
    "miri": "miro",
    "miriadi": "miriade",
    "miriamo": "mirare",
    "miriate": "mirare",
    "mirin": "mirare",
    "mirini": "mirino",
    "mirino": "mirare",
    "miro": "mirare",
    "mirti": "mirto",
    "mirtilli": "mirtillo",
    "mirò": "mirare",
    "misantropi": "misantropo",
    "misantropica": "misantropico",
    "misantropiche": "misantropico",
    "misantropici": "misantropico",
    "misantropie": "misantropia",
    "miscela": "miscelare",
    "miscelai": "miscelare",
    "miscelammo": "miscelare",
    "miscelan": "miscelare",
    "miscelando": "miscelare",
    "miscelano": "miscelare",
    "miscelante": "miscelare",
    "miscelanti": "miscelare",
    "miscelar": "miscelare",
    "miscelaron": "miscelare",
    "miscelarono": "miscelare",
    "miscelasse": "miscelare",
    "miscelasser": "miscelare",
    "miscelassero": "miscelare",
    "miscelassi": "miscelare",
    "miscelassimo": "miscelare",
    "miscelaste": "miscelare",
    "miscelasti": "miscelare",
    "miscelata": "miscelare",
    "miscelate": "miscelare",
    "miscelati": "miscelare",
    "miscelato": "miscelare",
    "miscelava": "miscelare",
    "miscelavamo": "miscelare",
    "miscelavan": "miscelare",
    "miscelavano": "miscelare",
    "miscelavate": "miscelare",
    "miscelavi": "miscelare",
    "miscelavo": "miscelare",
    "miscele": "miscela",
    "miscelerai": "miscelare",
    "misceleran": "miscelare",
    "misceleranno": "miscelare",
    "miscelerebbe": "miscelare",
    "miscelerebber": "miscelare",
    "miscelerebbero": "miscelare",
    "miscelerei": "miscelare",
    "misceleremmo": "miscelare",
    "misceleremo": "miscelare",
    "miscelereste": "miscelare",
    "misceleresti": "miscelare",
    "miscelerete": "miscelare",
    "miscelerà": "miscelare",
    "miscelerò": "miscelare",
    "misceli": "miscelare",
    "misceliamo": "miscelare",
    "misceliate": "miscelare",
    "miscelin": "miscelare",
    "miscelino": "miscelare",
    "miscellanea": "miscellaneo",
    "miscellanee": "miscellaneo",
    "miscellanei": "miscellaneo",
    "miscelo": "miscelare",
    "miscelò": "miscelare",
    "mischi": "mischiare",
    "mischia": "mischiare",
    "mischiai": "mischiare",
    "mischiammo": "mischiare",
    "mischiamo": "mischiare",
    "mischian": "mischiare",
    "mischiando": "mischiare",
    "mischiano": "mischiare",
    "mischiante": "mischiare",
    "mischianti": "mischiare",
    "mischiar": "mischiare",
    "mischiaron": "mischiare",
    "mischiarono": "mischiare",
    "mischiasse": "mischiare",
    "mischiasser": "mischiare",
    "mischiassero": "mischiare",
    "mischiassi": "mischiare",
    "mischiassimo": "mischiare",
    "mischiaste": "mischiare",
    "mischiasti": "mischiare",
    "mischiata": "mischiare",
    "mischiate": "mischiare",
    "mischiati": "mischiare",
    "mischiato": "mischiare",
    "mischiava": "mischiare",
    "mischiavamo": "mischiare",
    "mischiavan": "mischiare",
    "mischiavano": "mischiare",
    "mischiavate": "mischiare",
    "mischiavi": "mischiare",
    "mischiavo": "mischiare",
    "mischie": "mischia",
    "mischierai": "mischiare",
    "mischieran": "mischiare",
    "mischieranno": "mischiare",
    "mischierebbe": "mischiare",
    "mischierebber": "mischiare",
    "mischierebbero": "mischiare",
    "mischierei": "mischiare",
    "mischieremmo": "mischiare",
    "mischieremo": "mischiare",
    "mischiereste": "mischiare",
    "mischieresti": "mischiare",
    "mischierete": "mischiare",
    "mischierà": "mischiare",
    "mischierò": "mischiare",
    "mischin": "mischiare",
    "mischino": "mischiare",
    "mischio": "mischiare",
    "mischiò": "mischiare",
    "misconobbe": "misconoscere",
    "misconobber": "misconoscere",
    "misconobbero": "misconoscere",
    "misconobbi": "misconoscere",
    "misconosca": "misconoscere",
    "misconoscan": "misconoscere",
    "misconoscano": "misconoscere",
    "misconosce": "misconoscere",
    "misconoscemmo": "misconoscere",
    "misconoscendo": "misconoscere",
    "misconoscente": "misconoscere",
    "misconoscenti": "misconoscere",
    "misconoscer": "misconoscere",
    "misconoscerai": "misconoscere",
    "misconosceran": "misconoscere",
    "misconosceranno": "misconoscere",
    "misconoscerebbe": "misconoscere",
    "misconoscerebber": "misconoscere",
    "misconoscerebbero": "misconoscere",
    "misconoscerei": "misconoscere",
    "misconosceremmo": "misconoscere",
    "misconosceremo": "misconoscere",
    "misconoscereste": "misconoscere",
    "misconosceresti": "misconoscere",
    "misconoscerete": "misconoscere",
    "misconoscerà": "misconoscere",
    "misconoscerò": "misconoscere",
    "misconoscesse": "misconoscere",
    "misconoscesser": "misconoscere",
    "misconoscessero": "misconoscere",
    "misconoscessi": "misconoscere",
    "misconoscessimo": "misconoscere",
    "misconosceste": "misconoscere",
    "misconoscesti": "misconoscere",
    "misconoscete": "misconoscere",
    "misconosceva": "misconoscere",
    "misconoscevamo": "misconoscere",
    "misconoscevan": "misconoscere",
    "misconoscevano": "misconoscere",
    "misconoscevate": "misconoscere",
    "misconoscevi": "misconoscere",
    "misconoscevo": "misconoscere",
    "misconosci": "misconoscere",
    "misconosciamo": "misconoscere",
    "misconosciate": "misconoscere",
    "misconosciuta": "misconoscere",
    "misconosciute": "misconoscere",
    "misconosciuti": "misconoscere",
    "misconosciuto": "misconoscere",
    "misconosco": "misconoscere",
    "misconoscon": "misconoscere",
    "misconoscono": "misconoscere",
    "miscredenti": "miscredente",
    "miscugli": "miscuglio",
    "mise": "mettere",
    "miser": "mettere",
    "misera": "misero",
    "miserabili": "miserabile",
    "miseranda": "miserando",
    "miserande": "miserando",
    "miserandi": "miserando",
    "misere": "misero",
    "miserevoli": "miserevole",
    "miseri": "misero",
    "misericordie": "misericordia",
    "misericordiosa": "misericordioso",
    "misericordiose": "misericordioso",
    "misericordiosi": "misericordioso",
    "miserie": "miseria",
    "misero": "mettere",
    "miserrima": "miserrimo",
    "miserrime": "miserrimo",
    "miserrimi": "miserrimo",
    "misfatti": "misfatto",
    "misi": "mettere",
    "misogina": "misogino",
    "misogine": "misogino",
    "misogini": "misogino",
    "misoginie": "misoginia",
    "missaggi": "missaggio",
    "missili": "missile",
    "missilistica": "missilistico",
    "missilistiche": "missilistico",
    "missilistici": "missilistico",
    "missina": "missino",
    "missine": "missino",
    "missini": "missino",
    "missionari": "missionario",
    "missionaria": "missionario",
    "missionarie": "missionario",
    "missioni": "missione",
    "missive": "missiva",
    "mista": "misto",
    "miste": "misto",
    "misteri": "mistero",
    "misteriosa": "misterioso",
    "misteriose": "misterioso",
    "misteriosi": "misterioso",
    "misti": "misto",
    "mistica": "mistico",
    "mistiche": "mistico",
    "mistici": "mistico",
    "misticismi": "misticismo",
    "mistifica": "mistificare",
    "mistificai": "mistificare",
    "mistificammo": "mistificare",
    "mistifican": "mistificare",
    "mistificando": "mistificare",
    "mistificano": "mistificare",
    "mistificante": "mistificare",
    "mistificanti": "mistificare",
    "mistificar": "mistificare",
    "mistificaron": "mistificare",
    "mistificarono": "mistificare",
    "mistificasse": "mistificare",
    "mistificasser": "mistificare",
    "mistificassero": "mistificare",
    "mistificassi": "mistificare",
    "mistificassimo": "mistificare",
    "mistificaste": "mistificare",
    "mistificasti": "mistificare",
    "mistificata": "mistificare",
    "mistificate": "mistificare",
    "mistificati": "mistificare",
    "mistificato": "mistificare",
    "mistificatori": "mistificatorio",
    "mistificatoria": "mistificatorio",
    "mistificatorie": "mistificatorio",
    "mistificatrice": "mistificatore",
    "mistificatrici": "mistificatore",
    "mistificava": "mistificare",
    "mistificavamo": "mistificare",
    "mistificavan": "mistificare",
    "mistificavano": "mistificare",
    "mistificavate": "mistificare",
    "mistificavi": "mistificare",
    "mistificavo": "mistificare",
    "mistificazioni": "mistificazione",
    "mistificherai": "mistificare",
    "mistificheran": "mistificare",
    "mistificheranno": "mistificare",
    "mistificherebbe": "mistificare",
    "mistificherebber": "mistificare",
    "mistificherebbero": "mistificare",
    "mistificherei": "mistificare",
    "mistificheremmo": "mistificare",
    "mistificheremo": "mistificare",
    "mistifichereste": "mistificare",
    "mistificheresti": "mistificare",
    "mistificherete": "mistificare",
    "mistificherà": "mistificare",
    "mistificherò": "mistificare",
    "mistifichi": "mistificare",
    "mistifichiamo": "mistificare",
    "mistifichiate": "mistificare",
    "mistifichin": "mistificare",
    "mistifichino": "mistificare",
    "mistifico": "mistificare",
    "mistificò": "mistificare",
    "misture": "mistura",
    "misura": "misurare",
    "misurabili": "misurabile",
    "misurai": "misurare",
    "misurammo": "misurare",
    "misuran": "misurare",
    "misurando": "misurare",
    "misurano": "misurare",
    "misurante": "misurare",
    "misuranti": "misurare",
    "misurar": "misurare",
    "misuraron": "misurare",
    "misurarono": "misurare",
    "misurasse": "misurare",
    "misurasser": "misurare",
    "misurassero": "misurare",
    "misurassi": "misurare",
    "misurassimo": "misurare",
    "misuraste": "misurare",
    "misurasti": "misurare",
    "misurata": "misurato",
    "misurate": "misurato",
    "misurati": "misurato",
    "misurato": "misurare",
    "misuratori": "misuratore",
    "misurava": "misurare",
    "misuravamo": "misurare",
    "misuravan": "misurare",
    "misuravano": "misurare",
    "misuravate": "misurare",
    "misuravi": "misurare",
    "misuravo": "misurare",
    "misurazioni": "misurazione",
    "misure": "misura",
    "misurerai": "misurare",
    "misureran": "misurare",
    "misureranno": "misurare",
    "misurerebbe": "misurare",
    "misurerebber": "misurare",
    "misurerebbero": "misurare",
    "misurerei": "misurare",
    "misureremmo": "misurare",
    "misureremo": "misurare",
    "misurereste": "misurare",
    "misureresti": "misurare",
    "misurerete": "misurare",
    "misurerà": "misurare",
    "misurerò": "misurare",
    "misuri": "misurare",
    "misuriamo": "misurare",
    "misuriate": "misurare",
    "misurin": "misurare",
    "misurino": "misurare",
    "misuro": "misurare",
    "misurò": "misurare",
    "mitezze": "mitezza",
    "miti": "mito",
    "mitica": "mitico",
    "mitiche": "mitico",
    "mitici": "mitico",
    "miticizza": "miticizzare",
    "miticizzai": "miticizzare",
    "miticizzammo": "miticizzare",
    "miticizzan": "miticizzare",
    "miticizzando": "miticizzare",
    "miticizzano": "miticizzare",
    "miticizzante": "miticizzare",
    "miticizzanti": "miticizzare",
    "miticizzar": "miticizzare",
    "miticizzaron": "miticizzare",
    "miticizzarono": "miticizzare",
    "miticizzasse": "miticizzare",
    "miticizzasser": "miticizzare",
    "miticizzassero": "miticizzare",
    "miticizzassi": "miticizzare",
    "miticizzassimo": "miticizzare",
    "miticizzaste": "miticizzare",
    "miticizzasti": "miticizzare",
    "miticizzata": "miticizzare",
    "miticizzate": "miticizzare",
    "miticizzati": "miticizzare",
    "miticizzato": "miticizzare",
    "miticizzava": "miticizzare",
    "miticizzavamo": "miticizzare",
    "miticizzavan": "miticizzare",
    "miticizzavano": "miticizzare",
    "miticizzavate": "miticizzare",
    "miticizzavi": "miticizzare",
    "miticizzavo": "miticizzare",
    "miticizzerai": "miticizzare",
    "miticizzeran": "miticizzare",
    "miticizzeranno": "miticizzare",
    "miticizzerebbe": "miticizzare",
    "miticizzerebber": "miticizzare",
    "miticizzerebbero": "miticizzare",
    "miticizzerei": "miticizzare",
    "miticizzeremmo": "miticizzare",
    "miticizzeremo": "miticizzare",
    "miticizzereste": "miticizzare",
    "miticizzeresti": "miticizzare",
    "miticizzerete": "miticizzare",
    "miticizzerà": "miticizzare",
    "miticizzerò": "miticizzare",
    "miticizzi": "miticizzare",
    "miticizziamo": "miticizzare",
    "miticizziate": "miticizzare",
    "miticizzin": "miticizzare",
    "miticizzino": "miticizzare",
    "miticizzo": "miticizzare",
    "miticizzò": "miticizzare",
    "mitiga": "mitigare",
    "mitigai": "mitigare",
    "mitigammo": "mitigare",
    "mitigan": "mitigare",
    "mitigando": "mitigare",
    "mitigano": "mitigare",
    "mitigante": "mitigare",
    "mitiganti": "mitigare",
    "mitigar": "mitigare",
    "mitigaron": "mitigare",
    "mitigarono": "mitigare",
    "mitigasse": "mitigare",
    "mitigasser": "mitigare",
    "mitigassero": "mitigare",
    "mitigassi": "mitigare",
    "mitigassimo": "mitigare",
    "mitigaste": "mitigare",
    "mitigasti": "mitigare",
    "mitigata": "mitigare",
    "mitigate": "mitigare",
    "mitigati": "mitigare",
    "mitigato": "mitigare",
    "mitigava": "mitigare",
    "mitigavamo": "mitigare",
    "mitigavan": "mitigare",
    "mitigavano": "mitigare",
    "mitigavate": "mitigare",
    "mitigavi": "mitigare",
    "mitigavo": "mitigare",
    "mitigherai": "mitigare",
    "mitigheran": "mitigare",
    "mitigheranno": "mitigare",
    "mitigherebbe": "mitigare",
    "mitigherebber": "mitigare",
    "mitigherebbero": "mitigare",
    "mitigherei": "mitigare",
    "mitigheremmo": "mitigare",
    "mitigheremo": "mitigare",
    "mitighereste": "mitigare",
    "mitigheresti": "mitigare",
    "mitigherete": "mitigare",
    "mitigherà": "mitigare",
    "mitigherò": "mitigare",
    "mitighi": "mitigare",
    "mitighiamo": "mitigare",
    "mitighiate": "mitigare",
    "mitighin": "mitigare",
    "mitighino": "mitigare",
    "mitigo": "mitigare",
    "mitigò": "mitigare",
    "mitizza": "mitizzare",
    "mitizzai": "mitizzare",
    "mitizzammo": "mitizzare",
    "mitizzan": "mitizzare",
    "mitizzando": "mitizzare",
    "mitizzano": "mitizzare",
    "mitizzante": "mitizzare",
    "mitizzanti": "mitizzare",
    "mitizzar": "mitizzare",
    "mitizzaron": "mitizzare",
    "mitizzarono": "mitizzare",
    "mitizzasse": "mitizzare",
    "mitizzasser": "mitizzare",
    "mitizzassero": "mitizzare",
    "mitizzassi": "mitizzare",
    "mitizzassimo": "mitizzare",
    "mitizzaste": "mitizzare",
    "mitizzasti": "mitizzare",
    "mitizzata": "mitizzare",
    "mitizzate": "mitizzare",
    "mitizzati": "mitizzare",
    "mitizzato": "mitizzare",
    "mitizzava": "mitizzare",
    "mitizzavamo": "mitizzare",
    "mitizzavan": "mitizzare",
    "mitizzavano": "mitizzare",
    "mitizzavate": "mitizzare",
    "mitizzavi": "mitizzare",
    "mitizzavo": "mitizzare",
    "mitizzazioni": "mitizzazione",
    "mitizzerai": "mitizzare",
    "mitizzeran": "mitizzare",
    "mitizzeranno": "mitizzare",
    "mitizzerebbe": "mitizzare",
    "mitizzerebber": "mitizzare",
    "mitizzerebbero": "mitizzare",
    "mitizzerei": "mitizzare",
    "mitizzeremmo": "mitizzare",
    "mitizzeremo": "mitizzare",
    "mitizzereste": "mitizzare",
    "mitizzeresti": "mitizzare",
    "mitizzerete": "mitizzare",
    "mitizzerà": "mitizzare",
    "mitizzerò": "mitizzare",
    "mitizzi": "mitizzare",
    "mitizziamo": "mitizzare",
    "mitizziate": "mitizzare",
    "mitizzin": "mitizzare",
    "mitizzino": "mitizzare",
    "mitizzo": "mitizzare",
    "mitizzò": "mitizzare",
    "mitocondri": "mitocondrio",
    "mitologica": "mitologico",
    "mitologiche": "mitologico",
    "mitologici": "mitologico",
    "mitologie": "mitologia",
    "mitomani": "mitomane",
    "mitragli": "mitragliare",
    "mitraglia": "mitragliare",
    "mitragliai": "mitragliare",
    "mitragliamenti": "mitragliamento",
    "mitragliammo": "mitragliare",
    "mitragliamo": "mitragliare",
    "mitraglian": "mitragliare",
    "mitragliando": "mitragliare",
    "mitragliano": "mitragliare",
    "mitragliante": "mitragliare",
    "mitraglianti": "mitragliare",
    "mitragliar": "mitragliare",
    "mitragliaron": "mitragliare",
    "mitragliarono": "mitragliare",
    "mitragliasse": "mitragliare",
    "mitragliasser": "mitragliare",
    "mitragliassero": "mitragliare",
    "mitragliassi": "mitragliare",
    "mitragliassimo": "mitragliare",
    "mitragliaste": "mitragliare",
    "mitragliasti": "mitragliare",
    "mitragliata": "mitragliare",
    "mitragliate": "mitragliata",
    "mitragliati": "mitragliare",
    "mitragliato": "mitragliare",
    "mitragliatori": "mitragliatore",
    "mitragliatrice": "mitragliatore",
    "mitragliatrici": "mitragliatrice",
    "mitragliava": "mitragliare",
    "mitragliavamo": "mitragliare",
    "mitragliavan": "mitragliare",
    "mitragliavano": "mitragliare",
    "mitragliavate": "mitragliare",
    "mitragliavi": "mitragliare",
    "mitragliavo": "mitragliare",
    "mitraglie": "mitraglia",
    "mitraglierai": "mitragliare",
    "mitraglieran": "mitragliare",
    "mitraglieranno": "mitragliare",
    "mitragliere": "mitragliera",
    "mitraglierebbe": "mitragliare",
    "mitraglierebber": "mitragliare",
    "mitraglierebbero": "mitragliare",
    "mitraglierei": "mitragliare",
    "mitraglieremmo": "mitragliare",
    "mitraglieremo": "mitragliare",
    "mitragliereste": "mitragliare",
    "mitraglieresti": "mitragliare",
    "mitraglierete": "mitragliare",
    "mitraglieri": "mitragliere",
    "mitraglierà": "mitragliare",
    "mitraglierò": "mitragliare",
    "mitragliette": "mitraglietta",
    "mitraglin": "mitragliare",
    "mitraglino": "mitragliare",
    "mitraglio": "mitragliare",
    "mitragliò": "mitragliare",
    "mitridatizza": "mitridatizzare",
    "mitridatizzai": "mitridatizzare",
    "mitridatizzammo": "mitridatizzare",
    "mitridatizzan": "mitridatizzare",
    "mitridatizzando": "mitridatizzare",
    "mitridatizzano": "mitridatizzare",
    "mitridatizzante": "mitridatizzare",
    "mitridatizzanti": "mitridatizzare",
    "mitridatizzar": "mitridatizzare",
    "mitridatizzaron": "mitridatizzare",
    "mitridatizzarono": "mitridatizzare",
    "mitridatizzasse": "mitridatizzare",
    "mitridatizzasser": "mitridatizzare",
    "mitridatizzassero": "mitridatizzare",
    "mitridatizzassi": "mitridatizzare",
    "mitridatizzassimo": "mitridatizzare",
    "mitridatizzaste": "mitridatizzare",
    "mitridatizzasti": "mitridatizzare",
    "mitridatizzata": "mitridatizzare",
    "mitridatizzate": "mitridatizzare",
    "mitridatizzati": "mitridatizzare",
    "mitridatizzato": "mitridatizzare",
    "mitridatizzava": "mitridatizzare",
    "mitridatizzavamo": "mitridatizzare",
    "mitridatizzavan": "mitridatizzare",
    "mitridatizzavano": "mitridatizzare",
    "mitridatizzavate": "mitridatizzare",
    "mitridatizzavi": "mitridatizzare",
    "mitridatizzavo": "mitridatizzare",
    "mitridatizzerai": "mitridatizzare",
    "mitridatizzeran": "mitridatizzare",
    "mitridatizzeranno": "mitridatizzare",
    "mitridatizzerebbe": "mitridatizzare",
    "mitridatizzerebber": "mitridatizzare",
    "mitridatizzerebbero": "mitridatizzare",
    "mitridatizzerei": "mitridatizzare",
    "mitridatizzeremmo": "mitridatizzare",
    "mitridatizzeremo": "mitridatizzare",
    "mitridatizzereste": "mitridatizzare",
    "mitridatizzeresti": "mitridatizzare",
    "mitridatizzerete": "mitridatizzare",
    "mitridatizzerà": "mitridatizzare",
    "mitridatizzerò": "mitridatizzare",
    "mitridatizzi": "mitridatizzare",
    "mitridatizziamo": "mitridatizzare",
    "mitridatizziate": "mitridatizzare",
    "mitridatizzin": "mitridatizzare",
    "mitridatizzino": "mitridatizzare",
    "mitridatizzo": "mitridatizzare",
    "mitridatizzò": "mitridatizzare",
    "mitteleuropea": "mitteleuropeo",
    "mitteleuropee": "mitteleuropeo",
    "mitteleuropei": "mitteleuropeo",
    "mittenti": "mittente",
    "mitterrandiana": "mitterrandiano",
    "mitterrandiane": "mitterrandiano",
    "mitterrandiani": "mitterrandiano",
    "mitterrandismi": "mitterrandismo",
    "mnemonica": "mnemonico",
    "mnemoniche": "mnemonico",
    "mnemonici": "mnemonico",
    "mobiletti": "mobiletto",
    "mobili": "mobilio",
    "mobilia": "mobiliare",
    "mobiliai": "mobiliare",
    "mobiliammo": "mobiliare",
    "mobiliamo": "mobiliare",
    "mobilian": "mobiliare",
    "mobiliando": "mobiliare",
    "mobiliano": "mobiliare",
    "mobiliante": "mobiliare",
    "mobilianti": "mobiliare",
    "mobiliar": "mobiliare",
    "mobiliari": "mobiliare",
    "mobiliaron": "mobiliare",
    "mobiliarono": "mobiliare",
    "mobiliasse": "mobiliare",
    "mobiliasser": "mobiliare",
    "mobiliassero": "mobiliare",
    "mobiliassi": "mobiliare",
    "mobiliassimo": "mobiliare",
    "mobiliaste": "mobiliare",
    "mobiliasti": "mobiliare",
    "mobiliata": "mobiliare",
    "mobiliate": "mobiliare",
    "mobiliati": "mobiliare",
    "mobiliato": "mobiliare",
    "mobiliava": "mobiliare",
    "mobiliavamo": "mobiliare",
    "mobiliavan": "mobiliare",
    "mobiliavano": "mobiliare",
    "mobiliavate": "mobiliare",
    "mobiliavi": "mobiliare",
    "mobiliavo": "mobiliare",
    "mobilierai": "mobiliare",
    "mobilieran": "mobiliare",
    "mobilieranno": "mobiliare",
    "mobilierebbe": "mobiliare",
    "mobilierebber": "mobiliare",
    "mobilierebbero": "mobiliare",
    "mobilierei": "mobiliare",
    "mobilieremmo": "mobiliare",
    "mobilieremo": "mobiliare",
    "mobiliereste": "mobiliare",
    "mobilieresti": "mobiliare",
    "mobilierete": "mobiliare",
    "mobilieri": "mobiliere",
    "mobilierà": "mobiliare",
    "mobilierò": "mobiliare",
    "mobilifici": "mobilificio",
    "mobilin": "mobiliare",
    "mobilino": "mobiliare",
    "mobilio": "mobiliare",
    "mobilita": "mobilitare",
    "mobilitai": "mobilitare",
    "mobilitammo": "mobilitare",
    "mobilitan": "mobilitare",
    "mobilitando": "mobilitare",
    "mobilitano": "mobilitare",
    "mobilitante": "mobilitare",
    "mobilitanti": "mobilitare",
    "mobilitar": "mobilitare",
    "mobilitaron": "mobilitare",
    "mobilitarono": "mobilitare",
    "mobilitasse": "mobilitare",
    "mobilitasser": "mobilitare",
    "mobilitassero": "mobilitare",
    "mobilitassi": "mobilitare",
    "mobilitassimo": "mobilitare",
    "mobilitaste": "mobilitare",
    "mobilitasti": "mobilitare",
    "mobilitata": "mobilitare",
    "mobilitate": "mobilitare",
    "mobilitati": "mobilitare",
    "mobilitato": "mobilitare",
    "mobilitava": "mobilitare",
    "mobilitavamo": "mobilitare",
    "mobilitavan": "mobilitare",
    "mobilitavano": "mobilitare",
    "mobilitavate": "mobilitare",
    "mobilitavi": "mobilitare",
    "mobilitavo": "mobilitare",
    "mobilitazioni": "mobilitazione",
    "mobiliterai": "mobilitare",
    "mobiliteran": "mobilitare",
    "mobiliteranno": "mobilitare",
    "mobiliterebbe": "mobilitare",
    "mobiliterebber": "mobilitare",
    "mobiliterebbero": "mobilitare",
    "mobiliterei": "mobilitare",
    "mobiliteremmo": "mobilitare",
    "mobiliteremo": "mobilitare",
    "mobilitereste": "mobilitare",
    "mobiliteresti": "mobilitare",
    "mobiliterete": "mobilitare",
    "mobiliterà": "mobilitare",
    "mobiliterò": "mobilitare",
    "mobiliti": "mobilitare",
    "mobilitiamo": "mobilitare",
    "mobilitiate": "mobilitare",
    "mobilitin": "mobilitare",
    "mobilitino": "mobilitare",
    "mobilito": "mobilitare",
    "mobilitò": "mobilitare",
    "mobilizza": "mobilizzare",
    "mobilizzai": "mobilizzare",
    "mobilizzammo": "mobilizzare",
    "mobilizzan": "mobilizzare",
    "mobilizzando": "mobilizzare",
    "mobilizzano": "mobilizzare",
    "mobilizzante": "mobilizzare",
    "mobilizzanti": "mobilizzare",
    "mobilizzar": "mobilizzare",
    "mobilizzaron": "mobilizzare",
    "mobilizzarono": "mobilizzare",
    "mobilizzasse": "mobilizzare",
    "mobilizzasser": "mobilizzare",
    "mobilizzassero": "mobilizzare",
    "mobilizzassi": "mobilizzare",
    "mobilizzassimo": "mobilizzare",
    "mobilizzaste": "mobilizzare",
    "mobilizzasti": "mobilizzare",
    "mobilizzata": "mobilizzare",
    "mobilizzate": "mobilizzare",
    "mobilizzati": "mobilizzare",
    "mobilizzato": "mobilizzare",
    "mobilizzava": "mobilizzare",
    "mobilizzavamo": "mobilizzare",
    "mobilizzavan": "mobilizzare",
    "mobilizzavano": "mobilizzare",
    "mobilizzavate": "mobilizzare",
    "mobilizzavi": "mobilizzare",
    "mobilizzavo": "mobilizzare",
    "mobilizzerai": "mobilizzare",
    "mobilizzeran": "mobilizzare",
    "mobilizzeranno": "mobilizzare",
    "mobilizzerebbe": "mobilizzare",
    "mobilizzerebber": "mobilizzare",
    "mobilizzerebbero": "mobilizzare",
    "mobilizzerei": "mobilizzare",
    "mobilizzeremmo": "mobilizzare",
    "mobilizzeremo": "mobilizzare",
    "mobilizzereste": "mobilizzare",
    "mobilizzeresti": "mobilizzare",
    "mobilizzerete": "mobilizzare",
    "mobilizzerà": "mobilizzare",
    "mobilizzerò": "mobilizzare",
    "mobilizzi": "mobilizzare",
    "mobilizziamo": "mobilizzare",
    "mobilizziate": "mobilizzare",
    "mobilizzin": "mobilizzare",
    "mobilizzino": "mobilizzare",
    "mobilizzo": "mobilizzare",
    "mobilizzò": "mobilizzare",
    "mobiliò": "mobiliare",
    "mocassini": "mocassino",
    "mocciosa": "moccioso",
    "mocciose": "moccioso",
    "mocciosi": "moccioso",
    "moccoli": "moccolo",
    "modali": "modale",
    "modanature": "modanatura",
    "mode": "moda",
    "modella": "modellare",
    "modellabili": "modellabile",
    "modellai": "modellare",
    "modellammo": "modellare",
    "modellan": "modellare",
    "modellando": "modellare",
    "modellano": "modellare",
    "modellante": "modellare",
    "modellanti": "modellare",
    "modellar": "modellare",
    "modellaron": "modellare",
    "modellarono": "modellare",
    "modellasse": "modellare",
    "modellasser": "modellare",
    "modellassero": "modellare",
    "modellassi": "modellare",
    "modellassimo": "modellare",
    "modellaste": "modellare",
    "modellasti": "modellare",
    "modellata": "modellato",
    "modellate": "modellato",
    "modellati": "modellato",
    "modellato": "modellare",
    "modellava": "modellare",
    "modellavamo": "modellare",
    "modellavan": "modellare",
    "modellavano": "modellare",
    "modellavate": "modellare",
    "modellavi": "modellare",
    "modellavo": "modellare",
    "modelle": "modella",
    "modellerai": "modellare",
    "modelleran": "modellare",
    "modelleranno": "modellare",
    "modellerebbe": "modellare",
    "modellerebber": "modellare",
    "modellerebbero": "modellare",
    "modellerei": "modellare",
    "modelleremmo": "modellare",
    "modelleremo": "modellare",
    "modellereste": "modellare",
    "modelleresti": "modellare",
    "modellerete": "modellare",
    "modellerà": "modellare",
    "modellerò": "modellare",
    "modelli": "modello",
    "modelliamo": "modellare",
    "modelliate": "modellare",
    "modellin": "modellare",
    "modellini": "modellino",
    "modellino": "modellare",
    "modello": "modellare",
    "modellò": "modellare",
    "modenesi": "modenese",
    "modera": "moderare",
    "moderai": "moderare",
    "moderammo": "moderare",
    "moderan": "moderare",
    "moderando": "moderare",
    "moderano": "moderare",
    "moderante": "moderare",
    "moderanti": "moderare",
    "moderar": "moderare",
    "moderaron": "moderare",
    "moderarono": "moderare",
    "moderasse": "moderare",
    "moderasser": "moderare",
    "moderassero": "moderare",
    "moderassi": "moderare",
    "moderassimo": "moderare",
    "moderaste": "moderare",
    "moderasti": "moderare",
    "moderata": "moderato",
    "moderate": "moderato",
    "moderati": "moderato",
    "moderatismi": "moderatismo",
    "moderato": "moderare",
    "moderatori": "moderatore",
    "moderatrice": "moderatore",
    "moderatrici": "moderatore",
    "moderava": "moderare",
    "moderavamo": "moderare",
    "moderavan": "moderare",
    "moderavano": "moderare",
    "moderavate": "moderare",
    "moderavi": "moderare",
    "moderavo": "moderare",
    "moderazioni": "moderazione",
    "modererai": "moderare",
    "modereran": "moderare",
    "modereranno": "moderare",
    "modererebbe": "moderare",
    "modererebber": "moderare",
    "modererebbero": "moderare",
    "modererei": "moderare",
    "modereremmo": "moderare",
    "modereremo": "moderare",
    "moderereste": "moderare",
    "modereresti": "moderare",
    "modererete": "moderare",
    "modererà": "moderare",
    "modererò": "moderare",
    "moderi": "moderare",
    "moderiamo": "moderare",
    "moderiate": "moderare",
    "moderin": "moderare",
    "moderino": "moderare",
    "moderna": "moderno",
    "moderne": "moderno",
    "moderni": "moderno",
    "modernismi": "modernismo",
    "moderniste": "modernista",
    "modernisti": "modernista",
    "modernizza": "modernizzare",
    "modernizzai": "modernizzare",
    "modernizzammo": "modernizzare",
    "modernizzan": "modernizzare",
    "modernizzando": "modernizzare",
    "modernizzano": "modernizzare",
    "modernizzante": "modernizzare",
    "modernizzanti": "modernizzare",
    "modernizzar": "modernizzare",
    "modernizzaron": "modernizzare",
    "modernizzarono": "modernizzare",
    "modernizzasse": "modernizzare",
    "modernizzasser": "modernizzare",
    "modernizzassero": "modernizzare",
    "modernizzassi": "modernizzare",
    "modernizzassimo": "modernizzare",
    "modernizzaste": "modernizzare",
    "modernizzasti": "modernizzare",
    "modernizzata": "modernizzare",
    "modernizzate": "modernizzare",
    "modernizzati": "modernizzare",
    "modernizzato": "modernizzare",
    "modernizzatori": "modernizzatore",
    "modernizzava": "modernizzare",
    "modernizzavamo": "modernizzare",
    "modernizzavan": "modernizzare",
    "modernizzavano": "modernizzare",
    "modernizzavate": "modernizzare",
    "modernizzavi": "modernizzare",
    "modernizzavo": "modernizzare",
    "modernizzazioni": "modernizzazione",
    "modernizzerai": "modernizzare",
    "modernizzeran": "modernizzare",
    "modernizzeranno": "modernizzare",
    "modernizzerebbe": "modernizzare",
    "modernizzerebber": "modernizzare",
    "modernizzerebbero": "modernizzare",
    "modernizzerei": "modernizzare",
    "modernizzeremmo": "modernizzare",
    "modernizzeremo": "modernizzare",
    "modernizzereste": "modernizzare",
    "modernizzeresti": "modernizzare",
    "modernizzerete": "modernizzare",
    "modernizzerà": "modernizzare",
    "modernizzerò": "modernizzare",
    "modernizzi": "modernizzare",
    "modernizziamo": "modernizzare",
    "modernizziate": "modernizzare",
    "modernizzin": "modernizzare",
    "modernizzino": "modernizzare",
    "modernizzo": "modernizzare",
    "modernizzò": "modernizzare",
    "modero": "moderare",
    "moderò": "moderare",
    "modesta": "modesto",
    "modeste": "modesto",
    "modesti": "modesto",
    "modestie": "modestia",
    "modi": "modo",
    "modica": "modico",
    "modiche": "modico",
    "modici": "modico",
    "modifica": "modificare",
    "modificabili": "modificabile",
    "modificai": "modificare",
    "modificammo": "modificare",
    "modifican": "modificare",
    "modificando": "modificare",
    "modificano": "modificare",
    "modificante": "modificare",
    "modificanti": "modificare",
    "modificar": "modificare",
    "modificaron": "modificare",
    "modificarono": "modificare",
    "modificasse": "modificare",
    "modificasser": "modificare",
    "modificassero": "modificare",
    "modificassi": "modificare",
    "modificassimo": "modificare",
    "modificaste": "modificare",
    "modificasti": "modificare",
    "modificata": "modificare",
    "modificate": "modificare",
    "modificati": "modificare",
    "modificato": "modificare",
    "modificatori": "modificatore",
    "modificatrice": "modificatore",
    "modificatrici": "modificatore",
    "modificava": "modificare",
    "modificavamo": "modificare",
    "modificavan": "modificare",
    "modificavano": "modificare",
    "modificavate": "modificare",
    "modificavi": "modificare",
    "modificavo": "modificare",
    "modificazioni": "modificazione",
    "modifiche": "modifica",
    "modificherai": "modificare",
    "modificheran": "modificare",
    "modificheranno": "modificare",
    "modificherebbe": "modificare",
    "modificherebber": "modificare",
    "modificherebbero": "modificare",
    "modificherei": "modificare",
    "modificheremmo": "modificare",
    "modificheremo": "modificare",
    "modifichereste": "modificare",
    "modificheresti": "modificare",
    "modificherete": "modificare",
    "modificherà": "modificare",
    "modificherò": "modificare",
    "modifichi": "modificare",
    "modifichiamo": "modificare",
    "modifichiate": "modificare",
    "modifichin": "modificare",
    "modifichino": "modificare",
    "modifico": "modificare",
    "modificò": "modificare",
    "modiste": "modista",
    "modula": "modulare",
    "modulabili": "modulabile",
    "modulai": "modulare",
    "modulammo": "modulare",
    "modulan": "modulare",
    "modulando": "modulare",
    "modulano": "modulare",
    "modulante": "modulare",
    "modulanti": "modulare",
    "modular": "modulare",
    "modulari": "modulare",
    "modularon": "modulare",
    "modularono": "modulare",
    "modulasse": "modulare",
    "modulasser": "modulare",
    "modulassero": "modulare",
    "modulassi": "modulare",
    "modulassimo": "modulare",
    "modulaste": "modulare",
    "modulasti": "modulare",
    "modulata": "modulare",
    "modulate": "modulare",
    "modulati": "modulare",
    "modulato": "modulare",
    "modulava": "modulare",
    "modulavamo": "modulare",
    "modulavan": "modulare",
    "modulavano": "modulare",
    "modulavate": "modulare",
    "modulavi": "modulare",
    "modulavo": "modulare",
    "modulazioni": "modulazione",
    "modulerai": "modulare",
    "moduleran": "modulare",
    "moduleranno": "modulare",
    "modulerebbe": "modulare",
    "modulerebber": "modulare",
    "modulerebbero": "modulare",
    "modulerei": "modulare",
    "moduleremmo": "modulare",
    "moduleremo": "modulare",
    "modulereste": "modulare",
    "moduleresti": "modulare",
    "modulerete": "modulare",
    "modulerà": "modulare",
    "modulerò": "modulare",
    "moduli": "modulo",
    "moduliamo": "modulare",
    "moduliate": "modulare",
    "modulin": "modulare",
    "modulino": "modulare",
    "modulo": "modulare",
    "modulò": "modulare",
    "mogani": "mogano",
    "mogi": "mogio",
    "mogia": "mogio",
    "mogie": "mogio",
    "mogli": "moglie",
    "mogliettine": "mogliettina",
    "moine": "moina",
    "mola": "molare",
    "molai": "molare",
    "molammo": "molare",
    "molan": "molare",
    "molando": "molare",
    "molano": "molare",
    "molante": "molare",
    "molanti": "molare",
    "molar": "molare",
    "molaron": "molare",
    "molarono": "molare",
    "molasse": "molare",
    "molasser": "molare",
    "molassero": "molare",
    "molassi": "molare",
    "molassimo": "molare",
    "molaste": "molare",
    "molasti": "molare",
    "molata": "molare",
    "molate": "molare",
    "molati": "molare",
    "molato": "molare",
    "molava": "molare",
    "molavamo": "molare",
    "molavan": "molare",
    "molavano": "molare",
    "molavate": "molare",
    "molavi": "molare",
    "molavo": "molare",
    "molca": "molcere",
    "molcan": "molcere",
    "molcano": "molcere",
    "molce": "molcere",
    "molcei": "molcere",
    "molcemmo": "molcere",
    "molcendo": "molcere",
    "molcente": "molcere",
    "molcenti": "molcere",
    "molcer": "molcere",
    "molcerai": "molcere",
    "molceran": "molcere",
    "molceranno": "molcere",
    "molcerebbe": "molcere",
    "molcerebber": "molcere",
    "molcerebbero": "molcere",
    "molcerei": "molcere",
    "molceremmo": "molcere",
    "molceremo": "molcere",
    "molcereste": "molcere",
    "molceresti": "molcere",
    "molcerete": "molcere",
    "molceron": "molcere",
    "molcerono": "molcere",
    "molcerà": "molcere",
    "molcerò": "molcere",
    "molcesse": "molcere",
    "molcesser": "molcere",
    "molcessero": "molcere",
    "molcessi": "molcere",
    "molcessimo": "molcere",
    "molceste": "molcere",
    "molcesti": "molcere",
    "molcete": "molcere",
    "molceva": "molcere",
    "molcevamo": "molcere",
    "molcevan": "molcere",
    "molcevano": "molcere",
    "molcevate": "molcere",
    "molcevi": "molcere",
    "molcevo": "molcere",
    "molci": "molcere",
    "molciamo": "molcere",
    "molciate": "molcere",
    "molco": "molcere",
    "molcon": "molcere",
    "molcono": "molcere",
    "molcuta": "molcere",
    "molcute": "molcere",
    "molcuti": "molcere",
    "molcuto": "molcere",
    "molcè": "molcere",
    "moldavi": "moldavo",
    "molecolari": "molecolare",
    "molecole": "molecola",
    "molerai": "molare",
    "moleran": "molare",
    "moleranno": "molare",
    "molerebbe": "molare",
    "molerebber": "molare",
    "molerebbero": "molare",
    "molerei": "molare",
    "moleremmo": "molare",
    "moleremo": "molare",
    "molereste": "molare",
    "moleresti": "molare",
    "molerete": "molare",
    "molerà": "molare",
    "molerò": "molare",
    "molesta": "molesto",
    "molestai": "molestare",
    "molestammo": "molestare",
    "molestan": "molestare",
    "molestando": "molestare",
    "molestano": "molestare",
    "molestante": "molestare",
    "molestanti": "molestare",
    "molestar": "molestare",
    "molestaron": "molestare",
    "molestarono": "molestare",
    "molestasse": "molestare",
    "molestasser": "molestare",
    "molestassero": "molestare",
    "molestassi": "molestare",
    "molestassimo": "molestare",
    "molestaste": "molestare",
    "molestasti": "molestare",
    "molestata": "molestare",
    "molestate": "molestare",
    "molestati": "molestare",
    "molestato": "molestare",
    "molestatori": "molestatore",
    "molestava": "molestare",
    "molestavamo": "molestare",
    "molestavan": "molestare",
    "molestavano": "molestare",
    "molestavate": "molestare",
    "molestavi": "molestare",
    "molestavo": "molestare",
    "moleste": "molesto",
    "molesterai": "molestare",
    "molesteran": "molestare",
    "molesteranno": "molestare",
    "molesterebbe": "molestare",
    "molesterebber": "molestare",
    "molesterebbero": "molestare",
    "molesterei": "molestare",
    "molesteremmo": "molestare",
    "molesteremo": "molestare",
    "molestereste": "molestare",
    "molesteresti": "molestare",
    "molesterete": "molestare",
    "molesterà": "molestare",
    "molesterò": "molestare",
    "molesti": "molesto",
    "molestiamo": "molestare",
    "molestiate": "molestare",
    "molestie": "molestia",
    "molestin": "molestare",
    "molestino": "molestare",
    "molesto": "molestare",
    "molestò": "molestare",
    "moli": "molo",
    "moliamo": "molare",
    "moliate": "molare",
    "molin": "molare",
    "molino": "molare",
    "molisana": "molisano",
    "molisane": "molisano",
    "molisani": "molisano",
    "molitori": "molitorio",
    "molitoria": "molitorio",
    "molitorie": "molitorio",
    "molla": "mollo",
    "mollai": "mollare",
    "mollammo": "mollare",
    "mollan": "mollare",
    "mollando": "mollare",
    "mollano": "mollare",
    "mollante": "mollare",
    "mollanti": "mollare",
    "mollar": "mollare",
    "mollaron": "mollare",
    "mollarono": "mollare",
    "mollasse": "mollare",
    "mollasser": "mollare",
    "mollassero": "mollare",
    "mollassi": "mollare",
    "mollassimo": "mollare",
    "mollaste": "mollare",
    "mollasti": "mollare",
    "mollata": "mollare",
    "mollate": "mollare",
    "mollati": "mollare",
    "mollato": "mollare",
    "mollava": "mollare",
    "mollavamo": "mollare",
    "mollavan": "mollare",
    "mollavano": "mollare",
    "mollavate": "mollare",
    "mollavi": "mollare",
    "mollavo": "mollare",
    "molle": "mollo",
    "molleggerai": "molleggiare",
    "molleggeran": "molleggiare",
    "molleggeranno": "molleggiare",
    "molleggerebbe": "molleggiare",
    "molleggerebber": "molleggiare",
    "molleggerebbero": "molleggiare",
    "molleggerei": "molleggiare",
    "molleggeremmo": "molleggiare",
    "molleggeremo": "molleggiare",
    "molleggereste": "molleggiare",
    "molleggeresti": "molleggiare",
    "molleggerete": "molleggiare",
    "molleggerà": "molleggiare",
    "molleggerò": "molleggiare",
    "molleggi": "molleggiare",
    "molleggia": "molleggiare",
    "molleggiai": "molleggiare",
    "molleggiammo": "molleggiare",
    "molleggiamo": "molleggiare",
    "molleggian": "molleggiare",
    "molleggiando": "molleggiare",
    "molleggiano": "molleggiare",
    "molleggiante": "molleggiare",
    "molleggianti": "molleggiare",
    "molleggiar": "molleggiare",
    "molleggiaron": "molleggiare",
    "molleggiarono": "molleggiare",
    "molleggiasse": "molleggiare",
    "molleggiasser": "molleggiare",
    "molleggiassero": "molleggiare",
    "molleggiassi": "molleggiare",
    "molleggiassimo": "molleggiare",
    "molleggiaste": "molleggiare",
    "molleggiasti": "molleggiare",
    "molleggiata": "molleggiare",
    "molleggiate": "molleggiare",
    "molleggiati": "molleggiare",
    "molleggiato": "molleggiare",
    "molleggiava": "molleggiare",
    "molleggiavamo": "molleggiare",
    "molleggiavan": "molleggiare",
    "molleggiavano": "molleggiare",
    "molleggiavate": "molleggiare",
    "molleggiavi": "molleggiare",
    "molleggiavo": "molleggiare",
    "molleggin": "molleggiare",
    "molleggino": "molleggiare",
    "molleggio": "molleggiare",
    "molleggiò": "molleggiare",
    "mollerai": "mollare",
    "molleran": "mollare",
    "molleranno": "mollare",
    "mollerebbe": "mollare",
    "mollerebber": "mollare",
    "mollerebbero": "mollare",
    "mollerei": "mollare",
    "molleremmo": "mollare",
    "molleremo": "mollare",
    "mollereste": "mollare",
    "molleresti": "mollare",
    "mollerete": "mollare",
    "mollerà": "mollare",
    "mollerò": "mollare",
    "mollette": "molletta",
    "mollezze": "mollezza",
    "molli": "mollo",
    "molliamo": "mollare",
    "molliate": "mollare",
    "mollicce": "molliccio",
    "mollicci": "molliccio",
    "molliccia": "molliccio",
    "mollin": "mollare",
    "mollino": "mollare",
    "mollo": "mollare",
    "molluschi": "mollusco",
    "mollò": "mollare",
    "molo": "molare",
    "molossi": "molosso",
    "molta": "molto",
    "molte": "molto",
    "molteplici": "molteplice",
    "molti": "molto",
    "moltiplica": "moltiplicare",
    "moltiplicai": "moltiplicare",
    "moltiplicammo": "moltiplicare",
    "moltiplican": "moltiplicare",
    "moltiplicando": "moltiplicare",
    "moltiplicano": "moltiplicare",
    "moltiplicante": "moltiplicare",
    "moltiplicanti": "moltiplicare",
    "moltiplicar": "moltiplicare",
    "moltiplicaron": "moltiplicare",
    "moltiplicarono": "moltiplicare",
    "moltiplicasse": "moltiplicare",
    "moltiplicasser": "moltiplicare",
    "moltiplicassero": "moltiplicare",
    "moltiplicassi": "moltiplicare",
    "moltiplicassimo": "moltiplicare",
    "moltiplicaste": "moltiplicare",
    "moltiplicasti": "moltiplicare",
    "moltiplicata": "moltiplicare",
    "moltiplicate": "moltiplicare",
    "moltiplicati": "moltiplicare",
    "moltiplicativa": "moltiplicativo",
    "moltiplicative": "moltiplicativo",
    "moltiplicativi": "moltiplicativo",
    "moltiplicato": "moltiplicare",
    "moltiplicatori": "moltiplicatore",
    "moltiplicatrice": "moltiplicatore",
    "moltiplicatrici": "moltiplicatore",
    "moltiplicava": "moltiplicare",
    "moltiplicavamo": "moltiplicare",
    "moltiplicavan": "moltiplicare",
    "moltiplicavano": "moltiplicare",
    "moltiplicavate": "moltiplicare",
    "moltiplicavi": "moltiplicare",
    "moltiplicavo": "moltiplicare",
    "moltiplicazioni": "moltiplicazione",
    "moltiplicherai": "moltiplicare",
    "moltiplicheran": "moltiplicare",
    "moltiplicheranno": "moltiplicare",
    "moltiplicherebbe": "moltiplicare",
    "moltiplicherebber": "moltiplicare",
    "moltiplicherebbero": "moltiplicare",
    "moltiplicherei": "moltiplicare",
    "moltiplicheremmo": "moltiplicare",
    "moltiplicheremo": "moltiplicare",
    "moltiplichereste": "moltiplicare",
    "moltiplicheresti": "moltiplicare",
    "moltiplicherete": "moltiplicare",
    "moltiplicherà": "moltiplicare",
    "moltiplicherò": "moltiplicare",
    "moltiplichi": "moltiplicare",
    "moltiplichiamo": "moltiplicare",
    "moltiplichiate": "moltiplicare",
    "moltiplichin": "moltiplicare",
    "moltiplichino": "moltiplicare",
    "moltiplico": "moltiplicare",
    "moltiplicò": "moltiplicare",
    "moltitudini": "moltitudine",
    "molò": "molare",
    "momentacci": "momentaccio",
    "momentanea": "momentaneo",
    "momentanee": "momentaneo",
    "momentanei": "momentaneo",
    "momenti": "momento",
    "momumenti": "momumento",
    "monaca": "monacare",
    "monacai": "monacare",
    "monacali": "monacale",
    "monacammo": "monacare",
    "monacan": "monacare",
    "monacando": "monacare",
    "monacano": "monacare",
    "monacante": "monacare",
    "monacanti": "monacare",
    "monacar": "monacare",
    "monacaron": "monacare",
    "monacarono": "monacare",
    "monacasse": "monacare",
    "monacasser": "monacare",
    "monacassero": "monacare",
    "monacassi": "monacare",
    "monacassimo": "monacare",
    "monacaste": "monacare",
    "monacasti": "monacare",
    "monacata": "monacare",
    "monacate": "monacare",
    "monacati": "monacare",
    "monacato": "monacare",
    "monacava": "monacare",
    "monacavamo": "monacare",
    "monacavan": "monacare",
    "monacavano": "monacare",
    "monacavate": "monacare",
    "monacavi": "monacare",
    "monacavo": "monacare",
    "monache": "monaca",
    "monacherai": "monacare",
    "monacheran": "monacare",
    "monacheranno": "monacare",
    "monacherebbe": "monacare",
    "monacherebber": "monacare",
    "monacherebbero": "monacare",
    "monacherei": "monacare",
    "monacheremmo": "monacare",
    "monacheremo": "monacare",
    "monachereste": "monacare",
    "monacheresti": "monacare",
    "monacherete": "monacare",
    "monacherà": "monacare",
    "monacherò": "monacare",
    "monachi": "monacare",
    "monachiamo": "monacare",
    "monachiate": "monacare",
    "monachin": "monacare",
    "monachino": "monacare",
    "monaci": "monaco",
    "monaco": "monacare",
    "monacò": "monacare",
    "monadi": "monade",
    "monarchi": "monarca",
    "monarchica": "monarchico",
    "monarchiche": "monarchico",
    "monarchici": "monarchico",
    "monarchie": "monarchia",
    "monasteri": "monastero",
    "monastica": "monastico",
    "monastiche": "monastico",
    "monastici": "monastico",
    "monca": "monco",
    "monche": "monco",
    "moncherini": "moncherino",
    "monchi": "monco",
    "monconi": "moncone",
    "monda": "mondo",
    "mondai": "mondare",
    "mondammo": "mondare",
    "mondan": "mondare",
    "mondana": "mondano",
    "mondando": "mondare",
    "mondane": "mondano",
    "mondani": "mondano",
    "mondano": "mondare",
    "mondante": "mondare",
    "mondanti": "mondare",
    "mondar": "mondare",
    "mondaron": "mondare",
    "mondarono": "mondare",
    "mondasse": "mondare",
    "mondasser": "mondare",
    "mondassero": "mondare",
    "mondassi": "mondare",
    "mondassimo": "mondare",
    "mondaste": "mondare",
    "mondasti": "mondare",
    "mondata": "mondare",
    "mondate": "mondare",
    "mondati": "mondare",
    "mondato": "mondare",
    "mondava": "mondare",
    "mondavamo": "mondare",
    "mondavan": "mondare",
    "mondavano": "mondare",
    "mondavate": "mondare",
    "mondavi": "mondare",
    "mondavo": "mondare",
    "monde": "mondo",
    "monderai": "mondare",
    "monderan": "mondare",
    "monderanno": "mondare",
    "monderebbe": "mondare",
    "monderebber": "mondare",
    "monderebbero": "mondare",
    "monderei": "mondare",
    "monderemmo": "mondare",
    "monderemo": "mondare",
    "mondereste": "mondare",
    "monderesti": "mondare",
    "monderete": "mondare",
    "monderà": "mondare",
    "monderò": "mondare",
    "mondi": "mondo",
    "mondiali": "mondiale",
    "mondializzazioni": "mondializzazione",
    "mondiamo": "mondare",
    "mondiate": "mondare",
    "mondin": "mondare",
    "mondine": "mondina",
    "mondino": "mondare",
    "mondo": "mondare",
    "mondò": "mondare",
    "monegasca": "monegasco",
    "monegasche": "monegasco",
    "monegaschi": "monegasco",
    "monelli": "monello",
    "moneta": "monetare",
    "monetai": "monetare",
    "monetammo": "monetare",
    "monetan": "monetare",
    "monetando": "monetare",
    "monetano": "monetare",
    "monetante": "monetare",
    "monetanti": "monetare",
    "monetar": "monetare",
    "monetari": "monetario",
    "monetaria": "monetario",
    "monetarie": "monetario",
    "monetarismi": "monetarismo",
    "monetaristi": "monetarista",
    "monetaron": "monetare",
    "monetarono": "monetare",
    "monetasse": "monetare",
    "monetasser": "monetare",
    "monetassero": "monetare",
    "monetassi": "monetare",
    "monetassimo": "monetare",
    "monetaste": "monetare",
    "monetasti": "monetare",
    "monetata": "monetare",
    "monetate": "monetare",
    "monetati": "monetare",
    "monetato": "monetare",
    "monetava": "monetare",
    "monetavamo": "monetare",
    "monetavan": "monetare",
    "monetavano": "monetare",
    "monetavate": "monetare",
    "monetavi": "monetare",
    "monetavo": "monetare",
    "monete": "moneta",
    "moneterai": "monetare",
    "moneteran": "monetare",
    "moneteranno": "monetare",
    "moneterebbe": "monetare",
    "moneterebber": "monetare",
    "moneterebbero": "monetare",
    "moneterei": "monetare",
    "moneteremmo": "monetare",
    "moneteremo": "monetare",
    "monetereste": "monetare",
    "moneteresti": "monetare",
    "moneterete": "monetare",
    "moneterà": "monetare",
    "moneterò": "monetare",
    "moneti": "monetare",
    "monetiamo": "monetare",
    "monetiate": "monetare",
    "monetin": "monetare",
    "monetine": "monetina",
    "monetino": "monetare",
    "monetizza": "monetizzare",
    "monetizzai": "monetizzare",
    "monetizzammo": "monetizzare",
    "monetizzan": "monetizzare",
    "monetizzando": "monetizzare",
    "monetizzano": "monetizzare",
    "monetizzante": "monetizzare",
    "monetizzanti": "monetizzare",
    "monetizzar": "monetizzare",
    "monetizzaron": "monetizzare",
    "monetizzarono": "monetizzare",
    "monetizzasse": "monetizzare",
    "monetizzasser": "monetizzare",
    "monetizzassero": "monetizzare",
    "monetizzassi": "monetizzare",
    "monetizzassimo": "monetizzare",
    "monetizzaste": "monetizzare",
    "monetizzasti": "monetizzare",
    "monetizzata": "monetizzare",
    "monetizzate": "monetizzare",
    "monetizzati": "monetizzare",
    "monetizzato": "monetizzare",
    "monetizzava": "monetizzare",
    "monetizzavamo": "monetizzare",
    "monetizzavan": "monetizzare",
    "monetizzavano": "monetizzare",
    "monetizzavate": "monetizzare",
    "monetizzavi": "monetizzare",
    "monetizzavo": "monetizzare",
    "monetizzerai": "monetizzare",
    "monetizzeran": "monetizzare",
    "monetizzeranno": "monetizzare",
    "monetizzerebbe": "monetizzare",
    "monetizzerebber": "monetizzare",
    "monetizzerebbero": "monetizzare",
    "monetizzerei": "monetizzare",
    "monetizzeremmo": "monetizzare",
    "monetizzeremo": "monetizzare",
    "monetizzereste": "monetizzare",
    "monetizzeresti": "monetizzare",
    "monetizzerete": "monetizzare",
    "monetizzerà": "monetizzare",
    "monetizzerò": "monetizzare",
    "monetizzi": "monetizzare",
    "monetizziamo": "monetizzare",
    "monetizziate": "monetizzare",
    "monetizzin": "monetizzare",
    "monetizzino": "monetizzare",
    "monetizzo": "monetizzare",
    "monetizzò": "monetizzare",
    "moneto": "monetare",
    "monetò": "monetare",
    "mongola": "mongolo",
    "mongole": "mongolo",
    "mongolfiere": "mongolfiera",
    "mongoli": "mongolo",
    "moniti": "monito",
    "monitora": "monitorare",
    "monitoraggi": "monitoraggio",
    "monitorai": "monitorare",
    "monitorammo": "monitorare",
    "monitoran": "monitorare",
    "monitorando": "monitorare",
    "monitorano": "monitorare",
    "monitorante": "monitorare",
    "monitoranti": "monitorare",
    "monitorar": "monitorare",
    "monitoraron": "monitorare",
    "monitorarono": "monitorare",
    "monitorasse": "monitorare",
    "monitorasser": "monitorare",
    "monitorassero": "monitorare",
    "monitorassi": "monitorare",
    "monitorassimo": "monitorare",
    "monitoraste": "monitorare",
    "monitorasti": "monitorare",
    "monitorata": "monitorare",
    "monitorate": "monitorare",
    "monitorati": "monitorare",
    "monitorato": "monitorare",
    "monitorava": "monitorare",
    "monitoravamo": "monitorare",
    "monitoravan": "monitorare",
    "monitoravano": "monitorare",
    "monitoravate": "monitorare",
    "monitoravi": "monitorare",
    "monitoravo": "monitorare",
    "monitorerai": "monitorare",
    "monitoreran": "monitorare",
    "monitoreranno": "monitorare",
    "monitorerebbe": "monitorare",
    "monitorerebber": "monitorare",
    "monitorerebbero": "monitorare",
    "monitorerei": "monitorare",
    "monitoreremmo": "monitorare",
    "monitoreremo": "monitorare",
    "monitorereste": "monitorare",
    "monitoreresti": "monitorare",
    "monitorerete": "monitorare",
    "monitorerà": "monitorare",
    "monitorerò": "monitorare",
    "monitori": "monitorare",
    "monitoriamo": "monitorare",
    "monitoriate": "monitorare",
    "monitorin": "monitorare",
    "monitorino": "monitorare",
    "monitoro": "monitorare",
    "monitorò": "monitorare",
    "monocameralismi": "monocameralismo",
    "monocilindrica": "monocilindrico",
    "monocilindriche": "monocilindrico",
    "monocilindrici": "monocilindrico",
    "monocola": "monocolo",
    "monocole": "monocolo",
    "monocoli": "monocolo",
    "monocolora": "monocoloro",
    "monocolore": "monocoloro",
    "monocolori": "monocoloro",
    "monocolture": "monocoltura",
    "monocordi": "monocorde",
    "monocroma": "monocromo",
    "monocromatica": "monocromatico",
    "monocromatiche": "monocromatico",
    "monocromatici": "monocromatico",
    "monocrome": "monocromo",
    "monocromi": "monocromo",
    "monoculture": "monocultura",
    "monodica": "monodico",
    "monodiche": "monodico",
    "monodici": "monodico",
    "monogama": "monogamo",
    "monogame": "monogamo",
    "monogami": "monogamo",
    "monogamica": "monogamico",
    "monogamiche": "monogamico",
    "monogamici": "monogamico",
    "monogamie": "monogamia",
    "monografica": "monografico",
    "monografiche": "monografico",
    "monografici": "monografico",
    "monografie": "monografia",
    "monoliti": "monolito",
    "monolitica": "monolitico",
    "monolitiche": "monolitico",
    "monolitici": "monolitico",
    "monolitismi": "monolitismo",
    "monolocali": "monolocale",
    "monologa": "monologare",
    "monologai": "monologare",
    "monologammo": "monologare",
    "monologan": "monologare",
    "monologando": "monologare",
    "monologano": "monologare",
    "monologante": "monologare",
    "monologanti": "monologare",
    "monologar": "monologare",
    "monologaron": "monologare",
    "monologarono": "monologare",
    "monologasse": "monologare",
    "monologasser": "monologare",
    "monologassero": "monologare",
    "monologassi": "monologare",
    "monologassimo": "monologare",
    "monologaste": "monologare",
    "monologasti": "monologare",
    "monologata": "monologare",
    "monologate": "monologare",
    "monologati": "monologare",
    "monologato": "monologare",
    "monologava": "monologare",
    "monologavamo": "monologare",
    "monologavan": "monologare",
    "monologavano": "monologare",
    "monologavate": "monologare",
    "monologavi": "monologare",
    "monologavo": "monologare",
    "monologherai": "monologare",
    "monologheran": "monologare",
    "monologheranno": "monologare",
    "monologherebbe": "monologare",
    "monologherebber": "monologare",
    "monologherebbero": "monologare",
    "monologherei": "monologare",
    "monologheremmo": "monologare",
    "monologheremo": "monologare",
    "monologhereste": "monologare",
    "monologheresti": "monologare",
    "monologherete": "monologare",
    "monologherà": "monologare",
    "monologherò": "monologare",
    "monologhi": "monologo",
    "monologhiamo": "monologare",
    "monologhiate": "monologare",
    "monologhin": "monologare",
    "monologhino": "monologare",
    "monologo": "monologare",
    "monologò": "monologare",
    "monomaniaca": "monomaniaco",
    "monomaniache": "monomaniaco",
    "monomaniaci": "monomaniaco",
    "monomanie": "monomania",
    "monomotori": "monomotore",
    "monomotrice": "monomotore",
    "monomotrici": "monomotore",
    "monopattini": "monopattino",
    "monopoli": "monopolio",
    "monopoliste": "monopolista",
    "monopolisti": "monopolista",
    "monopolistica": "monopolistico",
    "monopolistiche": "monopolistico",
    "monopolistici": "monopolistico",
    "monopolizza": "monopolizzare",
    "monopolizzai": "monopolizzare",
    "monopolizzammo": "monopolizzare",
    "monopolizzan": "monopolizzare",
    "monopolizzando": "monopolizzare",
    "monopolizzano": "monopolizzare",
    "monopolizzante": "monopolizzare",
    "monopolizzanti": "monopolizzare",
    "monopolizzar": "monopolizzare",
    "monopolizzaron": "monopolizzare",
    "monopolizzarono": "monopolizzare",
    "monopolizzasse": "monopolizzare",
    "monopolizzasser": "monopolizzare",
    "monopolizzassero": "monopolizzare",
    "monopolizzassi": "monopolizzare",
    "monopolizzassimo": "monopolizzare",
    "monopolizzaste": "monopolizzare",
    "monopolizzasti": "monopolizzare",
    "monopolizzata": "monopolizzare",
    "monopolizzate": "monopolizzare",
    "monopolizzati": "monopolizzare",
    "monopolizzato": "monopolizzare",
    "monopolizzava": "monopolizzare",
    "monopolizzavamo": "monopolizzare",
    "monopolizzavan": "monopolizzare",
    "monopolizzavano": "monopolizzare",
    "monopolizzavate": "monopolizzare",
    "monopolizzavi": "monopolizzare",
    "monopolizzavo": "monopolizzare",
    "monopolizzerai": "monopolizzare",
    "monopolizzeran": "monopolizzare",
    "monopolizzeranno": "monopolizzare",
    "monopolizzerebbe": "monopolizzare",
    "monopolizzerebber": "monopolizzare",
    "monopolizzerebbero": "monopolizzare",
    "monopolizzerei": "monopolizzare",
    "monopolizzeremmo": "monopolizzare",
    "monopolizzeremo": "monopolizzare",
    "monopolizzereste": "monopolizzare",
    "monopolizzeresti": "monopolizzare",
    "monopolizzerete": "monopolizzare",
    "monopolizzerà": "monopolizzare",
    "monopolizzerò": "monopolizzare",
    "monopolizzi": "monopolizzare",
    "monopolizziamo": "monopolizzare",
    "monopolizziate": "monopolizzare",
    "monopolizzin": "monopolizzare",
    "monopolizzino": "monopolizzare",
    "monopolizzo": "monopolizzare",
    "monopolizzò": "monopolizzare",
    "monoposta": "monoposto",
    "monoposte": "monoposto",
    "monoposti": "monoposto",
    "monoscafi": "monoscafo",
    "monosillaba": "monosillabo",
    "monosillabe": "monosillabo",
    "monosillabi": "monosillabo",
    "monossidi": "monossido",
    "monoteismi": "monoteismo",
    "monoteiste": "monoteista",
    "monoteisti": "monoteista",
    "monoteistica": "monoteistico",
    "monoteistiche": "monoteistico",
    "monoteistici": "monoteistico",
    "monotipi": "monotipo",
    "monotona": "monotono",
    "monotone": "monotono",
    "monotoni": "monotono",
    "monotonie": "monotonia",
    "monsignor": "monsignore",
    "monsignori": "monsignore",
    "monsoni": "monsone",
    "monta": "montare",
    "montaggi": "montaggio",
    "montagne": "montagna",
    "montagnole": "montagnola",
    "montagnosa": "montagnoso",
    "montagnose": "montagnoso",
    "montagnosi": "montagnoso",
    "montai": "montare",
    "montammo": "montare",
    "montan": "montare",
    "montana": "montano",
    "montanara": "montanaro",
    "montanare": "montanaro",
    "montanari": "montanaro",
    "montando": "montare",
    "montane": "montano",
    "montani": "montano",
    "montanina": "montanino",
    "montanine": "montanino",
    "montanini": "montanino",
    "montano": "montare",
    "montante": "montare",
    "montanti": "montare",
    "montar": "montare",
    "montaron": "montare",
    "montarono": "montare",
    "montarozzi": "montarozzo",
    "montasse": "montare",
    "montasser": "montare",
    "montassero": "montare",
    "montassi": "montare",
    "montassimo": "montare",
    "montaste": "montare",
    "montasti": "montare",
    "montata": "montato",
    "montate": "montato",
    "montati": "montato",
    "montato": "montare",
    "montatori": "montatore",
    "montature": "montatura",
    "montava": "montare",
    "montavamo": "montare",
    "montavan": "montare",
    "montavano": "montare",
    "montavate": "montare",
    "montavi": "montare",
    "montavo": "montare",
    "montenegrini": "montenegrino",
    "monterai": "montare",
    "monteran": "montare",
    "monteranno": "montare",
    "monterebbe": "montare",
    "monterebber": "montare",
    "monterebbero": "montare",
    "monterei": "montare",
    "monteremmo": "montare",
    "monteremo": "montare",
    "montereste": "montare",
    "monteresti": "montare",
    "monterete": "montare",
    "monterà": "montare",
    "monterò": "montare",
    "monti": "monte",
    "montiamo": "montare",
    "montiate": "montare",
    "montin": "montare",
    "montiniana": "montiniano",
    "montiniane": "montiniano",
    "montiniani": "montiniano",
    "montino": "montare",
    "monto": "montare",
    "montoni": "montone",
    "montuosa": "montuoso",
    "montuose": "montuoso",
    "montuosi": "montuoso",
    "montò": "montare",
    "monumentali": "monumentale",
    "monumentalizza": "monumentalizzare",
    "monumentalizzai": "monumentalizzare",
    "monumentalizzammo": "monumentalizzare",
    "monumentalizzan": "monumentalizzare",
    "monumentalizzando": "monumentalizzare",
    "monumentalizzano": "monumentalizzare",
    "monumentalizzante": "monumentalizzare",
    "monumentalizzanti": "monumentalizzare",
    "monumentalizzar": "monumentalizzare",
    "monumentalizzaron": "monumentalizzare",
    "monumentalizzarono": "monumentalizzare",
    "monumentalizzasse": "monumentalizzare",
    "monumentalizzasser": "monumentalizzare",
    "monumentalizzassero": "monumentalizzare",
    "monumentalizzassi": "monumentalizzare",
    "monumentalizzassimo": "monumentalizzare",
    "monumentalizzaste": "monumentalizzare",
    "monumentalizzasti": "monumentalizzare",
    "monumentalizzata": "monumentalizzare",
    "monumentalizzate": "monumentalizzare",
    "monumentalizzati": "monumentalizzare",
    "monumentalizzato": "monumentalizzare",
    "monumentalizzava": "monumentalizzare",
    "monumentalizzavamo": "monumentalizzare",
    "monumentalizzavan": "monumentalizzare",
    "monumentalizzavano": "monumentalizzare",
    "monumentalizzavate": "monumentalizzare",
    "monumentalizzavi": "monumentalizzare",
    "monumentalizzavo": "monumentalizzare",
    "monumentalizzerai": "monumentalizzare",
    "monumentalizzeran": "monumentalizzare",
    "monumentalizzeranno": "monumentalizzare",
    "monumentalizzerebbe": "monumentalizzare",
    "monumentalizzerebber": "monumentalizzare",
    "monumentalizzerebbero": "monumentalizzare",
    "monumentalizzerei": "monumentalizzare",
    "monumentalizzeremmo": "monumentalizzare",
    "monumentalizzeremo": "monumentalizzare",
    "monumentalizzereste": "monumentalizzare",
    "monumentalizzeresti": "monumentalizzare",
    "monumentalizzerete": "monumentalizzare",
    "monumentalizzerà": "monumentalizzare",
    "monumentalizzerò": "monumentalizzare",
    "monumentalizzi": "monumentalizzare",
    "monumentalizziamo": "monumentalizzare",
    "monumentalizziate": "monumentalizzare",
    "monumentalizzin": "monumentalizzare",
    "monumentalizzino": "monumentalizzare",
    "monumentalizzo": "monumentalizzare",
    "monumentalizzò": "monumentalizzare",
    "monumenti": "monumento",
    "monzesi": "monzese",
    "mora": "moro",
    "moraleggerai": "moraleggiare",
    "moraleggeran": "moraleggiare",
    "moraleggeranno": "moraleggiare",
    "moraleggerebbe": "moraleggiare",
    "moraleggerebber": "moraleggiare",
    "moraleggerebbero": "moraleggiare",
    "moraleggerei": "moraleggiare",
    "moraleggeremmo": "moraleggiare",
    "moraleggeremo": "moraleggiare",
    "moraleggereste": "moraleggiare",
    "moraleggeresti": "moraleggiare",
    "moraleggerete": "moraleggiare",
    "moraleggerà": "moraleggiare",
    "moraleggerò": "moraleggiare",
    "moraleggi": "moraleggiare",
    "moraleggia": "moraleggiare",
    "moraleggiai": "moraleggiare",
    "moraleggiammo": "moraleggiare",
    "moraleggiamo": "moraleggiare",
    "moraleggian": "moraleggiare",
    "moraleggiando": "moraleggiare",
    "moraleggiano": "moraleggiare",
    "moraleggiante": "moraleggiare",
    "moraleggianti": "moraleggiare",
    "moraleggiar": "moraleggiare",
    "moraleggiaron": "moraleggiare",
    "moraleggiarono": "moraleggiare",
    "moraleggiasse": "moraleggiare",
    "moraleggiasser": "moraleggiare",
    "moraleggiassero": "moraleggiare",
    "moraleggiassi": "moraleggiare",
    "moraleggiassimo": "moraleggiare",
    "moraleggiaste": "moraleggiare",
    "moraleggiasti": "moraleggiare",
    "moraleggiata": "moraleggiare",
    "moraleggiate": "moraleggiare",
    "moraleggiati": "moraleggiare",
    "moraleggiato": "moraleggiare",
    "moraleggiava": "moraleggiare",
    "moraleggiavamo": "moraleggiare",
    "moraleggiavan": "moraleggiare",
    "moraleggiavano": "moraleggiare",
    "moraleggiavate": "moraleggiare",
    "moraleggiavi": "moraleggiare",
    "moraleggiavo": "moraleggiare",
    "moraleggin": "moraleggiare",
    "moraleggino": "moraleggiare",
    "moraleggio": "moraleggiare",
    "moraleggiò": "moraleggiare",
    "morali": "morale",
    "moralismi": "moralismo",
    "moraliste": "moralista",
    "moralisti": "moralista",
    "moralistica": "moralistico",
    "moralistiche": "moralistico",
    "moralistici": "moralistico",
    "moralizza": "moralizzare",
    "moralizzai": "moralizzare",
    "moralizzammo": "moralizzare",
    "moralizzan": "moralizzare",
    "moralizzando": "moralizzare",
    "moralizzano": "moralizzare",
    "moralizzante": "moralizzare",
    "moralizzanti": "moralizzare",
    "moralizzar": "moralizzare",
    "moralizzaron": "moralizzare",
    "moralizzarono": "moralizzare",
    "moralizzasse": "moralizzare",
    "moralizzasser": "moralizzare",
    "moralizzassero": "moralizzare",
    "moralizzassi": "moralizzare",
    "moralizzassimo": "moralizzare",
    "moralizzaste": "moralizzare",
    "moralizzasti": "moralizzare",
    "moralizzata": "moralizzare",
    "moralizzate": "moralizzare",
    "moralizzati": "moralizzare",
    "moralizzato": "moralizzare",
    "moralizzatori": "moralizzatore",
    "moralizzatrice": "moralizzatore",
    "moralizzatrici": "moralizzatore",
    "moralizzava": "moralizzare",
    "moralizzavamo": "moralizzare",
    "moralizzavan": "moralizzare",
    "moralizzavano": "moralizzare",
    "moralizzavate": "moralizzare",
    "moralizzavi": "moralizzare",
    "moralizzavo": "moralizzare",
    "moralizzazioni": "moralizzazione",
    "moralizzerai": "moralizzare",
    "moralizzeran": "moralizzare",
    "moralizzeranno": "moralizzare",
    "moralizzerebbe": "moralizzare",
    "moralizzerebber": "moralizzare",
    "moralizzerebbero": "moralizzare",
    "moralizzerei": "moralizzare",
    "moralizzeremmo": "moralizzare",
    "moralizzeremo": "moralizzare",
    "moralizzereste": "moralizzare",
    "moralizzeresti": "moralizzare",
    "moralizzerete": "moralizzare",
    "moralizzerà": "moralizzare",
    "moralizzerò": "moralizzare",
    "moralizzi": "moralizzare",
    "moralizziamo": "moralizzare",
    "moralizziate": "moralizzare",
    "moralizzin": "moralizzare",
    "moralizzino": "moralizzare",
    "moralizzo": "moralizzare",
    "moralizzò": "moralizzare",
    "moratori": "moratorio",
    "moratoria": "moratorio",
    "moratorie": "moratorio",
    "morbi": "morbo",
    "morbida": "morbido",
    "morbide": "morbido",
    "morbidezze": "morbidezza",
    "morbidi": "morbido",
    "morbilli": "morbillo",
    "morbosa": "morboso",
    "morbose": "morboso",
    "morbosi": "morboso",
    "morda": "mordere",
    "mordaci": "mordace",
    "mordan": "mordere",
    "mordano": "mordere",
    "morde": "mordere",
    "mordemmo": "mordere",
    "mordendo": "mordere",
    "mordente": "mordere",
    "mordenti": "mordere",
    "morder": "mordere",
    "morderai": "mordere",
    "morderan": "mordere",
    "morderanno": "mordere",
    "morderebbe": "mordere",
    "morderebber": "mordere",
    "morderebbero": "mordere",
    "morderei": "mordere",
    "morderemmo": "mordere",
    "morderemo": "mordere",
    "mordereste": "mordere",
    "morderesti": "mordere",
    "morderete": "mordere",
    "morderà": "mordere",
    "morderò": "mordere",
    "mordesse": "mordere",
    "mordesser": "mordere",
    "mordessero": "mordere",
    "mordessi": "mordere",
    "mordessimo": "mordere",
    "mordeste": "mordere",
    "mordesti": "mordere",
    "mordete": "mordere",
    "mordeva": "mordere",
    "mordevamo": "mordere",
    "mordevan": "mordere",
    "mordevano": "mordere",
    "mordevate": "mordere",
    "mordevi": "mordere",
    "mordevo": "mordere",
    "mordi": "mordere",
    "mordiamo": "mordere",
    "mordiate": "mordere",
    "mordicchi": "mordicchiare",
    "mordicchia": "mordicchiare",
    "mordicchiai": "mordicchiare",
    "mordicchiammo": "mordicchiare",
    "mordicchiamo": "mordicchiare",
    "mordicchian": "mordicchiare",
    "mordicchiando": "mordicchiare",
    "mordicchiano": "mordicchiare",
    "mordicchiante": "mordicchiare",
    "mordicchianti": "mordicchiare",
    "mordicchiar": "mordicchiare",
    "mordicchiaron": "mordicchiare",
    "mordicchiarono": "mordicchiare",
    "mordicchiasse": "mordicchiare",
    "mordicchiasser": "mordicchiare",
    "mordicchiassero": "mordicchiare",
    "mordicchiassi": "mordicchiare",
    "mordicchiassimo": "mordicchiare",
    "mordicchiaste": "mordicchiare",
    "mordicchiasti": "mordicchiare",
    "mordicchiata": "mordicchiare",
    "mordicchiate": "mordicchiare",
    "mordicchiati": "mordicchiare",
    "mordicchiato": "mordicchiare",
    "mordicchiava": "mordicchiare",
    "mordicchiavamo": "mordicchiare",
    "mordicchiavan": "mordicchiare",
    "mordicchiavano": "mordicchiare",
    "mordicchiavate": "mordicchiare",
    "mordicchiavi": "mordicchiare",
    "mordicchiavo": "mordicchiare",
    "mordicchierai": "mordicchiare",
    "mordicchieran": "mordicchiare",
    "mordicchieranno": "mordicchiare",
    "mordicchierebbe": "mordicchiare",
    "mordicchierebber": "mordicchiare",
    "mordicchierebbero": "mordicchiare",
    "mordicchierei": "mordicchiare",
    "mordicchieremmo": "mordicchiare",
    "mordicchieremo": "mordicchiare",
    "mordicchiereste": "mordicchiare",
    "mordicchieresti": "mordicchiare",
    "mordicchierete": "mordicchiare",
    "mordicchierà": "mordicchiare",
    "mordicchierò": "mordicchiare",
    "mordicchin": "mordicchiare",
    "mordicchino": "mordicchiare",
    "mordicchio": "mordicchiare",
    "mordicchiò": "mordicchiare",
    "mordo": "mordere",
    "mordon": "mordere",
    "mordono": "mordere",
    "more": "moro",
    "morella": "morello",
    "morelle": "morello",
    "morelli": "morello",
    "morendo": "morire",
    "morente": "morire",
    "morenti": "morire",
    "moresca": "moresco",
    "moresche": "moresco",
    "moreschi": "moresco",
    "morette": "moretta",
    "moretti": "moretto",
    "morfologica": "morfologico",
    "morfologiche": "morfologico",
    "morfologici": "morfologico",
    "morfologie": "morfologia",
    "mori": "moro",
    "moriamo": "morire",
    "moriate": "morire",
    "moribonda": "moribondo",
    "moribonde": "moribondo",
    "moribondi": "moribondo",
    "morie": "moria",
    "morigerata": "morigerato",
    "morigerate": "morigerato",
    "morigerati": "morigerato",
    "morii": "morire",
    "morimmo": "morire",
    "morir": "morire",
    "morirai": "morire",
    "moriran": "morire",
    "moriranno": "morire",
    "morirebbe": "morire",
    "morirebber": "morire",
    "morirebbero": "morire",
    "morirei": "morire",
    "moriremmo": "morire",
    "moriremo": "morire",
    "morireste": "morire",
    "moriresti": "morire",
    "morirete": "morire",
    "moriron": "morire",
    "morirono": "morire",
    "morirà": "morire",
    "morirò": "morire",
    "morisse": "morire",
    "morisser": "morire",
    "morissero": "morire",
    "morissi": "morire",
    "morissimo": "morire",
    "moriste": "morire",
    "moristi": "morire",
    "morite": "morire",
    "moritura": "morituro",
    "moriture": "morituro",
    "morituri": "morituro",
    "moriva": "morire",
    "morivamo": "morire",
    "morivan": "morire",
    "morivano": "morire",
    "morivate": "morire",
    "morivi": "morire",
    "morivo": "morire",
    "mormoni": "mormone",
    "mormora": "mormorare",
    "mormorai": "mormorare",
    "mormorammo": "mormorare",
    "mormoran": "mormorare",
    "mormorando": "mormorare",
    "mormorano": "mormorare",
    "mormorante": "mormorare",
    "mormoranti": "mormorare",
    "mormorar": "mormorare",
    "mormoraron": "mormorare",
    "mormorarono": "mormorare",
    "mormorasse": "mormorare",
    "mormorasser": "mormorare",
    "mormorassero": "mormorare",
    "mormorassi": "mormorare",
    "mormorassimo": "mormorare",
    "mormoraste": "mormorare",
    "mormorasti": "mormorare",
    "mormorata": "mormorare",
    "mormorate": "mormorare",
    "mormorati": "mormorare",
    "mormorato": "mormorare",
    "mormorava": "mormorare",
    "mormoravamo": "mormorare",
    "mormoravan": "mormorare",
    "mormoravano": "mormorare",
    "mormoravate": "mormorare",
    "mormoravi": "mormorare",
    "mormoravo": "mormorare",
    "mormorerai": "mormorare",
    "mormoreran": "mormorare",
    "mormoreranno": "mormorare",
    "mormorerebbe": "mormorare",
    "mormorerebber": "mormorare",
    "mormorerebbero": "mormorare",
    "mormorerei": "mormorare",
    "mormoreremmo": "mormorare",
    "mormoreremo": "mormorare",
    "mormorereste": "mormorare",
    "mormoreresti": "mormorare",
    "mormorerete": "mormorare",
    "mormorerà": "mormorare",
    "mormorerò": "mormorare",
    "mormori": "mormorare",
    "mormoriamo": "mormorare",
    "mormoriate": "mormorare",
    "mormorii": "mormorio",
    "mormorin": "mormorare",
    "mormorino": "mormorare",
    "mormoro": "mormorare",
    "mormorò": "mormorare",
    "morosa": "moroso",
    "morose": "moroso",
    "morosi": "moroso",
    "morotei": "moroteo",
    "morsa": "morso",
    "morse": "morso",
    "morser": "mordere",
    "morsero": "mordere",
    "morsi": "morso",
    "morsica": "morsicare",
    "morsicai": "morsicare",
    "morsicammo": "morsicare",
    "morsican": "morsicare",
    "morsicando": "morsicare",
    "morsicano": "morsicare",
    "morsicante": "morsicare",
    "morsicanti": "morsicare",
    "morsicar": "morsicare",
    "morsicaron": "morsicare",
    "morsicarono": "morsicare",
    "morsicasse": "morsicare",
    "morsicasser": "morsicare",
    "morsicassero": "morsicare",
    "morsicassi": "morsicare",
    "morsicassimo": "morsicare",
    "morsicaste": "morsicare",
    "morsicasti": "morsicare",
    "morsicata": "morsicare",
    "morsicate": "morsicare",
    "morsicati": "morsicare",
    "morsicato": "morsicare",
    "morsicava": "morsicare",
    "morsicavamo": "morsicare",
    "morsicavan": "morsicare",
    "morsicavano": "morsicare",
    "morsicavate": "morsicare",
    "morsicavi": "morsicare",
    "morsicavo": "morsicare",
    "morsicherai": "morsicare",
    "morsicheran": "morsicare",
    "morsicheranno": "morsicare",
    "morsicherebbe": "morsicare",
    "morsicherebber": "morsicare",
    "morsicherebbero": "morsicare",
    "morsicherei": "morsicare",
    "morsicheremmo": "morsicare",
    "morsicheremo": "morsicare",
    "morsichereste": "morsicare",
    "morsicheresti": "morsicare",
    "morsicherete": "morsicare",
    "morsicherà": "morsicare",
    "morsicherò": "morsicare",
    "morsichi": "morsicare",
    "morsichiamo": "morsicare",
    "morsichiate": "morsicare",
    "morsichin": "morsicare",
    "morsichino": "morsicare",
    "morsico": "morsicare",
    "morsicò": "morsicare",
    "morso": "mordere",
    "morsè": "mordere",
    "morta": "morto",
    "mortadelle": "mortadella",
    "mortai": "mortaio",
    "mortali": "mortale",
    "mortaretti": "mortaretto",
    "morte": "morto",
    "morti": "morto",
    "mortifera": "mortifero",
    "mortifere": "mortifero",
    "mortiferi": "mortifero",
    "mortifica": "mortificare",
    "mortificai": "mortificare",
    "mortificammo": "mortificare",
    "mortifican": "mortificare",
    "mortificando": "mortificare",
    "mortificano": "mortificare",
    "mortificante": "mortificare",
    "mortificanti": "mortificare",
    "mortificar": "mortificare",
    "mortificaron": "mortificare",
    "mortificarono": "mortificare",
    "mortificasse": "mortificare",
    "mortificasser": "mortificare",
    "mortificassero": "mortificare",
    "mortificassi": "mortificare",
    "mortificassimo": "mortificare",
    "mortificaste": "mortificare",
    "mortificasti": "mortificare",
    "mortificata": "mortificare",
    "mortificate": "mortificare",
    "mortificati": "mortificare",
    "mortificato": "mortificare",
    "mortificava": "mortificare",
    "mortificavamo": "mortificare",
    "mortificavan": "mortificare",
    "mortificavano": "mortificare",
    "mortificavate": "mortificare",
    "mortificavi": "mortificare",
    "mortificavo": "mortificare",
    "mortificazioni": "mortificazione",
    "mortificherai": "mortificare",
    "mortificheran": "mortificare",
    "mortificheranno": "mortificare",
    "mortificherebbe": "mortificare",
    "mortificherebber": "mortificare",
    "mortificherebbero": "mortificare",
    "mortificherei": "mortificare",
    "mortificheremmo": "mortificare",
    "mortificheremo": "mortificare",
    "mortifichereste": "mortificare",
    "mortificheresti": "mortificare",
    "mortificherete": "mortificare",
    "mortificherà": "mortificare",
    "mortificherò": "mortificare",
    "mortifichi": "mortificare",
    "mortifichiamo": "mortificare",
    "mortifichiate": "mortificare",
    "mortifichin": "mortificare",
    "mortifichino": "mortificare",
    "mortifico": "mortificare",
    "mortificò": "mortificare",
    "morto": "morire",
    "morì": "morire",
    "mosaici": "mosaico",
    "mosce": "moscio",
    "moscerini": "moscerino",
    "mosche": "mosca",
    "moschee": "moschea",
    "moschetti": "moschetto",
    "moschettieri": "moschettiere",
    "moschettoni": "moschettone",
    "moschicide": "moschicida",
    "moschicidi": "moschicida",
    "mosci": "moscio",
    "moscia": "moscio",
    "mosconi": "moscone",
    "moscovite": "moscovita",
    "moscoviti": "moscovita",
    "mossa": "muovere",
    "mosse": "muovere",
    "mosser": "muovere",
    "mossero": "muovere",
    "mossi": "muovere",
    "mosso": "muovere",
    "mosti": "mosto",
    "mostra": "mostrare",
    "mostrabili": "mostrabile",
    "mostrai": "mostrare",
    "mostrammo": "mostrare",
    "mostran": "mostrare",
    "mostrando": "mostrare",
    "mostrano": "mostrare",
    "mostrante": "mostrare",
    "mostranti": "mostrare",
    "mostrar": "mostrare",
    "mostraron": "mostrare",
    "mostrarono": "mostrare",
    "mostrasse": "mostrare",
    "mostrasser": "mostrare",
    "mostrassero": "mostrare",
    "mostrassi": "mostrare",
    "mostrassimo": "mostrare",
    "mostraste": "mostrare",
    "mostrasti": "mostrare",
    "mostrata": "mostrare",
    "mostrate": "mostrare",
    "mostrati": "mostrare",
    "mostrato": "mostrare",
    "mostrava": "mostrare",
    "mostravamo": "mostrare",
    "mostravan": "mostrare",
    "mostravano": "mostrare",
    "mostravate": "mostrare",
    "mostravi": "mostrare",
    "mostravo": "mostrare",
    "mostre": "mostra",
    "mostrerai": "mostrare",
    "mostreran": "mostrare",
    "mostreranno": "mostrare",
    "mostrerebbe": "mostrare",
    "mostrerebber": "mostrare",
    "mostrerebbero": "mostrare",
    "mostrerei": "mostrare",
    "mostreremmo": "mostrare",
    "mostreremo": "mostrare",
    "mostrereste": "mostrare",
    "mostreresti": "mostrare",
    "mostrerete": "mostrare",
    "mostrerà": "mostrare",
    "mostrerò": "mostrare",
    "mostri": "mostro",
    "mostriamo": "mostrare",
    "mostriate": "mostrare",
    "mostriciattoli": "mostriciattolo",
    "mostrin": "mostrare",
    "mostrine": "mostrina",
    "mostrino": "mostrare",
    "mostro": "mostrare",
    "mostruosa": "mostruoso",
    "mostruose": "mostruoso",
    "mostruosi": "mostruoso",
    "mostrò": "mostrare",
    "moti": "moto",
    "motiva": "motivare",
    "motivai": "motivare",
    "motivammo": "motivare",
    "motivan": "motivare",
    "motivando": "motivare",
    "motivano": "motivare",
    "motivante": "motivare",
    "motivanti": "motivare",
    "motivar": "motivare",
    "motivaron": "motivare",
    "motivarono": "motivare",
    "motivasse": "motivare",
    "motivasser": "motivare",
    "motivassero": "motivare",
    "motivassi": "motivare",
    "motivassimo": "motivare",
    "motivaste": "motivare",
    "motivasti": "motivare",
    "motivata": "motivato",
    "motivate": "motivato",
    "motivati": "motivato",
    "motivato": "motivare",
    "motivava": "motivare",
    "motivavamo": "motivare",
    "motivavan": "motivare",
    "motivavano": "motivare",
    "motivavate": "motivare",
    "motivavi": "motivare",
    "motivavo": "motivare",
    "motivazioni": "motivazione",
    "motiverai": "motivare",
    "motiveran": "motivare",
    "motiveranno": "motivare",
    "motiverebbe": "motivare",
    "motiverebber": "motivare",
    "motiverebbero": "motivare",
    "motiverei": "motivare",
    "motiveremmo": "motivare",
    "motiveremo": "motivare",
    "motivereste": "motivare",
    "motiveresti": "motivare",
    "motiverete": "motivare",
    "motiverà": "motivare",
    "motiverò": "motivare",
    "motivetti": "motivetto",
    "motivi": "motivo",
    "motiviamo": "motivare",
    "motiviate": "motivare",
    "motivin": "motivare",
    "motivino": "motivare",
    "motivo": "motivare",
    "motivò": "motivare",
    "motocarri": "motocarro",
    "motociclette": "motocicletta",
    "motocicli": "motociclo",
    "motociclismi": "motociclismo",
    "motociclisti": "motociclista",
    "motociclistica": "motociclistico",
    "motociclistiche": "motociclistico",
    "motociclistici": "motociclistico",
    "motolance": "motolancia",
    "motomondiali": "motomondiale",
    "motonautica": "motonautico",
    "motonautiche": "motonautico",
    "motonautici": "motonautico",
    "motonavi": "motonave",
    "motopescherecci": "motopeschereccio",
    "motopropulsori": "motopropulsore",
    "motorette": "motoretta",
    "motori": "motorio",
    "motoria": "motorio",
    "motorie": "motorio",
    "motorini": "motorino",
    "motoristi": "motorista",
    "motoristica": "motoristico",
    "motoristiche": "motoristico",
    "motoristici": "motoristico",
    "motorizza": "motorizzare",
    "motorizzai": "motorizzare",
    "motorizzammo": "motorizzare",
    "motorizzan": "motorizzare",
    "motorizzando": "motorizzare",
    "motorizzano": "motorizzare",
    "motorizzante": "motorizzare",
    "motorizzanti": "motorizzare",
    "motorizzar": "motorizzare",
    "motorizzaron": "motorizzare",
    "motorizzarono": "motorizzare",
    "motorizzasse": "motorizzare",
    "motorizzasser": "motorizzare",
    "motorizzassero": "motorizzare",
    "motorizzassi": "motorizzare",
    "motorizzassimo": "motorizzare",
    "motorizzaste": "motorizzare",
    "motorizzasti": "motorizzare",
    "motorizzata": "motorizzare",
    "motorizzate": "motorizzare",
    "motorizzati": "motorizzare",
    "motorizzato": "motorizzare",
    "motorizzava": "motorizzare",
    "motorizzavamo": "motorizzare",
    "motorizzavan": "motorizzare",
    "motorizzavano": "motorizzare",
    "motorizzavate": "motorizzare",
    "motorizzavi": "motorizzare",
    "motorizzavo": "motorizzare",
    "motorizzazioni": "motorizzazione",
    "motorizzerai": "motorizzare",
    "motorizzeran": "motorizzare",
    "motorizzeranno": "motorizzare",
    "motorizzerebbe": "motorizzare",
    "motorizzerebber": "motorizzare",
    "motorizzerebbero": "motorizzare",
    "motorizzerei": "motorizzare",
    "motorizzeremmo": "motorizzare",
    "motorizzeremo": "motorizzare",
    "motorizzereste": "motorizzare",
    "motorizzeresti": "motorizzare",
    "motorizzerete": "motorizzare",
    "motorizzerà": "motorizzare",
    "motorizzerò": "motorizzare",
    "motorizzi": "motorizzare",
    "motorizziamo": "motorizzare",
    "motorizziate": "motorizzare",
    "motorizzin": "motorizzare",
    "motorizzino": "motorizzare",
    "motorizzo": "motorizzare",
    "motorizzò": "motorizzare",
    "motoscafi": "motoscafo",
    "motoseghe": "motosega",
    "motoslitte": "motoslitta",
    "motovedette": "motovedetta",
    "motoveicoli": "motoveicolo",
    "motrice": "motore",
    "motrici": "motrice",
    "motteggerai": "motteggiare",
    "motteggeran": "motteggiare",
    "motteggeranno": "motteggiare",
    "motteggerebbe": "motteggiare",
    "motteggerebber": "motteggiare",
    "motteggerebbero": "motteggiare",
    "motteggerei": "motteggiare",
    "motteggeremmo": "motteggiare",
    "motteggeremo": "motteggiare",
    "motteggereste": "motteggiare",
    "motteggeresti": "motteggiare",
    "motteggerete": "motteggiare",
    "motteggerà": "motteggiare",
    "motteggerò": "motteggiare",
    "motteggi": "motteggiare",
    "motteggia": "motteggiare",
    "motteggiai": "motteggiare",
    "motteggiammo": "motteggiare",
    "motteggiamo": "motteggiare",
    "motteggian": "motteggiare",
    "motteggiando": "motteggiare",
    "motteggiano": "motteggiare",
    "motteggiante": "motteggiare",
    "motteggianti": "motteggiare",
    "motteggiar": "motteggiare",
    "motteggiaron": "motteggiare",
    "motteggiarono": "motteggiare",
    "motteggiasse": "motteggiare",
    "motteggiasser": "motteggiare",
    "motteggiassero": "motteggiare",
    "motteggiassi": "motteggiare",
    "motteggiassimo": "motteggiare",
    "motteggiaste": "motteggiare",
    "motteggiasti": "motteggiare",
    "motteggiata": "motteggiare",
    "motteggiate": "motteggiare",
    "motteggiati": "motteggiare",
    "motteggiato": "motteggiare",
    "motteggiava": "motteggiare",
    "motteggiavamo": "motteggiare",
    "motteggiavan": "motteggiare",
    "motteggiavano": "motteggiare",
    "motteggiavate": "motteggiare",
    "motteggiavi": "motteggiare",
    "motteggiavo": "motteggiare",
    "motteggin": "motteggiare",
    "motteggino": "motteggiare",
    "motteggio": "motteggiare",
    "motteggiò": "motteggiare",
    "mottetti": "mottetto",
    "motti": "motto",
    "moventi": "movente",
    "movenze": "movenza",
    "movibili": "movibile",
    "movimenta": "movimentare",
    "movimentai": "movimentare",
    "movimentammo": "movimentare",
    "movimentan": "movimentare",
    "movimentando": "movimentare",
    "movimentano": "movimentare",
    "movimentante": "movimentare",
    "movimentanti": "movimentare",
    "movimentar": "movimentare",
    "movimentaron": "movimentare",
    "movimentarono": "movimentare",
    "movimentasse": "movimentare",
    "movimentasser": "movimentare",
    "movimentassero": "movimentare",
    "movimentassi": "movimentare",
    "movimentassimo": "movimentare",
    "movimentaste": "movimentare",
    "movimentasti": "movimentare",
    "movimentata": "movimentare",
    "movimentate": "movimentare",
    "movimentati": "movimentare",
    "movimentato": "movimentare",
    "movimentava": "movimentare",
    "movimentavamo": "movimentare",
    "movimentavan": "movimentare",
    "movimentavano": "movimentare",
    "movimentavate": "movimentare",
    "movimentavi": "movimentare",
    "movimentavo": "movimentare",
    "movimentazioni": "movimentazione",
    "movimenterai": "movimentare",
    "movimenteran": "movimentare",
    "movimenteranno": "movimentare",
    "movimenterebbe": "movimentare",
    "movimenterebber": "movimentare",
    "movimenterebbero": "movimentare",
    "movimenterei": "movimentare",
    "movimenteremmo": "movimentare",
    "movimenteremo": "movimentare",
    "movimentereste": "movimentare",
    "movimenteresti": "movimentare",
    "movimenterete": "movimentare",
    "movimenterà": "movimentare",
    "movimenterò": "movimentare",
    "movimenti": "movimento",
    "movimentiamo": "movimentare",
    "movimentiate": "movimentare",
    "movimentin": "movimentare",
    "movimentino": "movimentare",
    "movimentismi": "movimentismo",
    "movimentisti": "movimentiste",
    "movimento": "movimentare",
    "movimentò": "movimentare",
    "moviole": "moviola",
    "mozambicani": "mozambicano",
    "mozartiana": "mozartiano",
    "mozartiane": "mozartiano",
    "mozartiani": "mozartiano",
    "mozioni": "mozione",
    "mozza": "mozzo",
    "mozzafiata": "mozzafiato",
    "mozzafiate": "mozzafiato",
    "mozzafiati": "mozzafiato",
    "mozzai": "mozzare",
    "mozzammo": "mozzare",
    "mozzan": "mozzare",
    "mozzando": "mozzare",
    "mozzano": "mozzare",
    "mozzante": "mozzare",
    "mozzanti": "mozzare",
    "mozzar": "mozzare",
    "mozzarelle": "mozzarella",
    "mozzaron": "mozzare",
    "mozzarono": "mozzare",
    "mozzasse": "mozzare",
    "mozzasser": "mozzare",
    "mozzassero": "mozzare",
    "mozzassi": "mozzare",
    "mozzassimo": "mozzare",
    "mozzaste": "mozzare",
    "mozzasti": "mozzare",
    "mozzata": "mozzare",
    "mozzate": "mozzare",
    "mozzati": "mozzare",
    "mozzato": "mozzare",
    "mozzava": "mozzare",
    "mozzavamo": "mozzare",
    "mozzavan": "mozzare",
    "mozzavano": "mozzare",
    "mozzavate": "mozzare",
    "mozzavi": "mozzare",
    "mozzavo": "mozzare",
    "mozze": "mozzo",
    "mozzerai": "mozzare",
    "mozzeran": "mozzare",
    "mozzeranno": "mozzare",
    "mozzerebbe": "mozzare",
    "mozzerebber": "mozzare",
    "mozzerebbero": "mozzare",
    "mozzerei": "mozzare",
    "mozzeremmo": "mozzare",
    "mozzeremo": "mozzare",
    "mozzereste": "mozzare",
    "mozzeresti": "mozzare",
    "mozzerete": "mozzare",
    "mozzerà": "mozzare",
    "mozzerò": "mozzare",
    "mozzi": "mozzo",
    "mozziamo": "mozzare",
    "mozziate": "mozzare",
    "mozziconi": "mozzicone",
    "mozzin": "mozzare",
    "mozzino": "mozzare",
    "mozzo": "mozzare",
    "mozzò": "mozzare",
    "mucche": "mucca",
    "mucchi": "mucchio",
    "mucchietti": "mucchietto",
    "muchi": "muco",
    "mucillaggini": "mucillaggine",
    "mucillagini": "mucillagine",
    "muffa": "muffo",
    "muffan": "muffire",
    "muffano": "muffire",
    "muffe": "muffo",
    "muffendo": "muffire",
    "muffente": "muffire",
    "muffenti": "muffire",
    "muffi": "muffo",
    "muffiamo": "muffire",
    "muffiate": "muffire",
    "muffii": "muffire",
    "muffimmo": "muffire",
    "muffir": "muffire",
    "muffirai": "muffire",
    "muffiran": "muffire",
    "muffiranno": "muffire",
    "muffirebbe": "muffire",
    "muffirebber": "muffire",
    "muffirebbero": "muffire",
    "muffirei": "muffire",
    "muffiremmo": "muffire",
    "muffiremo": "muffire",
    "muffireste": "muffire",
    "muffiresti": "muffire",
    "muffirete": "muffire",
    "muffiron": "muffire",
    "muffirono": "muffire",
    "muffirà": "muffire",
    "muffirò": "muffire",
    "muffisse": "muffire",
    "muffisser": "muffire",
    "muffissero": "muffire",
    "muffissi": "muffire",
    "muffissimo": "muffire",
    "muffiste": "muffire",
    "muffisti": "muffire",
    "muffita": "muffire",
    "muffite": "muffire",
    "muffiti": "muffire",
    "muffito": "muffire",
    "muffiva": "muffire",
    "muffivamo": "muffire",
    "muffivan": "muffire",
    "muffivano": "muffire",
    "muffivate": "muffire",
    "muffivi": "muffire",
    "muffivo": "muffire",
    "muffo": "muffire",
    "muffon": "muffire",
    "muffono": "muffire",
    "muffì": "muffire",
    "mufloni": "muflone",
    "mugga": "muggire",
    "muggan": "muggire",
    "muggano": "muggire",
    "mugge": "muggire",
    "muggendo": "muggire",
    "muggente": "muggire",
    "muggenti": "muggire",
    "mugghi": "mugghiare",
    "mugghia": "mugghiare",
    "mugghiai": "mugghiare",
    "mugghiammo": "mugghiare",
    "mugghiamo": "mugghiare",
    "mugghian": "mugghiare",
    "mugghiando": "mugghiare",
    "mugghiano": "mugghiare",
    "mugghiante": "mugghiare",
    "mugghianti": "mugghiare",
    "mugghiar": "mugghiare",
    "mugghiaron": "mugghiare",
    "mugghiarono": "mugghiare",
    "mugghiasse": "mugghiare",
    "mugghiasser": "mugghiare",
    "mugghiassero": "mugghiare",
    "mugghiassi": "mugghiare",
    "mugghiassimo": "mugghiare",
    "mugghiaste": "mugghiare",
    "mugghiasti": "mugghiare",
    "mugghiata": "mugghiare",
    "mugghiate": "mugghiare",
    "mugghiati": "mugghiare",
    "mugghiato": "mugghiare",
    "mugghiava": "mugghiare",
    "mugghiavamo": "mugghiare",
    "mugghiavan": "mugghiare",
    "mugghiavano": "mugghiare",
    "mugghiavate": "mugghiare",
    "mugghiavi": "mugghiare",
    "mugghiavo": "mugghiare",
    "mugghierai": "mugghiare",
    "mugghieran": "mugghiare",
    "mugghieranno": "mugghiare",
    "mugghierebbe": "mugghiare",
    "mugghierebber": "mugghiare",
    "mugghierebbero": "mugghiare",
    "mugghierei": "mugghiare",
    "mugghieremmo": "mugghiare",
    "mugghieremo": "mugghiare",
    "mugghiereste": "mugghiare",
    "mugghieresti": "mugghiare",
    "mugghierete": "mugghiare",
    "mugghierà": "mugghiare",
    "mugghierò": "mugghiare",
    "mugghin": "mugghiare",
    "mugghino": "mugghiare",
    "mugghio": "mugghiare",
    "mugghiò": "mugghiare",
    "muggi": "muggire",
    "muggiamo": "muggire",
    "muggiate": "muggire",
    "muggii": "muggire",
    "muggimmo": "muggire",
    "muggir": "muggire",
    "muggirai": "muggire",
    "muggiran": "muggire",
    "muggiranno": "muggire",
    "muggirebbe": "muggire",
    "muggirebber": "muggire",
    "muggirebbero": "muggire",
    "muggirei": "muggire",
    "muggiremmo": "muggire",
    "muggiremo": "muggire",
    "muggireste": "muggire",
    "muggiresti": "muggire",
    "muggirete": "muggire",
    "muggiron": "muggire",
    "muggirono": "muggire",
    "muggirà": "muggire",
    "muggirò": "muggire",
    "muggisse": "muggire",
    "muggisser": "muggire",
    "muggissero": "muggire",
    "muggissi": "muggire",
    "muggissimo": "muggire",
    "muggiste": "muggire",
    "muggisti": "muggire",
    "muggita": "muggire",
    "muggite": "muggire",
    "muggiti": "muggito",
    "muggito": "muggire",
    "muggiva": "muggire",
    "muggivamo": "muggire",
    "muggivan": "muggire",
    "muggivano": "muggire",
    "muggivate": "muggire",
    "muggivi": "muggire",
    "muggivo": "muggire",
    "muggo": "muggire",
    "muggon": "muggire",
    "muggono": "muggire",
    "muggì": "muggire",
    "mugola": "mugolare",
    "mugolai": "mugolare",
    "mugolammo": "mugolare",
    "mugolan": "mugolare",
    "mugolando": "mugolare",
    "mugolano": "mugolare",
    "mugolante": "mugolare",
    "mugolanti": "mugolare",
    "mugolar": "mugolare",
    "mugolaron": "mugolare",
    "mugolarono": "mugolare",
    "mugolasse": "mugolare",
    "mugolasser": "mugolare",
    "mugolassero": "mugolare",
    "mugolassi": "mugolare",
    "mugolassimo": "mugolare",
    "mugolaste": "mugolare",
    "mugolasti": "mugolare",
    "mugolata": "mugolare",
    "mugolate": "mugolare",
    "mugolati": "mugolare",
    "mugolato": "mugolare",
    "mugolava": "mugolare",
    "mugolavamo": "mugolare",
    "mugolavan": "mugolare",
    "mugolavano": "mugolare",
    "mugolavate": "mugolare",
    "mugolavi": "mugolare",
    "mugolavo": "mugolare",
    "mugolerai": "mugolare",
    "mugoleran": "mugolare",
    "mugoleranno": "mugolare",
    "mugolerebbe": "mugolare",
    "mugolerebber": "mugolare",
    "mugolerebbero": "mugolare",
    "mugolerei": "mugolare",
    "mugoleremmo": "mugolare",
    "mugoleremo": "mugolare",
    "mugolereste": "mugolare",
    "mugoleresti": "mugolare",
    "mugolerete": "mugolare",
    "mugolerà": "mugolare",
    "mugolerò": "mugolare",
    "mugoli": "mugolare",
    "mugoliamo": "mugolare",
    "mugoliate": "mugolare",
    "mugolii": "mugolio",
    "mugolin": "mugolare",
    "mugolino": "mugolare",
    "mugolo": "mugolare",
    "mugolò": "mugolare",
    "mugugna": "mugugnare",
    "mugugnai": "mugugnare",
    "mugugnammo": "mugugnare",
    "mugugnan": "mugugnare",
    "mugugnando": "mugugnare",
    "mugugnano": "mugugnare",
    "mugugnante": "mugugnare",
    "mugugnanti": "mugugnare",
    "mugugnar": "mugugnare",
    "mugugnaron": "mugugnare",
    "mugugnarono": "mugugnare",
    "mugugnasse": "mugugnare",
    "mugugnasser": "mugugnare",
    "mugugnassero": "mugugnare",
    "mugugnassi": "mugugnare",
    "mugugnassimo": "mugugnare",
    "mugugnaste": "mugugnare",
    "mugugnasti": "mugugnare",
    "mugugnata": "mugugnare",
    "mugugnate": "mugugnare",
    "mugugnati": "mugugnare",
    "mugugnato": "mugugnare",
    "mugugnava": "mugugnare",
    "mugugnavamo": "mugugnare",
    "mugugnavan": "mugugnare",
    "mugugnavano": "mugugnare",
    "mugugnavate": "mugugnare",
    "mugugnavi": "mugugnare",
    "mugugnavo": "mugugnare",
    "mugugnerai": "mugugnare",
    "mugugneran": "mugugnare",
    "mugugneranno": "mugugnare",
    "mugugnerebbe": "mugugnare",
    "mugugnerebber": "mugugnare",
    "mugugnerebbero": "mugugnare",
    "mugugnerei": "mugugnare",
    "mugugneremmo": "mugugnare",
    "mugugneremo": "mugugnare",
    "mugugnereste": "mugugnare",
    "mugugneresti": "mugugnare",
    "mugugnerete": "mugugnare",
    "mugugnerà": "mugugnare",
    "mugugnerò": "mugugnare",
    "mugugni": "mugugno",
    "mugugniamo": "mugugnare",
    "mugugniate": "mugugnare",
    "mugugnin": "mugugnare",
    "mugugnino": "mugugnare",
    "mugugno": "mugugnare",
    "mugugnò": "mugugnare",
    "mulatta": "mulatto",
    "mulatte": "mulatto",
    "mulatti": "mulatto",
    "mulattiera": "mulattiero",
    "mulattiere": "mulattiero",
    "mulattieri": "mulattiero",
    "muletti": "muletto",
    "muli": "mulo",
    "muliebri": "muliebre",
    "mulina": "mulinare",
    "mulinai": "mulinare",
    "mulinammo": "mulinare",
    "mulinan": "mulinare",
    "mulinando": "mulinare",
    "mulinano": "mulinare",
    "mulinante": "mulinare",
    "mulinanti": "mulinare",
    "mulinar": "mulinare",
    "mulinaron": "mulinare",
    "mulinarono": "mulinare",
    "mulinasse": "mulinare",
    "mulinasser": "mulinare",
    "mulinassero": "mulinare",
    "mulinassi": "mulinare",
    "mulinassimo": "mulinare",
    "mulinaste": "mulinare",
    "mulinasti": "mulinare",
    "mulinata": "mulinare",
    "mulinate": "mulinare",
    "mulinati": "mulinare",
    "mulinato": "mulinare",
    "mulinava": "mulinare",
    "mulinavamo": "mulinare",
    "mulinavan": "mulinare",
    "mulinavano": "mulinare",
    "mulinavate": "mulinare",
    "mulinavi": "mulinare",
    "mulinavo": "mulinare",
    "mulinelli": "mulinello",
    "mulinerai": "mulinare",
    "mulineran": "mulinare",
    "mulineranno": "mulinare",
    "mulinerebbe": "mulinare",
    "mulinerebber": "mulinare",
    "mulinerebbero": "mulinare",
    "mulinerei": "mulinare",
    "mulineremmo": "mulinare",
    "mulineremo": "mulinare",
    "mulinereste": "mulinare",
    "mulineresti": "mulinare",
    "mulinerete": "mulinare",
    "mulinerà": "mulinare",
    "mulinerò": "mulinare",
    "mulini": "mulino",
    "muliniamo": "mulinare",
    "muliniate": "mulinare",
    "mulinin": "mulinare",
    "mulinino": "mulinare",
    "mulino": "mulinare",
    "mulinò": "mulinare",
    "multa": "multare",
    "multai": "multare",
    "multammo": "multare",
    "multan": "multare",
    "multando": "multare",
    "multano": "multare",
    "multante": "multare",
    "multanti": "multare",
    "multar": "multare",
    "multaron": "multare",
    "multarono": "multare",
    "multasse": "multare",
    "multasser": "multare",
    "multassero": "multare",
    "multassi": "multare",
    "multassimo": "multare",
    "multaste": "multare",
    "multasti": "multare",
    "multata": "multare",
    "multate": "multare",
    "multati": "multare",
    "multato": "multare",
    "multava": "multare",
    "multavamo": "multare",
    "multavan": "multare",
    "multavano": "multare",
    "multavate": "multare",
    "multavi": "multare",
    "multavo": "multare",
    "multe": "multa",
    "multerai": "multare",
    "multeran": "multare",
    "multeranno": "multare",
    "multerebbe": "multare",
    "multerebber": "multare",
    "multerebbero": "multare",
    "multerei": "multare",
    "multeremmo": "multare",
    "multeremo": "multare",
    "multereste": "multare",
    "multeresti": "multare",
    "multerete": "multare",
    "multerà": "multare",
    "multerò": "multare",
    "multi": "multare",
    "multiamo": "multare",
    "multiate": "multare",
    "multicolori": "multicolore",
    "multiculturali": "multiculturale",
    "multiculturalismi": "multiculturalismo",
    "multietnica": "multietnico",
    "multietniche": "multietnico",
    "multietnici": "multietnico",
    "multiformi": "multiforme",
    "multilaterali": "multilaterale",
    "multilivella": "multilivellare",
    "multilivellai": "multilivellare",
    "multilivellammo": "multilivellare",
    "multilivellan": "multilivellare",
    "multilivellando": "multilivellare",
    "multilivellano": "multilivellare",
    "multilivellante": "multilivellare",
    "multilivellanti": "multilivellare",
    "multilivellar": "multilivellare",
    "multilivellaron": "multilivellare",
    "multilivellarono": "multilivellare",
    "multilivellasse": "multilivellare",
    "multilivellasser": "multilivellare",
    "multilivellassero": "multilivellare",
    "multilivellassi": "multilivellare",
    "multilivellassimo": "multilivellare",
    "multilivellaste": "multilivellare",
    "multilivellasti": "multilivellare",
    "multilivellata": "multilivellare",
    "multilivellate": "multilivellare",
    "multilivellati": "multilivellare",
    "multilivellato": "multilivellare",
    "multilivellava": "multilivellare",
    "multilivellavamo": "multilivellare",
    "multilivellavan": "multilivellare",
    "multilivellavano": "multilivellare",
    "multilivellavate": "multilivellare",
    "multilivellavi": "multilivellare",
    "multilivellavo": "multilivellare",
    "multilivellerai": "multilivellare",
    "multilivelleran": "multilivellare",
    "multilivelleranno": "multilivellare",
    "multilivellerebbe": "multilivellare",
    "multilivellerebber": "multilivellare",
    "multilivellerebbero": "multilivellare",
    "multilivellerei": "multilivellare",
    "multilivelleremmo": "multilivellare",
    "multilivelleremo": "multilivellare",
    "multilivellereste": "multilivellare",
    "multilivelleresti": "multilivellare",
    "multilivellerete": "multilivellare",
    "multilivellerà": "multilivellare",
    "multilivellerò": "multilivellare",
    "multilivelli": "multilivellare",
    "multilivelliamo": "multilivellare",
    "multilivelliate": "multilivellare",
    "multilivellin": "multilivellare",
    "multilivellino": "multilivellare",
    "multilivello": "multilivellare",
    "multilivellò": "multilivellare",
    "multimediali": "multimediale",
    "multimiliardari": "multimiliardario",
    "multimiliardaria": "multimiliardario",
    "multimiliardarie": "multimiliardario",
    "multimilionari": "multimilionario",
    "multimilionaria": "multimilionario",
    "multimilionarie": "multimilionario",
    "multin": "multare",
    "multinazionali": "multinazionale",
    "multino": "multare",
    "multipartitica": "multipartitico",
    "multipartitiche": "multipartitico",
    "multipartitici": "multipartitico",
    "multipartitismi": "multipartitismo",
    "multipla": "multiplo",
    "multiple": "multiplo",
    "multipli": "multiplo",
    "multiproprietari": "multiproprietario",
    "multisale": "multisala",
    "multo": "multare",
    "multò": "multare",
    "mummie": "mummia",
    "mummifica": "mummificare",
    "mummificai": "mummificare",
    "mummificammo": "mummificare",
    "mummifican": "mummificare",
    "mummificando": "mummificare",
    "mummificano": "mummificare",
    "mummificante": "mummificare",
    "mummificanti": "mummificare",
    "mummificar": "mummificare",
    "mummificaron": "mummificare",
    "mummificarono": "mummificare",
    "mummificasse": "mummificare",
    "mummificasser": "mummificare",
    "mummificassero": "mummificare",
    "mummificassi": "mummificare",
    "mummificassimo": "mummificare",
    "mummificaste": "mummificare",
    "mummificasti": "mummificare",
    "mummificata": "mummificare",
    "mummificate": "mummificare",
    "mummificati": "mummificare",
    "mummificato": "mummificare",
    "mummificava": "mummificare",
    "mummificavamo": "mummificare",
    "mummificavan": "mummificare",
    "mummificavano": "mummificare",
    "mummificavate": "mummificare",
    "mummificavi": "mummificare",
    "mummificavo": "mummificare",
    "mummificherai": "mummificare",
    "mummificheran": "mummificare",
    "mummificheranno": "mummificare",
    "mummificherebbe": "mummificare",
    "mummificherebber": "mummificare",
    "mummificherebbero": "mummificare",
    "mummificherei": "mummificare",
    "mummificheremmo": "mummificare",
    "mummificheremo": "mummificare",
    "mummifichereste": "mummificare",
    "mummificheresti": "mummificare",
    "mummificherete": "mummificare",
    "mummificherà": "mummificare",
    "mummificherò": "mummificare",
    "mummifichi": "mummificare",
    "mummifichiamo": "mummificare",
    "mummifichiate": "mummificare",
    "mummifichin": "mummificare",
    "mummifichino": "mummificare",
    "mummifico": "mummificare",
    "mummificò": "mummificare",
    "munendo": "munire",
    "munente": "munire",
    "munenti": "munire",
    "munga": "mungere",
    "mungan": "mungere",
    "mungano": "mungere",
    "munge": "mungere",
    "mungemmo": "mungere",
    "mungendo": "mungere",
    "mungente": "mungere",
    "mungenti": "mungere",
    "munger": "mungere",
    "mungerai": "mungere",
    "mungeran": "mungere",
    "mungeranno": "mungere",
    "mungerebbe": "mungere",
    "mungerebber": "mungere",
    "mungerebbero": "mungere",
    "mungerei": "mungere",
    "mungeremmo": "mungere",
    "mungeremo": "mungere",
    "mungereste": "mungere",
    "mungeresti": "mungere",
    "mungerete": "mungere",
    "mungerà": "mungere",
    "mungerò": "mungere",
    "mungesse": "mungere",
    "mungesser": "mungere",
    "mungessero": "mungere",
    "mungessi": "mungere",
    "mungessimo": "mungere",
    "mungeste": "mungere",
    "mungesti": "mungere",
    "mungete": "mungere",
    "mungeva": "mungere",
    "mungevamo": "mungere",
    "mungevan": "mungere",
    "mungevano": "mungere",
    "mungevate": "mungere",
    "mungevi": "mungere",
    "mungevo": "mungere",
    "mungi": "mungere",
    "mungiamo": "mungere",
    "mungiate": "mungere",
    "mungitori": "mungitore",
    "mungitrici": "mungitrice",
    "mungo": "mungere",
    "mungon": "mungere",
    "mungono": "mungere",
    "muniamo": "munire",
    "muniate": "munire",
    "municipali": "municipale",
    "municipalizza": "municipalizzare",
    "municipalizzai": "municipalizzare",
    "municipalizzammo": "municipalizzare",
    "municipalizzan": "municipalizzare",
    "municipalizzando": "municipalizzare",
    "municipalizzano": "municipalizzare",
    "municipalizzante": "municipalizzare",
    "municipalizzanti": "municipalizzare",
    "municipalizzar": "municipalizzare",
    "municipalizzaron": "municipalizzare",
    "municipalizzarono": "municipalizzare",
    "municipalizzasse": "municipalizzare",
    "municipalizzasser": "municipalizzare",
    "municipalizzassero": "municipalizzare",
    "municipalizzassi": "municipalizzare",
    "municipalizzassimo": "municipalizzare",
    "municipalizzaste": "municipalizzare",
    "municipalizzasti": "municipalizzare",
    "municipalizzata": "municipalizzare",
    "municipalizzate": "municipalizzare",
    "municipalizzati": "municipalizzare",
    "municipalizzato": "municipalizzare",
    "municipalizzava": "municipalizzare",
    "municipalizzavamo": "municipalizzare",
    "municipalizzavan": "municipalizzare",
    "municipalizzavano": "municipalizzare",
    "municipalizzavate": "municipalizzare",
    "municipalizzavi": "municipalizzare",
    "municipalizzavo": "municipalizzare",
    "municipalizzerai": "municipalizzare",
    "municipalizzeran": "municipalizzare",
    "municipalizzeranno": "municipalizzare",
    "municipalizzerebbe": "municipalizzare",
    "municipalizzerebber": "municipalizzare",
    "municipalizzerebbero": "municipalizzare",
    "municipalizzerei": "municipalizzare",
    "municipalizzeremmo": "municipalizzare",
    "municipalizzeremo": "municipalizzare",
    "municipalizzereste": "municipalizzare",
    "municipalizzeresti": "municipalizzare",
    "municipalizzerete": "municipalizzare",
    "municipalizzerà": "municipalizzare",
    "municipalizzerò": "municipalizzare",
    "municipalizzi": "municipalizzare",
    "municipalizziamo": "municipalizzare",
    "municipalizziate": "municipalizzare",
    "municipalizzin": "municipalizzare",
    "municipalizzino": "municipalizzare",
    "municipalizzo": "municipalizzare",
    "municipalizzò": "municipalizzare",
    "municipi": "municipio",
    "munifica": "munifico",
    "munificenze": "munificenza",
    "munifiche": "munifico",
    "munifici": "munifico",
    "munii": "munire",
    "munimmo": "munire",
    "munir": "munire",
    "munirai": "munire",
    "muniran": "munire",
    "muniranno": "munire",
    "munirebbe": "munire",
    "munirebber": "munire",
    "munirebbero": "munire",
    "munirei": "munire",
    "muniremmo": "munire",
    "muniremo": "munire",
    "munireste": "munire",
    "muniresti": "munire",
    "munirete": "munire",
    "muniron": "munire",
    "munirono": "munire",
    "munirà": "munire",
    "munirò": "munire",
    "munisca": "munire",
    "muniscan": "munire",
    "muniscano": "munire",
    "munisce": "munire",
    "munisci": "munire",
    "munisco": "munire",
    "muniscon": "munire",
    "muniscono": "munire",
    "munisse": "munire",
    "munisser": "munire",
    "munissero": "munire",
    "munissi": "munire",
    "munissimo": "munire",
    "muniste": "munire",
    "munisti": "munire",
    "munita": "munito",
    "munite": "munito",
    "muniti": "munito",
    "munito": "munire",
    "muniva": "munire",
    "munivamo": "munire",
    "munivan": "munire",
    "munivano": "munire",
    "munivate": "munire",
    "munivi": "munire",
    "munivo": "munire",
    "munizioni": "munizione",
    "munser": "mungere",
    "munsero": "mungere",
    "munsi": "mungere",
    "munsè": "mungere",
    "munta": "mungere",
    "munte": "mungere",
    "munti": "mungere",
    "munto": "mungere",
    "munì": "munire",
    "muoia": "morire",
    "muoian": "morire",
    "muoiano": "morire",
    "muoio": "morire",
    "muoion": "morire",
    "muoiono": "morire",
    "muoni": "muone",
    "muore": "morire",
    "muori": "morire",
    "muova": "muovere",
    "muovan": "muovere",
    "muovano": "muovere",
    "muove": "muovere",
    "muovemmo": "muovere",
    "muovendo": "muovere",
    "muovente": "muovere",
    "muoventi": "muovere",
    "muover": "muovere",
    "muoverai": "muovere",
    "muoveran": "muovere",
    "muoveranno": "muovere",
    "muoverebbe": "muovere",
    "muoverebber": "muovere",
    "muoverebbero": "muovere",
    "muoverei": "muovere",
    "muoveremmo": "muovere",
    "muoveremo": "muovere",
    "muovereste": "muovere",
    "muoveresti": "muovere",
    "muoverete": "muovere",
    "muoverà": "muovere",
    "muoverò": "muovere",
    "muovesse": "muovere",
    "muovesser": "muovere",
    "muovessero": "muovere",
    "muovessi": "muovere",
    "muovessimo": "muovere",
    "muoveste": "muovere",
    "muovesti": "muovere",
    "muovete": "muovere",
    "muoveva": "muovere",
    "muovevamo": "muovere",
    "muovevan": "muovere",
    "muovevano": "muovere",
    "muovevate": "muovere",
    "muovevi": "muovere",
    "muovevo": "muovere",
    "muovi": "muovere",
    "muoviamo": "muovere",
    "muoviate": "muovere",
    "muovo": "muovere",
    "muovon": "muovere",
    "muovono": "muovere",
    "mura": "muro",
    "muraglie": "muraglia",
    "muraglioni": "muraglione",
    "murai": "murare",
    "murali": "murale",
    "murammo": "murare",
    "muran": "murare",
    "murando": "murare",
    "murano": "murare",
    "murante": "murare",
    "muranti": "murare",
    "murar": "murare",
    "murari": "murario",
    "muraria": "murario",
    "murarie": "murario",
    "muraron": "murare",
    "murarono": "murare",
    "murasse": "murare",
    "murasser": "murare",
    "murassero": "murare",
    "murassi": "murare",
    "murassimo": "murare",
    "muraste": "murare",
    "murasti": "murare",
    "murata": "murare",
    "murate": "murare",
    "murati": "murare",
    "murato": "murare",
    "muratori": "muratore",
    "murature": "muratura",
    "murava": "murare",
    "muravamo": "murare",
    "muravan": "murare",
    "muravano": "murare",
    "muravate": "murare",
    "muravi": "murare",
    "muravo": "murare",
    "murerai": "murare",
    "mureran": "murare",
    "mureranno": "murare",
    "murerebbe": "murare",
    "murerebber": "murare",
    "murerebbero": "murare",
    "murerei": "murare",
    "mureremmo": "murare",
    "mureremo": "murare",
    "murereste": "murare",
    "mureresti": "murare",
    "murerete": "murare",
    "murerà": "murare",
    "murerò": "murare",
    "muretti": "muretto",
    "muri": "muro",
    "muriamo": "murare",
    "muriate": "murare",
    "murin": "murare",
    "murino": "murare",
    "muro": "murare",
    "murò": "murare",
    "muschi": "muschio",
    "muscola": "muscolare",
    "muscolai": "muscolare",
    "muscolammo": "muscolare",
    "muscolan": "muscolare",
    "muscolando": "muscolare",
    "muscolano": "muscolare",
    "muscolante": "muscolare",
    "muscolanti": "muscolare",
    "muscolar": "muscolare",
    "muscolari": "muscolare",
    "muscolaron": "muscolare",
    "muscolarono": "muscolare",
    "muscolasse": "muscolare",
    "muscolasser": "muscolare",
    "muscolassero": "muscolare",
    "muscolassi": "muscolare",
    "muscolassimo": "muscolare",
    "muscolaste": "muscolare",
    "muscolasti": "muscolare",
    "muscolata": "muscolare",
    "muscolate": "muscolare",
    "muscolati": "muscolare",
    "muscolato": "muscolare",
    "muscolature": "muscolatura",
    "muscolava": "muscolare",
    "muscolavamo": "muscolare",
    "muscolavan": "muscolare",
    "muscolavano": "muscolare",
    "muscolavate": "muscolare",
    "muscolavi": "muscolare",
    "muscolavo": "muscolare",
    "muscolerai": "muscolare",
    "muscoleran": "muscolare",
    "muscoleranno": "muscolare",
    "muscolerebbe": "muscolare",
    "muscolerebber": "muscolare",
    "muscolerebbero": "muscolare",
    "muscolerei": "muscolare",
    "muscoleremmo": "muscolare",
    "muscoleremo": "muscolare",
    "muscolereste": "muscolare",
    "muscoleresti": "muscolare",
    "muscolerete": "muscolare",
    "muscolerà": "muscolare",
    "muscolerò": "muscolare",
    "muscoli": "muscolo",
    "muscoliamo": "muscolare",
    "muscoliate": "muscolare",
    "muscolin": "muscolare",
    "muscolino": "muscolare",
    "muscolo": "muscolare",
    "muscolosa": "muscoloso",
    "muscolose": "muscoloso",
    "muscolosi": "muscoloso",
    "muscolò": "muscolare",
    "muse": "musa",
    "musei": "museo",
    "museruole": "museruola",
    "musetti": "musetto",
    "musi": "muso",
    "musica": "musico",
    "musicai": "musicare",
    "musicali": "musicale",
    "musicammo": "musicare",
    "musican": "musicare",
    "musicando": "musicare",
    "musicano": "musicare",
    "musicante": "musicare",
    "musicanti": "musicare",
    "musicar": "musicare",
    "musicaron": "musicare",
    "musicarono": "musicare",
    "musicasse": "musicare",
    "musicasser": "musicare",
    "musicassero": "musicare",
    "musicassette": "musicassetta",
    "musicassi": "musicare",
    "musicassimo": "musicare",
    "musicaste": "musicare",
    "musicasti": "musicare",
    "musicata": "musicare",
    "musicate": "musicare",
    "musicati": "musicare",
    "musicato": "musicare",
    "musicava": "musicare",
    "musicavamo": "musicare",
    "musicavan": "musicare",
    "musicavano": "musicare",
    "musicavate": "musicare",
    "musicavi": "musicare",
    "musicavo": "musicare",
    "musiche": "musico",
    "musicherai": "musicare",
    "musicheran": "musicare",
    "musicheranno": "musicare",
    "musicherebbe": "musicare",
    "musicherebber": "musicare",
    "musicherebbero": "musicare",
    "musicherei": "musicare",
    "musicheremmo": "musicare",
    "musicheremo": "musicare",
    "musichereste": "musicare",
    "musicheresti": "musicare",
    "musicherete": "musicare",
    "musicherà": "musicare",
    "musicherò": "musicare",
    "musichette": "musichetta",
    "musichi": "musicare",
    "musichiamo": "musicare",
    "musichiate": "musicare",
    "musichin": "musicare",
    "musichino": "musicare",
    "musici": "musico",
    "musiciste": "musicista",
    "musicisti": "musicista",
    "musico": "musicare",
    "musicofili": "musicofilo",
    "musicologi": "musicologo",
    "musicò": "musicare",
    "musini": "musino",
    "musiva": "musivo",
    "musive": "musivo",
    "musivi": "musivo",
    "mussa": "mussare",
    "mussai": "mussare",
    "mussammo": "mussare",
    "mussan": "mussare",
    "mussando": "mussare",
    "mussano": "mussare",
    "mussante": "mussare",
    "mussanti": "mussare",
    "mussar": "mussare",
    "mussaron": "mussare",
    "mussarono": "mussare",
    "mussasse": "mussare",
    "mussasser": "mussare",
    "mussassero": "mussare",
    "mussassi": "mussare",
    "mussassimo": "mussare",
    "mussaste": "mussare",
    "mussasti": "mussare",
    "mussata": "mussare",
    "mussate": "mussare",
    "mussati": "mussare",
    "mussato": "mussare",
    "mussava": "mussare",
    "mussavamo": "mussare",
    "mussavan": "mussare",
    "mussavano": "mussare",
    "mussavate": "mussare",
    "mussavi": "mussare",
    "mussavo": "mussare",
    "musserai": "mussare",
    "musseran": "mussare",
    "musseranno": "mussare",
    "musserebbe": "mussare",
    "musserebber": "mussare",
    "musserebbero": "mussare",
    "musserei": "mussare",
    "musseremmo": "mussare",
    "musseremo": "mussare",
    "mussereste": "mussare",
    "musseresti": "mussare",
    "musserete": "mussare",
    "musserà": "mussare",
    "musserò": "mussare",
    "mussi": "mussare",
    "mussiamo": "mussare",
    "mussiate": "mussare",
    "mussin": "mussare",
    "mussino": "mussare",
    "musso": "mussare",
    "mussulmana": "mussulmano",
    "mussulmane": "mussulmano",
    "mussulmani": "mussulmano",
    "mussò": "mussare",
    "musulmana": "musulmano",
    "musulmane": "musulmano",
    "musulmani": "musulmano",
    "muta": "muto",
    "mutai": "mutare",
    "mutamenti": "mutamento",
    "mutammo": "mutare",
    "mutan": "mutare",
    "mutande": "mutanda",
    "mutandine": "mutandina",
    "mutando": "mutare",
    "mutandoni": "mutandone",
    "mutano": "mutare",
    "mutante": "mutare",
    "mutanti": "mutare",
    "mutar": "mutare",
    "mutaron": "mutare",
    "mutarono": "mutare",
    "mutasse": "mutare",
    "mutasser": "mutare",
    "mutassero": "mutare",
    "mutassi": "mutare",
    "mutassimo": "mutare",
    "mutaste": "mutare",
    "mutasti": "mutare",
    "mutata": "mutare",
    "mutate": "mutare",
    "mutati": "mutare",
    "mutato": "mutare",
    "mutava": "mutare",
    "mutavamo": "mutare",
    "mutavan": "mutare",
    "mutavano": "mutare",
    "mutavate": "mutare",
    "mutavi": "mutare",
    "mutavo": "mutare",
    "mutazioni": "mutazione",
    "mute": "muto",
    "muterai": "mutare",
    "muteran": "mutare",
    "muteranno": "mutare",
    "muterebbe": "mutare",
    "muterebber": "mutare",
    "muterebbero": "mutare",
    "muterei": "mutare",
    "muteremmo": "mutare",
    "muteremo": "mutare",
    "mutereste": "mutare",
    "muteresti": "mutare",
    "muterete": "mutare",
    "muterà": "mutare",
    "muterò": "mutare",
    "mutevolezze": "mutevolezza",
    "mutevoli": "mutevole",
    "muti": "muto",
    "mutiamo": "mutare",
    "mutiate": "mutare",
    "mutila": "mutilo",
    "mutilai": "mutilare",
    "mutilammo": "mutilare",
    "mutilan": "mutilare",
    "mutilando": "mutilare",
    "mutilano": "mutilare",
    "mutilante": "mutilare",
    "mutilanti": "mutilare",
    "mutilar": "mutilare",
    "mutilaron": "mutilare",
    "mutilarono": "mutilare",
    "mutilasse": "mutilare",
    "mutilasser": "mutilare",
    "mutilassero": "mutilare",
    "mutilassi": "mutilare",
    "mutilassimo": "mutilare",
    "mutilaste": "mutilare",
    "mutilasti": "mutilare",
    "mutilata": "mutilato",
    "mutilate": "mutilato",
    "mutilati": "mutilato",
    "mutilato": "mutilare",
    "mutilava": "mutilare",
    "mutilavamo": "mutilare",
    "mutilavan": "mutilare",
    "mutilavano": "mutilare",
    "mutilavate": "mutilare",
    "mutilavi": "mutilare",
    "mutilavo": "mutilare",
    "mutilazioni": "mutilazione",
    "mutile": "mutilo",
    "mutilerai": "mutilare",
    "mutileran": "mutilare",
    "mutileranno": "mutilare",
    "mutilerebbe": "mutilare",
    "mutilerebber": "mutilare",
    "mutilerebbero": "mutilare",
    "mutilerei": "mutilare",
    "mutileremmo": "mutilare",
    "mutileremo": "mutilare",
    "mutilereste": "mutilare",
    "mutileresti": "mutilare",
    "mutilerete": "mutilare",
    "mutilerà": "mutilare",
    "mutilerò": "mutilare",
    "mutili": "mutilo",
    "mutiliamo": "mutilare",
    "mutiliate": "mutilare",
    "mutilin": "mutilare",
    "mutilino": "mutilare",
    "mutilo": "mutilare",
    "mutilò": "mutilare",
    "mutin": "mutare",
    "mutino": "mutare",
    "mutismi": "mutismo",
    "muto": "mutare",
    "mutua": "mutuo",
    "mutuai": "mutuare",
    "mutualisti": "mutualista",
    "mutualistica": "mutualistico",
    "mutualistiche": "mutualistico",
    "mutualistici": "mutualistico",
    "mutuammo": "mutuare",
    "mutuan": "mutuare",
    "mutuando": "mutuare",
    "mutuano": "mutuare",
    "mutuante": "mutuare",
    "mutuanti": "mutuare",
    "mutuar": "mutuare",
    "mutuaron": "mutuare",
    "mutuarono": "mutuare",
    "mutuasse": "mutuare",
    "mutuasser": "mutuare",
    "mutuassero": "mutuare",
    "mutuassi": "mutuare",
    "mutuassimo": "mutuare",
    "mutuaste": "mutuare",
    "mutuasti": "mutuare",
    "mutuata": "mutuare",
    "mutuatari": "mutuatario",
    "mutuate": "mutuare",
    "mutuati": "mutuare",
    "mutuato": "mutuare",
    "mutuava": "mutuare",
    "mutuavamo": "mutuare",
    "mutuavan": "mutuare",
    "mutuavano": "mutuare",
    "mutuavate": "mutuare",
    "mutuavi": "mutuare",
    "mutuavo": "mutuare",
    "mutue": "mutuo",
    "mutuerai": "mutuare",
    "mutueran": "mutuare",
    "mutueranno": "mutuare",
    "mutuerebbe": "mutuare",
    "mutuerebber": "mutuare",
    "mutuerebbero": "mutuare",
    "mutuerei": "mutuare",
    "mutueremmo": "mutuare",
    "mutueremo": "mutuare",
    "mutuereste": "mutuare",
    "mutueresti": "mutuare",
    "mutuerete": "mutuare",
    "mutuerà": "mutuare",
    "mutuerò": "mutuare",
    "mutui": "mutuo",
    "mutuiamo": "mutuare",
    "mutuiate": "mutuare",
    "mutuin": "mutuare",
    "mutuino": "mutuare",
    "mutuo": "mutuare",
    "mutuò": "mutuare",
    "mutò": "mutare",
    "mète": "mèta",
    "ménages": "ménage",
    "métri": "métro",
    "n'": "ne",
    "nababbi": "nababbo",
    "nacque": "nascere",
    "nacquer": "nascere",
    "nacquero": "nascere",
    "nacqui": "nascere",
    "naie": "naia",
    "nana": "nano",
    "nane": "nano",
    "nanetti": "nanetto",
    "nani": "nano",
    "napoleonica": "napoleonico",
    "napoleoniche": "napoleonico",
    "napoleonici": "napoleonico",
    "napoletana": "napoletano",
    "napoletane": "napoletano",
    "napoletani": "napoletano",
    "nappe": "nappa",
    "narcisi": "narciso",
    "narcisismi": "narcisismo",
    "narcisisti": "narcisista",
    "narcisistica": "narcisistico",
    "narcisistiche": "narcisistico",
    "narcisistici": "narcisistico",
    "narcotica": "narcotico",
    "narcotiche": "narcotico",
    "narcotici": "narcotico",
    "narcotizza": "narcotizzare",
    "narcotizzai": "narcotizzare",
    "narcotizzammo": "narcotizzare",
    "narcotizzan": "narcotizzare",
    "narcotizzando": "narcotizzare",
    "narcotizzano": "narcotizzare",
    "narcotizzante": "narcotizzare",
    "narcotizzanti": "narcotizzare",
    "narcotizzar": "narcotizzare",
    "narcotizzaron": "narcotizzare",
    "narcotizzarono": "narcotizzare",
    "narcotizzasse": "narcotizzare",
    "narcotizzasser": "narcotizzare",
    "narcotizzassero": "narcotizzare",
    "narcotizzassi": "narcotizzare",
    "narcotizzassimo": "narcotizzare",
    "narcotizzaste": "narcotizzare",
    "narcotizzasti": "narcotizzare",
    "narcotizzata": "narcotizzare",
    "narcotizzate": "narcotizzare",
    "narcotizzati": "narcotizzare",
    "narcotizzato": "narcotizzare",
    "narcotizzava": "narcotizzare",
    "narcotizzavamo": "narcotizzare",
    "narcotizzavan": "narcotizzare",
    "narcotizzavano": "narcotizzare",
    "narcotizzavate": "narcotizzare",
    "narcotizzavi": "narcotizzare",
    "narcotizzavo": "narcotizzare",
    "narcotizzerai": "narcotizzare",
    "narcotizzeran": "narcotizzare",
    "narcotizzeranno": "narcotizzare",
    "narcotizzerebbe": "narcotizzare",
    "narcotizzerebber": "narcotizzare",
    "narcotizzerebbero": "narcotizzare",
    "narcotizzerei": "narcotizzare",
    "narcotizzeremmo": "narcotizzare",
    "narcotizzeremo": "narcotizzare",
    "narcotizzereste": "narcotizzare",
    "narcotizzeresti": "narcotizzare",
    "narcotizzerete": "narcotizzare",
    "narcotizzerà": "narcotizzare",
    "narcotizzerò": "narcotizzare",
    "narcotizzi": "narcotizzare",
    "narcotizziamo": "narcotizzare",
    "narcotizziate": "narcotizzare",
    "narcotizzin": "narcotizzare",
    "narcotizzino": "narcotizzare",
    "narcotizzo": "narcotizzare",
    "narcotizzò": "narcotizzare",
    "narcotrafficanti": "narcotrafficante",
    "narici": "narice",
    "narra": "narrare",
    "narrai": "narrare",
    "narrammo": "narrare",
    "narran": "narrare",
    "narrando": "narrare",
    "narrano": "narrare",
    "narrante": "narrare",
    "narranti": "narrare",
    "narrar": "narrare",
    "narraron": "narrare",
    "narrarono": "narrare",
    "narrasse": "narrare",
    "narrasser": "narrare",
    "narrassero": "narrare",
    "narrassi": "narrare",
    "narrassimo": "narrare",
    "narraste": "narrare",
    "narrasti": "narrare",
    "narrata": "narrare",
    "narrate": "narrare",
    "narrati": "narrare",
    "narrativa": "narrativo",
    "narrative": "narrativo",
    "narrativi": "narrativo",
    "narrato": "narrare",
    "narratori": "narratore",
    "narratrici": "narratrice",
    "narrava": "narrare",
    "narravamo": "narrare",
    "narravan": "narrare",
    "narravano": "narrare",
    "narravate": "narrare",
    "narravi": "narrare",
    "narravo": "narrare",
    "narrazioni": "narrazione",
    "narrerai": "narrare",
    "narreran": "narrare",
    "narreranno": "narrare",
    "narrerebbe": "narrare",
    "narrerebber": "narrare",
    "narrerebbero": "narrare",
    "narrerei": "narrare",
    "narreremmo": "narrare",
    "narreremo": "narrare",
    "narrereste": "narrare",
    "narreresti": "narrare",
    "narrerete": "narrare",
    "narrerà": "narrare",
    "narrerò": "narrare",
    "narri": "narrare",
    "narriamo": "narrare",
    "narriate": "narrare",
    "narrin": "narrare",
    "narrino": "narrare",
    "narro": "narrare",
    "narrò": "narrare",
    "nasali": "nasale",
    "nasca": "nascere",
    "nascan": "nascere",
    "nascano": "nascere",
    "nasce": "nascere",
    "nascemmo": "nascere",
    "nascendo": "nascere",
    "nascente": "nascere",
    "nascenti": "nascere",
    "nascer": "nascere",
    "nascerai": "nascere",
    "nasceran": "nascere",
    "nasceranno": "nascere",
    "nascerebbe": "nascere",
    "nascerebber": "nascere",
    "nascerebbero": "nascere",
    "nascerei": "nascere",
    "nasceremmo": "nascere",
    "nasceremo": "nascere",
    "nascereste": "nascere",
    "nasceresti": "nascere",
    "nascerete": "nascere",
    "nascerà": "nascere",
    "nascerò": "nascere",
    "nascesse": "nascere",
    "nascesser": "nascere",
    "nascessero": "nascere",
    "nascessi": "nascere",
    "nascessimo": "nascere",
    "nasceste": "nascere",
    "nascesti": "nascere",
    "nascete": "nascere",
    "nasceva": "nascere",
    "nascevamo": "nascere",
    "nascevan": "nascere",
    "nascevano": "nascere",
    "nascevate": "nascere",
    "nascevi": "nascere",
    "nascevo": "nascere",
    "nasci": "nascere",
    "nasciamo": "nascere",
    "nasciate": "nascere",
    "nascite": "nascita",
    "nascitura": "nascituro",
    "nasciture": "nascituro",
    "nascituri": "nascituro",
    "nasco": "nascere",
    "nascon": "nascere",
    "nasconda": "nascondere",
    "nascondan": "nascondere",
    "nascondano": "nascondere",
    "nasconde": "nascondere",
    "nascondemmo": "nascondere",
    "nascondendo": "nascondere",
    "nascondente": "nascondere",
    "nascondenti": "nascondere",
    "nasconder": "nascondere",
    "nasconderai": "nascondere",
    "nasconderan": "nascondere",
    "nasconderanno": "nascondere",
    "nasconderebbe": "nascondere",
    "nasconderebber": "nascondere",
    "nasconderebbero": "nascondere",
    "nasconderei": "nascondere",
    "nasconderemmo": "nascondere",
    "nasconderemo": "nascondere",
    "nascondereste": "nascondere",
    "nasconderesti": "nascondere",
    "nasconderete": "nascondere",
    "nasconderà": "nascondere",
    "nasconderò": "nascondere",
    "nascondesse": "nascondere",
    "nascondesser": "nascondere",
    "nascondessero": "nascondere",
    "nascondessi": "nascondere",
    "nascondessimo": "nascondere",
    "nascondeste": "nascondere",
    "nascondesti": "nascondere",
    "nascondete": "nascondere",
    "nascondeva": "nascondere",
    "nascondevamo": "nascondere",
    "nascondevan": "nascondere",
    "nascondevano": "nascondere",
    "nascondevate": "nascondere",
    "nascondevi": "nascondere",
    "nascondevo": "nascondere",
    "nascondi": "nascondere",
    "nascondiamo": "nascondere",
    "nascondiate": "nascondere",
    "nascondigli": "nascondiglio",
    "nascondimenti": "nascondimento",
    "nascondo": "nascondere",
    "nascondon": "nascondere",
    "nascondono": "nascondere",
    "nascono": "nascere",
    "nascoser": "nascondere",
    "nascosero": "nascondere",
    "nascosi": "nascondere",
    "nascosta": "nascosto",
    "nascoste": "nascosto",
    "nascosti": "nascosto",
    "nascosto": "nascondere",
    "nascosè": "nascondere",
    "nasi": "naso",
    "nasini": "nasino",
    "nasoni": "nasone",
    "nastri": "nastro",
    "nastrini": "nastrino",
    "nata": "nato",
    "natali": "natale",
    "natalizi": "natalizio",
    "natalizia": "natalizio",
    "natalizie": "natalizio",
    "natanti": "natante",
    "natatori": "natatorio",
    "natatoria": "natatorio",
    "natatorie": "natatorio",
    "nate": "nato",
    "nati": "nato",
    "natia": "natio",
    "natiche": "natica",
    "natie": "natio",
    "nativa": "nativo",
    "native": "nativo",
    "nativi": "nativo",
    "nato": "nascere",
    "naturalezze": "naturalezza",
    "naturali": "naturale",
    "naturalismi": "naturalismo",
    "naturalisti": "naturalista",
    "naturalistica": "naturalistico",
    "naturalistiche": "naturalistico",
    "naturalistici": "naturalistico",
    "naturalizza": "naturalizzare",
    "naturalizzai": "naturalizzare",
    "naturalizzammo": "naturalizzare",
    "naturalizzan": "naturalizzare",
    "naturalizzando": "naturalizzare",
    "naturalizzano": "naturalizzare",
    "naturalizzante": "naturalizzare",
    "naturalizzanti": "naturalizzare",
    "naturalizzar": "naturalizzare",
    "naturalizzaron": "naturalizzare",
    "naturalizzarono": "naturalizzare",
    "naturalizzasse": "naturalizzare",
    "naturalizzasser": "naturalizzare",
    "naturalizzassero": "naturalizzare",
    "naturalizzassi": "naturalizzare",
    "naturalizzassimo": "naturalizzare",
    "naturalizzaste": "naturalizzare",
    "naturalizzasti": "naturalizzare",
    "naturalizzata": "naturalizzare",
    "naturalizzate": "naturalizzare",
    "naturalizzati": "naturalizzare",
    "naturalizzato": "naturalizzare",
    "naturalizzava": "naturalizzare",
    "naturalizzavamo": "naturalizzare",
    "naturalizzavan": "naturalizzare",
    "naturalizzavano": "naturalizzare",
    "naturalizzavate": "naturalizzare",
    "naturalizzavi": "naturalizzare",
    "naturalizzavo": "naturalizzare",
    "naturalizzazioni": "naturalizzazione",
    "naturalizzerai": "naturalizzare",
    "naturalizzeran": "naturalizzare",
    "naturalizzeranno": "naturalizzare",
    "naturalizzerebbe": "naturalizzare",
    "naturalizzerebber": "naturalizzare",
    "naturalizzerebbero": "naturalizzare",
    "naturalizzerei": "naturalizzare",
    "naturalizzeremmo": "naturalizzare",
    "naturalizzeremo": "naturalizzare",
    "naturalizzereste": "naturalizzare",
    "naturalizzeresti": "naturalizzare",
    "naturalizzerete": "naturalizzare",
    "naturalizzerà": "naturalizzare",
    "naturalizzerò": "naturalizzare",
    "naturalizzi": "naturalizzare",
    "naturalizziamo": "naturalizzare",
    "naturalizziate": "naturalizzare",
    "naturalizzin": "naturalizzare",
    "naturalizzino": "naturalizzare",
    "naturalizzo": "naturalizzare",
    "naturalizzò": "naturalizzare",
    "nature": "natura",
    "naturisti": "naturista",
    "naufraga": "naufragare",
    "naufragai": "naufragare",
    "naufragammo": "naufragare",
    "naufragan": "naufragare",
    "naufragando": "naufragare",
    "naufragano": "naufragare",
    "naufragante": "naufragare",
    "naufraganti": "naufragare",
    "naufragar": "naufragare",
    "naufragaron": "naufragare",
    "naufragarono": "naufragare",
    "naufragasse": "naufragare",
    "naufragasser": "naufragare",
    "naufragassero": "naufragare",
    "naufragassi": "naufragare",
    "naufragassimo": "naufragare",
    "naufragaste": "naufragare",
    "naufragasti": "naufragare",
    "naufragata": "naufragare",
    "naufragate": "naufragare",
    "naufragati": "naufragare",
    "naufragato": "naufragare",
    "naufragava": "naufragare",
    "naufragavamo": "naufragare",
    "naufragavan": "naufragare",
    "naufragavano": "naufragare",
    "naufragavate": "naufragare",
    "naufragavi": "naufragare",
    "naufragavo": "naufragare",
    "naufragherai": "naufragare",
    "naufragheran": "naufragare",
    "naufragheranno": "naufragare",
    "naufragherebbe": "naufragare",
    "naufragherebber": "naufragare",
    "naufragherebbero": "naufragare",
    "naufragherei": "naufragare",
    "naufragheremmo": "naufragare",
    "naufragheremo": "naufragare",
    "naufraghereste": "naufragare",
    "naufragheresti": "naufragare",
    "naufragherete": "naufragare",
    "naufragherà": "naufragare",
    "naufragherò": "naufragare",
    "naufraghi": "naufrago",
    "naufraghiamo": "naufragare",
    "naufraghiate": "naufragare",
    "naufraghin": "naufragare",
    "naufraghino": "naufragare",
    "naufragi": "naufragio",
    "naufrago": "naufragare",
    "naufragò": "naufragare",
    "nausea": "nauseare",
    "nauseabonda": "nauseabondo",
    "nauseabonde": "nauseabondo",
    "nauseabondi": "nauseabondo",
    "nauseai": "nauseare",
    "nauseammo": "nauseare",
    "nausean": "nauseare",
    "nauseando": "nauseare",
    "nauseano": "nauseare",
    "nauseante": "nauseare",
    "nauseanti": "nauseare",
    "nausear": "nauseare",
    "nausearon": "nauseare",
    "nausearono": "nauseare",
    "nauseasse": "nauseare",
    "nauseasser": "nauseare",
    "nauseassero": "nauseare",
    "nauseassi": "nauseare",
    "nauseassimo": "nauseare",
    "nauseaste": "nauseare",
    "nauseasti": "nauseare",
    "nauseata": "nauseare",
    "nauseate": "nauseare",
    "nauseati": "nauseare",
    "nauseato": "nauseare",
    "nauseava": "nauseare",
    "nauseavamo": "nauseare",
    "nauseavan": "nauseare",
    "nauseavano": "nauseare",
    "nauseavate": "nauseare",
    "nauseavi": "nauseare",
    "nauseavo": "nauseare",
    "nausee": "nausea",
    "nauseerai": "nauseare",
    "nauseeran": "nauseare",
    "nauseeranno": "nauseare",
    "nauseerebbe": "nauseare",
    "nauseerebber": "nauseare",
    "nauseerebbero": "nauseare",
    "nauseerei": "nauseare",
    "nauseeremmo": "nauseare",
    "nauseeremo": "nauseare",
    "nauseereste": "nauseare",
    "nauseeresti": "nauseare",
    "nauseerete": "nauseare",
    "nauseerà": "nauseare",
    "nauseerò": "nauseare",
    "nausei": "nauseare",
    "nauseiamo": "nauseare",
    "nauseiate": "nauseare",
    "nausein": "nauseare",
    "nauseino": "nauseare",
    "nauseo": "nauseare",
    "nauseò": "nauseare",
    "nautica": "nautico",
    "nautiche": "nautico",
    "nautici": "nautico",
    "navali": "navale",
    "navate": "navata",
    "navette": "navetta",
    "navi": "nave",
    "navicelle": "navicella",
    "naviga": "navigare",
    "navigabili": "navigabile",
    "navigai": "navigare",
    "navigammo": "navigare",
    "navigan": "navigare",
    "navigando": "navigare",
    "navigano": "navigare",
    "navigante": "navigare",
    "naviganti": "navigare",
    "navigar": "navigare",
    "navigaron": "navigare",
    "navigarono": "navigare",
    "navigasse": "navigare",
    "navigasser": "navigare",
    "navigassero": "navigare",
    "navigassi": "navigare",
    "navigassimo": "navigare",
    "navigaste": "navigare",
    "navigasti": "navigare",
    "navigata": "navigato",
    "navigate": "navigato",
    "navigati": "navigato",
    "navigato": "navigare",
    "navigatori": "navigatorio",
    "navigatoria": "navigatorio",
    "navigatorie": "navigatorio",
    "navigatrice": "navigatore",
    "navigatrici": "navigatore",
    "navigava": "navigare",
    "navigavamo": "navigare",
    "navigavan": "navigare",
    "navigavano": "navigare",
    "navigavate": "navigare",
    "navigavi": "navigare",
    "navigavo": "navigare",
    "navigazioni": "navigazione",
    "navigherai": "navigare",
    "navigheran": "navigare",
    "navigheranno": "navigare",
    "navigherebbe": "navigare",
    "navigherebber": "navigare",
    "navigherebbero": "navigare",
    "navigherei": "navigare",
    "navigheremmo": "navigare",
    "navigheremo": "navigare",
    "navighereste": "navigare",
    "navigheresti": "navigare",
    "navigherete": "navigare",
    "navigherà": "navigare",
    "navigherò": "navigare",
    "navighi": "navigare",
    "navighiamo": "navigare",
    "navighiate": "navigare",
    "navighin": "navigare",
    "navighino": "navigare",
    "navigli": "naviglio",
    "navigo": "navigare",
    "navigò": "navigare",
    "nazarena": "nazareno",
    "nazarene": "nazareno",
    "nazareni": "nazareno",
    "nazi-fasciste": "nazi-fascista",
    "nazi-fascisti": "nazi-fascista",
    "nazifascismi": "nazifascismo",
    "nazional-popolari": "nazional-popolare",
    "nazionali": "nazionale",
    "nazionalismi": "nazionalismo",
    "nazionaliste": "nazionalista",
    "nazionalisti": "nazionalista",
    "nazionalistica": "nazionalistico",
    "nazionalistiche": "nazionalistico",
    "nazionalistici": "nazionalistico",
    "nazionalizza": "nazionalizzare",
    "nazionalizzai": "nazionalizzare",
    "nazionalizzammo": "nazionalizzare",
    "nazionalizzan": "nazionalizzare",
    "nazionalizzando": "nazionalizzare",
    "nazionalizzano": "nazionalizzare",
    "nazionalizzante": "nazionalizzare",
    "nazionalizzanti": "nazionalizzare",
    "nazionalizzar": "nazionalizzare",
    "nazionalizzaron": "nazionalizzare",
    "nazionalizzarono": "nazionalizzare",
    "nazionalizzasse": "nazionalizzare",
    "nazionalizzasser": "nazionalizzare",
    "nazionalizzassero": "nazionalizzare",
    "nazionalizzassi": "nazionalizzare",
    "nazionalizzassimo": "nazionalizzare",
    "nazionalizzaste": "nazionalizzare",
    "nazionalizzasti": "nazionalizzare",
    "nazionalizzata": "nazionalizzare",
    "nazionalizzate": "nazionalizzare",
    "nazionalizzati": "nazionalizzare",
    "nazionalizzato": "nazionalizzare",
    "nazionalizzava": "nazionalizzare",
    "nazionalizzavamo": "nazionalizzare",
    "nazionalizzavan": "nazionalizzare",
    "nazionalizzavano": "nazionalizzare",
    "nazionalizzavate": "nazionalizzare",
    "nazionalizzavi": "nazionalizzare",
    "nazionalizzavo": "nazionalizzare",
    "nazionalizzazioni": "nazionalizzazione",
    "nazionalizzerai": "nazionalizzare",
    "nazionalizzeran": "nazionalizzare",
    "nazionalizzeranno": "nazionalizzare",
    "nazionalizzerebbe": "nazionalizzare",
    "nazionalizzerebber": "nazionalizzare",
    "nazionalizzerebbero": "nazionalizzare",
    "nazionalizzerei": "nazionalizzare",
    "nazionalizzeremmo": "nazionalizzare",
    "nazionalizzeremo": "nazionalizzare",
    "nazionalizzereste": "nazionalizzare",
    "nazionalizzeresti": "nazionalizzare",
    "nazionalizzerete": "nazionalizzare",
    "nazionalizzerà": "nazionalizzare",
    "nazionalizzerò": "nazionalizzare",
    "nazionalizzi": "nazionalizzare",
    "nazionalizziamo": "nazionalizzare",
    "nazionalizziate": "nazionalizzare",
    "nazionalizzin": "nazionalizzare",
    "nazionalizzino": "nazionalizzare",
    "nazionalizzo": "nazionalizzare",
    "nazionalizzò": "nazionalizzare",
    "nazionalsocialismi": "nazionalsocialismo",
    "nazionalsocialiste": "nazionalsocialista",
    "nazionalsocialisti": "nazionalsocialista",
    "nazioni": "nazione",
    "nazismi": "nazismo",
    "naziste": "nazista",
    "nazisti": "nazista",
    "nebbie": "nebbia",
    "nebbioline": "nebbiolina",
    "nebbioni": "nebbione",
    "nebbiosa": "nebbioso",
    "nebbiose": "nebbioso",
    "nebbiosi": "nebbioso",
    "nebulizza": "nebulizzare",
    "nebulizzai": "nebulizzare",
    "nebulizzammo": "nebulizzare",
    "nebulizzan": "nebulizzare",
    "nebulizzando": "nebulizzare",
    "nebulizzano": "nebulizzare",
    "nebulizzante": "nebulizzare",
    "nebulizzanti": "nebulizzare",
    "nebulizzar": "nebulizzare",
    "nebulizzaron": "nebulizzare",
    "nebulizzarono": "nebulizzare",
    "nebulizzasse": "nebulizzare",
    "nebulizzasser": "nebulizzare",
    "nebulizzassero": "nebulizzare",
    "nebulizzassi": "nebulizzare",
    "nebulizzassimo": "nebulizzare",
    "nebulizzaste": "nebulizzare",
    "nebulizzasti": "nebulizzare",
    "nebulizzata": "nebulizzare",
    "nebulizzate": "nebulizzare",
    "nebulizzati": "nebulizzare",
    "nebulizzato": "nebulizzare",
    "nebulizzava": "nebulizzare",
    "nebulizzavamo": "nebulizzare",
    "nebulizzavan": "nebulizzare",
    "nebulizzavano": "nebulizzare",
    "nebulizzavate": "nebulizzare",
    "nebulizzavi": "nebulizzare",
    "nebulizzavo": "nebulizzare",
    "nebulizzerai": "nebulizzare",
    "nebulizzeran": "nebulizzare",
    "nebulizzeranno": "nebulizzare",
    "nebulizzerebbe": "nebulizzare",
    "nebulizzerebber": "nebulizzare",
    "nebulizzerebbero": "nebulizzare",
    "nebulizzerei": "nebulizzare",
    "nebulizzeremmo": "nebulizzare",
    "nebulizzeremo": "nebulizzare",
    "nebulizzereste": "nebulizzare",
    "nebulizzeresti": "nebulizzare",
    "nebulizzerete": "nebulizzare",
    "nebulizzerà": "nebulizzare",
    "nebulizzerò": "nebulizzare",
    "nebulizzi": "nebulizzare",
    "nebulizziamo": "nebulizzare",
    "nebulizziate": "nebulizzare",
    "nebulizzin": "nebulizzare",
    "nebulizzino": "nebulizzare",
    "nebulizzo": "nebulizzare",
    "nebulizzò": "nebulizzare",
    "nebulosa": "nebuloso",
    "nebulose": "nebuloso",
    "nebulosi": "nebuloso",
    "necessari": "necessario",
    "necessaria": "necessario",
    "necessarie": "necessario",
    "necessita": "necessitare",
    "necessitai": "necessitare",
    "necessitammo": "necessitare",
    "necessitan": "necessitare",
    "necessitando": "necessitare",
    "necessitano": "necessitare",
    "necessitante": "necessitare",
    "necessitanti": "necessitare",
    "necessitar": "necessitare",
    "necessitaron": "necessitare",
    "necessitarono": "necessitare",
    "necessitasse": "necessitare",
    "necessitasser": "necessitare",
    "necessitassero": "necessitare",
    "necessitassi": "necessitare",
    "necessitassimo": "necessitare",
    "necessitaste": "necessitare",
    "necessitasti": "necessitare",
    "necessitata": "necessitare",
    "necessitate": "necessitare",
    "necessitati": "necessitare",
    "necessitato": "necessitare",
    "necessitava": "necessitare",
    "necessitavamo": "necessitare",
    "necessitavan": "necessitare",
    "necessitavano": "necessitare",
    "necessitavate": "necessitare",
    "necessitavi": "necessitare",
    "necessitavo": "necessitare",
    "necessiterai": "necessitare",
    "necessiteran": "necessitare",
    "necessiteranno": "necessitare",
    "necessiterebbe": "necessitare",
    "necessiterebber": "necessitare",
    "necessiterebbero": "necessitare",
    "necessiterei": "necessitare",
    "necessiteremmo": "necessitare",
    "necessiteremo": "necessitare",
    "necessitereste": "necessitare",
    "necessiteresti": "necessitare",
    "necessiterete": "necessitare",
    "necessiterà": "necessitare",
    "necessiterò": "necessitare",
    "necessiti": "necessitare",
    "necessitiamo": "necessitare",
    "necessitiate": "necessitare",
    "necessitin": "necessitare",
    "necessitino": "necessitare",
    "necessito": "necessitare",
    "necessitò": "necessitare",
    "necrofila": "necrofilo",
    "necrofile": "necrofilo",
    "necrofili": "necrofilo",
    "necrofori": "necroforo",
    "necrologi": "necrologio",
    "necroscopica": "necroscopico",
    "necroscopiche": "necroscopico",
    "necroscopici": "necroscopico",
    "necrotizza": "necrotizzare",
    "necrotizzai": "necrotizzare",
    "necrotizzammo": "necrotizzare",
    "necrotizzan": "necrotizzare",
    "necrotizzando": "necrotizzare",
    "necrotizzano": "necrotizzare",
    "necrotizzante": "necrotizzare",
    "necrotizzanti": "necrotizzare",
    "necrotizzar": "necrotizzare",
    "necrotizzaron": "necrotizzare",
    "necrotizzarono": "necrotizzare",
    "necrotizzasse": "necrotizzare",
    "necrotizzasser": "necrotizzare",
    "necrotizzassero": "necrotizzare",
    "necrotizzassi": "necrotizzare",
    "necrotizzassimo": "necrotizzare",
    "necrotizzaste": "necrotizzare",
    "necrotizzasti": "necrotizzare",
    "necrotizzata": "necrotizzare",
    "necrotizzate": "necrotizzare",
    "necrotizzati": "necrotizzare",
    "necrotizzato": "necrotizzare",
    "necrotizzava": "necrotizzare",
    "necrotizzavamo": "necrotizzare",
    "necrotizzavan": "necrotizzare",
    "necrotizzavano": "necrotizzare",
    "necrotizzavate": "necrotizzare",
    "necrotizzavi": "necrotizzare",
    "necrotizzavo": "necrotizzare",
    "necrotizzerai": "necrotizzare",
    "necrotizzeran": "necrotizzare",
    "necrotizzeranno": "necrotizzare",
    "necrotizzerebbe": "necrotizzare",
    "necrotizzerebber": "necrotizzare",
    "necrotizzerebbero": "necrotizzare",
    "necrotizzerei": "necrotizzare",
    "necrotizzeremmo": "necrotizzare",
    "necrotizzeremo": "necrotizzare",
    "necrotizzereste": "necrotizzare",
    "necrotizzeresti": "necrotizzare",
    "necrotizzerete": "necrotizzare",
    "necrotizzerà": "necrotizzare",
    "necrotizzerò": "necrotizzare",
    "necrotizzi": "necrotizzare",
    "necrotizziamo": "necrotizzare",
    "necrotizziate": "necrotizzare",
    "necrotizzin": "necrotizzare",
    "necrotizzino": "necrotizzare",
    "necrotizzo": "necrotizzare",
    "necrotizzò": "necrotizzare",
    "nefanda": "nefando",
    "nefande": "nefando",
    "nefandezze": "nefandezza",
    "nefandi": "nefando",
    "nefasta": "nefasto",
    "nefaste": "nefasto",
    "nefasti": "nefasto",
    "nega": "negare",
    "negai": "negare",
    "negammo": "negare",
    "negan": "negare",
    "negando": "negare",
    "negano": "negare",
    "negante": "negare",
    "neganti": "negare",
    "negar": "negare",
    "negaron": "negare",
    "negarono": "negare",
    "negasse": "negare",
    "negasser": "negare",
    "negassero": "negare",
    "negassi": "negare",
    "negassimo": "negare",
    "negaste": "negare",
    "negasti": "negare",
    "negata": "negato",
    "negate": "negato",
    "negati": "negato",
    "negativa": "negativo",
    "negative": "negativo",
    "negativi": "negativo",
    "negato": "negare",
    "negatori": "negatore",
    "negatrice": "negatore",
    "negatrici": "negatore",
    "negava": "negare",
    "negavamo": "negare",
    "negavan": "negare",
    "negavano": "negare",
    "negavate": "negare",
    "negavi": "negare",
    "negavo": "negare",
    "negazioni": "negazione",
    "negherai": "negare",
    "negheran": "negare",
    "negheranno": "negare",
    "negherebbe": "negare",
    "negherebber": "negare",
    "negherebbero": "negare",
    "negherei": "negare",
    "negheremmo": "negare",
    "negheremo": "negare",
    "neghereste": "negare",
    "negheresti": "negare",
    "negherete": "negare",
    "negherà": "negare",
    "negherò": "negare",
    "neghi": "negare",
    "neghiamo": "negare",
    "neghiate": "negare",
    "neghin": "negare",
    "neghino": "negare",
    "neghittosa": "neghittoso",
    "neghittose": "neghittoso",
    "neghittosi": "neghittoso",
    "negletta": "negletto",
    "neglette": "negletto",
    "negletti": "negletto",
    "negli": "nel",
    "negliga": "negligere",
    "negligan": "negligere",
    "negligano": "negligere",
    "neglige": "negligere",
    "negligei": "negligere",
    "negligemmo": "negligere",
    "negligendo": "negligere",
    "negligente": "negligere",
    "negligenti": "negligere",
    "negligenze": "negligenza",
    "negliger": "negligere",
    "negligerai": "negligere",
    "negligeran": "negligere",
    "negligeranno": "negligere",
    "negligerebbe": "negligere",
    "negligerebber": "negligere",
    "negligerebbero": "negligere",
    "negligerei": "negligere",
    "negligeremmo": "negligere",
    "negligeremo": "negligere",
    "negligereste": "negligere",
    "negligeresti": "negligere",
    "negligerete": "negligere",
    "negligeron": "negligere",
    "negligerono": "negligere",
    "negligerà": "negligere",
    "negligerò": "negligere",
    "negligesse": "negligere",
    "negligesser": "negligere",
    "negligessero": "negligere",
    "negligessi": "negligere",
    "negligessimo": "negligere",
    "negligeste": "negligere",
    "negligesti": "negligere",
    "negligete": "negligere",
    "negligeva": "negligere",
    "negligevamo": "negligere",
    "negligevan": "negligere",
    "negligevano": "negligere",
    "negligevate": "negligere",
    "negligevi": "negligere",
    "negligevo": "negligere",
    "negligi": "negligere",
    "negligiamo": "negligere",
    "negligiate": "negligere",
    "negligiuta": "negligere",
    "negligiute": "negligere",
    "negligiuti": "negligere",
    "negligiuto": "negligere",
    "negligo": "negligere",
    "negligon": "negligere",
    "negligono": "negligere",
    "negligè": "negligere",
    "nego": "negare",
    "negozi": "negozio",
    "negozia": "negoziare",
    "negoziabili": "negoziabile",
    "negoziai": "negoziare",
    "negoziali": "negoziale",
    "negoziammo": "negoziare",
    "negoziamo": "negoziare",
    "negozian": "negoziare",
    "negoziando": "negoziare",
    "negoziano": "negoziare",
    "negoziante": "negoziare",
    "negozianti": "negoziare",
    "negoziar": "negoziare",
    "negoziaron": "negoziare",
    "negoziarono": "negoziare",
    "negoziasse": "negoziare",
    "negoziasser": "negoziare",
    "negoziassero": "negoziare",
    "negoziassi": "negoziare",
    "negoziassimo": "negoziare",
    "negoziaste": "negoziare",
    "negoziasti": "negoziare",
    "negoziata": "negoziato",
    "negoziate": "negoziato",
    "negoziati": "negoziato",
    "negoziato": "negoziare",
    "negoziatori": "negoziatore",
    "negoziava": "negoziare",
    "negoziavamo": "negoziare",
    "negoziavan": "negoziare",
    "negoziavano": "negoziare",
    "negoziavate": "negoziare",
    "negoziavi": "negoziare",
    "negoziavo": "negoziare",
    "negoziazioni": "negoziazione",
    "negozierai": "negoziare",
    "negozieran": "negoziare",
    "negozieranno": "negoziare",
    "negozierebbe": "negoziare",
    "negozierebber": "negoziare",
    "negozierebbero": "negoziare",
    "negozierei": "negoziare",
    "negozieremmo": "negoziare",
    "negozieremo": "negoziare",
    "negoziereste": "negoziare",
    "negozieresti": "negoziare",
    "negozierete": "negoziare",
    "negozierà": "negoziare",
    "negozierò": "negoziare",
    "negozietti": "negozietto",
    "negozin": "negoziare",
    "negozino": "negoziare",
    "negozio": "negoziare",
    "negoziò": "negoziare",
    "negra": "negro",
    "negre": "negro",
    "negretti": "negretto",
    "negri": "negro",
    "negrieri": "negriero",
    "negritudini": "negritudine",
    "negromantica": "negromantico",
    "negromantiche": "negromantico",
    "negromantici": "negromantico",
    "negò": "negare",
    "nei": "neo",
    "nell'": "nella",
    "nelle": "nella",
    "nello": "nel",
    "nembi": "nembo",
    "nemica": "nemico",
    "nemiche": "nemico",
    "nemici": "nemico",
    "nenie": "nenia",
    "neo-assunti": "neo-assunto",
    "neo-avanguardie": "neo-avanguardia",
    "neo-campioni": "neo-campione",
    "neo-centriste": "neo-centrista",
    "neo-centristi": "neo-centrista",
    "neo-classica": "neo-classico",
    "neo-classiche": "neo-classico",
    "neo-classici": "neo-classico",
    "neo-consiglieri": "neo-consigliere",
    "neo-direttori": "neo-direttore",
    "neo-eletti": "neo-eletto",
    "neo-golliste": "neo-gollista",
    "neo-gollisti": "neo-gollista",
    "neo-imprenditori": "neo-imprenditore",
    "neo-laureati": "neo-laureato",
    "neo-mamme": "neo-mamma",
    "neo-ministri": "neo-ministro",
    "neo-nazisti": "neo-nazista",
    "neo-presidenti": "neo-presidente",
    "neo-segretari": "neo-segretario",
    "neoacquisti": "neoacquisto",
    "neoassunti": "neoassunto",
    "neoavanguardie": "neoavanguardia",
    "neocampioni": "neocampione",
    "neocapitalismi": "neocapitalismo",
    "neocapitaliste": "neocapitalista",
    "neocapitalisti": "neocapitalista",
    "neoclassica": "neoclassico",
    "neoclassiche": "neoclassico",
    "neoclassici": "neoclassico",
    "neoclassicismi": "neoclassicismo",
    "neocomuniste": "neocomunista",
    "neocomunisti": "neocomunista",
    "neodeputati": "neodeputato",
    "neodirettori": "neodirettore",
    "neoeletti": "neoeletto",
    "neofascismi": "neofascismo",
    "neofasciste": "neofascista",
    "neofascisti": "neofascista",
    "neofiti": "neofita",
    "neoformazioni": "neoformazione",
    "neogolliste": "neogollista",
    "neogollisti": "neogollista",
    "neoimprenditori": "neoimprenditore",
    "neolaureata": "neolaureato",
    "neolaureate": "neolaureato",
    "neolaureati": "neolaureato",
    "neoliberismi": "neoliberismo",
    "neologismi": "neologismo",
    "neomamme": "neomamma",
    "neoministri": "neoministro",
    "neonata": "neonato",
    "neonatali": "neonatale",
    "neonate": "neonato",
    "neonati": "neonato",
    "neonatologi": "neonatologo",
    "neonazismi": "neonazismo",
    "neonaziste": "neonazista",
    "neonazisti": "neonazista",
    "neopatentati": "neopatentato",
    "neoplasie": "neoplasia",
    "neopresidenti": "neopresidente",
    "neopromosse": "neopromossa",
    "neopromossi": "neopromosso",
    "neorealismi": "neorealismo",
    "neorealiste": "neorealista",
    "neorealisti": "neorealista",
    "neorealistica": "neorealistico",
    "neorealistiche": "neorealistico",
    "neorealistici": "neorealistico",
    "neosegretari": "neosegretario",
    "neosenatori": "neosenatore",
    "neosindaci": "neosindaco",
    "neosposi": "neosposo",
    "neozelandesi": "neozelandese",
    "nepalesi": "nepalese",
    "nepotismi": "nepotismo",
    "nequizie": "nequizia",
    "nera": "nero",
    "nerastra": "nerastro",
    "nerastre": "nerastro",
    "nerastri": "nerastro",
    "nerazzurra": "nerazzurro",
    "nerazzurre": "nerazzurro",
    "nerazzurri": "nerazzurro",
    "nerboruta": "nerboruto",
    "nerborute": "nerboruto",
    "nerboruti": "nerboruto",
    "nere": "nero",
    "nereggerai": "nereggiare",
    "nereggeran": "nereggiare",
    "nereggeranno": "nereggiare",
    "nereggerebbe": "nereggiare",
    "nereggerebber": "nereggiare",
    "nereggerebbero": "nereggiare",
    "nereggerei": "nereggiare",
    "nereggeremmo": "nereggiare",
    "nereggeremo": "nereggiare",
    "nereggereste": "nereggiare",
    "nereggeresti": "nereggiare",
    "nereggerete": "nereggiare",
    "nereggerà": "nereggiare",
    "nereggerò": "nereggiare",
    "nereggi": "nereggiare",
    "nereggia": "nereggiare",
    "nereggiai": "nereggiare",
    "nereggiammo": "nereggiare",
    "nereggiamo": "nereggiare",
    "nereggian": "nereggiare",
    "nereggiando": "nereggiare",
    "nereggiano": "nereggiare",
    "nereggiante": "nereggiare",
    "nereggianti": "nereggiare",
    "nereggiar": "nereggiare",
    "nereggiaron": "nereggiare",
    "nereggiarono": "nereggiare",
    "nereggiasse": "nereggiare",
    "nereggiasser": "nereggiare",
    "nereggiassero": "nereggiare",
    "nereggiassi": "nereggiare",
    "nereggiassimo": "nereggiare",
    "nereggiaste": "nereggiare",
    "nereggiasti": "nereggiare",
    "nereggiata": "nereggiare",
    "nereggiate": "nereggiare",
    "nereggiati": "nereggiare",
    "nereggiato": "nereggiare",
    "nereggiava": "nereggiare",
    "nereggiavamo": "nereggiare",
    "nereggiavan": "nereggiare",
    "nereggiavano": "nereggiare",
    "nereggiavate": "nereggiare",
    "nereggiavi": "nereggiare",
    "nereggiavo": "nereggiare",
    "nereggin": "nereggiare",
    "nereggino": "nereggiare",
    "nereggio": "nereggiare",
    "nereggiò": "nereggiare",
    "neri": "nero",
    "nervature": "nervatura",
    "nervi": "nervo",
    "nervina": "nervino",
    "nervine": "nervino",
    "nervini": "nervino",
    "nervosa": "nervoso",
    "nervose": "nervoso",
    "nervosi": "nervoso",
    "nervosismi": "nervosismo",
    "nessi": "nesso",
    "nessuna": "nessuno",
    "nessune": "nessuno",
    "nessuni": "nessuno",
    "netta": "netto",
    "nettai": "nettare",
    "nettammo": "nettare",
    "nettan": "nettare",
    "nettando": "nettare",
    "nettano": "nettare",
    "nettante": "nettare",
    "nettanti": "nettare",
    "nettar": "nettare",
    "nettaron": "nettare",
    "nettarono": "nettare",
    "nettasse": "nettare",
    "nettasser": "nettare",
    "nettassero": "nettare",
    "nettassi": "nettare",
    "nettassimo": "nettare",
    "nettaste": "nettare",
    "nettasti": "nettare",
    "nettata": "nettare",
    "nettate": "nettare",
    "nettati": "nettare",
    "nettato": "nettare",
    "nettava": "nettare",
    "nettavamo": "nettare",
    "nettavan": "nettare",
    "nettavano": "nettare",
    "nettavate": "nettare",
    "nettavi": "nettare",
    "nettavo": "nettare",
    "nette": "netto",
    "netterai": "nettare",
    "netteran": "nettare",
    "netteranno": "nettare",
    "netterebbe": "nettare",
    "netterebber": "nettare",
    "netterebbero": "nettare",
    "netterei": "nettare",
    "netteremmo": "nettare",
    "netteremo": "nettare",
    "nettereste": "nettare",
    "netteresti": "nettare",
    "netterete": "nettare",
    "netterà": "nettare",
    "netterò": "nettare",
    "nettezze": "nettezza",
    "netti": "netto",
    "nettiamo": "nettare",
    "nettiate": "nettare",
    "nettin": "nettare",
    "nettino": "nettare",
    "netto": "nettare",
    "netturbini": "netturbino",
    "nettò": "nettare",
    "neurobiologi": "neurobiologo",
    "neurochirurghi": "neurochirurgo",
    "neurofisiologi": "neurofisiologo",
    "neurologi": "neurologo",
    "neurologica": "neurologico",
    "neurologiche": "neurologico",
    "neurologici": "neurologico",
    "neuroni": "neurone",
    "neuropatie": "neuropatia",
    "neuropsichiatri": "neuropsichiatra",
    "neuroscienze": "neuroscienza",
    "neuroscienziati": "neuroscienziato",
    "neurotrasmettitori": "neurotrasmettitore",
    "neurovegetativa": "neurovegetativo",
    "neurovegetative": "neurovegetativo",
    "neurovegetativi": "neurovegetativo",
    "neutra": "neutro",
    "neutrali": "neutrale",
    "neutralismi": "neutralismo",
    "neutraliste": "neutralista",
    "neutralisti": "neutralista",
    "neutralizza": "neutralizzare",
    "neutralizzai": "neutralizzare",
    "neutralizzammo": "neutralizzare",
    "neutralizzan": "neutralizzare",
    "neutralizzando": "neutralizzare",
    "neutralizzano": "neutralizzare",
    "neutralizzante": "neutralizzare",
    "neutralizzanti": "neutralizzare",
    "neutralizzar": "neutralizzare",
    "neutralizzaron": "neutralizzare",
    "neutralizzarono": "neutralizzare",
    "neutralizzasse": "neutralizzare",
    "neutralizzasser": "neutralizzare",
    "neutralizzassero": "neutralizzare",
    "neutralizzassi": "neutralizzare",
    "neutralizzassimo": "neutralizzare",
    "neutralizzaste": "neutralizzare",
    "neutralizzasti": "neutralizzare",
    "neutralizzata": "neutralizzare",
    "neutralizzate": "neutralizzare",
    "neutralizzati": "neutralizzare",
    "neutralizzato": "neutralizzare",
    "neutralizzava": "neutralizzare",
    "neutralizzavamo": "neutralizzare",
    "neutralizzavan": "neutralizzare",
    "neutralizzavano": "neutralizzare",
    "neutralizzavate": "neutralizzare",
    "neutralizzavi": "neutralizzare",
    "neutralizzavo": "neutralizzare",
    "neutralizzazioni": "neutralizzazione",
    "neutralizzerai": "neutralizzare",
    "neutralizzeran": "neutralizzare",
    "neutralizzeranno": "neutralizzare",
    "neutralizzerebbe": "neutralizzare",
    "neutralizzerebber": "neutralizzare",
    "neutralizzerebbero": "neutralizzare",
    "neutralizzerei": "neutralizzare",
    "neutralizzeremmo": "neutralizzare",
    "neutralizzeremo": "neutralizzare",
    "neutralizzereste": "neutralizzare",
    "neutralizzeresti": "neutralizzare",
    "neutralizzerete": "neutralizzare",
    "neutralizzerà": "neutralizzare",
    "neutralizzerò": "neutralizzare",
    "neutralizzi": "neutralizzare",
    "neutralizziamo": "neutralizzare",
    "neutralizziate": "neutralizzare",
    "neutralizzin": "neutralizzare",
    "neutralizzino": "neutralizzare",
    "neutralizzo": "neutralizzare",
    "neutralizzò": "neutralizzare",
    "neutre": "neutro",
    "neutri": "neutro",
    "neutrini": "neutrino",
    "neutroni": "neutrone",
    "nevai": "nevaio",
    "nevi": "neve",
    "nevica": "nevicare",
    "nevicai": "nevicare",
    "nevicammo": "nevicare",
    "nevican": "nevicare",
    "nevicando": "nevicare",
    "nevicano": "nevicare",
    "nevicante": "nevicare",
    "nevicanti": "nevicare",
    "nevicar": "nevicare",
    "nevicaron": "nevicare",
    "nevicarono": "nevicare",
    "nevicasse": "nevicare",
    "nevicasser": "nevicare",
    "nevicassero": "nevicare",
    "nevicassi": "nevicare",
    "nevicassimo": "nevicare",
    "nevicaste": "nevicare",
    "nevicasti": "nevicare",
    "nevicata": "nevicare",
    "nevicate": "nevicata",
    "nevicati": "nevicare",
    "nevicato": "nevicare",
    "nevicava": "nevicare",
    "nevicavamo": "nevicare",
    "nevicavan": "nevicare",
    "nevicavano": "nevicare",
    "nevicavate": "nevicare",
    "nevicavi": "nevicare",
    "nevicavo": "nevicare",
    "nevicherai": "nevicare",
    "nevicheran": "nevicare",
    "nevicheranno": "nevicare",
    "nevicherebbe": "nevicare",
    "nevicherebber": "nevicare",
    "nevicherebbero": "nevicare",
    "nevicherei": "nevicare",
    "nevicheremmo": "nevicare",
    "nevicheremo": "nevicare",
    "nevichereste": "nevicare",
    "nevicheresti": "nevicare",
    "nevicherete": "nevicare",
    "nevicherà": "nevicare",
    "nevicherò": "nevicare",
    "nevichi": "nevicare",
    "nevichiamo": "nevicare",
    "nevichiate": "nevicare",
    "nevichin": "nevicare",
    "nevichino": "nevicare",
    "nevico": "nevicare",
    "nevicò": "nevicare",
    "nevischi": "nevischio",
    "nevischia": "nevischiare",
    "nevischiai": "nevischiare",
    "nevischiammo": "nevischiare",
    "nevischiamo": "nevischiare",
    "nevischian": "nevischiare",
    "nevischiando": "nevischiare",
    "nevischiano": "nevischiare",
    "nevischiante": "nevischiare",
    "nevischianti": "nevischiare",
    "nevischiar": "nevischiare",
    "nevischiaron": "nevischiare",
    "nevischiarono": "nevischiare",
    "nevischiasse": "nevischiare",
    "nevischiasser": "nevischiare",
    "nevischiassero": "nevischiare",
    "nevischiassi": "nevischiare",
    "nevischiassimo": "nevischiare",
    "nevischiaste": "nevischiare",
    "nevischiasti": "nevischiare",
    "nevischiata": "nevischiare",
    "nevischiate": "nevischiare",
    "nevischiati": "nevischiare",
    "nevischiato": "nevischiare",
    "nevischiava": "nevischiare",
    "nevischiavamo": "nevischiare",
    "nevischiavan": "nevischiare",
    "nevischiavano": "nevischiare",
    "nevischiavate": "nevischiare",
    "nevischiavi": "nevischiare",
    "nevischiavo": "nevischiare",
    "nevischierai": "nevischiare",
    "nevischieran": "nevischiare",
    "nevischieranno": "nevischiare",
    "nevischierebbe": "nevischiare",
    "nevischierebber": "nevischiare",
    "nevischierebbero": "nevischiare",
    "nevischierei": "nevischiare",
    "nevischieremmo": "nevischiare",
    "nevischieremo": "nevischiare",
    "nevischiereste": "nevischiare",
    "nevischieresti": "nevischiare",
    "nevischierete": "nevischiare",
    "nevischierà": "nevischiare",
    "nevischierò": "nevischiare",
    "nevischin": "nevischiare",
    "nevischino": "nevischiare",
    "nevischio": "nevischiare",
    "nevischiò": "nevischiare",
    "nevosa": "nevoso",
    "nevose": "nevoso",
    "nevosi": "nevoso",
    "nevralgica": "nevralgico",
    "nevralgiche": "nevralgico",
    "nevralgici": "nevralgico",
    "nevralgie": "nevralgia",
    "nevrastenie": "nevrastenia",
    "nevrotica": "nevrotico",
    "nevrotiche": "nevrotico",
    "nevrotici": "nevrotico",
    "newyorchesi": "newyorchese",
    "newyorkesi": "newyorkese",
    "nicaraguensi": "nicaraguense",
    "nicchi": "nicchiare",
    "nicchia": "nicchiare",
    "nicchiai": "nicchiare",
    "nicchiammo": "nicchiare",
    "nicchiamo": "nicchiare",
    "nicchian": "nicchiare",
    "nicchiando": "nicchiare",
    "nicchiano": "nicchiare",
    "nicchiante": "nicchiare",
    "nicchianti": "nicchiare",
    "nicchiar": "nicchiare",
    "nicchiaron": "nicchiare",
    "nicchiarono": "nicchiare",
    "nicchiasse": "nicchiare",
    "nicchiasser": "nicchiare",
    "nicchiassero": "nicchiare",
    "nicchiassi": "nicchiare",
    "nicchiassimo": "nicchiare",
    "nicchiaste": "nicchiare",
    "nicchiasti": "nicchiare",
    "nicchiata": "nicchiare",
    "nicchiate": "nicchiare",
    "nicchiati": "nicchiare",
    "nicchiato": "nicchiare",
    "nicchiava": "nicchiare",
    "nicchiavamo": "nicchiare",
    "nicchiavan": "nicchiare",
    "nicchiavano": "nicchiare",
    "nicchiavate": "nicchiare",
    "nicchiavi": "nicchiare",
    "nicchiavo": "nicchiare",
    "nicchie": "nicchia",
    "nicchierai": "nicchiare",
    "nicchieran": "nicchiare",
    "nicchieranno": "nicchiare",
    "nicchierebbe": "nicchiare",
    "nicchierebber": "nicchiare",
    "nicchierebbero": "nicchiare",
    "nicchierei": "nicchiare",
    "nicchieremmo": "nicchiare",
    "nicchieremo": "nicchiare",
    "nicchiereste": "nicchiare",
    "nicchieresti": "nicchiare",
    "nicchierete": "nicchiare",
    "nicchierà": "nicchiare",
    "nicchierò": "nicchiare",
    "nicchin": "nicchiare",
    "nicchino": "nicchiare",
    "nicchio": "nicchiare",
    "nicchiò": "nicchiare",
    "nichela": "nichelare",
    "nichelai": "nichelare",
    "nichelammo": "nichelare",
    "nichelan": "nichelare",
    "nichelando": "nichelare",
    "nichelano": "nichelare",
    "nichelante": "nichelare",
    "nichelanti": "nichelare",
    "nichelar": "nichelare",
    "nichelaron": "nichelare",
    "nichelarono": "nichelare",
    "nichelasse": "nichelare",
    "nichelasser": "nichelare",
    "nichelassero": "nichelare",
    "nichelassi": "nichelare",
    "nichelassimo": "nichelare",
    "nichelaste": "nichelare",
    "nichelasti": "nichelare",
    "nichelata": "nichelare",
    "nichelate": "nichelare",
    "nichelati": "nichelare",
    "nichelato": "nichelare",
    "nichelava": "nichelare",
    "nichelavamo": "nichelare",
    "nichelavan": "nichelare",
    "nichelavano": "nichelare",
    "nichelavate": "nichelare",
    "nichelavi": "nichelare",
    "nichelavo": "nichelare",
    "nichelerai": "nichelare",
    "nicheleran": "nichelare",
    "nicheleranno": "nichelare",
    "nichelerebbe": "nichelare",
    "nichelerebber": "nichelare",
    "nichelerebbero": "nichelare",
    "nichelerei": "nichelare",
    "nicheleremmo": "nichelare",
    "nicheleremo": "nichelare",
    "nichelereste": "nichelare",
    "nicheleresti": "nichelare",
    "nichelerete": "nichelare",
    "nichelerà": "nichelare",
    "nichelerò": "nichelare",
    "nicheli": "nichelare",
    "nicheliamo": "nichelare",
    "nicheliate": "nichelare",
    "nichelin": "nichelare",
    "nichelino": "nichelare",
    "nichelo": "nichelare",
    "nichelò": "nichelare",
    "nichilismi": "nichilismo",
    "nichiliste": "nichilista",
    "nichilisti": "nichilista",
    "nicotine": "nicotina",
    "nida": "nido",
    "nide": "nido",
    "nidi": "nido",
    "nidiate": "nidiata",
    "nidifica": "nidificare",
    "nidificai": "nidificare",
    "nidificammo": "nidificare",
    "nidifican": "nidificare",
    "nidificando": "nidificare",
    "nidificano": "nidificare",
    "nidificante": "nidificare",
    "nidificanti": "nidificare",
    "nidificar": "nidificare",
    "nidificaron": "nidificare",
    "nidificarono": "nidificare",
    "nidificasse": "nidificare",
    "nidificasser": "nidificare",
    "nidificassero": "nidificare",
    "nidificassi": "nidificare",
    "nidificassimo": "nidificare",
    "nidificaste": "nidificare",
    "nidificasti": "nidificare",
    "nidificata": "nidificare",
    "nidificate": "nidificare",
    "nidificati": "nidificare",
    "nidificato": "nidificare",
    "nidificava": "nidificare",
    "nidificavamo": "nidificare",
    "nidificavan": "nidificare",
    "nidificavano": "nidificare",
    "nidificavate": "nidificare",
    "nidificavi": "nidificare",
    "nidificavo": "nidificare",
    "nidificherai": "nidificare",
    "nidificheran": "nidificare",
    "nidificheranno": "nidificare",
    "nidificherebbe": "nidificare",
    "nidificherebber": "nidificare",
    "nidificherebbero": "nidificare",
    "nidificherei": "nidificare",
    "nidificheremmo": "nidificare",
    "nidificheremo": "nidificare",
    "nidifichereste": "nidificare",
    "nidificheresti": "nidificare",
    "nidificherete": "nidificare",
    "nidificherà": "nidificare",
    "nidificherò": "nidificare",
    "nidifichi": "nidificare",
    "nidifichiamo": "nidificare",
    "nidifichiate": "nidificare",
    "nidifichin": "nidificare",
    "nidifichino": "nidificare",
    "nidifico": "nidificare",
    "nidificò": "nidificare",
    "niella": "niellare",
    "niellai": "niellare",
    "niellammo": "niellare",
    "niellan": "niellare",
    "niellando": "niellare",
    "niellano": "niellare",
    "niellante": "niellare",
    "niellanti": "niellare",
    "niellar": "niellare",
    "niellaron": "niellare",
    "niellarono": "niellare",
    "niellasse": "niellare",
    "niellasser": "niellare",
    "niellassero": "niellare",
    "niellassi": "niellare",
    "niellassimo": "niellare",
    "niellaste": "niellare",
    "niellasti": "niellare",
    "niellata": "niellare",
    "niellate": "niellare",
    "niellati": "niellare",
    "niellato": "niellare",
    "niellava": "niellare",
    "niellavamo": "niellare",
    "niellavan": "niellare",
    "niellavano": "niellare",
    "niellavate": "niellare",
    "niellavi": "niellare",
    "niellavo": "niellare",
    "niellerai": "niellare",
    "nielleran": "niellare",
    "nielleranno": "niellare",
    "niellerebbe": "niellare",
    "niellerebber": "niellare",
    "niellerebbero": "niellare",
    "niellerei": "niellare",
    "nielleremmo": "niellare",
    "nielleremo": "niellare",
    "niellereste": "niellare",
    "nielleresti": "niellare",
    "niellerete": "niellare",
    "niellerà": "niellare",
    "niellerò": "niellare",
    "nielli": "niellare",
    "nielliamo": "niellare",
    "nielliate": "niellare",
    "niellin": "niellare",
    "niellino": "niellare",
    "niello": "niellare",
    "niellò": "niellare",
    "nigeriana": "nigeriano",
    "nigeriane": "nigeriano",
    "nigeriani": "nigeriano",
    "ninfe": "ninfa",
    "ninfette": "ninfetta",
    "ninna": "ninnare",
    "ninnai": "ninnare",
    "ninnammo": "ninnare",
    "ninnan": "ninnare",
    "ninnando": "ninnare",
    "ninnano": "ninnare",
    "ninnante": "ninnare",
    "ninnanti": "ninnare",
    "ninnar": "ninnare",
    "ninnaron": "ninnare",
    "ninnarono": "ninnare",
    "ninnasse": "ninnare",
    "ninnasser": "ninnare",
    "ninnassero": "ninnare",
    "ninnassi": "ninnare",
    "ninnassimo": "ninnare",
    "ninnaste": "ninnare",
    "ninnasti": "ninnare",
    "ninnata": "ninnare",
    "ninnate": "ninnare",
    "ninnati": "ninnare",
    "ninnato": "ninnare",
    "ninnava": "ninnare",
    "ninnavamo": "ninnare",
    "ninnavan": "ninnare",
    "ninnavano": "ninnare",
    "ninnavate": "ninnare",
    "ninnavi": "ninnare",
    "ninnavo": "ninnare",
    "ninne": "ninna",
    "ninnerai": "ninnare",
    "ninneran": "ninnare",
    "ninneranno": "ninnare",
    "ninnerebbe": "ninnare",
    "ninnerebber": "ninnare",
    "ninnerebbero": "ninnare",
    "ninnerei": "ninnare",
    "ninneremmo": "ninnare",
    "ninneremo": "ninnare",
    "ninnereste": "ninnare",
    "ninneresti": "ninnare",
    "ninnerete": "ninnare",
    "ninnerà": "ninnare",
    "ninnerò": "ninnare",
    "ninni": "ninnare",
    "ninniamo": "ninnare",
    "ninniate": "ninnare",
    "ninnin": "ninnare",
    "ninnino": "ninnare",
    "ninno": "ninnare",
    "ninnoli": "ninnolo",
    "ninnò": "ninnare",
    "nipoti": "nipote",
    "nipotine": "nipotina",
    "nipotini": "nipotino",
    "nipponica": "nipponico",
    "nipponiche": "nipponico",
    "nipponici": "nipponico",
    "nisseni": "nisseno",
    "nitida": "nitido",
    "nitide": "nitido",
    "nitidezze": "nitidezza",
    "nitidi": "nitido",
    "nitori": "nitore",
    "nitrata": "nitrato",
    "nitrate": "nitrato",
    "nitrati": "nitrato",
    "nitrendo": "nitrire",
    "nitrente": "nitrire",
    "nitrenti": "nitrire",
    "nitriamo": "nitrire",
    "nitriate": "nitrire",
    "nitrica": "nitrico",
    "nitriche": "nitrico",
    "nitrici": "nitrico",
    "nitrii": "nitrire",
    "nitrimmo": "nitrire",
    "nitrir": "nitrire",
    "nitrirai": "nitrire",
    "nitriran": "nitrire",
    "nitriranno": "nitrire",
    "nitrirebbe": "nitrire",
    "nitrirebber": "nitrire",
    "nitrirebbero": "nitrire",
    "nitrirei": "nitrire",
    "nitriremmo": "nitrire",
    "nitriremo": "nitrire",
    "nitrireste": "nitrire",
    "nitriresti": "nitrire",
    "nitrirete": "nitrire",
    "nitriron": "nitrire",
    "nitrirono": "nitrire",
    "nitrirà": "nitrire",
    "nitrirò": "nitrire",
    "nitrisca": "nitrire",
    "nitriscan": "nitrire",
    "nitriscano": "nitrire",
    "nitrisce": "nitrire",
    "nitrisci": "nitrire",
    "nitrisco": "nitrire",
    "nitriscon": "nitrire",
    "nitriscono": "nitrire",
    "nitrisse": "nitrire",
    "nitrisser": "nitrire",
    "nitrissero": "nitrire",
    "nitrissi": "nitrire",
    "nitrissimo": "nitrire",
    "nitriste": "nitrire",
    "nitristi": "nitrire",
    "nitrita": "nitrire",
    "nitrite": "nitrire",
    "nitriti": "nitrito",
    "nitrito": "nitrire",
    "nitriva": "nitrire",
    "nitrivamo": "nitrire",
    "nitrivan": "nitrire",
    "nitrivano": "nitrire",
    "nitrivate": "nitrire",
    "nitrivi": "nitrire",
    "nitrivo": "nitrire",
    "nitrì": "nitrire",
    "nobildonne": "nobildonna",
    "nobili": "nobiliare",
    "nobilia": "nobiliare",
    "nobiliai": "nobiliare",
    "nobiliammo": "nobiliare",
    "nobiliamo": "nobiliare",
    "nobilian": "nobiliare",
    "nobiliando": "nobiliare",
    "nobiliano": "nobiliare",
    "nobiliante": "nobiliare",
    "nobilianti": "nobiliare",
    "nobiliar": "nobiliare",
    "nobiliari": "nobiliare",
    "nobiliaron": "nobiliare",
    "nobiliarono": "nobiliare",
    "nobiliasse": "nobiliare",
    "nobiliasser": "nobiliare",
    "nobiliassero": "nobiliare",
    "nobiliassi": "nobiliare",
    "nobiliassimo": "nobiliare",
    "nobiliaste": "nobiliare",
    "nobiliasti": "nobiliare",
    "nobiliata": "nobiliare",
    "nobiliate": "nobiliare",
    "nobiliati": "nobiliare",
    "nobiliato": "nobiliare",
    "nobiliava": "nobiliare",
    "nobiliavamo": "nobiliare",
    "nobiliavan": "nobiliare",
    "nobiliavano": "nobiliare",
    "nobiliavate": "nobiliare",
    "nobiliavi": "nobiliare",
    "nobiliavo": "nobiliare",
    "nobilierai": "nobiliare",
    "nobilieran": "nobiliare",
    "nobilieranno": "nobiliare",
    "nobilierebbe": "nobiliare",
    "nobilierebber": "nobiliare",
    "nobilierebbero": "nobiliare",
    "nobilierei": "nobiliare",
    "nobilieremmo": "nobiliare",
    "nobilieremo": "nobiliare",
    "nobiliereste": "nobiliare",
    "nobilieresti": "nobiliare",
    "nobilierete": "nobiliare",
    "nobilierà": "nobiliare",
    "nobilierò": "nobiliare",
    "nobilin": "nobiliare",
    "nobilino": "nobiliare",
    "nobilio": "nobiliare",
    "nobilita": "nobilitare",
    "nobilitai": "nobilitare",
    "nobilitammo": "nobilitare",
    "nobilitan": "nobilitare",
    "nobilitando": "nobilitare",
    "nobilitano": "nobilitare",
    "nobilitante": "nobilitare",
    "nobilitanti": "nobilitare",
    "nobilitar": "nobilitare",
    "nobilitaron": "nobilitare",
    "nobilitarono": "nobilitare",
    "nobilitasse": "nobilitare",
    "nobilitasser": "nobilitare",
    "nobilitassero": "nobilitare",
    "nobilitassi": "nobilitare",
    "nobilitassimo": "nobilitare",
    "nobilitaste": "nobilitare",
    "nobilitasti": "nobilitare",
    "nobilitata": "nobilitare",
    "nobilitate": "nobilitare",
    "nobilitati": "nobilitare",
    "nobilitato": "nobilitare",
    "nobilitava": "nobilitare",
    "nobilitavamo": "nobilitare",
    "nobilitavan": "nobilitare",
    "nobilitavano": "nobilitare",
    "nobilitavate": "nobilitare",
    "nobilitavi": "nobilitare",
    "nobilitavo": "nobilitare",
    "nobiliterai": "nobilitare",
    "nobiliteran": "nobilitare",
    "nobiliteranno": "nobilitare",
    "nobiliterebbe": "nobilitare",
    "nobiliterebber": "nobilitare",
    "nobiliterebbero": "nobilitare",
    "nobiliterei": "nobilitare",
    "nobiliteremmo": "nobilitare",
    "nobiliteremo": "nobilitare",
    "nobilitereste": "nobilitare",
    "nobiliteresti": "nobilitare",
    "nobiliterete": "nobilitare",
    "nobiliterà": "nobilitare",
    "nobiliterò": "nobilitare",
    "nobiliti": "nobilitare",
    "nobilitiamo": "nobilitare",
    "nobilitiate": "nobilitare",
    "nobilitin": "nobilitare",
    "nobilitino": "nobilitare",
    "nobilito": "nobilitare",
    "nobilitò": "nobilitare",
    "nobiliò": "nobiliare",
    "nobiluomini": "nobiluomo",
    "nocchieri": "nocchiero",
    "noccia": "nuocere",
    "nocciano": "nuocere",
    "noccio": "nuocere",
    "nocciole": "nocciola",
    "noccioleti": "noccioleto",
    "noccioli": "nocciolo",
    "noccioline": "nocciolina",
    "nocciono": "nuocere",
    "nocemmo": "nuocere",
    "noceste": "nuocere",
    "nocesti": "nuocere",
    "nocete": "nuocere",
    "nociamo": "nuocere",
    "nociate": "nuocere",
    "nociuto": "nuocere",
    "nociva": "nocivo",
    "nocive": "nocivo",
    "nocivi": "nocivo",
    "nocque": "nuocere",
    "nocquer": "nuocere",
    "nocquero": "nuocere",
    "nocqui": "nuocere",
    "nodali": "nodale",
    "nodi": "nodo",
    "nodosa": "nodoso",
    "nodose": "nodoso",
    "nodosi": "nodoso",
    "noie": "noia",
    "noiosa": "noioso",
    "noiose": "noioso",
    "noiosi": "noioso",
    "noleggerai": "noleggiare",
    "noleggeran": "noleggiare",
    "noleggeranno": "noleggiare",
    "noleggerebbe": "noleggiare",
    "noleggerebber": "noleggiare",
    "noleggerebbero": "noleggiare",
    "noleggerei": "noleggiare",
    "noleggeremmo": "noleggiare",
    "noleggeremo": "noleggiare",
    "noleggereste": "noleggiare",
    "noleggeresti": "noleggiare",
    "noleggerete": "noleggiare",
    "noleggerà": "noleggiare",
    "noleggerò": "noleggiare",
    "noleggi": "noleggio",
    "noleggia": "noleggiare",
    "noleggiai": "noleggiare",
    "noleggiammo": "noleggiare",
    "noleggiamo": "noleggiare",
    "noleggian": "noleggiare",
    "noleggiando": "noleggiare",
    "noleggiano": "noleggiare",
    "noleggiante": "noleggiare",
    "noleggianti": "noleggiare",
    "noleggiar": "noleggiare",
    "noleggiaron": "noleggiare",
    "noleggiarono": "noleggiare",
    "noleggiasse": "noleggiare",
    "noleggiasser": "noleggiare",
    "noleggiassero": "noleggiare",
    "noleggiassi": "noleggiare",
    "noleggiassimo": "noleggiare",
    "noleggiaste": "noleggiare",
    "noleggiasti": "noleggiare",
    "noleggiata": "noleggiare",
    "noleggiate": "noleggiare",
    "noleggiati": "noleggiare",
    "noleggiato": "noleggiare",
    "noleggiatori": "noleggiatore",
    "noleggiava": "noleggiare",
    "noleggiavamo": "noleggiare",
    "noleggiavan": "noleggiare",
    "noleggiavano": "noleggiare",
    "noleggiavate": "noleggiare",
    "noleggiavi": "noleggiare",
    "noleggiavo": "noleggiare",
    "noleggin": "noleggiare",
    "noleggino": "noleggiare",
    "noleggio": "noleggiare",
    "noleggiò": "noleggiare",
    "nolenti": "nolente",
    "noli": "nolo",
    "noma": "nomare",
    "nomadi": "nomade",
    "nomadismi": "nomadismo",
    "nomai": "nomare",
    "nomammo": "nomare",
    "noman": "nomare",
    "nomando": "nomare",
    "nomano": "nomare",
    "nomante": "nomare",
    "nomanti": "nomare",
    "nomar": "nomare",
    "nomaron": "nomare",
    "nomarono": "nomare",
    "nomasse": "nomare",
    "nomasser": "nomare",
    "nomassero": "nomare",
    "nomassi": "nomare",
    "nomassimo": "nomare",
    "nomaste": "nomare",
    "nomasti": "nomare",
    "nomata": "nomare",
    "nomate": "nomare",
    "nomati": "nomare",
    "nomato": "nomare",
    "nomava": "nomare",
    "nomavamo": "nomare",
    "nomavan": "nomare",
    "nomavano": "nomare",
    "nomavate": "nomare",
    "nomavi": "nomare",
    "nomavo": "nomare",
    "nomee": "nomea",
    "nomenclature": "nomenclatura",
    "nomenklature": "nomenklatura",
    "nomerai": "nomare",
    "nomeran": "nomare",
    "nomeranno": "nomare",
    "nomerebbe": "nomare",
    "nomerebber": "nomare",
    "nomerebbero": "nomare",
    "nomerei": "nomare",
    "nomeremmo": "nomare",
    "nomeremo": "nomare",
    "nomereste": "nomare",
    "nomeresti": "nomare",
    "nomerete": "nomare",
    "nomerà": "nomare",
    "nomerò": "nomare",
    "nomi": "nome",
    "nomiamo": "nomare",
    "nomiate": "nomare",
    "nomignoli": "nomignolo",
    "nomime": "nomima",
    "nomin": "nomare",
    "nomina": "nominare",
    "nominai": "nominare",
    "nominali": "nominale",
    "nominalismi": "nominalismo",
    "nominalistica": "nominalistico",
    "nominalistiche": "nominalistico",
    "nominalistici": "nominalistico",
    "nominammo": "nominare",
    "nominan": "nominare",
    "nominando": "nominare",
    "nominano": "nominare",
    "nominante": "nominare",
    "nominanti": "nominare",
    "nominar": "nominare",
    "nominaron": "nominare",
    "nominarono": "nominare",
    "nominasse": "nominare",
    "nominasser": "nominare",
    "nominassero": "nominare",
    "nominassi": "nominare",
    "nominassimo": "nominare",
    "nominaste": "nominare",
    "nominasti": "nominare",
    "nominata": "nominato",
    "nominate": "nominato",
    "nominati": "nominato",
    "nominativa": "nominativo",
    "nominative": "nominativo",
    "nominativi": "nominativo",
    "nominato": "nominare",
    "nominava": "nominare",
    "nominavamo": "nominare",
    "nominavan": "nominare",
    "nominavano": "nominare",
    "nominavate": "nominare",
    "nominavi": "nominare",
    "nominavo": "nominare",
    "nomine": "nomina",
    "nominerai": "nominare",
    "nomineran": "nominare",
    "nomineranno": "nominare",
    "nominerebbe": "nominare",
    "nominerebber": "nominare",
    "nominerebbero": "nominare",
    "nominerei": "nominare",
    "nomineremmo": "nominare",
    "nomineremo": "nominare",
    "nominereste": "nominare",
    "nomineresti": "nominare",
    "nominerete": "nominare",
    "nominerà": "nominare",
    "nominerò": "nominare",
    "nomini": "nominare",
    "nominiamo": "nominare",
    "nominiate": "nominare",
    "nominin": "nominare",
    "nominino": "nominare",
    "nomino": "nominare",
    "nominò": "nominare",
    "nomo": "nomare",
    "nomò": "nomare",
    "non-fumatori": "non-fumatore",
    "non-lettori": "non-lettore",
    "non-violenta": "non-violento",
    "non-violente": "non-violento",
    "non-violenti": "non-violento",
    "non-violenze": "non-violenza",
    "non-voti": "non-voto",
    "nona": "nono",
    "nonchalances": "nonchalance",
    "noncuranti": "noncurante",
    "none": "nono",
    "noni": "nono",
    "nonne": "nonna",
    "nonnetti": "nonnetto",
    "nonni": "nonno",
    "nonnine": "nonnina",
    "nonnini": "nonnino",
    "nonnismi": "nonnismo",
    "nonsensi": "nonsenso",
    "nord-coreana": "nord-coreano",
    "nord-coreane": "nord-coreano",
    "nord-coreani": "nord-coreano",
    "nord-europea": "nord-europeo",
    "nord-europee": "nord-europeo",
    "nord-europei": "nord-europeo",
    "nord-irlandesi": "nord-irlandese",
    "nord-occidentali": "nord-occidentale",
    "nord-orientali": "nord-orientale",
    "nordafricana": "nordafricano",
    "nordafricane": "nordafricano",
    "nordafricani": "nordafricano",
    "nordamericana": "nordamericano",
    "nordamericane": "nordamericano",
    "nordamericani": "nordamericano",
    "nordcoreana": "nordcoreano",
    "nordcoreane": "nordcoreano",
    "nordcoreani": "nordcoreano",
    "nordica": "nordico",
    "nordiche": "nordico",
    "nordici": "nordico",
    "nordirlandesi": "nordirlandese",
    "nordista": "nordisto",
    "nordiste": "nordisto",
    "nordisti": "nordisto",
    "nordoccidentali": "nordoccidentale",
    "nordorientali": "nordorientale",
    "nordvietnamite": "nordvietnamita",
    "nordvietnamiti": "nordvietnamita",
    "normali": "normale",
    "normalizza": "normalizzare",
    "normalizzai": "normalizzare",
    "normalizzammo": "normalizzare",
    "normalizzan": "normalizzare",
    "normalizzando": "normalizzare",
    "normalizzano": "normalizzare",
    "normalizzante": "normalizzare",
    "normalizzanti": "normalizzare",
    "normalizzar": "normalizzare",
    "normalizzaron": "normalizzare",
    "normalizzarono": "normalizzare",
    "normalizzasse": "normalizzare",
    "normalizzasser": "normalizzare",
    "normalizzassero": "normalizzare",
    "normalizzassi": "normalizzare",
    "normalizzassimo": "normalizzare",
    "normalizzaste": "normalizzare",
    "normalizzasti": "normalizzare",
    "normalizzata": "normalizzare",
    "normalizzate": "normalizzare",
    "normalizzati": "normalizzare",
    "normalizzato": "normalizzare",
    "normalizzava": "normalizzare",
    "normalizzavamo": "normalizzare",
    "normalizzavan": "normalizzare",
    "normalizzavano": "normalizzare",
    "normalizzavate": "normalizzare",
    "normalizzavi": "normalizzare",
    "normalizzavo": "normalizzare",
    "normalizzazioni": "normalizzazione",
    "normalizzerai": "normalizzare",
    "normalizzeran": "normalizzare",
    "normalizzeranno": "normalizzare",
    "normalizzerebbe": "normalizzare",
    "normalizzerebber": "normalizzare",
    "normalizzerebbero": "normalizzare",
    "normalizzerei": "normalizzare",
    "normalizzeremmo": "normalizzare",
    "normalizzeremo": "normalizzare",
    "normalizzereste": "normalizzare",
    "normalizzeresti": "normalizzare",
    "normalizzerete": "normalizzare",
    "normalizzerà": "normalizzare",
    "normalizzerò": "normalizzare",
    "normalizzi": "normalizzare",
    "normalizziamo": "normalizzare",
    "normalizziate": "normalizzare",
    "normalizzin": "normalizzare",
    "normalizzino": "normalizzare",
    "normalizzo": "normalizzare",
    "normalizzò": "normalizzare",
    "normanna": "normanno",
    "normanne": "normanno",
    "normanni": "normanno",
    "normativa": "normativo",
    "normative": "normativo",
    "normativi": "normativo",
    "norme": "norma",
    "normografi": "normografo",
    "norvegesi": "norvegese",
    "nosocomi": "nosocomio",
    "nostalgica": "nostalgico",
    "nostalgiche": "nostalgico",
    "nostalgici": "nostalgico",
    "nostalgie": "nostalgia",
    "nostra": "nostro",
    "nostrana": "nostrano",
    "nostrane": "nostrano",
    "nostrani": "nostrano",
    "nostre": "nostro",
    "nostri": "nostro",
    "nota": "noto",
    "notabili": "notabile",
    "notai": "notare",
    "notammo": "notare",
    "notan": "notare",
    "notando": "notare",
    "notano": "notare",
    "notante": "notare",
    "notanti": "notare",
    "notar": "notare",
    "notarili": "notarile",
    "notaron": "notare",
    "notarono": "notare",
    "notasse": "notare",
    "notasser": "notare",
    "notassero": "notare",
    "notassi": "notare",
    "notassimo": "notare",
    "notaste": "notare",
    "notasti": "notare",
    "notata": "notare",
    "notate": "notare",
    "notati": "notare",
    "notato": "notare",
    "notava": "notare",
    "notavamo": "notare",
    "notavan": "notare",
    "notavano": "notare",
    "notavate": "notare",
    "notavi": "notare",
    "notavo": "notare",
    "notazioni": "notazione",
    "note": "noto",
    "noterai": "notare",
    "noteran": "notare",
    "noteranno": "notare",
    "noterebbe": "notare",
    "noterebber": "notare",
    "noterebbero": "notare",
    "noterei": "notare",
    "noterelle": "noterella",
    "noteremmo": "notare",
    "noteremo": "notare",
    "notereste": "notare",
    "noteresti": "notare",
    "noterete": "notare",
    "noterà": "notare",
    "noterò": "notare",
    "notevoli": "notevole",
    "noti": "noto",
    "notiamo": "notare",
    "notiate": "notare",
    "noticine": "noticina",
    "notifica": "notificare",
    "notificai": "notificare",
    "notificammo": "notificare",
    "notifican": "notificare",
    "notificando": "notificare",
    "notificano": "notificare",
    "notificante": "notificare",
    "notificanti": "notificare",
    "notificar": "notificare",
    "notificaron": "notificare",
    "notificarono": "notificare",
    "notificasse": "notificare",
    "notificasser": "notificare",
    "notificassero": "notificare",
    "notificassi": "notificare",
    "notificassimo": "notificare",
    "notificaste": "notificare",
    "notificasti": "notificare",
    "notificata": "notificare",
    "notificate": "notificare",
    "notificati": "notificare",
    "notificato": "notificare",
    "notificava": "notificare",
    "notificavamo": "notificare",
    "notificavan": "notificare",
    "notificavano": "notificare",
    "notificavate": "notificare",
    "notificavi": "notificare",
    "notificavo": "notificare",
    "notificazioni": "notificazione",
    "notifiche": "notifica",
    "notificherai": "notificare",
    "notificheran": "notificare",
    "notificheranno": "notificare",
    "notificherebbe": "notificare",
    "notificherebber": "notificare",
    "notificherebbero": "notificare",
    "notificherei": "notificare",
    "notificheremmo": "notificare",
    "notificheremo": "notificare",
    "notifichereste": "notificare",
    "notificheresti": "notificare",
    "notificherete": "notificare",
    "notificherà": "notificare",
    "notificherò": "notificare",
    "notifichi": "notificare",
    "notifichiamo": "notificare",
    "notifichiate": "notificare",
    "notifichin": "notificare",
    "notifichino": "notificare",
    "notifico": "notificare",
    "notificò": "notificare",
    "notin": "notare",
    "notino": "notare",
    "notisti": "notista",
    "notiziari": "notiziario",
    "notizie": "notizia",
    "notiziole": "notiziola",
    "noto": "notare",
    "notori": "notorio",
    "notoria": "notorio",
    "notorie": "notorio",
    "nottambula": "nottambulo",
    "nottambule": "nottambulo",
    "nottambuli": "nottambulo",
    "nottate": "nottata",
    "notti": "notte",
    "notturna": "notturno",
    "notturne": "notturno",
    "notturni": "notturno",
    "notò": "notare",
    "novantacinquesima": "novantacinquesimo",
    "novantacinquesime": "novantacinquesimo",
    "novantacinquesimi": "novantacinquesimo",
    "novantaduesima": "novantaduesimo",
    "novantaduesime": "novantaduesimo",
    "novantaduesimi": "novantaduesimo",
    "novantanovesima": "novantanovesimo",
    "novantanovesime": "novantanovesimo",
    "novantanovesimi": "novantanovesimo",
    "novantaquattresima": "novantaquattresimo",
    "novantaquattresime": "novantaquattresimo",
    "novantaquattresimi": "novantaquattresimo",
    "novantaseiesima": "novantaseiesimo",
    "novantaseiesime": "novantaseiesimo",
    "novantaseiesimi": "novantaseiesimo",
    "novantasettesima": "novantasettesimo",
    "novantasettesime": "novantasettesimo",
    "novantasettesimi": "novantasettesimo",
    "novantatreesima": "novantatreesimo",
    "novantatreesime": "novantatreesimo",
    "novantatreesimi": "novantatreesimo",
    "novantenni": "novantenne",
    "novantesima": "novantesimo",
    "novantesime": "novantesimo",
    "novantesimi": "novantesimo",
    "novantine": "novantina",
    "novantottesima": "novantottesimo",
    "novantottesime": "novantottesimo",
    "novantottesimi": "novantottesimo",
    "novantunesima": "novantunesimo",
    "novantunesime": "novantunesimo",
    "novantunesimi": "novantunesimo",
    "novaresi": "novarese",
    "novecentesca": "novecentesco",
    "novecentesche": "novecentesco",
    "novecenteschi": "novecentesco",
    "novecentesima": "novecentesimo",
    "novecentesime": "novecentesimo",
    "novecentesimi": "novecentesimo",
    "novecentiste": "novecentista",
    "novecentisti": "novecentista",
    "novella": "novello",
    "novellai": "novellare",
    "novellammo": "novellare",
    "novellan": "novellare",
    "novellando": "novellare",
    "novellano": "novellare",
    "novellante": "novellare",
    "novellanti": "novellare",
    "novellar": "novellare",
    "novellaron": "novellare",
    "novellarono": "novellare",
    "novellasse": "novellare",
    "novellasser": "novellare",
    "novellassero": "novellare",
    "novellassi": "novellare",
    "novellassimo": "novellare",
    "novellaste": "novellare",
    "novellasti": "novellare",
    "novellata": "novellare",
    "novellate": "novellare",
    "novellati": "novellare",
    "novellato": "novellare",
    "novellava": "novellare",
    "novellavamo": "novellare",
    "novellavan": "novellare",
    "novellavano": "novellare",
    "novellavate": "novellare",
    "novellavi": "novellare",
    "novellavo": "novellare",
    "novelle": "novello",
    "novellerai": "novellare",
    "novelleran": "novellare",
    "novelleranno": "novellare",
    "novellerebbe": "novellare",
    "novellerebber": "novellare",
    "novellerebbero": "novellare",
    "novellerei": "novellare",
    "novelleremmo": "novellare",
    "novelleremo": "novellare",
    "novellereste": "novellare",
    "novelleresti": "novellare",
    "novellerete": "novellare",
    "novellerà": "novellare",
    "novellerò": "novellare",
    "novelli": "novello",
    "novelliamo": "novellare",
    "novelliate": "novellare",
    "novellieri": "novelliere",
    "novellin": "novellare",
    "novellina": "novellino",
    "novelline": "novellino",
    "novellini": "novellino",
    "novellino": "novellare",
    "novello": "novellare",
    "novellò": "novellare",
    "novembri": "novembre",
    "novembrina": "novembrino",
    "novembrine": "novembrino",
    "novembrini": "novembrino",
    "novemillesima": "novemillesimo",
    "novemillesime": "novemillesimo",
    "novemillesimi": "novemillesimo",
    "novene": "novena",
    "novennali": "novennale",
    "novera": "noverare",
    "noverai": "noverare",
    "noverammo": "noverare",
    "noveran": "noverare",
    "noverando": "noverare",
    "noverano": "noverare",
    "noverante": "noverare",
    "noveranti": "noverare",
    "noverar": "noverare",
    "noveraron": "noverare",
    "noverarono": "noverare",
    "noverasse": "noverare",
    "noverasser": "noverare",
    "noverassero": "noverare",
    "noverassi": "noverare",
    "noverassimo": "noverare",
    "noveraste": "noverare",
    "noverasti": "noverare",
    "noverata": "noverare",
    "noverate": "noverare",
    "noverati": "noverare",
    "noverato": "noverare",
    "noverava": "noverare",
    "noveravamo": "noverare",
    "noveravan": "noverare",
    "noveravano": "noverare",
    "noveravate": "noverare",
    "noveravi": "noverare",
    "noveravo": "noverare",
    "novererai": "noverare",
    "novereran": "noverare",
    "novereranno": "noverare",
    "novererebbe": "noverare",
    "novererebber": "noverare",
    "novererebbero": "noverare",
    "novererei": "noverare",
    "novereremmo": "noverare",
    "novereremo": "noverare",
    "noverereste": "noverare",
    "novereresti": "noverare",
    "novererete": "noverare",
    "novererà": "noverare",
    "novererò": "noverare",
    "noveri": "noverare",
    "noveriamo": "noverare",
    "noveriate": "noverare",
    "noverin": "noverare",
    "noverino": "noverare",
    "novero": "noverare",
    "noverò": "noverare",
    "novissima": "novissimo",
    "novissime": "novissimo",
    "novissimi": "novissimo",
    "novizi": "novizio",
    "novizia": "novizio",
    "noviziati": "noviziato",
    "novizie": "novizio",
    "nozioni": "nozione",
    "nozionistica": "nozionistico",
    "nozionistiche": "nozionistico",
    "nozionistici": "nozionistico",
    "nubi": "nube",
    "nubifragi": "nubifragio",
    "nubili": "nubile",
    "nuche": "nuca",
    "nucleari": "nucleare",
    "nuclei": "nucleo",
    "nucleica": "nucleico",
    "nucleiche": "nucleico",
    "nucleici": "nucleico",
    "nuda": "nudo",
    "nude": "nudo",
    "nudi": "nudo",
    "nudiste": "nudista",
    "nudisti": "nudista",
    "nugoli": "nugolo",
    "nulla": "nullo",
    "nullafacenti": "nullafacente",
    "nullatenenti": "nullatenente",
    "nulle": "nullo",
    "nulli": "nullo",
    "numera": "numerare",
    "numerai": "numerare",
    "numerali": "numerale",
    "numerammo": "numerare",
    "numeran": "numerare",
    "numerando": "numerare",
    "numerano": "numerare",
    "numerante": "numerare",
    "numeranti": "numerare",
    "numerar": "numerare",
    "numeraron": "numerare",
    "numerarono": "numerare",
    "numerasse": "numerare",
    "numerasser": "numerare",
    "numerassero": "numerare",
    "numerassi": "numerare",
    "numerassimo": "numerare",
    "numeraste": "numerare",
    "numerasti": "numerare",
    "numerata": "numerato",
    "numerate": "numerato",
    "numerati": "numerato",
    "numerato": "numerare",
    "numerava": "numerare",
    "numeravamo": "numerare",
    "numeravan": "numerare",
    "numeravano": "numerare",
    "numeravate": "numerare",
    "numeravi": "numerare",
    "numeravo": "numerare",
    "numerazioni": "numerazione",
    "numererai": "numerare",
    "numereran": "numerare",
    "numereranno": "numerare",
    "numererebbe": "numerare",
    "numererebber": "numerare",
    "numererebbero": "numerare",
    "numererei": "numerare",
    "numereremmo": "numerare",
    "numereremo": "numerare",
    "numerereste": "numerare",
    "numereresti": "numerare",
    "numererete": "numerare",
    "numererà": "numerare",
    "numererò": "numerare",
    "numeretti": "numeretto",
    "numeri": "numero",
    "numeriamo": "numerare",
    "numeriate": "numerare",
    "numerica": "numerico",
    "numeriche": "numerico",
    "numerici": "numerico",
    "numerin": "numerare",
    "numerini": "numerino",
    "numerino": "numerare",
    "numero": "numerare",
    "numerosa": "numeroso",
    "numerose": "numeroso",
    "numerosi": "numeroso",
    "numerò": "numerare",
    "numi": "nume",
    "numismatica": "numismatico",
    "numismatiche": "numismatico",
    "numismatici": "numismatico",
    "nunzi": "nunzio",
    "nunziature": "nunziatura",
    "nuoccia": "nuocere",
    "nuocciano": "nuocere",
    "nuoccio": "nuocere",
    "nuocciono": "nuocere",
    "nuoce": "nuocere",
    "nuocemmo": "nuocere",
    "nuocendo": "nuocere",
    "nuocente": "nuocere",
    "nuocenti": "nuocere",
    "nuocer": "nuocere",
    "nuocerai": "nuocere",
    "nuoceran": "nuocere",
    "nuoceranno": "nuocere",
    "nuocerebbe": "nuocere",
    "nuocerebber": "nuocere",
    "nuocerebbero": "nuocere",
    "nuocerei": "nuocere",
    "nuoceremmo": "nuocere",
    "nuoceremo": "nuocere",
    "nuocereste": "nuocere",
    "nuoceresti": "nuocere",
    "nuocerete": "nuocere",
    "nuocerà": "nuocere",
    "nuocerò": "nuocere",
    "nuocesse": "nuocere",
    "nuocesser": "nuocere",
    "nuocessero": "nuocere",
    "nuocessi": "nuocere",
    "nuocessimo": "nuocere",
    "nuoceste": "nuocere",
    "nuocesti": "nuocere",
    "nuocete": "nuocere",
    "nuoceva": "nuocere",
    "nuocevamo": "nuocere",
    "nuocevan": "nuocere",
    "nuocevano": "nuocere",
    "nuocevate": "nuocere",
    "nuocevi": "nuocere",
    "nuocevo": "nuocere",
    "nuoci": "nuocere",
    "nuociamo": "nuocere",
    "nuociate": "nuocere",
    "nuociuto": "nuocere",
    "nuore": "nuora",
    "nuoresi": "nuorese",
    "nuota": "nuotare",
    "nuotai": "nuotare",
    "nuotammo": "nuotare",
    "nuotan": "nuotare",
    "nuotando": "nuotare",
    "nuotano": "nuotare",
    "nuotante": "nuotare",
    "nuotanti": "nuotare",
    "nuotar": "nuotare",
    "nuotaron": "nuotare",
    "nuotarono": "nuotare",
    "nuotasse": "nuotare",
    "nuotasser": "nuotare",
    "nuotassero": "nuotare",
    "nuotassi": "nuotare",
    "nuotassimo": "nuotare",
    "nuotaste": "nuotare",
    "nuotasti": "nuotare",
    "nuotata": "nuotare",
    "nuotate": "nuotata",
    "nuotati": "nuotare",
    "nuotato": "nuotare",
    "nuotatori": "nuotatore",
    "nuotatrici": "nuotatrice",
    "nuotava": "nuotare",
    "nuotavamo": "nuotare",
    "nuotavan": "nuotare",
    "nuotavano": "nuotare",
    "nuotavate": "nuotare",
    "nuotavi": "nuotare",
    "nuotavo": "nuotare",
    "nuoterai": "nuotare",
    "nuoteran": "nuotare",
    "nuoteranno": "nuotare",
    "nuoterebbe": "nuotare",
    "nuoterebber": "nuotare",
    "nuoterebbero": "nuotare",
    "nuoterei": "nuotare",
    "nuoteremmo": "nuotare",
    "nuoteremo": "nuotare",
    "nuotereste": "nuotare",
    "nuoteresti": "nuotare",
    "nuoterete": "nuotare",
    "nuoterà": "nuotare",
    "nuoterò": "nuotare",
    "nuoti": "nuoto",
    "nuotiamo": "nuotare",
    "nuotiate": "nuotare",
    "nuotin": "nuotare",
    "nuotino": "nuotare",
    "nuoto": "nuotare",
    "nuotò": "nuotare",
    "nuova": "nuovo",
    "nuovayorchesi": "nuovayorchese",
    "nuove": "nuovo",
    "nuovi": "nuovo",
    "nuovismi": "nuovismo",
    "nuraghi": "nuraghe",
    "nutra": "nutrire",
    "nutran": "nutrire",
    "nutrano": "nutrire",
    "nutre": "nutrire",
    "nutrendo": "nutrire",
    "nutrente": "nutrire",
    "nutrenti": "nutrire",
    "nutri": "nutrire",
    "nutriamo": "nutrire",
    "nutriate": "nutrire",
    "nutrica": "nutricare",
    "nutricai": "nutricare",
    "nutricammo": "nutricare",
    "nutrican": "nutricare",
    "nutricando": "nutricare",
    "nutricano": "nutricare",
    "nutricante": "nutricare",
    "nutricanti": "nutricare",
    "nutricar": "nutricare",
    "nutricaron": "nutricare",
    "nutricarono": "nutricare",
    "nutricasse": "nutricare",
    "nutricasser": "nutricare",
    "nutricassero": "nutricare",
    "nutricassi": "nutricare",
    "nutricassimo": "nutricare",
    "nutricaste": "nutricare",
    "nutricasti": "nutricare",
    "nutricata": "nutricare",
    "nutricate": "nutricare",
    "nutricati": "nutricare",
    "nutricato": "nutricare",
    "nutricava": "nutricare",
    "nutricavamo": "nutricare",
    "nutricavan": "nutricare",
    "nutricavano": "nutricare",
    "nutricavate": "nutricare",
    "nutricavi": "nutricare",
    "nutricavo": "nutricare",
    "nutricherai": "nutricare",
    "nutricheran": "nutricare",
    "nutricheranno": "nutricare",
    "nutricherebbe": "nutricare",
    "nutricherebber": "nutricare",
    "nutricherebbero": "nutricare",
    "nutricherei": "nutricare",
    "nutricheremmo": "nutricare",
    "nutricheremo": "nutricare",
    "nutrichereste": "nutricare",
    "nutricheresti": "nutricare",
    "nutricherete": "nutricare",
    "nutricherà": "nutricare",
    "nutricherò": "nutricare",
    "nutrichi": "nutricare",
    "nutrichiamo": "nutricare",
    "nutrichiate": "nutricare",
    "nutrichin": "nutricare",
    "nutrichino": "nutricare",
    "nutrici": "nutrice",
    "nutrico": "nutricare",
    "nutricò": "nutricare",
    "nutrienti": "nutriente",
    "nutrii": "nutrire",
    "nutrimenti": "nutrimento",
    "nutrimmo": "nutrire",
    "nutrir": "nutrire",
    "nutrirai": "nutrire",
    "nutriran": "nutrire",
    "nutriranno": "nutrire",
    "nutrirebbe": "nutrire",
    "nutrirebber": "nutrire",
    "nutrirebbero": "nutrire",
    "nutrirei": "nutrire",
    "nutriremmo": "nutrire",
    "nutriremo": "nutrire",
    "nutrireste": "nutrire",
    "nutriresti": "nutrire",
    "nutrirete": "nutrire",
    "nutriron": "nutrire",
    "nutrirono": "nutrire",
    "nutrirà": "nutrire",
    "nutrirò": "nutrire",
    "nutrisse": "nutrire",
    "nutrisser": "nutrire",
    "nutrissero": "nutrire",
    "nutrissi": "nutrire",
    "nutrissimo": "nutrire",
    "nutriste": "nutrire",
    "nutristi": "nutrire",
    "nutrita": "nutrito",
    "nutrite": "nutrito",
    "nutriti": "nutrito",
    "nutritiva": "nutritivo",
    "nutritive": "nutritivo",
    "nutritivi": "nutritivo",
    "nutrito": "nutrire",
    "nutriva": "nutrire",
    "nutrivamo": "nutrire",
    "nutrivan": "nutrire",
    "nutrivano": "nutrire",
    "nutrivate": "nutrire",
    "nutrivi": "nutrire",
    "nutrivo": "nutrire",
    "nutrizionali": "nutrizionale",
    "nutrizioni": "nutrizione",
    "nutrizionisti": "nutrizionista",
    "nutro": "nutrire",
    "nutron": "nutrire",
    "nutrono": "nutrire",
    "nutrì": "nutrire",
    "nuvola": "nuvolo",
    "nuvolaglie": "nuvolaglia",
    "nuvole": "nuvolo",
    "nuvolette": "nuvoletta",
    "nuvoli": "nuvolo",
    "nuvoloni": "nuvolone",
    "nuvolosa": "nuvoloso",
    "nuvolose": "nuvoloso",
    "nuvolosi": "nuvoloso",
    "nuziali": "nuziale",
    "obbedendo": "obbedire",
    "obbediamo": "obbedire",
    "obbediate": "obbedire",
    "obbediente": "obbedire",
    "obbedienti": "obbedire",
    "obbedienze": "obbedienza",
    "obbedii": "obbedire",
    "obbedimmo": "obbedire",
    "obbedir": "obbedire",
    "obbedirai": "obbedire",
    "obbediran": "obbedire",
    "obbediranno": "obbedire",
    "obbedirebbe": "obbedire",
    "obbedirebber": "obbedire",
    "obbedirebbero": "obbedire",
    "obbedirei": "obbedire",
    "obbediremmo": "obbedire",
    "obbediremo": "obbedire",
    "obbedireste": "obbedire",
    "obbediresti": "obbedire",
    "obbedirete": "obbedire",
    "obbediron": "obbedire",
    "obbedirono": "obbedire",
    "obbedirà": "obbedire",
    "obbedirò": "obbedire",
    "obbedisca": "obbedire",
    "obbediscan": "obbedire",
    "obbediscano": "obbedire",
    "obbedisce": "obbedire",
    "obbedisci": "obbedire",
    "obbedisco": "obbedire",
    "obbediscon": "obbedire",
    "obbediscono": "obbedire",
    "obbedisse": "obbedire",
    "obbedisser": "obbedire",
    "obbedissero": "obbedire",
    "obbedissi": "obbedire",
    "obbedissimo": "obbedire",
    "obbediste": "obbedire",
    "obbedisti": "obbedire",
    "obbedita": "obbedire",
    "obbedite": "obbedire",
    "obbediti": "obbedire",
    "obbedito": "obbedire",
    "obbediva": "obbedire",
    "obbedivamo": "obbedire",
    "obbedivan": "obbedire",
    "obbedivano": "obbedire",
    "obbedivate": "obbedire",
    "obbedivi": "obbedire",
    "obbedivo": "obbedire",
    "obbedì": "obbedire",
    "obbietta": "obbiettare",
    "obbiettai": "obbiettare",
    "obbiettammo": "obbiettare",
    "obbiettan": "obbiettare",
    "obbiettando": "obbiettare",
    "obbiettano": "obbiettare",
    "obbiettante": "obbiettare",
    "obbiettanti": "obbiettare",
    "obbiettar": "obbiettare",
    "obbiettaron": "obbiettare",
    "obbiettarono": "obbiettare",
    "obbiettasse": "obbiettare",
    "obbiettasser": "obbiettare",
    "obbiettassero": "obbiettare",
    "obbiettassi": "obbiettare",
    "obbiettassimo": "obbiettare",
    "obbiettaste": "obbiettare",
    "obbiettasti": "obbiettare",
    "obbiettata": "obbiettare",
    "obbiettate": "obbiettare",
    "obbiettati": "obbiettare",
    "obbiettato": "obbiettare",
    "obbiettava": "obbiettare",
    "obbiettavamo": "obbiettare",
    "obbiettavan": "obbiettare",
    "obbiettavano": "obbiettare",
    "obbiettavate": "obbiettare",
    "obbiettavi": "obbiettare",
    "obbiettavo": "obbiettare",
    "obbietterai": "obbiettare",
    "obbietteran": "obbiettare",
    "obbietteranno": "obbiettare",
    "obbietterebbe": "obbiettare",
    "obbietterebber": "obbiettare",
    "obbietterebbero": "obbiettare",
    "obbietterei": "obbiettare",
    "obbietteremmo": "obbiettare",
    "obbietteremo": "obbiettare",
    "obbiettereste": "obbiettare",
    "obbietteresti": "obbiettare",
    "obbietterete": "obbiettare",
    "obbietterà": "obbiettare",
    "obbietterò": "obbiettare",
    "obbietti": "obbiettare",
    "obbiettiamo": "obbiettare",
    "obbiettiate": "obbiettare",
    "obbiettin": "obbiettare",
    "obbiettino": "obbiettare",
    "obbiettivi": "obbiettivo",
    "obbietto": "obbiettare",
    "obbiettò": "obbiettare",
    "obbiezioni": "obbiezione",
    "obbliga": "obbligare",
    "obbligai": "obbligare",
    "obbligammo": "obbligare",
    "obbligan": "obbligare",
    "obbligando": "obbligare",
    "obbligano": "obbligare",
    "obbligante": "obbligare",
    "obbliganti": "obbligare",
    "obbligar": "obbligare",
    "obbligaron": "obbligare",
    "obbligarono": "obbligare",
    "obbligasse": "obbligare",
    "obbligasser": "obbligare",
    "obbligassero": "obbligare",
    "obbligassi": "obbligare",
    "obbligassimo": "obbligare",
    "obbligaste": "obbligare",
    "obbligasti": "obbligare",
    "obbligata": "obbligato",
    "obbligate": "obbligato",
    "obbligati": "obbligato",
    "obbligato": "obbligare",
    "obbligatori": "obbligatorio",
    "obbligatoria": "obbligatorio",
    "obbligatorie": "obbligatorio",
    "obbligava": "obbligare",
    "obbligavamo": "obbligare",
    "obbligavan": "obbligare",
    "obbligavano": "obbligare",
    "obbligavate": "obbligare",
    "obbligavi": "obbligare",
    "obbligavo": "obbligare",
    "obbligazionari": "obbligazionario",
    "obbligazionaria": "obbligazionario",
    "obbligazionarie": "obbligazionario",
    "obbligazioni": "obbligazione",
    "obbligazionisti": "obbligazionista",
    "obbligherai": "obbligare",
    "obbligheran": "obbligare",
    "obbligheranno": "obbligare",
    "obbligherebbe": "obbligare",
    "obbligherebber": "obbligare",
    "obbligherebbero": "obbligare",
    "obbligherei": "obbligare",
    "obbligheremmo": "obbligare",
    "obbligheremo": "obbligare",
    "obblighereste": "obbligare",
    "obbligheresti": "obbligare",
    "obbligherete": "obbligare",
    "obbligherà": "obbligare",
    "obbligherò": "obbligare",
    "obblighi": "obbligo",
    "obblighiamo": "obbligare",
    "obblighiate": "obbligare",
    "obblighin": "obbligare",
    "obblighino": "obbligare",
    "obbligo": "obbligare",
    "obbligò": "obbligare",
    "obbrobri": "obbrobrio",
    "obbrobriosa": "obbrobrioso",
    "obbrobriose": "obbrobrioso",
    "obbrobriosi": "obbrobrioso",
    "obelischi": "obelisco",
    "obera": "oberare",
    "oberai": "oberare",
    "oberammo": "oberare",
    "oberan": "oberare",
    "oberando": "oberare",
    "oberano": "oberare",
    "oberante": "oberare",
    "oberanti": "oberare",
    "oberar": "oberare",
    "oberaron": "oberare",
    "oberarono": "oberare",
    "oberasse": "oberare",
    "oberasser": "oberare",
    "oberassero": "oberare",
    "oberassi": "oberare",
    "oberassimo": "oberare",
    "oberaste": "oberare",
    "oberasti": "oberare",
    "oberata": "oberato",
    "oberate": "oberato",
    "oberati": "oberato",
    "oberato": "oberare",
    "oberava": "oberare",
    "oberavamo": "oberare",
    "oberavan": "oberare",
    "oberavano": "oberare",
    "oberavate": "oberare",
    "oberavi": "oberare",
    "oberavo": "oberare",
    "obererai": "oberare",
    "obereran": "oberare",
    "obereranno": "oberare",
    "obererebbe": "oberare",
    "obererebber": "oberare",
    "obererebbero": "oberare",
    "obererei": "oberare",
    "obereremmo": "oberare",
    "obereremo": "oberare",
    "oberereste": "oberare",
    "obereresti": "oberare",
    "obererete": "oberare",
    "obererà": "oberare",
    "obererò": "oberare",
    "oberi": "oberare",
    "oberiamo": "oberare",
    "oberiate": "oberare",
    "oberin": "oberare",
    "oberino": "oberare",
    "obero": "oberare",
    "oberò": "oberare",
    "obesa": "obeso",
    "obese": "obeso",
    "obesi": "obeso",
    "obici": "obice",
    "obietta": "obiettare",
    "obiettai": "obiettare",
    "obiettammo": "obiettare",
    "obiettan": "obiettare",
    "obiettando": "obiettare",
    "obiettano": "obiettare",
    "obiettante": "obiettare",
    "obiettanti": "obiettare",
    "obiettar": "obiettare",
    "obiettaron": "obiettare",
    "obiettarono": "obiettare",
    "obiettasse": "obiettare",
    "obiettasser": "obiettare",
    "obiettassero": "obiettare",
    "obiettassi": "obiettare",
    "obiettassimo": "obiettare",
    "obiettaste": "obiettare",
    "obiettasti": "obiettare",
    "obiettata": "obiettare",
    "obiettate": "obiettare",
    "obiettati": "obiettare",
    "obiettato": "obiettare",
    "obiettava": "obiettare",
    "obiettavamo": "obiettare",
    "obiettavan": "obiettare",
    "obiettavano": "obiettare",
    "obiettavate": "obiettare",
    "obiettavi": "obiettare",
    "obiettavo": "obiettare",
    "obietterai": "obiettare",
    "obietteran": "obiettare",
    "obietteranno": "obiettare",
    "obietterebbe": "obiettare",
    "obietterebber": "obiettare",
    "obietterebbero": "obiettare",
    "obietterei": "obiettare",
    "obietteremmo": "obiettare",
    "obietteremo": "obiettare",
    "obiettereste": "obiettare",
    "obietteresti": "obiettare",
    "obietterete": "obiettare",
    "obietterà": "obiettare",
    "obietterò": "obiettare",
    "obietti": "obiettare",
    "obiettiamo": "obiettare",
    "obiettiate": "obiettare",
    "obiettin": "obiettare",
    "obiettino": "obiettare",
    "obiettiva": "obiettivo",
    "obiettivai": "obiettivare",
    "obiettivammo": "obiettivare",
    "obiettivan": "obiettivare",
    "obiettivando": "obiettivare",
    "obiettivano": "obiettivare",
    "obiettivante": "obiettivare",
    "obiettivanti": "obiettivare",
    "obiettivar": "obiettivare",
    "obiettivaron": "obiettivare",
    "obiettivarono": "obiettivare",
    "obiettivasse": "obiettivare",
    "obiettivasser": "obiettivare",
    "obiettivassero": "obiettivare",
    "obiettivassi": "obiettivare",
    "obiettivassimo": "obiettivare",
    "obiettivaste": "obiettivare",
    "obiettivasti": "obiettivare",
    "obiettivata": "obiettivare",
    "obiettivate": "obiettivare",
    "obiettivati": "obiettivare",
    "obiettivato": "obiettivare",
    "obiettivava": "obiettivare",
    "obiettivavamo": "obiettivare",
    "obiettivavan": "obiettivare",
    "obiettivavano": "obiettivare",
    "obiettivavate": "obiettivare",
    "obiettivavi": "obiettivare",
    "obiettivavo": "obiettivare",
    "obiettive": "obiettivo",
    "obiettiverai": "obiettivare",
    "obiettiveran": "obiettivare",
    "obiettiveranno": "obiettivare",
    "obiettiverebbe": "obiettivare",
    "obiettiverebber": "obiettivare",
    "obiettiverebbero": "obiettivare",
    "obiettiverei": "obiettivare",
    "obiettiveremmo": "obiettivare",
    "obiettiveremo": "obiettivare",
    "obiettivereste": "obiettivare",
    "obiettiveresti": "obiettivare",
    "obiettiverete": "obiettivare",
    "obiettiverà": "obiettivare",
    "obiettiverò": "obiettivare",
    "obiettivi": "obiettivo",
    "obiettiviamo": "obiettivare",
    "obiettiviate": "obiettivare",
    "obiettivin": "obiettivare",
    "obiettivino": "obiettivare",
    "obiettivo": "obiettivare",
    "obiettivò": "obiettivare",
    "obietto": "obiettare",
    "obiettori": "obiettore",
    "obiettò": "obiettare",
    "obiezioni": "obiezione",
    "obitori": "obitorio",
    "oblazioni": "oblazione",
    "obli": "obliare",
    "oblia": "obliare",
    "obliai": "obliare",
    "obliammo": "obliare",
    "obliamo": "obliare",
    "oblian": "obliare",
    "obliando": "obliare",
    "obliano": "obliare",
    "obliante": "obliare",
    "oblianti": "obliare",
    "obliar": "obliare",
    "obliaron": "obliare",
    "obliarono": "obliare",
    "obliasse": "obliare",
    "obliasser": "obliare",
    "obliassero": "obliare",
    "obliassi": "obliare",
    "obliassimo": "obliare",
    "obliaste": "obliare",
    "obliasti": "obliare",
    "obliata": "obliare",
    "obliate": "obliare",
    "obliati": "obliare",
    "obliato": "obliare",
    "obliava": "obliare",
    "obliavamo": "obliare",
    "obliavan": "obliare",
    "obliavano": "obliare",
    "obliavate": "obliare",
    "obliavi": "obliare",
    "obliavo": "obliare",
    "oblierai": "obliare",
    "oblieran": "obliare",
    "oblieranno": "obliare",
    "oblierebbe": "obliare",
    "oblierebber": "obliare",
    "oblierebbero": "obliare",
    "oblierei": "obliare",
    "oblieremmo": "obliare",
    "oblieremo": "obliare",
    "obliereste": "obliare",
    "oblieresti": "obliare",
    "oblierete": "obliare",
    "oblierà": "obliare",
    "oblierò": "obliare",
    "oblii": "oblio",
    "oblin": "obliare",
    "oblino": "obliare",
    "oblio": "obliare",
    "obliqua": "obliquo",
    "oblique": "obliquo",
    "obliqui": "obliquo",
    "oblitera": "obliterare",
    "obliterai": "obliterare",
    "obliterammo": "obliterare",
    "obliteran": "obliterare",
    "obliterando": "obliterare",
    "obliterano": "obliterare",
    "obliterante": "obliterare",
    "obliteranti": "obliterare",
    "obliterar": "obliterare",
    "obliteraron": "obliterare",
    "obliterarono": "obliterare",
    "obliterasse": "obliterare",
    "obliterasser": "obliterare",
    "obliterassero": "obliterare",
    "obliterassi": "obliterare",
    "obliterassimo": "obliterare",
    "obliteraste": "obliterare",
    "obliterasti": "obliterare",
    "obliterata": "obliterare",
    "obliterate": "obliterare",
    "obliterati": "obliterare",
    "obliterato": "obliterare",
    "obliterava": "obliterare",
    "obliteravamo": "obliterare",
    "obliteravan": "obliterare",
    "obliteravano": "obliterare",
    "obliteravate": "obliterare",
    "obliteravi": "obliterare",
    "obliteravo": "obliterare",
    "oblitererai": "obliterare",
    "oblitereran": "obliterare",
    "oblitereranno": "obliterare",
    "oblitererebbe": "obliterare",
    "oblitererebber": "obliterare",
    "oblitererebbero": "obliterare",
    "oblitererei": "obliterare",
    "oblitereremmo": "obliterare",
    "oblitereremo": "obliterare",
    "obliterereste": "obliterare",
    "oblitereresti": "obliterare",
    "oblitererete": "obliterare",
    "oblitererà": "obliterare",
    "oblitererò": "obliterare",
    "obliteri": "obliterare",
    "obliteriamo": "obliterare",
    "obliteriate": "obliterare",
    "obliterin": "obliterare",
    "obliterino": "obliterare",
    "oblitero": "obliterare",
    "obliterò": "obliterare",
    "obliò": "obliare",
    "obnubila": "obnubilare",
    "obnubilai": "obnubilare",
    "obnubilammo": "obnubilare",
    "obnubilan": "obnubilare",
    "obnubilando": "obnubilare",
    "obnubilano": "obnubilare",
    "obnubilante": "obnubilare",
    "obnubilanti": "obnubilare",
    "obnubilar": "obnubilare",
    "obnubilaron": "obnubilare",
    "obnubilarono": "obnubilare",
    "obnubilasse": "obnubilare",
    "obnubilasser": "obnubilare",
    "obnubilassero": "obnubilare",
    "obnubilassi": "obnubilare",
    "obnubilassimo": "obnubilare",
    "obnubilaste": "obnubilare",
    "obnubilasti": "obnubilare",
    "obnubilata": "obnubilare",
    "obnubilate": "obnubilare",
    "obnubilati": "obnubilare",
    "obnubilato": "obnubilare",
    "obnubilava": "obnubilare",
    "obnubilavamo": "obnubilare",
    "obnubilavan": "obnubilare",
    "obnubilavano": "obnubilare",
    "obnubilavate": "obnubilare",
    "obnubilavi": "obnubilare",
    "obnubilavo": "obnubilare",
    "obnubilerai": "obnubilare",
    "obnubileran": "obnubilare",
    "obnubileranno": "obnubilare",
    "obnubilerebbe": "obnubilare",
    "obnubilerebber": "obnubilare",
    "obnubilerebbero": "obnubilare",
    "obnubilerei": "obnubilare",
    "obnubileremmo": "obnubilare",
    "obnubileremo": "obnubilare",
    "obnubilereste": "obnubilare",
    "obnubileresti": "obnubilare",
    "obnubilerete": "obnubilare",
    "obnubilerà": "obnubilare",
    "obnubilerò": "obnubilare",
    "obnubili": "obnubilare",
    "obnubiliamo": "obnubilare",
    "obnubiliate": "obnubilare",
    "obnubilin": "obnubilare",
    "obnubilino": "obnubilare",
    "obnubilo": "obnubilare",
    "obnubilò": "obnubilare",
    "oboi": "oboe",
    "oboli": "obolo",
    "obsoleta": "obsoleto",
    "obsolete": "obsoleto",
    "obsoleti": "obsoleto",
    "occasiona": "occasionare",
    "occasionai": "occasionare",
    "occasionali": "occasionale",
    "occasionammo": "occasionare",
    "occasionan": "occasionare",
    "occasionando": "occasionare",
    "occasionano": "occasionare",
    "occasionante": "occasionare",
    "occasionanti": "occasionare",
    "occasionar": "occasionare",
    "occasionaron": "occasionare",
    "occasionarono": "occasionare",
    "occasionasse": "occasionare",
    "occasionasser": "occasionare",
    "occasionassero": "occasionare",
    "occasionassi": "occasionare",
    "occasionassimo": "occasionare",
    "occasionaste": "occasionare",
    "occasionasti": "occasionare",
    "occasionata": "occasionare",
    "occasionate": "occasionare",
    "occasionati": "occasionare",
    "occasionato": "occasionare",
    "occasionava": "occasionare",
    "occasionavamo": "occasionare",
    "occasionavan": "occasionare",
    "occasionavano": "occasionare",
    "occasionavate": "occasionare",
    "occasionavi": "occasionare",
    "occasionavo": "occasionare",
    "occasionerai": "occasionare",
    "occasioneran": "occasionare",
    "occasioneranno": "occasionare",
    "occasionerebbe": "occasionare",
    "occasionerebber": "occasionare",
    "occasionerebbero": "occasionare",
    "occasionerei": "occasionare",
    "occasioneremmo": "occasionare",
    "occasioneremo": "occasionare",
    "occasionereste": "occasionare",
    "occasioneresti": "occasionare",
    "occasionerete": "occasionare",
    "occasionerà": "occasionare",
    "occasionerò": "occasionare",
    "occasioni": "occasione",
    "occasioniamo": "occasionare",
    "occasioniate": "occasionare",
    "occasionin": "occasionare",
    "occasionino": "occasionare",
    "occasiono": "occasionare",
    "occasionò": "occasionare",
    "occhettiana": "occhettiano",
    "occhettiane": "occhettiano",
    "occhettiani": "occhettiano",
    "occhi": "occhio",
    "occhiaie": "occhiaia",
    "occhialetti": "occhialetto",
    "occhiali": "occhiale",
    "occhialini": "occhialino",
    "occhialoni": "occhialone",
    "occhialuta": "occhialuto",
    "occhialute": "occhialuto",
    "occhialuti": "occhialuto",
    "occhiata": "occhiato",
    "occhiatacce": "occhiataccia",
    "occhiate": "occhiato",
    "occhiati": "occhiato",
    "occhieggerai": "occhieggiare",
    "occhieggeran": "occhieggiare",
    "occhieggeranno": "occhieggiare",
    "occhieggerebbe": "occhieggiare",
    "occhieggerebber": "occhieggiare",
    "occhieggerebbero": "occhieggiare",
    "occhieggerei": "occhieggiare",
    "occhieggeremmo": "occhieggiare",
    "occhieggeremo": "occhieggiare",
    "occhieggereste": "occhieggiare",
    "occhieggeresti": "occhieggiare",
    "occhieggerete": "occhieggiare",
    "occhieggerà": "occhieggiare",
    "occhieggerò": "occhieggiare",
    "occhieggi": "occhieggiare",
    "occhieggia": "occhieggiare",
    "occhieggiai": "occhieggiare",
    "occhieggiammo": "occhieggiare",
    "occhieggiamo": "occhieggiare",
    "occhieggian": "occhieggiare",
    "occhieggiando": "occhieggiare",
    "occhieggiano": "occhieggiare",
    "occhieggiante": "occhieggiare",
    "occhieggianti": "occhieggiare",
    "occhieggiar": "occhieggiare",
    "occhieggiaron": "occhieggiare",
    "occhieggiarono": "occhieggiare",
    "occhieggiasse": "occhieggiare",
    "occhieggiasser": "occhieggiare",
    "occhieggiassero": "occhieggiare",
    "occhieggiassi": "occhieggiare",
    "occhieggiassimo": "occhieggiare",
    "occhieggiaste": "occhieggiare",
    "occhieggiasti": "occhieggiare",
    "occhieggiata": "occhieggiare",
    "occhieggiate": "occhieggiare",
    "occhieggiati": "occhieggiare",
    "occhieggiato": "occhieggiare",
    "occhieggiava": "occhieggiare",
    "occhieggiavamo": "occhieggiare",
    "occhieggiavan": "occhieggiare",
    "occhieggiavano": "occhieggiare",
    "occhieggiavate": "occhieggiare",
    "occhieggiavi": "occhieggiare",
    "occhieggiavo": "occhieggiare",
    "occhieggin": "occhieggiare",
    "occhieggino": "occhieggiare",
    "occhieggio": "occhieggiare",
    "occhieggiò": "occhieggiare",
    "occhielli": "occhiello",
    "occhietti": "occhietto",
    "occhiolini": "occhiolino",
    "occhioni": "occhione",
    "occhiuta": "occhiuto",
    "occhiute": "occhiuto",
    "occhiuti": "occhiuto",
    "occidentali": "occidentale",
    "occidentalizza": "occidentalizzare",
    "occidentalizzai": "occidentalizzare",
    "occidentalizzammo": "occidentalizzare",
    "occidentalizzan": "occidentalizzare",
    "occidentalizzando": "occidentalizzare",
    "occidentalizzano": "occidentalizzare",
    "occidentalizzante": "occidentalizzare",
    "occidentalizzanti": "occidentalizzare",
    "occidentalizzar": "occidentalizzare",
    "occidentalizzaron": "occidentalizzare",
    "occidentalizzarono": "occidentalizzare",
    "occidentalizzasse": "occidentalizzare",
    "occidentalizzasser": "occidentalizzare",
    "occidentalizzassero": "occidentalizzare",
    "occidentalizzassi": "occidentalizzare",
    "occidentalizzassimo": "occidentalizzare",
    "occidentalizzaste": "occidentalizzare",
    "occidentalizzasti": "occidentalizzare",
    "occidentalizzata": "occidentalizzare",
    "occidentalizzate": "occidentalizzare",
    "occidentalizzati": "occidentalizzare",
    "occidentalizzato": "occidentalizzare",
    "occidentalizzava": "occidentalizzare",
    "occidentalizzavamo": "occidentalizzare",
    "occidentalizzavan": "occidentalizzare",
    "occidentalizzavano": "occidentalizzare",
    "occidentalizzavate": "occidentalizzare",
    "occidentalizzavi": "occidentalizzare",
    "occidentalizzavo": "occidentalizzare",
    "occidentalizzerai": "occidentalizzare",
    "occidentalizzeran": "occidentalizzare",
    "occidentalizzeranno": "occidentalizzare",
    "occidentalizzerebbe": "occidentalizzare",
    "occidentalizzerebber": "occidentalizzare",
    "occidentalizzerebbero": "occidentalizzare",
    "occidentalizzerei": "occidentalizzare",
    "occidentalizzeremmo": "occidentalizzare",
    "occidentalizzeremo": "occidentalizzare",
    "occidentalizzereste": "occidentalizzare",
    "occidentalizzeresti": "occidentalizzare",
    "occidentalizzerete": "occidentalizzare",
    "occidentalizzerà": "occidentalizzare",
    "occidentalizzerò": "occidentalizzare",
    "occidentalizzi": "occidentalizzare",
    "occidentalizziamo": "occidentalizzare",
    "occidentalizziate": "occidentalizzare",
    "occidentalizzin": "occidentalizzare",
    "occidentalizzino": "occidentalizzare",
    "occidentalizzo": "occidentalizzare",
    "occidentalizzò": "occidentalizzare",
    "occidenti": "occidente",
    "occluda": "occludere",
    "occludan": "occludere",
    "occludano": "occludere",
    "occlude": "occludere",
    "occludemmo": "occludere",
    "occludendo": "occludere",
    "occludente": "occludere",
    "occludenti": "occludere",
    "occluder": "occludere",
    "occluderai": "occludere",
    "occluderan": "occludere",
    "occluderanno": "occludere",
    "occluderebbe": "occludere",
    "occluderebber": "occludere",
    "occluderebbero": "occludere",
    "occluderei": "occludere",
    "occluderemmo": "occludere",
    "occluderemo": "occludere",
    "occludereste": "occludere",
    "occluderesti": "occludere",
    "occluderete": "occludere",
    "occluderà": "occludere",
    "occluderò": "occludere",
    "occludesse": "occludere",
    "occludesser": "occludere",
    "occludessero": "occludere",
    "occludessi": "occludere",
    "occludessimo": "occludere",
    "occludeste": "occludere",
    "occludesti": "occludere",
    "occludete": "occludere",
    "occludeva": "occludere",
    "occludevamo": "occludere",
    "occludevan": "occludere",
    "occludevano": "occludere",
    "occludevate": "occludere",
    "occludevi": "occludere",
    "occludevo": "occludere",
    "occludi": "occludere",
    "occludiamo": "occludere",
    "occludiate": "occludere",
    "occludo": "occludere",
    "occludon": "occludere",
    "occludono": "occludere",
    "occlusa": "occludere",
    "occluse": "occludere",
    "occluser": "occludere",
    "occlusero": "occludere",
    "occlusi": "occludere",
    "occlusioni": "occlusione",
    "occluso": "occludere",
    "occorra": "occorrere",
    "occorran": "occorrere",
    "occorrano": "occorrere",
    "occorre": "occorrere",
    "occorremmo": "occorrere",
    "occorrendo": "occorrere",
    "occorrente": "occorrere",
    "occorrenti": "occorrere",
    "occorrenze": "occorrenza",
    "occorrer": "occorrere",
    "occorrerai": "occorrere",
    "occorreran": "occorrere",
    "occorreranno": "occorrere",
    "occorrerebbe": "occorrere",
    "occorrerebber": "occorrere",
    "occorrerebbero": "occorrere",
    "occorrerei": "occorrere",
    "occorreremmo": "occorrere",
    "occorreremo": "occorrere",
    "occorrereste": "occorrere",
    "occorreresti": "occorrere",
    "occorrerete": "occorrere",
    "occorrerà": "occorrere",
    "occorrerò": "occorrere",
    "occorresse": "occorrere",
    "occorresser": "occorrere",
    "occorressero": "occorrere",
    "occorressi": "occorrere",
    "occorressimo": "occorrere",
    "occorreste": "occorrere",
    "occorresti": "occorrere",
    "occorrete": "occorrere",
    "occorreva": "occorrere",
    "occorrevamo": "occorrere",
    "occorrevan": "occorrere",
    "occorrevano": "occorrere",
    "occorrevate": "occorrere",
    "occorrevi": "occorrere",
    "occorrevo": "occorrere",
    "occorri": "occorrere",
    "occorriamo": "occorrere",
    "occorriate": "occorrere",
    "occorro": "occorrere",
    "occorron": "occorrere",
    "occorrono": "occorrere",
    "occorsa": "occorrere",
    "occorse": "occorrere",
    "occorser": "occorrere",
    "occorsero": "occorrere",
    "occorsi": "occorrere",
    "occorso": "occorrere",
    "occulta": "occulto",
    "occultabili": "occultabile",
    "occultai": "occultare",
    "occultamenti": "occultamento",
    "occultammo": "occultare",
    "occultan": "occultare",
    "occultando": "occultare",
    "occultano": "occultare",
    "occultante": "occultare",
    "occultanti": "occultare",
    "occultar": "occultare",
    "occultaron": "occultare",
    "occultarono": "occultare",
    "occultasse": "occultare",
    "occultasser": "occultare",
    "occultassero": "occultare",
    "occultassi": "occultare",
    "occultassimo": "occultare",
    "occultaste": "occultare",
    "occultasti": "occultare",
    "occultata": "occultare",
    "occultate": "occultare",
    "occultati": "occultare",
    "occultato": "occultare",
    "occultava": "occultare",
    "occultavamo": "occultare",
    "occultavan": "occultare",
    "occultavano": "occultare",
    "occultavate": "occultare",
    "occultavi": "occultare",
    "occultavo": "occultare",
    "occulte": "occulto",
    "occulterai": "occultare",
    "occulteran": "occultare",
    "occulteranno": "occultare",
    "occulterebbe": "occultare",
    "occulterebber": "occultare",
    "occulterebbero": "occultare",
    "occulterei": "occultare",
    "occulteremmo": "occultare",
    "occulteremo": "occultare",
    "occultereste": "occultare",
    "occulteresti": "occultare",
    "occulterete": "occultare",
    "occulterà": "occultare",
    "occulterò": "occultare",
    "occulti": "occulto",
    "occultiamo": "occultare",
    "occultiate": "occultare",
    "occultin": "occultare",
    "occultino": "occultare",
    "occulto": "occultare",
    "occultò": "occultare",
    "occupa": "occupare",
    "occupai": "occupare",
    "occupammo": "occupare",
    "occupan": "occupare",
    "occupando": "occupare",
    "occupano": "occupare",
    "occupante": "occupare",
    "occupanti": "occupare",
    "occupar": "occupare",
    "occuparon": "occupare",
    "occuparono": "occupare",
    "occupasse": "occupare",
    "occupasser": "occupare",
    "occupassero": "occupare",
    "occupassi": "occupare",
    "occupassimo": "occupare",
    "occupaste": "occupare",
    "occupasti": "occupare",
    "occupata": "occupato",
    "occupate": "occupato",
    "occupati": "occupato",
    "occupato": "occupare",
    "occupava": "occupare",
    "occupavamo": "occupare",
    "occupavan": "occupare",
    "occupavano": "occupare",
    "occupavate": "occupare",
    "occupavi": "occupare",
    "occupavo": "occupare",
    "occupazionali": "occupazionale",
    "occupazioni": "occupazione",
    "occuperai": "occupare",
    "occuperan": "occupare",
    "occuperanno": "occupare",
    "occuperebbe": "occupare",
    "occuperebber": "occupare",
    "occuperebbero": "occupare",
    "occuperei": "occupare",
    "occuperemmo": "occupare",
    "occuperemo": "occupare",
    "occupereste": "occupare",
    "occuperesti": "occupare",
    "occuperete": "occupare",
    "occuperà": "occupare",
    "occuperò": "occupare",
    "occupi": "occupare",
    "occupiamo": "occupare",
    "occupiate": "occupare",
    "occupin": "occupare",
    "occupino": "occupare",
    "occupo": "occupare",
    "occupò": "occupare",
    "oceani": "oceano",
    "oceanica": "oceanico",
    "oceaniche": "oceanico",
    "oceanici": "oceanico",
    "oceanografica": "oceanografico",
    "oceanografiche": "oceanografico",
    "oceanografici": "oceanografico",
    "oche": "oca",
    "oculari": "oculare",
    "oculata": "oculato",
    "oculate": "oculato",
    "oculatezze": "oculatezza",
    "oculati": "oculato",
    "oculisti": "oculista",
    "oculistica": "oculistico",
    "oculistiche": "oculistico",
    "oculistici": "oculistico",
    "oda": "udire",
    "odan": "udire",
    "odano": "udire",
    "ode": "udire",
    "odi": "udire",
    "odia": "odiare",
    "odiai": "odiare",
    "odiammo": "odiare",
    "odiamo": "odiare",
    "odian": "odiare",
    "odiando": "odiare",
    "odiano": "odiare",
    "odiante": "odiare",
    "odianti": "odiare",
    "odiar": "odiare",
    "odiaron": "odiare",
    "odiarono": "odiare",
    "odiasse": "odiare",
    "odiasser": "odiare",
    "odiassero": "odiare",
    "odiassi": "odiare",
    "odiassimo": "odiare",
    "odiaste": "odiare",
    "odiasti": "odiare",
    "odiata": "odiare",
    "odiate": "odiata",
    "odiati": "odiare",
    "odiato": "odiare",
    "odiava": "odiare",
    "odiavamo": "odiare",
    "odiavan": "odiare",
    "odiavano": "odiare",
    "odiavate": "odiare",
    "odiavi": "odiare",
    "odiavo": "odiare",
    "odierai": "odiare",
    "odieran": "odiare",
    "odieranno": "odiare",
    "odierebbe": "odiare",
    "odierebber": "odiare",
    "odierebbero": "odiare",
    "odierei": "odiare",
    "odieremmo": "odiare",
    "odieremo": "odiare",
    "odiereste": "odiare",
    "odieresti": "odiare",
    "odierete": "odiare",
    "odierna": "odierno",
    "odierne": "odierno",
    "odierni": "odierno",
    "odierà": "odiare",
    "odierò": "odiare",
    "odii": "odio",
    "odin": "odiare",
    "odino": "odiare",
    "odio": "odiare",
    "odiosa": "odioso",
    "odiose": "odioso",
    "odiosi": "odioso",
    "odissee": "odissea",
    "odiò": "odiare",
    "odo": "udire",
    "odon": "udire",
    "odono": "udire",
    "odontoiatri": "odontoiatra",
    "odontoiatrica": "odontoiatrico",
    "odontoiatriche": "odontoiatrico",
    "odontoiatrici": "odontoiatrico",
    "odontotecnici": "odontotecnico",
    "odora": "odorare",
    "odorai": "odorare",
    "odorammo": "odorare",
    "odoran": "odorare",
    "odorando": "odorare",
    "odorano": "odorare",
    "odorante": "odorare",
    "odoranti": "odorare",
    "odorar": "odorare",
    "odoraron": "odorare",
    "odorarono": "odorare",
    "odorasse": "odorare",
    "odorasser": "odorare",
    "odorassero": "odorare",
    "odorassi": "odorare",
    "odorassimo": "odorare",
    "odoraste": "odorare",
    "odorasti": "odorare",
    "odorata": "odorare",
    "odorate": "odorare",
    "odorati": "odorare",
    "odorato": "odorare",
    "odorava": "odorare",
    "odoravamo": "odorare",
    "odoravan": "odorare",
    "odoravano": "odorare",
    "odoravate": "odorare",
    "odoravi": "odorare",
    "odoravo": "odorare",
    "odorerai": "odorare",
    "odoreran": "odorare",
    "odoreranno": "odorare",
    "odorerebbe": "odorare",
    "odorerebber": "odorare",
    "odorerebbero": "odorare",
    "odorerei": "odorare",
    "odoreremmo": "odorare",
    "odoreremo": "odorare",
    "odorereste": "odorare",
    "odoreresti": "odorare",
    "odorerete": "odorare",
    "odorerà": "odorare",
    "odorerò": "odorare",
    "odori": "odore",
    "odoriamo": "odorare",
    "odoriate": "odorare",
    "odorin": "odorare",
    "odorino": "odorare",
    "odoro": "odorare",
    "odorosa": "odoroso",
    "odorose": "odoroso",
    "odorosi": "odoroso",
    "odorò": "odorare",
    "offenda": "offendere",
    "offendan": "offendere",
    "offendano": "offendere",
    "offende": "offendere",
    "offendemmo": "offendere",
    "offendendo": "offendere",
    "offendente": "offendere",
    "offendenti": "offendere",
    "offender": "offendere",
    "offenderai": "offendere",
    "offenderan": "offendere",
    "offenderanno": "offendere",
    "offenderebbe": "offendere",
    "offenderebber": "offendere",
    "offenderebbero": "offendere",
    "offenderei": "offendere",
    "offenderemmo": "offendere",
    "offenderemo": "offendere",
    "offendereste": "offendere",
    "offenderesti": "offendere",
    "offenderete": "offendere",
    "offenderà": "offendere",
    "offenderò": "offendere",
    "offendesse": "offendere",
    "offendesser": "offendere",
    "offendessero": "offendere",
    "offendessi": "offendere",
    "offendessimo": "offendere",
    "offendeste": "offendere",
    "offendesti": "offendere",
    "offendete": "offendere",
    "offendeva": "offendere",
    "offendevamo": "offendere",
    "offendevan": "offendere",
    "offendevano": "offendere",
    "offendevate": "offendere",
    "offendevi": "offendere",
    "offendevo": "offendere",
    "offendi": "offendere",
    "offendiamo": "offendere",
    "offendiate": "offendere",
    "offendo": "offendere",
    "offendon": "offendere",
    "offendono": "offendere",
    "offensiva": "offensivo",
    "offensive": "offensivo",
    "offensivi": "offensivo",
    "offerenti": "offerente",
    "offerta": "offrire",
    "offerte": "offrire",
    "offerti": "offrire",
    "offerto": "offrire",
    "offesa": "offeso",
    "offese": "offeso",
    "offeser": "offendere",
    "offesero": "offendere",
    "offesi": "offeso",
    "offeso": "offendere",
    "offesè": "offendere",
    "officerai": "officiare",
    "officeran": "officiare",
    "officeranno": "officiare",
    "officerebbe": "officiare",
    "officerebber": "officiare",
    "officerebbero": "officiare",
    "officerei": "officiare",
    "officeremmo": "officiare",
    "officeremo": "officiare",
    "officereste": "officiare",
    "officeresti": "officiare",
    "officerete": "officiare",
    "officerà": "officiare",
    "officerò": "officiare",
    "offici": "officiare",
    "officia": "officiare",
    "officiai": "officiare",
    "officiammo": "officiare",
    "officiamo": "officiare",
    "offician": "officiare",
    "officiando": "officiare",
    "officiano": "officiare",
    "officiante": "officiare",
    "officianti": "officiare",
    "officiar": "officiare",
    "officiaron": "officiare",
    "officiarono": "officiare",
    "officiasse": "officiare",
    "officiasser": "officiare",
    "officiassero": "officiare",
    "officiassi": "officiare",
    "officiassimo": "officiare",
    "officiaste": "officiare",
    "officiasti": "officiare",
    "officiata": "officiare",
    "officiate": "officiare",
    "officiati": "officiare",
    "officiato": "officiare",
    "officiava": "officiare",
    "officiavamo": "officiare",
    "officiavan": "officiare",
    "officiavano": "officiare",
    "officiavate": "officiare",
    "officiavi": "officiare",
    "officiavo": "officiare",
    "officin": "officiare",
    "officinali": "officinale",
    "officine": "officina",
    "officino": "officiare",
    "officio": "officiare",
    "officiò": "officiare",
    "offra": "offrire",
    "offran": "offrire",
    "offrano": "offrire",
    "offre": "offrire",
    "offrendo": "offrire",
    "offrente": "offrire",
    "offrenti": "offrire",
    "offri": "offrire",
    "offriamo": "offrire",
    "offriate": "offrire",
    "offrii": "offrire",
    "offrimmo": "offrire",
    "offrir": "offrire",
    "offrirai": "offrire",
    "offriran": "offrire",
    "offriranno": "offrire",
    "offrirebbe": "offrire",
    "offrirebber": "offrire",
    "offrirebbero": "offrire",
    "offrirei": "offrire",
    "offriremmo": "offrire",
    "offriremo": "offrire",
    "offrireste": "offrire",
    "offriresti": "offrire",
    "offrirete": "offrire",
    "offriron": "offrire",
    "offrirono": "offrire",
    "offrirà": "offrire",
    "offrirò": "offrire",
    "offrisse": "offrire",
    "offrisser": "offrire",
    "offrissero": "offrire",
    "offrissi": "offrire",
    "offrissimo": "offrire",
    "offriste": "offrire",
    "offristi": "offrire",
    "offrite": "offrire",
    "offriva": "offrire",
    "offrivamo": "offrire",
    "offrivan": "offrire",
    "offrivano": "offrire",
    "offrivate": "offrire",
    "offrivi": "offrire",
    "offrivo": "offrire",
    "offro": "offrire",
    "offron": "offrire",
    "offrono": "offrire",
    "offrì": "offrire",
    "offusca": "offuscare",
    "offuscai": "offuscare",
    "offuscammo": "offuscare",
    "offuscan": "offuscare",
    "offuscando": "offuscare",
    "offuscano": "offuscare",
    "offuscante": "offuscare",
    "offuscanti": "offuscare",
    "offuscar": "offuscare",
    "offuscaron": "offuscare",
    "offuscarono": "offuscare",
    "offuscasse": "offuscare",
    "offuscasser": "offuscare",
    "offuscassero": "offuscare",
    "offuscassi": "offuscare",
    "offuscassimo": "offuscare",
    "offuscaste": "offuscare",
    "offuscasti": "offuscare",
    "offuscata": "offuscare",
    "offuscate": "offuscare",
    "offuscati": "offuscare",
    "offuscato": "offuscare",
    "offuscava": "offuscare",
    "offuscavamo": "offuscare",
    "offuscavan": "offuscare",
    "offuscavano": "offuscare",
    "offuscavate": "offuscare",
    "offuscavi": "offuscare",
    "offuscavo": "offuscare",
    "offuscherai": "offuscare",
    "offuscheran": "offuscare",
    "offuscheranno": "offuscare",
    "offuscherebbe": "offuscare",
    "offuscherebber": "offuscare",
    "offuscherebbero": "offuscare",
    "offuscherei": "offuscare",
    "offuscheremmo": "offuscare",
    "offuscheremo": "offuscare",
    "offuschereste": "offuscare",
    "offuscheresti": "offuscare",
    "offuscherete": "offuscare",
    "offuscherà": "offuscare",
    "offuscherò": "offuscare",
    "offuschi": "offuscare",
    "offuschiamo": "offuscare",
    "offuschiate": "offuscare",
    "offuschin": "offuscare",
    "offuschino": "offuscare",
    "offusco": "offuscare",
    "offuscò": "offuscare",
    "oftalmica": "oftalmico",
    "oftalmiche": "oftalmico",
    "oftalmici": "oftalmico",
    "oggetta": "oggetto",
    "oggette": "oggetto",
    "oggetti": "oggetto",
    "oggettini": "oggettino",
    "oggettiva": "oggettivo",
    "oggettivai": "oggettivare",
    "oggettivammo": "oggettivare",
    "oggettivan": "oggettivare",
    "oggettivando": "oggettivare",
    "oggettivano": "oggettivare",
    "oggettivante": "oggettivare",
    "oggettivanti": "oggettivare",
    "oggettivar": "oggettivare",
    "oggettivaron": "oggettivare",
    "oggettivarono": "oggettivare",
    "oggettivasse": "oggettivare",
    "oggettivasser": "oggettivare",
    "oggettivassero": "oggettivare",
    "oggettivassi": "oggettivare",
    "oggettivassimo": "oggettivare",
    "oggettivaste": "oggettivare",
    "oggettivasti": "oggettivare",
    "oggettivata": "oggettivare",
    "oggettivate": "oggettivare",
    "oggettivati": "oggettivare",
    "oggettivato": "oggettivare",
    "oggettivava": "oggettivare",
    "oggettivavamo": "oggettivare",
    "oggettivavan": "oggettivare",
    "oggettivavano": "oggettivare",
    "oggettivavate": "oggettivare",
    "oggettivavi": "oggettivare",
    "oggettivavo": "oggettivare",
    "oggettive": "oggettivo",
    "oggettiverai": "oggettivare",
    "oggettiveran": "oggettivare",
    "oggettiveranno": "oggettivare",
    "oggettiverebbe": "oggettivare",
    "oggettiverebber": "oggettivare",
    "oggettiverebbero": "oggettivare",
    "oggettiverei": "oggettivare",
    "oggettiveremmo": "oggettivare",
    "oggettiveremo": "oggettivare",
    "oggettivereste": "oggettivare",
    "oggettiveresti": "oggettivare",
    "oggettiverete": "oggettivare",
    "oggettiverà": "oggettivare",
    "oggettiverò": "oggettivare",
    "oggettivi": "oggettivo",
    "oggettiviamo": "oggettivare",
    "oggettiviate": "oggettivare",
    "oggettivin": "oggettivare",
    "oggettivino": "oggettivare",
    "oggettivo": "oggettivare",
    "oggettivò": "oggettivare",
    "oggettuali": "oggettuale",
    "ogivali": "ogivale",
    "ogive": "ogiva",
    "olandesi": "olandese",
    "ole": "ola",
    "oleandri": "oleandro",
    "oleari": "oleario",
    "olearia": "oleario",
    "olearie": "oleario",
    "oleata": "oleato",
    "oleate": "oleato",
    "oleati": "oleato",
    "oleifici": "oleificio",
    "oleodotti": "oleodotto",
    "oleografica": "oleografico",
    "oleografiche": "oleografico",
    "oleografici": "oleografico",
    "oleografie": "oleografia",
    "oleosa": "oleoso",
    "oleose": "oleoso",
    "oleosi": "oleoso",
    "olezza": "olezzare",
    "olezzai": "olezzare",
    "olezzammo": "olezzare",
    "olezzan": "olezzare",
    "olezzando": "olezzare",
    "olezzano": "olezzare",
    "olezzante": "olezzare",
    "olezzanti": "olezzare",
    "olezzar": "olezzare",
    "olezzaron": "olezzare",
    "olezzarono": "olezzare",
    "olezzasse": "olezzare",
    "olezzasser": "olezzare",
    "olezzassero": "olezzare",
    "olezzassi": "olezzare",
    "olezzassimo": "olezzare",
    "olezzaste": "olezzare",
    "olezzasti": "olezzare",
    "olezzata": "olezzare",
    "olezzate": "olezzare",
    "olezzati": "olezzare",
    "olezzato": "olezzare",
    "olezzava": "olezzare",
    "olezzavamo": "olezzare",
    "olezzavan": "olezzare",
    "olezzavano": "olezzare",
    "olezzavate": "olezzare",
    "olezzavi": "olezzare",
    "olezzavo": "olezzare",
    "olezzerai": "olezzare",
    "olezzeran": "olezzare",
    "olezzeranno": "olezzare",
    "olezzerebbe": "olezzare",
    "olezzerebber": "olezzare",
    "olezzerebbero": "olezzare",
    "olezzerei": "olezzare",
    "olezzeremmo": "olezzare",
    "olezzeremo": "olezzare",
    "olezzereste": "olezzare",
    "olezzeresti": "olezzare",
    "olezzerete": "olezzare",
    "olezzerà": "olezzare",
    "olezzerò": "olezzare",
    "olezzi": "olezzare",
    "olezziamo": "olezzare",
    "olezziate": "olezzare",
    "olezzin": "olezzare",
    "olezzino": "olezzare",
    "olezzo": "olezzare",
    "olezzò": "olezzare",
    "olfatta": "olfatto",
    "olfatte": "olfatto",
    "olfatti": "olfatto",
    "olfattiva": "olfattivo",
    "olfattive": "olfattivo",
    "olfattivi": "olfattivo",
    "oli": "olio",
    "olia": "oliare",
    "oliai": "oliare",
    "oliammo": "oliare",
    "oliamo": "oliare",
    "olian": "oliare",
    "oliando": "oliare",
    "oliano": "oliare",
    "oliante": "oliare",
    "olianti": "oliare",
    "oliar": "oliare",
    "oliaron": "oliare",
    "oliarono": "oliare",
    "oliasse": "oliare",
    "oliasser": "oliare",
    "oliassero": "oliare",
    "oliassi": "oliare",
    "oliassimo": "oliare",
    "oliaste": "oliare",
    "oliasti": "oliare",
    "oliata": "oliato",
    "oliate": "oliato",
    "oliati": "oliato",
    "oliato": "oliare",
    "oliava": "oliare",
    "oliavamo": "oliare",
    "oliavan": "oliare",
    "oliavano": "oliare",
    "oliavate": "oliare",
    "oliavi": "oliare",
    "oliavo": "oliare",
    "olierai": "oliare",
    "olieran": "oliare",
    "olieranno": "oliare",
    "olierebbe": "oliare",
    "olierebber": "oliare",
    "olierebbero": "oliare",
    "olierei": "oliare",
    "olieremmo": "oliare",
    "olieremo": "oliare",
    "oliereste": "oliare",
    "olieresti": "oliare",
    "olierete": "oliare",
    "olierà": "oliare",
    "olierò": "oliare",
    "oligarchi": "oligarca",
    "oligarchica": "oligarchico",
    "oligarchiche": "oligarchico",
    "oligarchici": "oligarchico",
    "oligarchie": "oligarchia",
    "oligominerali": "oligominerale",
    "oligopoli": "oligopolio",
    "oligopolistica": "oligopolistico",
    "oligopolistiche": "oligopolistico",
    "oligopolistici": "oligopolistico",
    "olii": "olio",
    "olimpi": "olimpio",
    "olimpia": "olimpio",
    "olimpiadi": "olimpiade",
    "olimpica": "olimpico",
    "olimpiche": "olimpico",
    "olimpici": "olimpico",
    "olimpie": "olimpio",
    "olimpionica": "olimpionico",
    "olimpioniche": "olimpionico",
    "olimpionici": "olimpionico",
    "olin": "oliare",
    "olino": "oliare",
    "olio": "oliare",
    "olivastra": "olivastro",
    "olivastre": "olivastro",
    "olivastri": "olivastro",
    "olive": "oliva",
    "oliveti": "oliveto",
    "olivi": "olivo",
    "oliò": "oliare",
    "olmi": "olmo",
    "olocausti": "olocausto",
    "ologrammi": "ologramma",
    "oltraggerai": "oltraggiare",
    "oltraggeran": "oltraggiare",
    "oltraggeranno": "oltraggiare",
    "oltraggerebbe": "oltraggiare",
    "oltraggerebber": "oltraggiare",
    "oltraggerebbero": "oltraggiare",
    "oltraggerei": "oltraggiare",
    "oltraggeremmo": "oltraggiare",
    "oltraggeremo": "oltraggiare",
    "oltraggereste": "oltraggiare",
    "oltraggeresti": "oltraggiare",
    "oltraggerete": "oltraggiare",
    "oltraggerà": "oltraggiare",
    "oltraggerò": "oltraggiare",
    "oltraggi": "oltraggio",
    "oltraggia": "oltraggiare",
    "oltraggiai": "oltraggiare",
    "oltraggiammo": "oltraggiare",
    "oltraggiamo": "oltraggiare",
    "oltraggian": "oltraggiare",
    "oltraggiando": "oltraggiare",
    "oltraggiano": "oltraggiare",
    "oltraggiante": "oltraggiare",
    "oltraggianti": "oltraggiare",
    "oltraggiar": "oltraggiare",
    "oltraggiaron": "oltraggiare",
    "oltraggiarono": "oltraggiare",
    "oltraggiasse": "oltraggiare",
    "oltraggiasser": "oltraggiare",
    "oltraggiassero": "oltraggiare",
    "oltraggiassi": "oltraggiare",
    "oltraggiassimo": "oltraggiare",
    "oltraggiaste": "oltraggiare",
    "oltraggiasti": "oltraggiare",
    "oltraggiata": "oltraggiare",
    "oltraggiate": "oltraggiare",
    "oltraggiati": "oltraggiare",
    "oltraggiato": "oltraggiare",
    "oltraggiava": "oltraggiare",
    "oltraggiavamo": "oltraggiare",
    "oltraggiavan": "oltraggiare",
    "oltraggiavano": "oltraggiare",
    "oltraggiavate": "oltraggiare",
    "oltraggiavi": "oltraggiare",
    "oltraggiavo": "oltraggiare",
    "oltraggin": "oltraggiare",
    "oltraggino": "oltraggiare",
    "oltraggio": "oltraggiare",
    "oltraggiosa": "oltraggioso",
    "oltraggiose": "oltraggioso",
    "oltraggiosi": "oltraggioso",
    "oltraggiò": "oltraggiare",
    "oltranzismi": "oltranzismo",
    "oltranziste": "oltranzista",
    "oltranzisti": "oltranzista",
    "oltrepassa": "oltrepassare",
    "oltrepassai": "oltrepassare",
    "oltrepassammo": "oltrepassare",
    "oltrepassan": "oltrepassare",
    "oltrepassando": "oltrepassare",
    "oltrepassano": "oltrepassare",
    "oltrepassante": "oltrepassare",
    "oltrepassanti": "oltrepassare",
    "oltrepassar": "oltrepassare",
    "oltrepassaron": "oltrepassare",
    "oltrepassarono": "oltrepassare",
    "oltrepassasse": "oltrepassare",
    "oltrepassasser": "oltrepassare",
    "oltrepassassero": "oltrepassare",
    "oltrepassassi": "oltrepassare",
    "oltrepassassimo": "oltrepassare",
    "oltrepassaste": "oltrepassare",
    "oltrepassasti": "oltrepassare",
    "oltrepassata": "oltrepassare",
    "oltrepassate": "oltrepassare",
    "oltrepassati": "oltrepassare",
    "oltrepassato": "oltrepassare",
    "oltrepassava": "oltrepassare",
    "oltrepassavamo": "oltrepassare",
    "oltrepassavan": "oltrepassare",
    "oltrepassavano": "oltrepassare",
    "oltrepassavate": "oltrepassare",
    "oltrepassavi": "oltrepassare",
    "oltrepassavo": "oltrepassare",
    "oltrepasserai": "oltrepassare",
    "oltrepasseran": "oltrepassare",
    "oltrepasseranno": "oltrepassare",
    "oltrepasserebbe": "oltrepassare",
    "oltrepasserebber": "oltrepassare",
    "oltrepasserebbero": "oltrepassare",
    "oltrepasserei": "oltrepassare",
    "oltrepasseremmo": "oltrepassare",
    "oltrepasseremo": "oltrepassare",
    "oltrepassereste": "oltrepassare",
    "oltrepasseresti": "oltrepassare",
    "oltrepasserete": "oltrepassare",
    "oltrepasserà": "oltrepassare",
    "oltrepasserò": "oltrepassare",
    "oltrepassi": "oltrepassare",
    "oltrepassiamo": "oltrepassare",
    "oltrepassiate": "oltrepassare",
    "oltrepassin": "oltrepassare",
    "oltrepassino": "oltrepassare",
    "oltrepasso": "oltrepassare",
    "oltrepassò": "oltrepassare",
    "omaccioni": "omaccione",
    "omaggi": "omaggio",
    "ombelicali": "ombelicale",
    "ombelichi": "ombelico",
    "ombra": "ombrare",
    "ombrai": "ombrare",
    "ombrammo": "ombrare",
    "ombran": "ombrare",
    "ombrando": "ombrare",
    "ombrano": "ombrare",
    "ombrante": "ombrare",
    "ombranti": "ombrare",
    "ombrar": "ombrare",
    "ombraron": "ombrare",
    "ombrarono": "ombrare",
    "ombrasse": "ombrare",
    "ombrasser": "ombrare",
    "ombrassero": "ombrare",
    "ombrassi": "ombrare",
    "ombrassimo": "ombrare",
    "ombraste": "ombrare",
    "ombrasti": "ombrare",
    "ombrata": "ombrare",
    "ombrate": "ombrare",
    "ombrati": "ombrare",
    "ombrato": "ombrare",
    "ombrava": "ombrare",
    "ombravamo": "ombrare",
    "ombravan": "ombrare",
    "ombravano": "ombrare",
    "ombravate": "ombrare",
    "ombravi": "ombrare",
    "ombravo": "ombrare",
    "ombre": "ombra",
    "ombreggerai": "ombreggiare",
    "ombreggeran": "ombreggiare",
    "ombreggeranno": "ombreggiare",
    "ombreggerebbe": "ombreggiare",
    "ombreggerebber": "ombreggiare",
    "ombreggerebbero": "ombreggiare",
    "ombreggerei": "ombreggiare",
    "ombreggeremmo": "ombreggiare",
    "ombreggeremo": "ombreggiare",
    "ombreggereste": "ombreggiare",
    "ombreggeresti": "ombreggiare",
    "ombreggerete": "ombreggiare",
    "ombreggerà": "ombreggiare",
    "ombreggerò": "ombreggiare",
    "ombreggi": "ombreggiare",
    "ombreggia": "ombreggiare",
    "ombreggiai": "ombreggiare",
    "ombreggiammo": "ombreggiare",
    "ombreggiamo": "ombreggiare",
    "ombreggian": "ombreggiare",
    "ombreggiando": "ombreggiare",
    "ombreggiano": "ombreggiare",
    "ombreggiante": "ombreggiare",
    "ombreggianti": "ombreggiare",
    "ombreggiar": "ombreggiare",
    "ombreggiaron": "ombreggiare",
    "ombreggiarono": "ombreggiare",
    "ombreggiasse": "ombreggiare",
    "ombreggiasser": "ombreggiare",
    "ombreggiassero": "ombreggiare",
    "ombreggiassi": "ombreggiare",
    "ombreggiassimo": "ombreggiare",
    "ombreggiaste": "ombreggiare",
    "ombreggiasti": "ombreggiare",
    "ombreggiata": "ombreggiare",
    "ombreggiate": "ombreggiare",
    "ombreggiati": "ombreggiare",
    "ombreggiato": "ombreggiare",
    "ombreggiava": "ombreggiare",
    "ombreggiavamo": "ombreggiare",
    "ombreggiavan": "ombreggiare",
    "ombreggiavano": "ombreggiare",
    "ombreggiavate": "ombreggiare",
    "ombreggiavi": "ombreggiare",
    "ombreggiavo": "ombreggiare",
    "ombreggin": "ombreggiare",
    "ombreggino": "ombreggiare",
    "ombreggio": "ombreggiare",
    "ombreggiò": "ombreggiare",
    "ombrelli": "ombrello",
    "ombrellini": "ombrellino",
    "ombrelloni": "ombrellone",
    "ombrerai": "ombrare",
    "ombreran": "ombrare",
    "ombreranno": "ombrare",
    "ombrerebbe": "ombrare",
    "ombrerebber": "ombrare",
    "ombrerebbero": "ombrare",
    "ombrerei": "ombrare",
    "ombreremmo": "ombrare",
    "ombreremo": "ombrare",
    "ombrereste": "ombrare",
    "ombreresti": "ombrare",
    "ombrerete": "ombrare",
    "ombrerà": "ombrare",
    "ombrerò": "ombrare",
    "ombri": "ombrare",
    "ombriamo": "ombrare",
    "ombriate": "ombrare",
    "ombrin": "ombrare",
    "ombrino": "ombrare",
    "ombro": "ombrare",
    "ombrosa": "ombroso",
    "ombrose": "ombroso",
    "ombrosi": "ombroso",
    "ombrò": "ombrare",
    "omelie": "omelia",
    "omeopatica": "omeopatico",
    "omeopatiche": "omeopatico",
    "omeopatici": "omeopatico",
    "omerica": "omerico",
    "omeriche": "omerico",
    "omerici": "omerico",
    "omessa": "omettere",
    "omesse": "omettere",
    "omessi": "omettere",
    "omesso": "omettere",
    "ometta": "omettere",
    "omettan": "omettere",
    "omettano": "omettere",
    "omette": "omettere",
    "omettemmo": "omettere",
    "omettendo": "omettere",
    "omettente": "omettere",
    "omettenti": "omettere",
    "ometter": "omettere",
    "ometterai": "omettere",
    "ometteran": "omettere",
    "ometteranno": "omettere",
    "ometterebbe": "omettere",
    "ometterebber": "omettere",
    "ometterebbero": "omettere",
    "ometterei": "omettere",
    "ometteremmo": "omettere",
    "ometteremo": "omettere",
    "omettereste": "omettere",
    "ometteresti": "omettere",
    "ometterete": "omettere",
    "ometterà": "omettere",
    "ometterò": "omettere",
    "omettesse": "omettere",
    "omettesser": "omettere",
    "omettessero": "omettere",
    "omettessi": "omettere",
    "omettessimo": "omettere",
    "ometteste": "omettere",
    "omettesti": "omettere",
    "omettete": "omettere",
    "ometteva": "omettere",
    "omettevamo": "omettere",
    "omettevan": "omettere",
    "omettevano": "omettere",
    "omettevate": "omettere",
    "omettevi": "omettere",
    "omettevo": "omettere",
    "ometti": "ometto",
    "omettiamo": "omettere",
    "omettiate": "omettere",
    "ometto": "omettere",
    "ometton": "omettere",
    "omettono": "omettere",
    "omicidi": "omicidio",
    "omini": "omino",
    "omise": "omettere",
    "omiser": "omettere",
    "omisero": "omettere",
    "omisi": "omettere",
    "omissioni": "omissione",
    "omoerotica": "omoerotico",
    "omoerotiche": "omoerotico",
    "omoerotici": "omoerotico",
    "omofona": "omofono",
    "omofone": "omofono",
    "omofoni": "omofono",
    "omogenea": "omogeneo",
    "omogenee": "omogeneo",
    "omogenei": "omogeneo",
    "omogeneizza": "omogeneizzare",
    "omogeneizzai": "omogeneizzare",
    "omogeneizzammo": "omogeneizzare",
    "omogeneizzan": "omogeneizzare",
    "omogeneizzando": "omogeneizzare",
    "omogeneizzano": "omogeneizzare",
    "omogeneizzante": "omogeneizzare",
    "omogeneizzanti": "omogeneizzare",
    "omogeneizzar": "omogeneizzare",
    "omogeneizzaron": "omogeneizzare",
    "omogeneizzarono": "omogeneizzare",
    "omogeneizzasse": "omogeneizzare",
    "omogeneizzasser": "omogeneizzare",
    "omogeneizzassero": "omogeneizzare",
    "omogeneizzassi": "omogeneizzare",
    "omogeneizzassimo": "omogeneizzare",
    "omogeneizzaste": "omogeneizzare",
    "omogeneizzasti": "omogeneizzare",
    "omogeneizzata": "omogeneizzato",
    "omogeneizzate": "omogeneizzato",
    "omogeneizzati": "omogeneizzato",
    "omogeneizzato": "omogeneizzare",
    "omogeneizzava": "omogeneizzare",
    "omogeneizzavamo": "omogeneizzare",
    "omogeneizzavan": "omogeneizzare",
    "omogeneizzavano": "omogeneizzare",
    "omogeneizzavate": "omogeneizzare",
    "omogeneizzavi": "omogeneizzare",
    "omogeneizzavo": "omogeneizzare",
    "omogeneizzazioni": "omogeneizzazione",
    "omogeneizzerai": "omogeneizzare",
    "omogeneizzeran": "omogeneizzare",
    "omogeneizzeranno": "omogeneizzare",
    "omogeneizzerebbe": "omogeneizzare",
    "omogeneizzerebber": "omogeneizzare",
    "omogeneizzerebbero": "omogeneizzare",
    "omogeneizzerei": "omogeneizzare",
    "omogeneizzeremmo": "omogeneizzare",
    "omogeneizzeremo": "omogeneizzare",
    "omogeneizzereste": "omogeneizzare",
    "omogeneizzeresti": "omogeneizzare",
    "omogeneizzerete": "omogeneizzare",
    "omogeneizzerà": "omogeneizzare",
    "omogeneizzerò": "omogeneizzare",
    "omogeneizzi": "omogeneizzare",
    "omogeneizziamo": "omogeneizzare",
    "omogeneizziate": "omogeneizzare",
    "omogeneizzin": "omogeneizzare",
    "omogeneizzino": "omogeneizzare",
    "omogeneizzo": "omogeneizzare",
    "omogeneizzò": "omogeneizzare",
    "omologa": "omologo",
    "omologabili": "omologabile",
    "omologai": "omologare",
    "omologammo": "omologare",
    "omologan": "omologare",
    "omologando": "omologare",
    "omologano": "omologare",
    "omologante": "omologare",
    "omologanti": "omologare",
    "omologar": "omologare",
    "omologaron": "omologare",
    "omologarono": "omologare",
    "omologasse": "omologare",
    "omologasser": "omologare",
    "omologassero": "omologare",
    "omologassi": "omologare",
    "omologassimo": "omologare",
    "omologaste": "omologare",
    "omologasti": "omologare",
    "omologata": "omologare",
    "omologate": "omologare",
    "omologati": "omologare",
    "omologato": "omologare",
    "omologava": "omologare",
    "omologavamo": "omologare",
    "omologavan": "omologare",
    "omologavano": "omologare",
    "omologavate": "omologare",
    "omologavi": "omologare",
    "omologavo": "omologare",
    "omologazioni": "omologazione",
    "omologhe": "omologo",
    "omologherai": "omologare",
    "omologheran": "omologare",
    "omologheranno": "omologare",
    "omologherebbe": "omologare",
    "omologherebber": "omologare",
    "omologherebbero": "omologare",
    "omologherei": "omologare",
    "omologheremmo": "omologare",
    "omologheremo": "omologare",
    "omologhereste": "omologare",
    "omologheresti": "omologare",
    "omologherete": "omologare",
    "omologherà": "omologare",
    "omologherò": "omologare",
    "omologhi": "omologo",
    "omologhiamo": "omologare",
    "omologhiate": "omologare",
    "omologhin": "omologare",
    "omologhino": "omologare",
    "omologie": "omologia",
    "omologo": "omologare",
    "omologò": "omologare",
    "omoni": "omone",
    "omonima": "omonimo",
    "omonime": "omonimo",
    "omonimi": "omonimo",
    "omonimie": "omonimia",
    "omosessuali": "omosessuale",
    "omuncoli": "omuncolo",
    "once": "oncia",
    "oncologi": "oncologo",
    "oncologica": "oncologico",
    "oncologiche": "oncologico",
    "oncologici": "oncologico",
    "oncologie": "oncologia",
    "ondate": "ondata",
    "onde": "onda",
    "ondeggerai": "ondeggiare",
    "ondeggeran": "ondeggiare",
    "ondeggeranno": "ondeggiare",
    "ondeggerebbe": "ondeggiare",
    "ondeggerebber": "ondeggiare",
    "ondeggerebbero": "ondeggiare",
    "ondeggerei": "ondeggiare",
    "ondeggeremmo": "ondeggiare",
    "ondeggeremo": "ondeggiare",
    "ondeggereste": "ondeggiare",
    "ondeggeresti": "ondeggiare",
    "ondeggerete": "ondeggiare",
    "ondeggerà": "ondeggiare",
    "ondeggerò": "ondeggiare",
    "ondeggi": "ondeggiare",
    "ondeggia": "ondeggiare",
    "ondeggiai": "ondeggiare",
    "ondeggiamenti": "ondeggiamento",
    "ondeggiammo": "ondeggiare",
    "ondeggiamo": "ondeggiare",
    "ondeggian": "ondeggiare",
    "ondeggiando": "ondeggiare",
    "ondeggiano": "ondeggiare",
    "ondeggiante": "ondeggiare",
    "ondeggianti": "ondeggiare",
    "ondeggiar": "ondeggiare",
    "ondeggiaron": "ondeggiare",
    "ondeggiarono": "ondeggiare",
    "ondeggiasse": "ondeggiare",
    "ondeggiasser": "ondeggiare",
    "ondeggiassero": "ondeggiare",
    "ondeggiassi": "ondeggiare",
    "ondeggiassimo": "ondeggiare",
    "ondeggiaste": "ondeggiare",
    "ondeggiasti": "ondeggiare",
    "ondeggiata": "ondeggiare",
    "ondeggiate": "ondeggiare",
    "ondeggiati": "ondeggiare",
    "ondeggiato": "ondeggiare",
    "ondeggiava": "ondeggiare",
    "ondeggiavamo": "ondeggiare",
    "ondeggiavan": "ondeggiare",
    "ondeggiavano": "ondeggiare",
    "ondeggiavate": "ondeggiare",
    "ondeggiavi": "ondeggiare",
    "ondeggiavo": "ondeggiare",
    "ondeggin": "ondeggiare",
    "ondeggino": "ondeggiare",
    "ondeggio": "ondeggiare",
    "ondeggiò": "ondeggiare",
    "ondine": "ondina",
    "ondosa": "ondoso",
    "ondose": "ondoso",
    "ondosi": "ondoso",
    "ondula": "ondulare",
    "ondulai": "ondulare",
    "ondulammo": "ondulare",
    "ondulan": "ondulare",
    "ondulando": "ondulare",
    "ondulano": "ondulare",
    "ondulante": "ondulare",
    "ondulanti": "ondulare",
    "ondular": "ondulare",
    "ondularon": "ondulare",
    "ondularono": "ondulare",
    "ondulasse": "ondulare",
    "ondulasser": "ondulare",
    "ondulassero": "ondulare",
    "ondulassi": "ondulare",
    "ondulassimo": "ondulare",
    "ondulaste": "ondulare",
    "ondulasti": "ondulare",
    "ondulata": "ondulato",
    "ondulate": "ondulato",
    "ondulati": "ondulato",
    "ondulato": "ondulare",
    "ondulatori": "ondulatorio",
    "ondulatoria": "ondulatorio",
    "ondulatorie": "ondulatorio",
    "ondulava": "ondulare",
    "ondulavamo": "ondulare",
    "ondulavan": "ondulare",
    "ondulavano": "ondulare",
    "ondulavate": "ondulare",
    "ondulavi": "ondulare",
    "ondulavo": "ondulare",
    "ondulazioni": "ondulazione",
    "ondulerai": "ondulare",
    "onduleran": "ondulare",
    "onduleranno": "ondulare",
    "ondulerebbe": "ondulare",
    "ondulerebber": "ondulare",
    "ondulerebbero": "ondulare",
    "ondulerei": "ondulare",
    "onduleremmo": "ondulare",
    "onduleremo": "ondulare",
    "ondulereste": "ondulare",
    "onduleresti": "ondulare",
    "ondulerete": "ondulare",
    "ondulerà": "ondulare",
    "ondulerò": "ondulare",
    "onduli": "ondulare",
    "onduliamo": "ondulare",
    "onduliate": "ondulare",
    "ondulin": "ondulare",
    "ondulino": "ondulare",
    "ondulo": "ondulare",
    "ondulò": "ondulare",
    "onera": "onerare",
    "onerai": "onerare",
    "onerammo": "onerare",
    "oneran": "onerare",
    "onerando": "onerare",
    "onerano": "onerare",
    "onerante": "onerare",
    "oneranti": "onerare",
    "onerar": "onerare",
    "oneraron": "onerare",
    "onerarono": "onerare",
    "onerasse": "onerare",
    "onerasser": "onerare",
    "onerassero": "onerare",
    "onerassi": "onerare",
    "onerassimo": "onerare",
    "oneraste": "onerare",
    "onerasti": "onerare",
    "onerata": "onerare",
    "onerate": "onerare",
    "onerati": "onerare",
    "onerato": "onerare",
    "onerava": "onerare",
    "oneravamo": "onerare",
    "oneravan": "onerare",
    "oneravano": "onerare",
    "oneravate": "onerare",
    "oneravi": "onerare",
    "oneravo": "onerare",
    "onererai": "onerare",
    "onereran": "onerare",
    "onereranno": "onerare",
    "onererebbe": "onerare",
    "onererebber": "onerare",
    "onererebbero": "onerare",
    "onererei": "onerare",
    "onereremmo": "onerare",
    "onereremo": "onerare",
    "onerereste": "onerare",
    "onereresti": "onerare",
    "onererete": "onerare",
    "onererà": "onerare",
    "onererò": "onerare",
    "oneri": "onere",
    "oneriamo": "onerare",
    "oneriate": "onerare",
    "onerin": "onerare",
    "onerino": "onerare",
    "onero": "onerare",
    "onerosa": "oneroso",
    "onerose": "oneroso",
    "onerosi": "oneroso",
    "onerò": "onerare",
    "onesta": "onesto",
    "oneste": "onesto",
    "onesti": "onesto",
    "onirica": "onirico",
    "oniriche": "onirico",
    "onirici": "onirico",
    "onnicomprensiva": "onnicomprensivo",
    "onnicomprensive": "onnicomprensivo",
    "onnicomprensivi": "onnicomprensivo",
    "onnipotenti": "onnipotente",
    "onnipotenze": "onnipotenza",
    "onnipresenti": "onnipresente",
    "onniscienti": "onnisciente",
    "onniveggenti": "onniveggente",
    "onnivora": "onnivoro",
    "onnivore": "onnivoro",
    "onnivori": "onnivoro",
    "onomastica": "onomastico",
    "onomastiche": "onomastico",
    "onomastici": "onomastico",
    "onomatopeica": "onomatopeico",
    "onomatopeiche": "onomatopeico",
    "onomatopeici": "onomatopeico",
    "onora": "onorare",
    "onorabili": "onorabile",
    "onorai": "onorare",
    "onorammo": "onorare",
    "onoran": "onorare",
    "onorando": "onorare",
    "onorano": "onorare",
    "onorante": "onorare",
    "onoranti": "onorare",
    "onorar": "onorare",
    "onorari": "onorario",
    "onoraria": "onorario",
    "onorarie": "onorario",
    "onoraron": "onorare",
    "onorarono": "onorare",
    "onorasse": "onorare",
    "onorasser": "onorare",
    "onorassero": "onorare",
    "onorassi": "onorare",
    "onorassimo": "onorare",
    "onoraste": "onorare",
    "onorasti": "onorare",
    "onorata": "onorato",
    "onorate": "onorato",
    "onorati": "onorato",
    "onorato": "onorare",
    "onorava": "onorare",
    "onoravamo": "onorare",
    "onoravan": "onorare",
    "onoravano": "onorare",
    "onoravate": "onorare",
    "onoravi": "onorare",
    "onoravo": "onorare",
    "onoreficenze": "onoreficenza",
    "onorerai": "onorare",
    "onoreran": "onorare",
    "onoreranno": "onorare",
    "onorerebbe": "onorare",
    "onorerebber": "onorare",
    "onorerebbero": "onorare",
    "onorerei": "onorare",
    "onoreremmo": "onorare",
    "onoreremo": "onorare",
    "onorereste": "onorare",
    "onoreresti": "onorare",
    "onorerete": "onorare",
    "onorerà": "onorare",
    "onorerò": "onorare",
    "onorevoli": "onorevole",
    "onori": "onore",
    "onoriamo": "onorare",
    "onoriate": "onorare",
    "onorifica": "onorifico",
    "onorificenze": "onorificenza",
    "onorifiche": "onorifico",
    "onorifici": "onorifico",
    "onorin": "onorare",
    "onorino": "onorare",
    "onoro": "onorare",
    "onorò": "onorare",
    "onte": "onta",
    "ontologica": "ontologico",
    "ontologiche": "ontologico",
    "ontologici": "ontologico",
    "onusta": "onusto",
    "onuste": "onusto",
    "onusti": "onusto",
    "opaca": "opaco",
    "opache": "opaco",
    "opachi": "opaco",
    "opaci": "opaco",
    "opacizza": "opacizzare",
    "opacizzai": "opacizzare",
    "opacizzammo": "opacizzare",
    "opacizzan": "opacizzare",
    "opacizzando": "opacizzare",
    "opacizzano": "opacizzare",
    "opacizzante": "opacizzare",
    "opacizzanti": "opacizzare",
    "opacizzar": "opacizzare",
    "opacizzaron": "opacizzare",
    "opacizzarono": "opacizzare",
    "opacizzasse": "opacizzare",
    "opacizzasser": "opacizzare",
    "opacizzassero": "opacizzare",
    "opacizzassi": "opacizzare",
    "opacizzassimo": "opacizzare",
    "opacizzaste": "opacizzare",
    "opacizzasti": "opacizzare",
    "opacizzata": "opacizzare",
    "opacizzate": "opacizzare",
    "opacizzati": "opacizzare",
    "opacizzato": "opacizzare",
    "opacizzava": "opacizzare",
    "opacizzavamo": "opacizzare",
    "opacizzavan": "opacizzare",
    "opacizzavano": "opacizzare",
    "opacizzavate": "opacizzare",
    "opacizzavi": "opacizzare",
    "opacizzavo": "opacizzare",
    "opacizzerai": "opacizzare",
    "opacizzeran": "opacizzare",
    "opacizzeranno": "opacizzare",
    "opacizzerebbe": "opacizzare",
    "opacizzerebber": "opacizzare",
    "opacizzerebbero": "opacizzare",
    "opacizzerei": "opacizzare",
    "opacizzeremmo": "opacizzare",
    "opacizzeremo": "opacizzare",
    "opacizzereste": "opacizzare",
    "opacizzeresti": "opacizzare",
    "opacizzerete": "opacizzare",
    "opacizzerà": "opacizzare",
    "opacizzerò": "opacizzare",
    "opacizzi": "opacizzare",
    "opacizziamo": "opacizzare",
    "opacizziate": "opacizzare",
    "opacizzin": "opacizzare",
    "opacizzino": "opacizzare",
    "opacizzo": "opacizzare",
    "opacizzò": "opacizzare",
    "opera": "operare",
    "operabili": "operabile",
    "operai": "operare",
    "operaia": "operaio",
    "operaie": "operaio",
    "operaisti": "operaista",
    "operammo": "operare",
    "operan": "operare",
    "operando": "operare",
    "operano": "operare",
    "operante": "operare",
    "operanti": "operare",
    "operar": "operare",
    "operaron": "operare",
    "operarono": "operare",
    "operasse": "operare",
    "operasser": "operare",
    "operassero": "operare",
    "operassi": "operare",
    "operassimo": "operare",
    "operaste": "operare",
    "operasti": "operare",
    "operata": "operato",
    "operate": "operato",
    "operati": "operato",
    "operativa": "operativo",
    "operative": "operativo",
    "operativi": "operativo",
    "operato": "operare",
    "operatori": "operatorio",
    "operatoria": "operatorio",
    "operatorie": "operatorio",
    "operatrice": "operatore",
    "operatrici": "operatrice",
    "operava": "operare",
    "operavamo": "operare",
    "operavan": "operare",
    "operavano": "operare",
    "operavate": "operare",
    "operavi": "operare",
    "operavo": "operare",
    "operazioni": "operazione",
    "opere": "opera",
    "opererai": "operare",
    "opereran": "operare",
    "opereranno": "operare",
    "opererebbe": "operare",
    "opererebber": "operare",
    "opererebbero": "operare",
    "opererei": "operare",
    "opereremmo": "operare",
    "opereremo": "operare",
    "operereste": "operare",
    "opereresti": "operare",
    "opererete": "operare",
    "opererà": "operare",
    "opererò": "operare",
    "operette": "operetta",
    "operettistica": "operettistico",
    "operettistiche": "operettistico",
    "operettistici": "operettistico",
    "operi": "operare",
    "operiamo": "operare",
    "operiate": "operare",
    "operin": "operare",
    "operine": "operina",
    "operino": "operare",
    "operisti": "operista",
    "operistica": "operistico",
    "operistiche": "operistico",
    "operistici": "operistico",
    "opero": "operare",
    "operosa": "operoso",
    "operose": "operoso",
    "operosi": "operoso",
    "operò": "operare",
    "opifici": "opificio",
    "opina": "opinare",
    "opinabili": "opinabile",
    "opinai": "opinare",
    "opinammo": "opinare",
    "opinan": "opinare",
    "opinando": "opinare",
    "opinano": "opinare",
    "opinante": "opinare",
    "opinanti": "opinare",
    "opinar": "opinare",
    "opinaron": "opinare",
    "opinarono": "opinare",
    "opinasse": "opinare",
    "opinasser": "opinare",
    "opinassero": "opinare",
    "opinassi": "opinare",
    "opinassimo": "opinare",
    "opinaste": "opinare",
    "opinasti": "opinare",
    "opinata": "opinare",
    "opinate": "opinare",
    "opinati": "opinare",
    "opinato": "opinare",
    "opinava": "opinare",
    "opinavamo": "opinare",
    "opinavan": "opinare",
    "opinavano": "opinare",
    "opinavate": "opinare",
    "opinavi": "opinare",
    "opinavo": "opinare",
    "opinerai": "opinare",
    "opineran": "opinare",
    "opineranno": "opinare",
    "opinerebbe": "opinare",
    "opinerebber": "opinare",
    "opinerebbero": "opinare",
    "opinerei": "opinare",
    "opineremmo": "opinare",
    "opineremo": "opinare",
    "opinereste": "opinare",
    "opineresti": "opinare",
    "opinerete": "opinare",
    "opinerà": "opinare",
    "opinerò": "opinare",
    "opini": "opinare",
    "opiniamo": "opinare",
    "opiniate": "opinare",
    "opinin": "opinare",
    "opinino": "opinare",
    "opinioni": "opinione",
    "opinionisti": "opinionista",
    "opino": "opinare",
    "opinò": "opinare",
    "oppi": "oppiare",
    "oppia": "oppiare",
    "oppiai": "oppiare",
    "oppiammo": "oppiare",
    "oppiamo": "oppiare",
    "oppian": "oppiare",
    "oppiando": "oppiare",
    "oppiano": "oppiare",
    "oppiante": "oppiare",
    "oppianti": "oppiare",
    "oppiar": "oppiare",
    "oppiaron": "oppiare",
    "oppiarono": "oppiare",
    "oppiasse": "oppiare",
    "oppiasser": "oppiare",
    "oppiassero": "oppiare",
    "oppiassi": "oppiare",
    "oppiassimo": "oppiare",
    "oppiaste": "oppiare",
    "oppiasti": "oppiare",
    "oppiata": "oppiare",
    "oppiate": "oppiare",
    "oppiati": "oppiare",
    "oppiato": "oppiare",
    "oppiava": "oppiare",
    "oppiavamo": "oppiare",
    "oppiavan": "oppiare",
    "oppiavano": "oppiare",
    "oppiavate": "oppiare",
    "oppiavi": "oppiare",
    "oppiavo": "oppiare",
    "oppierai": "oppiare",
    "oppieran": "oppiare",
    "oppieranno": "oppiare",
    "oppierebbe": "oppiare",
    "oppierebber": "oppiare",
    "oppierebbero": "oppiare",
    "oppierei": "oppiare",
    "oppieremmo": "oppiare",
    "oppieremo": "oppiare",
    "oppiereste": "oppiare",
    "oppieresti": "oppiare",
    "oppierete": "oppiare",
    "oppierà": "oppiare",
    "oppierò": "oppiare",
    "oppin": "oppiare",
    "oppino": "oppiare",
    "oppio": "oppiare",
    "oppiò": "oppiare",
    "oppone": "opporre",
    "opponemmo": "opporre",
    "opponendo": "opporre",
    "opponente": "opporre",
    "opponenti": "opporre",
    "opponesse": "opporre",
    "opponesser": "opporre",
    "opponessero": "opporre",
    "opponessi": "opporre",
    "opponessimo": "opporre",
    "opponeste": "opporre",
    "opponesti": "opporre",
    "opponete": "opporre",
    "opponeva": "opporre",
    "opponevamo": "opporre",
    "opponevan": "opporre",
    "opponevano": "opporre",
    "opponevate": "opporre",
    "opponevi": "opporre",
    "opponevo": "opporre",
    "opponga": "opporre",
    "oppongan": "opporre",
    "oppongano": "opporre",
    "oppongo": "opporre",
    "oppongon": "opporre",
    "oppongono": "opporre",
    "opponi": "opporre",
    "opponiamo": "opporre",
    "opponiate": "opporre",
    "opponibili": "opponibile",
    "opporr": "opporre",
    "opporrai": "opporre",
    "opporran": "opporre",
    "opporranno": "opporre",
    "opporrebbe": "opporre",
    "opporrebber": "opporre",
    "opporrebbero": "opporre",
    "opporrei": "opporre",
    "opporremmo": "opporre",
    "opporremo": "opporre",
    "opporreste": "opporre",
    "opporresti": "opporre",
    "opporrete": "opporre",
    "opporrà": "opporre",
    "opporrò": "opporre",
    "opportuna": "opportuno",
    "opportune": "opportuno",
    "opportuni": "opportuno",
    "opportunismi": "opportunismo",
    "opportunisti": "opportunista",
    "opportunistica": "opportunistico",
    "opportunistiche": "opportunistico",
    "opportunistici": "opportunistico",
    "oppose": "opporre",
    "opposer": "opporre",
    "opposero": "opporre",
    "opposi": "opporre",
    "oppositori": "oppositore",
    "opposizioni": "opposizione",
    "opposta": "opposto",
    "opposte": "opposto",
    "opposti": "opposto",
    "opposto": "opporre",
    "oppressa": "oppresso",
    "oppresse": "oppresso",
    "oppressi": "oppresso",
    "oppressioni": "oppressione",
    "oppressiva": "oppressivo",
    "oppressive": "oppressivo",
    "oppressivi": "oppressivo",
    "oppressori": "oppressore",
    "opprima": "opprimere",
    "oppriman": "opprimere",
    "opprimano": "opprimere",
    "opprime": "opprimere",
    "opprimei": "opprimere",
    "opprimemmo": "opprimere",
    "opprimendo": "opprimere",
    "opprimente": "opprimere",
    "opprimenti": "opprimere",
    "opprimer": "opprimere",
    "opprimerai": "opprimere",
    "opprimeran": "opprimere",
    "opprimeranno": "opprimere",
    "opprimerebbe": "opprimere",
    "opprimerebber": "opprimere",
    "opprimerebbero": "opprimere",
    "opprimerei": "opprimere",
    "opprimeremmo": "opprimere",
    "opprimeremo": "opprimere",
    "opprimereste": "opprimere",
    "opprimeresti": "opprimere",
    "opprimerete": "opprimere",
    "opprimeron": "opprimere",
    "opprimerono": "opprimere",
    "opprimerà": "opprimere",
    "opprimerò": "opprimere",
    "opprimesse": "opprimere",
    "opprimesser": "opprimere",
    "opprimessero": "opprimere",
    "opprimessi": "opprimere",
    "opprimessimo": "opprimere",
    "opprimeste": "opprimere",
    "opprimesti": "opprimere",
    "opprimete": "opprimere",
    "opprimeva": "opprimere",
    "opprimevamo": "opprimere",
    "opprimevan": "opprimere",
    "opprimevano": "opprimere",
    "opprimevate": "opprimere",
    "opprimevi": "opprimere",
    "opprimevo": "opprimere",
    "opprimi": "opprimere",
    "opprimiamo": "opprimere",
    "opprimiate": "opprimere",
    "opprimo": "opprimere",
    "opprimon": "opprimere",
    "opprimono": "opprimere",
    "opprimuta": "opprimere",
    "opprimute": "opprimere",
    "opprimuti": "opprimere",
    "opprimuto": "opprimere",
    "opprimè": "opprimere",
    "oppugna": "oppugnare",
    "oppugnai": "oppugnare",
    "oppugnammo": "oppugnare",
    "oppugnan": "oppugnare",
    "oppugnando": "oppugnare",
    "oppugnano": "oppugnare",
    "oppugnante": "oppugnare",
    "oppugnanti": "oppugnare",
    "oppugnar": "oppugnare",
    "oppugnaron": "oppugnare",
    "oppugnarono": "oppugnare",
    "oppugnasse": "oppugnare",
    "oppugnasser": "oppugnare",
    "oppugnassero": "oppugnare",
    "oppugnassi": "oppugnare",
    "oppugnassimo": "oppugnare",
    "oppugnaste": "oppugnare",
    "oppugnasti": "oppugnare",
    "oppugnata": "oppugnare",
    "oppugnate": "oppugnare",
    "oppugnati": "oppugnare",
    "oppugnato": "oppugnare",
    "oppugnava": "oppugnare",
    "oppugnavamo": "oppugnare",
    "oppugnavan": "oppugnare",
    "oppugnavano": "oppugnare",
    "oppugnavate": "oppugnare",
    "oppugnavi": "oppugnare",
    "oppugnavo": "oppugnare",
    "oppugnerai": "oppugnare",
    "oppugneran": "oppugnare",
    "oppugneranno": "oppugnare",
    "oppugnerebbe": "oppugnare",
    "oppugnerebber": "oppugnare",
    "oppugnerebbero": "oppugnare",
    "oppugnerei": "oppugnare",
    "oppugneremmo": "oppugnare",
    "oppugneremo": "oppugnare",
    "oppugnereste": "oppugnare",
    "oppugneresti": "oppugnare",
    "oppugnerete": "oppugnare",
    "oppugnerà": "oppugnare",
    "oppugnerò": "oppugnare",
    "oppugni": "oppugnare",
    "oppugniamo": "oppugnare",
    "oppugniate": "oppugnare",
    "oppugnin": "oppugnare",
    "oppugnino": "oppugnare",
    "oppugno": "oppugnare",
    "oppugnò": "oppugnare",
    "opra": "oprare",
    "oprai": "oprare",
    "oprammo": "oprare",
    "opran": "oprare",
    "oprando": "oprare",
    "oprano": "oprare",
    "oprante": "oprare",
    "opranti": "oprare",
    "oprar": "oprare",
    "opraron": "oprare",
    "oprarono": "oprare",
    "oprasse": "oprare",
    "oprasser": "oprare",
    "oprassero": "oprare",
    "oprassi": "oprare",
    "oprassimo": "oprare",
    "opraste": "oprare",
    "oprasti": "oprare",
    "oprata": "oprare",
    "oprate": "oprare",
    "oprati": "oprare",
    "oprato": "oprare",
    "oprava": "oprare",
    "opravamo": "oprare",
    "opravan": "oprare",
    "opravano": "oprare",
    "opravate": "oprare",
    "opravi": "oprare",
    "opravo": "oprare",
    "oprerai": "oprare",
    "opreran": "oprare",
    "opreranno": "oprare",
    "oprerebbe": "oprare",
    "oprerebber": "oprare",
    "oprerebbero": "oprare",
    "oprerei": "oprare",
    "opreremmo": "oprare",
    "opreremo": "oprare",
    "oprereste": "oprare",
    "opreresti": "oprare",
    "oprerete": "oprare",
    "oprerà": "oprare",
    "oprerò": "oprare",
    "opri": "oprare",
    "opriamo": "oprare",
    "opriate": "oprare",
    "oprin": "oprare",
    "oprino": "oprare",
    "opro": "oprare",
    "oprò": "oprare",
    "opta": "optare",
    "optai": "optare",
    "optammo": "optare",
    "optan": "optare",
    "optando": "optare",
    "optano": "optare",
    "optante": "optare",
    "optanti": "optare",
    "optar": "optare",
    "optaron": "optare",
    "optarono": "optare",
    "optasse": "optare",
    "optasser": "optare",
    "optassero": "optare",
    "optassi": "optare",
    "optassimo": "optare",
    "optaste": "optare",
    "optasti": "optare",
    "optata": "optare",
    "optate": "optare",
    "optati": "optare",
    "optato": "optare",
    "optava": "optare",
    "optavamo": "optare",
    "optavan": "optare",
    "optavano": "optare",
    "optavate": "optare",
    "optavi": "optare",
    "optavo": "optare",
    "opterai": "optare",
    "opteran": "optare",
    "opteranno": "optare",
    "opterebbe": "optare",
    "opterebber": "optare",
    "opterebbero": "optare",
    "opterei": "optare",
    "opteremmo": "optare",
    "opteremo": "optare",
    "optereste": "optare",
    "opteresti": "optare",
    "opterete": "optare",
    "opterà": "optare",
    "opterò": "optare",
    "opti": "optare",
    "optiamo": "optare",
    "optiate": "optare",
    "optin": "optare",
    "optino": "optare",
    "opto": "optare",
    "optò": "optare",
    "opulenta": "opulento",
    "opulente": "opulento",
    "opulenti": "opulento",
    "opulenze": "opulenza",
    "opuscoli": "opuscolo",
    "opzionali": "opzionale",
    "opzioni": "opzione",
    "ora": "orare",
    "oracoli": "oracolo",
    "orafi": "orafo",
    "orai": "orare",
    "orali": "orale",
    "orammo": "orare",
    "oran": "orare",
    "orando": "orare",
    "oranghi": "orango",
    "orangisti": "orangista",
    "orano": "orare",
    "orante": "orare",
    "oranti": "orare",
    "orar": "orare",
    "orari": "orario",
    "oraria": "orario",
    "orarie": "orario",
    "oraron": "orare",
    "orarono": "orare",
    "orasse": "orare",
    "orasser": "orare",
    "orassero": "orare",
    "orassi": "orare",
    "orassimo": "orare",
    "oraste": "orare",
    "orasti": "orare",
    "orata": "orare",
    "orate": "orare",
    "orati": "orare",
    "orato": "orare",
    "oratora": "oratoro",
    "oratore": "oratoro",
    "oratori": "oratoro",
    "oratoria": "oratorio",
    "oratoriali": "oratoriale",
    "oratorie": "oratorio",
    "orava": "orare",
    "oravamo": "orare",
    "oravan": "orare",
    "oravano": "orare",
    "oravate": "orare",
    "oravi": "orare",
    "oravo": "orare",
    "orazioni": "orazione",
    "orba": "orbo",
    "orbai": "orbare",
    "orbammo": "orbare",
    "orban": "orbare",
    "orbando": "orbare",
    "orbano": "orbare",
    "orbante": "orbare",
    "orbanti": "orbare",
    "orbar": "orbare",
    "orbaron": "orbare",
    "orbarono": "orbare",
    "orbasse": "orbare",
    "orbasser": "orbare",
    "orbassero": "orbare",
    "orbassi": "orbare",
    "orbassimo": "orbare",
    "orbaste": "orbare",
    "orbasti": "orbare",
    "orbata": "orbare",
    "orbate": "orbare",
    "orbati": "orbare",
    "orbato": "orbare",
    "orbava": "orbare",
    "orbavamo": "orbare",
    "orbavan": "orbare",
    "orbavano": "orbare",
    "orbavate": "orbare",
    "orbavi": "orbare",
    "orbavo": "orbare",
    "orbe": "orbo",
    "orberai": "orbare",
    "orberan": "orbare",
    "orberanno": "orbare",
    "orberebbe": "orbare",
    "orberebber": "orbare",
    "orberebbero": "orbare",
    "orberei": "orbare",
    "orberemmo": "orbare",
    "orberemo": "orbare",
    "orbereste": "orbare",
    "orberesti": "orbare",
    "orberete": "orbare",
    "orberà": "orbare",
    "orberò": "orbare",
    "orbi": "orbo",
    "orbiamo": "orbare",
    "orbiate": "orbare",
    "orbin": "orbare",
    "orbino": "orbare",
    "orbita": "orbitare",
    "orbitai": "orbitare",
    "orbitali": "orbitale",
    "orbitammo": "orbitare",
    "orbitan": "orbitare",
    "orbitando": "orbitare",
    "orbitano": "orbitare",
    "orbitante": "orbitare",
    "orbitanti": "orbitare",
    "orbitar": "orbitare",
    "orbitaron": "orbitare",
    "orbitarono": "orbitare",
    "orbitasse": "orbitare",
    "orbitasser": "orbitare",
    "orbitassero": "orbitare",
    "orbitassi": "orbitare",
    "orbitassimo": "orbitare",
    "orbitaste": "orbitare",
    "orbitasti": "orbitare",
    "orbitata": "orbitare",
    "orbitate": "orbitare",
    "orbitati": "orbitare",
    "orbitato": "orbitare",
    "orbitava": "orbitare",
    "orbitavamo": "orbitare",
    "orbitavan": "orbitare",
    "orbitavano": "orbitare",
    "orbitavate": "orbitare",
    "orbitavi": "orbitare",
    "orbitavo": "orbitare",
    "orbite": "orbita",
    "orbiterai": "orbitare",
    "orbiteran": "orbitare",
    "orbiteranno": "orbitare",
    "orbiterebbe": "orbitare",
    "orbiterebber": "orbitare",
    "orbiterebbero": "orbitare",
    "orbiterei": "orbitare",
    "orbiteremmo": "orbitare",
    "orbiteremo": "orbitare",
    "orbitereste": "orbitare",
    "orbiteresti": "orbitare",
    "orbiterete": "orbitare",
    "orbiterà": "orbitare",
    "orbiterò": "orbitare",
    "orbiti": "orbitare",
    "orbitiamo": "orbitare",
    "orbitiate": "orbitare",
    "orbitin": "orbitare",
    "orbitino": "orbitare",
    "orbito": "orbitare",
    "orbitò": "orbitare",
    "orbo": "orbare",
    "orbò": "orbare",
    "orchestra": "orchestrare",
    "orchestrai": "orchestrare",
    "orchestrali": "orchestrale",
    "orchestrammo": "orchestrare",
    "orchestran": "orchestrare",
    "orchestrando": "orchestrare",
    "orchestrano": "orchestrare",
    "orchestrante": "orchestrare",
    "orchestranti": "orchestrare",
    "orchestrar": "orchestrare",
    "orchestraron": "orchestrare",
    "orchestrarono": "orchestrare",
    "orchestrasse": "orchestrare",
    "orchestrasser": "orchestrare",
    "orchestrassero": "orchestrare",
    "orchestrassi": "orchestrare",
    "orchestrassimo": "orchestrare",
    "orchestraste": "orchestrare",
    "orchestrasti": "orchestrare",
    "orchestrata": "orchestrare",
    "orchestrate": "orchestrare",
    "orchestrati": "orchestrare",
    "orchestrato": "orchestrare",
    "orchestrava": "orchestrare",
    "orchestravamo": "orchestrare",
    "orchestravan": "orchestrare",
    "orchestravano": "orchestrare",
    "orchestravate": "orchestrare",
    "orchestravi": "orchestrare",
    "orchestravo": "orchestrare",
    "orchestrazioni": "orchestrazione",
    "orchestre": "orchestra",
    "orchestrerai": "orchestrare",
    "orchestreran": "orchestrare",
    "orchestreranno": "orchestrare",
    "orchestrerebbe": "orchestrare",
    "orchestrerebber": "orchestrare",
    "orchestrerebbero": "orchestrare",
    "orchestrerei": "orchestrare",
    "orchestreremmo": "orchestrare",
    "orchestreremo": "orchestrare",
    "orchestrereste": "orchestrare",
    "orchestreresti": "orchestrare",
    "orchestrerete": "orchestrare",
    "orchestrerà": "orchestrare",
    "orchestrerò": "orchestrare",
    "orchestri": "orchestrare",
    "orchestriamo": "orchestrare",
    "orchestriate": "orchestrare",
    "orchestrin": "orchestrare",
    "orchestrine": "orchestrina",
    "orchestrino": "orchestrare",
    "orchestro": "orchestrare",
    "orchestrò": "orchestrare",
    "orchi": "orco",
    "orde": "orda",
    "ordendo": "ordire",
    "ordente": "ordire",
    "ordenti": "ordire",
    "ordiamo": "ordire",
    "ordiate": "ordire",
    "ordigni": "ordigno",
    "ordii": "ordire",
    "ordimmo": "ordire",
    "ordina": "ordinare",
    "ordinai": "ordinare",
    "ordinamenti": "ordinamento",
    "ordinammo": "ordinare",
    "ordinan": "ordinare",
    "ordinando": "ordinare",
    "ordinano": "ordinare",
    "ordinante": "ordinare",
    "ordinanti": "ordinare",
    "ordinanze": "ordinanza",
    "ordinar": "ordinare",
    "ordinari": "ordinario",
    "ordinaria": "ordinario",
    "ordinarie": "ordinario",
    "ordinaron": "ordinare",
    "ordinarono": "ordinare",
    "ordinasse": "ordinare",
    "ordinasser": "ordinare",
    "ordinassero": "ordinare",
    "ordinassi": "ordinare",
    "ordinassimo": "ordinare",
    "ordinaste": "ordinare",
    "ordinasti": "ordinare",
    "ordinata": "ordinato",
    "ordinate": "ordinato",
    "ordinati": "ordinato",
    "ordinativa": "ordinativo",
    "ordinative": "ordinativo",
    "ordinativi": "ordinativo",
    "ordinato": "ordinare",
    "ordinatori": "ordinatore",
    "ordinatrice": "ordinatore",
    "ordinatrici": "ordinatore",
    "ordinava": "ordinare",
    "ordinavamo": "ordinare",
    "ordinavan": "ordinare",
    "ordinavano": "ordinare",
    "ordinavate": "ordinare",
    "ordinavi": "ordinare",
    "ordinavo": "ordinare",
    "ordinazioni": "ordinazione",
    "ordinerai": "ordinare",
    "ordineran": "ordinare",
    "ordineranno": "ordinare",
    "ordinerebbe": "ordinare",
    "ordinerebber": "ordinare",
    "ordinerebbero": "ordinare",
    "ordinerei": "ordinare",
    "ordineremmo": "ordinare",
    "ordineremo": "ordinare",
    "ordinereste": "ordinare",
    "ordineresti": "ordinare",
    "ordinerete": "ordinare",
    "ordinerà": "ordinare",
    "ordinerò": "ordinare",
    "ordini": "ordine",
    "ordiniamo": "ordinare",
    "ordiniate": "ordinare",
    "ordinin": "ordinare",
    "ordinino": "ordinare",
    "ordino": "ordinare",
    "ordinò": "ordinare",
    "ordir": "ordire",
    "ordirai": "ordire",
    "ordiran": "ordire",
    "ordiranno": "ordire",
    "ordirebbe": "ordire",
    "ordirebber": "ordire",
    "ordirebbero": "ordire",
    "ordirei": "ordire",
    "ordiremmo": "ordire",
    "ordiremo": "ordire",
    "ordireste": "ordire",
    "ordiresti": "ordire",
    "ordirete": "ordire",
    "ordiron": "ordire",
    "ordirono": "ordire",
    "ordirà": "ordire",
    "ordirò": "ordire",
    "ordisca": "ordire",
    "ordiscan": "ordire",
    "ordiscano": "ordire",
    "ordisce": "ordire",
    "ordisci": "ordire",
    "ordisco": "ordire",
    "ordiscon": "ordire",
    "ordiscono": "ordire",
    "ordisse": "ordire",
    "ordisser": "ordire",
    "ordissero": "ordire",
    "ordissi": "ordire",
    "ordissimo": "ordire",
    "ordiste": "ordire",
    "ordisti": "ordire",
    "ordita": "ordito",
    "ordite": "ordito",
    "orditi": "ordito",
    "ordito": "ordire",
    "ordiva": "ordire",
    "ordivamo": "ordire",
    "ordivan": "ordire",
    "ordivano": "ordire",
    "ordivate": "ordire",
    "ordivi": "ordire",
    "ordivo": "ordire",
    "ordì": "ordire",
    "ore": "ora",
    "orecchi": "orecchio",
    "orecchia": "orecchiare",
    "orecchiabili": "orecchiabile",
    "orecchiai": "orecchiare",
    "orecchiammo": "orecchiare",
    "orecchiamo": "orecchiare",
    "orecchian": "orecchiare",
    "orecchiando": "orecchiare",
    "orecchiano": "orecchiare",
    "orecchiante": "orecchiare",
    "orecchianti": "orecchiare",
    "orecchiar": "orecchiare",
    "orecchiaron": "orecchiare",
    "orecchiarono": "orecchiare",
    "orecchiasse": "orecchiare",
    "orecchiasser": "orecchiare",
    "orecchiassero": "orecchiare",
    "orecchiassi": "orecchiare",
    "orecchiassimo": "orecchiare",
    "orecchiaste": "orecchiare",
    "orecchiasti": "orecchiare",
    "orecchiata": "orecchiare",
    "orecchiate": "orecchiare",
    "orecchiati": "orecchiare",
    "orecchiato": "orecchiare",
    "orecchiava": "orecchiare",
    "orecchiavamo": "orecchiare",
    "orecchiavan": "orecchiare",
    "orecchiavano": "orecchiare",
    "orecchiavate": "orecchiare",
    "orecchiavi": "orecchiare",
    "orecchiavo": "orecchiare",
    "orecchie": "orecchio",
    "orecchierai": "orecchiare",
    "orecchieran": "orecchiare",
    "orecchieranno": "orecchiare",
    "orecchierebbe": "orecchiare",
    "orecchierebber": "orecchiare",
    "orecchierebbero": "orecchiare",
    "orecchierei": "orecchiare",
    "orecchieremmo": "orecchiare",
    "orecchieremo": "orecchiare",
    "orecchiereste": "orecchiare",
    "orecchieresti": "orecchiare",
    "orecchierete": "orecchiare",
    "orecchierà": "orecchiare",
    "orecchierò": "orecchiare",
    "orecchin": "orecchiare",
    "orecchini": "orecchino",
    "orecchino": "orecchiare",
    "orecchio": "orecchiare",
    "orecchiò": "orecchiare",
    "oreficerie": "oreficeria",
    "orefici": "orefice",
    "orerai": "orare",
    "oreran": "orare",
    "oreranno": "orare",
    "orerebbe": "orare",
    "orerebber": "orare",
    "orerebbero": "orare",
    "orerei": "orare",
    "oreremmo": "orare",
    "oreremo": "orare",
    "orereste": "orare",
    "oreresti": "orare",
    "orerete": "orare",
    "orerà": "orare",
    "orerò": "orare",
    "orette": "oretta",
    "orfana": "orfano",
    "orfanatrofi": "orfanatrofio",
    "orfane": "orfano",
    "orfanelle": "orfanella",
    "orfanelli": "orfanello",
    "orfani": "orfano",
    "orfanotrofi": "orfanotrofio",
    "orfica": "orfico",
    "orfiche": "orfico",
    "orfici": "orfico",
    "organetti": "organetto",
    "organi": "organo",
    "organica": "organico",
    "organiche": "organico",
    "organici": "organico",
    "organigrammi": "organigramma",
    "organismi": "organismo",
    "organisti": "organista",
    "organistica": "organistico",
    "organistiche": "organistico",
    "organistici": "organistico",
    "organizza": "organizzare",
    "organizzai": "organizzare",
    "organizzammo": "organizzare",
    "organizzan": "organizzare",
    "organizzando": "organizzare",
    "organizzano": "organizzare",
    "organizzante": "organizzare",
    "organizzanti": "organizzare",
    "organizzar": "organizzare",
    "organizzaron": "organizzare",
    "organizzarono": "organizzare",
    "organizzasse": "organizzare",
    "organizzasser": "organizzare",
    "organizzassero": "organizzare",
    "organizzassi": "organizzare",
    "organizzassimo": "organizzare",
    "organizzaste": "organizzare",
    "organizzasti": "organizzare",
    "organizzata": "organizzato",
    "organizzate": "organizzato",
    "organizzati": "organizzato",
    "organizzativa": "organizzativo",
    "organizzative": "organizzativo",
    "organizzativi": "organizzativo",
    "organizzato": "organizzare",
    "organizzatori": "organizzatore",
    "organizzatrice": "organizzatore",
    "organizzatrici": "organizzatrice",
    "organizzava": "organizzare",
    "organizzavamo": "organizzare",
    "organizzavan": "organizzare",
    "organizzavano": "organizzare",
    "organizzavate": "organizzare",
    "organizzavi": "organizzare",
    "organizzavo": "organizzare",
    "organizzazioni": "organizzazione",
    "organizzerai": "organizzare",
    "organizzeran": "organizzare",
    "organizzeranno": "organizzare",
    "organizzerebbe": "organizzare",
    "organizzerebber": "organizzare",
    "organizzerebbero": "organizzare",
    "organizzerei": "organizzare",
    "organizzeremmo": "organizzare",
    "organizzeremo": "organizzare",
    "organizzereste": "organizzare",
    "organizzeresti": "organizzare",
    "organizzerete": "organizzare",
    "organizzerà": "organizzare",
    "organizzerò": "organizzare",
    "organizzi": "organizzare",
    "organizziamo": "organizzare",
    "organizziate": "organizzare",
    "organizzin": "organizzare",
    "organizzino": "organizzare",
    "organizzo": "organizzare",
    "organizzò": "organizzare",
    "organolettica": "organolettico",
    "organolettiche": "organolettico",
    "organolettici": "organolettico",
    "orgasmi": "orgasmo",
    "orge": "orgia",
    "orgiastica": "orgiastico",
    "orgiastiche": "orgiastico",
    "orgiastici": "orgiastico",
    "orgini": "orgine",
    "orgogli": "orgoglio",
    "orgogliosa": "orgoglioso",
    "orgogliose": "orgoglioso",
    "orgogliosi": "orgoglioso",
    "ori": "oro",
    "oriamo": "orare",
    "oriate": "orare",
    "orienta": "orientare",
    "orientai": "orientare",
    "orientaleggianti": "orientaleggiante",
    "orientali": "orientale",
    "orientalismi": "orientalismo",
    "orientalisti": "orientalista",
    "orientamenti": "orientamento",
    "orientammo": "orientare",
    "orientan": "orientare",
    "orientando": "orientare",
    "orientano": "orientare",
    "orientante": "orientare",
    "orientanti": "orientare",
    "orientar": "orientare",
    "orientaron": "orientare",
    "orientarono": "orientare",
    "orientasse": "orientare",
    "orientasser": "orientare",
    "orientassero": "orientare",
    "orientassi": "orientare",
    "orientassimo": "orientare",
    "orientaste": "orientare",
    "orientasti": "orientare",
    "orientata": "orientato",
    "orientate": "orientato",
    "orientati": "orientato",
    "orientativa": "orientativo",
    "orientative": "orientativo",
    "orientativi": "orientativo",
    "orientato": "orientare",
    "orientava": "orientare",
    "orientavamo": "orientare",
    "orientavan": "orientare",
    "orientavano": "orientare",
    "orientavate": "orientare",
    "orientavi": "orientare",
    "orientavo": "orientare",
    "orienterai": "orientare",
    "orienteran": "orientare",
    "orienteranno": "orientare",
    "orienterebbe": "orientare",
    "orienterebber": "orientare",
    "orienterebbero": "orientare",
    "orienterei": "orientare",
    "orienteremmo": "orientare",
    "orienteremo": "orientare",
    "orientereste": "orientare",
    "orienteresti": "orientare",
    "orienterete": "orientare",
    "orienterà": "orientare",
    "orienterò": "orientare",
    "orienti": "oriente",
    "orientiamo": "orientare",
    "orientiate": "orientare",
    "orientin": "orientare",
    "orientino": "orientare",
    "oriento": "orientare",
    "orientò": "orientare",
    "orifizi": "orifizio",
    "origina": "originare",
    "originai": "originare",
    "originali": "originale",
    "originammo": "originare",
    "originan": "originare",
    "originando": "originare",
    "originano": "originare",
    "originante": "originare",
    "originanti": "originare",
    "originar": "originare",
    "originari": "originario",
    "originaria": "originario",
    "originarie": "originario",
    "originaron": "originare",
    "originarono": "originare",
    "originasse": "originare",
    "originasser": "originare",
    "originassero": "originare",
    "originassi": "originare",
    "originassimo": "originare",
    "originaste": "originare",
    "originasti": "originare",
    "originata": "originare",
    "originate": "originare",
    "originati": "originare",
    "originato": "originare",
    "originava": "originare",
    "originavamo": "originare",
    "originavan": "originare",
    "originavano": "originare",
    "originavate": "originare",
    "originavi": "originare",
    "originavo": "originare",
    "originerai": "originare",
    "origineran": "originare",
    "origineranno": "originare",
    "originerebbe": "originare",
    "originerebber": "originare",
    "originerebbero": "originare",
    "originerei": "originare",
    "origineremmo": "originare",
    "origineremo": "originare",
    "originereste": "originare",
    "origineresti": "originare",
    "originerete": "originare",
    "originerà": "originare",
    "originerò": "originare",
    "origini": "origine",
    "originiamo": "originare",
    "originiate": "originare",
    "originin": "originare",
    "originino": "originare",
    "origino": "originare",
    "originò": "originare",
    "origli": "origliare",
    "origlia": "origliare",
    "origliai": "origliare",
    "origliammo": "origliare",
    "origliamo": "origliare",
    "origlian": "origliare",
    "origliando": "origliare",
    "origliano": "origliare",
    "origliante": "origliare",
    "origlianti": "origliare",
    "origliar": "origliare",
    "origliaron": "origliare",
    "origliarono": "origliare",
    "origliasse": "origliare",
    "origliasser": "origliare",
    "origliassero": "origliare",
    "origliassi": "origliare",
    "origliassimo": "origliare",
    "origliaste": "origliare",
    "origliasti": "origliare",
    "origliata": "origliare",
    "origliate": "origliare",
    "origliati": "origliare",
    "origliato": "origliare",
    "origliava": "origliare",
    "origliavamo": "origliare",
    "origliavan": "origliare",
    "origliavano": "origliare",
    "origliavate": "origliare",
    "origliavi": "origliare",
    "origliavo": "origliare",
    "origlierai": "origliare",
    "origlieran": "origliare",
    "origlieranno": "origliare",
    "origlierebbe": "origliare",
    "origlierebber": "origliare",
    "origlierebbero": "origliare",
    "origlierei": "origliare",
    "origlieremmo": "origliare",
    "origlieremo": "origliare",
    "origliereste": "origliare",
    "origlieresti": "origliare",
    "origlierete": "origliare",
    "origlierà": "origliare",
    "origlierò": "origliare",
    "origlin": "origliare",
    "origlino": "origliare",
    "origlio": "origliare",
    "origliò": "origliare",
    "orin": "orare",
    "orina": "orinare",
    "orinai": "orinare",
    "orinammo": "orinare",
    "orinan": "orinare",
    "orinando": "orinare",
    "orinano": "orinare",
    "orinante": "orinare",
    "orinanti": "orinare",
    "orinar": "orinare",
    "orinaron": "orinare",
    "orinarono": "orinare",
    "orinasse": "orinare",
    "orinasser": "orinare",
    "orinassero": "orinare",
    "orinassi": "orinare",
    "orinassimo": "orinare",
    "orinaste": "orinare",
    "orinasti": "orinare",
    "orinata": "orinare",
    "orinate": "orinare",
    "orinati": "orinare",
    "orinato": "orinare",
    "orinatoi": "orinatoio",
    "orinava": "orinare",
    "orinavamo": "orinare",
    "orinavan": "orinare",
    "orinavano": "orinare",
    "orinavate": "orinare",
    "orinavi": "orinare",
    "orinavo": "orinare",
    "orinerai": "orinare",
    "orineran": "orinare",
    "orineranno": "orinare",
    "orinerebbe": "orinare",
    "orinerebber": "orinare",
    "orinerebbero": "orinare",
    "orinerei": "orinare",
    "orineremmo": "orinare",
    "orineremo": "orinare",
    "orinereste": "orinare",
    "orineresti": "orinare",
    "orinerete": "orinare",
    "orinerà": "orinare",
    "orinerò": "orinare",
    "orini": "orinare",
    "oriniamo": "orinare",
    "oriniate": "orinare",
    "orinin": "orinare",
    "orinino": "orinare",
    "orino": "orinare",
    "orinò": "orinare",
    "oriundi": "oriundo",
    "orizzonta": "orizzontare",
    "orizzontai": "orizzontare",
    "orizzontali": "orizzontale",
    "orizzontammo": "orizzontare",
    "orizzontan": "orizzontare",
    "orizzontando": "orizzontare",
    "orizzontano": "orizzontare",
    "orizzontante": "orizzontare",
    "orizzontanti": "orizzontare",
    "orizzontar": "orizzontare",
    "orizzontaron": "orizzontare",
    "orizzontarono": "orizzontare",
    "orizzontasse": "orizzontare",
    "orizzontasser": "orizzontare",
    "orizzontassero": "orizzontare",
    "orizzontassi": "orizzontare",
    "orizzontassimo": "orizzontare",
    "orizzontaste": "orizzontare",
    "orizzontasti": "orizzontare",
    "orizzontata": "orizzontare",
    "orizzontate": "orizzontare",
    "orizzontati": "orizzontare",
    "orizzontato": "orizzontare",
    "orizzontava": "orizzontare",
    "orizzontavamo": "orizzontare",
    "orizzontavan": "orizzontare",
    "orizzontavano": "orizzontare",
    "orizzontavate": "orizzontare",
    "orizzontavi": "orizzontare",
    "orizzontavo": "orizzontare",
    "orizzonterai": "orizzontare",
    "orizzonteran": "orizzontare",
    "orizzonteranno": "orizzontare",
    "orizzonterebbe": "orizzontare",
    "orizzonterebber": "orizzontare",
    "orizzonterebbero": "orizzontare",
    "orizzonterei": "orizzontare",
    "orizzonteremmo": "orizzontare",
    "orizzonteremo": "orizzontare",
    "orizzontereste": "orizzontare",
    "orizzonteresti": "orizzontare",
    "orizzonterete": "orizzontare",
    "orizzonterà": "orizzontare",
    "orizzonterò": "orizzontare",
    "orizzonti": "orizzonte",
    "orizzontiamo": "orizzontare",
    "orizzontiate": "orizzontare",
    "orizzontin": "orizzontare",
    "orizzontino": "orizzontare",
    "orizzonto": "orizzontare",
    "orizzontò": "orizzontare",
    "orla": "orlare",
    "orlai": "orlare",
    "orlammo": "orlare",
    "orlan": "orlare",
    "orlando": "orlare",
    "orlano": "orlare",
    "orlante": "orlare",
    "orlanti": "orlare",
    "orlar": "orlare",
    "orlaron": "orlare",
    "orlarono": "orlare",
    "orlasse": "orlare",
    "orlasser": "orlare",
    "orlassero": "orlare",
    "orlassi": "orlare",
    "orlassimo": "orlare",
    "orlaste": "orlare",
    "orlasti": "orlare",
    "orlata": "orlare",
    "orlate": "orlare",
    "orlati": "orlare",
    "orlato": "orlare",
    "orlava": "orlare",
    "orlavamo": "orlare",
    "orlavan": "orlare",
    "orlavano": "orlare",
    "orlavate": "orlare",
    "orlavi": "orlare",
    "orlavo": "orlare",
    "orlerai": "orlare",
    "orleran": "orlare",
    "orleranno": "orlare",
    "orlerebbe": "orlare",
    "orlerebber": "orlare",
    "orlerebbero": "orlare",
    "orlerei": "orlare",
    "orleremmo": "orlare",
    "orleremo": "orlare",
    "orlereste": "orlare",
    "orleresti": "orlare",
    "orlerete": "orlare",
    "orlerà": "orlare",
    "orlerò": "orlare",
    "orli": "orlare",
    "orliamo": "orlare",
    "orliate": "orlare",
    "orlin": "orlare",
    "orlino": "orlare",
    "orlo": "orlare",
    "orlò": "orlare",
    "orme": "orma",
    "ormeggerai": "ormeggiare",
    "ormeggeran": "ormeggiare",
    "ormeggeranno": "ormeggiare",
    "ormeggerebbe": "ormeggiare",
    "ormeggerebber": "ormeggiare",
    "ormeggerebbero": "ormeggiare",
    "ormeggerei": "ormeggiare",
    "ormeggeremmo": "ormeggiare",
    "ormeggeremo": "ormeggiare",
    "ormeggereste": "ormeggiare",
    "ormeggeresti": "ormeggiare",
    "ormeggerete": "ormeggiare",
    "ormeggerà": "ormeggiare",
    "ormeggerò": "ormeggiare",
    "ormeggi": "ormeggio",
    "ormeggia": "ormeggiare",
    "ormeggiai": "ormeggiare",
    "ormeggiammo": "ormeggiare",
    "ormeggiamo": "ormeggiare",
    "ormeggian": "ormeggiare",
    "ormeggiando": "ormeggiare",
    "ormeggiano": "ormeggiare",
    "ormeggiante": "ormeggiare",
    "ormeggianti": "ormeggiare",
    "ormeggiar": "ormeggiare",
    "ormeggiaron": "ormeggiare",
    "ormeggiarono": "ormeggiare",
    "ormeggiasse": "ormeggiare",
    "ormeggiasser": "ormeggiare",
    "ormeggiassero": "ormeggiare",
    "ormeggiassi": "ormeggiare",
    "ormeggiassimo": "ormeggiare",
    "ormeggiaste": "ormeggiare",
    "ormeggiasti": "ormeggiare",
    "ormeggiata": "ormeggiare",
    "ormeggiate": "ormeggiare",
    "ormeggiati": "ormeggiare",
    "ormeggiato": "ormeggiare",
    "ormeggiava": "ormeggiare",
    "ormeggiavamo": "ormeggiare",
    "ormeggiavan": "ormeggiare",
    "ormeggiavano": "ormeggiare",
    "ormeggiavate": "ormeggiare",
    "ormeggiavi": "ormeggiare",
    "ormeggiavo": "ormeggiare",
    "ormeggin": "ormeggiare",
    "ormeggino": "ormeggiare",
    "ormeggio": "ormeggiare",
    "ormeggiò": "ormeggiare",
    "ormonali": "ormonale",
    "ormoni": "ormone",
    "ormonica": "ormonico",
    "ormoniche": "ormonico",
    "ormonici": "ormonico",
    "orna": "ornare",
    "ornai": "ornare",
    "ornamentali": "ornamentale",
    "ornamenti": "ornamento",
    "ornammo": "ornare",
    "ornan": "ornare",
    "ornando": "ornare",
    "ornano": "ornare",
    "ornante": "ornare",
    "ornanti": "ornare",
    "ornar": "ornare",
    "ornaron": "ornare",
    "ornarono": "ornare",
    "ornasse": "ornare",
    "ornasser": "ornare",
    "ornassero": "ornare",
    "ornassi": "ornare",
    "ornassimo": "ornare",
    "ornaste": "ornare",
    "ornasti": "ornare",
    "ornata": "ornato",
    "ornate": "ornato",
    "ornati": "ornato",
    "ornato": "ornare",
    "ornava": "ornare",
    "ornavamo": "ornare",
    "ornavan": "ornare",
    "ornavano": "ornare",
    "ornavate": "ornare",
    "ornavi": "ornare",
    "ornavo": "ornare",
    "ornerai": "ornare",
    "orneran": "ornare",
    "orneranno": "ornare",
    "ornerebbe": "ornare",
    "ornerebber": "ornare",
    "ornerebbero": "ornare",
    "ornerei": "ornare",
    "orneremmo": "ornare",
    "orneremo": "ornare",
    "ornereste": "ornare",
    "orneresti": "ornare",
    "ornerete": "ornare",
    "ornerà": "ornare",
    "ornerò": "ornare",
    "orni": "ornare",
    "orniamo": "ornare",
    "orniate": "ornare",
    "ornin": "ornare",
    "ornino": "ornare",
    "ornitologi": "ornitologo",
    "orno": "ornare",
    "ornò": "ornare",
    "oro": "orare",
    "orobica": "orobico",
    "orobiche": "orobico",
    "orobici": "orobico",
    "orografica": "orografico",
    "orografiche": "orografico",
    "orografici": "orografico",
    "orologi": "orologio",
    "orologiai": "orologiaio",
    "orologini": "orologino",
    "oroscopi": "oroscopo",
    "orpelli": "orpello",
    "orrenda": "orrendo",
    "orrende": "orrendo",
    "orrendi": "orrendo",
    "orribili": "orribile",
    "orrida": "orrido",
    "orride": "orrido",
    "orridi": "orrido",
    "orripilanti": "orripilante",
    "orrori": "orrore",
    "orsacchiotti": "orsacchiotto",
    "orsetti": "orsetto",
    "orsi": "orso",
    "ortaggi": "ortaggio",
    "orti": "orto",
    "orticelli": "orticello",
    "ortiche": "ortica",
    "orticola": "orticolo",
    "orticole": "orticolo",
    "orticoli": "orticolo",
    "ortodossa": "ortodosso",
    "ortodosse": "ortodosso",
    "ortodossi": "ortodosso",
    "ortodossie": "ortodossia",
    "ortofrutticola": "ortofrutticolo",
    "ortofrutticole": "ortofrutticolo",
    "ortofrutticoli": "ortofrutticolo",
    "ortogonali": "ortogonale",
    "ortografica": "ortografico",
    "ortografiche": "ortografico",
    "ortografici": "ortografico",
    "ortolani": "ortolano",
    "ortopedica": "ortopedico",
    "ortopediche": "ortopedico",
    "ortopedici": "ortopedico",
    "orza": "orzare",
    "orzai": "orzare",
    "orzammo": "orzare",
    "orzan": "orzare",
    "orzando": "orzare",
    "orzano": "orzare",
    "orzante": "orzare",
    "orzanti": "orzare",
    "orzar": "orzare",
    "orzaron": "orzare",
    "orzarono": "orzare",
    "orzasse": "orzare",
    "orzasser": "orzare",
    "orzassero": "orzare",
    "orzassi": "orzare",
    "orzassimo": "orzare",
    "orzaste": "orzare",
    "orzasti": "orzare",
    "orzata": "orzare",
    "orzate": "orzare",
    "orzati": "orzare",
    "orzato": "orzare",
    "orzava": "orzare",
    "orzavamo": "orzare",
    "orzavan": "orzare",
    "orzavano": "orzare",
    "orzavate": "orzare",
    "orzavi": "orzare",
    "orzavo": "orzare",
    "orzerai": "orzare",
    "orzeran": "orzare",
    "orzeranno": "orzare",
    "orzerebbe": "orzare",
    "orzerebber": "orzare",
    "orzerebbero": "orzare",
    "orzerei": "orzare",
    "orzeremmo": "orzare",
    "orzeremo": "orzare",
    "orzereste": "orzare",
    "orzeresti": "orzare",
    "orzerete": "orzare",
    "orzerà": "orzare",
    "orzerò": "orzare",
    "orzi": "orzare",
    "orziamo": "orzare",
    "orziate": "orzare",
    "orzin": "orzare",
    "orzino": "orzare",
    "orzo": "orzare",
    "orzò": "orzare",
    "orò": "orare",
    "osa": "osare",
    "osai": "osare",
    "osammo": "osare",
    "osan": "osare",
    "osando": "osare",
    "osanna": "osannare",
    "osannai": "osannare",
    "osannammo": "osannare",
    "osannan": "osannare",
    "osannando": "osannare",
    "osannano": "osannare",
    "osannante": "osannare",
    "osannanti": "osannare",
    "osannar": "osannare",
    "osannaron": "osannare",
    "osannarono": "osannare",
    "osannasse": "osannare",
    "osannasser": "osannare",
    "osannassero": "osannare",
    "osannassi": "osannare",
    "osannassimo": "osannare",
    "osannaste": "osannare",
    "osannasti": "osannare",
    "osannata": "osannare",
    "osannate": "osannare",
    "osannati": "osannare",
    "osannato": "osannare",
    "osannava": "osannare",
    "osannavamo": "osannare",
    "osannavan": "osannare",
    "osannavano": "osannare",
    "osannavate": "osannare",
    "osannavi": "osannare",
    "osannavo": "osannare",
    "osannerai": "osannare",
    "osanneran": "osannare",
    "osanneranno": "osannare",
    "osannerebbe": "osannare",
    "osannerebber": "osannare",
    "osannerebbero": "osannare",
    "osannerei": "osannare",
    "osanneremmo": "osannare",
    "osanneremo": "osannare",
    "osannereste": "osannare",
    "osanneresti": "osannare",
    "osannerete": "osannare",
    "osannerà": "osannare",
    "osannerò": "osannare",
    "osanni": "osannare",
    "osanniamo": "osannare",
    "osanniate": "osannare",
    "osannin": "osannare",
    "osannino": "osannare",
    "osanno": "osannare",
    "osannò": "osannare",
    "osano": "osare",
    "osante": "osare",
    "osanti": "osare",
    "osar": "osare",
    "osaron": "osare",
    "osarono": "osare",
    "osasse": "osare",
    "osasser": "osare",
    "osassero": "osare",
    "osassi": "osare",
    "osassimo": "osare",
    "osaste": "osare",
    "osasti": "osare",
    "osata": "osare",
    "osate": "osare",
    "osati": "osare",
    "osato": "osare",
    "osava": "osare",
    "osavamo": "osare",
    "osavan": "osare",
    "osavano": "osare",
    "osavate": "osare",
    "osavi": "osare",
    "osavo": "osare",
    "oscena": "osceno",
    "oscene": "osceno",
    "osceni": "osceno",
    "oscilla": "oscillare",
    "oscillai": "oscillare",
    "oscillammo": "oscillare",
    "oscillan": "oscillare",
    "oscillando": "oscillare",
    "oscillano": "oscillare",
    "oscillante": "oscillare",
    "oscillanti": "oscillare",
    "oscillar": "oscillare",
    "oscillaron": "oscillare",
    "oscillarono": "oscillare",
    "oscillasse": "oscillare",
    "oscillasser": "oscillare",
    "oscillassero": "oscillare",
    "oscillassi": "oscillare",
    "oscillassimo": "oscillare",
    "oscillaste": "oscillare",
    "oscillasti": "oscillare",
    "oscillata": "oscillare",
    "oscillate": "oscillare",
    "oscillati": "oscillare",
    "oscillato": "oscillare",
    "oscillava": "oscillare",
    "oscillavamo": "oscillare",
    "oscillavan": "oscillare",
    "oscillavano": "oscillare",
    "oscillavate": "oscillare",
    "oscillavi": "oscillare",
    "oscillavo": "oscillare",
    "oscillazioni": "oscillazione",
    "oscillerai": "oscillare",
    "oscilleran": "oscillare",
    "oscilleranno": "oscillare",
    "oscillerebbe": "oscillare",
    "oscillerebber": "oscillare",
    "oscillerebbero": "oscillare",
    "oscillerei": "oscillare",
    "oscilleremmo": "oscillare",
    "oscilleremo": "oscillare",
    "oscillereste": "oscillare",
    "oscilleresti": "oscillare",
    "oscillerete": "oscillare",
    "oscillerà": "oscillare",
    "oscillerò": "oscillare",
    "oscilli": "oscillare",
    "oscilliamo": "oscillare",
    "oscilliate": "oscillare",
    "oscillin": "oscillare",
    "oscillino": "oscillare",
    "oscillo": "oscillare",
    "oscillò": "oscillare",
    "oscura": "oscuro",
    "oscurai": "oscurare",
    "oscuramenti": "oscuramento",
    "oscurammo": "oscurare",
    "oscuran": "oscurare",
    "oscurando": "oscurare",
    "oscurano": "oscurare",
    "oscurante": "oscurare",
    "oscuranti": "oscurare",
    "oscurantismi": "oscurantismo",
    "oscurantiste": "oscurantista",
    "oscurantisti": "oscurantista",
    "oscurar": "oscurare",
    "oscuraron": "oscurare",
    "oscurarono": "oscurare",
    "oscurasse": "oscurare",
    "oscurasser": "oscurare",
    "oscurassero": "oscurare",
    "oscurassi": "oscurare",
    "oscurassimo": "oscurare",
    "oscuraste": "oscurare",
    "oscurasti": "oscurare",
    "oscurata": "oscurare",
    "oscurate": "oscurare",
    "oscurati": "oscurare",
    "oscurato": "oscurare",
    "oscurava": "oscurare",
    "oscuravamo": "oscurare",
    "oscuravan": "oscurare",
    "oscuravano": "oscurare",
    "oscuravate": "oscurare",
    "oscuravi": "oscurare",
    "oscuravo": "oscurare",
    "oscure": "oscuro",
    "oscurerai": "oscurare",
    "oscureran": "oscurare",
    "oscureranno": "oscurare",
    "oscurerebbe": "oscurare",
    "oscurerebber": "oscurare",
    "oscurerebbero": "oscurare",
    "oscurerei": "oscurare",
    "oscureremmo": "oscurare",
    "oscureremo": "oscurare",
    "oscurereste": "oscurare",
    "oscureresti": "oscurare",
    "oscurerete": "oscurare",
    "oscurerà": "oscurare",
    "oscurerò": "oscurare",
    "oscuri": "oscuro",
    "oscuriamo": "oscurare",
    "oscuriate": "oscurare",
    "oscurin": "oscurare",
    "oscurino": "oscurare",
    "oscuro": "oscurare",
    "oscurò": "oscurare",
    "oserai": "osare",
    "oseran": "osare",
    "oseranno": "osare",
    "oserebbe": "osare",
    "oserebber": "osare",
    "oserebbero": "osare",
    "oserei": "osare",
    "oseremmo": "osare",
    "oseremo": "osare",
    "osereste": "osare",
    "oseresti": "osare",
    "oserete": "osare",
    "oserà": "osare",
    "oserò": "osare",
    "osi": "osare",
    "osiamo": "osare",
    "osiate": "osare",
    "osin": "osare",
    "osino": "osare",
    "oso": "osare",
    "ospedali": "ospedale",
    "ospedaliera": "ospedaliero",
    "ospedaliere": "ospedaliero",
    "ospedalieri": "ospedaliero",
    "ospedalizza": "ospedalizzare",
    "ospedalizzai": "ospedalizzare",
    "ospedalizzammo": "ospedalizzare",
    "ospedalizzan": "ospedalizzare",
    "ospedalizzando": "ospedalizzare",
    "ospedalizzano": "ospedalizzare",
    "ospedalizzante": "ospedalizzare",
    "ospedalizzanti": "ospedalizzare",
    "ospedalizzar": "ospedalizzare",
    "ospedalizzaron": "ospedalizzare",
    "ospedalizzarono": "ospedalizzare",
    "ospedalizzasse": "ospedalizzare",
    "ospedalizzasser": "ospedalizzare",
    "ospedalizzassero": "ospedalizzare",
    "ospedalizzassi": "ospedalizzare",
    "ospedalizzassimo": "ospedalizzare",
    "ospedalizzaste": "ospedalizzare",
    "ospedalizzasti": "ospedalizzare",
    "ospedalizzata": "ospedalizzare",
    "ospedalizzate": "ospedalizzare",
    "ospedalizzati": "ospedalizzare",
    "ospedalizzato": "ospedalizzare",
    "ospedalizzava": "ospedalizzare",
    "ospedalizzavamo": "ospedalizzare",
    "ospedalizzavan": "ospedalizzare",
    "ospedalizzavano": "ospedalizzare",
    "ospedalizzavate": "ospedalizzare",
    "ospedalizzavi": "ospedalizzare",
    "ospedalizzavo": "ospedalizzare",
    "ospedalizzerai": "ospedalizzare",
    "ospedalizzeran": "ospedalizzare",
    "ospedalizzeranno": "ospedalizzare",
    "ospedalizzerebbe": "ospedalizzare",
    "ospedalizzerebber": "ospedalizzare",
    "ospedalizzerebbero": "ospedalizzare",
    "ospedalizzerei": "ospedalizzare",
    "ospedalizzeremmo": "ospedalizzare",
    "ospedalizzeremo": "ospedalizzare",
    "ospedalizzereste": "ospedalizzare",
    "ospedalizzeresti": "ospedalizzare",
    "ospedalizzerete": "ospedalizzare",
    "ospedalizzerà": "ospedalizzare",
    "ospedalizzerò": "ospedalizzare",
    "ospedalizzi": "ospedalizzare",
    "ospedalizziamo": "ospedalizzare",
    "ospedalizziate": "ospedalizzare",
    "ospedalizzin": "ospedalizzare",
    "ospedalizzino": "ospedalizzare",
    "ospedalizzo": "ospedalizzare",
    "ospedalizzò": "ospedalizzare",
    "ospita": "ospitare",
    "ospitai": "ospitare",
    "ospitali": "ospitale",
    "ospitammo": "ospitare",
    "ospitan": "ospitare",
    "ospitando": "ospitare",
    "ospitano": "ospitare",
    "ospitante": "ospitare",
    "ospitanti": "ospitare",
    "ospitar": "ospitare",
    "ospitaron": "ospitare",
    "ospitarono": "ospitare",
    "ospitasse": "ospitare",
    "ospitasser": "ospitare",
    "ospitassero": "ospitare",
    "ospitassi": "ospitare",
    "ospitassimo": "ospitare",
    "ospitaste": "ospitare",
    "ospitasti": "ospitare",
    "ospitata": "ospitare",
    "ospitate": "ospitare",
    "ospitati": "ospitare",
    "ospitato": "ospitare",
    "ospitava": "ospitare",
    "ospitavamo": "ospitare",
    "ospitavan": "ospitare",
    "ospitavano": "ospitare",
    "ospitavate": "ospitare",
    "ospitavi": "ospitare",
    "ospitavo": "ospitare",
    "ospiterai": "ospitare",
    "ospiteran": "ospitare",
    "ospiteranno": "ospitare",
    "ospiterebbe": "ospitare",
    "ospiterebber": "ospitare",
    "ospiterebbero": "ospitare",
    "ospiterei": "ospitare",
    "ospiteremmo": "ospitare",
    "ospiteremo": "ospitare",
    "ospitereste": "ospitare",
    "ospiteresti": "ospitare",
    "ospiterete": "ospitare",
    "ospiterà": "ospitare",
    "ospiterò": "ospitare",
    "ospiti": "ospite",
    "ospitiamo": "ospitare",
    "ospitiate": "ospitare",
    "ospitin": "ospitare",
    "ospitino": "ospitare",
    "ospito": "ospitare",
    "ospitò": "ospitare",
    "ospizi": "ospizio",
    "ossa": "osso",
    "ossari": "ossario",
    "ossature": "ossatura",
    "ossea": "osseo",
    "ossee": "osseo",
    "ossei": "osseo",
    "ossequi": "ossequio",
    "ossequia": "ossequiare",
    "ossequiai": "ossequiare",
    "ossequiammo": "ossequiare",
    "ossequiamo": "ossequiare",
    "ossequian": "ossequiare",
    "ossequiando": "ossequiare",
    "ossequiano": "ossequiare",
    "ossequiante": "ossequiare",
    "ossequianti": "ossequiare",
    "ossequiar": "ossequiare",
    "ossequiaron": "ossequiare",
    "ossequiarono": "ossequiare",
    "ossequiasse": "ossequiare",
    "ossequiasser": "ossequiare",
    "ossequiassero": "ossequiare",
    "ossequiassi": "ossequiare",
    "ossequiassimo": "ossequiare",
    "ossequiaste": "ossequiare",
    "ossequiasti": "ossequiare",
    "ossequiata": "ossequiare",
    "ossequiate": "ossequiare",
    "ossequiati": "ossequiare",
    "ossequiato": "ossequiare",
    "ossequiava": "ossequiare",
    "ossequiavamo": "ossequiare",
    "ossequiavan": "ossequiare",
    "ossequiavano": "ossequiare",
    "ossequiavate": "ossequiare",
    "ossequiavi": "ossequiare",
    "ossequiavo": "ossequiare",
    "ossequienti": "ossequiente",
    "ossequierai": "ossequiare",
    "ossequieran": "ossequiare",
    "ossequieranno": "ossequiare",
    "ossequierebbe": "ossequiare",
    "ossequierebber": "ossequiare",
    "ossequierebbero": "ossequiare",
    "ossequierei": "ossequiare",
    "ossequieremmo": "ossequiare",
    "ossequieremo": "ossequiare",
    "ossequiereste": "ossequiare",
    "ossequieresti": "ossequiare",
    "ossequierete": "ossequiare",
    "ossequierà": "ossequiare",
    "ossequierò": "ossequiare",
    "ossequin": "ossequiare",
    "ossequino": "ossequiare",
    "ossequio": "ossequiare",
    "ossequiosa": "ossequioso",
    "ossequiose": "ossequioso",
    "ossequiosi": "ossequioso",
    "ossequiò": "ossequiare",
    "osserva": "osservare",
    "osservai": "osservare",
    "osservammo": "osservare",
    "osservan": "osservare",
    "osservando": "osservare",
    "osservano": "osservare",
    "osservante": "osservare",
    "osservanti": "osservare",
    "osservanze": "osservanza",
    "osservar": "osservare",
    "osservaron": "osservare",
    "osservarono": "osservare",
    "osservasse": "osservare",
    "osservasser": "osservare",
    "osservassero": "osservare",
    "osservassi": "osservare",
    "osservassimo": "osservare",
    "osservaste": "osservare",
    "osservasti": "osservare",
    "osservata": "osservare",
    "osservate": "osservare",
    "osservati": "osservare",
    "osservato": "osservare",
    "osservatori": "osservatorio",
    "osservatrice": "osservatore",
    "osservatrici": "osservatore",
    "osservava": "osservare",
    "osservavamo": "osservare",
    "osservavan": "osservare",
    "osservavano": "osservare",
    "osservavate": "osservare",
    "osservavi": "osservare",
    "osservavo": "osservare",
    "osservazioni": "osservazione",
    "osserverai": "osservare",
    "osserveran": "osservare",
    "osserveranno": "osservare",
    "osserverebbe": "osservare",
    "osserverebber": "osservare",
    "osserverebbero": "osservare",
    "osserverei": "osservare",
    "osserveremmo": "osservare",
    "osserveremo": "osservare",
    "osservereste": "osservare",
    "osserveresti": "osservare",
    "osserverete": "osservare",
    "osserverà": "osservare",
    "osserverò": "osservare",
    "osservi": "osservare",
    "osserviamo": "osservare",
    "osserviate": "osservare",
    "osservin": "osservare",
    "osservino": "osservare",
    "osservo": "osservare",
    "osservò": "osservare",
    "ossessa": "ossesso",
    "ossesse": "ossesso",
    "ossessi": "ossesso",
    "ossessiona": "ossessionare",
    "ossessionai": "ossessionare",
    "ossessionammo": "ossessionare",
    "ossessionan": "ossessionare",
    "ossessionando": "ossessionare",
    "ossessionano": "ossessionare",
    "ossessionante": "ossessionare",
    "ossessionanti": "ossessionare",
    "ossessionar": "ossessionare",
    "ossessionaron": "ossessionare",
    "ossessionarono": "ossessionare",
    "ossessionasse": "ossessionare",
    "ossessionasser": "ossessionare",
    "ossessionassero": "ossessionare",
    "ossessionassi": "ossessionare",
    "ossessionassimo": "ossessionare",
    "ossessionaste": "ossessionare",
    "ossessionasti": "ossessionare",
    "ossessionata": "ossessionare",
    "ossessionate": "ossessionare",
    "ossessionati": "ossessionare",
    "ossessionato": "ossessionare",
    "ossessionava": "ossessionare",
    "ossessionavamo": "ossessionare",
    "ossessionavan": "ossessionare",
    "ossessionavano": "ossessionare",
    "ossessionavate": "ossessionare",
    "ossessionavi": "ossessionare",
    "ossessionavo": "ossessionare",
    "ossessionerai": "ossessionare",
    "ossessioneran": "ossessionare",
    "ossessioneranno": "ossessionare",
    "ossessionerebbe": "ossessionare",
    "ossessionerebber": "ossessionare",
    "ossessionerebbero": "ossessionare",
    "ossessionerei": "ossessionare",
    "ossessioneremmo": "ossessionare",
    "ossessioneremo": "ossessionare",
    "ossessionereste": "ossessionare",
    "ossessioneresti": "ossessionare",
    "ossessionerete": "ossessionare",
    "ossessionerà": "ossessionare",
    "ossessionerò": "ossessionare",
    "ossessioni": "ossessione",
    "ossessioniamo": "ossessionare",
    "ossessioniate": "ossessionare",
    "ossessionin": "ossessionare",
    "ossessionino": "ossessionare",
    "ossessiono": "ossessionare",
    "ossessionò": "ossessionare",
    "ossessiva": "ossessivo",
    "ossessive": "ossessivo",
    "ossessivi": "ossessivo",
    "ossi": "osso",
    "ossiacetilenica": "ossiacetilenico",
    "ossiacetileniche": "ossiacetilenico",
    "ossiacetilenici": "ossiacetilenico",
    "ossicini": "ossicino",
    "ossida": "ossidare",
    "ossidai": "ossidare",
    "ossidammo": "ossidare",
    "ossidan": "ossidare",
    "ossidando": "ossidare",
    "ossidano": "ossidare",
    "ossidante": "ossidare",
    "ossidanti": "ossidare",
    "ossidar": "ossidare",
    "ossidaron": "ossidare",
    "ossidarono": "ossidare",
    "ossidasse": "ossidare",
    "ossidasser": "ossidare",
    "ossidassero": "ossidare",
    "ossidassi": "ossidare",
    "ossidassimo": "ossidare",
    "ossidaste": "ossidare",
    "ossidasti": "ossidare",
    "ossidata": "ossidare",
    "ossidate": "ossidare",
    "ossidati": "ossidare",
    "ossidato": "ossidare",
    "ossidava": "ossidare",
    "ossidavamo": "ossidare",
    "ossidavan": "ossidare",
    "ossidavano": "ossidare",
    "ossidavate": "ossidare",
    "ossidavi": "ossidare",
    "ossidavo": "ossidare",
    "ossiderai": "ossidare",
    "ossideran": "ossidare",
    "ossideranno": "ossidare",
    "ossiderebbe": "ossidare",
    "ossiderebber": "ossidare",
    "ossiderebbero": "ossidare",
    "ossiderei": "ossidare",
    "ossideremmo": "ossidare",
    "ossideremo": "ossidare",
    "ossidereste": "ossidare",
    "ossideresti": "ossidare",
    "ossiderete": "ossidare",
    "ossiderà": "ossidare",
    "ossiderò": "ossidare",
    "ossidi": "ossido",
    "ossidiamo": "ossidare",
    "ossidiate": "ossidare",
    "ossidin": "ossidare",
    "ossidino": "ossidare",
    "ossido": "ossidare",
    "ossidrica": "ossidrico",
    "ossidriche": "ossidrico",
    "ossidrici": "ossidrico",
    "ossidò": "ossidare",
    "ossifica": "ossificare",
    "ossificai": "ossificare",
    "ossificammo": "ossificare",
    "ossifican": "ossificare",
    "ossificando": "ossificare",
    "ossificano": "ossificare",
    "ossificante": "ossificare",
    "ossificanti": "ossificare",
    "ossificar": "ossificare",
    "ossificaron": "ossificare",
    "ossificarono": "ossificare",
    "ossificasse": "ossificare",
    "ossificasser": "ossificare",
    "ossificassero": "ossificare",
    "ossificassi": "ossificare",
    "ossificassimo": "ossificare",
    "ossificaste": "ossificare",
    "ossificasti": "ossificare",
    "ossificata": "ossificare",
    "ossificate": "ossificare",
    "ossificati": "ossificare",
    "ossificato": "ossificare",
    "ossificava": "ossificare",
    "ossificavamo": "ossificare",
    "ossificavan": "ossificare",
    "ossificavano": "ossificare",
    "ossificavate": "ossificare",
    "ossificavi": "ossificare",
    "ossificavo": "ossificare",
    "ossificherai": "ossificare",
    "ossificheran": "ossificare",
    "ossificheranno": "ossificare",
    "ossificherebbe": "ossificare",
    "ossificherebber": "ossificare",
    "ossificherebbero": "ossificare",
    "ossificherei": "ossificare",
    "ossificheremmo": "ossificare",
    "ossificheremo": "ossificare",
    "ossifichereste": "ossificare",
    "ossificheresti": "ossificare",
    "ossificherete": "ossificare",
    "ossificherà": "ossificare",
    "ossificherò": "ossificare",
    "ossifichi": "ossificare",
    "ossifichiamo": "ossificare",
    "ossifichiate": "ossificare",
    "ossifichin": "ossificare",
    "ossifichino": "ossificare",
    "ossifico": "ossificare",
    "ossificò": "ossificare",
    "ossigena": "ossigenare",
    "ossigenai": "ossigenare",
    "ossigenammo": "ossigenare",
    "ossigenan": "ossigenare",
    "ossigenando": "ossigenare",
    "ossigenano": "ossigenare",
    "ossigenante": "ossigenare",
    "ossigenanti": "ossigenare",
    "ossigenar": "ossigenare",
    "ossigenaron": "ossigenare",
    "ossigenarono": "ossigenare",
    "ossigenasse": "ossigenare",
    "ossigenasser": "ossigenare",
    "ossigenassero": "ossigenare",
    "ossigenassi": "ossigenare",
    "ossigenassimo": "ossigenare",
    "ossigenaste": "ossigenare",
    "ossigenasti": "ossigenare",
    "ossigenata": "ossigenare",
    "ossigenate": "ossigenare",
    "ossigenati": "ossigenare",
    "ossigenato": "ossigenare",
    "ossigenava": "ossigenare",
    "ossigenavamo": "ossigenare",
    "ossigenavan": "ossigenare",
    "ossigenavano": "ossigenare",
    "ossigenavate": "ossigenare",
    "ossigenavi": "ossigenare",
    "ossigenavo": "ossigenare",
    "ossigenerai": "ossigenare",
    "ossigeneran": "ossigenare",
    "ossigeneranno": "ossigenare",
    "ossigenerebbe": "ossigenare",
    "ossigenerebber": "ossigenare",
    "ossigenerebbero": "ossigenare",
    "ossigenerei": "ossigenare",
    "ossigeneremmo": "ossigenare",
    "ossigeneremo": "ossigenare",
    "ossigenereste": "ossigenare",
    "ossigeneresti": "ossigenare",
    "ossigenerete": "ossigenare",
    "ossigenerà": "ossigenare",
    "ossigenerò": "ossigenare",
    "ossigeni": "ossigeno",
    "ossigeniamo": "ossigenare",
    "ossigeniate": "ossigenare",
    "ossigenin": "ossigenare",
    "ossigenino": "ossigenare",
    "ossigeno": "ossigenare",
    "ossigenò": "ossigenare",
    "ossimori": "ossimoro",
    "ossuta": "ossuto",
    "ossute": "ossuto",
    "ossuti": "ossuto",
    "osta": "ostare",
    "ostacola": "ostacolare",
    "ostacolai": "ostacolare",
    "ostacolammo": "ostacolare",
    "ostacolan": "ostacolare",
    "ostacolando": "ostacolare",
    "ostacolano": "ostacolare",
    "ostacolante": "ostacolare",
    "ostacolanti": "ostacolare",
    "ostacolar": "ostacolare",
    "ostacolaron": "ostacolare",
    "ostacolarono": "ostacolare",
    "ostacolasse": "ostacolare",
    "ostacolasser": "ostacolare",
    "ostacolassero": "ostacolare",
    "ostacolassi": "ostacolare",
    "ostacolassimo": "ostacolare",
    "ostacolaste": "ostacolare",
    "ostacolasti": "ostacolare",
    "ostacolata": "ostacolare",
    "ostacolate": "ostacolare",
    "ostacolati": "ostacolare",
    "ostacolato": "ostacolare",
    "ostacolava": "ostacolare",
    "ostacolavamo": "ostacolare",
    "ostacolavan": "ostacolare",
    "ostacolavano": "ostacolare",
    "ostacolavate": "ostacolare",
    "ostacolavi": "ostacolare",
    "ostacolavo": "ostacolare",
    "ostacolerai": "ostacolare",
    "ostacoleran": "ostacolare",
    "ostacoleranno": "ostacolare",
    "ostacolerebbe": "ostacolare",
    "ostacolerebber": "ostacolare",
    "ostacolerebbero": "ostacolare",
    "ostacolerei": "ostacolare",
    "ostacoleremmo": "ostacolare",
    "ostacoleremo": "ostacolare",
    "ostacolereste": "ostacolare",
    "ostacoleresti": "ostacolare",
    "ostacolerete": "ostacolare",
    "ostacolerà": "ostacolare",
    "ostacolerò": "ostacolare",
    "ostacoli": "ostacolo",
    "ostacoliamo": "ostacolare",
    "ostacoliate": "ostacolare",
    "ostacolin": "ostacolare",
    "ostacolino": "ostacolare",
    "ostacolo": "ostacolare",
    "ostacolò": "ostacolare",
    "ostaggi": "ostaggio",
    "ostai": "ostare",
    "ostammo": "ostare",
    "ostan": "ostare",
    "ostando": "ostare",
    "ostano": "ostare",
    "ostante": "ostare",
    "ostanti": "ostare",
    "ostar": "ostare",
    "ostaron": "ostare",
    "ostarono": "ostare",
    "ostasse": "ostare",
    "ostasser": "ostare",
    "ostassero": "ostare",
    "ostassi": "ostare",
    "ostassimo": "ostare",
    "ostaste": "ostare",
    "ostasti": "ostare",
    "ostata": "ostare",
    "ostate": "ostare",
    "ostati": "ostare",
    "ostativa": "ostativo",
    "ostative": "ostativo",
    "ostativi": "ostativo",
    "ostato": "ostare",
    "ostava": "ostare",
    "ostavamo": "ostare",
    "ostavan": "ostare",
    "ostavano": "ostare",
    "ostavate": "ostare",
    "ostavi": "ostare",
    "ostavo": "ostare",
    "osteggerai": "osteggiare",
    "osteggeran": "osteggiare",
    "osteggeranno": "osteggiare",
    "osteggerebbe": "osteggiare",
    "osteggerebber": "osteggiare",
    "osteggerebbero": "osteggiare",
    "osteggerei": "osteggiare",
    "osteggeremmo": "osteggiare",
    "osteggeremo": "osteggiare",
    "osteggereste": "osteggiare",
    "osteggeresti": "osteggiare",
    "osteggerete": "osteggiare",
    "osteggerà": "osteggiare",
    "osteggerò": "osteggiare",
    "osteggi": "osteggiare",
    "osteggia": "osteggiare",
    "osteggiai": "osteggiare",
    "osteggiammo": "osteggiare",
    "osteggiamo": "osteggiare",
    "osteggian": "osteggiare",
    "osteggiando": "osteggiare",
    "osteggiano": "osteggiare",
    "osteggiante": "osteggiare",
    "osteggianti": "osteggiare",
    "osteggiar": "osteggiare",
    "osteggiaron": "osteggiare",
    "osteggiarono": "osteggiare",
    "osteggiasse": "osteggiare",
    "osteggiasser": "osteggiare",
    "osteggiassero": "osteggiare",
    "osteggiassi": "osteggiare",
    "osteggiassimo": "osteggiare",
    "osteggiaste": "osteggiare",
    "osteggiasti": "osteggiare",
    "osteggiata": "osteggiare",
    "osteggiate": "osteggiare",
    "osteggiati": "osteggiare",
    "osteggiato": "osteggiare",
    "osteggiava": "osteggiare",
    "osteggiavamo": "osteggiare",
    "osteggiavan": "osteggiare",
    "osteggiavano": "osteggiare",
    "osteggiavate": "osteggiare",
    "osteggiavi": "osteggiare",
    "osteggiavo": "osteggiare",
    "osteggin": "osteggiare",
    "osteggino": "osteggiare",
    "osteggio": "osteggiare",
    "osteggiò": "osteggiare",
    "ostelli": "ostello",
    "ostensibili": "ostensibile",
    "ostenta": "ostentare",
    "ostentai": "ostentare",
    "ostentammo": "ostentare",
    "ostentan": "ostentare",
    "ostentando": "ostentare",
    "ostentano": "ostentare",
    "ostentante": "ostentare",
    "ostentanti": "ostentare",
    "ostentar": "ostentare",
    "ostentaron": "ostentare",
    "ostentarono": "ostentare",
    "ostentasse": "ostentare",
    "ostentasser": "ostentare",
    "ostentassero": "ostentare",
    "ostentassi": "ostentare",
    "ostentassimo": "ostentare",
    "ostentaste": "ostentare",
    "ostentasti": "ostentare",
    "ostentata": "ostentare",
    "ostentate": "ostentare",
    "ostentati": "ostentare",
    "ostentato": "ostentare",
    "ostentava": "ostentare",
    "ostentavamo": "ostentare",
    "ostentavan": "ostentare",
    "ostentavano": "ostentare",
    "ostentavate": "ostentare",
    "ostentavi": "ostentare",
    "ostentavo": "ostentare",
    "ostentazioni": "ostentazione",
    "ostenterai": "ostentare",
    "ostenteran": "ostentare",
    "ostenteranno": "ostentare",
    "ostenterebbe": "ostentare",
    "ostenterebber": "ostentare",
    "ostenterebbero": "ostentare",
    "ostenterei": "ostentare",
    "ostenteremmo": "ostentare",
    "ostenteremo": "ostentare",
    "ostentereste": "ostentare",
    "ostenteresti": "ostentare",
    "ostenterete": "ostentare",
    "ostenterà": "ostentare",
    "ostenterò": "ostentare",
    "ostenti": "ostentare",
    "ostentiamo": "ostentare",
    "ostentiate": "ostentare",
    "ostentin": "ostentare",
    "ostentino": "ostentare",
    "ostento": "ostentare",
    "ostentò": "ostentare",
    "osterai": "ostare",
    "osteran": "ostare",
    "osteranno": "ostare",
    "osterebbe": "ostare",
    "osterebber": "ostare",
    "osterebbero": "ostare",
    "osterei": "ostare",
    "osteremmo": "ostare",
    "osteremo": "ostare",
    "ostereste": "ostare",
    "osteresti": "ostare",
    "osterete": "ostare",
    "osterie": "osteria",
    "osterà": "ostare",
    "osterò": "ostare",
    "ostetrica": "ostetrico",
    "ostetriche": "ostetrico",
    "ostetrici": "ostetrico",
    "osti": "oste",
    "ostiamo": "ostare",
    "ostiate": "ostare",
    "ostica": "ostico",
    "ostiche": "ostico",
    "ostici": "ostico",
    "ostie": "ostia",
    "ostili": "ostile",
    "ostin": "ostare",
    "ostina": "ostinare",
    "ostinai": "ostinare",
    "ostinammo": "ostinare",
    "ostinan": "ostinare",
    "ostinando": "ostinare",
    "ostinano": "ostinare",
    "ostinar": "ostinare",
    "ostinaron": "ostinare",
    "ostinarono": "ostinare",
    "ostinasse": "ostinare",
    "ostinasser": "ostinare",
    "ostinassero": "ostinare",
    "ostinassi": "ostinare",
    "ostinassimo": "ostinare",
    "ostinaste": "ostinare",
    "ostinasti": "ostinare",
    "ostinata": "ostinato",
    "ostinate": "ostinato",
    "ostinati": "ostinato",
    "ostinato": "ostinare",
    "ostinava": "ostinare",
    "ostinavamo": "ostinare",
    "ostinavan": "ostinare",
    "ostinavano": "ostinare",
    "ostinavate": "ostinare",
    "ostinavi": "ostinare",
    "ostinavo": "ostinare",
    "ostinazioni": "ostinazione",
    "ostinerai": "ostinare",
    "ostineran": "ostinare",
    "ostineranno": "ostinare",
    "ostinerebbe": "ostinare",
    "ostinerebber": "ostinare",
    "ostinerebbero": "ostinare",
    "ostinerei": "ostinare",
    "ostineremmo": "ostinare",
    "ostineremo": "ostinare",
    "ostinereste": "ostinare",
    "ostineresti": "ostinare",
    "ostinerete": "ostinare",
    "ostinerà": "ostinare",
    "ostinerò": "ostinare",
    "ostini": "ostinare",
    "ostiniamo": "ostinare",
    "ostiniate": "ostinare",
    "ostinin": "ostinare",
    "ostinino": "ostinare",
    "ostino": "ostinare",
    "ostinò": "ostinare",
    "osto": "ostare",
    "ostracismi": "ostracismo",
    "ostracizza": "ostracizzare",
    "ostracizzai": "ostracizzare",
    "ostracizzammo": "ostracizzare",
    "ostracizzan": "ostracizzare",
    "ostracizzando": "ostracizzare",
    "ostracizzano": "ostracizzare",
    "ostracizzante": "ostracizzare",
    "ostracizzanti": "ostracizzare",
    "ostracizzar": "ostracizzare",
    "ostracizzaron": "ostracizzare",
    "ostracizzarono": "ostracizzare",
    "ostracizzasse": "ostracizzare",
    "ostracizzasser": "ostracizzare",
    "ostracizzassero": "ostracizzare",
    "ostracizzassi": "ostracizzare",
    "ostracizzassimo": "ostracizzare",
    "ostracizzaste": "ostracizzare",
    "ostracizzasti": "ostracizzare",
    "ostracizzata": "ostracizzare",
    "ostracizzate": "ostracizzare",
    "ostracizzati": "ostracizzare",
    "ostracizzato": "ostracizzare",
    "ostracizzava": "ostracizzare",
    "ostracizzavamo": "ostracizzare",
    "ostracizzavan": "ostracizzare",
    "ostracizzavano": "ostracizzare",
    "ostracizzavate": "ostracizzare",
    "ostracizzavi": "ostracizzare",
    "ostracizzavo": "ostracizzare",
    "ostracizzerai": "ostracizzare",
    "ostracizzeran": "ostracizzare",
    "ostracizzeranno": "ostracizzare",
    "ostracizzerebbe": "ostracizzare",
    "ostracizzerebber": "ostracizzare",
    "ostracizzerebbero": "ostracizzare",
    "ostracizzerei": "ostracizzare",
    "ostracizzeremmo": "ostracizzare",
    "ostracizzeremo": "ostracizzare",
    "ostracizzereste": "ostracizzare",
    "ostracizzeresti": "ostracizzare",
    "ostracizzerete": "ostracizzare",
    "ostracizzerà": "ostracizzare",
    "ostracizzerò": "ostracizzare",
    "ostracizzi": "ostracizzare",
    "ostracizziamo": "ostracizzare",
    "ostracizziate": "ostracizzare",
    "ostracizzin": "ostracizzare",
    "ostracizzino": "ostracizzare",
    "ostracizzo": "ostracizzare",
    "ostracizzò": "ostracizzare",
    "ostriche": "ostrica",
    "ostrogota": "ostrogoto",
    "ostrogote": "ostrogoto",
    "ostrogoti": "ostrogoto",
    "ostruendo": "ostruire",
    "ostruente": "ostruire",
    "ostruenti": "ostruire",
    "ostruiamo": "ostruire",
    "ostruiate": "ostruire",
    "ostruii": "ostruire",
    "ostruimmo": "ostruire",
    "ostruir": "ostruire",
    "ostruirai": "ostruire",
    "ostruiran": "ostruire",
    "ostruiranno": "ostruire",
    "ostruirebbe": "ostruire",
    "ostruirebber": "ostruire",
    "ostruirebbero": "ostruire",
    "ostruirei": "ostruire",
    "ostruiremmo": "ostruire",
    "ostruiremo": "ostruire",
    "ostruireste": "ostruire",
    "ostruiresti": "ostruire",
    "ostruirete": "ostruire",
    "ostruiron": "ostruire",
    "ostruirono": "ostruire",
    "ostruirà": "ostruire",
    "ostruirò": "ostruire",
    "ostruisca": "ostruire",
    "ostruiscan": "ostruire",
    "ostruiscano": "ostruire",
    "ostruisce": "ostruire",
    "ostruisci": "ostruire",
    "ostruisco": "ostruire",
    "ostruiscon": "ostruire",
    "ostruiscono": "ostruire",
    "ostruisse": "ostruire",
    "ostruisser": "ostruire",
    "ostruissero": "ostruire",
    "ostruissi": "ostruire",
    "ostruissimo": "ostruire",
    "ostruiste": "ostruire",
    "ostruisti": "ostruire",
    "ostruita": "ostruire",
    "ostruite": "ostruire",
    "ostruiti": "ostruire",
    "ostruito": "ostruire",
    "ostruiva": "ostruire",
    "ostruivamo": "ostruire",
    "ostruivan": "ostruire",
    "ostruivano": "ostruire",
    "ostruivate": "ostruire",
    "ostruivi": "ostruire",
    "ostruivo": "ostruire",
    "ostruzioni": "ostruzione",
    "ostruzionismi": "ostruzionismo",
    "ostruzionistica": "ostruzionistico",
    "ostruzionistiche": "ostruzionistico",
    "ostruzionistici": "ostruzionistico",
    "ostruì": "ostruire",
    "ostò": "ostare",
    "osò": "osare",
    "otiti": "otite",
    "otorinolaringoiatri": "otorinolaringoiatra",
    "otri": "otre",
    "ottagonali": "ottagonale",
    "ottantacinquesima": "ottantacinquesimo",
    "ottantacinquesime": "ottantacinquesimo",
    "ottantacinquesimi": "ottantacinquesimo",
    "ottantaduesima": "ottantaduesimo",
    "ottantaduesime": "ottantaduesimo",
    "ottantaduesimi": "ottantaduesimo",
    "ottantanovesima": "ottantanovesimo",
    "ottantanovesime": "ottantanovesimo",
    "ottantanovesimi": "ottantanovesimo",
    "ottantaquattresima": "ottantaquattresimo",
    "ottantaquattresime": "ottantaquattresimo",
    "ottantaquattresimi": "ottantaquattresimo",
    "ottantaseiesima": "ottantaseiesimo",
    "ottantaseiesime": "ottantaseiesimo",
    "ottantaseiesimi": "ottantaseiesimo",
    "ottantasettesima": "ottantasettesimo",
    "ottantasettesime": "ottantasettesimo",
    "ottantasettesimi": "ottantasettesimo",
    "ottantatreesima": "ottantatreesimo",
    "ottantatreesime": "ottantatreesimo",
    "ottantatreesimi": "ottantatreesimo",
    "ottantenni": "ottantenne",
    "ottantesima": "ottantesimo",
    "ottantesime": "ottantesimo",
    "ottantesimi": "ottantesimo",
    "ottantine": "ottantina",
    "ottantottesima": "ottantottesimo",
    "ottantottesime": "ottantottesimo",
    "ottantottesimi": "ottantottesimo",
    "ottantunesima": "ottantunesimo",
    "ottantunesime": "ottantunesimo",
    "ottantunesimi": "ottantunesimo",
    "ottava": "ottavo",
    "ottave": "ottavo",
    "ottavi": "ottavo",
    "ottempera": "ottemperare",
    "ottemperai": "ottemperare",
    "ottemperammo": "ottemperare",
    "ottemperan": "ottemperare",
    "ottemperando": "ottemperare",
    "ottemperano": "ottemperare",
    "ottemperante": "ottemperare",
    "ottemperanti": "ottemperare",
    "ottemperar": "ottemperare",
    "ottemperaron": "ottemperare",
    "ottemperarono": "ottemperare",
    "ottemperasse": "ottemperare",
    "ottemperasser": "ottemperare",
    "ottemperassero": "ottemperare",
    "ottemperassi": "ottemperare",
    "ottemperassimo": "ottemperare",
    "ottemperaste": "ottemperare",
    "ottemperasti": "ottemperare",
    "ottemperata": "ottemperare",
    "ottemperate": "ottemperare",
    "ottemperati": "ottemperare",
    "ottemperato": "ottemperare",
    "ottemperava": "ottemperare",
    "ottemperavamo": "ottemperare",
    "ottemperavan": "ottemperare",
    "ottemperavano": "ottemperare",
    "ottemperavate": "ottemperare",
    "ottemperavi": "ottemperare",
    "ottemperavo": "ottemperare",
    "ottempererai": "ottemperare",
    "ottempereran": "ottemperare",
    "ottempereranno": "ottemperare",
    "ottempererebbe": "ottemperare",
    "ottempererebber": "ottemperare",
    "ottempererebbero": "ottemperare",
    "ottempererei": "ottemperare",
    "ottempereremmo": "ottemperare",
    "ottempereremo": "ottemperare",
    "ottemperereste": "ottemperare",
    "ottempereresti": "ottemperare",
    "ottempererete": "ottemperare",
    "ottempererà": "ottemperare",
    "ottempererò": "ottemperare",
    "ottemperi": "ottemperare",
    "ottemperiamo": "ottemperare",
    "ottemperiate": "ottemperare",
    "ottemperin": "ottemperare",
    "ottemperino": "ottemperare",
    "ottempero": "ottemperare",
    "ottemperò": "ottemperare",
    "ottenebra": "ottenebrare",
    "ottenebrai": "ottenebrare",
    "ottenebrammo": "ottenebrare",
    "ottenebran": "ottenebrare",
    "ottenebrando": "ottenebrare",
    "ottenebrano": "ottenebrare",
    "ottenebrante": "ottenebrare",
    "ottenebranti": "ottenebrare",
    "ottenebrar": "ottenebrare",
    "ottenebraron": "ottenebrare",
    "ottenebrarono": "ottenebrare",
    "ottenebrasse": "ottenebrare",
    "ottenebrasser": "ottenebrare",
    "ottenebrassero": "ottenebrare",
    "ottenebrassi": "ottenebrare",
    "ottenebrassimo": "ottenebrare",
    "ottenebraste": "ottenebrare",
    "ottenebrasti": "ottenebrare",
    "ottenebrata": "ottenebrare",
    "ottenebrate": "ottenebrare",
    "ottenebrati": "ottenebrare",
    "ottenebrato": "ottenebrare",
    "ottenebrava": "ottenebrare",
    "ottenebravamo": "ottenebrare",
    "ottenebravan": "ottenebrare",
    "ottenebravano": "ottenebrare",
    "ottenebravate": "ottenebrare",
    "ottenebravi": "ottenebrare",
    "ottenebravo": "ottenebrare",
    "ottenebrerai": "ottenebrare",
    "ottenebreran": "ottenebrare",
    "ottenebreranno": "ottenebrare",
    "ottenebrerebbe": "ottenebrare",
    "ottenebrerebber": "ottenebrare",
    "ottenebrerebbero": "ottenebrare",
    "ottenebrerei": "ottenebrare",
    "ottenebreremmo": "ottenebrare",
    "ottenebreremo": "ottenebrare",
    "ottenebrereste": "ottenebrare",
    "ottenebreresti": "ottenebrare",
    "ottenebrerete": "ottenebrare",
    "ottenebrerà": "ottenebrare",
    "ottenebrerò": "ottenebrare",
    "ottenebri": "ottenebrare",
    "ottenebriamo": "ottenebrare",
    "ottenebriate": "ottenebrare",
    "ottenebrin": "ottenebrare",
    "ottenebrino": "ottenebrare",
    "ottenebro": "ottenebrare",
    "ottenebrò": "ottenebrare",
    "ottenemmo": "ottenere",
    "ottenendo": "ottenere",
    "ottenente": "ottenere",
    "ottenenti": "ottenere",
    "ottener": "ottenere",
    "ottenesse": "ottenere",
    "ottenesser": "ottenere",
    "ottenessero": "ottenere",
    "ottenessi": "ottenere",
    "ottenessimo": "ottenere",
    "otteneste": "ottenere",
    "ottenesti": "ottenere",
    "ottenete": "ottenere",
    "otteneva": "ottenere",
    "ottenevamo": "ottenere",
    "ottenevan": "ottenere",
    "ottenevano": "ottenere",
    "ottenevate": "ottenere",
    "ottenevi": "ottenere",
    "ottenevo": "ottenere",
    "ottenga": "ottenere",
    "ottengan": "ottenere",
    "ottengano": "ottenere",
    "ottengo": "ottenere",
    "ottengon": "ottenere",
    "ottengono": "ottenere",
    "otteniamo": "ottenere",
    "otteniate": "ottenere",
    "ottenibili": "ottenibile",
    "ottenne": "ottenere",
    "ottenner": "ottenere",
    "ottennero": "ottenere",
    "ottenni": "ottenne",
    "ottenuta": "ottenere",
    "ottenute": "ottenere",
    "ottenuti": "ottenere",
    "ottenuto": "ottenere",
    "otterrai": "ottenere",
    "otterran": "ottenere",
    "otterranno": "ottenere",
    "otterrebbe": "ottenere",
    "otterrebber": "ottenere",
    "otterrebbero": "ottenere",
    "otterrei": "ottenere",
    "otterremmo": "ottenere",
    "otterremo": "ottenere",
    "otterreste": "ottenere",
    "otterresti": "ottenere",
    "otterrete": "ottenere",
    "otterrà": "ottenere",
    "otterrò": "ottenere",
    "ottica": "ottico",
    "ottiche": "ottico",
    "ottici": "ottico",
    "ottiene": "ottenere",
    "ottieni": "ottenere",
    "ottima": "ottimo",
    "ottimai": "ottimare",
    "ottimali": "ottimale",
    "ottimammo": "ottimare",
    "ottiman": "ottimare",
    "ottimando": "ottimare",
    "ottimano": "ottimare",
    "ottimante": "ottimare",
    "ottimanti": "ottimare",
    "ottimar": "ottimare",
    "ottimaron": "ottimare",
    "ottimarono": "ottimare",
    "ottimasse": "ottimare",
    "ottimasser": "ottimare",
    "ottimassero": "ottimare",
    "ottimassi": "ottimare",
    "ottimassimo": "ottimare",
    "ottimaste": "ottimare",
    "ottimasti": "ottimare",
    "ottimata": "ottimare",
    "ottimate": "ottimare",
    "ottimati": "ottimare",
    "ottimato": "ottimare",
    "ottimava": "ottimare",
    "ottimavamo": "ottimare",
    "ottimavan": "ottimare",
    "ottimavano": "ottimare",
    "ottimavate": "ottimare",
    "ottimavi": "ottimare",
    "ottimavo": "ottimare",
    "ottime": "ottimo",
    "ottimerai": "ottimare",
    "ottimeran": "ottimare",
    "ottimeranno": "ottimare",
    "ottimerebbe": "ottimare",
    "ottimerebber": "ottimare",
    "ottimerebbero": "ottimare",
    "ottimerei": "ottimare",
    "ottimeremmo": "ottimare",
    "ottimeremo": "ottimare",
    "ottimereste": "ottimare",
    "ottimeresti": "ottimare",
    "ottimerete": "ottimare",
    "ottimerà": "ottimare",
    "ottimerò": "ottimare",
    "ottimi": "ottimo",
    "ottimiamo": "ottimare",
    "ottimiate": "ottimare",
    "ottimin": "ottimare",
    "ottimino": "ottimare",
    "ottimismi": "ottimismo",
    "ottimisti": "ottimista",
    "ottimistica": "ottimistico",
    "ottimistiche": "ottimistico",
    "ottimistici": "ottimistico",
    "ottimizza": "ottimizzare",
    "ottimizzai": "ottimizzare",
    "ottimizzammo": "ottimizzare",
    "ottimizzan": "ottimizzare",
    "ottimizzando": "ottimizzare",
    "ottimizzano": "ottimizzare",
    "ottimizzante": "ottimizzare",
    "ottimizzanti": "ottimizzare",
    "ottimizzar": "ottimizzare",
    "ottimizzaron": "ottimizzare",
    "ottimizzarono": "ottimizzare",
    "ottimizzasse": "ottimizzare",
    "ottimizzasser": "ottimizzare",
    "ottimizzassero": "ottimizzare",
    "ottimizzassi": "ottimizzare",
    "ottimizzassimo": "ottimizzare",
    "ottimizzaste": "ottimizzare",
    "ottimizzasti": "ottimizzare",
    "ottimizzata": "ottimizzare",
    "ottimizzate": "ottimizzare",
    "ottimizzati": "ottimizzare",
    "ottimizzato": "ottimizzare",
    "ottimizzava": "ottimizzare",
    "ottimizzavamo": "ottimizzare",
    "ottimizzavan": "ottimizzare",
    "ottimizzavano": "ottimizzare",
    "ottimizzavate": "ottimizzare",
    "ottimizzavi": "ottimizzare",
    "ottimizzavo": "ottimizzare",
    "ottimizzerai": "ottimizzare",
    "ottimizzeran": "ottimizzare",
    "ottimizzeranno": "ottimizzare",
    "ottimizzerebbe": "ottimizzare",
    "ottimizzerebber": "ottimizzare",
    "ottimizzerebbero": "ottimizzare",
    "ottimizzerei": "ottimizzare",
    "ottimizzeremmo": "ottimizzare",
    "ottimizzeremo": "ottimizzare",
    "ottimizzereste": "ottimizzare",
    "ottimizzeresti": "ottimizzare",
    "ottimizzerete": "ottimizzare",
    "ottimizzerà": "ottimizzare",
    "ottimizzerò": "ottimizzare",
    "ottimizzi": "ottimizzare",
    "ottimizziamo": "ottimizzare",
    "ottimizziate": "ottimizzare",
    "ottimizzin": "ottimizzare",
    "ottimizzino": "ottimizzare",
    "ottimizzo": "ottimizzare",
    "ottimizzò": "ottimizzare",
    "ottimo": "ottimare",
    "ottimò": "ottimare",
    "ottobri": "ottobre",
    "ottocentesca": "ottocentesco",
    "ottocentesche": "ottocentesco",
    "ottocenteschi": "ottocentesco",
    "ottocentesima": "ottocentesimo",
    "ottocentesime": "ottocentesimo",
    "ottocentesimi": "ottocentesimo",
    "ottomana": "ottomano",
    "ottomane": "ottomano",
    "ottomani": "ottomano",
    "ottomillesima": "ottomillesimo",
    "ottomillesime": "ottomillesimo",
    "ottomillesimi": "ottomillesimo",
    "ottona": "ottonare",
    "ottonai": "ottonare",
    "ottonammo": "ottonare",
    "ottonan": "ottonare",
    "ottonando": "ottonare",
    "ottonano": "ottonare",
    "ottonante": "ottonare",
    "ottonanti": "ottonare",
    "ottonar": "ottonare",
    "ottonaron": "ottonare",
    "ottonarono": "ottonare",
    "ottonasse": "ottonare",
    "ottonasser": "ottonare",
    "ottonassero": "ottonare",
    "ottonassi": "ottonare",
    "ottonassimo": "ottonare",
    "ottonaste": "ottonare",
    "ottonasti": "ottonare",
    "ottonata": "ottonare",
    "ottonate": "ottonare",
    "ottonati": "ottonare",
    "ottonato": "ottonare",
    "ottonava": "ottonare",
    "ottonavamo": "ottonare",
    "ottonavan": "ottonare",
    "ottonavano": "ottonare",
    "ottonavate": "ottonare",
    "ottonavi": "ottonare",
    "ottonavo": "ottonare",
    "ottonerai": "ottonare",
    "ottoneran": "ottonare",
    "ottoneranno": "ottonare",
    "ottonerebbe": "ottonare",
    "ottonerebber": "ottonare",
    "ottonerebbero": "ottonare",
    "ottonerei": "ottonare",
    "ottoneremmo": "ottonare",
    "ottoneremo": "ottonare",
    "ottonereste": "ottonare",
    "ottoneresti": "ottonare",
    "ottonerete": "ottonare",
    "ottonerà": "ottonare",
    "ottonerò": "ottonare",
    "ottoni": "ottone",
    "ottoniamo": "ottonare",
    "ottoniate": "ottonare",
    "ottonin": "ottonare",
    "ottonino": "ottonare",
    "ottono": "ottonare",
    "ottonò": "ottonare",
    "ottuagenari": "ottuagenario",
    "ottuagenaria": "ottuagenario",
    "ottuagenarie": "ottuagenario",
    "ottunda": "ottundere",
    "ottundan": "ottundere",
    "ottundano": "ottundere",
    "ottunde": "ottundere",
    "ottundemmo": "ottundere",
    "ottundendo": "ottundere",
    "ottundente": "ottundere",
    "ottundenti": "ottundere",
    "ottunder": "ottundere",
    "ottunderai": "ottundere",
    "ottunderan": "ottundere",
    "ottunderanno": "ottundere",
    "ottunderebbe": "ottundere",
    "ottunderebber": "ottundere",
    "ottunderebbero": "ottundere",
    "ottunderei": "ottundere",
    "ottunderemmo": "ottundere",
    "ottunderemo": "ottundere",
    "ottundereste": "ottundere",
    "ottunderesti": "ottundere",
    "ottunderete": "ottundere",
    "ottunderà": "ottundere",
    "ottunderò": "ottundere",
    "ottundesse": "ottundere",
    "ottundesser": "ottundere",
    "ottundessero": "ottundere",
    "ottundessi": "ottundere",
    "ottundessimo": "ottundere",
    "ottundeste": "ottundere",
    "ottundesti": "ottundere",
    "ottundete": "ottundere",
    "ottundeva": "ottundere",
    "ottundevamo": "ottundere",
    "ottundevan": "ottundere",
    "ottundevano": "ottundere",
    "ottundevate": "ottundere",
    "ottundevi": "ottundere",
    "ottundevo": "ottundere",
    "ottundi": "ottundere",
    "ottundiamo": "ottundere",
    "ottundiate": "ottundere",
    "ottundo": "ottundere",
    "ottundon": "ottundere",
    "ottundono": "ottundere",
    "ottura": "otturare",
    "otturai": "otturare",
    "otturammo": "otturare",
    "otturan": "otturare",
    "otturando": "otturare",
    "otturano": "otturare",
    "otturante": "otturare",
    "otturanti": "otturare",
    "otturar": "otturare",
    "otturaron": "otturare",
    "otturarono": "otturare",
    "otturasse": "otturare",
    "otturasser": "otturare",
    "otturassero": "otturare",
    "otturassi": "otturare",
    "otturassimo": "otturare",
    "otturaste": "otturare",
    "otturasti": "otturare",
    "otturata": "otturare",
    "otturate": "otturare",
    "otturati": "otturare",
    "otturato": "otturare",
    "otturava": "otturare",
    "otturavamo": "otturare",
    "otturavan": "otturare",
    "otturavano": "otturare",
    "otturavate": "otturare",
    "otturavi": "otturare",
    "otturavo": "otturare",
    "otturazioni": "otturazione",
    "otturerai": "otturare",
    "ottureran": "otturare",
    "ottureranno": "otturare",
    "otturerebbe": "otturare",
    "otturerebber": "otturare",
    "otturerebbero": "otturare",
    "otturerei": "otturare",
    "ottureremmo": "otturare",
    "ottureremo": "otturare",
    "otturereste": "otturare",
    "ottureresti": "otturare",
    "otturerete": "otturare",
    "otturerà": "otturare",
    "otturerò": "otturare",
    "otturi": "otturare",
    "otturiamo": "otturare",
    "otturiate": "otturare",
    "otturin": "otturare",
    "otturino": "otturare",
    "otturo": "otturare",
    "otturò": "otturare",
    "ottusa": "ottuso",
    "ottuse": "ottuso",
    "ottuser": "ottundere",
    "ottusero": "ottundere",
    "ottusi": "ottuso",
    "ottuso": "ottundere",
    "ottusè": "ottundere",
    "ouvertures": "ouverture",
    "ovaie": "ovaia",
    "ovali": "ovale",
    "ovatta": "ovattare",
    "ovattai": "ovattare",
    "ovattammo": "ovattare",
    "ovattan": "ovattare",
    "ovattando": "ovattare",
    "ovattano": "ovattare",
    "ovattante": "ovattare",
    "ovattanti": "ovattare",
    "ovattar": "ovattare",
    "ovattaron": "ovattare",
    "ovattarono": "ovattare",
    "ovattasse": "ovattare",
    "ovattasser": "ovattare",
    "ovattassero": "ovattare",
    "ovattassi": "ovattare",
    "ovattassimo": "ovattare",
    "ovattaste": "ovattare",
    "ovattasti": "ovattare",
    "ovattata": "ovattare",
    "ovattate": "ovattare",
    "ovattati": "ovattare",
    "ovattato": "ovattare",
    "ovattava": "ovattare",
    "ovattavamo": "ovattare",
    "ovattavan": "ovattare",
    "ovattavano": "ovattare",
    "ovattavate": "ovattare",
    "ovattavi": "ovattare",
    "ovattavo": "ovattare",
    "ovatterai": "ovattare",
    "ovatteran": "ovattare",
    "ovatteranno": "ovattare",
    "ovatterebbe": "ovattare",
    "ovatterebber": "ovattare",
    "ovatterebbero": "ovattare",
    "ovatterei": "ovattare",
    "ovatteremmo": "ovattare",
    "ovatteremo": "ovattare",
    "ovattereste": "ovattare",
    "ovatteresti": "ovattare",
    "ovatterete": "ovattare",
    "ovatterà": "ovattare",
    "ovatterò": "ovattare",
    "ovatti": "ovattare",
    "ovattiamo": "ovattare",
    "ovattiate": "ovattare",
    "ovattin": "ovattare",
    "ovattino": "ovattare",
    "ovatto": "ovattare",
    "ovattò": "ovattare",
    "ovazioni": "ovazione",
    "overdosi": "overdose",
    "ovetti": "ovetto",
    "ovina": "ovino",
    "ovine": "ovino",
    "ovini": "ovino",
    "ovociti": "ovocita",
    "ovulazioni": "ovulazione",
    "ovuli": "ovulo",
    "ovvi": "ovvio",
    "ovvia": "ovvio",
    "ovviai": "ovviare",
    "ovviammo": "ovviare",
    "ovviamo": "ovviare",
    "ovvian": "ovviare",
    "ovviando": "ovviare",
    "ovviano": "ovviare",
    "ovviante": "ovviare",
    "ovvianti": "ovviare",
    "ovviar": "ovviare",
    "ovviaron": "ovviare",
    "ovviarono": "ovviare",
    "ovviasse": "ovviare",
    "ovviasser": "ovviare",
    "ovviassero": "ovviare",
    "ovviassi": "ovviare",
    "ovviassimo": "ovviare",
    "ovviaste": "ovviare",
    "ovviasti": "ovviare",
    "ovviata": "ovviare",
    "ovviate": "ovviare",
    "ovviati": "ovviare",
    "ovviato": "ovviare",
    "ovviava": "ovviare",
    "ovviavamo": "ovviare",
    "ovviavan": "ovviare",
    "ovviavano": "ovviare",
    "ovviavate": "ovviare",
    "ovviavi": "ovviare",
    "ovviavo": "ovviare",
    "ovvie": "ovvio",
    "ovvierai": "ovviare",
    "ovvieran": "ovviare",
    "ovvieranno": "ovviare",
    "ovvierebbe": "ovviare",
    "ovvierebber": "ovviare",
    "ovvierebbero": "ovviare",
    "ovvierei": "ovviare",
    "ovvieremmo": "ovviare",
    "ovvieremo": "ovviare",
    "ovviereste": "ovviare",
    "ovvieresti": "ovviare",
    "ovvierete": "ovviare",
    "ovvierà": "ovviare",
    "ovvierò": "ovviare",
    "ovvii": "ovvio",
    "ovvin": "ovviare",
    "ovvino": "ovviare",
    "ovvio": "ovviare",
    "ovviò": "ovviare",
    "oxfordiana": "oxfordiano",
    "oxfordiane": "oxfordiano",
    "oxfordiani": "oxfordiano",
    "ozi": "ozio",
    "ozia": "oziare",
    "oziai": "oziare",
    "oziammo": "oziare",
    "oziamo": "oziare",
    "ozian": "oziare",
    "oziando": "oziare",
    "oziano": "oziare",
    "oziante": "oziare",
    "ozianti": "oziare",
    "oziar": "oziare",
    "oziaron": "oziare",
    "oziarono": "oziare",
    "oziasse": "oziare",
    "oziasser": "oziare",
    "oziassero": "oziare",
    "oziassi": "oziare",
    "oziassimo": "oziare",
    "oziaste": "oziare",
    "oziasti": "oziare",
    "oziata": "oziare",
    "oziate": "oziare",
    "oziati": "oziare",
    "oziato": "oziare",
    "oziava": "oziare",
    "oziavamo": "oziare",
    "oziavan": "oziare",
    "oziavano": "oziare",
    "oziavate": "oziare",
    "oziavi": "oziare",
    "oziavo": "oziare",
    "ozierai": "oziare",
    "ozieran": "oziare",
    "ozieranno": "oziare",
    "ozierebbe": "oziare",
    "ozierebber": "oziare",
    "ozierebbero": "oziare",
    "ozierei": "oziare",
    "ozieremmo": "oziare",
    "ozieremo": "oziare",
    "oziereste": "oziare",
    "ozieresti": "oziare",
    "ozierete": "oziare",
    "ozierà": "oziare",
    "ozierò": "oziare",
    "ozin": "oziare",
    "ozino": "oziare",
    "ozio": "oziare",
    "oziosa": "ozioso",
    "oziose": "ozioso",
    "oziosi": "ozioso",
    "oziò": "oziare",
    "paca": "pacare",
    "pacai": "pacare",
    "pacammo": "pacare",
    "pacan": "pacare",
    "pacando": "pacare",
    "pacano": "pacare",
    "pacante": "pacare",
    "pacanti": "pacare",
    "pacar": "pacare",
    "pacaron": "pacare",
    "pacarono": "pacare",
    "pacasse": "pacare",
    "pacasser": "pacare",
    "pacassero": "pacare",
    "pacassi": "pacare",
    "pacassimo": "pacare",
    "pacaste": "pacare",
    "pacasti": "pacare",
    "pacata": "pacato",
    "pacate": "pacato",
    "pacatezze": "pacatezza",
    "pacati": "pacato",
    "pacato": "pacare",
    "pacava": "pacare",
    "pacavamo": "pacare",
    "pacavan": "pacare",
    "pacavano": "pacare",
    "pacavate": "pacare",
    "pacavi": "pacare",
    "pacavo": "pacare",
    "pacche": "pacca",
    "pacchetti": "pacchetto",
    "pacchettini": "pacchettino",
    "pacchi": "pacco",
    "pacchiana": "pacchiano",
    "pacchiane": "pacchiano",
    "pacchiani": "pacchiano",
    "paccottiglie": "paccottiglia",
    "paces": "pax",
    "pacherai": "pacare",
    "pacheran": "pacare",
    "pacheranno": "pacare",
    "pacherebbe": "pacare",
    "pacherebber": "pacare",
    "pacherebbero": "pacare",
    "pacherei": "pacare",
    "pacheremmo": "pacare",
    "pacheremo": "pacare",
    "pachereste": "pacare",
    "pacheresti": "pacare",
    "pacherete": "pacare",
    "pacherà": "pacare",
    "pacherò": "pacare",
    "pachi": "pacare",
    "pachiamo": "pacare",
    "pachiate": "pacare",
    "pachidermi": "pachiderma",
    "pachin": "pacare",
    "pachino": "pacare",
    "pachistani": "pachistano",
    "paci": "pace",
    "pacieri": "paciere",
    "pacifica": "pacifico",
    "pacificai": "pacificare",
    "pacificammo": "pacificare",
    "pacifican": "pacificare",
    "pacificando": "pacificare",
    "pacificano": "pacificare",
    "pacificante": "pacificare",
    "pacificanti": "pacificare",
    "pacificar": "pacificare",
    "pacificaron": "pacificare",
    "pacificarono": "pacificare",
    "pacificasse": "pacificare",
    "pacificasser": "pacificare",
    "pacificassero": "pacificare",
    "pacificassi": "pacificare",
    "pacificassimo": "pacificare",
    "pacificaste": "pacificare",
    "pacificasti": "pacificare",
    "pacificata": "pacificare",
    "pacificate": "pacificare",
    "pacificati": "pacificare",
    "pacificato": "pacificare",
    "pacificatori": "pacificatore",
    "pacificatrice": "pacificatore",
    "pacificatrici": "pacificatore",
    "pacificava": "pacificare",
    "pacificavamo": "pacificare",
    "pacificavan": "pacificare",
    "pacificavano": "pacificare",
    "pacificavate": "pacificare",
    "pacificavi": "pacificare",
    "pacificavo": "pacificare",
    "pacificazioni": "pacificazione",
    "pacifiche": "pacifico",
    "pacificherai": "pacificare",
    "pacificheran": "pacificare",
    "pacificheranno": "pacificare",
    "pacificherebbe": "pacificare",
    "pacificherebber": "pacificare",
    "pacificherebbero": "pacificare",
    "pacificherei": "pacificare",
    "pacificheremmo": "pacificare",
    "pacificheremo": "pacificare",
    "pacifichereste": "pacificare",
    "pacificheresti": "pacificare",
    "pacificherete": "pacificare",
    "pacificherà": "pacificare",
    "pacificherò": "pacificare",
    "pacifichi": "pacificare",
    "pacifichiamo": "pacificare",
    "pacifichiate": "pacificare",
    "pacifichin": "pacificare",
    "pacifichino": "pacificare",
    "pacifici": "pacifico",
    "pacifico": "pacificare",
    "pacificò": "pacificare",
    "pacifismi": "pacifismo",
    "pacifiste": "pacifista",
    "pacifisti": "pacifista",
    "paciosa": "pacioso",
    "paciose": "pacioso",
    "paciosi": "pacioso",
    "paco": "pacare",
    "pacò": "pacare",
    "padana": "padano",
    "padane": "padano",
    "padani": "padano",
    "padelle": "padella",
    "padelloni": "padellone",
    "padiglioni": "padiglione",
    "padovana": "padovano",
    "padovane": "padovano",
    "padovani": "padovano",
    "padreterni": "padreterno",
    "padri": "padre",
    "padri-padroni": "padre-padrone",
    "padrinaggi": "padrinaggio",
    "padrini": "padrino",
    "padronali": "padronale",
    "padronanze": "padronanza",
    "padronati": "padronato",
    "padroncini": "padroncino",
    "padrone": "padrona",
    "padroneggerai": "padroneggiare",
    "padroneggeran": "padroneggiare",
    "padroneggeranno": "padroneggiare",
    "padroneggerebbe": "padroneggiare",
    "padroneggerebber": "padroneggiare",
    "padroneggerebbero": "padroneggiare",
    "padroneggerei": "padroneggiare",
    "padroneggeremmo": "padroneggiare",
    "padroneggeremo": "padroneggiare",
    "padroneggereste": "padroneggiare",
    "padroneggeresti": "padroneggiare",
    "padroneggerete": "padroneggiare",
    "padroneggerà": "padroneggiare",
    "padroneggerò": "padroneggiare",
    "padroneggi": "padroneggiare",
    "padroneggia": "padroneggiare",
    "padroneggiai": "padroneggiare",
    "padroneggiammo": "padroneggiare",
    "padroneggiamo": "padroneggiare",
    "padroneggian": "padroneggiare",
    "padroneggiando": "padroneggiare",
    "padroneggiano": "padroneggiare",
    "padroneggiante": "padroneggiare",
    "padroneggianti": "padroneggiare",
    "padroneggiar": "padroneggiare",
    "padroneggiaron": "padroneggiare",
    "padroneggiarono": "padroneggiare",
    "padroneggiasse": "padroneggiare",
    "padroneggiasser": "padroneggiare",
    "padroneggiassero": "padroneggiare",
    "padroneggiassi": "padroneggiare",
    "padroneggiassimo": "padroneggiare",
    "padroneggiaste": "padroneggiare",
    "padroneggiasti": "padroneggiare",
    "padroneggiata": "padroneggiare",
    "padroneggiate": "padroneggiare",
    "padroneggiati": "padroneggiare",
    "padroneggiato": "padroneggiare",
    "padroneggiava": "padroneggiare",
    "padroneggiavamo": "padroneggiare",
    "padroneggiavan": "padroneggiare",
    "padroneggiavano": "padroneggiare",
    "padroneggiavate": "padroneggiare",
    "padroneggiavi": "padroneggiare",
    "padroneggiavo": "padroneggiare",
    "padroneggin": "padroneggiare",
    "padroneggino": "padroneggiare",
    "padroneggio": "padroneggiare",
    "padroneggiò": "padroneggiare",
    "padroni": "padrone",
    "paesaggi": "paesaggio",
    "paesaggisti": "paesaggista",
    "paesaggistica": "paesaggistico",
    "paesaggistiche": "paesaggistico",
    "paesaggistici": "paesaggistico",
    "paesana": "paesano",
    "paesane": "paesano",
    "paesani": "paesano",
    "paeselli": "paesello",
    "paesetti": "paesetto",
    "paesi": "paese",
    "paesini": "paesino",
    "paesistica": "paesistico",
    "paesistiche": "paesistico",
    "paesistici": "paesistico",
    "paesoni": "paesone",
    "paesotti": "paesotto",
    "paffuta": "paffuto",
    "paffute": "paffuto",
    "paffuti": "paffuto",
    "paga": "pago",
    "pagabili": "pagabile",
    "pagai": "pagare",
    "pagamenti": "pagamento",
    "pagammo": "pagare",
    "pagan": "pagare",
    "pagana": "pagano",
    "pagando": "pagare",
    "pagane": "pagano",
    "paganeggerai": "paganeggiare",
    "paganeggeran": "paganeggiare",
    "paganeggeranno": "paganeggiare",
    "paganeggerebbe": "paganeggiare",
    "paganeggerebber": "paganeggiare",
    "paganeggerebbero": "paganeggiare",
    "paganeggerei": "paganeggiare",
    "paganeggeremmo": "paganeggiare",
    "paganeggeremo": "paganeggiare",
    "paganeggereste": "paganeggiare",
    "paganeggeresti": "paganeggiare",
    "paganeggerete": "paganeggiare",
    "paganeggerà": "paganeggiare",
    "paganeggerò": "paganeggiare",
    "paganeggi": "paganeggiare",
    "paganeggia": "paganeggiare",
    "paganeggiai": "paganeggiare",
    "paganeggiammo": "paganeggiare",
    "paganeggiamo": "paganeggiare",
    "paganeggian": "paganeggiare",
    "paganeggiando": "paganeggiare",
    "paganeggiano": "paganeggiare",
    "paganeggiante": "paganeggiare",
    "paganeggianti": "paganeggiare",
    "paganeggiar": "paganeggiare",
    "paganeggiaron": "paganeggiare",
    "paganeggiarono": "paganeggiare",
    "paganeggiasse": "paganeggiare",
    "paganeggiasser": "paganeggiare",
    "paganeggiassero": "paganeggiare",
    "paganeggiassi": "paganeggiare",
    "paganeggiassimo": "paganeggiare",
    "paganeggiaste": "paganeggiare",
    "paganeggiasti": "paganeggiare",
    "paganeggiata": "paganeggiare",
    "paganeggiate": "paganeggiare",
    "paganeggiati": "paganeggiare",
    "paganeggiato": "paganeggiare",
    "paganeggiava": "paganeggiare",
    "paganeggiavamo": "paganeggiare",
    "paganeggiavan": "paganeggiare",
    "paganeggiavano": "paganeggiare",
    "paganeggiavate": "paganeggiare",
    "paganeggiavi": "paganeggiare",
    "paganeggiavo": "paganeggiare",
    "paganeggin": "paganeggiare",
    "paganeggino": "paganeggiare",
    "paganeggio": "paganeggiare",
    "paganeggiò": "paganeggiare",
    "paganesimi": "paganesimo",
    "pagani": "pagano",
    "pagano": "pagare",
    "pagante": "pagare",
    "paganti": "pagare",
    "pagar": "pagare",
    "pagaron": "pagare",
    "pagarono": "pagare",
    "pagasse": "pagare",
    "pagasser": "pagare",
    "pagassero": "pagare",
    "pagassi": "pagare",
    "pagassimo": "pagare",
    "pagaste": "pagare",
    "pagasti": "pagare",
    "pagata": "pagare",
    "pagate": "pagare",
    "pagati": "pagare",
    "pagato": "pagare",
    "pagatori": "pagatore",
    "pagatrice": "pagatore",
    "pagatrici": "pagatore",
    "pagava": "pagare",
    "pagavamo": "pagare",
    "pagavan": "pagare",
    "pagavano": "pagare",
    "pagavate": "pagare",
    "pagavi": "pagare",
    "pagavo": "pagare",
    "pagelle": "pagella",
    "pages": "page",
    "paggetti": "paggetto",
    "paggi": "paggio",
    "paghe": "pago",
    "pagherai": "pagare",
    "pagheran": "pagare",
    "pagheranno": "pagare",
    "pagherebbe": "pagare",
    "pagherebber": "pagare",
    "pagherebbero": "pagare",
    "pagherei": "pagare",
    "pagheremmo": "pagare",
    "pagheremo": "pagare",
    "paghereste": "pagare",
    "pagheresti": "pagare",
    "pagherete": "pagare",
    "pagherà": "pagare",
    "pagherò": "pagare",
    "paghi": "pago",
    "paghiamo": "pagare",
    "paghiate": "pagare",
    "paghin": "pagare",
    "paghino": "pagare",
    "pagine": "pagina",
    "paginette": "paginetta",
    "paginoni": "paginone",
    "pagliacci": "pagliaccio",
    "pagliacciate": "pagliacciata",
    "pagliai": "pagliaio",
    "paglie": "paglia",
    "pagliericci": "pagliericcio",
    "paglierina": "paglierino",
    "paglierine": "paglierino",
    "paglierini": "paglierino",
    "pagliuzze": "pagliuzza",
    "pagnotte": "pagnotta",
    "pago": "pagare",
    "pagode": "pagoda",
    "pagò": "pagare",
    "paia": "parere",
    "paiamo": "parere",
    "paian": "parere",
    "paiano": "parere",
    "paiate": "parere",
    "paillettes": "paillette",
    "paio": "parere",
    "paion": "parere",
    "paiono": "parere",
    "pakistana": "pakistano",
    "pakistane": "pakistano",
    "pakistani": "pakistano",
    "pala": "palare",
    "paladini": "paladino",
    "palafitte": "palafitta",
    "palai": "palare",
    "palammo": "palare",
    "palan": "palare",
    "palando": "palare",
    "palandrane": "palandrana",
    "palano": "palare",
    "palante": "palare",
    "palanti": "palare",
    "palar": "palare",
    "palaron": "palare",
    "palarono": "palare",
    "palasse": "palare",
    "palasser": "palare",
    "palassero": "palare",
    "palassi": "palare",
    "palassimo": "palare",
    "palaste": "palare",
    "palasti": "palare",
    "palata": "palare",
    "palate": "palare",
    "palati": "palato",
    "palatina": "palatino",
    "palatine": "palatino",
    "palatini": "palatino",
    "palato": "palare",
    "palava": "palare",
    "palavamo": "palare",
    "palavan": "palare",
    "palavano": "palare",
    "palavate": "palare",
    "palavi": "palare",
    "palavo": "palare",
    "palazzacci": "palazzaccio",
    "palazzetti": "palazzetto",
    "palazzi": "palazzo",
    "palazzinari": "palazzinaro",
    "palazzine": "palazzina",
    "palazzoni": "palazzone",
    "palazzotti": "palazzotto",
    "palchetti": "palchetto",
    "palchi": "palco",
    "palcoscenici": "palcoscenico",
    "pale": "pala",
    "paleoantropologi": "paleoantropologo",
    "paleolitica": "paleolitico",
    "paleolitiche": "paleolitico",
    "paleolitici": "paleolitico",
    "paleontologi": "paleontologo",
    "palerai": "palare",
    "paleran": "palare",
    "paleranno": "palare",
    "palerebbe": "palare",
    "palerebber": "palare",
    "palerebbero": "palare",
    "palerei": "palare",
    "paleremmo": "palare",
    "paleremo": "palare",
    "palereste": "palare",
    "paleresti": "palare",
    "palerete": "palare",
    "palermitana": "palermitano",
    "palermitane": "palermitano",
    "palermitani": "palermitano",
    "palerà": "palare",
    "palerò": "palare",
    "palesa": "palesare",
    "palesai": "palesare",
    "palesammo": "palesare",
    "palesan": "palesare",
    "palesando": "palesare",
    "palesano": "palesare",
    "palesante": "palesare",
    "palesanti": "palesare",
    "palesar": "palesare",
    "palesaron": "palesare",
    "palesarono": "palesare",
    "palesasse": "palesare",
    "palesasser": "palesare",
    "palesassero": "palesare",
    "palesassi": "palesare",
    "palesassimo": "palesare",
    "palesaste": "palesare",
    "palesasti": "palesare",
    "palesata": "palesare",
    "palesate": "palesare",
    "palesati": "palesare",
    "palesato": "palesare",
    "palesava": "palesare",
    "palesavamo": "palesare",
    "palesavan": "palesare",
    "palesavano": "palesare",
    "palesavate": "palesare",
    "palesavi": "palesare",
    "palesavo": "palesare",
    "paleserai": "palesare",
    "paleseran": "palesare",
    "paleseranno": "palesare",
    "paleserebbe": "palesare",
    "paleserebber": "palesare",
    "paleserebbero": "palesare",
    "paleserei": "palesare",
    "paleseremmo": "palesare",
    "paleseremo": "palesare",
    "palesereste": "palesare",
    "paleseresti": "palesare",
    "paleserete": "palesare",
    "paleserà": "palesare",
    "paleserò": "palesare",
    "palesi": "palese",
    "palesiamo": "palesare",
    "palesiate": "palesare",
    "palesin": "palesare",
    "palesino": "palesare",
    "paleso": "palesare",
    "palestinesi": "palestinese",
    "palestre": "palestra",
    "palesò": "palesare",
    "palette": "paletta",
    "paletti": "paletto",
    "pali": "palo",
    "paliamo": "palare",
    "paliate": "palare",
    "palin": "palare",
    "palino": "palare",
    "palinsensti": "palinsensto",
    "palinsesti": "palinsesto",
    "palizzate": "palizzata",
    "pallada": "pallado",
    "pallade": "pallado",
    "palladi": "pallado",
    "palladia": "palladio",
    "palladie": "palladio",
    "pallanuotisti": "pallanuotista",
    "pallate": "pallata",
    "pallavoliste": "pallavolista",
    "pallavolisti": "pallavolista",
    "palle": "palla",
    "palle-gol": "palla-gol",
    "palleggerai": "palleggiare",
    "palleggeran": "palleggiare",
    "palleggeranno": "palleggiare",
    "palleggerebbe": "palleggiare",
    "palleggerebber": "palleggiare",
    "palleggerebbero": "palleggiare",
    "palleggerei": "palleggiare",
    "palleggeremmo": "palleggiare",
    "palleggeremo": "palleggiare",
    "palleggereste": "palleggiare",
    "palleggeresti": "palleggiare",
    "palleggerete": "palleggiare",
    "palleggerà": "palleggiare",
    "palleggerò": "palleggiare",
    "palleggi": "palleggio",
    "palleggia": "palleggiare",
    "palleggiai": "palleggiare",
    "palleggiamenti": "palleggiamento",
    "palleggiammo": "palleggiare",
    "palleggiamo": "palleggiare",
    "palleggian": "palleggiare",
    "palleggiando": "palleggiare",
    "palleggiano": "palleggiare",
    "palleggiante": "palleggiare",
    "palleggianti": "palleggiare",
    "palleggiar": "palleggiare",
    "palleggiaron": "palleggiare",
    "palleggiarono": "palleggiare",
    "palleggiasse": "palleggiare",
    "palleggiasser": "palleggiare",
    "palleggiassero": "palleggiare",
    "palleggiassi": "palleggiare",
    "palleggiassimo": "palleggiare",
    "palleggiaste": "palleggiare",
    "palleggiasti": "palleggiare",
    "palleggiata": "palleggiare",
    "palleggiate": "palleggiare",
    "palleggiati": "palleggiare",
    "palleggiato": "palleggiare",
    "palleggiatori": "palleggiatore",
    "palleggiava": "palleggiare",
    "palleggiavamo": "palleggiare",
    "palleggiavan": "palleggiare",
    "palleggiavano": "palleggiare",
    "palleggiavate": "palleggiare",
    "palleggiavi": "palleggiare",
    "palleggiavo": "palleggiare",
    "palleggin": "palleggiare",
    "palleggino": "palleggiare",
    "palleggio": "palleggiare",
    "palleggiò": "palleggiare",
    "pallettoni": "pallettone",
    "palli": "palliare",
    "pallia": "palliare",
    "palliai": "palliare",
    "palliammo": "palliare",
    "palliamo": "palliare",
    "pallian": "palliare",
    "palliando": "palliare",
    "palliano": "palliare",
    "palliante": "palliare",
    "pallianti": "palliare",
    "palliar": "palliare",
    "palliaron": "palliare",
    "palliarono": "palliare",
    "palliasse": "palliare",
    "palliasser": "palliare",
    "palliassero": "palliare",
    "palliassi": "palliare",
    "palliassimo": "palliare",
    "palliaste": "palliare",
    "palliasti": "palliare",
    "palliata": "palliare",
    "palliate": "palliare",
    "palliati": "palliare",
    "palliativi": "palliativo",
    "palliato": "palliare",
    "palliava": "palliare",
    "palliavamo": "palliare",
    "palliavan": "palliare",
    "palliavano": "palliare",
    "palliavate": "palliare",
    "palliavi": "palliare",
    "palliavo": "palliare",
    "pallida": "pallido",
    "pallide": "pallido",
    "pallidi": "pallido",
    "pallierai": "palliare",
    "pallieran": "palliare",
    "pallieranno": "palliare",
    "pallierebbe": "palliare",
    "pallierebber": "palliare",
    "pallierebbero": "palliare",
    "pallierei": "palliare",
    "pallieremmo": "palliare",
    "pallieremo": "palliare",
    "palliereste": "palliare",
    "pallieresti": "palliare",
    "pallierete": "palliare",
    "pallierà": "palliare",
    "pallierò": "palliare",
    "pallin": "palliare",
    "palline": "pallina",
    "pallini": "pallino",
    "pallino": "palliare",
    "pallio": "palliare",
    "palliò": "palliare",
    "pallonate": "pallonata",
    "palloncini": "palloncino",
    "pallonetti": "pallonetto",
    "palloni": "pallone",
    "pallori": "pallore",
    "pallottole": "pallottola",
    "pallottolieri": "pallottoliere",
    "palme": "palma",
    "palmeti": "palmeto",
    "palmi": "palmo",
    "palmizi": "palmizio",
    "palo": "palare",
    "palombari": "palombaro",
    "palombelle": "palombella",
    "palpa": "palpare",
    "palpabili": "palpabile",
    "palpai": "palpare",
    "palpammo": "palpare",
    "palpan": "palpare",
    "palpando": "palpare",
    "palpano": "palpare",
    "palpante": "palpare",
    "palpanti": "palpare",
    "palpar": "palpare",
    "palparon": "palpare",
    "palparono": "palpare",
    "palpasse": "palpare",
    "palpasser": "palpare",
    "palpassero": "palpare",
    "palpassi": "palpare",
    "palpassimo": "palpare",
    "palpaste": "palpare",
    "palpasti": "palpare",
    "palpata": "palpare",
    "palpate": "palpare",
    "palpati": "palpare",
    "palpato": "palpare",
    "palpava": "palpare",
    "palpavamo": "palpare",
    "palpavan": "palpare",
    "palpavano": "palpare",
    "palpavate": "palpare",
    "palpavi": "palpare",
    "palpavo": "palpare",
    "palpebre": "palpebra",
    "palpeggerai": "palpeggiare",
    "palpeggeran": "palpeggiare",
    "palpeggeranno": "palpeggiare",
    "palpeggerebbe": "palpeggiare",
    "palpeggerebber": "palpeggiare",
    "palpeggerebbero": "palpeggiare",
    "palpeggerei": "palpeggiare",
    "palpeggeremmo": "palpeggiare",
    "palpeggeremo": "palpeggiare",
    "palpeggereste": "palpeggiare",
    "palpeggeresti": "palpeggiare",
    "palpeggerete": "palpeggiare",
    "palpeggerà": "palpeggiare",
    "palpeggerò": "palpeggiare",
    "palpeggi": "palpeggiare",
    "palpeggia": "palpeggiare",
    "palpeggiai": "palpeggiare",
    "palpeggiamenti": "palpeggiamento",
    "palpeggiammo": "palpeggiare",
    "palpeggiamo": "palpeggiare",
    "palpeggian": "palpeggiare",
    "palpeggiando": "palpeggiare",
    "palpeggiano": "palpeggiare",
    "palpeggiante": "palpeggiare",
    "palpeggianti": "palpeggiare",
    "palpeggiar": "palpeggiare",
    "palpeggiaron": "palpeggiare",
    "palpeggiarono": "palpeggiare",
    "palpeggiasse": "palpeggiare",
    "palpeggiasser": "palpeggiare",
    "palpeggiassero": "palpeggiare",
    "palpeggiassi": "palpeggiare",
    "palpeggiassimo": "palpeggiare",
    "palpeggiaste": "palpeggiare",
    "palpeggiasti": "palpeggiare",
    "palpeggiata": "palpeggiare",
    "palpeggiate": "palpeggiare",
    "palpeggiati": "palpeggiare",
    "palpeggiato": "palpeggiare",
    "palpeggiava": "palpeggiare",
    "palpeggiavamo": "palpeggiare",
    "palpeggiavan": "palpeggiare",
    "palpeggiavano": "palpeggiare",
    "palpeggiavate": "palpeggiare",
    "palpeggiavi": "palpeggiare",
    "palpeggiavo": "palpeggiare",
    "palpeggin": "palpeggiare",
    "palpeggino": "palpeggiare",
    "palpeggio": "palpeggiare",
    "palpeggiò": "palpeggiare",
    "palperai": "palpare",
    "palperan": "palpare",
    "palperanno": "palpare",
    "palperebbe": "palpare",
    "palperebber": "palpare",
    "palperebbero": "palpare",
    "palperei": "palpare",
    "palperemmo": "palpare",
    "palperemo": "palpare",
    "palpereste": "palpare",
    "palperesti": "palpare",
    "palperete": "palpare",
    "palperà": "palpare",
    "palperò": "palpare",
    "palpi": "palpare",
    "palpiamo": "palpare",
    "palpiate": "palpare",
    "palpin": "palpare",
    "palpino": "palpare",
    "palpita": "palpitare",
    "palpitai": "palpitare",
    "palpitammo": "palpitare",
    "palpitan": "palpitare",
    "palpitando": "palpitare",
    "palpitano": "palpitare",
    "palpitante": "palpitare",
    "palpitanti": "palpitare",
    "palpitar": "palpitare",
    "palpitaron": "palpitare",
    "palpitarono": "palpitare",
    "palpitasse": "palpitare",
    "palpitasser": "palpitare",
    "palpitassero": "palpitare",
    "palpitassi": "palpitare",
    "palpitassimo": "palpitare",
    "palpitaste": "palpitare",
    "palpitasti": "palpitare",
    "palpitata": "palpitare",
    "palpitate": "palpitare",
    "palpitati": "palpitare",
    "palpitato": "palpitare",
    "palpitava": "palpitare",
    "palpitavamo": "palpitare",
    "palpitavan": "palpitare",
    "palpitavano": "palpitare",
    "palpitavate": "palpitare",
    "palpitavi": "palpitare",
    "palpitavo": "palpitare",
    "palpitazioni": "palpitazione",
    "palpiterai": "palpitare",
    "palpiteran": "palpitare",
    "palpiteranno": "palpitare",
    "palpiterebbe": "palpitare",
    "palpiterebber": "palpitare",
    "palpiterebbero": "palpitare",
    "palpiterei": "palpitare",
    "palpiteremmo": "palpitare",
    "palpiteremo": "palpitare",
    "palpitereste": "palpitare",
    "palpiteresti": "palpitare",
    "palpiterete": "palpitare",
    "palpiterà": "palpitare",
    "palpiterò": "palpitare",
    "palpiti": "palpito",
    "palpitiamo": "palpitare",
    "palpitiate": "palpitare",
    "palpitin": "palpitare",
    "palpitino": "palpitare",
    "palpito": "palpitare",
    "palpitò": "palpitare",
    "palpo": "palpare",
    "palpò": "palpare",
    "paluda": "paludare",
    "paludai": "paludare",
    "paludamenti": "paludamento",
    "paludammo": "paludare",
    "paludan": "paludare",
    "paludando": "paludare",
    "paludano": "paludare",
    "paludante": "paludare",
    "paludanti": "paludare",
    "paludar": "paludare",
    "paludaron": "paludare",
    "paludarono": "paludare",
    "paludasse": "paludare",
    "paludasser": "paludare",
    "paludassero": "paludare",
    "paludassi": "paludare",
    "paludassimo": "paludare",
    "paludaste": "paludare",
    "paludasti": "paludare",
    "paludata": "paludato",
    "paludate": "paludato",
    "paludati": "paludato",
    "paludato": "paludare",
    "paludava": "paludare",
    "paludavamo": "paludare",
    "paludavan": "paludare",
    "paludavano": "paludare",
    "paludavate": "paludare",
    "paludavi": "paludare",
    "paludavo": "paludare",
    "paluderai": "paludare",
    "paluderan": "paludare",
    "paluderanno": "paludare",
    "paluderebbe": "paludare",
    "paluderebber": "paludare",
    "paluderebbero": "paludare",
    "paluderei": "paludare",
    "paluderemmo": "paludare",
    "paluderemo": "paludare",
    "paludereste": "paludare",
    "paluderesti": "paludare",
    "paluderete": "paludare",
    "paluderà": "paludare",
    "paluderò": "paludare",
    "paludi": "palude",
    "paludiamo": "paludare",
    "paludiate": "paludare",
    "paludin": "paludare",
    "paludino": "paludare",
    "paludo": "paludare",
    "paludosa": "paludoso",
    "paludose": "paludoso",
    "paludosi": "paludoso",
    "paludò": "paludare",
    "palustri": "palustre",
    "palò": "palare",
    "pampas": "pampa",
    "pana": "panare",
    "panacee": "panacea",
    "panai": "panare",
    "panamensi": "panamense",
    "panammo": "panare",
    "panan": "panare",
    "panando": "panare",
    "panano": "panare",
    "panante": "panare",
    "pananti": "panare",
    "panar": "panare",
    "panarabismi": "panarabismo",
    "panaron": "panare",
    "panarono": "panare",
    "panasse": "panare",
    "panasser": "panare",
    "panassero": "panare",
    "panassi": "panare",
    "panassimo": "panare",
    "panaste": "panare",
    "panasti": "panare",
    "panata": "panare",
    "panate": "panare",
    "panati": "panare",
    "panato": "panare",
    "panava": "panare",
    "panavamo": "panare",
    "panavan": "panare",
    "panavano": "panare",
    "panavate": "panare",
    "panavi": "panare",
    "panavo": "panare",
    "pance": "pancia",
    "pancette": "pancetta",
    "panche": "panca",
    "panchinari": "panchinaro",
    "panchine": "panchina",
    "pancini": "pancino",
    "pancioni": "pancione",
    "panciotti": "panciotto",
    "pandemoni": "pandemonio",
    "panegirici": "panegirico",
    "panerai": "panare",
    "paneran": "panare",
    "paneranno": "panare",
    "panerebbe": "panare",
    "panerebber": "panare",
    "panerebbero": "panare",
    "panerei": "panare",
    "paneremmo": "panare",
    "paneremo": "panare",
    "panereste": "panare",
    "paneresti": "panare",
    "panerete": "panare",
    "panerà": "panare",
    "panerò": "panare",
    "panetterie": "panetteria",
    "panettieri": "panettiere",
    "panettoni": "panettone",
    "paneuropea": "paneuropeo",
    "paneuropee": "paneuropeo",
    "paneuropei": "paneuropeo",
    "panfili": "panfilo",
    "pani": "pane",
    "paniamo": "panare",
    "paniate": "panare",
    "panica": "panico",
    "paniche": "panico",
    "panici": "panico",
    "panie": "pania",
    "panieri": "paniere",
    "panifica": "panificare",
    "panificai": "panificare",
    "panificammo": "panificare",
    "panifican": "panificare",
    "panificando": "panificare",
    "panificano": "panificare",
    "panificante": "panificare",
    "panificanti": "panificare",
    "panificar": "panificare",
    "panificaron": "panificare",
    "panificarono": "panificare",
    "panificasse": "panificare",
    "panificasser": "panificare",
    "panificassero": "panificare",
    "panificassi": "panificare",
    "panificassimo": "panificare",
    "panificaste": "panificare",
    "panificasti": "panificare",
    "panificata": "panificare",
    "panificate": "panificare",
    "panificati": "panificare",
    "panificato": "panificare",
    "panificava": "panificare",
    "panificavamo": "panificare",
    "panificavan": "panificare",
    "panificavano": "panificare",
    "panificavate": "panificare",
    "panificavi": "panificare",
    "panificavo": "panificare",
    "panificherai": "panificare",
    "panificheran": "panificare",
    "panificheranno": "panificare",
    "panificherebbe": "panificare",
    "panificherebber": "panificare",
    "panificherebbero": "panificare",
    "panificherei": "panificare",
    "panificheremmo": "panificare",
    "panificheremo": "panificare",
    "panifichereste": "panificare",
    "panificheresti": "panificare",
    "panificherete": "panificare",
    "panificherà": "panificare",
    "panificherò": "panificare",
    "panifichi": "panificare",
    "panifichiamo": "panificare",
    "panifichiate": "panificare",
    "panifichin": "panificare",
    "panifichino": "panificare",
    "panifici": "panificio",
    "panifico": "panificare",
    "panificò": "panificare",
    "panin": "panare",
    "paninari": "paninaro",
    "panini": "panino",
    "panino": "panare",
    "paninoteche": "paninoteca",
    "panne": "panna",
    "panneggerai": "panneggiare",
    "panneggeran": "panneggiare",
    "panneggeranno": "panneggiare",
    "panneggerebbe": "panneggiare",
    "panneggerebber": "panneggiare",
    "panneggerebbero": "panneggiare",
    "panneggerei": "panneggiare",
    "panneggeremmo": "panneggiare",
    "panneggeremo": "panneggiare",
    "panneggereste": "panneggiare",
    "panneggeresti": "panneggiare",
    "panneggerete": "panneggiare",
    "panneggerà": "panneggiare",
    "panneggerò": "panneggiare",
    "panneggi": "panneggio",
    "panneggia": "panneggiare",
    "panneggiai": "panneggiare",
    "panneggiammo": "panneggiare",
    "panneggiamo": "panneggiare",
    "panneggian": "panneggiare",
    "panneggiando": "panneggiare",
    "panneggiano": "panneggiare",
    "panneggiante": "panneggiare",
    "panneggianti": "panneggiare",
    "panneggiar": "panneggiare",
    "panneggiaron": "panneggiare",
    "panneggiarono": "panneggiare",
    "panneggiasse": "panneggiare",
    "panneggiasser": "panneggiare",
    "panneggiassero": "panneggiare",
    "panneggiassi": "panneggiare",
    "panneggiassimo": "panneggiare",
    "panneggiaste": "panneggiare",
    "panneggiasti": "panneggiare",
    "panneggiata": "panneggiare",
    "panneggiate": "panneggiare",
    "panneggiati": "panneggiare",
    "panneggiato": "panneggiare",
    "panneggiava": "panneggiare",
    "panneggiavamo": "panneggiare",
    "panneggiavan": "panneggiare",
    "panneggiavano": "panneggiare",
    "panneggiavate": "panneggiare",
    "panneggiavi": "panneggiare",
    "panneggiavo": "panneggiare",
    "panneggin": "panneggiare",
    "panneggino": "panneggiare",
    "panneggio": "panneggiare",
    "panneggiò": "panneggiare",
    "pannelli": "pannello",
    "pannelliana": "pannelliano",
    "pannelliane": "pannelliano",
    "pannelliani": "pannelliano",
    "panni": "panno",
    "pannicelli": "pannicello",
    "pannocchie": "pannocchia",
    "pannolini": "pannolino",
    "pannoloni": "pannolone",
    "pano": "panare",
    "panorami": "panorama",
    "panoramica": "panoramico",
    "panoramiche": "panoramico",
    "panoramici": "panoramico",
    "pantagruelica": "pantagruelico",
    "pantagrueliche": "pantagruelico",
    "pantagruelici": "pantagruelico",
    "pantaloncini": "pantaloncino",
    "pantaloni": "pantalone",
    "pantani": "pantano",
    "pantegane": "pantegana",
    "pantere": "pantera",
    "pantofole": "pantofola",
    "pantografi": "pantografo",
    "pantomime": "pantomima",
    "pantomimica": "pantomimico",
    "pantomimiche": "pantomimico",
    "pantomimici": "pantomimico",
    "panzane": "panzana",
    "panò": "panare",
    "paonazza": "paonazzo",
    "paonazze": "paonazzo",
    "paonazzi": "paonazzo",
    "papabili": "papabile",
    "papali": "papale",
    "papalina": "papalino",
    "papaline": "papalino",
    "papalini": "papalino",
    "paparazzi": "paparazzo",
    "papati": "papato",
    "papaveri": "papavero",
    "papere": "papera",
    "paperi": "papero",
    "paperoni": "paperone",
    "papi": "papa",
    "papilla": "papillare",
    "papillai": "papillare",
    "papillammo": "papillare",
    "papillan": "papillare",
    "papillando": "papillare",
    "papillano": "papillare",
    "papillante": "papillare",
    "papillanti": "papillare",
    "papillar": "papillare",
    "papillaron": "papillare",
    "papillarono": "papillare",
    "papillasse": "papillare",
    "papillasser": "papillare",
    "papillassero": "papillare",
    "papillassi": "papillare",
    "papillassimo": "papillare",
    "papillaste": "papillare",
    "papillasti": "papillare",
    "papillata": "papillare",
    "papillate": "papillare",
    "papillati": "papillare",
    "papillato": "papillare",
    "papillava": "papillare",
    "papillavamo": "papillare",
    "papillavan": "papillare",
    "papillavano": "papillare",
    "papillavate": "papillare",
    "papillavi": "papillare",
    "papillavo": "papillare",
    "papillerai": "papillare",
    "papilleran": "papillare",
    "papilleranno": "papillare",
    "papillerebbe": "papillare",
    "papillerebber": "papillare",
    "papillerebbero": "papillare",
    "papillerei": "papillare",
    "papilleremmo": "papillare",
    "papilleremo": "papillare",
    "papillereste": "papillare",
    "papilleresti": "papillare",
    "papillerete": "papillare",
    "papillerà": "papillare",
    "papillerò": "papillare",
    "papilli": "papillare",
    "papilliamo": "papillare",
    "papilliate": "papillare",
    "papillin": "papillare",
    "papillino": "papillare",
    "papillo": "papillare",
    "papillò": "papillare",
    "papiri": "papiro",
    "papocchi": "papocchio",
    "pappa": "pappare",
    "pappagallesca": "pappagallesco",
    "pappagallesche": "pappagallesco",
    "pappagalleschi": "pappagallesco",
    "pappagalli": "pappagallo",
    "pappai": "pappare",
    "pappammo": "pappare",
    "pappan": "pappare",
    "pappando": "pappare",
    "pappano": "pappare",
    "pappante": "pappare",
    "pappanti": "pappare",
    "pappar": "pappare",
    "papparon": "pappare",
    "papparono": "pappare",
    "pappasse": "pappare",
    "pappasser": "pappare",
    "pappassero": "pappare",
    "pappassi": "pappare",
    "pappassimo": "pappare",
    "pappaste": "pappare",
    "pappasti": "pappare",
    "pappata": "pappare",
    "pappate": "pappare",
    "pappati": "pappare",
    "pappato": "pappare",
    "pappava": "pappare",
    "pappavamo": "pappare",
    "pappavan": "pappare",
    "pappavano": "pappare",
    "pappavate": "pappare",
    "pappavi": "pappare",
    "pappavo": "pappare",
    "pappe": "pappa",
    "papperai": "pappare",
    "papperan": "pappare",
    "papperanno": "pappare",
    "papperebbe": "pappare",
    "papperebber": "pappare",
    "papperebbero": "pappare",
    "papperei": "pappare",
    "papperemmo": "pappare",
    "papperemo": "pappare",
    "pappereste": "pappare",
    "papperesti": "pappare",
    "papperete": "pappare",
    "papperà": "pappare",
    "papperò": "pappare",
    "pappi": "pappare",
    "pappiamo": "pappare",
    "pappiate": "pappare",
    "pappin": "pappare",
    "pappino": "pappare",
    "pappo": "pappare",
    "papponi": "pappone",
    "pappò": "pappare",
    "para": "parare",
    "para-militari": "para-militare",
    "parabancari": "parabancario",
    "parabole": "parabola",
    "parabolica": "parabolico",
    "paraboliche": "parabolico",
    "parabolici": "parabolico",
    "paracaduta": "paracadutare",
    "paracadutai": "paracadutare",
    "paracadutammo": "paracadutare",
    "paracadutan": "paracadutare",
    "paracadutando": "paracadutare",
    "paracadutano": "paracadutare",
    "paracadutante": "paracadutare",
    "paracadutanti": "paracadutare",
    "paracadutar": "paracadutare",
    "paracadutaron": "paracadutare",
    "paracadutarono": "paracadutare",
    "paracadutasse": "paracadutare",
    "paracadutasser": "paracadutare",
    "paracadutassero": "paracadutare",
    "paracadutassi": "paracadutare",
    "paracadutassimo": "paracadutare",
    "paracadutaste": "paracadutare",
    "paracadutasti": "paracadutare",
    "paracadutata": "paracadutare",
    "paracadutate": "paracadutare",
    "paracadutati": "paracadutare",
    "paracadutato": "paracadutare",
    "paracadutava": "paracadutare",
    "paracadutavamo": "paracadutare",
    "paracadutavan": "paracadutare",
    "paracadutavano": "paracadutare",
    "paracadutavate": "paracadutare",
    "paracadutavi": "paracadutare",
    "paracadutavo": "paracadutare",
    "paracaduterai": "paracadutare",
    "paracaduteran": "paracadutare",
    "paracaduteranno": "paracadutare",
    "paracaduterebbe": "paracadutare",
    "paracaduterebber": "paracadutare",
    "paracaduterebbero": "paracadutare",
    "paracaduterei": "paracadutare",
    "paracaduteremmo": "paracadutare",
    "paracaduteremo": "paracadutare",
    "paracadutereste": "paracadutare",
    "paracaduteresti": "paracadutare",
    "paracaduterete": "paracadutare",
    "paracaduterà": "paracadutare",
    "paracaduterò": "paracadutare",
    "paracaduti": "paracadutare",
    "paracadutiamo": "paracadutare",
    "paracadutiate": "paracadutare",
    "paracadutin": "paracadutare",
    "paracadutino": "paracadutare",
    "paracadutisti": "paracadutista",
    "paracaduto": "paracadutare",
    "paracadutò": "paracadutare",
    "paracarri": "paracarro",
    "paradigmatica": "paradigmatico",
    "paradigmatiche": "paradigmatico",
    "paradigmatici": "paradigmatico",
    "paradigmi": "paradigma",
    "paradisi": "paradiso",
    "paradisiaca": "paradisiaco",
    "paradisiache": "paradisiaco",
    "paradisiaci": "paradisiaco",
    "paradossali": "paradossale",
    "paradossi": "paradosso",
    "parafa": "parafare",
    "parafai": "parafare",
    "parafammo": "parafare",
    "parafan": "parafare",
    "parafando": "parafare",
    "parafanghi": "parafango",
    "parafano": "parafare",
    "parafante": "parafare",
    "parafanti": "parafare",
    "parafar": "parafare",
    "parafaron": "parafare",
    "parafarono": "parafare",
    "parafasse": "parafare",
    "parafasser": "parafare",
    "parafassero": "parafare",
    "parafassi": "parafare",
    "parafassimo": "parafare",
    "parafaste": "parafare",
    "parafasti": "parafare",
    "parafata": "parafare",
    "parafate": "parafare",
    "parafati": "parafare",
    "parafato": "parafare",
    "parafava": "parafare",
    "parafavamo": "parafare",
    "parafavan": "parafare",
    "parafavano": "parafare",
    "parafavate": "parafare",
    "parafavi": "parafare",
    "parafavo": "parafare",
    "paraferai": "parafare",
    "paraferan": "parafare",
    "paraferanno": "parafare",
    "paraferebbe": "parafare",
    "paraferebber": "parafare",
    "paraferebbero": "parafare",
    "paraferei": "parafare",
    "paraferemmo": "parafare",
    "paraferemo": "parafare",
    "parafereste": "parafare",
    "paraferesti": "parafare",
    "paraferete": "parafare",
    "paraferà": "parafare",
    "paraferò": "parafare",
    "paraffina": "paraffinare",
    "paraffinai": "paraffinare",
    "paraffinammo": "paraffinare",
    "paraffinan": "paraffinare",
    "paraffinando": "paraffinare",
    "paraffinano": "paraffinare",
    "paraffinante": "paraffinare",
    "paraffinanti": "paraffinare",
    "paraffinar": "paraffinare",
    "paraffinaron": "paraffinare",
    "paraffinarono": "paraffinare",
    "paraffinasse": "paraffinare",
    "paraffinasser": "paraffinare",
    "paraffinassero": "paraffinare",
    "paraffinassi": "paraffinare",
    "paraffinassimo": "paraffinare",
    "paraffinaste": "paraffinare",
    "paraffinasti": "paraffinare",
    "paraffinata": "paraffinare",
    "paraffinate": "paraffinare",
    "paraffinati": "paraffinare",
    "paraffinato": "paraffinare",
    "paraffinava": "paraffinare",
    "paraffinavamo": "paraffinare",
    "paraffinavan": "paraffinare",
    "paraffinavano": "paraffinare",
    "paraffinavate": "paraffinare",
    "paraffinavi": "paraffinare",
    "paraffinavo": "paraffinare",
    "paraffine": "paraffina",
    "paraffinerai": "paraffinare",
    "paraffineran": "paraffinare",
    "paraffineranno": "paraffinare",
    "paraffinerebbe": "paraffinare",
    "paraffinerebber": "paraffinare",
    "paraffinerebbero": "paraffinare",
    "paraffinerei": "paraffinare",
    "paraffineremmo": "paraffinare",
    "paraffineremo": "paraffinare",
    "paraffinereste": "paraffinare",
    "paraffineresti": "paraffinare",
    "paraffinerete": "paraffinare",
    "paraffinerà": "paraffinare",
    "paraffinerò": "paraffinare",
    "paraffini": "paraffinare",
    "paraffiniamo": "paraffinare",
    "paraffiniate": "paraffinare",
    "paraffinin": "paraffinare",
    "paraffinino": "paraffinare",
    "paraffino": "paraffinare",
    "paraffinò": "paraffinare",
    "parafi": "parafare",
    "parafiamo": "parafare",
    "parafiate": "parafare",
    "parafin": "parafare",
    "parafino": "parafare",
    "parafiscali": "parafiscale",
    "parafo": "parafare",
    "parafrasa": "parafrasare",
    "parafrasai": "parafrasare",
    "parafrasammo": "parafrasare",
    "parafrasan": "parafrasare",
    "parafrasando": "parafrasare",
    "parafrasano": "parafrasare",
    "parafrasante": "parafrasare",
    "parafrasanti": "parafrasare",
    "parafrasar": "parafrasare",
    "parafrasaron": "parafrasare",
    "parafrasarono": "parafrasare",
    "parafrasasse": "parafrasare",
    "parafrasasser": "parafrasare",
    "parafrasassero": "parafrasare",
    "parafrasassi": "parafrasare",
    "parafrasassimo": "parafrasare",
    "parafrasaste": "parafrasare",
    "parafrasasti": "parafrasare",
    "parafrasata": "parafrasare",
    "parafrasate": "parafrasare",
    "parafrasati": "parafrasare",
    "parafrasato": "parafrasare",
    "parafrasava": "parafrasare",
    "parafrasavamo": "parafrasare",
    "parafrasavan": "parafrasare",
    "parafrasavano": "parafrasare",
    "parafrasavate": "parafrasare",
    "parafrasavi": "parafrasare",
    "parafrasavo": "parafrasare",
    "parafraserai": "parafrasare",
    "parafraseran": "parafrasare",
    "parafraseranno": "parafrasare",
    "parafraserebbe": "parafrasare",
    "parafraserebber": "parafrasare",
    "parafraserebbero": "parafrasare",
    "parafraserei": "parafrasare",
    "parafraseremmo": "parafrasare",
    "parafraseremo": "parafrasare",
    "parafrasereste": "parafrasare",
    "parafraseresti": "parafrasare",
    "parafraserete": "parafrasare",
    "parafraserà": "parafrasare",
    "parafraserò": "parafrasare",
    "parafrasi": "parafrasare",
    "parafrasiamo": "parafrasare",
    "parafrasiate": "parafrasare",
    "parafrasin": "parafrasare",
    "parafrasino": "parafrasare",
    "parafraso": "parafrasare",
    "parafrasò": "parafrasare",
    "parafulmini": "parafulmine",
    "parafò": "parafare",
    "paraggi": "paraggio",
    "paragona": "paragonare",
    "paragonabili": "paragonabile",
    "paragonai": "paragonare",
    "paragonammo": "paragonare",
    "paragonan": "paragonare",
    "paragonando": "paragonare",
    "paragonano": "paragonare",
    "paragonante": "paragonare",
    "paragonanti": "paragonare",
    "paragonar": "paragonare",
    "paragonaron": "paragonare",
    "paragonarono": "paragonare",
    "paragonasse": "paragonare",
    "paragonasser": "paragonare",
    "paragonassero": "paragonare",
    "paragonassi": "paragonare",
    "paragonassimo": "paragonare",
    "paragonaste": "paragonare",
    "paragonasti": "paragonare",
    "paragonata": "paragonare",
    "paragonate": "paragonare",
    "paragonati": "paragonare",
    "paragonato": "paragonare",
    "paragonava": "paragonare",
    "paragonavamo": "paragonare",
    "paragonavan": "paragonare",
    "paragonavano": "paragonare",
    "paragonavate": "paragonare",
    "paragonavi": "paragonare",
    "paragonavo": "paragonare",
    "paragonerai": "paragonare",
    "paragoneran": "paragonare",
    "paragoneranno": "paragonare",
    "paragonerebbe": "paragonare",
    "paragonerebber": "paragonare",
    "paragonerebbero": "paragonare",
    "paragonerei": "paragonare",
    "paragoneremmo": "paragonare",
    "paragoneremo": "paragonare",
    "paragonereste": "paragonare",
    "paragoneresti": "paragonare",
    "paragonerete": "paragonare",
    "paragonerà": "paragonare",
    "paragonerò": "paragonare",
    "paragoni": "paragone",
    "paragoniamo": "paragonare",
    "paragoniate": "paragonare",
    "paragonin": "paragonare",
    "paragonino": "paragonare",
    "paragono": "paragonare",
    "paragonò": "paragonare",
    "paragrafa": "paragrafare",
    "paragrafai": "paragrafare",
    "paragrafammo": "paragrafare",
    "paragrafan": "paragrafare",
    "paragrafando": "paragrafare",
    "paragrafano": "paragrafare",
    "paragrafante": "paragrafare",
    "paragrafanti": "paragrafare",
    "paragrafar": "paragrafare",
    "paragrafaron": "paragrafare",
    "paragrafarono": "paragrafare",
    "paragrafasse": "paragrafare",
    "paragrafasser": "paragrafare",
    "paragrafassero": "paragrafare",
    "paragrafassi": "paragrafare",
    "paragrafassimo": "paragrafare",
    "paragrafaste": "paragrafare",
    "paragrafasti": "paragrafare",
    "paragrafata": "paragrafare",
    "paragrafate": "paragrafare",
    "paragrafati": "paragrafare",
    "paragrafato": "paragrafare",
    "paragrafava": "paragrafare",
    "paragrafavamo": "paragrafare",
    "paragrafavan": "paragrafare",
    "paragrafavano": "paragrafare",
    "paragrafavate": "paragrafare",
    "paragrafavi": "paragrafare",
    "paragrafavo": "paragrafare",
    "paragraferai": "paragrafare",
    "paragraferan": "paragrafare",
    "paragraferanno": "paragrafare",
    "paragraferebbe": "paragrafare",
    "paragraferebber": "paragrafare",
    "paragraferebbero": "paragrafare",
    "paragraferei": "paragrafare",
    "paragraferemmo": "paragrafare",
    "paragraferemo": "paragrafare",
    "paragrafereste": "paragrafare",
    "paragraferesti": "paragrafare",
    "paragraferete": "paragrafare",
    "paragraferà": "paragrafare",
    "paragraferò": "paragrafare",
    "paragrafi": "paragrafo",
    "paragrafiamo": "paragrafare",
    "paragrafiate": "paragrafare",
    "paragrafin": "paragrafare",
    "paragrafino": "paragrafare",
    "paragrafo": "paragrafare",
    "paragrafò": "paragrafare",
    "paraguaiana": "paraguaiano",
    "paraguaiane": "paraguaiano",
    "paraguaiani": "paraguaiano",
    "paraguayani": "paraguayano",
    "parai": "parare",
    "paralitica": "paralitico",
    "paralitiche": "paralitico",
    "paralitici": "paralitico",
    "paralizza": "paralizzare",
    "paralizzai": "paralizzare",
    "paralizzammo": "paralizzare",
    "paralizzan": "paralizzare",
    "paralizzando": "paralizzare",
    "paralizzano": "paralizzare",
    "paralizzante": "paralizzare",
    "paralizzanti": "paralizzare",
    "paralizzar": "paralizzare",
    "paralizzaron": "paralizzare",
    "paralizzarono": "paralizzare",
    "paralizzasse": "paralizzare",
    "paralizzasser": "paralizzare",
    "paralizzassero": "paralizzare",
    "paralizzassi": "paralizzare",
    "paralizzassimo": "paralizzare",
    "paralizzaste": "paralizzare",
    "paralizzasti": "paralizzare",
    "paralizzata": "paralizzato",
    "paralizzate": "paralizzato",
    "paralizzati": "paralizzato",
    "paralizzato": "paralizzare",
    "paralizzava": "paralizzare",
    "paralizzavamo": "paralizzare",
    "paralizzavan": "paralizzare",
    "paralizzavano": "paralizzare",
    "paralizzavate": "paralizzare",
    "paralizzavi": "paralizzare",
    "paralizzavo": "paralizzare",
    "paralizzerai": "paralizzare",
    "paralizzeran": "paralizzare",
    "paralizzeranno": "paralizzare",
    "paralizzerebbe": "paralizzare",
    "paralizzerebber": "paralizzare",
    "paralizzerebbero": "paralizzare",
    "paralizzerei": "paralizzare",
    "paralizzeremmo": "paralizzare",
    "paralizzeremo": "paralizzare",
    "paralizzereste": "paralizzare",
    "paralizzeresti": "paralizzare",
    "paralizzerete": "paralizzare",
    "paralizzerà": "paralizzare",
    "paralizzerò": "paralizzare",
    "paralizzi": "paralizzare",
    "paralizziamo": "paralizzare",
    "paralizziate": "paralizzare",
    "paralizzin": "paralizzare",
    "paralizzino": "paralizzare",
    "paralizzo": "paralizzare",
    "paralizzò": "paralizzare",
    "parallela": "parallelo",
    "parallele": "parallelo",
    "paralleli": "parallelo",
    "parallelismi": "parallelismo",
    "paralumi": "paralume",
    "paramedica": "paramedico",
    "paramediche": "paramedico",
    "paramedici": "paramedico",
    "paramenti": "paramento",
    "parametri": "parametro",
    "paramilitari": "paramilitare",
    "parammo": "parare",
    "paran": "parare",
    "parando": "parare",
    "parano": "parare",
    "paranoica": "paranoico",
    "paranoiche": "paranoico",
    "paranoici": "paranoico",
    "paranoie": "paranoia",
    "paranormali": "paranormale",
    "parante": "parare",
    "paranti": "parare",
    "parapetti": "parapetto",
    "paraplegica": "paraplegico",
    "paraplegiche": "paraplegico",
    "paraplegici": "paraplegico",
    "parapsicologie": "parapsicologia",
    "parar": "parare",
    "pararon": "parare",
    "pararono": "parare",
    "parascolastica": "parascolastico",
    "parascolastiche": "parascolastico",
    "parascolastici": "parascolastico",
    "parasociali": "parasociale",
    "parasse": "parare",
    "parasser": "parare",
    "parassero": "parare",
    "parassi": "parare",
    "parassimo": "parare",
    "parassitari": "parassitario",
    "parassitaria": "parassitario",
    "parassitarie": "parassitario",
    "parassite": "parassita",
    "parassiti": "parassita",
    "parassitismi": "parassitismo",
    "parastatali": "parastatale",
    "parastati": "parastato",
    "paraste": "parare",
    "parasti": "parare",
    "parastinchi": "parastinco",
    "parata": "parato",
    "parate": "parato",
    "parati": "parato",
    "paratie": "paratia",
    "parato": "parare",
    "parava": "parare",
    "paravamo": "parare",
    "paravan": "parare",
    "paravano": "parare",
    "paravate": "parare",
    "paraventi": "paravento",
    "paravi": "parare",
    "paravo": "parare",
    "parca": "parco",
    "parcai": "parcare",
    "parcammo": "parcare",
    "parcan": "parcare",
    "parcando": "parcare",
    "parcano": "parcare",
    "parcante": "parcare",
    "parcanti": "parcare",
    "parcar": "parcare",
    "parcaron": "parcare",
    "parcarono": "parcare",
    "parcasse": "parcare",
    "parcasser": "parcare",
    "parcassero": "parcare",
    "parcassi": "parcare",
    "parcassimo": "parcare",
    "parcaste": "parcare",
    "parcasti": "parcare",
    "parcata": "parcare",
    "parcate": "parcare",
    "parcati": "parcare",
    "parcato": "parcare",
    "parcava": "parcare",
    "parcavamo": "parcare",
    "parcavan": "parcare",
    "parcavano": "parcare",
    "parcavate": "parcare",
    "parcavi": "parcare",
    "parcavo": "parcare",
    "parcella": "parcellare",
    "parcellai": "parcellare",
    "parcellammo": "parcellare",
    "parcellan": "parcellare",
    "parcellando": "parcellare",
    "parcellano": "parcellare",
    "parcellante": "parcellare",
    "parcellanti": "parcellare",
    "parcellar": "parcellare",
    "parcellaron": "parcellare",
    "parcellarono": "parcellare",
    "parcellasse": "parcellare",
    "parcellasser": "parcellare",
    "parcellassero": "parcellare",
    "parcellassi": "parcellare",
    "parcellassimo": "parcellare",
    "parcellaste": "parcellare",
    "parcellasti": "parcellare",
    "parcellata": "parcellare",
    "parcellate": "parcellare",
    "parcellati": "parcellare",
    "parcellato": "parcellare",
    "parcellava": "parcellare",
    "parcellavamo": "parcellare",
    "parcellavan": "parcellare",
    "parcellavano": "parcellare",
    "parcellavate": "parcellare",
    "parcellavi": "parcellare",
    "parcellavo": "parcellare",
    "parcelle": "parcella",
    "parcellerai": "parcellare",
    "parcelleran": "parcellare",
    "parcelleranno": "parcellare",
    "parcellerebbe": "parcellare",
    "parcellerebber": "parcellare",
    "parcellerebbero": "parcellare",
    "parcellerei": "parcellare",
    "parcelleremmo": "parcellare",
    "parcelleremo": "parcellare",
    "parcellereste": "parcellare",
    "parcelleresti": "parcellare",
    "parcellerete": "parcellare",
    "parcellerà": "parcellare",
    "parcellerò": "parcellare",
    "parcelli": "parcellare",
    "parcelliamo": "parcellare",
    "parcelliate": "parcellare",
    "parcellin": "parcellare",
    "parcellino": "parcellare",
    "parcellizzazioni": "parcellizzazione",
    "parcello": "parcellare",
    "parcellò": "parcellare",
    "parche": "parco",
    "parcheggerai": "parcheggiare",
    "parcheggeran": "parcheggiare",
    "parcheggeranno": "parcheggiare",
    "parcheggerebbe": "parcheggiare",
    "parcheggerebber": "parcheggiare",
    "parcheggerebbero": "parcheggiare",
    "parcheggerei": "parcheggiare",
    "parcheggeremmo": "parcheggiare",
    "parcheggeremo": "parcheggiare",
    "parcheggereste": "parcheggiare",
    "parcheggeresti": "parcheggiare",
    "parcheggerete": "parcheggiare",
    "parcheggerà": "parcheggiare",
    "parcheggerò": "parcheggiare",
    "parcheggi": "parcheggio",
    "parcheggia": "parcheggiare",
    "parcheggiai": "parcheggiare",
    "parcheggiammo": "parcheggiare",
    "parcheggiamo": "parcheggiare",
    "parcheggian": "parcheggiare",
    "parcheggiando": "parcheggiare",
    "parcheggiano": "parcheggiare",
    "parcheggiante": "parcheggiare",
    "parcheggianti": "parcheggiare",
    "parcheggiar": "parcheggiare",
    "parcheggiaron": "parcheggiare",
    "parcheggiarono": "parcheggiare",
    "parcheggiasse": "parcheggiare",
    "parcheggiasser": "parcheggiare",
    "parcheggiassero": "parcheggiare",
    "parcheggiassi": "parcheggiare",
    "parcheggiassimo": "parcheggiare",
    "parcheggiaste": "parcheggiare",
    "parcheggiasti": "parcheggiare",
    "parcheggiata": "parcheggiare",
    "parcheggiate": "parcheggiare",
    "parcheggiati": "parcheggiare",
    "parcheggiato": "parcheggiare",
    "parcheggiatori": "parcheggiatore",
    "parcheggiava": "parcheggiare",
    "parcheggiavamo": "parcheggiare",
    "parcheggiavan": "parcheggiare",
    "parcheggiavano": "parcheggiare",
    "parcheggiavate": "parcheggiare",
    "parcheggiavi": "parcheggiare",
    "parcheggiavo": "parcheggiare",
    "parcheggin": "parcheggiare",
    "parcheggino": "parcheggiare",
    "parcheggio": "parcheggiare",
    "parcheggiò": "parcheggiare",
    "parcherai": "parcare",
    "parcheran": "parcare",
    "parcheranno": "parcare",
    "parcherebbe": "parcare",
    "parcherebber": "parcare",
    "parcherebbero": "parcare",
    "parcherei": "parcare",
    "parcheremmo": "parcare",
    "parcheremo": "parcare",
    "parchereste": "parcare",
    "parcheresti": "parcare",
    "parcherete": "parcare",
    "parcherà": "parcare",
    "parcherò": "parcare",
    "parchi": "parco",
    "parchiamo": "parcare",
    "parchiate": "parcare",
    "parchimetri": "parchimetro",
    "parchin": "parcare",
    "parchino": "parcare",
    "parco": "parcare",
    "parcò": "parcare",
    "pare": "parere",
    "parecchi": "parecchio",
    "parecchia": "parecchio",
    "parecchie": "parecchio",
    "pareggerai": "pareggiare",
    "pareggeran": "pareggiare",
    "pareggeranno": "pareggiare",
    "pareggerebbe": "pareggiare",
    "pareggerebber": "pareggiare",
    "pareggerebbero": "pareggiare",
    "pareggerei": "pareggiare",
    "pareggeremmo": "pareggiare",
    "pareggeremo": "pareggiare",
    "pareggereste": "pareggiare",
    "pareggeresti": "pareggiare",
    "pareggerete": "pareggiare",
    "pareggerà": "pareggiare",
    "pareggerò": "pareggiare",
    "pareggi": "pareggio",
    "pareggia": "pareggiare",
    "pareggiai": "pareggiare",
    "pareggiammo": "pareggiare",
    "pareggiamo": "pareggiare",
    "pareggian": "pareggiare",
    "pareggiando": "pareggiare",
    "pareggiano": "pareggiare",
    "pareggiante": "pareggiare",
    "pareggianti": "pareggiare",
    "pareggiar": "pareggiare",
    "pareggiaron": "pareggiare",
    "pareggiarono": "pareggiare",
    "pareggiasse": "pareggiare",
    "pareggiasser": "pareggiare",
    "pareggiassero": "pareggiare",
    "pareggiassi": "pareggiare",
    "pareggiassimo": "pareggiare",
    "pareggiaste": "pareggiare",
    "pareggiasti": "pareggiare",
    "pareggiata": "pareggiato",
    "pareggiate": "pareggiato",
    "pareggiati": "pareggiato",
    "pareggiato": "pareggiare",
    "pareggiava": "pareggiare",
    "pareggiavamo": "pareggiare",
    "pareggiavan": "pareggiare",
    "pareggiavano": "pareggiare",
    "pareggiavate": "pareggiare",
    "pareggiavi": "pareggiare",
    "pareggiavo": "pareggiare",
    "pareggin": "pareggiare",
    "pareggino": "pareggiare",
    "pareggio": "pareggiare",
    "pareggiò": "pareggiare",
    "paremmo": "parere",
    "parendo": "parere",
    "parentali": "parentale",
    "parente": "parere",
    "parentele": "parentela",
    "parenti": "parere",
    "parer": "parere",
    "parerai": "parare",
    "pareran": "parare",
    "pareranno": "parare",
    "parerebbe": "parare",
    "parerebber": "parare",
    "parerebbero": "parare",
    "parerei": "parare",
    "pareremmo": "parare",
    "pareremo": "parare",
    "parereste": "parare",
    "pareresti": "parare",
    "parerete": "parare",
    "pareri": "parere",
    "parerà": "parare",
    "parerò": "parare",
    "paresse": "parere",
    "paresser": "parere",
    "paressero": "parere",
    "paressi": "parere",
    "paressimo": "parere",
    "pareste": "parere",
    "paresti": "parere",
    "parete": "parere",
    "pareti": "parete",
    "pareva": "parere",
    "parevamo": "parere",
    "parevan": "parere",
    "parevano": "parere",
    "parevate": "parere",
    "parevi": "parere",
    "parevo": "parere",
    "pargoletti": "pargoletto",
    "pargoli": "pargolo",
    "pari": "pario",
    "paria": "pario",
    "pariamo": "parere",
    "pariate": "parere",
    "parie": "pario",
    "parifica": "parificare",
    "parificai": "parificare",
    "parificammo": "parificare",
    "parifican": "parificare",
    "parificando": "parificare",
    "parificano": "parificare",
    "parificante": "parificare",
    "parificanti": "parificare",
    "parificar": "parificare",
    "parificaron": "parificare",
    "parificarono": "parificare",
    "parificasse": "parificare",
    "parificasser": "parificare",
    "parificassero": "parificare",
    "parificassi": "parificare",
    "parificassimo": "parificare",
    "parificaste": "parificare",
    "parificasti": "parificare",
    "parificata": "parificato",
    "parificate": "parificato",
    "parificati": "parificato",
    "parificato": "parificare",
    "parificava": "parificare",
    "parificavamo": "parificare",
    "parificavan": "parificare",
    "parificavano": "parificare",
    "parificavate": "parificare",
    "parificavi": "parificare",
    "parificavo": "parificare",
    "parificazioni": "parificazione",
    "parificherai": "parificare",
    "parificheran": "parificare",
    "parificheranno": "parificare",
    "parificherebbe": "parificare",
    "parificherebber": "parificare",
    "parificherebbero": "parificare",
    "parificherei": "parificare",
    "parificheremmo": "parificare",
    "parificheremo": "parificare",
    "parifichereste": "parificare",
    "parificheresti": "parificare",
    "parificherete": "parificare",
    "parificherà": "parificare",
    "parificherò": "parificare",
    "parifichi": "parificare",
    "parifichiamo": "parificare",
    "parifichiate": "parificare",
    "parifichin": "parificare",
    "parifichino": "parificare",
    "parifico": "parificare",
    "parificò": "parificare",
    "parigina": "parigino",
    "parigine": "parigino",
    "parigini": "parigino",
    "parin": "parare",
    "parino": "parare",
    "paritari": "paritario",
    "paritaria": "paritario",
    "paritarie": "paritario",
    "paritetica": "paritetico",
    "paritetiche": "paritetico",
    "paritetici": "paritetico",
    "parla": "parlare",
    "parlai": "parlare",
    "parlamenta": "parlamentare",
    "parlamentai": "parlamentare",
    "parlamentammo": "parlamentare",
    "parlamentan": "parlamentare",
    "parlamentando": "parlamentare",
    "parlamentano": "parlamentare",
    "parlamentante": "parlamentare",
    "parlamentanti": "parlamentare",
    "parlamentar": "parlamentare",
    "parlamentari": "parlamentare",
    "parlamentarismi": "parlamentarismo",
    "parlamentaron": "parlamentare",
    "parlamentarono": "parlamentare",
    "parlamentasse": "parlamentare",
    "parlamentasser": "parlamentare",
    "parlamentassero": "parlamentare",
    "parlamentassi": "parlamentare",
    "parlamentassimo": "parlamentare",
    "parlamentaste": "parlamentare",
    "parlamentasti": "parlamentare",
    "parlamentata": "parlamentare",
    "parlamentate": "parlamentare",
    "parlamentati": "parlamentare",
    "parlamentato": "parlamentare",
    "parlamentava": "parlamentare",
    "parlamentavamo": "parlamentare",
    "parlamentavan": "parlamentare",
    "parlamentavano": "parlamentare",
    "parlamentavate": "parlamentare",
    "parlamentavi": "parlamentare",
    "parlamentavo": "parlamentare",
    "parlamenterai": "parlamentare",
    "parlamenteran": "parlamentare",
    "parlamenteranno": "parlamentare",
    "parlamenterebbe": "parlamentare",
    "parlamenterebber": "parlamentare",
    "parlamenterebbero": "parlamentare",
    "parlamenterei": "parlamentare",
    "parlamenteremmo": "parlamentare",
    "parlamenteremo": "parlamentare",
    "parlamentereste": "parlamentare",
    "parlamenteresti": "parlamentare",
    "parlamenterete": "parlamentare",
    "parlamenterà": "parlamentare",
    "parlamenterò": "parlamentare",
    "parlamenti": "parlamento",
    "parlamentiamo": "parlamentare",
    "parlamentiate": "parlamentare",
    "parlamentin": "parlamentare",
    "parlamentini": "parlamentino",
    "parlamentino": "parlamentare",
    "parlamento": "parlamentare",
    "parlamentò": "parlamentare",
    "parlammo": "parlare",
    "parlan": "parlare",
    "parlando": "parlare",
    "parlano": "parlare",
    "parlante": "parlare",
    "parlanti": "parlare",
    "parlantine": "parlantina",
    "parlar": "parlare",
    "parlaron": "parlare",
    "parlarono": "parlare",
    "parlasse": "parlare",
    "parlasser": "parlare",
    "parlassero": "parlare",
    "parlassi": "parlare",
    "parlassimo": "parlare",
    "parlaste": "parlare",
    "parlasti": "parlare",
    "parlata": "parlato",
    "parlate": "parlato",
    "parlati": "parlato",
    "parlato": "parlare",
    "parlatori": "parlatore",
    "parlatorii": "parlatorio",
    "parlava": "parlare",
    "parlavamo": "parlare",
    "parlavan": "parlare",
    "parlavano": "parlare",
    "parlavate": "parlare",
    "parlavi": "parlare",
    "parlavo": "parlare",
    "parlerai": "parlare",
    "parleran": "parlare",
    "parleranno": "parlare",
    "parlerebbe": "parlare",
    "parlerebber": "parlare",
    "parlerebbero": "parlare",
    "parlerei": "parlare",
    "parleremmo": "parlare",
    "parleremo": "parlare",
    "parlereste": "parlare",
    "parleresti": "parlare",
    "parlerete": "parlare",
    "parlerà": "parlare",
    "parlerò": "parlare",
    "parli": "parlare",
    "parliamo": "parlare",
    "parliate": "parlare",
    "parlin": "parlare",
    "parlino": "parlare",
    "parlo": "parlare",
    "parlotta": "parlottare",
    "parlottai": "parlottare",
    "parlottammo": "parlottare",
    "parlottan": "parlottare",
    "parlottando": "parlottare",
    "parlottano": "parlottare",
    "parlottante": "parlottare",
    "parlottanti": "parlottare",
    "parlottar": "parlottare",
    "parlottaron": "parlottare",
    "parlottarono": "parlottare",
    "parlottasse": "parlottare",
    "parlottasser": "parlottare",
    "parlottassero": "parlottare",
    "parlottassi": "parlottare",
    "parlottassimo": "parlottare",
    "parlottaste": "parlottare",
    "parlottasti": "parlottare",
    "parlottata": "parlottare",
    "parlottate": "parlottare",
    "parlottati": "parlottare",
    "parlottato": "parlottare",
    "parlottava": "parlottare",
    "parlottavamo": "parlottare",
    "parlottavan": "parlottare",
    "parlottavano": "parlottare",
    "parlottavate": "parlottare",
    "parlottavi": "parlottare",
    "parlottavo": "parlottare",
    "parlotterai": "parlottare",
    "parlotteran": "parlottare",
    "parlotteranno": "parlottare",
    "parlotterebbe": "parlottare",
    "parlotterebber": "parlottare",
    "parlotterebbero": "parlottare",
    "parlotterei": "parlottare",
    "parlotteremmo": "parlottare",
    "parlotteremo": "parlottare",
    "parlottereste": "parlottare",
    "parlotteresti": "parlottare",
    "parlotterete": "parlottare",
    "parlotterà": "parlottare",
    "parlotterò": "parlottare",
    "parlotti": "parlottare",
    "parlottiamo": "parlottare",
    "parlottiate": "parlottare",
    "parlottin": "parlottare",
    "parlottino": "parlottare",
    "parlotto": "parlottare",
    "parlottò": "parlottare",
    "parlò": "parlare",
    "parmensi": "parmense",
    "parmigiana": "parmigiano",
    "parmigiane": "parmigiano",
    "parmigiani": "parmigiano",
    "paro": "parare",
    "parodi": "parodiare",
    "parodia": "parodiare",
    "parodiai": "parodiare",
    "parodiammo": "parodiare",
    "parodiamo": "parodiare",
    "parodian": "parodiare",
    "parodiando": "parodiare",
    "parodiano": "parodiare",
    "parodiante": "parodiare",
    "parodianti": "parodiare",
    "parodiar": "parodiare",
    "parodiaron": "parodiare",
    "parodiarono": "parodiare",
    "parodiasse": "parodiare",
    "parodiasser": "parodiare",
    "parodiassero": "parodiare",
    "parodiassi": "parodiare",
    "parodiassimo": "parodiare",
    "parodiaste": "parodiare",
    "parodiasti": "parodiare",
    "parodiata": "parodiare",
    "parodiate": "parodiare",
    "parodiati": "parodiare",
    "parodiato": "parodiare",
    "parodiava": "parodiare",
    "parodiavamo": "parodiare",
    "parodiavan": "parodiare",
    "parodiavano": "parodiare",
    "parodiavate": "parodiare",
    "parodiavi": "parodiare",
    "parodiavo": "parodiare",
    "parodie": "parodia",
    "parodierai": "parodiare",
    "parodieran": "parodiare",
    "parodieranno": "parodiare",
    "parodierebbe": "parodiare",
    "parodierebber": "parodiare",
    "parodierebbero": "parodiare",
    "parodierei": "parodiare",
    "parodieremmo": "parodiare",
    "parodieremo": "parodiare",
    "parodiereste": "parodiare",
    "parodieresti": "parodiare",
    "parodierete": "parodiare",
    "parodierà": "parodiare",
    "parodierò": "parodiare",
    "parodin": "parodiare",
    "parodino": "parodiare",
    "parodio": "parodiare",
    "parodistica": "parodistico",
    "parodistiche": "parodistico",
    "parodistici": "parodistico",
    "parodiò": "parodiare",
    "parolacce": "parolaccia",
    "parolai": "parolaio",
    "parolaia": "parolaio",
    "parolaie": "parolaio",
    "parole": "parola",
    "parole-chiave": "parola-chiave",
    "parolette": "paroletta",
    "parolieri": "paroliere",
    "paroline": "parolina",
    "paroloni": "parolone",
    "parossismi": "parossismo",
    "parossistica": "parossistico",
    "parossistiche": "parossistico",
    "parossistici": "parossistico",
    "parrai": "parere",
    "parran": "parere",
    "parranno": "parere",
    "parrebbe": "parere",
    "parrebber": "parere",
    "parrebbero": "parere",
    "parrei": "parere",
    "parremmo": "parere",
    "parremo": "parere",
    "parreste": "parere",
    "parresti": "parere",
    "parrete": "parere",
    "parricidi": "parricidio",
    "parrocchiali": "parrocchiale",
    "parrocchiane": "parrocchiana",
    "parrocchiani": "parrocchiano",
    "parrocchie": "parrocchia",
    "parroci": "parroco",
    "parrucche": "parrucca",
    "parrucchiere": "parrucchiera",
    "parrucchieri": "parrucchiere",
    "parrucchini": "parrucchino",
    "parrucconi": "parruccone",
    "parrà": "parere",
    "parrò": "parere",
    "parsa": "parere",
    "parse": "parere",
    "parsi": "parere",
    "parsimoniosa": "parsimonioso",
    "parsimoniose": "parsimonioso",
    "parsimoniosi": "parsimonioso",
    "parso": "parere",
    "parta": "partire",
    "partan": "partire",
    "partano": "partire",
    "parte": "partire",
    "parteciapzioni": "parteciapzione",
    "partecipa": "partecipare",
    "partecipai": "partecipare",
    "partecipammo": "partecipare",
    "partecipan": "partecipare",
    "partecipando": "partecipare",
    "partecipano": "partecipare",
    "partecipante": "partecipare",
    "partecipanti": "partecipare",
    "partecipar": "partecipare",
    "parteciparon": "partecipare",
    "parteciparono": "partecipare",
    "partecipasse": "partecipare",
    "partecipasser": "partecipare",
    "partecipassero": "partecipare",
    "partecipassi": "partecipare",
    "partecipassimo": "partecipare",
    "partecipaste": "partecipare",
    "partecipasti": "partecipare",
    "partecipata": "partecipare",
    "partecipate": "partecipare",
    "partecipati": "partecipare",
    "partecipativa": "partecipativo",
    "partecipative": "partecipativo",
    "partecipativi": "partecipativo",
    "partecipato": "partecipare",
    "partecipava": "partecipare",
    "partecipavamo": "partecipare",
    "partecipavan": "partecipare",
    "partecipavano": "partecipare",
    "partecipavate": "partecipare",
    "partecipavi": "partecipare",
    "partecipavo": "partecipare",
    "partecipazioni": "partecipazione",
    "parteciperai": "partecipare",
    "parteciperan": "partecipare",
    "parteciperanno": "partecipare",
    "parteciperebbe": "partecipare",
    "parteciperebber": "partecipare",
    "parteciperebbero": "partecipare",
    "parteciperei": "partecipare",
    "parteciperemmo": "partecipare",
    "parteciperemo": "partecipare",
    "partecipereste": "partecipare",
    "parteciperesti": "partecipare",
    "parteciperete": "partecipare",
    "parteciperà": "partecipare",
    "parteciperò": "partecipare",
    "partecipi": "partecipe",
    "partecipiamo": "partecipare",
    "partecipiate": "partecipare",
    "partecipin": "partecipare",
    "partecipino": "partecipare",
    "partecipo": "partecipare",
    "partecipò": "partecipare",
    "parteggerai": "parteggiare",
    "parteggeran": "parteggiare",
    "parteggeranno": "parteggiare",
    "parteggerebbe": "parteggiare",
    "parteggerebber": "parteggiare",
    "parteggerebbero": "parteggiare",
    "parteggerei": "parteggiare",
    "parteggeremmo": "parteggiare",
    "parteggeremo": "parteggiare",
    "parteggereste": "parteggiare",
    "parteggeresti": "parteggiare",
    "parteggerete": "parteggiare",
    "parteggerà": "parteggiare",
    "parteggerò": "parteggiare",
    "parteggi": "parteggiare",
    "parteggia": "parteggiare",
    "parteggiai": "parteggiare",
    "parteggiammo": "parteggiare",
    "parteggiamo": "parteggiare",
    "parteggian": "parteggiare",
    "parteggiando": "parteggiare",
    "parteggiano": "parteggiare",
    "parteggiante": "parteggiare",
    "parteggianti": "parteggiare",
    "parteggiar": "parteggiare",
    "parteggiaron": "parteggiare",
    "parteggiarono": "parteggiare",
    "parteggiasse": "parteggiare",
    "parteggiasser": "parteggiare",
    "parteggiassero": "parteggiare",
    "parteggiassi": "parteggiare",
    "parteggiassimo": "parteggiare",
    "parteggiaste": "parteggiare",
    "parteggiasti": "parteggiare",
    "parteggiata": "parteggiare",
    "parteggiate": "parteggiare",
    "parteggiati": "parteggiare",
    "parteggiato": "parteggiare",
    "parteggiava": "parteggiare",
    "parteggiavamo": "parteggiare",
    "parteggiavan": "parteggiare",
    "parteggiavano": "parteggiare",
    "parteggiavate": "parteggiare",
    "parteggiavi": "parteggiare",
    "parteggiavo": "parteggiare",
    "parteggin": "parteggiare",
    "parteggino": "parteggiare",
    "parteggio": "parteggiare",
    "parteggiò": "parteggiare",
    "partendo": "partire",
    "partenogenetica": "partenogenetico",
    "partenogenetiche": "partenogenetico",
    "partenogenetici": "partenogenetico",
    "partenopea": "partenopeo",
    "partenopee": "partenopeo",
    "partenopei": "partenopeo",
    "partente": "partire",
    "partenti": "partire",
    "partenze": "partenza",
    "parti": "parto",
    "partiamo": "partire",
    "partiate": "partire",
    "particelle": "particella",
    "particine": "particina",
    "participi": "participio",
    "particolareggerai": "particolareggiare",
    "particolareggeran": "particolareggiare",
    "particolareggeranno": "particolareggiare",
    "particolareggerebbe": "particolareggiare",
    "particolareggerebber": "particolareggiare",
    "particolareggerebbero": "particolareggiare",
    "particolareggerei": "particolareggiare",
    "particolareggeremmo": "particolareggiare",
    "particolareggeremo": "particolareggiare",
    "particolareggereste": "particolareggiare",
    "particolareggeresti": "particolareggiare",
    "particolareggerete": "particolareggiare",
    "particolareggerà": "particolareggiare",
    "particolareggerò": "particolareggiare",
    "particolareggi": "particolareggiare",
    "particolareggia": "particolareggiare",
    "particolareggiai": "particolareggiare",
    "particolareggiammo": "particolareggiare",
    "particolareggiamo": "particolareggiare",
    "particolareggian": "particolareggiare",
    "particolareggiando": "particolareggiare",
    "particolareggiano": "particolareggiare",
    "particolareggiante": "particolareggiare",
    "particolareggianti": "particolareggiare",
    "particolareggiar": "particolareggiare",
    "particolareggiaron": "particolareggiare",
    "particolareggiarono": "particolareggiare",
    "particolareggiasse": "particolareggiare",
    "particolareggiasser": "particolareggiare",
    "particolareggiassero": "particolareggiare",
    "particolareggiassi": "particolareggiare",
    "particolareggiassimo": "particolareggiare",
    "particolareggiaste": "particolareggiare",
    "particolareggiasti": "particolareggiare",
    "particolareggiata": "particolareggiato",
    "particolareggiate": "particolareggiato",
    "particolareggiati": "particolareggiato",
    "particolareggiato": "particolareggiare",
    "particolareggiava": "particolareggiare",
    "particolareggiavamo": "particolareggiare",
    "particolareggiavan": "particolareggiare",
    "particolareggiavano": "particolareggiare",
    "particolareggiavate": "particolareggiare",
    "particolareggiavi": "particolareggiare",
    "particolareggiavo": "particolareggiare",
    "particolareggin": "particolareggiare",
    "particolareggino": "particolareggiare",
    "particolareggio": "particolareggiare",
    "particolareggiò": "particolareggiare",
    "particolari": "particolare",
    "particolarismi": "particolarismo",
    "particolaristica": "particolaristico",
    "particolaristiche": "particolaristico",
    "particolaristici": "particolaristico",
    "parties": "party",
    "partigiana": "partigiano",
    "partigiane": "partigiano",
    "partigianerie": "partigianeria",
    "partigiani": "partigiano",
    "partii": "partire",
    "partimmo": "partire",
    "partir": "partire",
    "partirai": "partire",
    "partiran": "partire",
    "partiranno": "partire",
    "partirebbe": "partire",
    "partirebber": "partire",
    "partirebbero": "partire",
    "partirei": "partire",
    "partiremmo": "partire",
    "partiremo": "partire",
    "partireste": "partire",
    "partiresti": "partire",
    "partirete": "partire",
    "partiron": "partire",
    "partirono": "partire",
    "partirà": "partire",
    "partirò": "partire",
    "partisse": "partire",
    "partisser": "partire",
    "partissero": "partire",
    "partissi": "partire",
    "partissimo": "partire",
    "partiste": "partire",
    "partisti": "partire",
    "partita": "partito",
    "partite": "partito",
    "partitelle": "partitella",
    "partiti": "partito",
    "partiti-azienda": "partito-azienda",
    "partiti-stati": "partito-stato",
    "partitica": "partitico",
    "partitiche": "partitico",
    "partitici": "partitico",
    "partitini": "partitino",
    "partito": "partire",
    "partitocrati": "partitocrate",
    "partitocrazie": "partitocrazia",
    "partitoni": "partitone",
    "partiture": "partitura",
    "partiva": "partire",
    "partivamo": "partire",
    "partivan": "partire",
    "partivano": "partire",
    "partivate": "partire",
    "partivi": "partire",
    "partivo": "partire",
    "partizioni": "partizione",
    "partners": "partner",
    "parto": "partire",
    "parton": "partire",
    "partono": "partire",
    "partorendo": "partorire",
    "partorente": "partorire",
    "partorenti": "partorire",
    "partoriamo": "partorire",
    "partoriate": "partorire",
    "partorienti": "partoriente",
    "partorii": "partorire",
    "partorimmo": "partorire",
    "partorir": "partorire",
    "partorirai": "partorire",
    "partoriran": "partorire",
    "partoriranno": "partorire",
    "partorirebbe": "partorire",
    "partorirebber": "partorire",
    "partorirebbero": "partorire",
    "partorirei": "partorire",
    "partoriremmo": "partorire",
    "partoriremo": "partorire",
    "partorireste": "partorire",
    "partoriresti": "partorire",
    "partorirete": "partorire",
    "partoriron": "partorire",
    "partorirono": "partorire",
    "partorirà": "partorire",
    "partorirò": "partorire",
    "partorisca": "partorire",
    "partoriscan": "partorire",
    "partoriscano": "partorire",
    "partorisce": "partorire",
    "partorisci": "partorire",
    "partorisco": "partorire",
    "partoriscon": "partorire",
    "partoriscono": "partorire",
    "partorisse": "partorire",
    "partorisser": "partorire",
    "partorissero": "partorire",
    "partorissi": "partorire",
    "partorissimo": "partorire",
    "partoriste": "partorire",
    "partoristi": "partorire",
    "partorita": "partorire",
    "partorite": "partorire",
    "partoriti": "partorire",
    "partorito": "partorire",
    "partoriva": "partorire",
    "partorivamo": "partorire",
    "partorivan": "partorire",
    "partorivano": "partorire",
    "partorivate": "partorire",
    "partorivi": "partorire",
    "partorivo": "partorire",
    "partorì": "partorire",
    "partì": "partire",
    "parve": "parere",
    "parvenze": "parvenza",
    "parver": "parere",
    "parvero": "parere",
    "parvi": "parere",
    "parziali": "parziale",
    "parò": "parare",
    "pasca": "pascere",
    "pascan": "pascere",
    "pascano": "pascere",
    "pasce": "pascere",
    "pascei": "pascere",
    "pascemmo": "pascere",
    "pascendo": "pascere",
    "pascente": "pascere",
    "pascenti": "pascere",
    "pascer": "pascere",
    "pascerai": "pascere",
    "pasceran": "pascere",
    "pasceranno": "pascere",
    "pascerebbe": "pascere",
    "pascerebber": "pascere",
    "pascerebbero": "pascere",
    "pascerei": "pascere",
    "pasceremmo": "pascere",
    "pasceremo": "pascere",
    "pascereste": "pascere",
    "pasceresti": "pascere",
    "pascerete": "pascere",
    "pasceron": "pascere",
    "pascerono": "pascere",
    "pascerà": "pascere",
    "pascerò": "pascere",
    "pascesse": "pascere",
    "pascesser": "pascere",
    "pascessero": "pascere",
    "pascessi": "pascere",
    "pascessimo": "pascere",
    "pasceste": "pascere",
    "pascesti": "pascere",
    "pascete": "pascere",
    "pasceva": "pascere",
    "pascevamo": "pascere",
    "pascevan": "pascere",
    "pascevano": "pascere",
    "pascevate": "pascere",
    "pascevi": "pascere",
    "pascevo": "pascere",
    "pasci": "pascere",
    "pasciamo": "pascere",
    "pasciate": "pascere",
    "pasciuta": "pascere",
    "pasciute": "pascere",
    "pasciuti": "pascere",
    "pasciuto": "pascere",
    "pasco": "pascere",
    "pascola": "pascolare",
    "pascolai": "pascolare",
    "pascolammo": "pascolare",
    "pascolan": "pascolare",
    "pascolando": "pascolare",
    "pascolano": "pascolare",
    "pascolante": "pascolare",
    "pascolanti": "pascolare",
    "pascolar": "pascolare",
    "pascolaron": "pascolare",
    "pascolarono": "pascolare",
    "pascolasse": "pascolare",
    "pascolasser": "pascolare",
    "pascolassero": "pascolare",
    "pascolassi": "pascolare",
    "pascolassimo": "pascolare",
    "pascolaste": "pascolare",
    "pascolasti": "pascolare",
    "pascolata": "pascolare",
    "pascolate": "pascolare",
    "pascolati": "pascolare",
    "pascolato": "pascolare",
    "pascolava": "pascolare",
    "pascolavamo": "pascolare",
    "pascolavan": "pascolare",
    "pascolavano": "pascolare",
    "pascolavate": "pascolare",
    "pascolavi": "pascolare",
    "pascolavo": "pascolare",
    "pascolerai": "pascolare",
    "pascoleran": "pascolare",
    "pascoleranno": "pascolare",
    "pascolerebbe": "pascolare",
    "pascolerebber": "pascolare",
    "pascolerebbero": "pascolare",
    "pascolerei": "pascolare",
    "pascoleremmo": "pascolare",
    "pascoleremo": "pascolare",
    "pascolereste": "pascolare",
    "pascoleresti": "pascolare",
    "pascolerete": "pascolare",
    "pascolerà": "pascolare",
    "pascolerò": "pascolare",
    "pascoli": "pascolo",
    "pascoliamo": "pascolare",
    "pascoliate": "pascolare",
    "pascolin": "pascolare",
    "pascolino": "pascolare",
    "pascolo": "pascolare",
    "pascolò": "pascolare",
    "pascon": "pascere",
    "pascono": "pascere",
    "pascè": "pascere",
    "pasionarie": "pasionaria",
    "pasquali": "pasquale",
    "passa": "passo",
    "passabili": "passabile",
    "passaggi": "passaggio",
    "passai": "passare",
    "passamanerie": "passamaneria",
    "passammo": "passare",
    "passan": "passare",
    "passando": "passare",
    "passano": "passare",
    "passante": "passare",
    "passanti": "passare",
    "passaporti": "passaporto",
    "passar": "passare",
    "passaron": "passare",
    "passarono": "passare",
    "passasse": "passare",
    "passasser": "passare",
    "passassero": "passare",
    "passassi": "passare",
    "passassimo": "passare",
    "passaste": "passare",
    "passasti": "passare",
    "passata": "passato",
    "passate": "passato",
    "passatempi": "passatempo",
    "passati": "passato",
    "passatisti": "passatista",
    "passato": "passare",
    "passatori": "passatore",
    "passava": "passare",
    "passavamo": "passare",
    "passavan": "passare",
    "passavano": "passare",
    "passavate": "passare",
    "passavi": "passare",
    "passavo": "passare",
    "passe": "passo",
    "passeggera": "passeggero",
    "passeggerai": "passeggiare",
    "passeggeran": "passeggiare",
    "passeggeranno": "passeggiare",
    "passeggere": "passeggero",
    "passeggerebbe": "passeggiare",
    "passeggerebber": "passeggiare",
    "passeggerebbero": "passeggiare",
    "passeggerei": "passeggiare",
    "passeggeremmo": "passeggiare",
    "passeggeremo": "passeggiare",
    "passeggereste": "passeggiare",
    "passeggeresti": "passeggiare",
    "passeggerete": "passeggiare",
    "passeggeri": "passeggero",
    "passeggerà": "passeggiare",
    "passeggerò": "passeggiare",
    "passeggi": "passeggiare",
    "passeggia": "passeggiare",
    "passeggiai": "passeggiare",
    "passeggiammo": "passeggiare",
    "passeggiamo": "passeggiare",
    "passeggian": "passeggiare",
    "passeggiando": "passeggiare",
    "passeggiano": "passeggiare",
    "passeggiante": "passeggiare",
    "passeggianti": "passeggiare",
    "passeggiar": "passeggiare",
    "passeggiaron": "passeggiare",
    "passeggiarono": "passeggiare",
    "passeggiasse": "passeggiare",
    "passeggiasser": "passeggiare",
    "passeggiassero": "passeggiare",
    "passeggiassi": "passeggiare",
    "passeggiassimo": "passeggiare",
    "passeggiaste": "passeggiare",
    "passeggiasti": "passeggiare",
    "passeggiata": "passeggiare",
    "passeggiate": "passeggiata",
    "passeggiati": "passeggiare",
    "passeggiatine": "passeggiatina",
    "passeggiato": "passeggiare",
    "passeggiatrici": "passeggiatrice",
    "passeggiava": "passeggiare",
    "passeggiavamo": "passeggiare",
    "passeggiavan": "passeggiare",
    "passeggiavano": "passeggiare",
    "passeggiavate": "passeggiare",
    "passeggiavi": "passeggiare",
    "passeggiavo": "passeggiare",
    "passeggin": "passeggiare",
    "passeggini": "passeggino",
    "passeggino": "passeggiare",
    "passeggio": "passeggiare",
    "passeggiò": "passeggiare",
    "passerai": "passare",
    "passeran": "passare",
    "passeranno": "passare",
    "passerebbe": "passare",
    "passerebber": "passare",
    "passerebbero": "passare",
    "passerei": "passare",
    "passerelle": "passerella",
    "passeremmo": "passare",
    "passeremo": "passare",
    "passereste": "passare",
    "passeresti": "passare",
    "passerete": "passare",
    "passerotti": "passerotto",
    "passerà": "passare",
    "passerò": "passare",
    "passetti": "passetto",
    "passettini": "passettino",
    "passi": "passo",
    "passiamo": "passare",
    "passiate": "passare",
    "passibili": "passibile",
    "passin": "passare",
    "passino": "passare",
    "passionali": "passionale",
    "passioni": "passione",
    "passisti": "passista",
    "passiva": "passivo",
    "passive": "passivo",
    "passivi": "passivo",
    "passo": "passare",
    "passò": "passare",
    "pastai": "pastaio",
    "pastasciutte": "pastasciutta",
    "paste": "pasta",
    "pasteggerai": "pasteggiare",
    "pasteggeran": "pasteggiare",
    "pasteggeranno": "pasteggiare",
    "pasteggerebbe": "pasteggiare",
    "pasteggerebber": "pasteggiare",
    "pasteggerebbero": "pasteggiare",
    "pasteggerei": "pasteggiare",
    "pasteggeremmo": "pasteggiare",
    "pasteggeremo": "pasteggiare",
    "pasteggereste": "pasteggiare",
    "pasteggeresti": "pasteggiare",
    "pasteggerete": "pasteggiare",
    "pasteggerà": "pasteggiare",
    "pasteggerò": "pasteggiare",
    "pasteggi": "pasteggiare",
    "pasteggia": "pasteggiare",
    "pasteggiai": "pasteggiare",
    "pasteggiammo": "pasteggiare",
    "pasteggiamo": "pasteggiare",
    "pasteggian": "pasteggiare",
    "pasteggiando": "pasteggiare",
    "pasteggiano": "pasteggiare",
    "pasteggiante": "pasteggiare",
    "pasteggianti": "pasteggiare",
    "pasteggiar": "pasteggiare",
    "pasteggiaron": "pasteggiare",
    "pasteggiarono": "pasteggiare",
    "pasteggiasse": "pasteggiare",
    "pasteggiasser": "pasteggiare",
    "pasteggiassero": "pasteggiare",
    "pasteggiassi": "pasteggiare",
    "pasteggiassimo": "pasteggiare",
    "pasteggiaste": "pasteggiare",
    "pasteggiasti": "pasteggiare",
    "pasteggiata": "pasteggiare",
    "pasteggiate": "pasteggiare",
    "pasteggiati": "pasteggiare",
    "pasteggiato": "pasteggiare",
    "pasteggiava": "pasteggiare",
    "pasteggiavamo": "pasteggiare",
    "pasteggiavan": "pasteggiare",
    "pasteggiavano": "pasteggiare",
    "pasteggiavate": "pasteggiare",
    "pasteggiavi": "pasteggiare",
    "pasteggiavo": "pasteggiare",
    "pasteggin": "pasteggiare",
    "pasteggino": "pasteggiare",
    "pasteggio": "pasteggiare",
    "pasteggiò": "pasteggiare",
    "pastelli": "pastello",
    "pastette": "pastetta",
    "pasti": "pasto",
    "pasticcerai": "pasticciare",
    "pasticceran": "pasticciare",
    "pasticceranno": "pasticciare",
    "pasticcerebbe": "pasticciare",
    "pasticcerebber": "pasticciare",
    "pasticcerebbero": "pasticciare",
    "pasticcerei": "pasticciare",
    "pasticceremmo": "pasticciare",
    "pasticceremo": "pasticciare",
    "pasticcereste": "pasticciare",
    "pasticceresti": "pasticciare",
    "pasticcerete": "pasticciare",
    "pasticceri": "pasticcere",
    "pasticcerie": "pasticceria",
    "pasticcerà": "pasticciare",
    "pasticcerò": "pasticciare",
    "pasticche": "pasticca",
    "pasticci": "pasticcio",
    "pasticcia": "pasticciare",
    "pasticciacci": "pasticciaccio",
    "pasticciai": "pasticciare",
    "pasticciammo": "pasticciare",
    "pasticciamo": "pasticciare",
    "pasticcian": "pasticciare",
    "pasticciando": "pasticciare",
    "pasticciano": "pasticciare",
    "pasticciante": "pasticciare",
    "pasticcianti": "pasticciare",
    "pasticciar": "pasticciare",
    "pasticciaron": "pasticciare",
    "pasticciarono": "pasticciare",
    "pasticciasse": "pasticciare",
    "pasticciasser": "pasticciare",
    "pasticciassero": "pasticciare",
    "pasticciassi": "pasticciare",
    "pasticciassimo": "pasticciare",
    "pasticciaste": "pasticciare",
    "pasticciasti": "pasticciare",
    "pasticciata": "pasticciato",
    "pasticciate": "pasticciato",
    "pasticciati": "pasticciato",
    "pasticciato": "pasticciare",
    "pasticciava": "pasticciare",
    "pasticciavamo": "pasticciare",
    "pasticciavan": "pasticciare",
    "pasticciavano": "pasticciare",
    "pasticciavate": "pasticciare",
    "pasticciavi": "pasticciare",
    "pasticciavo": "pasticciare",
    "pasticcieri": "pasticciere",
    "pasticcin": "pasticciare",
    "pasticcini": "pasticcino",
    "pasticcino": "pasticciare",
    "pasticcio": "pasticciare",
    "pasticcioni": "pasticcione",
    "pasticciò": "pasticciare",
    "pastiches": "pastiche",
    "pastifici": "pastificio",
    "pastiglie": "pastiglia",
    "pastoie": "pastoia",
    "pastoni": "pastone",
    "pastorali": "pastorale",
    "pastorelle": "pastorella",
    "pastorellerie": "pastorelleria",
    "pastorelli": "pastorello",
    "pastori": "pastore",
    "pastorizi": "pastorizio",
    "pastorizia": "pastorizio",
    "pastorizie": "pastorizio",
    "pastorizza": "pastorizzare",
    "pastorizzai": "pastorizzare",
    "pastorizzammo": "pastorizzare",
    "pastorizzan": "pastorizzare",
    "pastorizzando": "pastorizzare",
    "pastorizzano": "pastorizzare",
    "pastorizzante": "pastorizzare",
    "pastorizzanti": "pastorizzare",
    "pastorizzar": "pastorizzare",
    "pastorizzaron": "pastorizzare",
    "pastorizzarono": "pastorizzare",
    "pastorizzasse": "pastorizzare",
    "pastorizzasser": "pastorizzare",
    "pastorizzassero": "pastorizzare",
    "pastorizzassi": "pastorizzare",
    "pastorizzassimo": "pastorizzare",
    "pastorizzaste": "pastorizzare",
    "pastorizzasti": "pastorizzare",
    "pastorizzata": "pastorizzare",
    "pastorizzate": "pastorizzare",
    "pastorizzati": "pastorizzare",
    "pastorizzato": "pastorizzare",
    "pastorizzava": "pastorizzare",
    "pastorizzavamo": "pastorizzare",
    "pastorizzavan": "pastorizzare",
    "pastorizzavano": "pastorizzare",
    "pastorizzavate": "pastorizzare",
    "pastorizzavi": "pastorizzare",
    "pastorizzavo": "pastorizzare",
    "pastorizzerai": "pastorizzare",
    "pastorizzeran": "pastorizzare",
    "pastorizzeranno": "pastorizzare",
    "pastorizzerebbe": "pastorizzare",
    "pastorizzerebber": "pastorizzare",
    "pastorizzerebbero": "pastorizzare",
    "pastorizzerei": "pastorizzare",
    "pastorizzeremmo": "pastorizzare",
    "pastorizzeremo": "pastorizzare",
    "pastorizzereste": "pastorizzare",
    "pastorizzeresti": "pastorizzare",
    "pastorizzerete": "pastorizzare",
    "pastorizzerà": "pastorizzare",
    "pastorizzerò": "pastorizzare",
    "pastorizzi": "pastorizzare",
    "pastorizziamo": "pastorizzare",
    "pastorizziate": "pastorizzare",
    "pastorizzin": "pastorizzare",
    "pastorizzino": "pastorizzare",
    "pastorizzo": "pastorizzare",
    "pastorizzò": "pastorizzare",
    "pastosa": "pastoso",
    "pastose": "pastoso",
    "pastosi": "pastoso",
    "pastrani": "pastrano",
    "pastrocchi": "pastrocchio",
    "pastura": "pasturare",
    "pasturai": "pasturare",
    "pasturammo": "pasturare",
    "pasturan": "pasturare",
    "pasturando": "pasturare",
    "pasturano": "pasturare",
    "pasturante": "pasturare",
    "pasturanti": "pasturare",
    "pasturar": "pasturare",
    "pasturaron": "pasturare",
    "pasturarono": "pasturare",
    "pasturasse": "pasturare",
    "pasturasser": "pasturare",
    "pasturassero": "pasturare",
    "pasturassi": "pasturare",
    "pasturassimo": "pasturare",
    "pasturaste": "pasturare",
    "pasturasti": "pasturare",
    "pasturata": "pasturare",
    "pasturate": "pasturare",
    "pasturati": "pasturare",
    "pasturato": "pasturare",
    "pasturava": "pasturare",
    "pasturavamo": "pasturare",
    "pasturavan": "pasturare",
    "pasturavano": "pasturare",
    "pasturavate": "pasturare",
    "pasturavi": "pasturare",
    "pasturavo": "pasturare",
    "pasturerai": "pasturare",
    "pastureran": "pasturare",
    "pastureranno": "pasturare",
    "pasturerebbe": "pasturare",
    "pasturerebber": "pasturare",
    "pasturerebbero": "pasturare",
    "pasturerei": "pasturare",
    "pastureremmo": "pasturare",
    "pastureremo": "pasturare",
    "pasturereste": "pasturare",
    "pastureresti": "pasturare",
    "pasturerete": "pasturare",
    "pasturerà": "pasturare",
    "pasturerò": "pasturare",
    "pasturi": "pasturare",
    "pasturiamo": "pasturare",
    "pasturiate": "pasturare",
    "pasturin": "pasturare",
    "pasturino": "pasturare",
    "pasturo": "pasturare",
    "pasturò": "pasturare",
    "pataccari": "pataccaro",
    "patacche": "patacca",
    "patarina": "patarino",
    "patarine": "patarino",
    "patarini": "patarino",
    "patate": "patata",
    "patatine": "patatina",
    "patavina": "patavino",
    "patavine": "patavino",
    "patavini": "patavino",
    "patendo": "patire",
    "patentata": "patentato",
    "patentate": "patentato",
    "patentati": "patentato",
    "patente": "patire",
    "patenti": "patire",
    "patentini": "patentino",
    "pateracchi": "pateracchio",
    "paterna": "paterno",
    "paternalismi": "paternalismo",
    "paternalistica": "paternalistico",
    "paternalistiche": "paternalistico",
    "paternalistici": "paternalistico",
    "paterne": "paterno",
    "paterni": "paterno",
    "patetica": "patetico",
    "patetiche": "patetico",
    "patetici": "patetico",
    "patetismi": "patetismo",
    "pati": "patio",
    "patiamo": "patire",
    "patiate": "patire",
    "patibola": "patibolare",
    "patibolai": "patibolare",
    "patibolammo": "patibolare",
    "patibolan": "patibolare",
    "patibolando": "patibolare",
    "patibolano": "patibolare",
    "patibolante": "patibolare",
    "patibolanti": "patibolare",
    "patibolar": "patibolare",
    "patibolari": "patibolare",
    "patibolaron": "patibolare",
    "patibolarono": "patibolare",
    "patibolasse": "patibolare",
    "patibolasser": "patibolare",
    "patibolassero": "patibolare",
    "patibolassi": "patibolare",
    "patibolassimo": "patibolare",
    "patibolaste": "patibolare",
    "patibolasti": "patibolare",
    "patibolata": "patibolare",
    "patibolate": "patibolare",
    "patibolati": "patibolare",
    "patibolato": "patibolare",
    "patibolava": "patibolare",
    "patibolavamo": "patibolare",
    "patibolavan": "patibolare",
    "patibolavano": "patibolare",
    "patibolavate": "patibolare",
    "patibolavi": "patibolare",
    "patibolavo": "patibolare",
    "patibolerai": "patibolare",
    "patiboleran": "patibolare",
    "patiboleranno": "patibolare",
    "patibolerebbe": "patibolare",
    "patibolerebber": "patibolare",
    "patibolerebbero": "patibolare",
    "patibolerei": "patibolare",
    "patiboleremmo": "patibolare",
    "patiboleremo": "patibolare",
    "patibolereste": "patibolare",
    "patiboleresti": "patibolare",
    "patibolerete": "patibolare",
    "patibolerà": "patibolare",
    "patibolerò": "patibolare",
    "patiboli": "patibolo",
    "patiboliamo": "patibolare",
    "patiboliate": "patibolare",
    "patibolin": "patibolare",
    "patibolino": "patibolare",
    "patibolo": "patibolare",
    "patibolò": "patibolare",
    "patii": "patire",
    "patimenti": "patimento",
    "patimmo": "patire",
    "patina": "patinare",
    "patinai": "patinare",
    "patinammo": "patinare",
    "patinan": "patinare",
    "patinando": "patinare",
    "patinano": "patinare",
    "patinante": "patinare",
    "patinanti": "patinare",
    "patinar": "patinare",
    "patinaron": "patinare",
    "patinarono": "patinare",
    "patinasse": "patinare",
    "patinasser": "patinare",
    "patinassero": "patinare",
    "patinassi": "patinare",
    "patinassimo": "patinare",
    "patinaste": "patinare",
    "patinasti": "patinare",
    "patinata": "patinato",
    "patinate": "patinato",
    "patinati": "patinato",
    "patinato": "patinare",
    "patinava": "patinare",
    "patinavamo": "patinare",
    "patinavan": "patinare",
    "patinavano": "patinare",
    "patinavate": "patinare",
    "patinavi": "patinare",
    "patinavo": "patinare",
    "patine": "patina",
    "patinerai": "patinare",
    "patineran": "patinare",
    "patineranno": "patinare",
    "patinerebbe": "patinare",
    "patinerebber": "patinare",
    "patinerebbero": "patinare",
    "patinerei": "patinare",
    "patineremmo": "patinare",
    "patineremo": "patinare",
    "patinereste": "patinare",
    "patineresti": "patinare",
    "patinerete": "patinare",
    "patinerà": "patinare",
    "patinerò": "patinare",
    "patini": "patinare",
    "patiniamo": "patinare",
    "patiniate": "patinare",
    "patinin": "patinare",
    "patinino": "patinare",
    "patino": "patinare",
    "patinò": "patinare",
    "patir": "patire",
    "patirai": "patire",
    "patiran": "patire",
    "patiranno": "patire",
    "patirebbe": "patire",
    "patirebber": "patire",
    "patirebbero": "patire",
    "patirei": "patire",
    "patiremmo": "patire",
    "patiremo": "patire",
    "patireste": "patire",
    "patiresti": "patire",
    "patirete": "patire",
    "patiron": "patire",
    "patirono": "patire",
    "patirà": "patire",
    "patirò": "patire",
    "patisca": "patire",
    "patiscan": "patire",
    "patiscano": "patire",
    "patisce": "patire",
    "patisci": "patire",
    "patisco": "patire",
    "patiscon": "patire",
    "patiscono": "patire",
    "patisse": "patire",
    "patisser": "patire",
    "patissero": "patire",
    "patissi": "patire",
    "patissimo": "patire",
    "patiste": "patire",
    "patisti": "patire",
    "patita": "patito",
    "patite": "patito",
    "patiti": "patito",
    "patito": "patire",
    "pativa": "patire",
    "pativamo": "patire",
    "pativan": "patire",
    "pativano": "patire",
    "pativate": "patire",
    "pativi": "patire",
    "pativo": "patire",
    "patogena": "patogeno",
    "patogene": "patogeno",
    "patogeni": "patogeno",
    "patologi": "patologo",
    "patologica": "patologico",
    "patologiche": "patologico",
    "patologici": "patologico",
    "patologie": "patologia",
    "patri": "patrio",
    "patria": "patrio",
    "patriarcali": "patriarcale",
    "patriarcati": "patriarcato",
    "patriarchi": "patriarca",
    "patrie": "patrio",
    "patrigni": "patrigno",
    "patrilinea": "patrilineare",
    "patrilineai": "patrilineare",
    "patrilineammo": "patrilineare",
    "patrilinean": "patrilineare",
    "patrilineando": "patrilineare",
    "patrilineano": "patrilineare",
    "patrilineante": "patrilineare",
    "patrilineanti": "patrilineare",
    "patrilinear": "patrilineare",
    "patrilinearon": "patrilineare",
    "patrilinearono": "patrilineare",
    "patrilineasse": "patrilineare",
    "patrilineasser": "patrilineare",
    "patrilineassero": "patrilineare",
    "patrilineassi": "patrilineare",
    "patrilineassimo": "patrilineare",
    "patrilineaste": "patrilineare",
    "patrilineasti": "patrilineare",
    "patrilineata": "patrilineare",
    "patrilineate": "patrilineare",
    "patrilineati": "patrilineare",
    "patrilineato": "patrilineare",
    "patrilineava": "patrilineare",
    "patrilineavamo": "patrilineare",
    "patrilineavan": "patrilineare",
    "patrilineavano": "patrilineare",
    "patrilineavate": "patrilineare",
    "patrilineavi": "patrilineare",
    "patrilineavo": "patrilineare",
    "patrilineerai": "patrilineare",
    "patrilineeran": "patrilineare",
    "patrilineeranno": "patrilineare",
    "patrilineerebbe": "patrilineare",
    "patrilineerebber": "patrilineare",
    "patrilineerebbero": "patrilineare",
    "patrilineerei": "patrilineare",
    "patrilineeremmo": "patrilineare",
    "patrilineeremo": "patrilineare",
    "patrilineereste": "patrilineare",
    "patrilineeresti": "patrilineare",
    "patrilineerete": "patrilineare",
    "patrilineerà": "patrilineare",
    "patrilineerò": "patrilineare",
    "patrilinei": "patrilineare",
    "patrilineiamo": "patrilineare",
    "patrilineiate": "patrilineare",
    "patrilinein": "patrilineare",
    "patrilineino": "patrilineare",
    "patrilineo": "patrilineare",
    "patrilineò": "patrilineare",
    "patrimoni": "patrimonio",
    "patrimoniali": "patrimoniale",
    "patrimonializzazioni": "patrimonializzazione",
    "patrioti": "patriota",
    "patriottarda": "patriottardo",
    "patriottarde": "patriottardo",
    "patriottardi": "patriottardo",
    "patriottica": "patriottico",
    "patriottiche": "patriottico",
    "patriottici": "patriottico",
    "patriottismi": "patriottismo",
    "patrizi": "patrizio",
    "patrizia": "patrizio",
    "patrizie": "patrizio",
    "patrocina": "patrocinare",
    "patrocinai": "patrocinare",
    "patrocinammo": "patrocinare",
    "patrocinan": "patrocinare",
    "patrocinando": "patrocinare",
    "patrocinano": "patrocinare",
    "patrocinante": "patrocinare",
    "patrocinanti": "patrocinare",
    "patrocinar": "patrocinare",
    "patrocinaron": "patrocinare",
    "patrocinarono": "patrocinare",
    "patrocinasse": "patrocinare",
    "patrocinasser": "patrocinare",
    "patrocinassero": "patrocinare",
    "patrocinassi": "patrocinare",
    "patrocinassimo": "patrocinare",
    "patrocinaste": "patrocinare",
    "patrocinasti": "patrocinare",
    "patrocinata": "patrocinare",
    "patrocinate": "patrocinare",
    "patrocinati": "patrocinare",
    "patrocinato": "patrocinare",
    "patrocinatori": "patrocinatore",
    "patrocinava": "patrocinare",
    "patrocinavamo": "patrocinare",
    "patrocinavan": "patrocinare",
    "patrocinavano": "patrocinare",
    "patrocinavate": "patrocinare",
    "patrocinavi": "patrocinare",
    "patrocinavo": "patrocinare",
    "patrocinerai": "patrocinare",
    "patrocineran": "patrocinare",
    "patrocineranno": "patrocinare",
    "patrocinerebbe": "patrocinare",
    "patrocinerebber": "patrocinare",
    "patrocinerebbero": "patrocinare",
    "patrocinerei": "patrocinare",
    "patrocineremmo": "patrocinare",
    "patrocineremo": "patrocinare",
    "patrocinereste": "patrocinare",
    "patrocineresti": "patrocinare",
    "patrocinerete": "patrocinare",
    "patrocinerà": "patrocinare",
    "patrocinerò": "patrocinare",
    "patrocini": "patrocinio",
    "patrociniamo": "patrocinare",
    "patrociniate": "patrocinare",
    "patrocinin": "patrocinare",
    "patrocinino": "patrocinare",
    "patrocino": "patrocinare",
    "patrocinò": "patrocinare",
    "patronali": "patronale",
    "patronati": "patronato",
    "patrone": "patrona",
    "patroni": "patrono",
    "patteggerai": "patteggiare",
    "patteggeran": "patteggiare",
    "patteggeranno": "patteggiare",
    "patteggerebbe": "patteggiare",
    "patteggerebber": "patteggiare",
    "patteggerebbero": "patteggiare",
    "patteggerei": "patteggiare",
    "patteggeremmo": "patteggiare",
    "patteggeremo": "patteggiare",
    "patteggereste": "patteggiare",
    "patteggeresti": "patteggiare",
    "patteggerete": "patteggiare",
    "patteggerà": "patteggiare",
    "patteggerò": "patteggiare",
    "patteggi": "patteggiare",
    "patteggia": "patteggiare",
    "patteggiai": "patteggiare",
    "patteggiamenti": "patteggiamento",
    "patteggiammo": "patteggiare",
    "patteggiamo": "patteggiare",
    "patteggian": "patteggiare",
    "patteggiando": "patteggiare",
    "patteggiano": "patteggiare",
    "patteggiante": "patteggiare",
    "patteggianti": "patteggiare",
    "patteggiar": "patteggiare",
    "patteggiaron": "patteggiare",
    "patteggiarono": "patteggiare",
    "patteggiasse": "patteggiare",
    "patteggiasser": "patteggiare",
    "patteggiassero": "patteggiare",
    "patteggiassi": "patteggiare",
    "patteggiassimo": "patteggiare",
    "patteggiaste": "patteggiare",
    "patteggiasti": "patteggiare",
    "patteggiata": "patteggiare",
    "patteggiate": "patteggiare",
    "patteggiati": "patteggiare",
    "patteggiato": "patteggiare",
    "patteggiava": "patteggiare",
    "patteggiavamo": "patteggiare",
    "patteggiavan": "patteggiare",
    "patteggiavano": "patteggiare",
    "patteggiavate": "patteggiare",
    "patteggiavi": "patteggiare",
    "patteggiavo": "patteggiare",
    "patteggin": "patteggiare",
    "patteggino": "patteggiare",
    "patteggio": "patteggiare",
    "patteggiò": "patteggiare",
    "patti": "patto",
    "pattina": "pattinare",
    "pattinaggi": "pattinaggio",
    "pattinai": "pattinare",
    "pattinammo": "pattinare",
    "pattinan": "pattinare",
    "pattinando": "pattinare",
    "pattinano": "pattinare",
    "pattinante": "pattinare",
    "pattinanti": "pattinare",
    "pattinar": "pattinare",
    "pattinaron": "pattinare",
    "pattinarono": "pattinare",
    "pattinasse": "pattinare",
    "pattinasser": "pattinare",
    "pattinassero": "pattinare",
    "pattinassi": "pattinare",
    "pattinassimo": "pattinare",
    "pattinaste": "pattinare",
    "pattinasti": "pattinare",
    "pattinata": "pattinare",
    "pattinate": "pattinare",
    "pattinati": "pattinare",
    "pattinato": "pattinare",
    "pattinatori": "pattinatore",
    "pattinatrici": "pattinatrice",
    "pattinava": "pattinare",
    "pattinavamo": "pattinare",
    "pattinavan": "pattinare",
    "pattinavano": "pattinare",
    "pattinavate": "pattinare",
    "pattinavi": "pattinare",
    "pattinavo": "pattinare",
    "pattinerai": "pattinare",
    "pattineran": "pattinare",
    "pattineranno": "pattinare",
    "pattinerebbe": "pattinare",
    "pattinerebber": "pattinare",
    "pattinerebbero": "pattinare",
    "pattinerei": "pattinare",
    "pattineremmo": "pattinare",
    "pattineremo": "pattinare",
    "pattinereste": "pattinare",
    "pattineresti": "pattinare",
    "pattinerete": "pattinare",
    "pattinerà": "pattinare",
    "pattinerò": "pattinare",
    "pattini": "pattino",
    "pattiniamo": "pattinare",
    "pattiniate": "pattinare",
    "pattinin": "pattinare",
    "pattinino": "pattinare",
    "pattino": "pattinare",
    "pattinò": "pattinare",
    "pattisti": "pattista",
    "pattua": "pattuire",
    "pattuan": "pattuire",
    "pattuano": "pattuire",
    "pattue": "pattuire",
    "pattuendo": "pattuire",
    "pattuente": "pattuire",
    "pattuenti": "pattuire",
    "pattugli": "pattugliare",
    "pattuglia": "pattugliare",
    "pattugliai": "pattugliare",
    "pattugliamenti": "pattugliamento",
    "pattugliammo": "pattugliare",
    "pattugliamo": "pattugliare",
    "pattuglian": "pattugliare",
    "pattugliando": "pattugliare",
    "pattugliano": "pattugliare",
    "pattugliante": "pattugliare",
    "pattuglianti": "pattugliare",
    "pattugliar": "pattugliare",
    "pattugliaron": "pattugliare",
    "pattugliarono": "pattugliare",
    "pattugliasse": "pattugliare",
    "pattugliasser": "pattugliare",
    "pattugliassero": "pattugliare",
    "pattugliassi": "pattugliare",
    "pattugliassimo": "pattugliare",
    "pattugliaste": "pattugliare",
    "pattugliasti": "pattugliare",
    "pattugliata": "pattugliare",
    "pattugliate": "pattugliare",
    "pattugliati": "pattugliare",
    "pattugliato": "pattugliare",
    "pattugliatori": "pattugliatore",
    "pattugliava": "pattugliare",
    "pattugliavamo": "pattugliare",
    "pattugliavan": "pattugliare",
    "pattugliavano": "pattugliare",
    "pattugliavate": "pattugliare",
    "pattugliavi": "pattugliare",
    "pattugliavo": "pattugliare",
    "pattuglie": "pattuglia",
    "pattuglierai": "pattugliare",
    "pattuglieran": "pattugliare",
    "pattuglieranno": "pattugliare",
    "pattuglierebbe": "pattugliare",
    "pattuglierebber": "pattugliare",
    "pattuglierebbero": "pattugliare",
    "pattuglierei": "pattugliare",
    "pattuglieremmo": "pattugliare",
    "pattuglieremo": "pattugliare",
    "pattugliereste": "pattugliare",
    "pattuglieresti": "pattugliare",
    "pattuglierete": "pattugliare",
    "pattuglierà": "pattugliare",
    "pattuglierò": "pattugliare",
    "pattuglin": "pattugliare",
    "pattuglino": "pattugliare",
    "pattuglio": "pattugliare",
    "pattuglioni": "pattuglione",
    "pattugliò": "pattugliare",
    "pattui": "pattuire",
    "pattuiamo": "pattuire",
    "pattuiate": "pattuire",
    "pattuii": "pattuire",
    "pattuimmo": "pattuire",
    "pattuir": "pattuire",
    "pattuirai": "pattuire",
    "pattuiran": "pattuire",
    "pattuiranno": "pattuire",
    "pattuirebbe": "pattuire",
    "pattuirebber": "pattuire",
    "pattuirebbero": "pattuire",
    "pattuirei": "pattuire",
    "pattuiremmo": "pattuire",
    "pattuiremo": "pattuire",
    "pattuireste": "pattuire",
    "pattuiresti": "pattuire",
    "pattuirete": "pattuire",
    "pattuiron": "pattuire",
    "pattuirono": "pattuire",
    "pattuirà": "pattuire",
    "pattuirò": "pattuire",
    "pattuisse": "pattuire",
    "pattuisser": "pattuire",
    "pattuissero": "pattuire",
    "pattuissi": "pattuire",
    "pattuissimo": "pattuire",
    "pattuiste": "pattuire",
    "pattuisti": "pattuire",
    "pattuita": "pattuito",
    "pattuite": "pattuito",
    "pattuiti": "pattuito",
    "pattuito": "pattuire",
    "pattuiva": "pattuire",
    "pattuivamo": "pattuire",
    "pattuivan": "pattuire",
    "pattuivano": "pattuire",
    "pattuivate": "pattuire",
    "pattuivi": "pattuire",
    "pattuivo": "pattuire",
    "pattuizioni": "pattuizione",
    "pattumiere": "pattumiera",
    "pattuo": "pattuire",
    "pattuon": "pattuire",
    "pattuono": "pattuire",
    "pattuì": "pattuire",
    "patì": "patire",
    "pauperismi": "pauperismo",
    "paure": "paura",
    "paurosa": "pauroso",
    "paurose": "pauroso",
    "paurosi": "pauroso",
    "pause": "pausa",
    "paventa": "paventare",
    "paventai": "paventare",
    "paventammo": "paventare",
    "paventan": "paventare",
    "paventando": "paventare",
    "paventano": "paventare",
    "paventante": "paventare",
    "paventanti": "paventare",
    "paventar": "paventare",
    "paventaron": "paventare",
    "paventarono": "paventare",
    "paventasse": "paventare",
    "paventasser": "paventare",
    "paventassero": "paventare",
    "paventassi": "paventare",
    "paventassimo": "paventare",
    "paventaste": "paventare",
    "paventasti": "paventare",
    "paventata": "paventare",
    "paventate": "paventare",
    "paventati": "paventare",
    "paventato": "paventare",
    "paventava": "paventare",
    "paventavamo": "paventare",
    "paventavan": "paventare",
    "paventavano": "paventare",
    "paventavate": "paventare",
    "paventavi": "paventare",
    "paventavo": "paventare",
    "paventerai": "paventare",
    "paventeran": "paventare",
    "paventeranno": "paventare",
    "paventerebbe": "paventare",
    "paventerebber": "paventare",
    "paventerebbero": "paventare",
    "paventerei": "paventare",
    "paventeremmo": "paventare",
    "paventeremo": "paventare",
    "paventereste": "paventare",
    "paventeresti": "paventare",
    "paventerete": "paventare",
    "paventerà": "paventare",
    "paventerò": "paventare",
    "paventi": "paventare",
    "paventiamo": "paventare",
    "paventiate": "paventare",
    "paventin": "paventare",
    "paventino": "paventare",
    "pavento": "paventare",
    "paventò": "paventare",
    "pavesa": "pavesare",
    "pavesai": "pavesare",
    "pavesammo": "pavesare",
    "pavesan": "pavesare",
    "pavesando": "pavesare",
    "pavesano": "pavesare",
    "pavesante": "pavesare",
    "pavesanti": "pavesare",
    "pavesar": "pavesare",
    "pavesaron": "pavesare",
    "pavesarono": "pavesare",
    "pavesasse": "pavesare",
    "pavesasser": "pavesare",
    "pavesassero": "pavesare",
    "pavesassi": "pavesare",
    "pavesassimo": "pavesare",
    "pavesaste": "pavesare",
    "pavesasti": "pavesare",
    "pavesata": "pavesare",
    "pavesate": "pavesare",
    "pavesati": "pavesare",
    "pavesato": "pavesare",
    "pavesava": "pavesare",
    "pavesavamo": "pavesare",
    "pavesavan": "pavesare",
    "pavesavano": "pavesare",
    "pavesavate": "pavesare",
    "pavesavi": "pavesare",
    "pavesavo": "pavesare",
    "paveserai": "pavesare",
    "paveseran": "pavesare",
    "paveseranno": "pavesare",
    "paveserebbe": "pavesare",
    "paveserebber": "pavesare",
    "paveserebbero": "pavesare",
    "paveserei": "pavesare",
    "paveseremmo": "pavesare",
    "paveseremo": "pavesare",
    "pavesereste": "pavesare",
    "paveseresti": "pavesare",
    "paveserete": "pavesare",
    "paveserà": "pavesare",
    "paveserò": "pavesare",
    "pavesi": "pavese",
    "pavesiamo": "pavesare",
    "pavesiate": "pavesare",
    "pavesin": "pavesare",
    "pavesino": "pavesare",
    "paveso": "pavesare",
    "pavesò": "pavesare",
    "pavida": "pavido",
    "pavide": "pavido",
    "pavidi": "pavido",
    "pavimenta": "pavimentare",
    "pavimentai": "pavimentare",
    "pavimentammo": "pavimentare",
    "pavimentan": "pavimentare",
    "pavimentando": "pavimentare",
    "pavimentano": "pavimentare",
    "pavimentante": "pavimentare",
    "pavimentanti": "pavimentare",
    "pavimentar": "pavimentare",
    "pavimentaron": "pavimentare",
    "pavimentarono": "pavimentare",
    "pavimentasse": "pavimentare",
    "pavimentasser": "pavimentare",
    "pavimentassero": "pavimentare",
    "pavimentassi": "pavimentare",
    "pavimentassimo": "pavimentare",
    "pavimentaste": "pavimentare",
    "pavimentasti": "pavimentare",
    "pavimentata": "pavimentare",
    "pavimentate": "pavimentare",
    "pavimentati": "pavimentare",
    "pavimentato": "pavimentare",
    "pavimentava": "pavimentare",
    "pavimentavamo": "pavimentare",
    "pavimentavan": "pavimentare",
    "pavimentavano": "pavimentare",
    "pavimentavate": "pavimentare",
    "pavimentavi": "pavimentare",
    "pavimentavo": "pavimentare",
    "pavimentazioni": "pavimentazione",
    "pavimenterai": "pavimentare",
    "pavimenteran": "pavimentare",
    "pavimenteranno": "pavimentare",
    "pavimenterebbe": "pavimentare",
    "pavimenterebber": "pavimentare",
    "pavimenterebbero": "pavimentare",
    "pavimenterei": "pavimentare",
    "pavimenteremmo": "pavimentare",
    "pavimenteremo": "pavimentare",
    "pavimentereste": "pavimentare",
    "pavimenteresti": "pavimentare",
    "pavimenterete": "pavimentare",
    "pavimenterà": "pavimentare",
    "pavimenterò": "pavimentare",
    "pavimenti": "pavimento",
    "pavimentiamo": "pavimentare",
    "pavimentiate": "pavimentare",
    "pavimentin": "pavimentare",
    "pavimentino": "pavimentare",
    "pavimento": "pavimentare",
    "pavimentò": "pavimentare",
    "pavoneggerai": "pavoneggiare",
    "pavoneggeran": "pavoneggiare",
    "pavoneggeranno": "pavoneggiare",
    "pavoneggerebbe": "pavoneggiare",
    "pavoneggerebber": "pavoneggiare",
    "pavoneggerebbero": "pavoneggiare",
    "pavoneggerei": "pavoneggiare",
    "pavoneggeremmo": "pavoneggiare",
    "pavoneggeremo": "pavoneggiare",
    "pavoneggereste": "pavoneggiare",
    "pavoneggeresti": "pavoneggiare",
    "pavoneggerete": "pavoneggiare",
    "pavoneggerà": "pavoneggiare",
    "pavoneggerò": "pavoneggiare",
    "pavoneggi": "pavoneggiare",
    "pavoneggia": "pavoneggiare",
    "pavoneggiai": "pavoneggiare",
    "pavoneggiammo": "pavoneggiare",
    "pavoneggiamo": "pavoneggiare",
    "pavoneggian": "pavoneggiare",
    "pavoneggiando": "pavoneggiare",
    "pavoneggiano": "pavoneggiare",
    "pavoneggiar": "pavoneggiare",
    "pavoneggiaron": "pavoneggiare",
    "pavoneggiarono": "pavoneggiare",
    "pavoneggiasse": "pavoneggiare",
    "pavoneggiasser": "pavoneggiare",
    "pavoneggiassero": "pavoneggiare",
    "pavoneggiassi": "pavoneggiare",
    "pavoneggiassimo": "pavoneggiare",
    "pavoneggiaste": "pavoneggiare",
    "pavoneggiasti": "pavoneggiare",
    "pavoneggiata": "pavoneggiare",
    "pavoneggiate": "pavoneggiare",
    "pavoneggiati": "pavoneggiare",
    "pavoneggiato": "pavoneggiare",
    "pavoneggiava": "pavoneggiare",
    "pavoneggiavamo": "pavoneggiare",
    "pavoneggiavan": "pavoneggiare",
    "pavoneggiavano": "pavoneggiare",
    "pavoneggiavate": "pavoneggiare",
    "pavoneggiavi": "pavoneggiare",
    "pavoneggiavo": "pavoneggiare",
    "pavoneggin": "pavoneggiare",
    "pavoneggino": "pavoneggiare",
    "pavoneggio": "pavoneggiare",
    "pavoneggiò": "pavoneggiare",
    "pavoni": "pavone",
    "pazienta": "pazientare",
    "pazientai": "pazientare",
    "pazientammo": "pazientare",
    "pazientan": "pazientare",
    "pazientando": "pazientare",
    "pazientano": "pazientare",
    "pazientante": "pazientare",
    "pazientanti": "pazientare",
    "pazientar": "pazientare",
    "pazientaron": "pazientare",
    "pazientarono": "pazientare",
    "pazientasse": "pazientare",
    "pazientasser": "pazientare",
    "pazientassero": "pazientare",
    "pazientassi": "pazientare",
    "pazientassimo": "pazientare",
    "pazientaste": "pazientare",
    "pazientasti": "pazientare",
    "pazientata": "pazientare",
    "pazientate": "pazientare",
    "pazientati": "pazientare",
    "pazientato": "pazientare",
    "pazientava": "pazientare",
    "pazientavamo": "pazientare",
    "pazientavan": "pazientare",
    "pazientavano": "pazientare",
    "pazientavate": "pazientare",
    "pazientavi": "pazientare",
    "pazientavo": "pazientare",
    "pazienterai": "pazientare",
    "pazienteran": "pazientare",
    "pazienteranno": "pazientare",
    "pazienterebbe": "pazientare",
    "pazienterebber": "pazientare",
    "pazienterebbero": "pazientare",
    "pazienterei": "pazientare",
    "pazienteremmo": "pazientare",
    "pazienteremo": "pazientare",
    "pazientereste": "pazientare",
    "pazienteresti": "pazientare",
    "pazienterete": "pazientare",
    "pazienterà": "pazientare",
    "pazienterò": "pazientare",
    "pazienti": "paziente",
    "pazientiamo": "pazientare",
    "pazientiate": "pazientare",
    "pazientin": "pazientare",
    "pazientino": "pazientare",
    "paziento": "pazientare",
    "pazientò": "pazientare",
    "pazienze": "pazienza",
    "pazza": "pazzo",
    "pazzarielli": "pazzariello",
    "pazze": "pazzo",
    "pazzeggerai": "pazzeggiare",
    "pazzeggeran": "pazzeggiare",
    "pazzeggeranno": "pazzeggiare",
    "pazzeggerebbe": "pazzeggiare",
    "pazzeggerebber": "pazzeggiare",
    "pazzeggerebbero": "pazzeggiare",
    "pazzeggerei": "pazzeggiare",
    "pazzeggeremmo": "pazzeggiare",
    "pazzeggeremo": "pazzeggiare",
    "pazzeggereste": "pazzeggiare",
    "pazzeggeresti": "pazzeggiare",
    "pazzeggerete": "pazzeggiare",
    "pazzeggerà": "pazzeggiare",
    "pazzeggerò": "pazzeggiare",
    "pazzeggi": "pazzeggiare",
    "pazzeggia": "pazzeggiare",
    "pazzeggiai": "pazzeggiare",
    "pazzeggiammo": "pazzeggiare",
    "pazzeggiamo": "pazzeggiare",
    "pazzeggian": "pazzeggiare",
    "pazzeggiando": "pazzeggiare",
    "pazzeggiano": "pazzeggiare",
    "pazzeggiante": "pazzeggiare",
    "pazzeggianti": "pazzeggiare",
    "pazzeggiar": "pazzeggiare",
    "pazzeggiaron": "pazzeggiare",
    "pazzeggiarono": "pazzeggiare",
    "pazzeggiasse": "pazzeggiare",
    "pazzeggiasser": "pazzeggiare",
    "pazzeggiassero": "pazzeggiare",
    "pazzeggiassi": "pazzeggiare",
    "pazzeggiassimo": "pazzeggiare",
    "pazzeggiaste": "pazzeggiare",
    "pazzeggiasti": "pazzeggiare",
    "pazzeggiata": "pazzeggiare",
    "pazzeggiate": "pazzeggiare",
    "pazzeggiati": "pazzeggiare",
    "pazzeggiato": "pazzeggiare",
    "pazzeggiava": "pazzeggiare",
    "pazzeggiavamo": "pazzeggiare",
    "pazzeggiavan": "pazzeggiare",
    "pazzeggiavano": "pazzeggiare",
    "pazzeggiavate": "pazzeggiare",
    "pazzeggiavi": "pazzeggiare",
    "pazzeggiavo": "pazzeggiare",
    "pazzeggin": "pazzeggiare",
    "pazzeggino": "pazzeggiare",
    "pazzeggio": "pazzeggiare",
    "pazzeggiò": "pazzeggiare",
    "pazzerella": "pazzerello",
    "pazzerelle": "pazzerello",
    "pazzerelli": "pazzerello",
    "pazzerelloni": "pazzerellone",
    "pazzesca": "pazzesco",
    "pazzesche": "pazzesco",
    "pazzeschi": "pazzesco",
    "pazzi": "pazzo",
    "pazzie": "pazzia",
    "pazzoidi": "pazzoide",
    "pecca": "peccare",
    "peccai": "peccare",
    "peccaminosa": "peccaminoso",
    "peccaminose": "peccaminoso",
    "peccaminosi": "peccaminoso",
    "peccammo": "peccare",
    "peccan": "peccare",
    "peccando": "peccare",
    "peccano": "peccare",
    "peccante": "peccare",
    "peccanti": "peccare",
    "peccar": "peccare",
    "peccaron": "peccare",
    "peccarono": "peccare",
    "peccasse": "peccare",
    "peccasser": "peccare",
    "peccassero": "peccare",
    "peccassi": "peccare",
    "peccassimo": "peccare",
    "peccaste": "peccare",
    "peccasti": "peccare",
    "peccata": "peccare",
    "peccate": "peccare",
    "peccati": "peccato",
    "peccato": "peccare",
    "peccatori": "peccatore",
    "peccatrici": "peccatrice",
    "peccatucci": "peccatuccio",
    "peccava": "peccare",
    "peccavamo": "peccare",
    "peccavan": "peccare",
    "peccavano": "peccare",
    "peccavate": "peccare",
    "peccavi": "peccare",
    "peccavo": "peccare",
    "pecche": "pecca",
    "peccherai": "peccare",
    "peccheran": "peccare",
    "peccheranno": "peccare",
    "peccherebbe": "peccare",
    "peccherebber": "peccare",
    "peccherebbero": "peccare",
    "peccherei": "peccare",
    "peccheremmo": "peccare",
    "peccheremo": "peccare",
    "pecchereste": "peccare",
    "peccheresti": "peccare",
    "peccherete": "peccare",
    "peccherà": "peccare",
    "peccherò": "peccare",
    "pecchi": "peccare",
    "pecchiamo": "peccare",
    "pecchiate": "peccare",
    "pecchin": "peccare",
    "pecchino": "peccare",
    "pecco": "peccare",
    "peccò": "peccare",
    "pecette": "pecetta",
    "pechinesi": "pechinese",
    "peci": "pece",
    "pecorai": "pecoraio",
    "pecore": "pecora",
    "pecorecce": "pecoreccio",
    "pecorecci": "pecoreccio",
    "pecoreccia": "pecoreccio",
    "pecorelle": "pecorella",
    "pecorina": "pecorino",
    "pecorine": "pecorino",
    "pecorini": "pecorino",
    "peculati": "peculato",
    "peculi": "peculiare",
    "peculia": "peculiare",
    "peculiai": "peculiare",
    "peculiammo": "peculiare",
    "peculiamo": "peculiare",
    "peculian": "peculiare",
    "peculiando": "peculiare",
    "peculiano": "peculiare",
    "peculiante": "peculiare",
    "peculianti": "peculiare",
    "peculiar": "peculiare",
    "peculiari": "peculiare",
    "peculiaron": "peculiare",
    "peculiarono": "peculiare",
    "peculiasse": "peculiare",
    "peculiasser": "peculiare",
    "peculiassero": "peculiare",
    "peculiassi": "peculiare",
    "peculiassimo": "peculiare",
    "peculiaste": "peculiare",
    "peculiasti": "peculiare",
    "peculiata": "peculiare",
    "peculiate": "peculiare",
    "peculiati": "peculiare",
    "peculiato": "peculiare",
    "peculiava": "peculiare",
    "peculiavamo": "peculiare",
    "peculiavan": "peculiare",
    "peculiavano": "peculiare",
    "peculiavate": "peculiare",
    "peculiavi": "peculiare",
    "peculiavo": "peculiare",
    "peculierai": "peculiare",
    "peculieran": "peculiare",
    "peculieranno": "peculiare",
    "peculierebbe": "peculiare",
    "peculierebber": "peculiare",
    "peculierebbero": "peculiare",
    "peculierei": "peculiare",
    "peculieremmo": "peculiare",
    "peculieremo": "peculiare",
    "peculiereste": "peculiare",
    "peculieresti": "peculiare",
    "peculierete": "peculiare",
    "peculierà": "peculiare",
    "peculierò": "peculiare",
    "peculin": "peculiare",
    "peculino": "peculiare",
    "peculio": "peculiare",
    "peculiò": "peculiare",
    "pecuniari": "pecuniario",
    "pecuniaria": "pecuniario",
    "pecuniarie": "pecuniario",
    "pedaggi": "pedaggio",
    "pedagoghi": "pedagogo",
    "pedagogica": "pedagogico",
    "pedagogiche": "pedagogico",
    "pedagogici": "pedagogico",
    "pedagogico-punitiva": "pedagogico-punitivo",
    "pedagogico-punitive": "pedagogico-punitivo",
    "pedagogico-punitivi": "pedagogico-punitivo",
    "pedagogie": "pedagogia",
    "pedagogisti": "pedagogista",
    "pedala": "pedalare",
    "pedalabili": "pedalabile",
    "pedalai": "pedalare",
    "pedalammo": "pedalare",
    "pedalan": "pedalare",
    "pedalando": "pedalare",
    "pedalano": "pedalare",
    "pedalante": "pedalare",
    "pedalanti": "pedalare",
    "pedalar": "pedalare",
    "pedalaron": "pedalare",
    "pedalarono": "pedalare",
    "pedalasse": "pedalare",
    "pedalasser": "pedalare",
    "pedalassero": "pedalare",
    "pedalassi": "pedalare",
    "pedalassimo": "pedalare",
    "pedalaste": "pedalare",
    "pedalasti": "pedalare",
    "pedalata": "pedalare",
    "pedalate": "pedalata",
    "pedalati": "pedalare",
    "pedalato": "pedalare",
    "pedalatori": "pedalatore",
    "pedalava": "pedalare",
    "pedalavamo": "pedalare",
    "pedalavan": "pedalare",
    "pedalavano": "pedalare",
    "pedalavate": "pedalare",
    "pedalavi": "pedalare",
    "pedalavo": "pedalare",
    "pedalerai": "pedalare",
    "pedaleran": "pedalare",
    "pedaleranno": "pedalare",
    "pedalerebbe": "pedalare",
    "pedalerebber": "pedalare",
    "pedalerebbero": "pedalare",
    "pedalerei": "pedalare",
    "pedaleremmo": "pedalare",
    "pedaleremo": "pedalare",
    "pedalereste": "pedalare",
    "pedaleresti": "pedalare",
    "pedalerete": "pedalare",
    "pedalerà": "pedalare",
    "pedalerò": "pedalare",
    "pedali": "pedale",
    "pedaliamo": "pedalare",
    "pedaliate": "pedalare",
    "pedalin": "pedalare",
    "pedalini": "pedalino",
    "pedalino": "pedalare",
    "pedalo": "pedalare",
    "pedalò": "pedalare",
    "pedane": "pedana",
    "pedanteggerai": "pedanteggiare",
    "pedanteggeran": "pedanteggiare",
    "pedanteggeranno": "pedanteggiare",
    "pedanteggerebbe": "pedanteggiare",
    "pedanteggerebber": "pedanteggiare",
    "pedanteggerebbero": "pedanteggiare",
    "pedanteggerei": "pedanteggiare",
    "pedanteggeremmo": "pedanteggiare",
    "pedanteggeremo": "pedanteggiare",
    "pedanteggereste": "pedanteggiare",
    "pedanteggeresti": "pedanteggiare",
    "pedanteggerete": "pedanteggiare",
    "pedanteggerà": "pedanteggiare",
    "pedanteggerò": "pedanteggiare",
    "pedanteggi": "pedanteggiare",
    "pedanteggia": "pedanteggiare",
    "pedanteggiai": "pedanteggiare",
    "pedanteggiammo": "pedanteggiare",
    "pedanteggiamo": "pedanteggiare",
    "pedanteggian": "pedanteggiare",
    "pedanteggiando": "pedanteggiare",
    "pedanteggiano": "pedanteggiare",
    "pedanteggiante": "pedanteggiare",
    "pedanteggianti": "pedanteggiare",
    "pedanteggiar": "pedanteggiare",
    "pedanteggiaron": "pedanteggiare",
    "pedanteggiarono": "pedanteggiare",
    "pedanteggiasse": "pedanteggiare",
    "pedanteggiasser": "pedanteggiare",
    "pedanteggiassero": "pedanteggiare",
    "pedanteggiassi": "pedanteggiare",
    "pedanteggiassimo": "pedanteggiare",
    "pedanteggiaste": "pedanteggiare",
    "pedanteggiasti": "pedanteggiare",
    "pedanteggiata": "pedanteggiare",
    "pedanteggiate": "pedanteggiare",
    "pedanteggiati": "pedanteggiare",
    "pedanteggiato": "pedanteggiare",
    "pedanteggiava": "pedanteggiare",
    "pedanteggiavamo": "pedanteggiare",
    "pedanteggiavan": "pedanteggiare",
    "pedanteggiavano": "pedanteggiare",
    "pedanteggiavate": "pedanteggiare",
    "pedanteggiavi": "pedanteggiare",
    "pedanteggiavo": "pedanteggiare",
    "pedanteggin": "pedanteggiare",
    "pedanteggino": "pedanteggiare",
    "pedanteggio": "pedanteggiare",
    "pedanteggiò": "pedanteggiare",
    "pedanterie": "pedanteria",
    "pedantesca": "pedantesco",
    "pedantesche": "pedantesco",
    "pedanteschi": "pedantesco",
    "pedanti": "pedante",
    "pedate": "pedata",
    "pedatori": "pedatore",
    "pedemontana": "pedemontano",
    "pedemontane": "pedemontano",
    "pedemontani": "pedemontano",
    "pederasti": "pederasta",
    "pedestri": "pedestre",
    "pediatre": "pediatra",
    "pediatri": "pediatra",
    "pediatrica": "pediatrico",
    "pediatriche": "pediatrico",
    "pediatrici": "pediatrico",
    "pedina": "pedinare",
    "pedinai": "pedinare",
    "pedinamenti": "pedinamento",
    "pedinammo": "pedinare",
    "pedinan": "pedinare",
    "pedinando": "pedinare",
    "pedinano": "pedinare",
    "pedinante": "pedinare",
    "pedinanti": "pedinare",
    "pedinar": "pedinare",
    "pedinaron": "pedinare",
    "pedinarono": "pedinare",
    "pedinasse": "pedinare",
    "pedinasser": "pedinare",
    "pedinassero": "pedinare",
    "pedinassi": "pedinare",
    "pedinassimo": "pedinare",
    "pedinaste": "pedinare",
    "pedinasti": "pedinare",
    "pedinata": "pedinare",
    "pedinate": "pedinare",
    "pedinati": "pedinare",
    "pedinato": "pedinare",
    "pedinava": "pedinare",
    "pedinavamo": "pedinare",
    "pedinavan": "pedinare",
    "pedinavano": "pedinare",
    "pedinavate": "pedinare",
    "pedinavi": "pedinare",
    "pedinavo": "pedinare",
    "pedine": "pedina",
    "pedinerai": "pedinare",
    "pedineran": "pedinare",
    "pedineranno": "pedinare",
    "pedinerebbe": "pedinare",
    "pedinerebber": "pedinare",
    "pedinerebbero": "pedinare",
    "pedinerei": "pedinare",
    "pedineremmo": "pedinare",
    "pedineremo": "pedinare",
    "pedinereste": "pedinare",
    "pedineresti": "pedinare",
    "pedinerete": "pedinare",
    "pedinerà": "pedinare",
    "pedinerò": "pedinare",
    "pedini": "pedinare",
    "pediniamo": "pedinare",
    "pediniate": "pedinare",
    "pedinin": "pedinare",
    "pedinino": "pedinare",
    "pedino": "pedinare",
    "pedinò": "pedinare",
    "pedissequa": "pedissequo",
    "pedisseque": "pedissequo",
    "pedissequi": "pedissequo",
    "pedivelle": "pedivella",
    "pedofili": "pedofilo",
    "pedofilie": "pedofilia",
    "pedonali": "pedonale",
    "pedonalizza": "pedonalizzare",
    "pedonalizzai": "pedonalizzare",
    "pedonalizzammo": "pedonalizzare",
    "pedonalizzan": "pedonalizzare",
    "pedonalizzando": "pedonalizzare",
    "pedonalizzano": "pedonalizzare",
    "pedonalizzante": "pedonalizzare",
    "pedonalizzanti": "pedonalizzare",
    "pedonalizzar": "pedonalizzare",
    "pedonalizzaron": "pedonalizzare",
    "pedonalizzarono": "pedonalizzare",
    "pedonalizzasse": "pedonalizzare",
    "pedonalizzasser": "pedonalizzare",
    "pedonalizzassero": "pedonalizzare",
    "pedonalizzassi": "pedonalizzare",
    "pedonalizzassimo": "pedonalizzare",
    "pedonalizzaste": "pedonalizzare",
    "pedonalizzasti": "pedonalizzare",
    "pedonalizzata": "pedonalizzare",
    "pedonalizzate": "pedonalizzare",
    "pedonalizzati": "pedonalizzare",
    "pedonalizzato": "pedonalizzare",
    "pedonalizzava": "pedonalizzare",
    "pedonalizzavamo": "pedonalizzare",
    "pedonalizzavan": "pedonalizzare",
    "pedonalizzavano": "pedonalizzare",
    "pedonalizzavate": "pedonalizzare",
    "pedonalizzavi": "pedonalizzare",
    "pedonalizzavo": "pedonalizzare",
    "pedonalizzerai": "pedonalizzare",
    "pedonalizzeran": "pedonalizzare",
    "pedonalizzeranno": "pedonalizzare",
    "pedonalizzerebbe": "pedonalizzare",
    "pedonalizzerebber": "pedonalizzare",
    "pedonalizzerebbero": "pedonalizzare",
    "pedonalizzerei": "pedonalizzare",
    "pedonalizzeremmo": "pedonalizzare",
    "pedonalizzeremo": "pedonalizzare",
    "pedonalizzereste": "pedonalizzare",
    "pedonalizzeresti": "pedonalizzare",
    "pedonalizzerete": "pedonalizzare",
    "pedonalizzerà": "pedonalizzare",
    "pedonalizzerò": "pedonalizzare",
    "pedonalizzi": "pedonalizzare",
    "pedonalizziamo": "pedonalizzare",
    "pedonalizziate": "pedonalizzare",
    "pedonalizzin": "pedonalizzare",
    "pedonalizzino": "pedonalizzare",
    "pedonalizzo": "pedonalizzare",
    "pedonalizzò": "pedonalizzare",
    "pedoni": "pedone",
    "peggiora": "peggiorare",
    "peggiorai": "peggiorare",
    "peggioramenti": "peggioramento",
    "peggiorammo": "peggiorare",
    "peggioran": "peggiorare",
    "peggiorando": "peggiorare",
    "peggiorano": "peggiorare",
    "peggiorante": "peggiorare",
    "peggioranti": "peggiorare",
    "peggiorar": "peggiorare",
    "peggioraron": "peggiorare",
    "peggiorarono": "peggiorare",
    "peggiorasse": "peggiorare",
    "peggiorasser": "peggiorare",
    "peggiorassero": "peggiorare",
    "peggiorassi": "peggiorare",
    "peggiorassimo": "peggiorare",
    "peggioraste": "peggiorare",
    "peggiorasti": "peggiorare",
    "peggiorata": "peggiorare",
    "peggiorate": "peggiorare",
    "peggiorati": "peggiorare",
    "peggiorativa": "peggiorativo",
    "peggiorative": "peggiorativo",
    "peggiorativi": "peggiorativo",
    "peggiorato": "peggiorare",
    "peggiorava": "peggiorare",
    "peggioravamo": "peggiorare",
    "peggioravan": "peggiorare",
    "peggioravano": "peggiorare",
    "peggioravate": "peggiorare",
    "peggioravi": "peggiorare",
    "peggioravo": "peggiorare",
    "peggiore": "cattivo",
    "peggiorerai": "peggiorare",
    "peggioreran": "peggiorare",
    "peggioreranno": "peggiorare",
    "peggiorerebbe": "peggiorare",
    "peggiorerebber": "peggiorare",
    "peggiorerebbero": "peggiorare",
    "peggiorerei": "peggiorare",
    "peggioreremmo": "peggiorare",
    "peggioreremo": "peggiorare",
    "peggiorereste": "peggiorare",
    "peggioreresti": "peggiorare",
    "peggiorerete": "peggiorare",
    "peggiorerà": "peggiorare",
    "peggiorerò": "peggiorare",
    "peggiori": "peggiore",
    "peggioriamo": "peggiorare",
    "peggioriate": "peggiorare",
    "peggiorin": "peggiorare",
    "peggiorino": "peggiorare",
    "peggioro": "peggiorare",
    "peggiorò": "peggiorare",
    "pegni": "pegno",
    "pela": "pelare",
    "pelai": "pelare",
    "pelammo": "pelare",
    "pelan": "pelare",
    "pelando": "pelare",
    "pelano": "pelare",
    "pelante": "pelare",
    "pelanti": "pelare",
    "pelar": "pelare",
    "pelaron": "pelare",
    "pelarono": "pelare",
    "pelasse": "pelare",
    "pelasser": "pelare",
    "pelassero": "pelare",
    "pelassi": "pelare",
    "pelassimo": "pelare",
    "pelaste": "pelare",
    "pelasti": "pelare",
    "pelata": "pelato",
    "pelate": "pelato",
    "pelati": "pelato",
    "pelato": "pelare",
    "pelava": "pelare",
    "pelavamo": "pelare",
    "pelavan": "pelare",
    "pelavano": "pelare",
    "pelavate": "pelare",
    "pelavi": "pelare",
    "pelavo": "pelare",
    "pelerai": "pelare",
    "peleran": "pelare",
    "peleranno": "pelare",
    "pelerebbe": "pelare",
    "pelerebber": "pelare",
    "pelerebbero": "pelare",
    "pelerei": "pelare",
    "peleremmo": "pelare",
    "peleremo": "pelare",
    "pelereste": "pelare",
    "peleresti": "pelare",
    "pelerete": "pelare",
    "pelerà": "pelare",
    "pelerò": "pelare",
    "peli": "pelo",
    "peliamo": "pelare",
    "peliate": "pelare",
    "pelin": "pelare",
    "pelino": "pelare",
    "pellegrina": "pellegrino",
    "pellegrinaggi": "pellegrinaggio",
    "pellegrinai": "pellegrinare",
    "pellegrinammo": "pellegrinare",
    "pellegrinan": "pellegrinare",
    "pellegrinando": "pellegrinare",
    "pellegrinano": "pellegrinare",
    "pellegrinante": "pellegrinare",
    "pellegrinanti": "pellegrinare",
    "pellegrinar": "pellegrinare",
    "pellegrinaron": "pellegrinare",
    "pellegrinarono": "pellegrinare",
    "pellegrinasse": "pellegrinare",
    "pellegrinasser": "pellegrinare",
    "pellegrinassero": "pellegrinare",
    "pellegrinassi": "pellegrinare",
    "pellegrinassimo": "pellegrinare",
    "pellegrinaste": "pellegrinare",
    "pellegrinasti": "pellegrinare",
    "pellegrinata": "pellegrinare",
    "pellegrinate": "pellegrinare",
    "pellegrinati": "pellegrinare",
    "pellegrinato": "pellegrinare",
    "pellegrinava": "pellegrinare",
    "pellegrinavamo": "pellegrinare",
    "pellegrinavan": "pellegrinare",
    "pellegrinavano": "pellegrinare",
    "pellegrinavate": "pellegrinare",
    "pellegrinavi": "pellegrinare",
    "pellegrinavo": "pellegrinare",
    "pellegrine": "pellegrino",
    "pellegrinerai": "pellegrinare",
    "pellegrineran": "pellegrinare",
    "pellegrineranno": "pellegrinare",
    "pellegrinerebbe": "pellegrinare",
    "pellegrinerebber": "pellegrinare",
    "pellegrinerebbero": "pellegrinare",
    "pellegrinerei": "pellegrinare",
    "pellegrineremmo": "pellegrinare",
    "pellegrineremo": "pellegrinare",
    "pellegrinereste": "pellegrinare",
    "pellegrineresti": "pellegrinare",
    "pellegrinerete": "pellegrinare",
    "pellegrinerà": "pellegrinare",
    "pellegrinerò": "pellegrinare",
    "pellegrini": "pellegrino",
    "pellegriniamo": "pellegrinare",
    "pellegriniate": "pellegrinare",
    "pellegrinin": "pellegrinare",
    "pellegrinino": "pellegrinare",
    "pellegrino": "pellegrinare",
    "pellegrinò": "pellegrinare",
    "pelletterie": "pelletteria",
    "pelli": "pelle",
    "pellicce": "pelliccia",
    "pelliccerie": "pellicceria",
    "pellicciai": "pellicciaio",
    "pellicole": "pellicola",
    "pelo": "pelare",
    "pelosa": "peloso",
    "pelose": "peloso",
    "pelosi": "peloso",
    "pelurie": "peluria",
    "pelò": "pelare",
    "pena": "penare",
    "penai": "penare",
    "penali": "penale",
    "penalisti": "penalista",
    "penalizza": "penalizzare",
    "penalizzai": "penalizzare",
    "penalizzammo": "penalizzare",
    "penalizzan": "penalizzare",
    "penalizzando": "penalizzare",
    "penalizzano": "penalizzare",
    "penalizzante": "penalizzare",
    "penalizzanti": "penalizzare",
    "penalizzar": "penalizzare",
    "penalizzaron": "penalizzare",
    "penalizzarono": "penalizzare",
    "penalizzasse": "penalizzare",
    "penalizzasser": "penalizzare",
    "penalizzassero": "penalizzare",
    "penalizzassi": "penalizzare",
    "penalizzassimo": "penalizzare",
    "penalizzaste": "penalizzare",
    "penalizzasti": "penalizzare",
    "penalizzata": "penalizzare",
    "penalizzate": "penalizzare",
    "penalizzati": "penalizzare",
    "penalizzato": "penalizzare",
    "penalizzava": "penalizzare",
    "penalizzavamo": "penalizzare",
    "penalizzavan": "penalizzare",
    "penalizzavano": "penalizzare",
    "penalizzavate": "penalizzare",
    "penalizzavi": "penalizzare",
    "penalizzavo": "penalizzare",
    "penalizzazioni": "penalizzazione",
    "penalizzerai": "penalizzare",
    "penalizzeran": "penalizzare",
    "penalizzeranno": "penalizzare",
    "penalizzerebbe": "penalizzare",
    "penalizzerebber": "penalizzare",
    "penalizzerebbero": "penalizzare",
    "penalizzerei": "penalizzare",
    "penalizzeremmo": "penalizzare",
    "penalizzeremo": "penalizzare",
    "penalizzereste": "penalizzare",
    "penalizzeresti": "penalizzare",
    "penalizzerete": "penalizzare",
    "penalizzerà": "penalizzare",
    "penalizzerò": "penalizzare",
    "penalizzi": "penalizzare",
    "penalizziamo": "penalizzare",
    "penalizziate": "penalizzare",
    "penalizzin": "penalizzare",
    "penalizzino": "penalizzare",
    "penalizzo": "penalizzare",
    "penalizzò": "penalizzare",
    "penammo": "penare",
    "penan": "penare",
    "penando": "penare",
    "penano": "penare",
    "penante": "penare",
    "penanti": "penare",
    "penar": "penare",
    "penaron": "penare",
    "penarono": "penare",
    "penasse": "penare",
    "penasser": "penare",
    "penassero": "penare",
    "penassi": "penare",
    "penassimo": "penare",
    "penaste": "penare",
    "penasti": "penare",
    "penata": "penare",
    "penate": "penare",
    "penati": "penare",
    "penato": "penare",
    "penava": "penare",
    "penavamo": "penare",
    "penavan": "penare",
    "penavano": "penare",
    "penavate": "penare",
    "penavi": "penare",
    "penavo": "penare",
    "pencola": "pencolare",
    "pencolai": "pencolare",
    "pencolammo": "pencolare",
    "pencolan": "pencolare",
    "pencolando": "pencolare",
    "pencolano": "pencolare",
    "pencolante": "pencolare",
    "pencolanti": "pencolare",
    "pencolar": "pencolare",
    "pencolaron": "pencolare",
    "pencolarono": "pencolare",
    "pencolasse": "pencolare",
    "pencolasser": "pencolare",
    "pencolassero": "pencolare",
    "pencolassi": "pencolare",
    "pencolassimo": "pencolare",
    "pencolaste": "pencolare",
    "pencolasti": "pencolare",
    "pencolata": "pencolare",
    "pencolate": "pencolare",
    "pencolati": "pencolare",
    "pencolato": "pencolare",
    "pencolava": "pencolare",
    "pencolavamo": "pencolare",
    "pencolavan": "pencolare",
    "pencolavano": "pencolare",
    "pencolavate": "pencolare",
    "pencolavi": "pencolare",
    "pencolavo": "pencolare",
    "pencolerai": "pencolare",
    "pencoleran": "pencolare",
    "pencoleranno": "pencolare",
    "pencolerebbe": "pencolare",
    "pencolerebber": "pencolare",
    "pencolerebbero": "pencolare",
    "pencolerei": "pencolare",
    "pencoleremmo": "pencolare",
    "pencoleremo": "pencolare",
    "pencolereste": "pencolare",
    "pencoleresti": "pencolare",
    "pencolerete": "pencolare",
    "pencolerà": "pencolare",
    "pencolerò": "pencolare",
    "pencoli": "pencolare",
    "pencoliamo": "pencolare",
    "pencoliate": "pencolare",
    "pencolin": "pencolare",
    "pencolino": "pencolare",
    "pencolo": "pencolare",
    "pencolò": "pencolare",
    "penda": "pendere",
    "pendagli": "pendaglio",
    "pendan": "pendere",
    "pendano": "pendere",
    "pende": "pendere",
    "pendemmo": "pendere",
    "pendendo": "pendere",
    "pendente": "pendere",
    "pendenti": "pendere",
    "pendenze": "pendenza",
    "pender": "pendere",
    "penderai": "pendere",
    "penderan": "pendere",
    "penderanno": "pendere",
    "penderebbe": "pendere",
    "penderebber": "pendere",
    "penderebbero": "pendere",
    "penderei": "pendere",
    "penderemmo": "pendere",
    "penderemo": "pendere",
    "pendereste": "pendere",
    "penderesti": "pendere",
    "penderete": "pendere",
    "penderà": "pendere",
    "penderò": "pendere",
    "pendesse": "pendere",
    "pendesser": "pendere",
    "pendessero": "pendere",
    "pendessi": "pendere",
    "pendessimo": "pendere",
    "pendeste": "pendere",
    "pendesti": "pendere",
    "pendete": "pendere",
    "pendeva": "pendere",
    "pendevamo": "pendere",
    "pendevan": "pendere",
    "pendevano": "pendere",
    "pendevate": "pendere",
    "pendevi": "pendere",
    "pendevo": "pendere",
    "pendi": "pendere",
    "pendiamo": "pendere",
    "pendiate": "pendere",
    "pendici": "pendice",
    "pendii": "pendio",
    "pendo": "pendere",
    "pendola": "pendolare",
    "pendolai": "pendolare",
    "pendolammo": "pendolare",
    "pendolan": "pendolare",
    "pendolando": "pendolare",
    "pendolano": "pendolare",
    "pendolante": "pendolare",
    "pendolanti": "pendolare",
    "pendolar": "pendolare",
    "pendolari": "pendolare",
    "pendolarismi": "pendolarismo",
    "pendolaron": "pendolare",
    "pendolarono": "pendolare",
    "pendolasse": "pendolare",
    "pendolasser": "pendolare",
    "pendolassero": "pendolare",
    "pendolassi": "pendolare",
    "pendolassimo": "pendolare",
    "pendolaste": "pendolare",
    "pendolasti": "pendolare",
    "pendolata": "pendolare",
    "pendolate": "pendolare",
    "pendolati": "pendolare",
    "pendolato": "pendolare",
    "pendolava": "pendolare",
    "pendolavamo": "pendolare",
    "pendolavan": "pendolare",
    "pendolavano": "pendolare",
    "pendolavate": "pendolare",
    "pendolavi": "pendolare",
    "pendolavo": "pendolare",
    "pendole": "pendola",
    "pendolerai": "pendolare",
    "pendoleran": "pendolare",
    "pendoleranno": "pendolare",
    "pendolerebbe": "pendolare",
    "pendolerebber": "pendolare",
    "pendolerebbero": "pendolare",
    "pendolerei": "pendolare",
    "pendoleremmo": "pendolare",
    "pendoleremo": "pendolare",
    "pendolereste": "pendolare",
    "pendoleresti": "pendolare",
    "pendolerete": "pendolare",
    "pendolerà": "pendolare",
    "pendolerò": "pendolare",
    "pendoli": "pendolo",
    "pendoliamo": "pendolare",
    "pendoliate": "pendolare",
    "pendolin": "pendolare",
    "pendolini": "pendolino",
    "pendolino": "pendolare",
    "pendolo": "pendolare",
    "pendolò": "pendolare",
    "pendon": "pendere",
    "pendono": "pendere",
    "pendula": "pendulo",
    "pendule": "pendulo",
    "penduli": "pendulo",
    "pene": "pena",
    "penerai": "penare",
    "peneran": "penare",
    "peneranno": "penare",
    "penerebbe": "penare",
    "penerebber": "penare",
    "penerebbero": "penare",
    "penerei": "penare",
    "peneremmo": "penare",
    "peneremo": "penare",
    "penereste": "penare",
    "peneresti": "penare",
    "penerete": "penare",
    "penerà": "penare",
    "penerò": "penare",
    "penetra": "penetrare",
    "penetrabili": "penetrabile",
    "penetrai": "penetrare",
    "penetrammo": "penetrare",
    "penetran": "penetrare",
    "penetrando": "penetrare",
    "penetrano": "penetrare",
    "penetrante": "penetrare",
    "penetranti": "penetrare",
    "penetrar": "penetrare",
    "penetraron": "penetrare",
    "penetrarono": "penetrare",
    "penetrasse": "penetrare",
    "penetrasser": "penetrare",
    "penetrassero": "penetrare",
    "penetrassi": "penetrare",
    "penetrassimo": "penetrare",
    "penetraste": "penetrare",
    "penetrasti": "penetrare",
    "penetrata": "penetrare",
    "penetrate": "penetrare",
    "penetrati": "penetrare",
    "penetrato": "penetrare",
    "penetrava": "penetrare",
    "penetravamo": "penetrare",
    "penetravan": "penetrare",
    "penetravano": "penetrare",
    "penetravate": "penetrare",
    "penetravi": "penetrare",
    "penetravo": "penetrare",
    "penetrazioni": "penetrazione",
    "penetrerai": "penetrare",
    "penetreran": "penetrare",
    "penetreranno": "penetrare",
    "penetrerebbe": "penetrare",
    "penetrerebber": "penetrare",
    "penetrerebbero": "penetrare",
    "penetrerei": "penetrare",
    "penetreremmo": "penetrare",
    "penetreremo": "penetrare",
    "penetrereste": "penetrare",
    "penetreresti": "penetrare",
    "penetrerete": "penetrare",
    "penetrerà": "penetrare",
    "penetrerò": "penetrare",
    "penetri": "penetrare",
    "penetriamo": "penetrare",
    "penetriate": "penetrare",
    "penetrin": "penetrare",
    "penetrino": "penetrare",
    "penetro": "penetrare",
    "penetrò": "penetrare",
    "peni": "pene",
    "peniamo": "penare",
    "peniate": "penare",
    "penicilline": "penicillina",
    "penin": "penare",
    "penino": "penare",
    "peninsulari": "peninsulare",
    "penisole": "penisola",
    "penitenti": "penitente",
    "penitenze": "penitenza",
    "penitenziali": "penitenziale",
    "penitenziari": "penitenziario",
    "penitenziaria": "penitenziario",
    "penitenziarie": "penitenziario",
    "pennacchi": "pennacchio",
    "pennarelli": "pennarello",
    "penne": "penna",
    "pennella": "pennellare",
    "pennellai": "pennellare",
    "pennellammo": "pennellare",
    "pennellan": "pennellare",
    "pennellando": "pennellare",
    "pennellano": "pennellare",
    "pennellante": "pennellare",
    "pennellanti": "pennellare",
    "pennellar": "pennellare",
    "pennellaron": "pennellare",
    "pennellarono": "pennellare",
    "pennellasse": "pennellare",
    "pennellasser": "pennellare",
    "pennellassero": "pennellare",
    "pennellassi": "pennellare",
    "pennellassimo": "pennellare",
    "pennellaste": "pennellare",
    "pennellasti": "pennellare",
    "pennellata": "pennellare",
    "pennellate": "pennellata",
    "pennellati": "pennellare",
    "pennellato": "pennellare",
    "pennellava": "pennellare",
    "pennellavamo": "pennellare",
    "pennellavan": "pennellare",
    "pennellavano": "pennellare",
    "pennellavate": "pennellare",
    "pennellavi": "pennellare",
    "pennellavo": "pennellare",
    "pennelleggerai": "pennelleggiare",
    "pennelleggeran": "pennelleggiare",
    "pennelleggeranno": "pennelleggiare",
    "pennelleggerebbe": "pennelleggiare",
    "pennelleggerebber": "pennelleggiare",
    "pennelleggerebbero": "pennelleggiare",
    "pennelleggerei": "pennelleggiare",
    "pennelleggeremmo": "pennelleggiare",
    "pennelleggeremo": "pennelleggiare",
    "pennelleggereste": "pennelleggiare",
    "pennelleggeresti": "pennelleggiare",
    "pennelleggerete": "pennelleggiare",
    "pennelleggerà": "pennelleggiare",
    "pennelleggerò": "pennelleggiare",
    "pennelleggi": "pennelleggiare",
    "pennelleggia": "pennelleggiare",
    "pennelleggiai": "pennelleggiare",
    "pennelleggiammo": "pennelleggiare",
    "pennelleggiamo": "pennelleggiare",
    "pennelleggian": "pennelleggiare",
    "pennelleggiando": "pennelleggiare",
    "pennelleggiano": "pennelleggiare",
    "pennelleggiante": "pennelleggiare",
    "pennelleggianti": "pennelleggiare",
    "pennelleggiar": "pennelleggiare",
    "pennelleggiaron": "pennelleggiare",
    "pennelleggiarono": "pennelleggiare",
    "pennelleggiasse": "pennelleggiare",
    "pennelleggiasser": "pennelleggiare",
    "pennelleggiassero": "pennelleggiare",
    "pennelleggiassi": "pennelleggiare",
    "pennelleggiassimo": "pennelleggiare",
    "pennelleggiaste": "pennelleggiare",
    "pennelleggiasti": "pennelleggiare",
    "pennelleggiata": "pennelleggiare",
    "pennelleggiate": "pennelleggiare",
    "pennelleggiati": "pennelleggiare",
    "pennelleggiato": "pennelleggiare",
    "pennelleggiava": "pennelleggiare",
    "pennelleggiavamo": "pennelleggiare",
    "pennelleggiavan": "pennelleggiare",
    "pennelleggiavano": "pennelleggiare",
    "pennelleggiavate": "pennelleggiare",
    "pennelleggiavi": "pennelleggiare",
    "pennelleggiavo": "pennelleggiare",
    "pennelleggin": "pennelleggiare",
    "pennelleggino": "pennelleggiare",
    "pennelleggio": "pennelleggiare",
    "pennelleggiò": "pennelleggiare",
    "pennellerai": "pennellare",
    "pennelleran": "pennellare",
    "pennelleranno": "pennellare",
    "pennellerebbe": "pennellare",
    "pennellerebber": "pennellare",
    "pennellerebbero": "pennellare",
    "pennellerei": "pennellare",
    "pennelleremmo": "pennellare",
    "pennelleremo": "pennellare",
    "pennellereste": "pennellare",
    "pennelleresti": "pennellare",
    "pennellerete": "pennellare",
    "pennellerà": "pennellare",
    "pennellerò": "pennellare",
    "pennelli": "pennello",
    "pennelliamo": "pennellare",
    "pennelliate": "pennellare",
    "pennellin": "pennellare",
    "pennellino": "pennellare",
    "pennello": "pennellare",
    "pennellò": "pennellare",
    "pennichelle": "pennichella",
    "pennini": "pennino",
    "pennivendoli": "pennivendolo",
    "pennoni": "pennone",
    "pennuta": "pennuto",
    "pennute": "pennuto",
    "pennuti": "pennuto",
    "peno": "penare",
    "penosa": "penoso",
    "penose": "penoso",
    "penosi": "penoso",
    "pensa": "pensare",
    "pensabili": "pensabile",
    "pensai": "pensare",
    "pensammo": "pensare",
    "pensan": "pensare",
    "pensando": "pensare",
    "pensano": "pensare",
    "pensante": "pensare",
    "pensanti": "pensare",
    "pensar": "pensare",
    "pensaron": "pensare",
    "pensarono": "pensare",
    "pensasse": "pensare",
    "pensasser": "pensare",
    "pensassero": "pensare",
    "pensassi": "pensare",
    "pensassimo": "pensare",
    "pensaste": "pensare",
    "pensasti": "pensare",
    "pensata": "pensare",
    "pensate": "pensata",
    "pensati": "pensare",
    "pensato": "pensare",
    "pensatoi": "pensatoio",
    "pensatori": "pensatore",
    "pensava": "pensare",
    "pensavamo": "pensare",
    "pensavan": "pensare",
    "pensavano": "pensare",
    "pensavate": "pensare",
    "pensavi": "pensare",
    "pensavo": "pensare",
    "penserai": "pensare",
    "penseran": "pensare",
    "penseranno": "pensare",
    "penserebbe": "pensare",
    "penserebber": "pensare",
    "penserebbero": "pensare",
    "penserei": "pensare",
    "penseremmo": "pensare",
    "penseremo": "pensare",
    "pensereste": "pensare",
    "penseresti": "pensare",
    "penserete": "pensare",
    "penserà": "pensare",
    "penserò": "pensare",
    "pensi": "pensare",
    "pensiamo": "pensare",
    "pensiate": "pensare",
    "pensieri": "pensiero",
    "pensierini": "pensierino",
    "pensierosa": "pensieroso",
    "pensierose": "pensieroso",
    "pensierosi": "pensieroso",
    "pensili": "pensile",
    "pensiline": "pensilina",
    "pensin": "pensare",
    "pensino": "pensare",
    "pensiona": "pensionare",
    "pensionabili": "pensionabile",
    "pensionai": "pensionare",
    "pensionamenti": "pensionamento",
    "pensionammo": "pensionare",
    "pensionan": "pensionare",
    "pensionando": "pensionare",
    "pensionano": "pensionare",
    "pensionante": "pensionare",
    "pensionanti": "pensionare",
    "pensionar": "pensionare",
    "pensionaron": "pensionare",
    "pensionarono": "pensionare",
    "pensionasse": "pensionare",
    "pensionasser": "pensionare",
    "pensionassero": "pensionare",
    "pensionassi": "pensionare",
    "pensionassimo": "pensionare",
    "pensionaste": "pensionare",
    "pensionasti": "pensionare",
    "pensionata": "pensionato",
    "pensionate": "pensionato",
    "pensionati": "pensionato",
    "pensionato": "pensionare",
    "pensionava": "pensionare",
    "pensionavamo": "pensionare",
    "pensionavan": "pensionare",
    "pensionavano": "pensionare",
    "pensionavate": "pensionare",
    "pensionavi": "pensionare",
    "pensionavo": "pensionare",
    "pensioncine": "pensioncina",
    "pensionerai": "pensionare",
    "pensioneran": "pensionare",
    "pensioneranno": "pensionare",
    "pensionerebbe": "pensionare",
    "pensionerebber": "pensionare",
    "pensionerebbero": "pensionare",
    "pensionerei": "pensionare",
    "pensioneremmo": "pensionare",
    "pensioneremo": "pensionare",
    "pensionereste": "pensionare",
    "pensioneresti": "pensionare",
    "pensionerete": "pensionare",
    "pensionerà": "pensionare",
    "pensionerò": "pensionare",
    "pensioni": "pensione",
    "pensioniamo": "pensionare",
    "pensioniate": "pensionare",
    "pensionin": "pensionare",
    "pensionino": "pensionare",
    "pensionistica": "pensionistico",
    "pensionistiche": "pensionistico",
    "pensionistici": "pensionistico",
    "pensiono": "pensionare",
    "pensionò": "pensionare",
    "penso": "pensare",
    "pensosa": "pensoso",
    "pensose": "pensoso",
    "pensosi": "pensoso",
    "pensò": "pensare",
    "penta": "pentire",
    "pentacolori": "pentacolore",
    "pentagrammi": "pentagramma",
    "pentan": "pentire",
    "pentano": "pentire",
    "pentapartita": "pentapartito",
    "pentapartite": "pentapartito",
    "pentapartiti": "pentapartito",
    "pente": "pentire",
    "pentecostali": "pentecostale",
    "pentendo": "pentire",
    "penti": "pentire",
    "pentiamo": "pentire",
    "pentiate": "pentire",
    "pentii": "pentire",
    "pentimenti": "pentimento",
    "pentimmo": "pentire",
    "pentir": "pentire",
    "pentirai": "pentire",
    "pentiran": "pentire",
    "pentiranno": "pentire",
    "pentirebbe": "pentire",
    "pentirebber": "pentire",
    "pentirebbero": "pentire",
    "pentirei": "pentire",
    "pentiremmo": "pentire",
    "pentiremo": "pentire",
    "pentireste": "pentire",
    "pentiresti": "pentire",
    "pentirete": "pentire",
    "pentiron": "pentire",
    "pentirono": "pentire",
    "pentirà": "pentire",
    "pentirò": "pentire",
    "pentisse": "pentire",
    "pentisser": "pentire",
    "pentissero": "pentire",
    "pentissi": "pentire",
    "pentissimo": "pentire",
    "pentiste": "pentire",
    "pentisti": "pentire",
    "pentita": "pentito",
    "pentite": "pentito",
    "pentiti": "pentito",
    "pentitismi": "pentitismo",
    "pentito": "pentire",
    "pentiva": "pentire",
    "pentivamo": "pentire",
    "pentivan": "pentire",
    "pentivano": "pentire",
    "pentivate": "pentire",
    "pentivi": "pentire",
    "pentivo": "pentire",
    "pento": "pentire",
    "pentole": "pentola",
    "pentolini": "pentolino",
    "pentoloni": "pentolone",
    "penton": "pentire",
    "pentono": "pentire",
    "pentì": "pentire",
    "penultima": "penultimo",
    "penultime": "penultimo",
    "penultimi": "penultimo",
    "penurie": "penuria",
    "penzola": "penzolare",
    "penzolai": "penzolare",
    "penzolammo": "penzolare",
    "penzolan": "penzolare",
    "penzolando": "penzolare",
    "penzolano": "penzolare",
    "penzolante": "penzolare",
    "penzolanti": "penzolare",
    "penzolar": "penzolare",
    "penzolaron": "penzolare",
    "penzolarono": "penzolare",
    "penzolasse": "penzolare",
    "penzolasser": "penzolare",
    "penzolassero": "penzolare",
    "penzolassi": "penzolare",
    "penzolassimo": "penzolare",
    "penzolaste": "penzolare",
    "penzolasti": "penzolare",
    "penzolata": "penzolare",
    "penzolate": "penzolare",
    "penzolati": "penzolare",
    "penzolato": "penzolare",
    "penzolava": "penzolare",
    "penzolavamo": "penzolare",
    "penzolavan": "penzolare",
    "penzolavano": "penzolare",
    "penzolavate": "penzolare",
    "penzolavi": "penzolare",
    "penzolavo": "penzolare",
    "penzolerai": "penzolare",
    "penzoleran": "penzolare",
    "penzoleranno": "penzolare",
    "penzolerebbe": "penzolare",
    "penzolerebber": "penzolare",
    "penzolerebbero": "penzolare",
    "penzolerei": "penzolare",
    "penzoleremmo": "penzolare",
    "penzoleremo": "penzolare",
    "penzolereste": "penzolare",
    "penzoleresti": "penzolare",
    "penzolerete": "penzolare",
    "penzolerà": "penzolare",
    "penzolerò": "penzolare",
    "penzoli": "penzolare",
    "penzoliamo": "penzolare",
    "penzoliate": "penzolare",
    "penzolin": "penzolare",
    "penzolino": "penzolare",
    "penzolo": "penzolare",
    "penzolò": "penzolare",
    "penò": "penare",
    "peones": "peone",
    "peonie": "peonia",
    "pepa": "pepare",
    "pepai": "pepare",
    "pepammo": "pepare",
    "pepan": "pepare",
    "pepando": "pepare",
    "pepano": "pepare",
    "pepante": "pepare",
    "pepanti": "pepare",
    "pepar": "pepare",
    "peparon": "pepare",
    "peparono": "pepare",
    "pepasse": "pepare",
    "pepasser": "pepare",
    "pepassero": "pepare",
    "pepassi": "pepare",
    "pepassimo": "pepare",
    "pepaste": "pepare",
    "pepasti": "pepare",
    "pepata": "pepato",
    "pepate": "pepato",
    "pepati": "pepato",
    "pepato": "pepare",
    "pepava": "pepare",
    "pepavamo": "pepare",
    "pepavan": "pepare",
    "pepavano": "pepare",
    "pepavate": "pepare",
    "pepavi": "pepare",
    "pepavo": "pepare",
    "peperai": "pepare",
    "peperan": "pepare",
    "peperanno": "pepare",
    "peperebbe": "pepare",
    "peperebber": "pepare",
    "peperebbero": "pepare",
    "peperei": "pepare",
    "peperemmo": "pepare",
    "peperemo": "pepare",
    "pepereste": "pepare",
    "peperesti": "pepare",
    "peperete": "pepare",
    "peperoncini": "peperoncino",
    "peperoni": "peperone",
    "peperà": "pepare",
    "peperò": "pepare",
    "pepi": "pepe",
    "pepiamo": "pepare",
    "pepiate": "pepare",
    "pepin": "pepare",
    "pepino": "pepare",
    "pepite": "pepita",
    "pepo": "pepare",
    "pepò": "pepare",
    "perbeni": "perbene",
    "perbenismi": "perbenismo",
    "percentuali": "percentuale",
    "percentualizza": "percentualizzare",
    "percentualizzai": "percentualizzare",
    "percentualizzammo": "percentualizzare",
    "percentualizzan": "percentualizzare",
    "percentualizzando": "percentualizzare",
    "percentualizzano": "percentualizzare",
    "percentualizzante": "percentualizzare",
    "percentualizzanti": "percentualizzare",
    "percentualizzar": "percentualizzare",
    "percentualizzaron": "percentualizzare",
    "percentualizzarono": "percentualizzare",
    "percentualizzasse": "percentualizzare",
    "percentualizzasser": "percentualizzare",
    "percentualizzassero": "percentualizzare",
    "percentualizzassi": "percentualizzare",
    "percentualizzassimo": "percentualizzare",
    "percentualizzaste": "percentualizzare",
    "percentualizzasti": "percentualizzare",
    "percentualizzata": "percentualizzare",
    "percentualizzate": "percentualizzare",
    "percentualizzati": "percentualizzare",
    "percentualizzato": "percentualizzare",
    "percentualizzava": "percentualizzare",
    "percentualizzavamo": "percentualizzare",
    "percentualizzavan": "percentualizzare",
    "percentualizzavano": "percentualizzare",
    "percentualizzavate": "percentualizzare",
    "percentualizzavi": "percentualizzare",
    "percentualizzavo": "percentualizzare",
    "percentualizzerai": "percentualizzare",
    "percentualizzeran": "percentualizzare",
    "percentualizzeranno": "percentualizzare",
    "percentualizzerebbe": "percentualizzare",
    "percentualizzerebber": "percentualizzare",
    "percentualizzerebbero": "percentualizzare",
    "percentualizzerei": "percentualizzare",
    "percentualizzeremmo": "percentualizzare",
    "percentualizzeremo": "percentualizzare",
    "percentualizzereste": "percentualizzare",
    "percentualizzeresti": "percentualizzare",
    "percentualizzerete": "percentualizzare",
    "percentualizzerà": "percentualizzare",
    "percentualizzerò": "percentualizzare",
    "percentualizzi": "percentualizzare",
    "percentualizziamo": "percentualizzare",
    "percentualizziate": "percentualizzare",
    "percentualizzin": "percentualizzare",
    "percentualizzino": "percentualizzare",
    "percentualizzo": "percentualizzare",
    "percentualizzò": "percentualizzare",
    "percependo": "percepire",
    "percepente": "percepire",
    "percepenti": "percepire",
    "percepiamo": "percepire",
    "percepiate": "percepire",
    "percepibili": "percepibile",
    "percepii": "percepire",
    "percepimmo": "percepire",
    "percepir": "percepire",
    "percepirai": "percepire",
    "percepiran": "percepire",
    "percepiranno": "percepire",
    "percepirebbe": "percepire",
    "percepirebber": "percepire",
    "percepirebbero": "percepire",
    "percepirei": "percepire",
    "percepiremmo": "percepire",
    "percepiremo": "percepire",
    "percepireste": "percepire",
    "percepiresti": "percepire",
    "percepirete": "percepire",
    "percepiron": "percepire",
    "percepirono": "percepire",
    "percepirà": "percepire",
    "percepirò": "percepire",
    "percepisca": "percepire",
    "percepiscan": "percepire",
    "percepiscano": "percepire",
    "percepisce": "percepire",
    "percepisci": "percepire",
    "percepisco": "percepire",
    "percepiscon": "percepire",
    "percepiscono": "percepire",
    "percepisse": "percepire",
    "percepisser": "percepire",
    "percepissero": "percepire",
    "percepissi": "percepire",
    "percepissimo": "percepire",
    "percepiste": "percepire",
    "percepisti": "percepire",
    "percepita": "percepire",
    "percepite": "percepire",
    "percepiti": "percepire",
    "percepito": "percepire",
    "percepiva": "percepire",
    "percepivamo": "percepire",
    "percepivan": "percepire",
    "percepivano": "percepire",
    "percepivate": "percepire",
    "percepivi": "percepire",
    "percepivo": "percepire",
    "percepì": "percepire",
    "percettibili": "percettibile",
    "percettiva": "percettivo",
    "percettive": "percettivo",
    "percettivi": "percettivo",
    "percettori": "percettore",
    "percezioni": "percezione",
    "percola": "percolare",
    "percolai": "percolare",
    "percolammo": "percolare",
    "percolan": "percolare",
    "percolando": "percolare",
    "percolano": "percolare",
    "percolante": "percolare",
    "percolanti": "percolare",
    "percolar": "percolare",
    "percolaron": "percolare",
    "percolarono": "percolare",
    "percolasse": "percolare",
    "percolasser": "percolare",
    "percolassero": "percolare",
    "percolassi": "percolare",
    "percolassimo": "percolare",
    "percolaste": "percolare",
    "percolasti": "percolare",
    "percolata": "percolare",
    "percolate": "percolare",
    "percolati": "percolare",
    "percolato": "percolare",
    "percolava": "percolare",
    "percolavamo": "percolare",
    "percolavan": "percolare",
    "percolavano": "percolare",
    "percolavate": "percolare",
    "percolavi": "percolare",
    "percolavo": "percolare",
    "percolerai": "percolare",
    "percoleran": "percolare",
    "percoleranno": "percolare",
    "percolerebbe": "percolare",
    "percolerebber": "percolare",
    "percolerebbero": "percolare",
    "percolerei": "percolare",
    "percoleremmo": "percolare",
    "percoleremo": "percolare",
    "percolereste": "percolare",
    "percoleresti": "percolare",
    "percolerete": "percolare",
    "percolerà": "percolare",
    "percolerò": "percolare",
    "percoli": "percolare",
    "percoliamo": "percolare",
    "percoliate": "percolare",
    "percolin": "percolare",
    "percolino": "percolare",
    "percolo": "percolare",
    "percolò": "percolare",
    "percorra": "percorrere",
    "percorran": "percorrere",
    "percorrano": "percorrere",
    "percorre": "percorrere",
    "percorremmo": "percorrere",
    "percorrendo": "percorrere",
    "percorrente": "percorrere",
    "percorrenti": "percorrere",
    "percorrenze": "percorrenza",
    "percorrer": "percorrere",
    "percorrerai": "percorrere",
    "percorreran": "percorrere",
    "percorreranno": "percorrere",
    "percorrerebbe": "percorrere",
    "percorrerebber": "percorrere",
    "percorrerebbero": "percorrere",
    "percorrerei": "percorrere",
    "percorreremmo": "percorrere",
    "percorreremo": "percorrere",
    "percorrereste": "percorrere",
    "percorreresti": "percorrere",
    "percorrerete": "percorrere",
    "percorrerà": "percorrere",
    "percorrerò": "percorrere",
    "percorresse": "percorrere",
    "percorresser": "percorrere",
    "percorressero": "percorrere",
    "percorressi": "percorrere",
    "percorressimo": "percorrere",
    "percorreste": "percorrere",
    "percorresti": "percorrere",
    "percorrete": "percorrere",
    "percorreva": "percorrere",
    "percorrevamo": "percorrere",
    "percorrevan": "percorrere",
    "percorrevano": "percorrere",
    "percorrevate": "percorrere",
    "percorrevi": "percorrere",
    "percorrevo": "percorrere",
    "percorri": "percorrere",
    "percorriamo": "percorrere",
    "percorriate": "percorrere",
    "percorribili": "percorribile",
    "percorro": "percorrere",
    "percorron": "percorrere",
    "percorrono": "percorrere",
    "percorsa": "percorso",
    "percorse": "percorso",
    "percorser": "percorrere",
    "percorsero": "percorrere",
    "percorsi": "percorso",
    "percorso": "percorrere",
    "percossa": "percuotere",
    "percosse": "percuotere",
    "percosser": "percuotere",
    "percossero": "percuotere",
    "percossi": "percuotere",
    "percosso": "percuotere",
    "percuota": "percuotere",
    "percuotan": "percuotere",
    "percuotano": "percuotere",
    "percuote": "percuotere",
    "percuotemmo": "percuotere",
    "percuoter": "percuotere",
    "percuoterai": "percuotere",
    "percuoteran": "percuotere",
    "percuoteranno": "percuotere",
    "percuoterebbe": "percuotere",
    "percuoterebber": "percuotere",
    "percuoterebbero": "percuotere",
    "percuoterei": "percuotere",
    "percuoteremmo": "percuotere",
    "percuoteremo": "percuotere",
    "percuotereste": "percuotere",
    "percuoteresti": "percuotere",
    "percuoterete": "percuotere",
    "percuoterà": "percuotere",
    "percuoterò": "percuotere",
    "percuotesse": "percuotere",
    "percuotessero": "percuotere",
    "percuotessi": "percuotere",
    "percuotessimo": "percuotere",
    "percuoteste": "percuotere",
    "percuotesti": "percuotere",
    "percuoteva": "percuotere",
    "percuotevamo": "percuotere",
    "percuotevano": "percuotere",
    "percuotevate": "percuotere",
    "percuotevi": "percuotere",
    "percuotevo": "percuotere",
    "percuoti": "percuotere",
    "percuotiamo": "percuotere",
    "percuotiate": "percuotere",
    "percuoto": "percuotere",
    "percuoton": "percuotere",
    "percuotono": "percuotere",
    "percussioni": "percussione",
    "percussionisti": "percussionista",
    "perda": "perdere",
    "perdan": "perdere",
    "perdano": "perdere",
    "perde": "perdere",
    "perdemmo": "perdere",
    "perdendo": "perdere",
    "perdente": "perdere",
    "perdenti": "perdere",
    "perder": "perdere",
    "perderai": "perdere",
    "perderan": "perdere",
    "perderanno": "perdere",
    "perderebbe": "perdere",
    "perderebber": "perdere",
    "perderebbero": "perdere",
    "perderei": "perdere",
    "perderemmo": "perdere",
    "perderemo": "perdere",
    "perdereste": "perdere",
    "perderesti": "perdere",
    "perderete": "perdere",
    "perderà": "perdere",
    "perderò": "perdere",
    "perdesse": "perdere",
    "perdesser": "perdere",
    "perdessero": "perdere",
    "perdessi": "perdere",
    "perdessimo": "perdere",
    "perdeste": "perdere",
    "perdesti": "perdere",
    "perdete": "perdere",
    "perdeva": "perdere",
    "perdevamo": "perdere",
    "perdevan": "perdere",
    "perdevano": "perdere",
    "perdevate": "perdere",
    "perdevi": "perdere",
    "perdevo": "perdere",
    "perdi": "perdere",
    "perdiamo": "perdere",
    "perdiate": "perdere",
    "perdite": "perdita",
    "perdizioni": "perdizione",
    "perdo": "perdere",
    "perdon": "perdere",
    "perdona": "perdonare",
    "perdonabili": "perdonabile",
    "perdonai": "perdonare",
    "perdonammo": "perdonare",
    "perdonan": "perdonare",
    "perdonando": "perdonare",
    "perdonano": "perdonare",
    "perdonante": "perdonare",
    "perdonanti": "perdonare",
    "perdonar": "perdonare",
    "perdonaron": "perdonare",
    "perdonarono": "perdonare",
    "perdonasse": "perdonare",
    "perdonasser": "perdonare",
    "perdonassero": "perdonare",
    "perdonassi": "perdonare",
    "perdonassimo": "perdonare",
    "perdonaste": "perdonare",
    "perdonasti": "perdonare",
    "perdonata": "perdonare",
    "perdonate": "perdonare",
    "perdonati": "perdonare",
    "perdonato": "perdonare",
    "perdonava": "perdonare",
    "perdonavamo": "perdonare",
    "perdonavan": "perdonare",
    "perdonavano": "perdonare",
    "perdonavate": "perdonare",
    "perdonavi": "perdonare",
    "perdonavo": "perdonare",
    "perdonerai": "perdonare",
    "perdoneran": "perdonare",
    "perdoneranno": "perdonare",
    "perdonerebbe": "perdonare",
    "perdonerebber": "perdonare",
    "perdonerebbero": "perdonare",
    "perdonerei": "perdonare",
    "perdoneremmo": "perdonare",
    "perdoneremo": "perdonare",
    "perdonereste": "perdonare",
    "perdoneresti": "perdonare",
    "perdonerete": "perdonare",
    "perdonerà": "perdonare",
    "perdonerò": "perdonare",
    "perdoni": "perdonare",
    "perdoniamo": "perdonare",
    "perdoniate": "perdonare",
    "perdonin": "perdonare",
    "perdonino": "perdonare",
    "perdonismi": "perdonismo",
    "perdono": "perdonare",
    "perdonò": "perdonare",
    "perdura": "perdurare",
    "perdurai": "perdurare",
    "perdurammo": "perdurare",
    "perduran": "perdurare",
    "perdurando": "perdurare",
    "perdurano": "perdurare",
    "perdurante": "perdurare",
    "perduranti": "perdurare",
    "perdurar": "perdurare",
    "perduraron": "perdurare",
    "perdurarono": "perdurare",
    "perdurasse": "perdurare",
    "perdurasser": "perdurare",
    "perdurassero": "perdurare",
    "perdurassi": "perdurare",
    "perdurassimo": "perdurare",
    "perduraste": "perdurare",
    "perdurasti": "perdurare",
    "perdurata": "perdurare",
    "perdurate": "perdurare",
    "perdurati": "perdurare",
    "perdurato": "perdurare",
    "perdurava": "perdurare",
    "perduravamo": "perdurare",
    "perduravan": "perdurare",
    "perduravano": "perdurare",
    "perduravate": "perdurare",
    "perduravi": "perdurare",
    "perduravo": "perdurare",
    "perdurerai": "perdurare",
    "perdureran": "perdurare",
    "perdureranno": "perdurare",
    "perdurerebbe": "perdurare",
    "perdurerebber": "perdurare",
    "perdurerebbero": "perdurare",
    "perdurerei": "perdurare",
    "perdureremmo": "perdurare",
    "perdureremo": "perdurare",
    "perdurereste": "perdurare",
    "perdureresti": "perdurare",
    "perdurerete": "perdurare",
    "perdurerà": "perdurare",
    "perdurerò": "perdurare",
    "perduri": "perdurare",
    "perduriamo": "perdurare",
    "perduriate": "perdurare",
    "perdurin": "perdurare",
    "perdurino": "perdurare",
    "perduro": "perdurare",
    "perdurò": "perdurare",
    "perduta": "perduto",
    "perdute": "perduto",
    "perduti": "perduto",
    "perduto": "perdere",
    "pere": "pera",
    "peregrina": "peregrino",
    "peregrinai": "peregrinare",
    "peregrinammo": "peregrinare",
    "peregrinan": "peregrinare",
    "peregrinando": "peregrinare",
    "peregrinano": "peregrinare",
    "peregrinante": "peregrinare",
    "peregrinanti": "peregrinare",
    "peregrinar": "peregrinare",
    "peregrinaron": "peregrinare",
    "peregrinarono": "peregrinare",
    "peregrinasse": "peregrinare",
    "peregrinasser": "peregrinare",
    "peregrinassero": "peregrinare",
    "peregrinassi": "peregrinare",
    "peregrinassimo": "peregrinare",
    "peregrinaste": "peregrinare",
    "peregrinasti": "peregrinare",
    "peregrinata": "peregrinare",
    "peregrinate": "peregrinare",
    "peregrinati": "peregrinare",
    "peregrinato": "peregrinare",
    "peregrinava": "peregrinare",
    "peregrinavamo": "peregrinare",
    "peregrinavan": "peregrinare",
    "peregrinavano": "peregrinare",
    "peregrinavate": "peregrinare",
    "peregrinavi": "peregrinare",
    "peregrinavo": "peregrinare",
    "peregrinazioni": "peregrinazione",
    "peregrine": "peregrino",
    "peregrinerai": "peregrinare",
    "peregrineran": "peregrinare",
    "peregrineranno": "peregrinare",
    "peregrinerebbe": "peregrinare",
    "peregrinerebber": "peregrinare",
    "peregrinerebbero": "peregrinare",
    "peregrinerei": "peregrinare",
    "peregrineremmo": "peregrinare",
    "peregrineremo": "peregrinare",
    "peregrinereste": "peregrinare",
    "peregrineresti": "peregrinare",
    "peregrinerete": "peregrinare",
    "peregrinerà": "peregrinare",
    "peregrinerò": "peregrinare",
    "peregrini": "peregrino",
    "peregriniamo": "peregrinare",
    "peregriniate": "peregrinare",
    "peregrinin": "peregrinare",
    "peregrinino": "peregrinare",
    "peregrino": "peregrinare",
    "peregrinò": "peregrinare",
    "perendo": "perire",
    "perenni": "perenne",
    "perente": "perire",
    "perenti": "perire",
    "perentori": "perentorio",
    "perentoria": "perentorio",
    "perentorie": "perentorio",
    "perequa": "perequare",
    "perequai": "perequare",
    "perequammo": "perequare",
    "perequan": "perequare",
    "perequando": "perequare",
    "perequano": "perequare",
    "perequante": "perequare",
    "perequanti": "perequare",
    "perequar": "perequare",
    "perequaron": "perequare",
    "perequarono": "perequare",
    "perequasse": "perequare",
    "perequasser": "perequare",
    "perequassero": "perequare",
    "perequassi": "perequare",
    "perequassimo": "perequare",
    "perequaste": "perequare",
    "perequasti": "perequare",
    "perequata": "perequare",
    "perequate": "perequare",
    "perequati": "perequare",
    "perequativa": "perequativo",
    "perequative": "perequativo",
    "perequativi": "perequativo",
    "perequato": "perequare",
    "perequava": "perequare",
    "perequavamo": "perequare",
    "perequavan": "perequare",
    "perequavano": "perequare",
    "perequavate": "perequare",
    "perequavi": "perequare",
    "perequavo": "perequare",
    "perequazioni": "perequazione",
    "perequerai": "perequare",
    "perequeran": "perequare",
    "perequeranno": "perequare",
    "perequerebbe": "perequare",
    "perequerebber": "perequare",
    "perequerebbero": "perequare",
    "perequerei": "perequare",
    "perequeremmo": "perequare",
    "perequeremo": "perequare",
    "perequereste": "perequare",
    "perequeresti": "perequare",
    "perequerete": "perequare",
    "perequerà": "perequare",
    "perequerò": "perequare",
    "perequi": "perequare",
    "perequiamo": "perequare",
    "perequiate": "perequare",
    "perequin": "perequare",
    "perequino": "perequare",
    "perequo": "perequare",
    "perequò": "perequare",
    "perestroike": "perestroika",
    "perestrojke": "perestrojka",
    "perfetta": "perfetto",
    "perfette": "perfetto",
    "perfetti": "perfetto",
    "perfettibili": "perfettibile",
    "perfeziona": "perfezionare",
    "perfezionai": "perfezionare",
    "perfezionamenti": "perfezionamento",
    "perfezionammo": "perfezionare",
    "perfezionan": "perfezionare",
    "perfezionando": "perfezionare",
    "perfezionano": "perfezionare",
    "perfezionante": "perfezionare",
    "perfezionanti": "perfezionare",
    "perfezionar": "perfezionare",
    "perfezionaron": "perfezionare",
    "perfezionarono": "perfezionare",
    "perfezionasse": "perfezionare",
    "perfezionasser": "perfezionare",
    "perfezionassero": "perfezionare",
    "perfezionassi": "perfezionare",
    "perfezionassimo": "perfezionare",
    "perfezionaste": "perfezionare",
    "perfezionasti": "perfezionare",
    "perfezionata": "perfezionare",
    "perfezionate": "perfezionare",
    "perfezionati": "perfezionare",
    "perfezionato": "perfezionare",
    "perfezionava": "perfezionare",
    "perfezionavamo": "perfezionare",
    "perfezionavan": "perfezionare",
    "perfezionavano": "perfezionare",
    "perfezionavate": "perfezionare",
    "perfezionavi": "perfezionare",
    "perfezionavo": "perfezionare",
    "perfezionerai": "perfezionare",
    "perfezioneran": "perfezionare",
    "perfezioneranno": "perfezionare",
    "perfezionerebbe": "perfezionare",
    "perfezionerebber": "perfezionare",
    "perfezionerebbero": "perfezionare",
    "perfezionerei": "perfezionare",
    "perfezioneremmo": "perfezionare",
    "perfezioneremo": "perfezionare",
    "perfezionereste": "perfezionare",
    "perfezioneresti": "perfezionare",
    "perfezionerete": "perfezionare",
    "perfezionerà": "perfezionare",
    "perfezionerò": "perfezionare",
    "perfezioni": "perfezione",
    "perfezioniamo": "perfezionare",
    "perfezioniate": "perfezionare",
    "perfezionin": "perfezionare",
    "perfezionino": "perfezionare",
    "perfezionismi": "perfezionismo",
    "perfezioniste": "perfezionista",
    "perfezionisti": "perfezionista",
    "perfeziono": "perfezionare",
    "perfezionò": "perfezionare",
    "perfida": "perfido",
    "perfide": "perfido",
    "perfidi": "perfido",
    "perfidie": "perfidia",
    "perfora": "perforare",
    "perforai": "perforare",
    "perforammo": "perforare",
    "perforan": "perforare",
    "perforando": "perforare",
    "perforano": "perforare",
    "perforante": "perforare",
    "perforanti": "perforare",
    "perforar": "perforare",
    "perforaron": "perforare",
    "perforarono": "perforare",
    "perforasse": "perforare",
    "perforasser": "perforare",
    "perforassero": "perforare",
    "perforassi": "perforare",
    "perforassimo": "perforare",
    "perforaste": "perforare",
    "perforasti": "perforare",
    "perforata": "perforare",
    "perforate": "perforare",
    "perforati": "perforare",
    "perforato": "perforare",
    "perforava": "perforare",
    "perforavamo": "perforare",
    "perforavan": "perforare",
    "perforavano": "perforare",
    "perforavate": "perforare",
    "perforavi": "perforare",
    "perforavo": "perforare",
    "perforazioni": "perforazione",
    "perforerai": "perforare",
    "perforeran": "perforare",
    "perforeranno": "perforare",
    "perforerebbe": "perforare",
    "perforerebber": "perforare",
    "perforerebbero": "perforare",
    "perforerei": "perforare",
    "perforeremmo": "perforare",
    "perforeremo": "perforare",
    "perforereste": "perforare",
    "perforeresti": "perforare",
    "perforerete": "perforare",
    "perforerà": "perforare",
    "perforerò": "perforare",
    "perfori": "perforare",
    "perforiamo": "perforare",
    "perforiate": "perforare",
    "perforin": "perforare",
    "perforino": "perforare",
    "performances": "performance",
    "perforo": "perforare",
    "perforò": "perforare",
    "pergamene": "pergamena",
    "pergolati": "pergolato",
    "peri": "pero",
    "periamo": "perire",
    "periate": "perire",
    "pericola": "pericolare",
    "pericolai": "pericolare",
    "pericolammo": "pericolare",
    "pericolan": "pericolare",
    "pericolando": "pericolare",
    "pericolano": "pericolare",
    "pericolante": "pericolare",
    "pericolanti": "pericolare",
    "pericolar": "pericolare",
    "pericolaron": "pericolare",
    "pericolarono": "pericolare",
    "pericolasse": "pericolare",
    "pericolasser": "pericolare",
    "pericolassero": "pericolare",
    "pericolassi": "pericolare",
    "pericolassimo": "pericolare",
    "pericolaste": "pericolare",
    "pericolasti": "pericolare",
    "pericolata": "pericolare",
    "pericolate": "pericolare",
    "pericolati": "pericolare",
    "pericolato": "pericolare",
    "pericolava": "pericolare",
    "pericolavamo": "pericolare",
    "pericolavan": "pericolare",
    "pericolavano": "pericolare",
    "pericolavate": "pericolare",
    "pericolavi": "pericolare",
    "pericolavo": "pericolare",
    "pericolerai": "pericolare",
    "pericoleran": "pericolare",
    "pericoleranno": "pericolare",
    "pericolerebbe": "pericolare",
    "pericolerebber": "pericolare",
    "pericolerebbero": "pericolare",
    "pericolerei": "pericolare",
    "pericoleremmo": "pericolare",
    "pericoleremo": "pericolare",
    "pericolereste": "pericolare",
    "pericoleresti": "pericolare",
    "pericolerete": "pericolare",
    "pericolerà": "pericolare",
    "pericolerò": "pericolare",
    "pericoli": "pericolo",
    "pericoliamo": "pericolare",
    "pericoliate": "pericolare",
    "pericolin": "pericolare",
    "pericolino": "pericolare",
    "pericolo": "pericolare",
    "pericolosa": "pericoloso",
    "pericolose": "pericoloso",
    "pericolosi": "pericoloso",
    "pericolò": "pericolare",
    "periferica": "periferico",
    "periferiche": "periferico",
    "periferici": "periferico",
    "periferie": "periferia",
    "perifrasa": "perifrasare",
    "perifrasai": "perifrasare",
    "perifrasammo": "perifrasare",
    "perifrasan": "perifrasare",
    "perifrasando": "perifrasare",
    "perifrasano": "perifrasare",
    "perifrasante": "perifrasare",
    "perifrasanti": "perifrasare",
    "perifrasar": "perifrasare",
    "perifrasaron": "perifrasare",
    "perifrasarono": "perifrasare",
    "perifrasasse": "perifrasare",
    "perifrasasser": "perifrasare",
    "perifrasassero": "perifrasare",
    "perifrasassi": "perifrasare",
    "perifrasassimo": "perifrasare",
    "perifrasaste": "perifrasare",
    "perifrasasti": "perifrasare",
    "perifrasata": "perifrasare",
    "perifrasate": "perifrasare",
    "perifrasati": "perifrasare",
    "perifrasato": "perifrasare",
    "perifrasava": "perifrasare",
    "perifrasavamo": "perifrasare",
    "perifrasavan": "perifrasare",
    "perifrasavano": "perifrasare",
    "perifrasavate": "perifrasare",
    "perifrasavi": "perifrasare",
    "perifrasavo": "perifrasare",
    "perifraserai": "perifrasare",
    "perifraseran": "perifrasare",
    "perifraseranno": "perifrasare",
    "perifraserebbe": "perifrasare",
    "perifraserebber": "perifrasare",
    "perifraserebbero": "perifrasare",
    "perifraserei": "perifrasare",
    "perifraseremmo": "perifrasare",
    "perifraseremo": "perifrasare",
    "perifrasereste": "perifrasare",
    "perifraseresti": "perifrasare",
    "perifraserete": "perifrasare",
    "perifraserà": "perifrasare",
    "perifraserò": "perifrasare",
    "perifrasi": "perifrasare",
    "perifrasiamo": "perifrasare",
    "perifrasiate": "perifrasare",
    "perifrasin": "perifrasare",
    "perifrasino": "perifrasare",
    "perifraso": "perifrasare",
    "perifrasò": "perifrasare",
    "perii": "perire",
    "perimetrali": "perimetrale",
    "perimetri": "perimetro",
    "perimmo": "perire",
    "perinatali": "perinatale",
    "perioda": "periodare",
    "periodai": "periodare",
    "periodammo": "periodare",
    "periodan": "periodare",
    "periodando": "periodare",
    "periodano": "periodare",
    "periodante": "periodare",
    "periodanti": "periodare",
    "periodar": "periodare",
    "periodaron": "periodare",
    "periodarono": "periodare",
    "periodasse": "periodare",
    "periodasser": "periodare",
    "periodassero": "periodare",
    "periodassi": "periodare",
    "periodassimo": "periodare",
    "periodaste": "periodare",
    "periodasti": "periodare",
    "periodata": "periodare",
    "periodate": "periodare",
    "periodati": "periodare",
    "periodato": "periodare",
    "periodava": "periodare",
    "periodavamo": "periodare",
    "periodavan": "periodare",
    "periodavano": "periodare",
    "periodavate": "periodare",
    "periodavi": "periodare",
    "periodavo": "periodare",
    "perioderai": "periodare",
    "perioderan": "periodare",
    "perioderanno": "periodare",
    "perioderebbe": "periodare",
    "perioderebber": "periodare",
    "perioderebbero": "periodare",
    "perioderei": "periodare",
    "perioderemmo": "periodare",
    "perioderemo": "periodare",
    "periodereste": "periodare",
    "perioderesti": "periodare",
    "perioderete": "periodare",
    "perioderà": "periodare",
    "perioderò": "periodare",
    "periodi": "periodo",
    "periodiamo": "periodare",
    "periodiate": "periodare",
    "periodica": "periodico",
    "periodiche": "periodico",
    "periodici": "periodico",
    "periodin": "periodare",
    "periodino": "periodare",
    "periodizza": "periodizzare",
    "periodizzai": "periodizzare",
    "periodizzammo": "periodizzare",
    "periodizzan": "periodizzare",
    "periodizzando": "periodizzare",
    "periodizzano": "periodizzare",
    "periodizzante": "periodizzare",
    "periodizzanti": "periodizzare",
    "periodizzar": "periodizzare",
    "periodizzaron": "periodizzare",
    "periodizzarono": "periodizzare",
    "periodizzasse": "periodizzare",
    "periodizzasser": "periodizzare",
    "periodizzassero": "periodizzare",
    "periodizzassi": "periodizzare",
    "periodizzassimo": "periodizzare",
    "periodizzaste": "periodizzare",
    "periodizzasti": "periodizzare",
    "periodizzata": "periodizzare",
    "periodizzate": "periodizzare",
    "periodizzati": "periodizzare",
    "periodizzato": "periodizzare",
    "periodizzava": "periodizzare",
    "periodizzavamo": "periodizzare",
    "periodizzavan": "periodizzare",
    "periodizzavano": "periodizzare",
    "periodizzavate": "periodizzare",
    "periodizzavi": "periodizzare",
    "periodizzavo": "periodizzare",
    "periodizzerai": "periodizzare",
    "periodizzeran": "periodizzare",
    "periodizzeranno": "periodizzare",
    "periodizzerebbe": "periodizzare",
    "periodizzerebber": "periodizzare",
    "periodizzerebbero": "periodizzare",
    "periodizzerei": "periodizzare",
    "periodizzeremmo": "periodizzare",
    "periodizzeremo": "periodizzare",
    "periodizzereste": "periodizzare",
    "periodizzeresti": "periodizzare",
    "periodizzerete": "periodizzare",
    "periodizzerà": "periodizzare",
    "periodizzerò": "periodizzare",
    "periodizzi": "periodizzare",
    "periodizziamo": "periodizzare",
    "periodizziate": "periodizzare",
    "periodizzin": "periodizzare",
    "periodizzino": "periodizzare",
    "periodizzo": "periodizzare",
    "periodizzò": "periodizzare",
    "periodo": "periodare",
    "periodò": "periodare",
    "peripatetica": "peripatetico",
    "peripatetiche": "peripatetico",
    "peripatetici": "peripatetico",
    "peripezie": "peripezia",
    "perir": "perire",
    "perirai": "perire",
    "periran": "perire",
    "periranno": "perire",
    "perirebbe": "perire",
    "perirebber": "perire",
    "perirebbero": "perire",
    "perirei": "perire",
    "periremmo": "perire",
    "periremo": "perire",
    "perireste": "perire",
    "periresti": "perire",
    "perirete": "perire",
    "periron": "perire",
    "perirono": "perire",
    "perirà": "perire",
    "perirò": "perire",
    "perisca": "perire",
    "periscan": "perire",
    "periscano": "perire",
    "perisce": "perire",
    "perisci": "perire",
    "perisco": "perire",
    "periscon": "perire",
    "periscono": "perire",
    "periscopi": "periscopio",
    "perisse": "perire",
    "perisser": "perire",
    "perissero": "perire",
    "perissi": "perire",
    "perissimo": "perire",
    "periste": "perire",
    "peristi": "perire",
    "perita": "perito",
    "peritai": "peritare",
    "peritali": "peritale",
    "peritammo": "peritare",
    "peritan": "peritare",
    "peritando": "peritare",
    "peritano": "peritare",
    "peritar": "peritare",
    "peritaron": "peritare",
    "peritarono": "peritare",
    "peritasse": "peritare",
    "peritasser": "peritare",
    "peritassero": "peritare",
    "peritassi": "peritare",
    "peritassimo": "peritare",
    "peritaste": "peritare",
    "peritasti": "peritare",
    "peritata": "peritare",
    "peritate": "peritare",
    "peritati": "peritare",
    "peritato": "peritare",
    "peritava": "peritare",
    "peritavamo": "peritare",
    "peritavan": "peritare",
    "peritavano": "peritare",
    "peritavate": "peritare",
    "peritavi": "peritare",
    "peritavo": "peritare",
    "perite": "perito",
    "periterai": "peritare",
    "periteran": "peritare",
    "periteranno": "peritare",
    "periterebbe": "peritare",
    "periterebber": "peritare",
    "periterebbero": "peritare",
    "periterei": "peritare",
    "periteremmo": "peritare",
    "periteremo": "peritare",
    "peritereste": "peritare",
    "periteresti": "peritare",
    "periterete": "peritare",
    "periterà": "peritare",
    "periterò": "peritare",
    "periti": "perito",
    "peritiamo": "peritare",
    "peritiate": "peritare",
    "peritin": "peritare",
    "peritino": "peritare",
    "perito": "peritare",
    "peritò": "peritare",
    "periva": "perire",
    "perivamo": "perire",
    "perivan": "perire",
    "perivano": "perire",
    "perivate": "perire",
    "perivi": "perire",
    "perivo": "perire",
    "perizi": "periziare",
    "perizia": "periziare",
    "periziai": "periziare",
    "periziammo": "periziare",
    "periziamo": "periziare",
    "perizian": "periziare",
    "periziando": "periziare",
    "periziano": "periziare",
    "periziante": "periziare",
    "perizianti": "periziare",
    "periziar": "periziare",
    "periziaron": "periziare",
    "periziarono": "periziare",
    "periziasse": "periziare",
    "periziasser": "periziare",
    "periziassero": "periziare",
    "periziassi": "periziare",
    "periziassimo": "periziare",
    "periziaste": "periziare",
    "periziasti": "periziare",
    "periziata": "periziare",
    "periziate": "periziare",
    "periziati": "periziare",
    "periziato": "periziare",
    "periziava": "periziare",
    "periziavamo": "periziare",
    "periziavan": "periziare",
    "periziavano": "periziare",
    "periziavate": "periziare",
    "periziavi": "periziare",
    "periziavo": "periziare",
    "perizie": "perizia",
    "perizierai": "periziare",
    "perizieran": "periziare",
    "perizieranno": "periziare",
    "perizierebbe": "periziare",
    "perizierebber": "periziare",
    "perizierebbero": "periziare",
    "perizierei": "periziare",
    "perizieremmo": "periziare",
    "perizieremo": "periziare",
    "periziereste": "periziare",
    "perizieresti": "periziare",
    "perizierete": "periziare",
    "perizierà": "periziare",
    "perizierò": "periziare",
    "perizin": "periziare",
    "perizino": "periziare",
    "perizio": "periziare",
    "periziò": "periziare",
    "perlacea": "perlaceo",
    "perlacee": "perlaceo",
    "perlacei": "perlaceo",
    "perline": "perlina",
    "perlustra": "perlustrare",
    "perlustrai": "perlustrare",
    "perlustrammo": "perlustrare",
    "perlustran": "perlustrare",
    "perlustrando": "perlustrare",
    "perlustrano": "perlustrare",
    "perlustrante": "perlustrare",
    "perlustranti": "perlustrare",
    "perlustrar": "perlustrare",
    "perlustraron": "perlustrare",
    "perlustrarono": "perlustrare",
    "perlustrasse": "perlustrare",
    "perlustrasser": "perlustrare",
    "perlustrassero": "perlustrare",
    "perlustrassi": "perlustrare",
    "perlustrassimo": "perlustrare",
    "perlustraste": "perlustrare",
    "perlustrasti": "perlustrare",
    "perlustrata": "perlustrare",
    "perlustrate": "perlustrare",
    "perlustrati": "perlustrare",
    "perlustrato": "perlustrare",
    "perlustrava": "perlustrare",
    "perlustravamo": "perlustrare",
    "perlustravan": "perlustrare",
    "perlustravano": "perlustrare",
    "perlustravate": "perlustrare",
    "perlustravi": "perlustrare",
    "perlustravo": "perlustrare",
    "perlustrazioni": "perlustrazione",
    "perlustrerai": "perlustrare",
    "perlustreran": "perlustrare",
    "perlustreranno": "perlustrare",
    "perlustrerebbe": "perlustrare",
    "perlustrerebber": "perlustrare",
    "perlustrerebbero": "perlustrare",
    "perlustrerei": "perlustrare",
    "perlustreremmo": "perlustrare",
    "perlustreremo": "perlustrare",
    "perlustrereste": "perlustrare",
    "perlustreresti": "perlustrare",
    "perlustrerete": "perlustrare",
    "perlustrerà": "perlustrare",
    "perlustrerò": "perlustrare",
    "perlustri": "perlustrare",
    "perlustriamo": "perlustrare",
    "perlustriate": "perlustrare",
    "perlustrin": "perlustrare",
    "perlustrino": "perlustrare",
    "perlustro": "perlustrare",
    "perlustrò": "perlustrare",
    "permalosa": "permaloso",
    "permalose": "permaloso",
    "permalosi": "permaloso",
    "permane": "permanere",
    "permanemmo": "permanere",
    "permanendo": "permanere",
    "permanente": "permanere",
    "permanenti": "permanere",
    "permanenze": "permanenza",
    "permaner": "permanere",
    "permanesse": "permanere",
    "permanesser": "permanere",
    "permanessero": "permanere",
    "permanessi": "permanere",
    "permanessimo": "permanere",
    "permaneste": "permanere",
    "permanesti": "permanere",
    "permanete": "permanere",
    "permaneva": "permanere",
    "permanevamo": "permanere",
    "permanevan": "permanere",
    "permanevano": "permanere",
    "permanevate": "permanere",
    "permanevi": "permanere",
    "permanevo": "permanere",
    "permanga": "permanere",
    "permangan": "permanere",
    "permangano": "permanere",
    "permango": "permanere",
    "permangon": "permanere",
    "permangono": "permanere",
    "permani": "permanere",
    "permaniamo": "permanere",
    "permaniate": "permanere",
    "permarrai": "permanere",
    "permarran": "permanere",
    "permarranno": "permanere",
    "permarrebbe": "permanere",
    "permarrebber": "permanere",
    "permarrebbero": "permanere",
    "permarrei": "permanere",
    "permarremmo": "permanere",
    "permarremo": "permanere",
    "permarreste": "permanere",
    "permarresti": "permanere",
    "permarrete": "permanere",
    "permarrà": "permanere",
    "permarrò": "permanere",
    "permase": "permanere",
    "permaser": "permanere",
    "permasero": "permanere",
    "permasi": "permanere",
    "permasta": "permanere",
    "permaste": "permanere",
    "permasti": "permanere",
    "permasto": "permanere",
    "permea": "permeare",
    "permeabili": "permeabile",
    "permeai": "permeare",
    "permeammo": "permeare",
    "permean": "permeare",
    "permeando": "permeare",
    "permeano": "permeare",
    "permeante": "permeare",
    "permeanti": "permeare",
    "permear": "permeare",
    "permearon": "permeare",
    "permearono": "permeare",
    "permeasse": "permeare",
    "permeasser": "permeare",
    "permeassero": "permeare",
    "permeassi": "permeare",
    "permeassimo": "permeare",
    "permeaste": "permeare",
    "permeasti": "permeare",
    "permeata": "permeare",
    "permeate": "permeare",
    "permeati": "permeare",
    "permeato": "permeare",
    "permeava": "permeare",
    "permeavamo": "permeare",
    "permeavan": "permeare",
    "permeavano": "permeare",
    "permeavate": "permeare",
    "permeavi": "permeare",
    "permeavo": "permeare",
    "permeerai": "permeare",
    "permeeran": "permeare",
    "permeeranno": "permeare",
    "permeerebbe": "permeare",
    "permeerebber": "permeare",
    "permeerebbero": "permeare",
    "permeerei": "permeare",
    "permeeremmo": "permeare",
    "permeeremo": "permeare",
    "permeereste": "permeare",
    "permeeresti": "permeare",
    "permeerete": "permeare",
    "permeerà": "permeare",
    "permeerò": "permeare",
    "permei": "permeare",
    "permeiamo": "permeare",
    "permeiate": "permeare",
    "permein": "permeare",
    "permeino": "permeare",
    "permeo": "permeare",
    "permessa": "permettere",
    "permesse": "permettere",
    "permessi": "permettere",
    "permesso": "permettere",
    "permetta": "permettere",
    "permettan": "permettere",
    "permettano": "permettere",
    "permette": "permettere",
    "permettemmo": "permettere",
    "permettendo": "permettere",
    "permettente": "permettere",
    "permettenti": "permettere",
    "permetter": "permettere",
    "permetterai": "permettere",
    "permetteran": "permettere",
    "permetteranno": "permettere",
    "permetterebbe": "permettere",
    "permetterebber": "permettere",
    "permetterebbero": "permettere",
    "permetterei": "permettere",
    "permetteremmo": "permettere",
    "permetteremo": "permettere",
    "permettereste": "permettere",
    "permetteresti": "permettere",
    "permetterete": "permettere",
    "permetterà": "permettere",
    "permetterò": "permettere",
    "permettesse": "permettere",
    "permettesser": "permettere",
    "permettessero": "permettere",
    "permettessi": "permettere",
    "permettessimo": "permettere",
    "permetteste": "permettere",
    "permettesti": "permettere",
    "permettete": "permettere",
    "permetteva": "permettere",
    "permettevamo": "permettere",
    "permettevan": "permettere",
    "permettevano": "permettere",
    "permettevate": "permettere",
    "permettevi": "permettere",
    "permettevo": "permettere",
    "permetti": "permettere",
    "permettiamo": "permettere",
    "permettiate": "permettere",
    "permetto": "permettere",
    "permetton": "permettere",
    "permettono": "permettere",
    "permeò": "permeare",
    "permise": "permettere",
    "permiser": "permettere",
    "permisero": "permettere",
    "permisi": "permettere",
    "permissiva": "permissivo",
    "permissive": "permissivo",
    "permissivi": "permissivo",
    "permissivismi": "permissivismo",
    "permuta": "permutare",
    "permutabili": "permutabile",
    "permutai": "permutare",
    "permutammo": "permutare",
    "permutan": "permutare",
    "permutando": "permutare",
    "permutano": "permutare",
    "permutante": "permutare",
    "permutanti": "permutare",
    "permutar": "permutare",
    "permutaron": "permutare",
    "permutarono": "permutare",
    "permutasse": "permutare",
    "permutasser": "permutare",
    "permutassero": "permutare",
    "permutassi": "permutare",
    "permutassimo": "permutare",
    "permutaste": "permutare",
    "permutasti": "permutare",
    "permutata": "permutare",
    "permutate": "permutare",
    "permutati": "permutare",
    "permutato": "permutare",
    "permutava": "permutare",
    "permutavamo": "permutare",
    "permutavan": "permutare",
    "permutavano": "permutare",
    "permutavate": "permutare",
    "permutavi": "permutare",
    "permutavo": "permutare",
    "permute": "permuta",
    "permuterai": "permutare",
    "permuteran": "permutare",
    "permuteranno": "permutare",
    "permuterebbe": "permutare",
    "permuterebber": "permutare",
    "permuterebbero": "permutare",
    "permuterei": "permutare",
    "permuteremmo": "permutare",
    "permuteremo": "permutare",
    "permutereste": "permutare",
    "permuteresti": "permutare",
    "permuterete": "permutare",
    "permuterà": "permutare",
    "permuterò": "permutare",
    "permuti": "permutare",
    "permutiamo": "permutare",
    "permutiate": "permutare",
    "permutin": "permutare",
    "permutino": "permutare",
    "permuto": "permutare",
    "permutò": "permutare",
    "pernacchie": "pernacchia",
    "perni": "perno",
    "pernici": "pernice",
    "perniciosa": "pernicioso",
    "perniciose": "pernicioso",
    "perniciosi": "pernicioso",
    "pernotta": "pernottare",
    "pernottai": "pernottare",
    "pernottamenti": "pernottamento",
    "pernottammo": "pernottare",
    "pernottan": "pernottare",
    "pernottando": "pernottare",
    "pernottano": "pernottare",
    "pernottante": "pernottare",
    "pernottanti": "pernottare",
    "pernottar": "pernottare",
    "pernottaron": "pernottare",
    "pernottarono": "pernottare",
    "pernottasse": "pernottare",
    "pernottasser": "pernottare",
    "pernottassero": "pernottare",
    "pernottassi": "pernottare",
    "pernottassimo": "pernottare",
    "pernottaste": "pernottare",
    "pernottasti": "pernottare",
    "pernottata": "pernottare",
    "pernottate": "pernottare",
    "pernottati": "pernottare",
    "pernottato": "pernottare",
    "pernottava": "pernottare",
    "pernottavamo": "pernottare",
    "pernottavan": "pernottare",
    "pernottavano": "pernottare",
    "pernottavate": "pernottare",
    "pernottavi": "pernottare",
    "pernottavo": "pernottare",
    "pernotterai": "pernottare",
    "pernotteran": "pernottare",
    "pernotteranno": "pernottare",
    "pernotterebbe": "pernottare",
    "pernotterebber": "pernottare",
    "pernotterebbero": "pernottare",
    "pernotterei": "pernottare",
    "pernotteremmo": "pernottare",
    "pernotteremo": "pernottare",
    "pernottereste": "pernottare",
    "pernotteresti": "pernottare",
    "pernotterete": "pernottare",
    "pernotterà": "pernottare",
    "pernotterò": "pernottare",
    "pernotti": "pernottare",
    "pernottiamo": "pernottare",
    "pernottiate": "pernottare",
    "pernottin": "pernottare",
    "pernottino": "pernottare",
    "pernotto": "pernottare",
    "pernottò": "pernottare",
    "peronismi": "peronismo",
    "peroniste": "peronista",
    "peronisti": "peronista",
    "perora": "perorare",
    "perorai": "perorare",
    "perorammo": "perorare",
    "peroran": "perorare",
    "perorando": "perorare",
    "perorano": "perorare",
    "perorante": "perorare",
    "peroranti": "perorare",
    "perorar": "perorare",
    "peroraron": "perorare",
    "perorarono": "perorare",
    "perorasse": "perorare",
    "perorasser": "perorare",
    "perorassero": "perorare",
    "perorassi": "perorare",
    "perorassimo": "perorare",
    "peroraste": "perorare",
    "perorasti": "perorare",
    "perorata": "perorare",
    "perorate": "perorare",
    "perorati": "perorare",
    "perorato": "perorare",
    "perorava": "perorare",
    "peroravamo": "perorare",
    "peroravan": "perorare",
    "peroravano": "perorare",
    "peroravate": "perorare",
    "peroravi": "perorare",
    "peroravo": "perorare",
    "perorazioni": "perorazione",
    "perorerai": "perorare",
    "peroreran": "perorare",
    "peroreranno": "perorare",
    "perorerebbe": "perorare",
    "perorerebber": "perorare",
    "perorerebbero": "perorare",
    "perorerei": "perorare",
    "peroreremmo": "perorare",
    "peroreremo": "perorare",
    "perorereste": "perorare",
    "peroreresti": "perorare",
    "perorerete": "perorare",
    "perorerà": "perorare",
    "perorerò": "perorare",
    "perori": "perorare",
    "peroriamo": "perorare",
    "peroriate": "perorare",
    "perorin": "perorare",
    "perorino": "perorare",
    "peroro": "perorare",
    "perorò": "perorare",
    "perpendicolari": "perpendicolare",
    "perpetra": "perpetrare",
    "perpetrai": "perpetrare",
    "perpetrammo": "perpetrare",
    "perpetran": "perpetrare",
    "perpetrando": "perpetrare",
    "perpetrano": "perpetrare",
    "perpetrante": "perpetrare",
    "perpetranti": "perpetrare",
    "perpetrar": "perpetrare",
    "perpetraron": "perpetrare",
    "perpetrarono": "perpetrare",
    "perpetrasse": "perpetrare",
    "perpetrasser": "perpetrare",
    "perpetrassero": "perpetrare",
    "perpetrassi": "perpetrare",
    "perpetrassimo": "perpetrare",
    "perpetraste": "perpetrare",
    "perpetrasti": "perpetrare",
    "perpetrata": "perpetrare",
    "perpetrate": "perpetrare",
    "perpetrati": "perpetrare",
    "perpetrato": "perpetrare",
    "perpetrava": "perpetrare",
    "perpetravamo": "perpetrare",
    "perpetravan": "perpetrare",
    "perpetravano": "perpetrare",
    "perpetravate": "perpetrare",
    "perpetravi": "perpetrare",
    "perpetravo": "perpetrare",
    "perpetrerai": "perpetrare",
    "perpetreran": "perpetrare",
    "perpetreranno": "perpetrare",
    "perpetrerebbe": "perpetrare",
    "perpetrerebber": "perpetrare",
    "perpetrerebbero": "perpetrare",
    "perpetrerei": "perpetrare",
    "perpetreremmo": "perpetrare",
    "perpetreremo": "perpetrare",
    "perpetrereste": "perpetrare",
    "perpetreresti": "perpetrare",
    "perpetrerete": "perpetrare",
    "perpetrerà": "perpetrare",
    "perpetrerò": "perpetrare",
    "perpetri": "perpetrare",
    "perpetriamo": "perpetrare",
    "perpetriate": "perpetrare",
    "perpetrin": "perpetrare",
    "perpetrino": "perpetrare",
    "perpetro": "perpetrare",
    "perpetrò": "perpetrare",
    "perpetua": "perpetuo",
    "perpetuai": "perpetuare",
    "perpetuammo": "perpetuare",
    "perpetuan": "perpetuare",
    "perpetuando": "perpetuare",
    "perpetuano": "perpetuare",
    "perpetuante": "perpetuare",
    "perpetuanti": "perpetuare",
    "perpetuar": "perpetuare",
    "perpetuaron": "perpetuare",
    "perpetuarono": "perpetuare",
    "perpetuasse": "perpetuare",
    "perpetuasser": "perpetuare",
    "perpetuassero": "perpetuare",
    "perpetuassi": "perpetuare",
    "perpetuassimo": "perpetuare",
    "perpetuaste": "perpetuare",
    "perpetuasti": "perpetuare",
    "perpetuata": "perpetuare",
    "perpetuate": "perpetuare",
    "perpetuati": "perpetuare",
    "perpetuato": "perpetuare",
    "perpetuava": "perpetuare",
    "perpetuavamo": "perpetuare",
    "perpetuavan": "perpetuare",
    "perpetuavano": "perpetuare",
    "perpetuavate": "perpetuare",
    "perpetuavi": "perpetuare",
    "perpetuavo": "perpetuare",
    "perpetuazioni": "perpetuazione",
    "perpetue": "perpetuo",
    "perpetuerai": "perpetuare",
    "perpetueran": "perpetuare",
    "perpetueranno": "perpetuare",
    "perpetuerebbe": "perpetuare",
    "perpetuerebber": "perpetuare",
    "perpetuerebbero": "perpetuare",
    "perpetuerei": "perpetuare",
    "perpetueremmo": "perpetuare",
    "perpetueremo": "perpetuare",
    "perpetuereste": "perpetuare",
    "perpetueresti": "perpetuare",
    "perpetuerete": "perpetuare",
    "perpetuerà": "perpetuare",
    "perpetuerò": "perpetuare",
    "perpetui": "perpetuo",
    "perpetuiamo": "perpetuare",
    "perpetuiate": "perpetuare",
    "perpetuin": "perpetuare",
    "perpetuino": "perpetuare",
    "perpetuo": "perpetuare",
    "perpetuò": "perpetuare",
    "perplessa": "perplesso",
    "perplesse": "perplesso",
    "perplessi": "perplesso",
    "perquisendo": "perquisire",
    "perquisente": "perquisire",
    "perquisenti": "perquisire",
    "perquisiamo": "perquisire",
    "perquisiate": "perquisire",
    "perquisii": "perquisire",
    "perquisimmo": "perquisire",
    "perquisir": "perquisire",
    "perquisirai": "perquisire",
    "perquisiran": "perquisire",
    "perquisiranno": "perquisire",
    "perquisirebbe": "perquisire",
    "perquisirebber": "perquisire",
    "perquisirebbero": "perquisire",
    "perquisirei": "perquisire",
    "perquisiremmo": "perquisire",
    "perquisiremo": "perquisire",
    "perquisireste": "perquisire",
    "perquisiresti": "perquisire",
    "perquisirete": "perquisire",
    "perquisiron": "perquisire",
    "perquisirono": "perquisire",
    "perquisirà": "perquisire",
    "perquisirò": "perquisire",
    "perquisisca": "perquisire",
    "perquisiscan": "perquisire",
    "perquisiscano": "perquisire",
    "perquisisce": "perquisire",
    "perquisisci": "perquisire",
    "perquisisco": "perquisire",
    "perquisiscon": "perquisire",
    "perquisiscono": "perquisire",
    "perquisisse": "perquisire",
    "perquisisser": "perquisire",
    "perquisissero": "perquisire",
    "perquisissi": "perquisire",
    "perquisissimo": "perquisire",
    "perquisiste": "perquisire",
    "perquisisti": "perquisire",
    "perquisita": "perquisire",
    "perquisite": "perquisire",
    "perquisiti": "perquisire",
    "perquisito": "perquisire",
    "perquisiva": "perquisire",
    "perquisivamo": "perquisire",
    "perquisivan": "perquisire",
    "perquisivano": "perquisire",
    "perquisivate": "perquisire",
    "perquisivi": "perquisire",
    "perquisivo": "perquisire",
    "perquisizioni": "perquisizione",
    "perquisì": "perquisire",
    "persa": "perso",
    "perscruta": "perscrutare",
    "perscrutai": "perscrutare",
    "perscrutammo": "perscrutare",
    "perscrutan": "perscrutare",
    "perscrutando": "perscrutare",
    "perscrutano": "perscrutare",
    "perscrutante": "perscrutare",
    "perscrutanti": "perscrutare",
    "perscrutar": "perscrutare",
    "perscrutaron": "perscrutare",
    "perscrutarono": "perscrutare",
    "perscrutasse": "perscrutare",
    "perscrutasser": "perscrutare",
    "perscrutassero": "perscrutare",
    "perscrutassi": "perscrutare",
    "perscrutassimo": "perscrutare",
    "perscrutaste": "perscrutare",
    "perscrutasti": "perscrutare",
    "perscrutata": "perscrutare",
    "perscrutate": "perscrutare",
    "perscrutati": "perscrutare",
    "perscrutato": "perscrutare",
    "perscrutava": "perscrutare",
    "perscrutavamo": "perscrutare",
    "perscrutavan": "perscrutare",
    "perscrutavano": "perscrutare",
    "perscrutavate": "perscrutare",
    "perscrutavi": "perscrutare",
    "perscrutavo": "perscrutare",
    "perscruterai": "perscrutare",
    "perscruteran": "perscrutare",
    "perscruteranno": "perscrutare",
    "perscruterebbe": "perscrutare",
    "perscruterebber": "perscrutare",
    "perscruterebbero": "perscrutare",
    "perscruterei": "perscrutare",
    "perscruteremmo": "perscrutare",
    "perscruteremo": "perscrutare",
    "perscrutereste": "perscrutare",
    "perscruteresti": "perscrutare",
    "perscruterete": "perscrutare",
    "perscruterà": "perscrutare",
    "perscruterò": "perscrutare",
    "perscruti": "perscrutare",
    "perscrutiamo": "perscrutare",
    "perscrutiate": "perscrutare",
    "perscrutin": "perscrutare",
    "perscrutino": "perscrutare",
    "perscruto": "perscrutare",
    "perscrutò": "perscrutare",
    "perse": "perso",
    "persecutori": "persecutorio",
    "persecutoria": "persecutorio",
    "persecutorie": "persecutorio",
    "persecutrice": "persecutore",
    "persecutrici": "persecutore",
    "persecuzioni": "persecuzione",
    "persegua": "perseguire",
    "perseguan": "perseguire",
    "perseguano": "perseguire",
    "persegue": "perseguire",
    "perseguendo": "perseguire",
    "perseguente": "perseguire",
    "perseguenti": "perseguire",
    "persegui": "perseguire",
    "perseguiamo": "perseguire",
    "perseguiate": "perseguire",
    "perseguibili": "perseguibile",
    "perseguii": "perseguire",
    "perseguimenti": "perseguimento",
    "perseguimmo": "perseguire",
    "perseguir": "perseguire",
    "perseguirai": "perseguire",
    "perseguiran": "perseguire",
    "perseguiranno": "perseguire",
    "perseguirebbe": "perseguire",
    "perseguirebber": "perseguire",
    "perseguirebbero": "perseguire",
    "perseguirei": "perseguire",
    "perseguiremmo": "perseguire",
    "perseguiremo": "perseguire",
    "perseguireste": "perseguire",
    "perseguiresti": "perseguire",
    "perseguirete": "perseguire",
    "perseguiron": "perseguire",
    "perseguirono": "perseguire",
    "perseguirà": "perseguire",
    "perseguirò": "perseguire",
    "perseguisse": "perseguire",
    "perseguisser": "perseguire",
    "perseguissero": "perseguire",
    "perseguissi": "perseguire",
    "perseguissimo": "perseguire",
    "perseguiste": "perseguire",
    "perseguisti": "perseguire",
    "perseguita": "perseguitare",
    "perseguitai": "perseguitare",
    "perseguitammo": "perseguitare",
    "perseguitan": "perseguitare",
    "perseguitando": "perseguitare",
    "perseguitano": "perseguitare",
    "perseguitante": "perseguitare",
    "perseguitanti": "perseguitare",
    "perseguitar": "perseguitare",
    "perseguitaron": "perseguitare",
    "perseguitarono": "perseguitare",
    "perseguitasse": "perseguitare",
    "perseguitasser": "perseguitare",
    "perseguitassero": "perseguitare",
    "perseguitassi": "perseguitare",
    "perseguitassimo": "perseguitare",
    "perseguitaste": "perseguitare",
    "perseguitasti": "perseguitare",
    "perseguitata": "perseguitato",
    "perseguitate": "perseguitato",
    "perseguitati": "perseguitato",
    "perseguitato": "perseguitare",
    "perseguitava": "perseguitare",
    "perseguitavamo": "perseguitare",
    "perseguitavan": "perseguitare",
    "perseguitavano": "perseguitare",
    "perseguitavate": "perseguitare",
    "perseguitavi": "perseguitare",
    "perseguitavo": "perseguitare",
    "perseguite": "perseguire",
    "perseguiterai": "perseguitare",
    "perseguiteran": "perseguitare",
    "perseguiteranno": "perseguitare",
    "perseguiterebbe": "perseguitare",
    "perseguiterebber": "perseguitare",
    "perseguiterebbero": "perseguitare",
    "perseguiterei": "perseguitare",
    "perseguiteremmo": "perseguitare",
    "perseguiteremo": "perseguitare",
    "perseguitereste": "perseguitare",
    "perseguiteresti": "perseguitare",
    "perseguiterete": "perseguitare",
    "perseguiterà": "perseguitare",
    "perseguiterò": "perseguitare",
    "perseguiti": "perseguitare",
    "perseguitiamo": "perseguitare",
    "perseguitiate": "perseguitare",
    "perseguitin": "perseguitare",
    "perseguitino": "perseguitare",
    "perseguito": "perseguitare",
    "perseguitò": "perseguitare",
    "perseguiva": "perseguire",
    "perseguivamo": "perseguire",
    "perseguivan": "perseguire",
    "perseguivano": "perseguire",
    "perseguivate": "perseguire",
    "perseguivi": "perseguire",
    "perseguivo": "perseguire",
    "perseguo": "perseguire",
    "perseguon": "perseguire",
    "perseguono": "perseguire",
    "perseguì": "perseguire",
    "perser": "perdere",
    "persero": "perdere",
    "persevera": "perseverare",
    "perseverai": "perseverare",
    "perseverammo": "perseverare",
    "perseveran": "perseverare",
    "perseverando": "perseverare",
    "perseverano": "perseverare",
    "perseverante": "perseverare",
    "perseveranti": "perseverare",
    "perseverar": "perseverare",
    "perseveraron": "perseverare",
    "perseverarono": "perseverare",
    "perseverasse": "perseverare",
    "perseverasser": "perseverare",
    "perseverassero": "perseverare",
    "perseverassi": "perseverare",
    "perseverassimo": "perseverare",
    "perseveraste": "perseverare",
    "perseverasti": "perseverare",
    "perseverata": "perseverare",
    "perseverate": "perseverare",
    "perseverati": "perseverare",
    "perseverato": "perseverare",
    "perseverava": "perseverare",
    "perseveravamo": "perseverare",
    "perseveravan": "perseverare",
    "perseveravano": "perseverare",
    "perseveravate": "perseverare",
    "perseveravi": "perseverare",
    "perseveravo": "perseverare",
    "persevererai": "perseverare",
    "persevereran": "perseverare",
    "persevereranno": "perseverare",
    "persevererebbe": "perseverare",
    "persevererebber": "perseverare",
    "persevererebbero": "perseverare",
    "persevererei": "perseverare",
    "persevereremmo": "perseverare",
    "persevereremo": "perseverare",
    "perseverereste": "perseverare",
    "persevereresti": "perseverare",
    "persevererete": "perseverare",
    "persevererà": "perseverare",
    "persevererò": "perseverare",
    "perseveri": "perseverare",
    "perseveriamo": "perseverare",
    "perseveriate": "perseverare",
    "perseverin": "perseverare",
    "perseverino": "perseverare",
    "persevero": "perseverare",
    "perseverò": "perseverare",
    "persi": "perso",
    "persiana": "persiano",
    "persiane": "persiano",
    "persiani": "persiano",
    "persica": "persico",
    "persiche": "persico",
    "persici": "persico",
    "persista": "persistere",
    "persistan": "persistere",
    "persistano": "persistere",
    "persiste": "persistere",
    "persistei": "persistere",
    "persistemmo": "persistere",
    "persistendo": "persistere",
    "persistente": "persistere",
    "persistenti": "persistere",
    "persistenze": "persistenza",
    "persister": "persistere",
    "persisterai": "persistere",
    "persisteran": "persistere",
    "persisteranno": "persistere",
    "persisterebbe": "persistere",
    "persisterebber": "persistere",
    "persisterebbero": "persistere",
    "persisterei": "persistere",
    "persisteremmo": "persistere",
    "persisteremo": "persistere",
    "persistereste": "persistere",
    "persisteresti": "persistere",
    "persisterete": "persistere",
    "persisteron": "persistere",
    "persisterono": "persistere",
    "persisterà": "persistere",
    "persisterò": "persistere",
    "persistesse": "persistere",
    "persistesser": "persistere",
    "persistessero": "persistere",
    "persistessi": "persistere",
    "persistessimo": "persistere",
    "persisteste": "persistere",
    "persistesti": "persistere",
    "persistete": "persistere",
    "persisteva": "persistere",
    "persistevamo": "persistere",
    "persistevan": "persistere",
    "persistevano": "persistere",
    "persistevate": "persistere",
    "persistevi": "persistere",
    "persistevo": "persistere",
    "persisti": "persistere",
    "persistiamo": "persistere",
    "persistiate": "persistere",
    "persisto": "persistere",
    "persiston": "persistere",
    "persistono": "persistere",
    "persistuta": "persistere",
    "persistute": "persistere",
    "persistuti": "persistere",
    "persistuto": "persistere",
    "persistè": "persistere",
    "perso": "perdere",
    "personaggi": "personaggio",
    "personaggi-chiave": "personaggio-chiave",
    "personaggini": "personaggino",
    "personali": "personale",
    "personalismi": "personalismo",
    "personalistica": "personalistico",
    "personalistiche": "personalistico",
    "personalistici": "personalistico",
    "personalizza": "personalizzare",
    "personalizzai": "personalizzare",
    "personalizzammo": "personalizzare",
    "personalizzan": "personalizzare",
    "personalizzando": "personalizzare",
    "personalizzano": "personalizzare",
    "personalizzante": "personalizzare",
    "personalizzanti": "personalizzare",
    "personalizzar": "personalizzare",
    "personalizzaron": "personalizzare",
    "personalizzarono": "personalizzare",
    "personalizzasse": "personalizzare",
    "personalizzasser": "personalizzare",
    "personalizzassero": "personalizzare",
    "personalizzassi": "personalizzare",
    "personalizzassimo": "personalizzare",
    "personalizzaste": "personalizzare",
    "personalizzasti": "personalizzare",
    "personalizzata": "personalizzato",
    "personalizzate": "personalizzato",
    "personalizzati": "personalizzato",
    "personalizzato": "personalizzare",
    "personalizzava": "personalizzare",
    "personalizzavamo": "personalizzare",
    "personalizzavan": "personalizzare",
    "personalizzavano": "personalizzare",
    "personalizzavate": "personalizzare",
    "personalizzavi": "personalizzare",
    "personalizzavo": "personalizzare",
    "personalizzazioni": "personalizzazione",
    "personalizzerai": "personalizzare",
    "personalizzeran": "personalizzare",
    "personalizzeranno": "personalizzare",
    "personalizzerebbe": "personalizzare",
    "personalizzerebber": "personalizzare",
    "personalizzerebbero": "personalizzare",
    "personalizzerei": "personalizzare",
    "personalizzeremmo": "personalizzare",
    "personalizzeremo": "personalizzare",
    "personalizzereste": "personalizzare",
    "personalizzeresti": "personalizzare",
    "personalizzerete": "personalizzare",
    "personalizzerà": "personalizzare",
    "personalizzerò": "personalizzare",
    "personalizzi": "personalizzare",
    "personalizziamo": "personalizzare",
    "personalizziate": "personalizzare",
    "personalizzin": "personalizzare",
    "personalizzino": "personalizzare",
    "personalizzo": "personalizzare",
    "personalizzò": "personalizzare",
    "personcine": "personcina",
    "persone": "persona",
    "personifica": "personificare",
    "personificai": "personificare",
    "personificammo": "personificare",
    "personifican": "personificare",
    "personificando": "personificare",
    "personificano": "personificare",
    "personificante": "personificare",
    "personificanti": "personificare",
    "personificar": "personificare",
    "personificaron": "personificare",
    "personificarono": "personificare",
    "personificasse": "personificare",
    "personificasser": "personificare",
    "personificassero": "personificare",
    "personificassi": "personificare",
    "personificassimo": "personificare",
    "personificaste": "personificare",
    "personificasti": "personificare",
    "personificata": "personificare",
    "personificate": "personificare",
    "personificati": "personificare",
    "personificato": "personificare",
    "personificava": "personificare",
    "personificavamo": "personificare",
    "personificavan": "personificare",
    "personificavano": "personificare",
    "personificavate": "personificare",
    "personificavi": "personificare",
    "personificavo": "personificare",
    "personificazioni": "personificazione",
    "personificherai": "personificare",
    "personificheran": "personificare",
    "personificheranno": "personificare",
    "personificherebbe": "personificare",
    "personificherebber": "personificare",
    "personificherebbero": "personificare",
    "personificherei": "personificare",
    "personificheremmo": "personificare",
    "personificheremo": "personificare",
    "personifichereste": "personificare",
    "personificheresti": "personificare",
    "personificherete": "personificare",
    "personificherà": "personificare",
    "personificherò": "personificare",
    "personifichi": "personificare",
    "personifichiamo": "personificare",
    "personifichiate": "personificare",
    "personifichin": "personificare",
    "personifichino": "personificare",
    "personifico": "personificare",
    "personificò": "personificare",
    "perspicaci": "perspicace",
    "perspicua": "perspicuo",
    "perspicue": "perspicuo",
    "perspicui": "perspicuo",
    "persuada": "persuadere",
    "persuadan": "persuadere",
    "persuadano": "persuadere",
    "persuade": "persuadere",
    "persuademmo": "persuadere",
    "persuadendo": "persuadere",
    "persuadente": "persuadere",
    "persuadenti": "persuadere",
    "persuader": "persuadere",
    "persuaderai": "persuadere",
    "persuaderan": "persuadere",
    "persuaderanno": "persuadere",
    "persuaderebbe": "persuadere",
    "persuaderebber": "persuadere",
    "persuaderebbero": "persuadere",
    "persuaderei": "persuadere",
    "persuaderemmo": "persuadere",
    "persuaderemo": "persuadere",
    "persuadereste": "persuadere",
    "persuaderesti": "persuadere",
    "persuaderete": "persuadere",
    "persuaderà": "persuadere",
    "persuaderò": "persuadere",
    "persuadesse": "persuadere",
    "persuadesser": "persuadere",
    "persuadessero": "persuadere",
    "persuadessi": "persuadere",
    "persuadessimo": "persuadere",
    "persuadeste": "persuadere",
    "persuadesti": "persuadere",
    "persuadete": "persuadere",
    "persuadeva": "persuadere",
    "persuadevamo": "persuadere",
    "persuadevan": "persuadere",
    "persuadevano": "persuadere",
    "persuadevate": "persuadere",
    "persuadevi": "persuadere",
    "persuadevo": "persuadere",
    "persuadi": "persuadere",
    "persuadiamo": "persuadere",
    "persuadiate": "persuadere",
    "persuado": "persuadere",
    "persuadon": "persuadere",
    "persuadono": "persuadere",
    "persuasa": "persuadere",
    "persuase": "persuadere",
    "persuaser": "persuadere",
    "persuasero": "persuadere",
    "persuasi": "persuadere",
    "persuasioni": "persuasione",
    "persuasiva": "persuasivo",
    "persuasive": "persuasivo",
    "persuasivi": "persuasivo",
    "persuaso": "persuadere",
    "persuasori": "persuasore",
    "pertiche": "pertica",
    "perticoni": "perticone",
    "pertinenti": "pertinente",
    "pertinenze": "pertinenza",
    "pertossi": "pertosse",
    "pertugi": "pertugio",
    "perturba": "perturbare",
    "perturbai": "perturbare",
    "perturbammo": "perturbare",
    "perturban": "perturbare",
    "perturbando": "perturbare",
    "perturbano": "perturbare",
    "perturbante": "perturbare",
    "perturbanti": "perturbare",
    "perturbar": "perturbare",
    "perturbaron": "perturbare",
    "perturbarono": "perturbare",
    "perturbasse": "perturbare",
    "perturbasser": "perturbare",
    "perturbassero": "perturbare",
    "perturbassi": "perturbare",
    "perturbassimo": "perturbare",
    "perturbaste": "perturbare",
    "perturbasti": "perturbare",
    "perturbata": "perturbare",
    "perturbate": "perturbare",
    "perturbati": "perturbare",
    "perturbato": "perturbare",
    "perturbava": "perturbare",
    "perturbavamo": "perturbare",
    "perturbavan": "perturbare",
    "perturbavano": "perturbare",
    "perturbavate": "perturbare",
    "perturbavi": "perturbare",
    "perturbavo": "perturbare",
    "perturbazioni": "perturbazione",
    "perturberai": "perturbare",
    "perturberan": "perturbare",
    "perturberanno": "perturbare",
    "perturberebbe": "perturbare",
    "perturberebber": "perturbare",
    "perturberebbero": "perturbare",
    "perturberei": "perturbare",
    "perturberemmo": "perturbare",
    "perturberemo": "perturbare",
    "perturbereste": "perturbare",
    "perturberesti": "perturbare",
    "perturberete": "perturbare",
    "perturberà": "perturbare",
    "perturberò": "perturbare",
    "perturbi": "perturbare",
    "perturbiamo": "perturbare",
    "perturbiate": "perturbare",
    "perturbin": "perturbare",
    "perturbino": "perturbare",
    "perturbo": "perturbare",
    "perturbò": "perturbare",
    "perugina": "perugino",
    "perugine": "perugino",
    "perugini": "perugino",
    "peruviana": "peruviano",
    "peruviane": "peruviano",
    "peruviani": "peruviano",
    "pervada": "pervadere",
    "pervadan": "pervadere",
    "pervadano": "pervadere",
    "pervade": "pervadere",
    "pervademmo": "pervadere",
    "pervadendo": "pervadere",
    "pervadente": "pervadere",
    "pervadenti": "pervadere",
    "pervader": "pervadere",
    "pervaderai": "pervadere",
    "pervaderan": "pervadere",
    "pervaderanno": "pervadere",
    "pervaderebbe": "pervadere",
    "pervaderebber": "pervadere",
    "pervaderebbero": "pervadere",
    "pervaderei": "pervadere",
    "pervaderemmo": "pervadere",
    "pervaderemo": "pervadere",
    "pervadereste": "pervadere",
    "pervaderesti": "pervadere",
    "pervaderete": "pervadere",
    "pervaderà": "pervadere",
    "pervaderò": "pervadere",
    "pervadesse": "pervadere",
    "pervadesser": "pervadere",
    "pervadessero": "pervadere",
    "pervadessi": "pervadere",
    "pervadessimo": "pervadere",
    "pervadeste": "pervadere",
    "pervadesti": "pervadere",
    "pervadete": "pervadere",
    "pervadeva": "pervadere",
    "pervadevamo": "pervadere",
    "pervadevan": "pervadere",
    "pervadevano": "pervadere",
    "pervadevate": "pervadere",
    "pervadevi": "pervadere",
    "pervadevo": "pervadere",
    "pervadi": "pervadere",
    "pervadiamo": "pervadere",
    "pervadiate": "pervadere",
    "pervado": "pervadere",
    "pervadon": "pervadere",
    "pervadono": "pervadere",
    "pervasa": "pervadere",
    "pervase": "pervadere",
    "pervaser": "pervadere",
    "pervasero": "pervadere",
    "pervasi": "pervadere",
    "pervaso": "pervadere",
    "pervenendo": "pervenire",
    "pervenente": "pervenire",
    "pervenenti": "pervenire",
    "pervenga": "pervenire",
    "pervengan": "pervenire",
    "pervengano": "pervenire",
    "pervengo": "pervenire",
    "pervengon": "pervenire",
    "pervengono": "pervenire",
    "perveniamo": "pervenire",
    "perveniate": "pervenire",
    "pervenimmo": "pervenire",
    "pervenir": "pervenire",
    "pervenisse": "pervenire",
    "pervenisser": "pervenire",
    "pervenissero": "pervenire",
    "pervenissi": "pervenire",
    "pervenissimo": "pervenire",
    "perveniste": "pervenire",
    "pervenisti": "pervenire",
    "pervenite": "pervenire",
    "perveniva": "pervenire",
    "pervenivamo": "pervenire",
    "pervenivan": "pervenire",
    "pervenivano": "pervenire",
    "pervenivate": "pervenire",
    "pervenivi": "pervenire",
    "pervenivo": "pervenire",
    "pervenne": "pervenire",
    "pervenner": "pervenire",
    "pervennero": "pervenire",
    "pervenni": "pervenire",
    "pervenuta": "pervenire",
    "pervenute": "pervenire",
    "pervenuti": "pervenire",
    "pervenuto": "pervenire",
    "perverrai": "pervenire",
    "perverran": "pervenire",
    "perverranno": "pervenire",
    "perverrebbe": "pervenire",
    "perverrebber": "pervenire",
    "perverrebbero": "pervenire",
    "perverrei": "pervenire",
    "perverremmo": "pervenire",
    "perverremo": "pervenire",
    "perverreste": "pervenire",
    "perverresti": "pervenire",
    "perverrete": "pervenire",
    "perverrà": "pervenire",
    "perverrò": "pervenire",
    "perversa": "perverso",
    "perverse": "perverso",
    "perversi": "perverso",
    "perversioni": "perversione",
    "perverta": "pervertire",
    "pervertan": "pervertire",
    "pervertano": "pervertire",
    "perverte": "pervertire",
    "pervertendo": "pervertire",
    "pervertente": "pervertire",
    "pervertenti": "pervertire",
    "perverti": "pervertire",
    "pervertiamo": "pervertire",
    "pervertiate": "pervertire",
    "pervertii": "pervertire",
    "pervertimmo": "pervertire",
    "pervertir": "pervertire",
    "pervertirai": "pervertire",
    "pervertiran": "pervertire",
    "pervertiranno": "pervertire",
    "pervertirebbe": "pervertire",
    "pervertirebber": "pervertire",
    "pervertirebbero": "pervertire",
    "pervertirei": "pervertire",
    "pervertiremmo": "pervertire",
    "pervertiremo": "pervertire",
    "pervertireste": "pervertire",
    "pervertiresti": "pervertire",
    "pervertirete": "pervertire",
    "pervertiron": "pervertire",
    "pervertirono": "pervertire",
    "pervertirà": "pervertire",
    "pervertirò": "pervertire",
    "pervertisse": "pervertire",
    "pervertisser": "pervertire",
    "pervertissero": "pervertire",
    "pervertissi": "pervertire",
    "pervertissimo": "pervertire",
    "pervertiste": "pervertire",
    "pervertisti": "pervertire",
    "pervertita": "pervertire",
    "pervertite": "pervertire",
    "pervertiti": "pervertito",
    "pervertito": "pervertire",
    "pervertiva": "pervertire",
    "pervertivamo": "pervertire",
    "pervertivan": "pervertire",
    "pervertivano": "pervertire",
    "pervertivate": "pervertire",
    "pervertivi": "pervertire",
    "pervertivo": "pervertire",
    "perverto": "pervertire",
    "perverton": "pervertire",
    "pervertono": "pervertire",
    "pervertì": "pervertire",
    "pervicaci": "pervicace",
    "pervicacie": "pervicacia",
    "perviene": "pervenire",
    "pervieni": "pervenire",
    "perì": "perire",
    "pesa": "pesare",
    "pesai": "pesare",
    "pesammo": "pesare",
    "pesan": "pesare",
    "pesando": "pesare",
    "pesano": "pesare",
    "pesante": "pesare",
    "pesantezze": "pesantezza",
    "pesanti": "pesare",
    "pesar": "pesare",
    "pesaresi": "pesarese",
    "pesaron": "pesare",
    "pesarono": "pesare",
    "pesasse": "pesare",
    "pesasser": "pesare",
    "pesassero": "pesare",
    "pesassi": "pesare",
    "pesassimo": "pesare",
    "pesaste": "pesare",
    "pesasti": "pesare",
    "pesata": "pesare",
    "pesate": "pesare",
    "pesati": "pesare",
    "pesato": "pesare",
    "pesava": "pesare",
    "pesavamo": "pesare",
    "pesavan": "pesare",
    "pesavano": "pesare",
    "pesavate": "pesare",
    "pesavi": "pesare",
    "pesavo": "pesare",
    "pesca": "pescare",
    "pescai": "pescare",
    "pescammo": "pescare",
    "pescan": "pescare",
    "pescando": "pescare",
    "pescano": "pescare",
    "pescante": "pescare",
    "pescanti": "pescare",
    "pescar": "pescare",
    "pescaresi": "pescarese",
    "pescaron": "pescare",
    "pescarono": "pescare",
    "pescasse": "pescare",
    "pescasser": "pescare",
    "pescassero": "pescare",
    "pescassi": "pescare",
    "pescassimo": "pescare",
    "pescaste": "pescare",
    "pescasti": "pescare",
    "pescata": "pescare",
    "pescate": "pescare",
    "pescati": "pescare",
    "pescato": "pescare",
    "pescatori": "pescatore",
    "pescatrice": "pescatore",
    "pescatrici": "pescatore",
    "pescava": "pescare",
    "pescavamo": "pescare",
    "pescavan": "pescare",
    "pescavano": "pescare",
    "pescavate": "pescare",
    "pescavi": "pescare",
    "pescavo": "pescare",
    "pescecani": "pescecane",
    "pesche": "pesca",
    "pescherai": "pescare",
    "pescheran": "pescare",
    "pescheranno": "pescare",
    "pescherebbe": "pescare",
    "pescherebber": "pescare",
    "pescherebbero": "pescare",
    "pescherecce": "peschereccio",
    "pescherecci": "peschereccio",
    "peschereccia": "peschereccio",
    "pescherei": "pescare",
    "pescheremmo": "pescare",
    "pescheremo": "pescare",
    "peschereste": "pescare",
    "pescheresti": "pescare",
    "pescherete": "pescare",
    "pescherie": "pescheria",
    "pescherà": "pescare",
    "pescherò": "pescare",
    "peschi": "pescare",
    "peschiamo": "pescare",
    "peschiate": "pescare",
    "peschin": "pescare",
    "peschino": "pescare",
    "pesci": "pesce",
    "pesciolini": "pesciolino",
    "pescivendoli": "pescivendolo",
    "pesco": "pescare",
    "pescò": "pescare",
    "pese": "pesa",
    "peser": "pendere",
    "peserai": "pesare",
    "peseran": "pesare",
    "peseranno": "pesare",
    "peserebbe": "pesare",
    "peserebber": "pesare",
    "peserebbero": "pesare",
    "peserei": "pesare",
    "peseremmo": "pesare",
    "peseremo": "pesare",
    "pesereste": "pesare",
    "peseresti": "pesare",
    "peserete": "pesare",
    "pesero": "pendere",
    "peserà": "pesare",
    "peserò": "pesare",
    "pesetas": "peseta",
    "pesi": "peso",
    "pesiamo": "pesare",
    "pesiate": "pesare",
    "pesin": "pesare",
    "pesino": "pesare",
    "pesisti": "pesista",
    "peso": "pesare",
    "pessima": "pessimo",
    "pessime": "pessimo",
    "pessimi": "pessimo",
    "pessimismi": "pessimismo",
    "pessimisti": "pessimista",
    "pessimistica": "pessimistico",
    "pessimistiche": "pessimistico",
    "pessimistici": "pessimistico",
    "pessimo": "cattivo",
    "pesta": "pesto",
    "pestaggi": "pestaggio",
    "pestai": "pestare",
    "pestammo": "pestare",
    "pestan": "pestare",
    "pestando": "pestare",
    "pestano": "pestare",
    "pestante": "pestare",
    "pestanti": "pestare",
    "pestar": "pestare",
    "pestaron": "pestare",
    "pestarono": "pestare",
    "pestasse": "pestare",
    "pestasser": "pestare",
    "pestassero": "pestare",
    "pestassi": "pestare",
    "pestassimo": "pestare",
    "pestaste": "pestare",
    "pestasti": "pestare",
    "pestata": "pestare",
    "pestate": "pestare",
    "pestati": "pestare",
    "pestato": "pestare",
    "pestava": "pestare",
    "pestavamo": "pestare",
    "pestavan": "pestare",
    "pestavano": "pestare",
    "pestavate": "pestare",
    "pestavi": "pestare",
    "pestavo": "pestare",
    "peste": "pesto",
    "pesterai": "pestare",
    "pesteran": "pestare",
    "pesteranno": "pestare",
    "pesterebbe": "pestare",
    "pesterebber": "pestare",
    "pesterebbero": "pestare",
    "pesterei": "pestare",
    "pesteremmo": "pestare",
    "pesteremo": "pestare",
    "pestereste": "pestare",
    "pesteresti": "pestare",
    "pesterete": "pestare",
    "pesterà": "pestare",
    "pesterò": "pestare",
    "pesti": "pesto",
    "pestiamo": "pestare",
    "pestiate": "pestare",
    "pesticcerai": "pesticciare",
    "pesticceran": "pesticciare",
    "pesticceranno": "pesticciare",
    "pesticcerebbe": "pesticciare",
    "pesticcerebber": "pesticciare",
    "pesticcerebbero": "pesticciare",
    "pesticcerei": "pesticciare",
    "pesticceremmo": "pesticciare",
    "pesticceremo": "pesticciare",
    "pesticcereste": "pesticciare",
    "pesticceresti": "pesticciare",
    "pesticcerete": "pesticciare",
    "pesticcerà": "pesticciare",
    "pesticcerò": "pesticciare",
    "pesticci": "pesticciare",
    "pesticcia": "pesticciare",
    "pesticciai": "pesticciare",
    "pesticciammo": "pesticciare",
    "pesticciamo": "pesticciare",
    "pesticcian": "pesticciare",
    "pesticciando": "pesticciare",
    "pesticciano": "pesticciare",
    "pesticciante": "pesticciare",
    "pesticcianti": "pesticciare",
    "pesticciar": "pesticciare",
    "pesticciaron": "pesticciare",
    "pesticciarono": "pesticciare",
    "pesticciasse": "pesticciare",
    "pesticciasser": "pesticciare",
    "pesticciassero": "pesticciare",
    "pesticciassi": "pesticciare",
    "pesticciassimo": "pesticciare",
    "pesticciaste": "pesticciare",
    "pesticciasti": "pesticciare",
    "pesticciata": "pesticciare",
    "pesticciate": "pesticciare",
    "pesticciati": "pesticciare",
    "pesticciato": "pesticciare",
    "pesticciava": "pesticciare",
    "pesticciavamo": "pesticciare",
    "pesticciavan": "pesticciare",
    "pesticciavano": "pesticciare",
    "pesticciavate": "pesticciare",
    "pesticciavi": "pesticciare",
    "pesticciavo": "pesticciare",
    "pesticcin": "pesticciare",
    "pesticcino": "pesticciare",
    "pesticcio": "pesticciare",
    "pesticciò": "pesticciare",
    "pesticidi": "pesticida",
    "pestilenze": "pestilenza",
    "pestilenziali": "pestilenziale",
    "pestin": "pestare",
    "pestino": "pestare",
    "pesto": "pestare",
    "pestoni": "pestone",
    "pestò": "pestare",
    "pesè": "pendere",
    "pesò": "pesare",
    "petali": "petalo",
    "petardi": "petardo",
    "petecchiali": "petecchiale",
    "peti": "peto",
    "petizioni": "petizione",
    "petrodollari": "petrodollaro",
    "petrolchimica": "petrolchimico",
    "petrolchimiche": "petrolchimico",
    "petrolchimici": "petrolchimico",
    "petroli": "petrolio",
    "petroliera": "petroliero",
    "petroliere": "petroliero",
    "petrolieri": "petroliero",
    "petrolifera": "petrolifero",
    "petrolifere": "petrolifero",
    "petroliferi": "petrolifero",
    "petrosa": "petroso",
    "petrose": "petroso",
    "petrosi": "petroso",
    "pettegola": "pettegolo",
    "pettegolai": "pettegolare",
    "pettegolammo": "pettegolare",
    "pettegolan": "pettegolare",
    "pettegolando": "pettegolare",
    "pettegolano": "pettegolare",
    "pettegolante": "pettegolare",
    "pettegolanti": "pettegolare",
    "pettegolar": "pettegolare",
    "pettegolaron": "pettegolare",
    "pettegolarono": "pettegolare",
    "pettegolasse": "pettegolare",
    "pettegolasser": "pettegolare",
    "pettegolassero": "pettegolare",
    "pettegolassi": "pettegolare",
    "pettegolassimo": "pettegolare",
    "pettegolaste": "pettegolare",
    "pettegolasti": "pettegolare",
    "pettegolata": "pettegolare",
    "pettegolate": "pettegolare",
    "pettegolati": "pettegolare",
    "pettegolato": "pettegolare",
    "pettegolava": "pettegolare",
    "pettegolavamo": "pettegolare",
    "pettegolavan": "pettegolare",
    "pettegolavano": "pettegolare",
    "pettegolavate": "pettegolare",
    "pettegolavi": "pettegolare",
    "pettegolavo": "pettegolare",
    "pettegole": "pettegolo",
    "pettegolerai": "pettegolare",
    "pettegoleran": "pettegolare",
    "pettegoleranno": "pettegolare",
    "pettegolerebbe": "pettegolare",
    "pettegolerebber": "pettegolare",
    "pettegolerebbero": "pettegolare",
    "pettegolerei": "pettegolare",
    "pettegoleremmo": "pettegolare",
    "pettegoleremo": "pettegolare",
    "pettegolereste": "pettegolare",
    "pettegoleresti": "pettegolare",
    "pettegolerete": "pettegolare",
    "pettegolerà": "pettegolare",
    "pettegolerò": "pettegolare",
    "pettegolezzi": "pettegolezzo",
    "pettegoli": "pettegolo",
    "pettegoliamo": "pettegolare",
    "pettegoliate": "pettegolare",
    "pettegolin": "pettegolare",
    "pettegolino": "pettegolare",
    "pettegolo": "pettegolare",
    "pettegolò": "pettegolare",
    "petti": "petto",
    "pettina": "pettinare",
    "pettinai": "pettinare",
    "pettinammo": "pettinare",
    "pettinan": "pettinare",
    "pettinando": "pettinare",
    "pettinano": "pettinare",
    "pettinante": "pettinare",
    "pettinanti": "pettinare",
    "pettinar": "pettinare",
    "pettinaron": "pettinare",
    "pettinarono": "pettinare",
    "pettinasse": "pettinare",
    "pettinasser": "pettinare",
    "pettinassero": "pettinare",
    "pettinassi": "pettinare",
    "pettinassimo": "pettinare",
    "pettinaste": "pettinare",
    "pettinasti": "pettinare",
    "pettinata": "pettinato",
    "pettinate": "pettinato",
    "pettinati": "pettinato",
    "pettinato": "pettinare",
    "pettinature": "pettinatura",
    "pettinava": "pettinare",
    "pettinavamo": "pettinare",
    "pettinavan": "pettinare",
    "pettinavano": "pettinare",
    "pettinavate": "pettinare",
    "pettinavi": "pettinare",
    "pettinavo": "pettinare",
    "pettinerai": "pettinare",
    "pettineran": "pettinare",
    "pettineranno": "pettinare",
    "pettinerebbe": "pettinare",
    "pettinerebber": "pettinare",
    "pettinerebbero": "pettinare",
    "pettinerei": "pettinare",
    "pettineremmo": "pettinare",
    "pettineremo": "pettinare",
    "pettinereste": "pettinare",
    "pettineresti": "pettinare",
    "pettinerete": "pettinare",
    "pettinerà": "pettinare",
    "pettinerò": "pettinare",
    "pettini": "pettine",
    "pettiniamo": "pettinare",
    "pettiniate": "pettinare",
    "pettinin": "pettinare",
    "pettinino": "pettinare",
    "pettino": "pettinare",
    "pettinò": "pettinare",
    "pettirossi": "pettirosso",
    "pettorali": "pettorale",
    "pettorine": "pettorina",
    "petulanti": "petulante",
    "petulanze": "petulanza",
    "pezzata": "pezzato",
    "pezzate": "pezzato",
    "pezzati": "pezzato",
    "pezzature": "pezzatura",
    "pezze": "pezza",
    "pezzenti": "pezzente",
    "pezzetti": "pezzetto",
    "pezzettini": "pezzettino",
    "pezzi": "pezzo",
    "pi": "piare",
    "pia": "pio",
    "piaccia": "piacere",
    "piacciamo": "piacere",
    "piaccian": "piacere",
    "piacciano": "piacere",
    "piacciate": "piacere",
    "piaccio": "piacere",
    "piaccion": "piacere",
    "piacciono": "piacere",
    "piace": "piacere",
    "piacemmo": "piacere",
    "piacendo": "piacere",
    "piacente": "piacere",
    "piacenti": "piacere",
    "piacentini": "piacentino",
    "piacer": "piacere",
    "piacerai": "piacere",
    "piaceran": "piacere",
    "piaceranno": "piacere",
    "piacerebbe": "piacere",
    "piacerebber": "piacere",
    "piacerebbero": "piacere",
    "piacerei": "piacere",
    "piaceremmo": "piacere",
    "piaceremo": "piacere",
    "piacereste": "piacere",
    "piaceresti": "piacere",
    "piacerete": "piacere",
    "piaceri": "piacere",
    "piacerà": "piacere",
    "piacerò": "piacere",
    "piacesse": "piacere",
    "piacesser": "piacere",
    "piacessero": "piacere",
    "piacessi": "piacere",
    "piacessimo": "piacere",
    "piaceste": "piacere",
    "piacesti": "piacere",
    "piacete": "piacere",
    "piaceva": "piacere",
    "piacevamo": "piacere",
    "piacevan": "piacere",
    "piacevano": "piacere",
    "piacevate": "piacere",
    "piacevi": "piacere",
    "piacevo": "piacere",
    "piacevolezze": "piacevolezza",
    "piacevoli": "piacevole",
    "piaci": "piacere",
    "piacimenti": "piacimento",
    "piaciuta": "piacere",
    "piaciute": "piacere",
    "piaciuti": "piacere",
    "piaciuto": "piacere",
    "piacque": "piacere",
    "piacquer": "piacere",
    "piacquero": "piacere",
    "piacqui": "piacere",
    "piadine": "piadina",
    "piaga": "piagare",
    "piagai": "piagare",
    "piagammo": "piagare",
    "piagan": "piagare",
    "piagando": "piagare",
    "piagano": "piagare",
    "piagante": "piagare",
    "piaganti": "piagare",
    "piagar": "piagare",
    "piagaron": "piagare",
    "piagarono": "piagare",
    "piagasse": "piagare",
    "piagasser": "piagare",
    "piagassero": "piagare",
    "piagassi": "piagare",
    "piagassimo": "piagare",
    "piagaste": "piagare",
    "piagasti": "piagare",
    "piagata": "piagare",
    "piagate": "piagare",
    "piagati": "piagare",
    "piagato": "piagare",
    "piagava": "piagare",
    "piagavamo": "piagare",
    "piagavan": "piagare",
    "piagavano": "piagare",
    "piagavate": "piagare",
    "piagavi": "piagare",
    "piagavo": "piagare",
    "piaggerai": "piaggiare",
    "piaggeran": "piaggiare",
    "piaggeranno": "piaggiare",
    "piaggerebbe": "piaggiare",
    "piaggerebber": "piaggiare",
    "piaggerebbero": "piaggiare",
    "piaggerei": "piaggiare",
    "piaggeremmo": "piaggiare",
    "piaggeremo": "piaggiare",
    "piaggereste": "piaggiare",
    "piaggeresti": "piaggiare",
    "piaggerete": "piaggiare",
    "piaggerà": "piaggiare",
    "piaggerò": "piaggiare",
    "piaggi": "piaggiare",
    "piaggia": "piaggiare",
    "piaggiai": "piaggiare",
    "piaggiammo": "piaggiare",
    "piaggiamo": "piaggiare",
    "piaggian": "piaggiare",
    "piaggiando": "piaggiare",
    "piaggiano": "piaggiare",
    "piaggiante": "piaggiare",
    "piaggianti": "piaggiare",
    "piaggiar": "piaggiare",
    "piaggiaron": "piaggiare",
    "piaggiarono": "piaggiare",
    "piaggiasse": "piaggiare",
    "piaggiasser": "piaggiare",
    "piaggiassero": "piaggiare",
    "piaggiassi": "piaggiare",
    "piaggiassimo": "piaggiare",
    "piaggiaste": "piaggiare",
    "piaggiasti": "piaggiare",
    "piaggiata": "piaggiare",
    "piaggiate": "piaggiare",
    "piaggiati": "piaggiare",
    "piaggiato": "piaggiare",
    "piaggiava": "piaggiare",
    "piaggiavamo": "piaggiare",
    "piaggiavan": "piaggiare",
    "piaggiavano": "piaggiare",
    "piaggiavate": "piaggiare",
    "piaggiavi": "piaggiare",
    "piaggiavo": "piaggiare",
    "piaggin": "piaggiare",
    "piaggino": "piaggiare",
    "piaggio": "piaggiare",
    "piaggiò": "piaggiare",
    "piaghe": "piaga",
    "piagherai": "piagare",
    "piagheran": "piagare",
    "piagheranno": "piagare",
    "piagherebbe": "piagare",
    "piagherebber": "piagare",
    "piagherebbero": "piagare",
    "piagherei": "piagare",
    "piagheremmo": "piagare",
    "piagheremo": "piagare",
    "piaghereste": "piagare",
    "piagheresti": "piagare",
    "piagherete": "piagare",
    "piagherà": "piagare",
    "piagherò": "piagare",
    "piaghi": "piagare",
    "piaghiamo": "piagare",
    "piaghiate": "piagare",
    "piaghin": "piagare",
    "piaghino": "piagare",
    "piagnistei": "piagnisteo",
    "piagnoni": "piagnone",
    "piagnucola": "piagnucolare",
    "piagnucolai": "piagnucolare",
    "piagnucolammo": "piagnucolare",
    "piagnucolan": "piagnucolare",
    "piagnucolando": "piagnucolare",
    "piagnucolano": "piagnucolare",
    "piagnucolante": "piagnucolare",
    "piagnucolanti": "piagnucolare",
    "piagnucolar": "piagnucolare",
    "piagnucolaron": "piagnucolare",
    "piagnucolarono": "piagnucolare",
    "piagnucolasse": "piagnucolare",
    "piagnucolasser": "piagnucolare",
    "piagnucolassero": "piagnucolare",
    "piagnucolassi": "piagnucolare",
    "piagnucolassimo": "piagnucolare",
    "piagnucolaste": "piagnucolare",
    "piagnucolasti": "piagnucolare",
    "piagnucolata": "piagnucolare",
    "piagnucolate": "piagnucolare",
    "piagnucolati": "piagnucolare",
    "piagnucolato": "piagnucolare",
    "piagnucolava": "piagnucolare",
    "piagnucolavamo": "piagnucolare",
    "piagnucolavan": "piagnucolare",
    "piagnucolavano": "piagnucolare",
    "piagnucolavate": "piagnucolare",
    "piagnucolavi": "piagnucolare",
    "piagnucolavo": "piagnucolare",
    "piagnucolerai": "piagnucolare",
    "piagnucoleran": "piagnucolare",
    "piagnucoleranno": "piagnucolare",
    "piagnucolerebbe": "piagnucolare",
    "piagnucolerebber": "piagnucolare",
    "piagnucolerebbero": "piagnucolare",
    "piagnucolerei": "piagnucolare",
    "piagnucoleremmo": "piagnucolare",
    "piagnucoleremo": "piagnucolare",
    "piagnucolereste": "piagnucolare",
    "piagnucoleresti": "piagnucolare",
    "piagnucolerete": "piagnucolare",
    "piagnucolerà": "piagnucolare",
    "piagnucolerò": "piagnucolare",
    "piagnucoli": "piagnucolare",
    "piagnucoliamo": "piagnucolare",
    "piagnucoliate": "piagnucolare",
    "piagnucolin": "piagnucolare",
    "piagnucolino": "piagnucolare",
    "piagnucolo": "piagnucolare",
    "piagnucolosa": "piagnucoloso",
    "piagnucolose": "piagnucoloso",
    "piagnucolosi": "piagnucoloso",
    "piagnucolò": "piagnucolare",
    "piago": "piagare",
    "piagò": "piagare",
    "piai": "piare",
    "pialla": "piallare",
    "piallai": "piallare",
    "piallammo": "piallare",
    "piallan": "piallare",
    "piallando": "piallare",
    "piallano": "piallare",
    "piallante": "piallare",
    "piallanti": "piallare",
    "piallar": "piallare",
    "piallaron": "piallare",
    "piallarono": "piallare",
    "piallasse": "piallare",
    "piallasser": "piallare",
    "piallassero": "piallare",
    "piallassi": "piallare",
    "piallassimo": "piallare",
    "piallaste": "piallare",
    "piallasti": "piallare",
    "piallata": "piallare",
    "piallate": "piallare",
    "piallati": "piallare",
    "piallato": "piallare",
    "piallava": "piallare",
    "piallavamo": "piallare",
    "piallavan": "piallare",
    "piallavano": "piallare",
    "piallavate": "piallare",
    "piallavi": "piallare",
    "piallavo": "piallare",
    "piallerai": "piallare",
    "pialleran": "piallare",
    "pialleranno": "piallare",
    "piallerebbe": "piallare",
    "piallerebber": "piallare",
    "piallerebbero": "piallare",
    "piallerei": "piallare",
    "pialleremmo": "piallare",
    "pialleremo": "piallare",
    "piallereste": "piallare",
    "pialleresti": "piallare",
    "piallerete": "piallare",
    "piallerà": "piallare",
    "piallerò": "piallare",
    "pialli": "piallare",
    "pialliamo": "piallare",
    "pialliate": "piallare",
    "piallin": "piallare",
    "piallino": "piallare",
    "piallo": "piallare",
    "piallò": "piallare",
    "piammo": "piare",
    "piamo": "piare",
    "pian": "piare",
    "piana": "piano",
    "pianali": "pianale",
    "piando": "piare",
    "piane": "piano",
    "pianeggerai": "pianeggiare",
    "pianeggeran": "pianeggiare",
    "pianeggeranno": "pianeggiare",
    "pianeggerebbe": "pianeggiare",
    "pianeggerebber": "pianeggiare",
    "pianeggerebbero": "pianeggiare",
    "pianeggerei": "pianeggiare",
    "pianeggeremmo": "pianeggiare",
    "pianeggeremo": "pianeggiare",
    "pianeggereste": "pianeggiare",
    "pianeggeresti": "pianeggiare",
    "pianeggerete": "pianeggiare",
    "pianeggerà": "pianeggiare",
    "pianeggerò": "pianeggiare",
    "pianeggi": "pianeggiare",
    "pianeggia": "pianeggiare",
    "pianeggiai": "pianeggiare",
    "pianeggiammo": "pianeggiare",
    "pianeggiamo": "pianeggiare",
    "pianeggian": "pianeggiare",
    "pianeggiando": "pianeggiare",
    "pianeggiano": "pianeggiare",
    "pianeggiante": "pianeggiare",
    "pianeggianti": "pianeggiare",
    "pianeggiar": "pianeggiare",
    "pianeggiaron": "pianeggiare",
    "pianeggiarono": "pianeggiare",
    "pianeggiasse": "pianeggiare",
    "pianeggiasser": "pianeggiare",
    "pianeggiassero": "pianeggiare",
    "pianeggiassi": "pianeggiare",
    "pianeggiassimo": "pianeggiare",
    "pianeggiaste": "pianeggiare",
    "pianeggiasti": "pianeggiare",
    "pianeggiata": "pianeggiare",
    "pianeggiate": "pianeggiare",
    "pianeggiati": "pianeggiare",
    "pianeggiato": "pianeggiare",
    "pianeggiava": "pianeggiare",
    "pianeggiavamo": "pianeggiare",
    "pianeggiavan": "pianeggiare",
    "pianeggiavano": "pianeggiare",
    "pianeggiavate": "pianeggiare",
    "pianeggiavi": "pianeggiare",
    "pianeggiavo": "pianeggiare",
    "pianeggin": "pianeggiare",
    "pianeggino": "pianeggiare",
    "pianeggio": "pianeggiare",
    "pianeggiò": "pianeggiare",
    "pianerottoli": "pianerottolo",
    "pianeti": "pianeta",
    "pianetti": "pianetto",
    "pianga": "piangere",
    "piangan": "piangere",
    "piangano": "piangere",
    "piange": "piangere",
    "piangemmo": "piangere",
    "piangendo": "piangere",
    "piangente": "piangere",
    "piangenti": "piangere",
    "pianger": "piangere",
    "piangerai": "piangere",
    "piangeran": "piangere",
    "piangeranno": "piangere",
    "piangerebbe": "piangere",
    "piangerebber": "piangere",
    "piangerebbero": "piangere",
    "piangerei": "piangere",
    "piangeremmo": "piangere",
    "piangeremo": "piangere",
    "piangereste": "piangere",
    "piangeresti": "piangere",
    "piangerete": "piangere",
    "piangerà": "piangere",
    "piangerò": "piangere",
    "piangesse": "piangere",
    "piangesser": "piangere",
    "piangessero": "piangere",
    "piangessi": "piangere",
    "piangessimo": "piangere",
    "piangeste": "piangere",
    "piangesti": "piangere",
    "piangete": "piangere",
    "piangeva": "piangere",
    "piangevamo": "piangere",
    "piangevan": "piangere",
    "piangevano": "piangere",
    "piangevate": "piangere",
    "piangevi": "piangere",
    "piangevo": "piangere",
    "piangi": "piangere",
    "piangiamo": "piangere",
    "piangiate": "piangere",
    "piango": "piangere",
    "piangon": "piangere",
    "piangono": "piangere",
    "piani": "piano",
    "pianifica": "pianificare",
    "pianificai": "pianificare",
    "pianificammo": "pianificare",
    "pianifican": "pianificare",
    "pianificando": "pianificare",
    "pianificano": "pianificare",
    "pianificante": "pianificare",
    "pianificanti": "pianificare",
    "pianificar": "pianificare",
    "pianificaron": "pianificare",
    "pianificarono": "pianificare",
    "pianificasse": "pianificare",
    "pianificasser": "pianificare",
    "pianificassero": "pianificare",
    "pianificassi": "pianificare",
    "pianificassimo": "pianificare",
    "pianificaste": "pianificare",
    "pianificasti": "pianificare",
    "pianificata": "pianificare",
    "pianificate": "pianificare",
    "pianificati": "pianificare",
    "pianificato": "pianificare",
    "pianificatori": "pianificatore",
    "pianificava": "pianificare",
    "pianificavamo": "pianificare",
    "pianificavan": "pianificare",
    "pianificavano": "pianificare",
    "pianificavate": "pianificare",
    "pianificavi": "pianificare",
    "pianificavo": "pianificare",
    "pianificazioni": "pianificazione",
    "pianificherai": "pianificare",
    "pianificheran": "pianificare",
    "pianificheranno": "pianificare",
    "pianificherebbe": "pianificare",
    "pianificherebber": "pianificare",
    "pianificherebbero": "pianificare",
    "pianificherei": "pianificare",
    "pianificheremmo": "pianificare",
    "pianificheremo": "pianificare",
    "pianifichereste": "pianificare",
    "pianificheresti": "pianificare",
    "pianificherete": "pianificare",
    "pianificherà": "pianificare",
    "pianificherò": "pianificare",
    "pianifichi": "pianificare",
    "pianifichiamo": "pianificare",
    "pianifichiate": "pianificare",
    "pianifichin": "pianificare",
    "pianifichino": "pianificare",
    "pianifico": "pianificare",
    "pianificò": "pianificare",
    "pianismi": "pianismo",
    "pianiste": "pianista",
    "pianisti": "pianista",
    "pianistica": "pianistico",
    "pianistiche": "pianistico",
    "pianistici": "pianistico",
    "piano": "piare",
    "pianoforti": "pianoforte",
    "pianole": "pianola",
    "pianori": "pianoro",
    "pianser": "piangere",
    "piansero": "piangere",
    "piansi": "piangere",
    "piansè": "piangere",
    "pianta": "pianto",
    "piantagioni": "piantagione",
    "piantai": "piantare",
    "piantammo": "piantare",
    "piantan": "piantare",
    "piantando": "piantare",
    "piantano": "piantare",
    "piantante": "piantare",
    "piantanti": "piantare",
    "piantar": "piantare",
    "piantaron": "piantare",
    "piantarono": "piantare",
    "piantasse": "piantare",
    "piantasser": "piantare",
    "piantassero": "piantare",
    "piantassi": "piantare",
    "piantassimo": "piantare",
    "piantaste": "piantare",
    "piantasti": "piantare",
    "piantata": "piantato",
    "piantate": "piantato",
    "piantati": "piantato",
    "piantato": "piantare",
    "piantatori": "piantatore",
    "piantava": "piantare",
    "piantavamo": "piantare",
    "piantavan": "piantare",
    "piantavano": "piantare",
    "piantavate": "piantare",
    "piantavi": "piantare",
    "piantavo": "piantare",
    "piante": "piare",
    "pianterai": "piantare",
    "pianteran": "piantare",
    "pianteranno": "piantare",
    "pianterebbe": "piantare",
    "pianterebber": "piantare",
    "pianterebbero": "piantare",
    "pianterei": "piantare",
    "pianteremmo": "piantare",
    "pianteremo": "piantare",
    "piantereste": "piantare",
    "pianteresti": "piantare",
    "pianterete": "piantare",
    "pianterreni": "pianterreno",
    "pianterà": "piantare",
    "pianterò": "piantare",
    "pianti": "piare",
    "piantiamo": "piantare",
    "piantiate": "piantare",
    "pianticelle": "pianticella",
    "piantin": "piantare",
    "piantine": "piantina",
    "piantino": "piantare",
    "pianto": "piantare",
    "piantona": "piantonare",
    "piantonai": "piantonare",
    "piantonamenti": "piantonamento",
    "piantonammo": "piantonare",
    "piantonan": "piantonare",
    "piantonando": "piantonare",
    "piantonano": "piantonare",
    "piantonante": "piantonare",
    "piantonanti": "piantonare",
    "piantonar": "piantonare",
    "piantonaron": "piantonare",
    "piantonarono": "piantonare",
    "piantonasse": "piantonare",
    "piantonasser": "piantonare",
    "piantonassero": "piantonare",
    "piantonassi": "piantonare",
    "piantonassimo": "piantonare",
    "piantonaste": "piantonare",
    "piantonasti": "piantonare",
    "piantonata": "piantonare",
    "piantonate": "piantonare",
    "piantonati": "piantonare",
    "piantonato": "piantonare",
    "piantonava": "piantonare",
    "piantonavamo": "piantonare",
    "piantonavan": "piantonare",
    "piantonavano": "piantonare",
    "piantonavate": "piantonare",
    "piantonavi": "piantonare",
    "piantonavo": "piantonare",
    "piantonerai": "piantonare",
    "piantoneran": "piantonare",
    "piantoneranno": "piantonare",
    "piantonerebbe": "piantonare",
    "piantonerebber": "piantonare",
    "piantonerebbero": "piantonare",
    "piantonerei": "piantonare",
    "piantoneremmo": "piantonare",
    "piantoneremo": "piantonare",
    "piantonereste": "piantonare",
    "piantoneresti": "piantonare",
    "piantonerete": "piantonare",
    "piantonerà": "piantonare",
    "piantonerò": "piantonare",
    "piantoni": "piantone",
    "piantoniamo": "piantonare",
    "piantoniate": "piantonare",
    "piantonin": "piantonare",
    "piantonino": "piantonare",
    "piantono": "piantonare",
    "piantonò": "piantonare",
    "piantò": "piantare",
    "pianure": "pianura",
    "piar": "piare",
    "piaron": "piare",
    "piarono": "piare",
    "piasse": "piare",
    "piasser": "piare",
    "piassero": "piare",
    "piassi": "piare",
    "piassimo": "piare",
    "piaste": "piare",
    "piasti": "piare",
    "piastre": "piastra",
    "piastrella": "piastrellare",
    "piastrellai": "piastrellare",
    "piastrellammo": "piastrellare",
    "piastrellan": "piastrellare",
    "piastrellando": "piastrellare",
    "piastrellano": "piastrellare",
    "piastrellante": "piastrellare",
    "piastrellanti": "piastrellare",
    "piastrellar": "piastrellare",
    "piastrellaron": "piastrellare",
    "piastrellarono": "piastrellare",
    "piastrellasse": "piastrellare",
    "piastrellasser": "piastrellare",
    "piastrellassero": "piastrellare",
    "piastrellassi": "piastrellare",
    "piastrellassimo": "piastrellare",
    "piastrellaste": "piastrellare",
    "piastrellasti": "piastrellare",
    "piastrellata": "piastrellare",
    "piastrellate": "piastrellare",
    "piastrellati": "piastrellare",
    "piastrellato": "piastrellare",
    "piastrellava": "piastrellare",
    "piastrellavamo": "piastrellare",
    "piastrellavan": "piastrellare",
    "piastrellavano": "piastrellare",
    "piastrellavate": "piastrellare",
    "piastrellavi": "piastrellare",
    "piastrellavo": "piastrellare",
    "piastrelle": "piastrella",
    "piastrellerai": "piastrellare",
    "piastrelleran": "piastrellare",
    "piastrelleranno": "piastrellare",
    "piastrellerebbe": "piastrellare",
    "piastrellerebber": "piastrellare",
    "piastrellerebbero": "piastrellare",
    "piastrellerei": "piastrellare",
    "piastrelleremmo": "piastrellare",
    "piastrelleremo": "piastrellare",
    "piastrellereste": "piastrellare",
    "piastrelleresti": "piastrellare",
    "piastrellerete": "piastrellare",
    "piastrellerà": "piastrellare",
    "piastrellerò": "piastrellare",
    "piastrelli": "piastrellare",
    "piastrelliamo": "piastrellare",
    "piastrelliate": "piastrellare",
    "piastrellin": "piastrellare",
    "piastrellino": "piastrellare",
    "piastrello": "piastrellare",
    "piastrellò": "piastrellare",
    "piastrine": "piastrina",
    "piata": "piare",
    "piate": "piare",
    "piati": "piare",
    "piato": "piare",
    "piatta": "piatto",
    "piattaforme": "piattaforma",
    "piatte": "piatto",
    "piattelli": "piattello",
    "piattezze": "piattezza",
    "piatti": "piatto",
    "piattini": "piattino",
    "piattona": "piattonare",
    "piattonai": "piattonare",
    "piattonammo": "piattonare",
    "piattonan": "piattonare",
    "piattonando": "piattonare",
    "piattonano": "piattonare",
    "piattonante": "piattonare",
    "piattonanti": "piattonare",
    "piattonar": "piattonare",
    "piattonaron": "piattonare",
    "piattonarono": "piattonare",
    "piattonasse": "piattonare",
    "piattonasser": "piattonare",
    "piattonassero": "piattonare",
    "piattonassi": "piattonare",
    "piattonassimo": "piattonare",
    "piattonaste": "piattonare",
    "piattonasti": "piattonare",
    "piattonata": "piattonare",
    "piattonate": "piattonare",
    "piattonati": "piattonare",
    "piattonato": "piattonare",
    "piattonava": "piattonare",
    "piattonavamo": "piattonare",
    "piattonavan": "piattonare",
    "piattonavano": "piattonare",
    "piattonavate": "piattonare",
    "piattonavi": "piattonare",
    "piattonavo": "piattonare",
    "piattonerai": "piattonare",
    "piattoneran": "piattonare",
    "piattoneranno": "piattonare",
    "piattonerebbe": "piattonare",
    "piattonerebber": "piattonare",
    "piattonerebbero": "piattonare",
    "piattonerei": "piattonare",
    "piattoneremmo": "piattonare",
    "piattoneremo": "piattonare",
    "piattonereste": "piattonare",
    "piattoneresti": "piattonare",
    "piattonerete": "piattonare",
    "piattonerà": "piattonare",
    "piattonerò": "piattonare",
    "piattoni": "piattonare",
    "piattoniamo": "piattonare",
    "piattoniate": "piattonare",
    "piattonin": "piattonare",
    "piattonino": "piattonare",
    "piattono": "piattonare",
    "piattonò": "piattonare",
    "piava": "piare",
    "piavamo": "piare",
    "piavan": "piare",
    "piavano": "piare",
    "piavate": "piare",
    "piavi": "piare",
    "piavo": "piare",
    "piazza": "piazzare",
    "piazzai": "piazzare",
    "piazzali": "piazzale",
    "piazzamenti": "piazzamento",
    "piazzammo": "piazzare",
    "piazzan": "piazzare",
    "piazzando": "piazzare",
    "piazzano": "piazzare",
    "piazzante": "piazzare",
    "piazzanti": "piazzare",
    "piazzar": "piazzare",
    "piazzaron": "piazzare",
    "piazzarono": "piazzare",
    "piazzasse": "piazzare",
    "piazzasser": "piazzare",
    "piazzassero": "piazzare",
    "piazzassi": "piazzare",
    "piazzassimo": "piazzare",
    "piazzaste": "piazzare",
    "piazzasti": "piazzare",
    "piazzata": "piazzato",
    "piazzate": "piazzato",
    "piazzati": "piazzato",
    "piazzato": "piazzare",
    "piazzava": "piazzare",
    "piazzavamo": "piazzare",
    "piazzavan": "piazzare",
    "piazzavano": "piazzare",
    "piazzavate": "piazzare",
    "piazzavi": "piazzare",
    "piazzavo": "piazzare",
    "piazze": "piazza",
    "piazzerai": "piazzare",
    "piazzeran": "piazzare",
    "piazzeranno": "piazzare",
    "piazzerebbe": "piazzare",
    "piazzerebber": "piazzare",
    "piazzerebbero": "piazzare",
    "piazzerei": "piazzare",
    "piazzeremmo": "piazzare",
    "piazzeremo": "piazzare",
    "piazzereste": "piazzare",
    "piazzeresti": "piazzare",
    "piazzerete": "piazzare",
    "piazzerà": "piazzare",
    "piazzerò": "piazzare",
    "piazzette": "piazzetta",
    "piazzi": "piazzare",
    "piazziamo": "piazzare",
    "piazziate": "piazzare",
    "piazzin": "piazzare",
    "piazzino": "piazzare",
    "piazzisti": "piazzista",
    "piazzo": "piazzare",
    "piazzole": "piazzola",
    "piazzuole": "piazzuola",
    "piazzò": "piazzare",
    "picaresca": "picaresco",
    "picaresche": "picaresco",
    "picareschi": "picaresco",
    "picari": "picaro",
    "picassiana": "picassiano",
    "picassiane": "picassiano",
    "picassiani": "picassiano",
    "picca": "piccare",
    "piccai": "piccare",
    "piccammo": "piccare",
    "piccan": "piccare",
    "piccando": "piccare",
    "piccano": "piccare",
    "piccanti": "piccante",
    "piccar": "piccare",
    "piccaron": "piccare",
    "piccarono": "piccare",
    "piccasse": "piccare",
    "piccasser": "piccare",
    "piccassero": "piccare",
    "piccassi": "piccare",
    "piccassimo": "piccare",
    "piccaste": "piccare",
    "piccasti": "piccare",
    "piccata": "piccare",
    "piccate": "piccare",
    "piccati": "piccare",
    "piccato": "piccare",
    "piccava": "piccare",
    "piccavamo": "piccare",
    "piccavan": "piccare",
    "piccavano": "piccare",
    "piccavate": "piccare",
    "piccavi": "piccare",
    "piccavo": "piccare",
    "picche": "picca",
    "piccherai": "piccare",
    "piccheran": "piccare",
    "piccheranno": "piccare",
    "piccherebbe": "piccare",
    "piccherebber": "piccare",
    "piccherebbero": "piccare",
    "piccherei": "piccare",
    "piccheremmo": "piccare",
    "piccheremo": "piccare",
    "picchereste": "piccare",
    "piccheresti": "piccare",
    "piccherete": "piccare",
    "piccherà": "piccare",
    "piccherò": "piccare",
    "picchetta": "picchettare",
    "picchettaggi": "picchettaggio",
    "picchettai": "picchettare",
    "picchettammo": "picchettare",
    "picchettan": "picchettare",
    "picchettando": "picchettare",
    "picchettano": "picchettare",
    "picchettante": "picchettare",
    "picchettanti": "picchettare",
    "picchettar": "picchettare",
    "picchettaron": "picchettare",
    "picchettarono": "picchettare",
    "picchettasse": "picchettare",
    "picchettasser": "picchettare",
    "picchettassero": "picchettare",
    "picchettassi": "picchettare",
    "picchettassimo": "picchettare",
    "picchettaste": "picchettare",
    "picchettasti": "picchettare",
    "picchettata": "picchettare",
    "picchettate": "picchettare",
    "picchettati": "picchettare",
    "picchettato": "picchettare",
    "picchettava": "picchettare",
    "picchettavamo": "picchettare",
    "picchettavan": "picchettare",
    "picchettavano": "picchettare",
    "picchettavate": "picchettare",
    "picchettavi": "picchettare",
    "picchettavo": "picchettare",
    "picchetterai": "picchettare",
    "picchetteran": "picchettare",
    "picchetteranno": "picchettare",
    "picchetterebbe": "picchettare",
    "picchetterebber": "picchettare",
    "picchetterebbero": "picchettare",
    "picchetterei": "picchettare",
    "picchetteremmo": "picchettare",
    "picchetteremo": "picchettare",
    "picchettereste": "picchettare",
    "picchetteresti": "picchettare",
    "picchetterete": "picchettare",
    "picchetterà": "picchettare",
    "picchetterò": "picchettare",
    "picchetti": "picchetto",
    "picchettiamo": "picchettare",
    "picchettiate": "picchettare",
    "picchettin": "picchettare",
    "picchettino": "picchettare",
    "picchetto": "picchettare",
    "picchettò": "picchettare",
    "picchi": "picco",
    "picchia": "picchiare",
    "picchiai": "picchiare",
    "picchiammo": "picchiare",
    "picchiamo": "picchiare",
    "picchian": "picchiare",
    "picchiando": "picchiare",
    "picchiano": "picchiare",
    "picchiante": "picchiare",
    "picchianti": "picchiare",
    "picchiar": "picchiare",
    "picchiaron": "picchiare",
    "picchiarono": "picchiare",
    "picchiasse": "picchiare",
    "picchiasser": "picchiare",
    "picchiassero": "picchiare",
    "picchiassi": "picchiare",
    "picchiassimo": "picchiare",
    "picchiaste": "picchiare",
    "picchiasti": "picchiare",
    "picchiata": "picchiare",
    "picchiate": "picchiata",
    "picchiatella": "picchiatello",
    "picchiatelle": "picchiatello",
    "picchiatelli": "picchiatello",
    "picchiati": "picchiare",
    "picchiato": "picchiare",
    "picchiatori": "picchiatore",
    "picchiava": "picchiare",
    "picchiavamo": "picchiare",
    "picchiavan": "picchiare",
    "picchiavano": "picchiare",
    "picchiavate": "picchiare",
    "picchiavi": "picchiare",
    "picchiavo": "picchiare",
    "picchierai": "picchiare",
    "picchieran": "picchiare",
    "picchieranno": "picchiare",
    "picchierebbe": "picchiare",
    "picchierebber": "picchiare",
    "picchierebbero": "picchiare",
    "picchierei": "picchiare",
    "picchieremmo": "picchiare",
    "picchieremo": "picchiare",
    "picchiereste": "picchiare",
    "picchieresti": "picchiare",
    "picchierete": "picchiare",
    "picchierà": "picchiare",
    "picchierò": "picchiare",
    "picchietta": "picchiettare",
    "picchiettai": "picchiettare",
    "picchiettammo": "picchiettare",
    "picchiettan": "picchiettare",
    "picchiettando": "picchiettare",
    "picchiettano": "picchiettare",
    "picchiettante": "picchiettare",
    "picchiettanti": "picchiettare",
    "picchiettar": "picchiettare",
    "picchiettaron": "picchiettare",
    "picchiettarono": "picchiettare",
    "picchiettasse": "picchiettare",
    "picchiettasser": "picchiettare",
    "picchiettassero": "picchiettare",
    "picchiettassi": "picchiettare",
    "picchiettassimo": "picchiettare",
    "picchiettaste": "picchiettare",
    "picchiettasti": "picchiettare",
    "picchiettata": "picchiettare",
    "picchiettate": "picchiettare",
    "picchiettati": "picchiettare",
    "picchiettato": "picchiettare",
    "picchiettava": "picchiettare",
    "picchiettavamo": "picchiettare",
    "picchiettavan": "picchiettare",
    "picchiettavano": "picchiettare",
    "picchiettavate": "picchiettare",
    "picchiettavi": "picchiettare",
    "picchiettavo": "picchiettare",
    "picchietterai": "picchiettare",
    "picchietteran": "picchiettare",
    "picchietteranno": "picchiettare",
    "picchietterebbe": "picchiettare",
    "picchietterebber": "picchiettare",
    "picchietterebbero": "picchiettare",
    "picchietterei": "picchiettare",
    "picchietteremmo": "picchiettare",
    "picchietteremo": "picchiettare",
    "picchiettereste": "picchiettare",
    "picchietteresti": "picchiettare",
    "picchietterete": "picchiettare",
    "picchietterà": "picchiettare",
    "picchietterò": "picchiettare",
    "picchietti": "picchiettare",
    "picchiettiamo": "picchiettare",
    "picchiettiate": "picchiettare",
    "picchiettin": "picchiettare",
    "picchiettino": "picchiettare",
    "picchietto": "picchiettare",
    "picchiettò": "picchiettare",
    "picchin": "picchiare",
    "picchino": "picchiare",
    "picchio": "picchiare",
    "picchiò": "picchiare",
    "piccina": "piccino",
    "piccine": "piccino",
    "piccinerie": "piccineria",
    "piccini": "piccino",
    "piccioli": "picciolo",
    "piccioni": "piccione",
    "picciotti": "picciotto",
    "picco": "piccare",
    "piccola": "piccolo",
    "piccole": "piccolo",
    "piccoletti": "piccoletto",
    "piccolezze": "piccolezza",
    "piccoli": "piccolo",
    "piccoline": "piccolina",
    "piccolini": "piccolino",
    "piccolo-borghesi": "piccolo-borghese",
    "picconate": "picconata",
    "picconatori": "picconatore",
    "picconi": "piccone",
    "piccò": "piccare",
    "pidiessina": "pidiessino",
    "pidiessine": "pidiessino",
    "pidiessini": "pidiessino",
    "pidocchi": "pidocchio",
    "pidocchiosa": "pidocchioso",
    "pidocchiose": "pidocchioso",
    "pidocchiosi": "pidocchioso",
    "piduiste": "piduista",
    "piduisti": "piduista",
    "pie": "pio",
    "pieces": "piece",
    "piedestalli": "piedestallo",
    "piedi": "piede",
    "piedini": "piedino",
    "piedissini": "piedissino",
    "piedistalli": "piedistallo",
    "piedoni": "piedone",
    "piega": "piegare",
    "piegai": "piegare",
    "piegamenti": "piegamento",
    "piegammo": "piegare",
    "piegan": "piegare",
    "piegando": "piegare",
    "piegano": "piegare",
    "piegante": "piegare",
    "pieganti": "piegare",
    "piegar": "piegare",
    "piegaron": "piegare",
    "piegarono": "piegare",
    "piegasse": "piegare",
    "piegasser": "piegare",
    "piegassero": "piegare",
    "piegassi": "piegare",
    "piegassimo": "piegare",
    "piegaste": "piegare",
    "piegasti": "piegare",
    "piegata": "piegare",
    "piegate": "piegare",
    "piegati": "piegare",
    "piegato": "piegare",
    "piegava": "piegare",
    "piegavamo": "piegare",
    "piegavan": "piegare",
    "piegavano": "piegare",
    "piegavate": "piegare",
    "piegavi": "piegare",
    "piegavo": "piegare",
    "pieghe": "piega",
    "piegherai": "piegare",
    "piegheran": "piegare",
    "piegheranno": "piegare",
    "piegherebbe": "piegare",
    "piegherebber": "piegare",
    "piegherebbero": "piegare",
    "piegherei": "piegare",
    "piegheremmo": "piegare",
    "piegheremo": "piegare",
    "pieghereste": "piegare",
    "piegheresti": "piegare",
    "piegherete": "piegare",
    "piegherà": "piegare",
    "piegherò": "piegare",
    "pieghetta": "pieghettare",
    "pieghettai": "pieghettare",
    "pieghettammo": "pieghettare",
    "pieghettan": "pieghettare",
    "pieghettando": "pieghettare",
    "pieghettano": "pieghettare",
    "pieghettante": "pieghettare",
    "pieghettanti": "pieghettare",
    "pieghettar": "pieghettare",
    "pieghettaron": "pieghettare",
    "pieghettarono": "pieghettare",
    "pieghettasse": "pieghettare",
    "pieghettasser": "pieghettare",
    "pieghettassero": "pieghettare",
    "pieghettassi": "pieghettare",
    "pieghettassimo": "pieghettare",
    "pieghettaste": "pieghettare",
    "pieghettasti": "pieghettare",
    "pieghettata": "pieghettare",
    "pieghettate": "pieghettare",
    "pieghettati": "pieghettare",
    "pieghettato": "pieghettare",
    "pieghettava": "pieghettare",
    "pieghettavamo": "pieghettare",
    "pieghettavan": "pieghettare",
    "pieghettavano": "pieghettare",
    "pieghettavate": "pieghettare",
    "pieghettavi": "pieghettare",
    "pieghettavo": "pieghettare",
    "pieghetterai": "pieghettare",
    "pieghetteran": "pieghettare",
    "pieghetteranno": "pieghettare",
    "pieghetterebbe": "pieghettare",
    "pieghetterebber": "pieghettare",
    "pieghetterebbero": "pieghettare",
    "pieghetterei": "pieghettare",
    "pieghetteremmo": "pieghettare",
    "pieghetteremo": "pieghettare",
    "pieghettereste": "pieghettare",
    "pieghetteresti": "pieghettare",
    "pieghetterete": "pieghettare",
    "pieghetterà": "pieghettare",
    "pieghetterò": "pieghettare",
    "pieghetti": "pieghettare",
    "pieghettiamo": "pieghettare",
    "pieghettiate": "pieghettare",
    "pieghettin": "pieghettare",
    "pieghettino": "pieghettare",
    "pieghetto": "pieghettare",
    "pieghettò": "pieghettare",
    "pieghevoli": "pieghevole",
    "pieghi": "piegare",
    "pieghiamo": "piegare",
    "pieghiate": "piegare",
    "pieghin": "piegare",
    "pieghino": "piegare",
    "piego": "piegare",
    "piegò": "piegare",
    "piemontesi": "piemontese",
    "piena": "pieno",
    "piene": "pieno",
    "pienezze": "pienezza",
    "pieni": "pieno",
    "pienoni": "pienone",
    "pierai": "piare",
    "pieran": "piare",
    "pieranno": "piare",
    "pierebbe": "piare",
    "pierebber": "piare",
    "pierebbero": "piare",
    "pierei": "piare",
    "pieremmo": "piare",
    "pieremo": "piare",
    "piereste": "piare",
    "pieresti": "piare",
    "pierete": "piare",
    "pierini": "pierino",
    "pierà": "piare",
    "pierò": "piare",
    "pietanze": "pietanza",
    "pietates": "pietas",
    "pietismi": "pietismo",
    "pietosa": "pietoso",
    "pietose": "pietoso",
    "pietosi": "pietoso",
    "pietraie": "pietraia",
    "pietre": "pietra",
    "pietrifica": "pietrificare",
    "pietrificai": "pietrificare",
    "pietrificammo": "pietrificare",
    "pietrifican": "pietrificare",
    "pietrificando": "pietrificare",
    "pietrificano": "pietrificare",
    "pietrificante": "pietrificare",
    "pietrificanti": "pietrificare",
    "pietrificar": "pietrificare",
    "pietrificaron": "pietrificare",
    "pietrificarono": "pietrificare",
    "pietrificasse": "pietrificare",
    "pietrificasser": "pietrificare",
    "pietrificassero": "pietrificare",
    "pietrificassi": "pietrificare",
    "pietrificassimo": "pietrificare",
    "pietrificaste": "pietrificare",
    "pietrificasti": "pietrificare",
    "pietrificata": "pietrificare",
    "pietrificate": "pietrificare",
    "pietrificati": "pietrificare",
    "pietrificato": "pietrificare",
    "pietrificava": "pietrificare",
    "pietrificavamo": "pietrificare",
    "pietrificavan": "pietrificare",
    "pietrificavano": "pietrificare",
    "pietrificavate": "pietrificare",
    "pietrificavi": "pietrificare",
    "pietrificavo": "pietrificare",
    "pietrificherai": "pietrificare",
    "pietrificheran": "pietrificare",
    "pietrificheranno": "pietrificare",
    "pietrificherebbe": "pietrificare",
    "pietrificherebber": "pietrificare",
    "pietrificherebbero": "pietrificare",
    "pietrificherei": "pietrificare",
    "pietrificheremmo": "pietrificare",
    "pietrificheremo": "pietrificare",
    "pietrifichereste": "pietrificare",
    "pietrificheresti": "pietrificare",
    "pietrificherete": "pietrificare",
    "pietrificherà": "pietrificare",
    "pietrificherò": "pietrificare",
    "pietrifichi": "pietrificare",
    "pietrifichiamo": "pietrificare",
    "pietrifichiate": "pietrificare",
    "pietrifichin": "pietrificare",
    "pietrifichino": "pietrificare",
    "pietrifico": "pietrificare",
    "pietrificò": "pietrificare",
    "pietroni": "pietrone",
    "pietrosa": "pietroso",
    "pietrose": "pietroso",
    "pietrosi": "pietroso",
    "pietruzze": "pietruzza",
    "pievi": "pieve",
    "pifferai": "pifferaio",
    "pifferi": "piffero",
    "pigerai": "pigiare",
    "pigeran": "pigiare",
    "pigeranno": "pigiare",
    "pigerebbe": "pigiare",
    "pigerebber": "pigiare",
    "pigerebbero": "pigiare",
    "pigerei": "pigiare",
    "pigeremmo": "pigiare",
    "pigeremo": "pigiare",
    "pigereste": "pigiare",
    "pigeresti": "pigiare",
    "pigerete": "pigiare",
    "pigerà": "pigiare",
    "pigerò": "pigiare",
    "pigi": "pigiare",
    "pigia": "pigiare",
    "pigiai": "pigiare",
    "pigiami": "pigiama",
    "pigiamini": "pigiamino",
    "pigiammo": "pigiare",
    "pigiamo": "pigiare",
    "pigian": "pigiare",
    "pigiando": "pigiare",
    "pigiano": "pigiare",
    "pigiante": "pigiare",
    "pigianti": "pigiare",
    "pigiar": "pigiare",
    "pigiaron": "pigiare",
    "pigiarono": "pigiare",
    "pigiasse": "pigiare",
    "pigiasser": "pigiare",
    "pigiassero": "pigiare",
    "pigiassi": "pigiare",
    "pigiassimo": "pigiare",
    "pigiaste": "pigiare",
    "pigiasti": "pigiare",
    "pigiata": "pigiare",
    "pigiate": "pigiare",
    "pigiati": "pigiare",
    "pigiato": "pigiare",
    "pigiava": "pigiare",
    "pigiavamo": "pigiare",
    "pigiavan": "pigiare",
    "pigiavano": "pigiare",
    "pigiavate": "pigiare",
    "pigiavi": "pigiare",
    "pigiavo": "pigiare",
    "pigin": "pigiare",
    "pigino": "pigiare",
    "pigio": "pigiare",
    "pigioni": "pigione",
    "pigiò": "pigiare",
    "pigli": "piglio",
    "piglia": "pigliare",
    "pigliai": "pigliare",
    "pigliammo": "pigliare",
    "pigliamo": "pigliare",
    "piglian": "pigliare",
    "pigliando": "pigliare",
    "pigliano": "pigliare",
    "pigliante": "pigliare",
    "piglianti": "pigliare",
    "pigliar": "pigliare",
    "pigliaron": "pigliare",
    "pigliarono": "pigliare",
    "pigliasse": "pigliare",
    "pigliasser": "pigliare",
    "pigliassero": "pigliare",
    "pigliassi": "pigliare",
    "pigliassimo": "pigliare",
    "pigliaste": "pigliare",
    "pigliasti": "pigliare",
    "pigliata": "pigliare",
    "pigliate": "pigliare",
    "pigliati": "pigliare",
    "pigliato": "pigliare",
    "pigliatutta": "pigliatutto",
    "pigliatutte": "pigliatutto",
    "pigliatutti": "pigliatutto",
    "pigliava": "pigliare",
    "pigliavamo": "pigliare",
    "pigliavan": "pigliare",
    "pigliavano": "pigliare",
    "pigliavate": "pigliare",
    "pigliavi": "pigliare",
    "pigliavo": "pigliare",
    "piglierai": "pigliare",
    "piglieran": "pigliare",
    "piglieranno": "pigliare",
    "piglierebbe": "pigliare",
    "piglierebber": "pigliare",
    "piglierebbero": "pigliare",
    "piglierei": "pigliare",
    "piglieremmo": "pigliare",
    "piglieremo": "pigliare",
    "pigliereste": "pigliare",
    "piglieresti": "pigliare",
    "piglierete": "pigliare",
    "piglierà": "pigliare",
    "piglierò": "pigliare",
    "piglin": "pigliare",
    "piglino": "pigliare",
    "piglio": "pigliare",
    "pigliò": "pigliare",
    "pigmalioni": "pigmalione",
    "pigmea": "pigmeo",
    "pigmee": "pigmeo",
    "pigmei": "pigmeo",
    "pigmenta": "pigmentare",
    "pigmentai": "pigmentare",
    "pigmentammo": "pigmentare",
    "pigmentan": "pigmentare",
    "pigmentando": "pigmentare",
    "pigmentano": "pigmentare",
    "pigmentante": "pigmentare",
    "pigmentanti": "pigmentare",
    "pigmentar": "pigmentare",
    "pigmentaron": "pigmentare",
    "pigmentarono": "pigmentare",
    "pigmentasse": "pigmentare",
    "pigmentasser": "pigmentare",
    "pigmentassero": "pigmentare",
    "pigmentassi": "pigmentare",
    "pigmentassimo": "pigmentare",
    "pigmentaste": "pigmentare",
    "pigmentasti": "pigmentare",
    "pigmentata": "pigmentare",
    "pigmentate": "pigmentare",
    "pigmentati": "pigmentare",
    "pigmentato": "pigmentare",
    "pigmentava": "pigmentare",
    "pigmentavamo": "pigmentare",
    "pigmentavan": "pigmentare",
    "pigmentavano": "pigmentare",
    "pigmentavate": "pigmentare",
    "pigmentavi": "pigmentare",
    "pigmentavo": "pigmentare",
    "pigmenterai": "pigmentare",
    "pigmenteran": "pigmentare",
    "pigmenteranno": "pigmentare",
    "pigmenterebbe": "pigmentare",
    "pigmenterebber": "pigmentare",
    "pigmenterebbero": "pigmentare",
    "pigmenterei": "pigmentare",
    "pigmenteremmo": "pigmentare",
    "pigmenteremo": "pigmentare",
    "pigmentereste": "pigmentare",
    "pigmenteresti": "pigmentare",
    "pigmenterete": "pigmentare",
    "pigmenterà": "pigmentare",
    "pigmenterò": "pigmentare",
    "pigmenti": "pigmento",
    "pigmentiamo": "pigmentare",
    "pigmentiate": "pigmentare",
    "pigmentin": "pigmentare",
    "pigmentino": "pigmentare",
    "pigmento": "pigmentare",
    "pigmentosa": "pigmentoso",
    "pigmentose": "pigmentoso",
    "pigmentosi": "pigmentoso",
    "pigmentò": "pigmentare",
    "pignola": "pignolo",
    "pignole": "pignolo",
    "pignolerie": "pignoleria",
    "pignoli": "pignolo",
    "pignora": "pignorare",
    "pignorai": "pignorare",
    "pignoramenti": "pignoramento",
    "pignorammo": "pignorare",
    "pignoran": "pignorare",
    "pignorando": "pignorare",
    "pignorano": "pignorare",
    "pignorante": "pignorare",
    "pignoranti": "pignorare",
    "pignorar": "pignorare",
    "pignoraron": "pignorare",
    "pignorarono": "pignorare",
    "pignorasse": "pignorare",
    "pignorasser": "pignorare",
    "pignorassero": "pignorare",
    "pignorassi": "pignorare",
    "pignorassimo": "pignorare",
    "pignoraste": "pignorare",
    "pignorasti": "pignorare",
    "pignorata": "pignorare",
    "pignorate": "pignorare",
    "pignorati": "pignorare",
    "pignoratizi": "pignoratizio",
    "pignoratizia": "pignoratizio",
    "pignoratizie": "pignoratizio",
    "pignorato": "pignorare",
    "pignorava": "pignorare",
    "pignoravamo": "pignorare",
    "pignoravan": "pignorare",
    "pignoravano": "pignorare",
    "pignoravate": "pignorare",
    "pignoravi": "pignorare",
    "pignoravo": "pignorare",
    "pignorerai": "pignorare",
    "pignoreran": "pignorare",
    "pignoreranno": "pignorare",
    "pignorerebbe": "pignorare",
    "pignorerebber": "pignorare",
    "pignorerebbero": "pignorare",
    "pignorerei": "pignorare",
    "pignoreremmo": "pignorare",
    "pignoreremo": "pignorare",
    "pignorereste": "pignorare",
    "pignoreresti": "pignorare",
    "pignorerete": "pignorare",
    "pignorerà": "pignorare",
    "pignorerò": "pignorare",
    "pignori": "pignorare",
    "pignoriamo": "pignorare",
    "pignoriate": "pignorare",
    "pignorin": "pignorare",
    "pignorino": "pignorare",
    "pignoro": "pignorare",
    "pignorò": "pignorare",
    "pigola": "pigolare",
    "pigolai": "pigolare",
    "pigolammo": "pigolare",
    "pigolan": "pigolare",
    "pigolando": "pigolare",
    "pigolano": "pigolare",
    "pigolante": "pigolare",
    "pigolanti": "pigolare",
    "pigolar": "pigolare",
    "pigolaron": "pigolare",
    "pigolarono": "pigolare",
    "pigolasse": "pigolare",
    "pigolasser": "pigolare",
    "pigolassero": "pigolare",
    "pigolassi": "pigolare",
    "pigolassimo": "pigolare",
    "pigolaste": "pigolare",
    "pigolasti": "pigolare",
    "pigolata": "pigolare",
    "pigolate": "pigolare",
    "pigolati": "pigolare",
    "pigolato": "pigolare",
    "pigolava": "pigolare",
    "pigolavamo": "pigolare",
    "pigolavan": "pigolare",
    "pigolavano": "pigolare",
    "pigolavate": "pigolare",
    "pigolavi": "pigolare",
    "pigolavo": "pigolare",
    "pigolerai": "pigolare",
    "pigoleran": "pigolare",
    "pigoleranno": "pigolare",
    "pigolerebbe": "pigolare",
    "pigolerebber": "pigolare",
    "pigolerebbero": "pigolare",
    "pigolerei": "pigolare",
    "pigoleremmo": "pigolare",
    "pigoleremo": "pigolare",
    "pigolereste": "pigolare",
    "pigoleresti": "pigolare",
    "pigolerete": "pigolare",
    "pigolerà": "pigolare",
    "pigolerò": "pigolare",
    "pigoli": "pigolare",
    "pigoliamo": "pigolare",
    "pigoliate": "pigolare",
    "pigolii": "pigolio",
    "pigolin": "pigolare",
    "pigolino": "pigolare",
    "pigolo": "pigolare",
    "pigolò": "pigolare",
    "pigra": "pigro",
    "pigre": "pigro",
    "pigri": "pigro",
    "pigrizie": "pigrizia",
    "pii": "pio",
    "pilastri": "pilastro",
    "pile": "pila",
    "pilifera": "pilifero",
    "pilifere": "pilifero",
    "piliferi": "pilifero",
    "pilla": "pillare",
    "pillai": "pillare",
    "pillammo": "pillare",
    "pillan": "pillare",
    "pillando": "pillare",
    "pillano": "pillare",
    "pillante": "pillare",
    "pillanti": "pillare",
    "pillar": "pillare",
    "pillaron": "pillare",
    "pillarono": "pillare",
    "pillasse": "pillare",
    "pillasser": "pillare",
    "pillassero": "pillare",
    "pillassi": "pillare",
    "pillassimo": "pillare",
    "pillaste": "pillare",
    "pillasti": "pillare",
    "pillata": "pillare",
    "pillate": "pillare",
    "pillati": "pillare",
    "pillato": "pillare",
    "pillava": "pillare",
    "pillavamo": "pillare",
    "pillavan": "pillare",
    "pillavano": "pillare",
    "pillavate": "pillare",
    "pillavi": "pillare",
    "pillavo": "pillare",
    "pillerai": "pillare",
    "pilleran": "pillare",
    "pilleranno": "pillare",
    "pillerebbe": "pillare",
    "pillerebber": "pillare",
    "pillerebbero": "pillare",
    "pillerei": "pillare",
    "pilleremmo": "pillare",
    "pilleremo": "pillare",
    "pillereste": "pillare",
    "pilleresti": "pillare",
    "pillerete": "pillare",
    "pillerà": "pillare",
    "pillerò": "pillare",
    "pilli": "pillare",
    "pilliamo": "pillare",
    "pilliate": "pillare",
    "pillin": "pillare",
    "pillino": "pillare",
    "pillo": "pillare",
    "pillole": "pillola",
    "pilloline": "pillolina",
    "pillò": "pillare",
    "piloni": "pilone",
    "pilota": "pilotare",
    "pilotai": "pilotare",
    "pilotammo": "pilotare",
    "pilotan": "pilotare",
    "pilotando": "pilotare",
    "pilotano": "pilotare",
    "pilotante": "pilotare",
    "pilotanti": "pilotare",
    "pilotar": "pilotare",
    "pilotaron": "pilotare",
    "pilotarono": "pilotare",
    "pilotasse": "pilotare",
    "pilotasser": "pilotare",
    "pilotassero": "pilotare",
    "pilotassi": "pilotare",
    "pilotassimo": "pilotare",
    "pilotaste": "pilotare",
    "pilotasti": "pilotare",
    "pilotata": "pilotare",
    "pilotate": "pilotare",
    "pilotati": "pilotare",
    "pilotato": "pilotare",
    "pilotava": "pilotare",
    "pilotavamo": "pilotare",
    "pilotavan": "pilotare",
    "pilotavano": "pilotare",
    "pilotavate": "pilotare",
    "pilotavi": "pilotare",
    "pilotavo": "pilotare",
    "piloterai": "pilotare",
    "piloteran": "pilotare",
    "piloteranno": "pilotare",
    "piloterebbe": "pilotare",
    "piloterebber": "pilotare",
    "piloterebbero": "pilotare",
    "piloterei": "pilotare",
    "piloteremmo": "pilotare",
    "piloteremo": "pilotare",
    "pilotereste": "pilotare",
    "piloteresti": "pilotare",
    "piloterete": "pilotare",
    "piloterà": "pilotare",
    "piloterò": "pilotare",
    "piloti": "pilotare",
    "pilotiamo": "pilotare",
    "pilotiate": "pilotare",
    "pilotin": "pilotare",
    "pilotino": "pilotare",
    "piloto": "pilotare",
    "pilotò": "pilotare",
    "pilucca": "piluccare",
    "piluccai": "piluccare",
    "piluccammo": "piluccare",
    "piluccan": "piluccare",
    "piluccando": "piluccare",
    "piluccano": "piluccare",
    "piluccante": "piluccare",
    "piluccanti": "piluccare",
    "piluccar": "piluccare",
    "piluccaron": "piluccare",
    "piluccarono": "piluccare",
    "piluccasse": "piluccare",
    "piluccasser": "piluccare",
    "piluccassero": "piluccare",
    "piluccassi": "piluccare",
    "piluccassimo": "piluccare",
    "piluccaste": "piluccare",
    "piluccasti": "piluccare",
    "piluccata": "piluccare",
    "piluccate": "piluccare",
    "piluccati": "piluccare",
    "piluccato": "piluccare",
    "piluccava": "piluccare",
    "piluccavamo": "piluccare",
    "piluccavan": "piluccare",
    "piluccavano": "piluccare",
    "piluccavate": "piluccare",
    "piluccavi": "piluccare",
    "piluccavo": "piluccare",
    "piluccherai": "piluccare",
    "piluccheran": "piluccare",
    "piluccheranno": "piluccare",
    "piluccherebbe": "piluccare",
    "piluccherebber": "piluccare",
    "piluccherebbero": "piluccare",
    "piluccherei": "piluccare",
    "piluccheremmo": "piluccare",
    "piluccheremo": "piluccare",
    "pilucchereste": "piluccare",
    "piluccheresti": "piluccare",
    "piluccherete": "piluccare",
    "piluccherà": "piluccare",
    "piluccherò": "piluccare",
    "pilucchi": "piluccare",
    "pilucchiamo": "piluccare",
    "pilucchiate": "piluccare",
    "pilucchin": "piluccare",
    "pilucchino": "piluccare",
    "pilucco": "piluccare",
    "piluccò": "piluccare",
    "pimenta": "pimentare",
    "pimentai": "pimentare",
    "pimentammo": "pimentare",
    "pimentan": "pimentare",
    "pimentando": "pimentare",
    "pimentano": "pimentare",
    "pimentante": "pimentare",
    "pimentanti": "pimentare",
    "pimentar": "pimentare",
    "pimentaron": "pimentare",
    "pimentarono": "pimentare",
    "pimentasse": "pimentare",
    "pimentasser": "pimentare",
    "pimentassero": "pimentare",
    "pimentassi": "pimentare",
    "pimentassimo": "pimentare",
    "pimentaste": "pimentare",
    "pimentasti": "pimentare",
    "pimentata": "pimentare",
    "pimentate": "pimentare",
    "pimentati": "pimentare",
    "pimentato": "pimentare",
    "pimentava": "pimentare",
    "pimentavamo": "pimentare",
    "pimentavan": "pimentare",
    "pimentavano": "pimentare",
    "pimentavate": "pimentare",
    "pimentavi": "pimentare",
    "pimentavo": "pimentare",
    "pimenterai": "pimentare",
    "pimenteran": "pimentare",
    "pimenteranno": "pimentare",
    "pimenterebbe": "pimentare",
    "pimenterebber": "pimentare",
    "pimenterebbero": "pimentare",
    "pimenterei": "pimentare",
    "pimenteremmo": "pimentare",
    "pimenteremo": "pimentare",
    "pimentereste": "pimentare",
    "pimenteresti": "pimentare",
    "pimenterete": "pimentare",
    "pimenterà": "pimentare",
    "pimenterò": "pimentare",
    "pimenti": "pimentare",
    "pimentiamo": "pimentare",
    "pimentiate": "pimentare",
    "pimentin": "pimentare",
    "pimentino": "pimentare",
    "pimento": "pimentare",
    "pimentò": "pimentare",
    "pimpanti": "pimpante",
    "pin": "piare",
    "pinacoteche": "pinacoteca",
    "pinete": "pineta",
    "pinga": "pingere",
    "pingan": "pingere",
    "pingano": "pingere",
    "pinge": "pingere",
    "pingemmo": "pingere",
    "pingendo": "pingere",
    "pingente": "pingere",
    "pingenti": "pingere",
    "pinger": "pingere",
    "pingerai": "pingere",
    "pingeran": "pingere",
    "pingeranno": "pingere",
    "pingerebbe": "pingere",
    "pingerebber": "pingere",
    "pingerebbero": "pingere",
    "pingerei": "pingere",
    "pingeremmo": "pingere",
    "pingeremo": "pingere",
    "pingereste": "pingere",
    "pingeresti": "pingere",
    "pingerete": "pingere",
    "pingerà": "pingere",
    "pingerò": "pingere",
    "pingesse": "pingere",
    "pingesser": "pingere",
    "pingessero": "pingere",
    "pingessi": "pingere",
    "pingessimo": "pingere",
    "pingeste": "pingere",
    "pingesti": "pingere",
    "pingete": "pingere",
    "pingeva": "pingere",
    "pingevamo": "pingere",
    "pingevan": "pingere",
    "pingevano": "pingere",
    "pingevate": "pingere",
    "pingevi": "pingere",
    "pingevo": "pingere",
    "pingi": "pingere",
    "pingiamo": "pingere",
    "pingiate": "pingere",
    "pingo": "pingere",
    "pingon": "pingere",
    "pingono": "pingere",
    "pinguedini": "pinguedine",
    "pingui": "pingue",
    "pinguini": "pinguino",
    "pini": "pino",
    "pinnacoli": "pinnacolo",
    "pinne": "pinna",
    "pino": "piare",
    "pinse": "pingere",
    "pinser": "pingere",
    "pinsero": "pingere",
    "pinsi": "pingere",
    "pinta": "pingere",
    "pinte": "pingere",
    "pinti": "pingere",
    "pinto": "pingere",
    "pinza": "pinzare",
    "pinzai": "pinzare",
    "pinzammo": "pinzare",
    "pinzan": "pinzare",
    "pinzando": "pinzare",
    "pinzano": "pinzare",
    "pinzante": "pinzare",
    "pinzanti": "pinzare",
    "pinzar": "pinzare",
    "pinzaron": "pinzare",
    "pinzarono": "pinzare",
    "pinzasse": "pinzare",
    "pinzasser": "pinzare",
    "pinzassero": "pinzare",
    "pinzassi": "pinzare",
    "pinzassimo": "pinzare",
    "pinzaste": "pinzare",
    "pinzasti": "pinzare",
    "pinzata": "pinzare",
    "pinzate": "pinzare",
    "pinzati": "pinzare",
    "pinzato": "pinzare",
    "pinzava": "pinzare",
    "pinzavamo": "pinzare",
    "pinzavan": "pinzare",
    "pinzavano": "pinzare",
    "pinzavate": "pinzare",
    "pinzavi": "pinzare",
    "pinzavo": "pinzare",
    "pinze": "pinza",
    "pinzerai": "pinzare",
    "pinzeran": "pinzare",
    "pinzeranno": "pinzare",
    "pinzerebbe": "pinzare",
    "pinzerebber": "pinzare",
    "pinzerebbero": "pinzare",
    "pinzerei": "pinzare",
    "pinzeremmo": "pinzare",
    "pinzeremo": "pinzare",
    "pinzereste": "pinzare",
    "pinzeresti": "pinzare",
    "pinzerete": "pinzare",
    "pinzerà": "pinzare",
    "pinzerò": "pinzare",
    "pinzette": "pinzetta",
    "pinzi": "pinzare",
    "pinziamo": "pinzare",
    "pinziate": "pinzare",
    "pinzin": "pinzare",
    "pinzino": "pinzare",
    "pinzo": "pinzare",
    "pinzò": "pinzare",
    "pio": "piare",
    "piogge": "pioggia",
    "pioggerelle": "pioggerella",
    "pioggerelline": "pioggerellina",
    "pioggie": "pioggia",
    "pioli": "piolo",
    "piomba": "piombare",
    "piombai": "piombare",
    "piombammo": "piombare",
    "piomban": "piombare",
    "piombando": "piombare",
    "piombano": "piombare",
    "piombante": "piombare",
    "piombanti": "piombare",
    "piombar": "piombare",
    "piombaron": "piombare",
    "piombarono": "piombare",
    "piombasse": "piombare",
    "piombasser": "piombare",
    "piombassero": "piombare",
    "piombassi": "piombare",
    "piombassimo": "piombare",
    "piombaste": "piombare",
    "piombasti": "piombare",
    "piombata": "piombare",
    "piombate": "piombare",
    "piombati": "piombare",
    "piombato": "piombare",
    "piombava": "piombare",
    "piombavamo": "piombare",
    "piombavan": "piombare",
    "piombavano": "piombare",
    "piombavate": "piombare",
    "piombavi": "piombare",
    "piombavo": "piombare",
    "piomberai": "piombare",
    "piomberan": "piombare",
    "piomberanno": "piombare",
    "piomberebbe": "piombare",
    "piomberebber": "piombare",
    "piomberebbero": "piombare",
    "piomberei": "piombare",
    "piomberemmo": "piombare",
    "piomberemo": "piombare",
    "piombereste": "piombare",
    "piomberesti": "piombare",
    "piomberete": "piombare",
    "piomberà": "piombare",
    "piomberò": "piombare",
    "piombi": "piombo",
    "piombiamo": "piombare",
    "piombiate": "piombare",
    "piombin": "piombare",
    "piombino": "piombare",
    "piombo": "piombare",
    "piombò": "piombare",
    "pioniere": "pioniera",
    "pionieri": "pioniere",
    "pionieristica": "pionieristico",
    "pionieristiche": "pionieristico",
    "pionieristici": "pionieristico",
    "pioppeti": "pioppeto",
    "piota": "piotare",
    "piotai": "piotare",
    "piotammo": "piotare",
    "piotan": "piotare",
    "piotando": "piotare",
    "piotano": "piotare",
    "piotante": "piotare",
    "piotanti": "piotare",
    "piotar": "piotare",
    "piotaron": "piotare",
    "piotarono": "piotare",
    "piotasse": "piotare",
    "piotasser": "piotare",
    "piotassero": "piotare",
    "piotassi": "piotare",
    "piotassimo": "piotare",
    "piotaste": "piotare",
    "piotasti": "piotare",
    "piotata": "piotare",
    "piotate": "piotare",
    "piotati": "piotare",
    "piotato": "piotare",
    "piotava": "piotare",
    "piotavamo": "piotare",
    "piotavan": "piotare",
    "piotavano": "piotare",
    "piotavate": "piotare",
    "piotavi": "piotare",
    "piotavo": "piotare",
    "pioterai": "piotare",
    "pioteran": "piotare",
    "pioteranno": "piotare",
    "pioterebbe": "piotare",
    "pioterebber": "piotare",
    "pioterebbero": "piotare",
    "pioterei": "piotare",
    "pioteremmo": "piotare",
    "pioteremo": "piotare",
    "piotereste": "piotare",
    "pioteresti": "piotare",
    "pioterete": "piotare",
    "pioterà": "piotare",
    "pioterò": "piotare",
    "pioti": "piotare",
    "piotiamo": "piotare",
    "piotiate": "piotare",
    "piotin": "piotare",
    "piotino": "piotare",
    "pioto": "piotare",
    "piotò": "piotare",
    "piova": "piovere",
    "piovan": "piovere",
    "piovana": "piovano",
    "piovane": "piovano",
    "piovani": "piovano",
    "piovano": "piovere",
    "piove": "piovere",
    "piovei": "piovere",
    "piovemmo": "piovere",
    "piovendo": "piovere",
    "piovente": "piovere",
    "pioventi": "piovere",
    "piover": "piovere",
    "pioverai": "piovere",
    "pioveran": "piovere",
    "pioveranno": "piovere",
    "pioverebbe": "piovere",
    "pioverebber": "piovere",
    "pioverebbero": "piovere",
    "pioverei": "piovere",
    "pioveremmo": "piovere",
    "pioveremo": "piovere",
    "piovereste": "piovere",
    "pioveresti": "piovere",
    "pioverete": "piovere",
    "pioveron": "piovere",
    "pioverono": "piovere",
    "pioverà": "piovere",
    "pioverò": "piovere",
    "piovesse": "piovere",
    "piovesser": "piovere",
    "piovessero": "piovere",
    "piovessi": "piovere",
    "piovessimo": "piovere",
    "pioveste": "piovere",
    "piovesti": "piovere",
    "piovete": "piovere",
    "pioveva": "piovere",
    "piovevamo": "piovere",
    "piovevan": "piovere",
    "piovevano": "piovere",
    "piovevate": "piovere",
    "piovevi": "piovere",
    "piovevo": "piovere",
    "piovi": "piovere",
    "pioviamo": "piovere",
    "pioviate": "piovere",
    "pioviggina": "piovigginare",
    "piovigginai": "piovigginare",
    "piovigginammo": "piovigginare",
    "piovigginan": "piovigginare",
    "piovigginando": "piovigginare",
    "piovigginano": "piovigginare",
    "piovigginante": "piovigginare",
    "piovigginanti": "piovigginare",
    "piovigginar": "piovigginare",
    "piovigginaron": "piovigginare",
    "piovigginarono": "piovigginare",
    "piovigginasse": "piovigginare",
    "piovigginasser": "piovigginare",
    "piovigginassero": "piovigginare",
    "piovigginassi": "piovigginare",
    "piovigginassimo": "piovigginare",
    "piovigginaste": "piovigginare",
    "piovigginasti": "piovigginare",
    "piovigginata": "piovigginare",
    "piovigginate": "piovigginare",
    "piovigginati": "piovigginare",
    "piovigginato": "piovigginare",
    "piovigginava": "piovigginare",
    "piovigginavamo": "piovigginare",
    "piovigginavan": "piovigginare",
    "piovigginavano": "piovigginare",
    "piovigginavate": "piovigginare",
    "piovigginavi": "piovigginare",
    "piovigginavo": "piovigginare",
    "piovigginerai": "piovigginare",
    "pioviggineran": "piovigginare",
    "pioviggineranno": "piovigginare",
    "piovigginerebbe": "piovigginare",
    "piovigginerebber": "piovigginare",
    "piovigginerebbero": "piovigginare",
    "piovigginerei": "piovigginare",
    "pioviggineremmo": "piovigginare",
    "pioviggineremo": "piovigginare",
    "piovigginereste": "piovigginare",
    "pioviggineresti": "piovigginare",
    "piovigginerete": "piovigginare",
    "piovigginerà": "piovigginare",
    "piovigginerò": "piovigginare",
    "pioviggini": "piovigginare",
    "piovigginiamo": "piovigginare",
    "piovigginiate": "piovigginare",
    "piovigginin": "piovigginare",
    "piovigginino": "piovigginare",
    "pioviggino": "piovigginare",
    "piovigginosa": "piovigginoso",
    "piovigginose": "piovigginoso",
    "piovigginosi": "piovigginoso",
    "piovigginò": "piovigginare",
    "piovo": "piovere",
    "piovon": "piovere",
    "piovono": "piovere",
    "piovosa": "piovoso",
    "piovose": "piovoso",
    "piovosi": "piovoso",
    "piovre": "piovra",
    "piovuta": "piovere",
    "piovute": "piovere",
    "piovuti": "piovere",
    "piovuto": "piovere",
    "piovè": "piovere",
    "pipa": "pipare",
    "pipai": "pipare",
    "pipammo": "pipare",
    "pipan": "pipare",
    "pipando": "pipare",
    "pipano": "pipare",
    "pipante": "pipare",
    "pipanti": "pipare",
    "pipar": "pipare",
    "piparon": "pipare",
    "piparono": "pipare",
    "pipasse": "pipare",
    "pipasser": "pipare",
    "pipassero": "pipare",
    "pipassi": "pipare",
    "pipassimo": "pipare",
    "pipaste": "pipare",
    "pipasti": "pipare",
    "pipata": "pipare",
    "pipate": "pipare",
    "pipati": "pipare",
    "pipato": "pipare",
    "pipava": "pipare",
    "pipavamo": "pipare",
    "pipavan": "pipare",
    "pipavano": "pipare",
    "pipavate": "pipare",
    "pipavi": "pipare",
    "pipavo": "pipare",
    "pipe": "pipa",
    "piperai": "pipare",
    "piperan": "pipare",
    "piperanno": "pipare",
    "piperebbe": "pipare",
    "piperebber": "pipare",
    "piperebbero": "pipare",
    "piperei": "pipare",
    "piperemmo": "pipare",
    "piperemo": "pipare",
    "pipereste": "pipare",
    "piperesti": "pipare",
    "piperete": "pipare",
    "piperà": "pipare",
    "piperò": "pipare",
    "pipi": "pipiare",
    "pipia": "pipiare",
    "pipiai": "pipiare",
    "pipiammo": "pipiare",
    "pipiamo": "pipiare",
    "pipian": "pipiare",
    "pipiando": "pipiare",
    "pipiano": "pipiare",
    "pipiante": "pipiare",
    "pipianti": "pipiare",
    "pipiar": "pipiare",
    "pipiaron": "pipiare",
    "pipiarono": "pipiare",
    "pipiasse": "pipiare",
    "pipiasser": "pipiare",
    "pipiassero": "pipiare",
    "pipiassi": "pipiare",
    "pipiassimo": "pipiare",
    "pipiaste": "pipiare",
    "pipiasti": "pipiare",
    "pipiata": "pipiare",
    "pipiate": "pipiare",
    "pipiati": "pipiare",
    "pipiato": "pipiare",
    "pipiava": "pipiare",
    "pipiavamo": "pipiare",
    "pipiavan": "pipiare",
    "pipiavano": "pipiare",
    "pipiavate": "pipiare",
    "pipiavi": "pipiare",
    "pipiavo": "pipiare",
    "pipierai": "pipiare",
    "pipieran": "pipiare",
    "pipieranno": "pipiare",
    "pipierebbe": "pipiare",
    "pipierebber": "pipiare",
    "pipierebbero": "pipiare",
    "pipierei": "pipiare",
    "pipieremmo": "pipiare",
    "pipieremo": "pipiare",
    "pipiereste": "pipiare",
    "pipieresti": "pipiare",
    "pipierete": "pipiare",
    "pipierà": "pipiare",
    "pipierò": "pipiare",
    "pipin": "pipiare",
    "pipino": "pipiare",
    "pipio": "pipiare",
    "pipistrelli": "pipistrello",
    "pipiò": "pipiare",
    "pipo": "pipare",
    "pipò": "pipare",
    "piramidali": "piramidale",
    "piramidi": "piramide",
    "pirateggerai": "pirateggiare",
    "pirateggeran": "pirateggiare",
    "pirateggeranno": "pirateggiare",
    "pirateggerebbe": "pirateggiare",
    "pirateggerebber": "pirateggiare",
    "pirateggerebbero": "pirateggiare",
    "pirateggerei": "pirateggiare",
    "pirateggeremmo": "pirateggiare",
    "pirateggeremo": "pirateggiare",
    "pirateggereste": "pirateggiare",
    "pirateggeresti": "pirateggiare",
    "pirateggerete": "pirateggiare",
    "pirateggerà": "pirateggiare",
    "pirateggerò": "pirateggiare",
    "pirateggi": "pirateggiare",
    "pirateggia": "pirateggiare",
    "pirateggiai": "pirateggiare",
    "pirateggiammo": "pirateggiare",
    "pirateggiamo": "pirateggiare",
    "pirateggian": "pirateggiare",
    "pirateggiando": "pirateggiare",
    "pirateggiano": "pirateggiare",
    "pirateggiante": "pirateggiare",
    "pirateggianti": "pirateggiare",
    "pirateggiar": "pirateggiare",
    "pirateggiaron": "pirateggiare",
    "pirateggiarono": "pirateggiare",
    "pirateggiasse": "pirateggiare",
    "pirateggiasser": "pirateggiare",
    "pirateggiassero": "pirateggiare",
    "pirateggiassi": "pirateggiare",
    "pirateggiassimo": "pirateggiare",
    "pirateggiaste": "pirateggiare",
    "pirateggiasti": "pirateggiare",
    "pirateggiata": "pirateggiare",
    "pirateggiate": "pirateggiare",
    "pirateggiati": "pirateggiare",
    "pirateggiato": "pirateggiare",
    "pirateggiava": "pirateggiare",
    "pirateggiavamo": "pirateggiare",
    "pirateggiavan": "pirateggiare",
    "pirateggiavano": "pirateggiare",
    "pirateggiavate": "pirateggiare",
    "pirateggiavi": "pirateggiare",
    "pirateggiavo": "pirateggiare",
    "pirateggin": "pirateggiare",
    "pirateggino": "pirateggiare",
    "pirateggio": "pirateggiare",
    "pirateggiò": "pirateggiare",
    "piraterie": "pirateria",
    "piratesca": "piratesco",
    "piratesche": "piratesco",
    "pirateschi": "piratesco",
    "pirati": "pirata",
    "pire": "pira",
    "pirenaica": "pirenaico",
    "pirenaiche": "pirenaico",
    "pirenaici": "pirenaico",
    "pirica": "pirico",
    "piriche": "pirico",
    "pirici": "pirico",
    "piroetta": "piroettare",
    "piroettai": "piroettare",
    "piroettammo": "piroettare",
    "piroettan": "piroettare",
    "piroettando": "piroettare",
    "piroettano": "piroettare",
    "piroettante": "piroettare",
    "piroettanti": "piroettare",
    "piroettar": "piroettare",
    "piroettaron": "piroettare",
    "piroettarono": "piroettare",
    "piroettasse": "piroettare",
    "piroettasser": "piroettare",
    "piroettassero": "piroettare",
    "piroettassi": "piroettare",
    "piroettassimo": "piroettare",
    "piroettaste": "piroettare",
    "piroettasti": "piroettare",
    "piroettata": "piroettare",
    "piroettate": "piroettare",
    "piroettati": "piroettare",
    "piroettato": "piroettare",
    "piroettava": "piroettare",
    "piroettavamo": "piroettare",
    "piroettavan": "piroettare",
    "piroettavano": "piroettare",
    "piroettavate": "piroettare",
    "piroettavi": "piroettare",
    "piroettavo": "piroettare",
    "piroette": "piroetta",
    "piroetterai": "piroettare",
    "piroetteran": "piroettare",
    "piroetteranno": "piroettare",
    "piroetterebbe": "piroettare",
    "piroetterebber": "piroettare",
    "piroetterebbero": "piroettare",
    "piroetterei": "piroettare",
    "piroetteremmo": "piroettare",
    "piroetteremo": "piroettare",
    "piroettereste": "piroettare",
    "piroetteresti": "piroettare",
    "piroetterete": "piroettare",
    "piroetterà": "piroettare",
    "piroetterò": "piroettare",
    "piroetti": "piroettare",
    "piroettiamo": "piroettare",
    "piroettiate": "piroettare",
    "piroettin": "piroettare",
    "piroettino": "piroettare",
    "piroetto": "piroettare",
    "piroettò": "piroettare",
    "piroghe": "piroga",
    "piromani": "piromane",
    "piroscafi": "piroscafo",
    "pirotecnica": "pirotecnico",
    "pirotecniche": "pirotecnico",
    "pirotecnici": "pirotecnico",
    "pisana": "pisano",
    "pisane": "pisano",
    "pisani": "pisano",
    "piscerai": "pisciare",
    "pisceran": "pisciare",
    "pisceranno": "pisciare",
    "piscerebbe": "pisciare",
    "piscerebber": "pisciare",
    "piscerebbero": "pisciare",
    "piscerei": "pisciare",
    "pisceremmo": "pisciare",
    "pisceremo": "pisciare",
    "piscereste": "pisciare",
    "pisceresti": "pisciare",
    "piscerete": "pisciare",
    "piscerà": "pisciare",
    "piscerò": "pisciare",
    "pisci": "pisciare",
    "piscia": "pisciare",
    "pisciai": "pisciare",
    "pisciammo": "pisciare",
    "pisciamo": "pisciare",
    "piscian": "pisciare",
    "pisciando": "pisciare",
    "pisciano": "pisciare",
    "pisciante": "pisciare",
    "piscianti": "pisciare",
    "pisciar": "pisciare",
    "pisciaron": "pisciare",
    "pisciarono": "pisciare",
    "pisciasse": "pisciare",
    "pisciasser": "pisciare",
    "pisciassero": "pisciare",
    "pisciassi": "pisciare",
    "pisciassimo": "pisciare",
    "pisciaste": "pisciare",
    "pisciasti": "pisciare",
    "pisciata": "pisciare",
    "pisciate": "pisciare",
    "pisciati": "pisciare",
    "pisciato": "pisciare",
    "pisciatoi": "pisciatoio",
    "pisciava": "pisciare",
    "pisciavamo": "pisciare",
    "pisciavan": "pisciare",
    "pisciavano": "pisciare",
    "pisciavate": "pisciare",
    "pisciavi": "pisciare",
    "pisciavo": "pisciare",
    "piscin": "pisciare",
    "piscine": "piscina",
    "piscino": "pisciare",
    "piscio": "pisciare",
    "pisciò": "pisciare",
    "piselli": "pisello",
    "pisellini": "pisellino",
    "pisola": "pisolare",
    "pisolai": "pisolare",
    "pisolammo": "pisolare",
    "pisolan": "pisolare",
    "pisolando": "pisolare",
    "pisolano": "pisolare",
    "pisolante": "pisolare",
    "pisolanti": "pisolare",
    "pisolar": "pisolare",
    "pisolaron": "pisolare",
    "pisolarono": "pisolare",
    "pisolasse": "pisolare",
    "pisolasser": "pisolare",
    "pisolassero": "pisolare",
    "pisolassi": "pisolare",
    "pisolassimo": "pisolare",
    "pisolaste": "pisolare",
    "pisolasti": "pisolare",
    "pisolata": "pisolare",
    "pisolate": "pisolare",
    "pisolati": "pisolare",
    "pisolato": "pisolare",
    "pisolava": "pisolare",
    "pisolavamo": "pisolare",
    "pisolavan": "pisolare",
    "pisolavano": "pisolare",
    "pisolavate": "pisolare",
    "pisolavi": "pisolare",
    "pisolavo": "pisolare",
    "pisolerai": "pisolare",
    "pisoleran": "pisolare",
    "pisoleranno": "pisolare",
    "pisolerebbe": "pisolare",
    "pisolerebber": "pisolare",
    "pisolerebbero": "pisolare",
    "pisolerei": "pisolare",
    "pisoleremmo": "pisolare",
    "pisoleremo": "pisolare",
    "pisolereste": "pisolare",
    "pisoleresti": "pisolare",
    "pisolerete": "pisolare",
    "pisolerà": "pisolare",
    "pisolerò": "pisolare",
    "pisoli": "pisolare",
    "pisoliamo": "pisolare",
    "pisoliate": "pisolare",
    "pisolin": "pisolare",
    "pisolini": "pisolino",
    "pisolino": "pisolare",
    "pisolo": "pisolare",
    "pisolò": "pisolare",
    "pispigli": "pispigliare",
    "pispiglia": "pispigliare",
    "pispigliai": "pispigliare",
    "pispigliammo": "pispigliare",
    "pispigliamo": "pispigliare",
    "pispiglian": "pispigliare",
    "pispigliando": "pispigliare",
    "pispigliano": "pispigliare",
    "pispigliante": "pispigliare",
    "pispiglianti": "pispigliare",
    "pispigliar": "pispigliare",
    "pispigliaron": "pispigliare",
    "pispigliarono": "pispigliare",
    "pispigliasse": "pispigliare",
    "pispigliasser": "pispigliare",
    "pispigliassero": "pispigliare",
    "pispigliassi": "pispigliare",
    "pispigliassimo": "pispigliare",
    "pispigliaste": "pispigliare",
    "pispigliasti": "pispigliare",
    "pispigliata": "pispigliare",
    "pispigliate": "pispigliare",
    "pispigliati": "pispigliare",
    "pispigliato": "pispigliare",
    "pispigliava": "pispigliare",
    "pispigliavamo": "pispigliare",
    "pispigliavan": "pispigliare",
    "pispigliavano": "pispigliare",
    "pispigliavate": "pispigliare",
    "pispigliavi": "pispigliare",
    "pispigliavo": "pispigliare",
    "pispiglierai": "pispigliare",
    "pispiglieran": "pispigliare",
    "pispiglieranno": "pispigliare",
    "pispiglierebbe": "pispigliare",
    "pispiglierebber": "pispigliare",
    "pispiglierebbero": "pispigliare",
    "pispiglierei": "pispigliare",
    "pispiglieremmo": "pispigliare",
    "pispiglieremo": "pispigliare",
    "pispigliereste": "pispigliare",
    "pispiglieresti": "pispigliare",
    "pispiglierete": "pispigliare",
    "pispiglierà": "pispigliare",
    "pispiglierò": "pispigliare",
    "pispiglin": "pispigliare",
    "pispiglino": "pispigliare",
    "pispiglio": "pispigliare",
    "pispigliò": "pispigliare",
    "pistacchi": "pistacchio",
    "piste": "pista",
    "pistoiesi": "pistoiese",
    "pistole": "pistola",
    "pistoleri": "pistolero",
    "pistolettate": "pistolettata",
    "pistoloni": "pistolone",
    "pistolotti": "pistolotto",
    "pistoni": "pistone",
    "pitagorica": "pitagorico",
    "pitagoriche": "pitagorico",
    "pitagorici": "pitagorico",
    "pitocca": "pitocco",
    "pitoccai": "pitoccare",
    "pitoccammo": "pitoccare",
    "pitoccan": "pitoccare",
    "pitoccando": "pitoccare",
    "pitoccano": "pitoccare",
    "pitoccante": "pitoccare",
    "pitoccanti": "pitoccare",
    "pitoccar": "pitoccare",
    "pitoccaron": "pitoccare",
    "pitoccarono": "pitoccare",
    "pitoccasse": "pitoccare",
    "pitoccasser": "pitoccare",
    "pitoccassero": "pitoccare",
    "pitoccassi": "pitoccare",
    "pitoccassimo": "pitoccare",
    "pitoccaste": "pitoccare",
    "pitoccasti": "pitoccare",
    "pitoccata": "pitoccare",
    "pitoccate": "pitoccare",
    "pitoccati": "pitoccare",
    "pitoccato": "pitoccare",
    "pitoccava": "pitoccare",
    "pitoccavamo": "pitoccare",
    "pitoccavan": "pitoccare",
    "pitoccavano": "pitoccare",
    "pitoccavate": "pitoccare",
    "pitoccavi": "pitoccare",
    "pitoccavo": "pitoccare",
    "pitocche": "pitocco",
    "pitoccherai": "pitoccare",
    "pitoccheran": "pitoccare",
    "pitoccheranno": "pitoccare",
    "pitoccherebbe": "pitoccare",
    "pitoccherebber": "pitoccare",
    "pitoccherebbero": "pitoccare",
    "pitoccherei": "pitoccare",
    "pitoccheremmo": "pitoccare",
    "pitoccheremo": "pitoccare",
    "pitocchereste": "pitoccare",
    "pitoccheresti": "pitoccare",
    "pitoccherete": "pitoccare",
    "pitoccherà": "pitoccare",
    "pitoccherò": "pitoccare",
    "pitocchi": "pitocco",
    "pitocchiamo": "pitoccare",
    "pitocchiate": "pitoccare",
    "pitocchin": "pitoccare",
    "pitocchino": "pitoccare",
    "pitocco": "pitoccare",
    "pitoccò": "pitoccare",
    "pitoni": "pitone",
    "pittoresca": "pittoresco",
    "pittoresche": "pittoresco",
    "pittoreschi": "pittoresco",
    "pittori": "pittore",
    "pittorica": "pittorico",
    "pittoriche": "pittorico",
    "pittorici": "pittorico",
    "pittrici": "pittrice",
    "pittura": "pitturare",
    "pitturai": "pitturare",
    "pitturammo": "pitturare",
    "pitturan": "pitturare",
    "pitturando": "pitturare",
    "pitturano": "pitturare",
    "pitturante": "pitturare",
    "pitturanti": "pitturare",
    "pitturar": "pitturare",
    "pitturaron": "pitturare",
    "pitturarono": "pitturare",
    "pitturasse": "pitturare",
    "pitturasser": "pitturare",
    "pitturassero": "pitturare",
    "pitturassi": "pitturare",
    "pitturassimo": "pitturare",
    "pitturaste": "pitturare",
    "pitturasti": "pitturare",
    "pitturata": "pitturare",
    "pitturate": "pitturare",
    "pitturati": "pitturare",
    "pitturato": "pitturare",
    "pitturava": "pitturare",
    "pitturavamo": "pitturare",
    "pitturavan": "pitturare",
    "pitturavano": "pitturare",
    "pitturavate": "pitturare",
    "pitturavi": "pitturare",
    "pitturavo": "pitturare",
    "pitture": "pittura",
    "pitturerai": "pitturare",
    "pittureran": "pitturare",
    "pittureranno": "pitturare",
    "pitturerebbe": "pitturare",
    "pitturerebber": "pitturare",
    "pitturerebbero": "pitturare",
    "pitturerei": "pitturare",
    "pittureremmo": "pitturare",
    "pittureremo": "pitturare",
    "pitturereste": "pitturare",
    "pittureresti": "pitturare",
    "pitturerete": "pitturare",
    "pitturerà": "pitturare",
    "pitturerò": "pitturare",
    "pitturi": "pitturare",
    "pitturiamo": "pitturare",
    "pitturiate": "pitturare",
    "pitturin": "pitturare",
    "pitturino": "pitturare",
    "pitturo": "pitturare",
    "pitturò": "pitturare",
    "piumaggi": "piumaggio",
    "piumata": "piumato",
    "piumate": "piumato",
    "piumati": "piumato",
    "piume": "piuma",
    "piumini": "piumino",
    "piumoni": "piumone",
    "pivelli": "pivello",
    "pizzaioli": "pizzaiolo",
    "pizze": "pizza",
    "pizzerie": "pizzeria",
    "pizzette": "pizzetta",
    "pizzetti": "pizzetto",
    "pizzi": "pizzo",
    "pizzica": "pizzicare",
    "pizzicai": "pizzicare",
    "pizzicammo": "pizzicare",
    "pizzican": "pizzicare",
    "pizzicando": "pizzicare",
    "pizzicano": "pizzicare",
    "pizzicante": "pizzicare",
    "pizzicanti": "pizzicare",
    "pizzicar": "pizzicare",
    "pizzicaron": "pizzicare",
    "pizzicarono": "pizzicare",
    "pizzicasse": "pizzicare",
    "pizzicasser": "pizzicare",
    "pizzicassero": "pizzicare",
    "pizzicassi": "pizzicare",
    "pizzicassimo": "pizzicare",
    "pizzicaste": "pizzicare",
    "pizzicasti": "pizzicare",
    "pizzicata": "pizzicato",
    "pizzicate": "pizzicato",
    "pizzicati": "pizzicato",
    "pizzicato": "pizzicare",
    "pizzicava": "pizzicare",
    "pizzicavamo": "pizzicare",
    "pizzicavan": "pizzicare",
    "pizzicavano": "pizzicare",
    "pizzicavate": "pizzicare",
    "pizzicavi": "pizzicare",
    "pizzicavo": "pizzicare",
    "pizzicherai": "pizzicare",
    "pizzicheran": "pizzicare",
    "pizzicheranno": "pizzicare",
    "pizzicherebbe": "pizzicare",
    "pizzicherebber": "pizzicare",
    "pizzicherebbero": "pizzicare",
    "pizzicherei": "pizzicare",
    "pizzicheremmo": "pizzicare",
    "pizzicheremo": "pizzicare",
    "pizzichereste": "pizzicare",
    "pizzicheresti": "pizzicare",
    "pizzicherete": "pizzicare",
    "pizzicherà": "pizzicare",
    "pizzicherò": "pizzicare",
    "pizzichi": "pizzico",
    "pizzichiamo": "pizzicare",
    "pizzichiate": "pizzicare",
    "pizzichin": "pizzicare",
    "pizzichino": "pizzicare",
    "pizzico": "pizzicare",
    "pizzicotta": "pizzicottare",
    "pizzicottai": "pizzicottare",
    "pizzicottammo": "pizzicottare",
    "pizzicottan": "pizzicottare",
    "pizzicottando": "pizzicottare",
    "pizzicottano": "pizzicottare",
    "pizzicottante": "pizzicottare",
    "pizzicottanti": "pizzicottare",
    "pizzicottar": "pizzicottare",
    "pizzicottaron": "pizzicottare",
    "pizzicottarono": "pizzicottare",
    "pizzicottasse": "pizzicottare",
    "pizzicottasser": "pizzicottare",
    "pizzicottassero": "pizzicottare",
    "pizzicottassi": "pizzicottare",
    "pizzicottassimo": "pizzicottare",
    "pizzicottaste": "pizzicottare",
    "pizzicottasti": "pizzicottare",
    "pizzicottata": "pizzicottare",
    "pizzicottate": "pizzicottare",
    "pizzicottati": "pizzicottare",
    "pizzicottato": "pizzicottare",
    "pizzicottava": "pizzicottare",
    "pizzicottavamo": "pizzicottare",
    "pizzicottavan": "pizzicottare",
    "pizzicottavano": "pizzicottare",
    "pizzicottavate": "pizzicottare",
    "pizzicottavi": "pizzicottare",
    "pizzicottavo": "pizzicottare",
    "pizzicotterai": "pizzicottare",
    "pizzicotteran": "pizzicottare",
    "pizzicotteranno": "pizzicottare",
    "pizzicotterebbe": "pizzicottare",
    "pizzicotterebber": "pizzicottare",
    "pizzicotterebbero": "pizzicottare",
    "pizzicotterei": "pizzicottare",
    "pizzicotteremmo": "pizzicottare",
    "pizzicotteremo": "pizzicottare",
    "pizzicottereste": "pizzicottare",
    "pizzicotteresti": "pizzicottare",
    "pizzicotterete": "pizzicottare",
    "pizzicotterà": "pizzicottare",
    "pizzicotterò": "pizzicottare",
    "pizzicotti": "pizzicotto",
    "pizzicottiamo": "pizzicottare",
    "pizzicottiate": "pizzicottare",
    "pizzicottin": "pizzicottare",
    "pizzicottino": "pizzicottare",
    "pizzicotto": "pizzicottare",
    "pizzicottò": "pizzicottare",
    "pizzicò": "pizzicare",
    "piéces": "piéce",
    "piò": "piare",
    "più": "molto",
    "placa": "placare",
    "placai": "placare",
    "placammo": "placare",
    "placan": "placare",
    "placando": "placare",
    "placano": "placare",
    "placante": "placare",
    "placanti": "placare",
    "placar": "placare",
    "placaron": "placare",
    "placarono": "placare",
    "placasse": "placare",
    "placasser": "placare",
    "placassero": "placare",
    "placassi": "placare",
    "placassimo": "placare",
    "placaste": "placare",
    "placasti": "placare",
    "placata": "placare",
    "placate": "placare",
    "placati": "placare",
    "placato": "placare",
    "placava": "placare",
    "placavamo": "placare",
    "placavan": "placare",
    "placavano": "placare",
    "placavate": "placare",
    "placavi": "placare",
    "placavo": "placare",
    "placca": "placcare",
    "placcaggi": "placcaggio",
    "placcai": "placcare",
    "placcammo": "placcare",
    "placcan": "placcare",
    "placcando": "placcare",
    "placcano": "placcare",
    "placcante": "placcare",
    "placcanti": "placcare",
    "placcar": "placcare",
    "placcaron": "placcare",
    "placcarono": "placcare",
    "placcasse": "placcare",
    "placcasser": "placcare",
    "placcassero": "placcare",
    "placcassi": "placcare",
    "placcassimo": "placcare",
    "placcaste": "placcare",
    "placcasti": "placcare",
    "placcata": "placcare",
    "placcate": "placcare",
    "placcati": "placcare",
    "placcato": "placcare",
    "placcava": "placcare",
    "placcavamo": "placcare",
    "placcavan": "placcare",
    "placcavano": "placcare",
    "placcavate": "placcare",
    "placcavi": "placcare",
    "placcavo": "placcare",
    "placche": "placca",
    "placcherai": "placcare",
    "placcheran": "placcare",
    "placcheranno": "placcare",
    "placcherebbe": "placcare",
    "placcherebber": "placcare",
    "placcherebbero": "placcare",
    "placcherei": "placcare",
    "placcheremmo": "placcare",
    "placcheremo": "placcare",
    "placchereste": "placcare",
    "placcheresti": "placcare",
    "placcherete": "placcare",
    "placcherà": "placcare",
    "placcherò": "placcare",
    "placchette": "placchetta",
    "placchi": "placcare",
    "placchiamo": "placcare",
    "placchiate": "placcare",
    "placchin": "placcare",
    "placchino": "placcare",
    "placco": "placcare",
    "placcò": "placcare",
    "placebi": "placebo",
    "placenta": "placentare",
    "placentai": "placentare",
    "placentammo": "placentare",
    "placentan": "placentare",
    "placentando": "placentare",
    "placentano": "placentare",
    "placentante": "placentare",
    "placentanti": "placentare",
    "placentar": "placentare",
    "placentaron": "placentare",
    "placentarono": "placentare",
    "placentasse": "placentare",
    "placentasser": "placentare",
    "placentassero": "placentare",
    "placentassi": "placentare",
    "placentassimo": "placentare",
    "placentaste": "placentare",
    "placentasti": "placentare",
    "placentata": "placentare",
    "placentate": "placentare",
    "placentati": "placentare",
    "placentato": "placentare",
    "placentava": "placentare",
    "placentavamo": "placentare",
    "placentavan": "placentare",
    "placentavano": "placentare",
    "placentavate": "placentare",
    "placentavi": "placentare",
    "placentavo": "placentare",
    "placente": "placenta",
    "placenterai": "placentare",
    "placenteran": "placentare",
    "placenteranno": "placentare",
    "placenterebbe": "placentare",
    "placenterebber": "placentare",
    "placenterebbero": "placentare",
    "placenterei": "placentare",
    "placenteremmo": "placentare",
    "placenteremo": "placentare",
    "placentereste": "placentare",
    "placenteresti": "placentare",
    "placenterete": "placentare",
    "placenterà": "placentare",
    "placenterò": "placentare",
    "placenti": "placentare",
    "placentiamo": "placentare",
    "placentiate": "placentare",
    "placentin": "placentare",
    "placentino": "placentare",
    "placento": "placentare",
    "placentò": "placentare",
    "placherai": "placare",
    "placheran": "placare",
    "placheranno": "placare",
    "placherebbe": "placare",
    "placherebber": "placare",
    "placherebbero": "placare",
    "placherei": "placare",
    "placheremmo": "placare",
    "placheremo": "placare",
    "plachereste": "placare",
    "placheresti": "placare",
    "placherete": "placare",
    "placherà": "placare",
    "placherò": "placare",
    "plachi": "placare",
    "plachiamo": "placare",
    "plachiate": "placare",
    "plachin": "placare",
    "plachino": "placare",
    "placo": "placare",
    "placò": "placare",
    "plagerai": "plagiare",
    "plageran": "plagiare",
    "plageranno": "plagiare",
    "plagerebbe": "plagiare",
    "plagerebber": "plagiare",
    "plagerebbero": "plagiare",
    "plagerei": "plagiare",
    "plageremmo": "plagiare",
    "plageremo": "plagiare",
    "plagereste": "plagiare",
    "plageresti": "plagiare",
    "plagerete": "plagiare",
    "plagerà": "plagiare",
    "plagerò": "plagiare",
    "plaghe": "plaga",
    "plagi": "plagio",
    "plagia": "plagiare",
    "plagiai": "plagiare",
    "plagiammo": "plagiare",
    "plagiamo": "plagiare",
    "plagian": "plagiare",
    "plagiando": "plagiare",
    "plagiano": "plagiare",
    "plagiante": "plagiare",
    "plagianti": "plagiare",
    "plagiar": "plagiare",
    "plagiaron": "plagiare",
    "plagiarono": "plagiare",
    "plagiasse": "plagiare",
    "plagiasser": "plagiare",
    "plagiassero": "plagiare",
    "plagiassi": "plagiare",
    "plagiassimo": "plagiare",
    "plagiaste": "plagiare",
    "plagiasti": "plagiare",
    "plagiata": "plagiare",
    "plagiate": "plagiare",
    "plagiati": "plagiare",
    "plagiato": "plagiare",
    "plagiava": "plagiare",
    "plagiavamo": "plagiare",
    "plagiavan": "plagiare",
    "plagiavano": "plagiare",
    "plagiavate": "plagiare",
    "plagiavi": "plagiare",
    "plagiavo": "plagiare",
    "plagin": "plagiare",
    "plagino": "plagiare",
    "plagio": "plagiare",
    "plagiò": "plagiare",
    "plana": "planare",
    "planai": "planare",
    "planammo": "planare",
    "planan": "planare",
    "planando": "planare",
    "planano": "planare",
    "planante": "planare",
    "plananti": "planare",
    "planar": "planare",
    "planari": "planare",
    "planaron": "planare",
    "planarono": "planare",
    "planasse": "planare",
    "planasser": "planare",
    "planassero": "planare",
    "planassi": "planare",
    "planassimo": "planare",
    "planaste": "planare",
    "planasti": "planare",
    "planata": "planare",
    "planate": "planata",
    "planati": "planare",
    "planato": "planare",
    "planava": "planare",
    "planavamo": "planare",
    "planavan": "planare",
    "planavano": "planare",
    "planavate": "planare",
    "planavi": "planare",
    "planavo": "planare",
    "plance": "plancia",
    "planerai": "planare",
    "planeran": "planare",
    "planeranno": "planare",
    "planerebbe": "planare",
    "planerebber": "planare",
    "planerebbero": "planare",
    "planerei": "planare",
    "planeremmo": "planare",
    "planeremo": "planare",
    "planereste": "planare",
    "planeresti": "planare",
    "planerete": "planare",
    "planerà": "planare",
    "planerò": "planare",
    "planetari": "planetario",
    "planetaria": "planetario",
    "planetarie": "planetario",
    "planetologi": "planetologo",
    "plani": "planare",
    "planiamo": "planare",
    "planiate": "planare",
    "planimetrica": "planimetrico",
    "planimetriche": "planimetrico",
    "planimetrici": "planimetrico",
    "planimetrie": "planimetria",
    "planin": "planare",
    "planino": "planare",
    "plano": "planare",
    "planta": "plantare",
    "plantai": "plantare",
    "plantammo": "plantare",
    "plantan": "plantare",
    "plantando": "plantare",
    "plantano": "plantare",
    "plantante": "plantare",
    "plantanti": "plantare",
    "plantar": "plantare",
    "plantari": "plantare",
    "plantaron": "plantare",
    "plantarono": "plantare",
    "plantasse": "plantare",
    "plantasser": "plantare",
    "plantassero": "plantare",
    "plantassi": "plantare",
    "plantassimo": "plantare",
    "plantaste": "plantare",
    "plantasti": "plantare",
    "plantata": "plantare",
    "plantate": "plantare",
    "plantati": "plantare",
    "plantato": "plantare",
    "plantava": "plantare",
    "plantavamo": "plantare",
    "plantavan": "plantare",
    "plantavano": "plantare",
    "plantavate": "plantare",
    "plantavi": "plantare",
    "plantavo": "plantare",
    "planterai": "plantare",
    "planteran": "plantare",
    "planteranno": "plantare",
    "planterebbe": "plantare",
    "planterebber": "plantare",
    "planterebbero": "plantare",
    "planterei": "plantare",
    "planteremmo": "plantare",
    "planteremo": "plantare",
    "plantereste": "plantare",
    "planteresti": "plantare",
    "planterete": "plantare",
    "planterà": "plantare",
    "planterò": "plantare",
    "planti": "plantare",
    "plantiamo": "plantare",
    "plantiate": "plantare",
    "plantin": "plantare",
    "plantino": "plantare",
    "planto": "plantare",
    "plantò": "plantare",
    "planò": "planare",
    "plasma": "plasmare",
    "plasmai": "plasmare",
    "plasmammo": "plasmare",
    "plasman": "plasmare",
    "plasmando": "plasmare",
    "plasmano": "plasmare",
    "plasmante": "plasmare",
    "plasmanti": "plasmare",
    "plasmar": "plasmare",
    "plasmaron": "plasmare",
    "plasmarono": "plasmare",
    "plasmasse": "plasmare",
    "plasmasser": "plasmare",
    "plasmassero": "plasmare",
    "plasmassi": "plasmare",
    "plasmassimo": "plasmare",
    "plasmaste": "plasmare",
    "plasmasti": "plasmare",
    "plasmata": "plasmare",
    "plasmate": "plasmare",
    "plasmati": "plasmare",
    "plasmato": "plasmare",
    "plasmava": "plasmare",
    "plasmavamo": "plasmare",
    "plasmavan": "plasmare",
    "plasmavano": "plasmare",
    "plasmavate": "plasmare",
    "plasmavi": "plasmare",
    "plasmavo": "plasmare",
    "plasmerai": "plasmare",
    "plasmeran": "plasmare",
    "plasmeranno": "plasmare",
    "plasmerebbe": "plasmare",
    "plasmerebber": "plasmare",
    "plasmerebbero": "plasmare",
    "plasmerei": "plasmare",
    "plasmeremmo": "plasmare",
    "plasmeremo": "plasmare",
    "plasmereste": "plasmare",
    "plasmeresti": "plasmare",
    "plasmerete": "plasmare",
    "plasmerà": "plasmare",
    "plasmerò": "plasmare",
    "plasmi": "plasmare",
    "plasmiamo": "plasmare",
    "plasmiate": "plasmare",
    "plasmin": "plasmare",
    "plasmino": "plasmare",
    "plasmo": "plasmare",
    "plasmò": "plasmare",
    "plastica": "plastico",
    "plasticai": "plasticare",
    "plasticammo": "plasticare",
    "plastican": "plasticare",
    "plasticando": "plasticare",
    "plasticano": "plasticare",
    "plasticante": "plasticare",
    "plasticanti": "plasticare",
    "plasticar": "plasticare",
    "plasticaron": "plasticare",
    "plasticarono": "plasticare",
    "plasticasse": "plasticare",
    "plasticasser": "plasticare",
    "plasticassero": "plasticare",
    "plasticassi": "plasticare",
    "plasticassimo": "plasticare",
    "plasticaste": "plasticare",
    "plasticasti": "plasticare",
    "plasticata": "plasticare",
    "plasticate": "plasticare",
    "plasticati": "plasticare",
    "plasticato": "plasticare",
    "plasticava": "plasticare",
    "plasticavamo": "plasticare",
    "plasticavan": "plasticare",
    "plasticavano": "plasticare",
    "plasticavate": "plasticare",
    "plasticavi": "plasticare",
    "plasticavo": "plasticare",
    "plastiche": "plastico",
    "plasticherai": "plasticare",
    "plasticheran": "plasticare",
    "plasticheranno": "plasticare",
    "plasticherebbe": "plasticare",
    "plasticherebber": "plasticare",
    "plasticherebbero": "plasticare",
    "plasticherei": "plasticare",
    "plasticheremmo": "plasticare",
    "plasticheremo": "plasticare",
    "plastichereste": "plasticare",
    "plasticheresti": "plasticare",
    "plasticherete": "plasticare",
    "plasticherà": "plasticare",
    "plasticherò": "plasticare",
    "plastichi": "plasticare",
    "plastichiamo": "plasticare",
    "plastichiate": "plasticare",
    "plastichin": "plasticare",
    "plastichino": "plasticare",
    "plastici": "plastico",
    "plastico": "plasticare",
    "plasticò": "plasticare",
    "plastifica": "plastificare",
    "plastificai": "plastificare",
    "plastificammo": "plastificare",
    "plastifican": "plastificare",
    "plastificando": "plastificare",
    "plastificano": "plastificare",
    "plastificante": "plastificare",
    "plastificanti": "plastificare",
    "plastificar": "plastificare",
    "plastificaron": "plastificare",
    "plastificarono": "plastificare",
    "plastificasse": "plastificare",
    "plastificasser": "plastificare",
    "plastificassero": "plastificare",
    "plastificassi": "plastificare",
    "plastificassimo": "plastificare",
    "plastificaste": "plastificare",
    "plastificasti": "plastificare",
    "plastificata": "plastificare",
    "plastificate": "plastificare",
    "plastificati": "plastificare",
    "plastificato": "plastificare",
    "plastificava": "plastificare",
    "plastificavamo": "plastificare",
    "plastificavan": "plastificare",
    "plastificavano": "plastificare",
    "plastificavate": "plastificare",
    "plastificavi": "plastificare",
    "plastificavo": "plastificare",
    "plastificherai": "plastificare",
    "plastificheran": "plastificare",
    "plastificheranno": "plastificare",
    "plastificherebbe": "plastificare",
    "plastificherebber": "plastificare",
    "plastificherebbero": "plastificare",
    "plastificherei": "plastificare",
    "plastificheremmo": "plastificare",
    "plastificheremo": "plastificare",
    "plastifichereste": "plastificare",
    "plastificheresti": "plastificare",
    "plastificherete": "plastificare",
    "plastificherà": "plastificare",
    "plastificherò": "plastificare",
    "plastifichi": "plastificare",
    "plastifichiamo": "plastificare",
    "plastifichiate": "plastificare",
    "plastifichin": "plastificare",
    "plastifichino": "plastificare",
    "plastifico": "plastificare",
    "plastificò": "plastificare",
    "platani": "platano",
    "plateali": "plateale",
    "platee": "platea",
    "platina": "platinare",
    "platinai": "platinare",
    "platinammo": "platinare",
    "platinan": "platinare",
    "platinando": "platinare",
    "platinano": "platinare",
    "platinante": "platinare",
    "platinanti": "platinare",
    "platinar": "platinare",
    "platinaron": "platinare",
    "platinarono": "platinare",
    "platinasse": "platinare",
    "platinasser": "platinare",
    "platinassero": "platinare",
    "platinassi": "platinare",
    "platinassimo": "platinare",
    "platinaste": "platinare",
    "platinasti": "platinare",
    "platinata": "platinare",
    "platinate": "platinare",
    "platinati": "platinare",
    "platinato": "platinare",
    "platinava": "platinare",
    "platinavamo": "platinare",
    "platinavan": "platinare",
    "platinavano": "platinare",
    "platinavate": "platinare",
    "platinavi": "platinare",
    "platinavo": "platinare",
    "platinerai": "platinare",
    "platineran": "platinare",
    "platineranno": "platinare",
    "platinerebbe": "platinare",
    "platinerebber": "platinare",
    "platinerebbero": "platinare",
    "platinerei": "platinare",
    "platineremmo": "platinare",
    "platineremo": "platinare",
    "platinereste": "platinare",
    "platineresti": "platinare",
    "platinerete": "platinare",
    "platinerà": "platinare",
    "platinerò": "platinare",
    "platini": "platino",
    "platiniamo": "platinare",
    "platiniate": "platinare",
    "platinin": "platinare",
    "platinino": "platinare",
    "platino": "platinare",
    "platinò": "platinare",
    "platonica": "platonico",
    "platoniche": "platonico",
    "platonici": "platonico",
    "platonismi": "platonismo",
    "plauda": "plaudire",
    "plaudan": "plaudire",
    "plaudano": "plaudire",
    "plaude": "plaudire",
    "plaudei": "plaudere",
    "plaudemmo": "plaudere",
    "plaudendo": "plaudire",
    "plaudente": "plaudire",
    "plaudenti": "plaudire",
    "plauder": "plaudere",
    "plauderai": "plaudere",
    "plauderan": "plaudere",
    "plauderanno": "plaudere",
    "plauderebbe": "plaudere",
    "plauderebber": "plaudere",
    "plauderebbero": "plaudere",
    "plauderei": "plaudere",
    "plauderemmo": "plaudere",
    "plauderemo": "plaudere",
    "plaudereste": "plaudere",
    "plauderesti": "plaudere",
    "plauderete": "plaudere",
    "plauderon": "plaudere",
    "plauderono": "plaudere",
    "plauderà": "plaudere",
    "plauderò": "plaudere",
    "plaudesse": "plaudere",
    "plaudesser": "plaudere",
    "plaudessero": "plaudere",
    "plaudessi": "plaudere",
    "plaudessimo": "plaudere",
    "plaudeste": "plaudere",
    "plaudesti": "plaudere",
    "plaudete": "plaudere",
    "plaudeva": "plaudere",
    "plaudevamo": "plaudere",
    "plaudevan": "plaudere",
    "plaudevano": "plaudere",
    "plaudevate": "plaudere",
    "plaudevi": "plaudere",
    "plaudevo": "plaudere",
    "plaudi": "plaudire",
    "plaudiamo": "plaudire",
    "plaudiate": "plaudire",
    "plaudii": "plaudire",
    "plaudimmo": "plaudire",
    "plaudir": "plaudire",
    "plaudirai": "plaudire",
    "plaudiran": "plaudire",
    "plaudiranno": "plaudire",
    "plaudirebbe": "plaudire",
    "plaudirebber": "plaudire",
    "plaudirebbero": "plaudire",
    "plaudirei": "plaudire",
    "plaudiremmo": "plaudire",
    "plaudiremo": "plaudire",
    "plaudireste": "plaudire",
    "plaudiresti": "plaudire",
    "plaudirete": "plaudire",
    "plaudiron": "plaudire",
    "plaudirono": "plaudire",
    "plaudirà": "plaudire",
    "plaudirò": "plaudire",
    "plaudisse": "plaudire",
    "plaudisser": "plaudire",
    "plaudissero": "plaudire",
    "plaudissi": "plaudire",
    "plaudissimo": "plaudire",
    "plaudiste": "plaudire",
    "plaudisti": "plaudire",
    "plaudita": "plaudire",
    "plaudite": "plaudire",
    "plauditi": "plaudire",
    "plaudito": "plaudire",
    "plaudiva": "plaudire",
    "plaudivamo": "plaudire",
    "plaudivan": "plaudire",
    "plaudivano": "plaudire",
    "plaudivate": "plaudire",
    "plaudivi": "plaudire",
    "plaudivo": "plaudire",
    "plaudo": "plaudire",
    "plaudon": "plaudire",
    "plaudono": "plaudire",
    "plauduta": "plaudere",
    "plaudute": "plaudere",
    "plauduti": "plaudere",
    "plauduto": "plaudere",
    "plaudè": "plaudere",
    "plaudì": "plaudire",
    "plausi": "plauso",
    "plausibili": "plausibile",
    "plazas": "plaza",
    "plebea": "plebeo",
    "plebee": "plebeo",
    "plebei": "plebeo",
    "plebi": "plebe",
    "plebiscitari": "plebiscitario",
    "plebiscitaria": "plebiscitario",
    "plebiscitarie": "plebiscitario",
    "plebisciti": "plebiscito",
    "plenari": "plenario",
    "plenaria": "plenario",
    "plenarie": "plenario",
    "plenipotenziari": "plenipotenziario",
    "plenipotenziaria": "plenipotenziario",
    "plenipotenziarie": "plenipotenziario",
    "pleonastica": "pleonastico",
    "pleonastiche": "pleonastico",
    "pleonastici": "pleonastico",
    "plessi": "plesso",
    "pletore": "pletora",
    "pletorica": "pletorico",
    "pletoriche": "pletorico",
    "pletorici": "pletorico",
    "plichi": "plico",
    "plissettata": "plissettato",
    "plissettate": "plissettato",
    "plissettati": "plissettato",
    "plora": "plorare",
    "plorai": "plorare",
    "plorammo": "plorare",
    "ploran": "plorare",
    "plorando": "plorare",
    "plorano": "plorare",
    "plorante": "plorare",
    "ploranti": "plorare",
    "plorar": "plorare",
    "ploraron": "plorare",
    "plorarono": "plorare",
    "plorasse": "plorare",
    "plorasser": "plorare",
    "plorassero": "plorare",
    "plorassi": "plorare",
    "plorassimo": "plorare",
    "ploraste": "plorare",
    "plorasti": "plorare",
    "plorata": "plorare",
    "plorate": "plorare",
    "plorati": "plorare",
    "plorato": "plorare",
    "plorava": "plorare",
    "ploravamo": "plorare",
    "ploravan": "plorare",
    "ploravano": "plorare",
    "ploravate": "plorare",
    "ploravi": "plorare",
    "ploravo": "plorare",
    "plorerai": "plorare",
    "ploreran": "plorare",
    "ploreranno": "plorare",
    "plorerebbe": "plorare",
    "plorerebber": "plorare",
    "plorerebbero": "plorare",
    "plorerei": "plorare",
    "ploreremmo": "plorare",
    "ploreremo": "plorare",
    "plorereste": "plorare",
    "ploreresti": "plorare",
    "plorerete": "plorare",
    "plorerà": "plorare",
    "plorerò": "plorare",
    "plori": "plorare",
    "ploriamo": "plorare",
    "ploriate": "plorare",
    "plorin": "plorare",
    "plorino": "plorare",
    "ploro": "plorare",
    "plorò": "plorare",
    "plotoncini": "plotoncino",
    "plotoni": "plotone",
    "plumbea": "plumbeo",
    "plumbee": "plumbeo",
    "plumbei": "plumbeo",
    "plurali": "plurale",
    "pluralismi": "pluralismo",
    "pluraliste": "pluralista",
    "pluralisti": "pluralista",
    "pluralistica": "pluralistico",
    "pluralistiche": "pluralistico",
    "pluralistici": "pluralistico",
    "pluralizza": "pluralizzare",
    "pluralizzai": "pluralizzare",
    "pluralizzammo": "pluralizzare",
    "pluralizzan": "pluralizzare",
    "pluralizzando": "pluralizzare",
    "pluralizzano": "pluralizzare",
    "pluralizzante": "pluralizzare",
    "pluralizzanti": "pluralizzare",
    "pluralizzar": "pluralizzare",
    "pluralizzaron": "pluralizzare",
    "pluralizzarono": "pluralizzare",
    "pluralizzasse": "pluralizzare",
    "pluralizzasser": "pluralizzare",
    "pluralizzassero": "pluralizzare",
    "pluralizzassi": "pluralizzare",
    "pluralizzassimo": "pluralizzare",
    "pluralizzaste": "pluralizzare",
    "pluralizzasti": "pluralizzare",
    "pluralizzata": "pluralizzare",
    "pluralizzate": "pluralizzare",
    "pluralizzati": "pluralizzare",
    "pluralizzato": "pluralizzare",
    "pluralizzava": "pluralizzare",
    "pluralizzavamo": "pluralizzare",
    "pluralizzavan": "pluralizzare",
    "pluralizzavano": "pluralizzare",
    "pluralizzavate": "pluralizzare",
    "pluralizzavi": "pluralizzare",
    "pluralizzavo": "pluralizzare",
    "pluralizzerai": "pluralizzare",
    "pluralizzeran": "pluralizzare",
    "pluralizzeranno": "pluralizzare",
    "pluralizzerebbe": "pluralizzare",
    "pluralizzerebber": "pluralizzare",
    "pluralizzerebbero": "pluralizzare",
    "pluralizzerei": "pluralizzare",
    "pluralizzeremmo": "pluralizzare",
    "pluralizzeremo": "pluralizzare",
    "pluralizzereste": "pluralizzare",
    "pluralizzeresti": "pluralizzare",
    "pluralizzerete": "pluralizzare",
    "pluralizzerà": "pluralizzare",
    "pluralizzerò": "pluralizzare",
    "pluralizzi": "pluralizzare",
    "pluralizziamo": "pluralizzare",
    "pluralizziate": "pluralizzare",
    "pluralizzin": "pluralizzare",
    "pluralizzino": "pluralizzare",
    "pluralizzo": "pluralizzare",
    "pluralizzò": "pluralizzare",
    "pluriaggravata": "pluriaggravato",
    "pluriaggravate": "pluriaggravato",
    "pluriaggravati": "pluriaggravato",
    "pluricellulari": "pluricellulare",
    "pluridecorata": "pluridecorato",
    "pluridecorate": "pluridecorato",
    "pluridecorati": "pluridecorato",
    "pluridimensionali": "pluridimensionale",
    "pluriennali": "pluriennale",
    "plurigemellari": "plurigemellare",
    "plurilingui": "plurilingue",
    "plurilinguismi": "plurilinguismo",
    "plurima": "plurimo",
    "plurime": "plurimo",
    "plurimi": "plurimo",
    "plurimiliardari": "plurimiliardario",
    "plurinazionali": "plurinazionale",
    "plurinominali": "plurinominale",
    "pluriomicidi": "pluriomicidio",
    "pluripartitismi": "pluripartitismo",
    "plurisecolari": "plurisecolare",
    "plusvalenze": "plusvalenza",
    "plusvalori": "plusvalore",
    "plutonii": "plutonio",
    "pluvi": "pluvio",
    "pluvia": "pluvio",
    "pluviali": "pluviale",
    "pluvie": "pluvio",
    "pluviometrica": "pluviometrico",
    "pluviometriche": "pluviometrico",
    "pluviometrici": "pluviometrico",
    "pneumatica": "pneumatico",
    "pneumatiche": "pneumatico",
    "pneumatici": "pneumatico",
    "poca": "poco",
    "pochades": "pochade",
    "poche": "poco",
    "pochezze": "pochezza",
    "pochi": "poco",
    "poderali": "poderale",
    "poderi": "podere",
    "poderosa": "poderoso",
    "poderose": "poderoso",
    "poderosi": "poderoso",
    "podi": "podio",
    "podisti": "podista",
    "podistica": "podistico",
    "podistiche": "podistico",
    "podistici": "podistico",
    "podologi": "podologo",
    "poemetti": "poemetto",
    "poemi": "poema",
    "poesie": "poesia",
    "poesiole": "poesiola",
    "poeta": "poetare",
    "poetai": "poetare",
    "poetammo": "poetare",
    "poetan": "poetare",
    "poetando": "poetare",
    "poetano": "poetare",
    "poetante": "poetare",
    "poetanti": "poetare",
    "poetar": "poetare",
    "poetaron": "poetare",
    "poetarono": "poetare",
    "poetasse": "poetare",
    "poetasser": "poetare",
    "poetassero": "poetare",
    "poetassi": "poetare",
    "poetassimo": "poetare",
    "poetaste": "poetare",
    "poetasti": "poetare",
    "poetata": "poetare",
    "poetate": "poetare",
    "poetati": "poetare",
    "poetato": "poetare",
    "poetava": "poetare",
    "poetavamo": "poetare",
    "poetavan": "poetare",
    "poetavano": "poetare",
    "poetavate": "poetare",
    "poetavi": "poetare",
    "poetavo": "poetare",
    "poeterai": "poetare",
    "poeteran": "poetare",
    "poeteranno": "poetare",
    "poeterebbe": "poetare",
    "poeterebber": "poetare",
    "poeterebbero": "poetare",
    "poeterei": "poetare",
    "poeteremmo": "poetare",
    "poeteremo": "poetare",
    "poetereste": "poetare",
    "poeteresti": "poetare",
    "poeterete": "poetare",
    "poeterà": "poetare",
    "poeterò": "poetare",
    "poetesse": "poetessa",
    "poeti": "poetare",
    "poetiamo": "poetare",
    "poetiate": "poetare",
    "poetica": "poetico",
    "poetiche": "poetico",
    "poetici": "poetico",
    "poeticizza": "poeticizzare",
    "poeticizzai": "poeticizzare",
    "poeticizzammo": "poeticizzare",
    "poeticizzan": "poeticizzare",
    "poeticizzando": "poeticizzare",
    "poeticizzano": "poeticizzare",
    "poeticizzante": "poeticizzare",
    "poeticizzanti": "poeticizzare",
    "poeticizzar": "poeticizzare",
    "poeticizzaron": "poeticizzare",
    "poeticizzarono": "poeticizzare",
    "poeticizzasse": "poeticizzare",
    "poeticizzasser": "poeticizzare",
    "poeticizzassero": "poeticizzare",
    "poeticizzassi": "poeticizzare",
    "poeticizzassimo": "poeticizzare",
    "poeticizzaste": "poeticizzare",
    "poeticizzasti": "poeticizzare",
    "poeticizzata": "poeticizzare",
    "poeticizzate": "poeticizzare",
    "poeticizzati": "poeticizzare",
    "poeticizzato": "poeticizzare",
    "poeticizzava": "poeticizzare",
    "poeticizzavamo": "poeticizzare",
    "poeticizzavan": "poeticizzare",
    "poeticizzavano": "poeticizzare",
    "poeticizzavate": "poeticizzare",
    "poeticizzavi": "poeticizzare",
    "poeticizzavo": "poeticizzare",
    "poeticizzerai": "poeticizzare",
    "poeticizzeran": "poeticizzare",
    "poeticizzeranno": "poeticizzare",
    "poeticizzerebbe": "poeticizzare",
    "poeticizzerebber": "poeticizzare",
    "poeticizzerebbero": "poeticizzare",
    "poeticizzerei": "poeticizzare",
    "poeticizzeremmo": "poeticizzare",
    "poeticizzeremo": "poeticizzare",
    "poeticizzereste": "poeticizzare",
    "poeticizzeresti": "poeticizzare",
    "poeticizzerete": "poeticizzare",
    "poeticizzerà": "poeticizzare",
    "poeticizzerò": "poeticizzare",
    "poeticizzi": "poeticizzare",
    "poeticizziamo": "poeticizzare",
    "poeticizziate": "poeticizzare",
    "poeticizzin": "poeticizzare",
    "poeticizzino": "poeticizzare",
    "poeticizzo": "poeticizzare",
    "poeticizzò": "poeticizzare",
    "poetin": "poetare",
    "poetino": "poetare",
    "poeto": "poetare",
    "poetò": "poetare",
    "poggerai": "poggiare",
    "poggeran": "poggiare",
    "poggeranno": "poggiare",
    "poggerebbe": "poggiare",
    "poggerebber": "poggiare",
    "poggerebbero": "poggiare",
    "poggerei": "poggiare",
    "poggeremmo": "poggiare",
    "poggeremo": "poggiare",
    "poggereste": "poggiare",
    "poggeresti": "poggiare",
    "poggerete": "poggiare",
    "poggerà": "poggiare",
    "poggerò": "poggiare",
    "poggi": "poggio",
    "poggia": "poggiare",
    "poggiai": "poggiare",
    "poggiammo": "poggiare",
    "poggiamo": "poggiare",
    "poggian": "poggiare",
    "poggiando": "poggiare",
    "poggiano": "poggiare",
    "poggiante": "poggiare",
    "poggianti": "poggiare",
    "poggiar": "poggiare",
    "poggiaron": "poggiare",
    "poggiarono": "poggiare",
    "poggiasse": "poggiare",
    "poggiasser": "poggiare",
    "poggiassero": "poggiare",
    "poggiassi": "poggiare",
    "poggiassimo": "poggiare",
    "poggiaste": "poggiare",
    "poggiasti": "poggiare",
    "poggiata": "poggiare",
    "poggiate": "poggiare",
    "poggiati": "poggiare",
    "poggiato": "poggiare",
    "poggiava": "poggiare",
    "poggiavamo": "poggiare",
    "poggiavan": "poggiare",
    "poggiavano": "poggiare",
    "poggiavate": "poggiare",
    "poggiavi": "poggiare",
    "poggiavo": "poggiare",
    "poggin": "poggiare",
    "poggino": "poggiare",
    "poggio": "poggiare",
    "poggiò": "poggiare",
    "pola": "polire",
    "polacca": "polacco",
    "polacche": "polacco",
    "polacchi": "polacco",
    "polan": "polire",
    "polano": "polire",
    "polari": "polare",
    "polarizza": "polarizzare",
    "polarizzai": "polarizzare",
    "polarizzammo": "polarizzare",
    "polarizzan": "polarizzare",
    "polarizzando": "polarizzare",
    "polarizzano": "polarizzare",
    "polarizzante": "polarizzare",
    "polarizzanti": "polarizzare",
    "polarizzar": "polarizzare",
    "polarizzaron": "polarizzare",
    "polarizzarono": "polarizzare",
    "polarizzasse": "polarizzare",
    "polarizzasser": "polarizzare",
    "polarizzassero": "polarizzare",
    "polarizzassi": "polarizzare",
    "polarizzassimo": "polarizzare",
    "polarizzaste": "polarizzare",
    "polarizzasti": "polarizzare",
    "polarizzata": "polarizzato",
    "polarizzate": "polarizzato",
    "polarizzati": "polarizzato",
    "polarizzato": "polarizzare",
    "polarizzava": "polarizzare",
    "polarizzavamo": "polarizzare",
    "polarizzavan": "polarizzare",
    "polarizzavano": "polarizzare",
    "polarizzavate": "polarizzare",
    "polarizzavi": "polarizzare",
    "polarizzavo": "polarizzare",
    "polarizzazioni": "polarizzazione",
    "polarizzerai": "polarizzare",
    "polarizzeran": "polarizzare",
    "polarizzeranno": "polarizzare",
    "polarizzerebbe": "polarizzare",
    "polarizzerebber": "polarizzare",
    "polarizzerebbero": "polarizzare",
    "polarizzerei": "polarizzare",
    "polarizzeremmo": "polarizzare",
    "polarizzeremo": "polarizzare",
    "polarizzereste": "polarizzare",
    "polarizzeresti": "polarizzare",
    "polarizzerete": "polarizzare",
    "polarizzerà": "polarizzare",
    "polarizzerò": "polarizzare",
    "polarizzi": "polarizzare",
    "polarizziamo": "polarizzare",
    "polarizziate": "polarizzare",
    "polarizzin": "polarizzare",
    "polarizzino": "polarizzare",
    "polarizzo": "polarizzare",
    "polarizzò": "polarizzare",
    "pole": "polire",
    "polemica": "polemico",
    "polemiche": "polemico",
    "polemichette": "polemichetta",
    "polemici": "polemico",
    "polemisti": "polemista",
    "polemizza": "polemizzare",
    "polemizzai": "polemizzare",
    "polemizzammo": "polemizzare",
    "polemizzan": "polemizzare",
    "polemizzando": "polemizzare",
    "polemizzano": "polemizzare",
    "polemizzante": "polemizzare",
    "polemizzanti": "polemizzare",
    "polemizzar": "polemizzare",
    "polemizzaron": "polemizzare",
    "polemizzarono": "polemizzare",
    "polemizzasse": "polemizzare",
    "polemizzasser": "polemizzare",
    "polemizzassero": "polemizzare",
    "polemizzassi": "polemizzare",
    "polemizzassimo": "polemizzare",
    "polemizzaste": "polemizzare",
    "polemizzasti": "polemizzare",
    "polemizzata": "polemizzare",
    "polemizzate": "polemizzare",
    "polemizzati": "polemizzare",
    "polemizzato": "polemizzare",
    "polemizzava": "polemizzare",
    "polemizzavamo": "polemizzare",
    "polemizzavan": "polemizzare",
    "polemizzavano": "polemizzare",
    "polemizzavate": "polemizzare",
    "polemizzavi": "polemizzare",
    "polemizzavo": "polemizzare",
    "polemizzerai": "polemizzare",
    "polemizzeran": "polemizzare",
    "polemizzeranno": "polemizzare",
    "polemizzerebbe": "polemizzare",
    "polemizzerebber": "polemizzare",
    "polemizzerebbero": "polemizzare",
    "polemizzerei": "polemizzare",
    "polemizzeremmo": "polemizzare",
    "polemizzeremo": "polemizzare",
    "polemizzereste": "polemizzare",
    "polemizzeresti": "polemizzare",
    "polemizzerete": "polemizzare",
    "polemizzerà": "polemizzare",
    "polemizzerò": "polemizzare",
    "polemizzi": "polemizzare",
    "polemizziamo": "polemizzare",
    "polemizziate": "polemizzare",
    "polemizzin": "polemizzare",
    "polemizzino": "polemizzare",
    "polemizzo": "polemizzare",
    "polemizzò": "polemizzare",
    "polendo": "polire",
    "polente": "polire",
    "polenti": "polire",
    "poli": "polo",
    "poliambulatori": "poliambulatorio",
    "poliamo": "polire",
    "poliate": "polire",
    "policentrica": "policentrico",
    "policentriche": "policentrico",
    "policentrici": "policentrico",
    "policlinici": "policlinico",
    "policroma": "policromo",
    "policromai": "policromare",
    "policromammo": "policromare",
    "policroman": "policromare",
    "policromando": "policromare",
    "policromano": "policromare",
    "policromante": "policromare",
    "policromanti": "policromare",
    "policromar": "policromare",
    "policromaron": "policromare",
    "policromarono": "policromare",
    "policromasse": "policromare",
    "policromasser": "policromare",
    "policromassero": "policromare",
    "policromassi": "policromare",
    "policromassimo": "policromare",
    "policromaste": "policromare",
    "policromasti": "policromare",
    "policromata": "policromare",
    "policromate": "policromare",
    "policromati": "policromare",
    "policromatica": "policromatico",
    "policromatiche": "policromatico",
    "policromatici": "policromatico",
    "policromato": "policromare",
    "policromava": "policromare",
    "policromavamo": "policromare",
    "policromavan": "policromare",
    "policromavano": "policromare",
    "policromavate": "policromare",
    "policromavi": "policromare",
    "policromavo": "policromare",
    "policrome": "policromo",
    "policromerai": "policromare",
    "policromeran": "policromare",
    "policromeranno": "policromare",
    "policromerebbe": "policromare",
    "policromerebber": "policromare",
    "policromerebbero": "policromare",
    "policromerei": "policromare",
    "policromeremmo": "policromare",
    "policromeremo": "policromare",
    "policromereste": "policromare",
    "policromeresti": "policromare",
    "policromerete": "policromare",
    "policromerà": "policromare",
    "policromerò": "policromare",
    "policromi": "policromo",
    "policromiamo": "policromare",
    "policromiate": "policromare",
    "policromin": "policromare",
    "policromino": "policromare",
    "policromo": "policromare",
    "policromò": "policromare",
    "poliedrica": "poliedrico",
    "poliedriche": "poliedrico",
    "poliedrici": "poliedrico",
    "poliennali": "poliennale",
    "polietileni": "polietilene",
    "polifonica": "polifonico",
    "polifoniche": "polifonico",
    "polifonici": "polifonico",
    "polifonie": "polifonia",
    "poligama": "poligamo",
    "poligame": "poligamo",
    "poligami": "poligamo",
    "poligamie": "poligamia",
    "poliglotta": "poliglotto",
    "poliglotte": "poliglotto",
    "poliglotti": "poliglotto",
    "poligoni": "poligono",
    "poligrafica": "poligrafico",
    "poligrafiche": "poligrafico",
    "poligrafici": "poligrafico",
    "polii": "polire",
    "polimeri": "polimero",
    "polimerica": "polimerico",
    "polimeriche": "polimerico",
    "polimerici": "polimerico",
    "polimerizza": "polimerizzare",
    "polimerizzai": "polimerizzare",
    "polimerizzammo": "polimerizzare",
    "polimerizzan": "polimerizzare",
    "polimerizzando": "polimerizzare",
    "polimerizzano": "polimerizzare",
    "polimerizzante": "polimerizzare",
    "polimerizzanti": "polimerizzare",
    "polimerizzar": "polimerizzare",
    "polimerizzaron": "polimerizzare",
    "polimerizzarono": "polimerizzare",
    "polimerizzasse": "polimerizzare",
    "polimerizzasser": "polimerizzare",
    "polimerizzassero": "polimerizzare",
    "polimerizzassi": "polimerizzare",
    "polimerizzassimo": "polimerizzare",
    "polimerizzaste": "polimerizzare",
    "polimerizzasti": "polimerizzare",
    "polimerizzata": "polimerizzare",
    "polimerizzate": "polimerizzare",
    "polimerizzati": "polimerizzare",
    "polimerizzato": "polimerizzare",
    "polimerizzava": "polimerizzare",
    "polimerizzavamo": "polimerizzare",
    "polimerizzavan": "polimerizzare",
    "polimerizzavano": "polimerizzare",
    "polimerizzavate": "polimerizzare",
    "polimerizzavi": "polimerizzare",
    "polimerizzavo": "polimerizzare",
    "polimerizzerai": "polimerizzare",
    "polimerizzeran": "polimerizzare",
    "polimerizzeranno": "polimerizzare",
    "polimerizzerebbe": "polimerizzare",
    "polimerizzerebber": "polimerizzare",
    "polimerizzerebbero": "polimerizzare",
    "polimerizzerei": "polimerizzare",
    "polimerizzeremmo": "polimerizzare",
    "polimerizzeremo": "polimerizzare",
    "polimerizzereste": "polimerizzare",
    "polimerizzeresti": "polimerizzare",
    "polimerizzerete": "polimerizzare",
    "polimerizzerà": "polimerizzare",
    "polimerizzerò": "polimerizzare",
    "polimerizzi": "polimerizzare",
    "polimerizziamo": "polimerizzare",
    "polimerizziate": "polimerizzare",
    "polimerizzin": "polimerizzare",
    "polimerizzino": "polimerizzare",
    "polimerizzo": "polimerizzare",
    "polimerizzò": "polimerizzare",
    "polimmo": "polire",
    "polimorfa": "polimorfo",
    "polimorfe": "polimorfo",
    "polimorfi": "polimorfo",
    "poliomieliti": "poliomielite",
    "poliomielitica": "poliomielitico",
    "poliomielitiche": "poliomielitico",
    "poliomielitici": "poliomielitico",
    "polipi": "polipo",
    "polipropileni": "polipropilene",
    "polir": "polire",
    "polirai": "polire",
    "poliran": "polire",
    "poliranno": "polire",
    "polirebbe": "polire",
    "polirebber": "polire",
    "polirebbero": "polire",
    "polirei": "polire",
    "poliremmo": "polire",
    "poliremo": "polire",
    "polireste": "polire",
    "poliresti": "polire",
    "polirete": "polire",
    "poliron": "polire",
    "polirono": "polire",
    "polirà": "polire",
    "polirò": "polire",
    "polisportiva": "polisportivo",
    "polisportive": "polisportivo",
    "polisportivi": "polisportivo",
    "polisse": "polire",
    "polisser": "polire",
    "polissero": "polire",
    "polissi": "polire",
    "polissimo": "polire",
    "poliste": "polista",
    "polisti": "polista",
    "polistiroli": "polistirolo",
    "polita": "polire",
    "polite": "polire",
    "politecnici": "politecnico",
    "politeiste": "politeista",
    "politeisti": "politeista",
    "politi": "polire",
    "politica": "politico",
    "politicanti": "politicante",
    "politiche": "politico",
    "politichesi": "politichese",
    "politici": "politico",
    "politicizza": "politicizzare",
    "politicizzai": "politicizzare",
    "politicizzammo": "politicizzare",
    "politicizzan": "politicizzare",
    "politicizzando": "politicizzare",
    "politicizzano": "politicizzare",
    "politicizzante": "politicizzare",
    "politicizzanti": "politicizzare",
    "politicizzar": "politicizzare",
    "politicizzaron": "politicizzare",
    "politicizzarono": "politicizzare",
    "politicizzasse": "politicizzare",
    "politicizzasser": "politicizzare",
    "politicizzassero": "politicizzare",
    "politicizzassi": "politicizzare",
    "politicizzassimo": "politicizzare",
    "politicizzaste": "politicizzare",
    "politicizzasti": "politicizzare",
    "politicizzata": "politicizzato",
    "politicizzate": "politicizzato",
    "politicizzati": "politicizzato",
    "politicizzato": "politicizzare",
    "politicizzava": "politicizzare",
    "politicizzavamo": "politicizzare",
    "politicizzavan": "politicizzare",
    "politicizzavano": "politicizzare",
    "politicizzavate": "politicizzare",
    "politicizzavi": "politicizzare",
    "politicizzavo": "politicizzare",
    "politicizzazioni": "politicizzazione",
    "politicizzerai": "politicizzare",
    "politicizzeran": "politicizzare",
    "politicizzeranno": "politicizzare",
    "politicizzerebbe": "politicizzare",
    "politicizzerebber": "politicizzare",
    "politicizzerebbero": "politicizzare",
    "politicizzerei": "politicizzare",
    "politicizzeremmo": "politicizzare",
    "politicizzeremo": "politicizzare",
    "politicizzereste": "politicizzare",
    "politicizzeresti": "politicizzare",
    "politicizzerete": "politicizzare",
    "politicizzerà": "politicizzare",
    "politicizzerò": "politicizzare",
    "politicizzi": "politicizzare",
    "politicizziamo": "politicizzare",
    "politicizziate": "politicizzare",
    "politicizzin": "politicizzare",
    "politicizzino": "politicizzare",
    "politicizzo": "politicizzare",
    "politicizzò": "politicizzare",
    "politico-amministrativa": "politico-amministrativo",
    "politico-amministrative": "politico-amministrativo",
    "politico-amministrativi": "politico-amministrativo",
    "politico-culturali": "politico-culturale",
    "politico-diplomatica": "politico-diplomatico",
    "politico-diplomatiche": "politico-diplomatico",
    "politico-diplomatici": "politico-diplomatico",
    "politico-economica": "politico-economico",
    "politico-economiche": "politico-economico",
    "politico-economici": "politico-economico",
    "politico-ideologica": "politico-ideologico",
    "politico-ideologiche": "politico-ideologico",
    "politico-ideologici": "politico-ideologico",
    "politico-istituzionali": "politico-istituzionale",
    "politico-mafiosa": "politico-mafioso",
    "politico-mafiose": "politico-mafioso",
    "politico-mafiosi": "politico-mafioso",
    "politico-militari": "politico-militare",
    "politico-parlamentari": "politico-parlamentare",
    "politico-propagandistica": "politico-propagandistico",
    "politico-propagandistiche": "politico-propagandistico",
    "politico-propagandistici": "politico-propagandistico",
    "politico-scientifica": "politico-scientifico",
    "politico-scientifiche": "politico-scientifico",
    "politico-scientifici": "politico-scientifico",
    "politico-sociali": "politico-sociale",
    "polito": "polire",
    "politologi": "politologo",
    "politologie": "politologia",
    "polittica": "polittico",
    "polittiche": "polittico",
    "polittici": "polittico",
    "poliuretani": "poliuretano",
    "poliva": "polire",
    "polivalenti": "polivalente",
    "polivamo": "polire",
    "polivan": "polire",
    "polivano": "polire",
    "polivate": "polire",
    "polivi": "polire",
    "polivo": "polire",
    "poliziana": "poliziano",
    "poliziane": "poliziano",
    "poliziani": "poliziano",
    "polizie": "polizia",
    "poliziesca": "poliziesco",
    "poliziesche": "poliziesco",
    "polizieschi": "poliziesco",
    "poliziotta": "poliziotto",
    "poliziotte": "poliziotto",
    "poliziotti": "poliziotto",
    "polizze": "polizza",
    "polke": "polka",
    "polla": "pollare",
    "pollai": "pollare",
    "pollami": "pollame",
    "pollammo": "pollare",
    "pollan": "pollare",
    "pollando": "pollare",
    "pollano": "pollare",
    "pollante": "pollare",
    "pollanti": "pollare",
    "pollar": "pollare",
    "pollaron": "pollare",
    "pollarono": "pollare",
    "pollasse": "pollare",
    "pollasser": "pollare",
    "pollassero": "pollare",
    "pollassi": "pollare",
    "pollassimo": "pollare",
    "pollaste": "pollare",
    "pollasti": "pollare",
    "pollastri": "pollastro",
    "pollata": "pollare",
    "pollate": "pollare",
    "pollati": "pollare",
    "pollato": "pollare",
    "pollava": "pollare",
    "pollavamo": "pollare",
    "pollavan": "pollare",
    "pollavano": "pollare",
    "pollavate": "pollare",
    "pollavi": "pollare",
    "pollavo": "pollare",
    "pollerai": "pollare",
    "polleran": "pollare",
    "polleranno": "pollare",
    "pollerebbe": "pollare",
    "pollerebber": "pollare",
    "pollerebbero": "pollare",
    "pollerei": "pollare",
    "polleremmo": "pollare",
    "polleremo": "pollare",
    "pollereste": "pollare",
    "polleresti": "pollare",
    "pollerete": "pollare",
    "pollerà": "pollare",
    "pollerò": "pollare",
    "polli": "pollo",
    "polliamo": "pollare",
    "polliate": "pollare",
    "pollici": "pollice",
    "pollin": "pollare",
    "pollina": "pollino",
    "polline": "pollino",
    "pollini": "pollino",
    "pollino": "pollare",
    "pollo": "pollare",
    "polluzioni": "polluzione",
    "pollò": "pollare",
    "polmona": "polmonare",
    "polmonai": "polmonare",
    "polmonammo": "polmonare",
    "polmonan": "polmonare",
    "polmonando": "polmonare",
    "polmonano": "polmonare",
    "polmonante": "polmonare",
    "polmonanti": "polmonare",
    "polmonar": "polmonare",
    "polmonari": "polmonare",
    "polmonaron": "polmonare",
    "polmonarono": "polmonare",
    "polmonasse": "polmonare",
    "polmonasser": "polmonare",
    "polmonassero": "polmonare",
    "polmonassi": "polmonare",
    "polmonassimo": "polmonare",
    "polmonaste": "polmonare",
    "polmonasti": "polmonare",
    "polmonata": "polmonare",
    "polmonate": "polmonare",
    "polmonati": "polmonare",
    "polmonato": "polmonare",
    "polmonava": "polmonare",
    "polmonavamo": "polmonare",
    "polmonavan": "polmonare",
    "polmonavano": "polmonare",
    "polmonavate": "polmonare",
    "polmonavi": "polmonare",
    "polmonavo": "polmonare",
    "polmonerai": "polmonare",
    "polmoneran": "polmonare",
    "polmoneranno": "polmonare",
    "polmonerebbe": "polmonare",
    "polmonerebber": "polmonare",
    "polmonerebbero": "polmonare",
    "polmonerei": "polmonare",
    "polmoneremmo": "polmonare",
    "polmoneremo": "polmonare",
    "polmonereste": "polmonare",
    "polmoneresti": "polmonare",
    "polmonerete": "polmonare",
    "polmonerà": "polmonare",
    "polmonerò": "polmonare",
    "polmoni": "polmone",
    "polmoniamo": "polmonare",
    "polmoniate": "polmonare",
    "polmonin": "polmonare",
    "polmonino": "polmonare",
    "polmoniti": "polmonite",
    "polmono": "polmonare",
    "polmonò": "polmonare",
    "polo": "polire",
    "polon": "polire",
    "polono": "polire",
    "polpacci": "polpaccio",
    "polpastrelli": "polpastrello",
    "polpe": "polpa",
    "polpette": "polpetta",
    "polpettoni": "polpettone",
    "polpi": "polpo",
    "polposa": "polposo",
    "polpose": "polposo",
    "polposi": "polposo",
    "polputa": "polputo",
    "polpute": "polputo",
    "polputi": "polputo",
    "polsi": "polso",
    "polsini": "polsino",
    "poltiglie": "poltiglia",
    "poltra": "poltrire",
    "poltran": "poltrire",
    "poltrano": "poltrire",
    "poltre": "poltrire",
    "poltrendo": "poltrire",
    "poltrente": "poltrire",
    "poltrenti": "poltrire",
    "poltri": "poltrire",
    "poltriamo": "poltrire",
    "poltriate": "poltrire",
    "poltrii": "poltrire",
    "poltrimmo": "poltrire",
    "poltrir": "poltrire",
    "poltrirai": "poltrire",
    "poltriran": "poltrire",
    "poltriranno": "poltrire",
    "poltrirebbe": "poltrire",
    "poltrirebber": "poltrire",
    "poltrirebbero": "poltrire",
    "poltrirei": "poltrire",
    "poltriremmo": "poltrire",
    "poltriremo": "poltrire",
    "poltrireste": "poltrire",
    "poltriresti": "poltrire",
    "poltrirete": "poltrire",
    "poltriron": "poltrire",
    "poltrirono": "poltrire",
    "poltrirà": "poltrire",
    "poltrirò": "poltrire",
    "poltrisse": "poltrire",
    "poltrisser": "poltrire",
    "poltrissero": "poltrire",
    "poltrissi": "poltrire",
    "poltrissimo": "poltrire",
    "poltriste": "poltrire",
    "poltristi": "poltrire",
    "poltrita": "poltrire",
    "poltrite": "poltrire",
    "poltriti": "poltrire",
    "poltrito": "poltrire",
    "poltriva": "poltrire",
    "poltrivamo": "poltrire",
    "poltrivan": "poltrire",
    "poltrivano": "poltrire",
    "poltrivate": "poltrire",
    "poltrivi": "poltrire",
    "poltrivo": "poltrire",
    "poltro": "poltrire",
    "poltron": "poltrire",
    "poltroncine": "poltroncina",
    "poltrone": "poltrona",
    "poltroni": "poltrone",
    "poltrono": "poltrire",
    "poltrì": "poltrire",
    "polveri": "polvere",
    "polveriere": "polveriera",
    "polverine": "polverina",
    "polverizza": "polverizzare",
    "polverizzai": "polverizzare",
    "polverizzammo": "polverizzare",
    "polverizzan": "polverizzare",
    "polverizzando": "polverizzare",
    "polverizzano": "polverizzare",
    "polverizzante": "polverizzare",
    "polverizzanti": "polverizzare",
    "polverizzar": "polverizzare",
    "polverizzaron": "polverizzare",
    "polverizzarono": "polverizzare",
    "polverizzasse": "polverizzare",
    "polverizzasser": "polverizzare",
    "polverizzassero": "polverizzare",
    "polverizzassi": "polverizzare",
    "polverizzassimo": "polverizzare",
    "polverizzaste": "polverizzare",
    "polverizzasti": "polverizzare",
    "polverizzata": "polverizzare",
    "polverizzate": "polverizzare",
    "polverizzati": "polverizzare",
    "polverizzato": "polverizzare",
    "polverizzava": "polverizzare",
    "polverizzavamo": "polverizzare",
    "polverizzavan": "polverizzare",
    "polverizzavano": "polverizzare",
    "polverizzavate": "polverizzare",
    "polverizzavi": "polverizzare",
    "polverizzavo": "polverizzare",
    "polverizzazioni": "polverizzazione",
    "polverizzerai": "polverizzare",
    "polverizzeran": "polverizzare",
    "polverizzeranno": "polverizzare",
    "polverizzerebbe": "polverizzare",
    "polverizzerebber": "polverizzare",
    "polverizzerebbero": "polverizzare",
    "polverizzerei": "polverizzare",
    "polverizzeremmo": "polverizzare",
    "polverizzeremo": "polverizzare",
    "polverizzereste": "polverizzare",
    "polverizzeresti": "polverizzare",
    "polverizzerete": "polverizzare",
    "polverizzerà": "polverizzare",
    "polverizzerò": "polverizzare",
    "polverizzi": "polverizzare",
    "polverizziamo": "polverizzare",
    "polverizziate": "polverizzare",
    "polverizzin": "polverizzare",
    "polverizzino": "polverizzare",
    "polverizzo": "polverizzare",
    "polverizzò": "polverizzare",
    "polveroni": "polverone",
    "polverosa": "polveroso",
    "polverose": "polveroso",
    "polverosi": "polveroso",
    "polì": "polire",
    "pomate": "pomata",
    "pomellata": "pomellato",
    "pomellate": "pomellato",
    "pomellati": "pomellato",
    "pomelli": "pomello",
    "pomeridiana": "pomeridiano",
    "pomeridiane": "pomeridiano",
    "pomeridiani": "pomeridiano",
    "pomeriggi": "pomeriggio",
    "pomi": "pomo",
    "pomicerai": "pomiciare",
    "pomiceran": "pomiciare",
    "pomiceranno": "pomiciare",
    "pomicerebbe": "pomiciare",
    "pomicerebber": "pomiciare",
    "pomicerebbero": "pomiciare",
    "pomicerei": "pomiciare",
    "pomiceremmo": "pomiciare",
    "pomiceremo": "pomiciare",
    "pomicereste": "pomiciare",
    "pomiceresti": "pomiciare",
    "pomicerete": "pomiciare",
    "pomicerà": "pomiciare",
    "pomicerò": "pomiciare",
    "pomici": "pomiciare",
    "pomicia": "pomiciare",
    "pomiciai": "pomiciare",
    "pomiciammo": "pomiciare",
    "pomiciamo": "pomiciare",
    "pomician": "pomiciare",
    "pomiciando": "pomiciare",
    "pomiciano": "pomiciare",
    "pomiciante": "pomiciare",
    "pomicianti": "pomiciare",
    "pomiciar": "pomiciare",
    "pomiciaron": "pomiciare",
    "pomiciarono": "pomiciare",
    "pomiciasse": "pomiciare",
    "pomiciasser": "pomiciare",
    "pomiciassero": "pomiciare",
    "pomiciassi": "pomiciare",
    "pomiciassimo": "pomiciare",
    "pomiciaste": "pomiciare",
    "pomiciasti": "pomiciare",
    "pomiciata": "pomiciare",
    "pomiciate": "pomiciare",
    "pomiciati": "pomiciare",
    "pomiciato": "pomiciare",
    "pomiciava": "pomiciare",
    "pomiciavamo": "pomiciare",
    "pomiciavan": "pomiciare",
    "pomiciavano": "pomiciare",
    "pomiciavate": "pomiciare",
    "pomiciavi": "pomiciare",
    "pomiciavo": "pomiciare",
    "pomicin": "pomiciare",
    "pomicino": "pomiciare",
    "pomicio": "pomiciare",
    "pomiciò": "pomiciare",
    "pomodori": "pomodoro",
    "pompa": "pompare",
    "pompai": "pompare",
    "pompammo": "pompare",
    "pompan": "pompare",
    "pompando": "pompare",
    "pompano": "pompare",
    "pompante": "pompare",
    "pompanti": "pompare",
    "pompar": "pompare",
    "pomparon": "pompare",
    "pomparono": "pompare",
    "pompasse": "pompare",
    "pompasser": "pompare",
    "pompassero": "pompare",
    "pompassi": "pompare",
    "pompassimo": "pompare",
    "pompaste": "pompare",
    "pompasti": "pompare",
    "pompata": "pompare",
    "pompate": "pompare",
    "pompati": "pompare",
    "pompato": "pompare",
    "pompava": "pompare",
    "pompavamo": "pompare",
    "pompavan": "pompare",
    "pompavano": "pompare",
    "pompavate": "pompare",
    "pompavi": "pompare",
    "pompavo": "pompare",
    "pompe": "pompa",
    "pompelmi": "pompelmo",
    "pomperai": "pompare",
    "pomperan": "pompare",
    "pomperanno": "pompare",
    "pomperebbe": "pompare",
    "pomperebber": "pompare",
    "pomperebbero": "pompare",
    "pomperei": "pompare",
    "pomperemmo": "pompare",
    "pomperemo": "pompare",
    "pompereste": "pompare",
    "pomperesti": "pompare",
    "pomperete": "pompare",
    "pomperà": "pompare",
    "pomperò": "pompare",
    "pompi": "pompare",
    "pompiamo": "pompare",
    "pompiate": "pompare",
    "pompieri": "pompiere",
    "pompin": "pompare",
    "pompino": "pompare",
    "pompo": "pompare",
    "pomposa": "pomposo",
    "pompose": "pomposo",
    "pomposi": "pomposo",
    "pompò": "pompare",
    "pondera": "ponderare",
    "ponderai": "ponderare",
    "ponderammo": "ponderare",
    "ponderan": "ponderare",
    "ponderando": "ponderare",
    "ponderano": "ponderare",
    "ponderante": "ponderare",
    "ponderanti": "ponderare",
    "ponderar": "ponderare",
    "ponderaron": "ponderare",
    "ponderarono": "ponderare",
    "ponderasse": "ponderare",
    "ponderasser": "ponderare",
    "ponderassero": "ponderare",
    "ponderassi": "ponderare",
    "ponderassimo": "ponderare",
    "ponderaste": "ponderare",
    "ponderasti": "ponderare",
    "ponderata": "ponderato",
    "ponderate": "ponderato",
    "ponderati": "ponderato",
    "ponderato": "ponderare",
    "ponderava": "ponderare",
    "ponderavamo": "ponderare",
    "ponderavan": "ponderare",
    "ponderavano": "ponderare",
    "ponderavate": "ponderare",
    "ponderavi": "ponderare",
    "ponderavo": "ponderare",
    "ponderazioni": "ponderazione",
    "pondererai": "ponderare",
    "pondereran": "ponderare",
    "pondereranno": "ponderare",
    "pondererebbe": "ponderare",
    "pondererebber": "ponderare",
    "pondererebbero": "ponderare",
    "pondererei": "ponderare",
    "pondereremmo": "ponderare",
    "pondereremo": "ponderare",
    "ponderereste": "ponderare",
    "pondereresti": "ponderare",
    "pondererete": "ponderare",
    "pondererà": "ponderare",
    "pondererò": "ponderare",
    "ponderi": "ponderare",
    "ponderiamo": "ponderare",
    "ponderiate": "ponderare",
    "ponderin": "ponderare",
    "ponderino": "ponderare",
    "pondero": "ponderare",
    "ponderosa": "ponderoso",
    "ponderose": "ponderoso",
    "ponderosi": "ponderoso",
    "ponderò": "ponderare",
    "pone": "porre",
    "ponemmo": "porre",
    "ponendo": "porre",
    "ponente": "porre",
    "ponenti": "porre",
    "ponesse": "porre",
    "ponesser": "porre",
    "ponessero": "porre",
    "ponessi": "porre",
    "ponessimo": "porre",
    "poneste": "porre",
    "ponesti": "porre",
    "ponete": "porre",
    "poneva": "porre",
    "ponevamo": "porre",
    "ponevan": "porre",
    "ponevano": "porre",
    "ponevate": "porre",
    "ponevi": "porre",
    "ponevo": "porre",
    "ponga": "porre",
    "pongan": "porre",
    "pongano": "porre",
    "pongo": "porre",
    "pongon": "porre",
    "pongono": "porre",
    "poni": "porre",
    "poniamo": "porre",
    "poniate": "porre",
    "pontefici": "pontefice",
    "ponteggi": "ponteggio",
    "ponti": "ponte",
    "ponticelli": "ponticello",
    "pontieri": "pontiere",
    "pontifica": "pontificare",
    "pontificai": "pontificare",
    "pontificali": "pontificale",
    "pontificammo": "pontificare",
    "pontifican": "pontificare",
    "pontificando": "pontificare",
    "pontificano": "pontificare",
    "pontificante": "pontificare",
    "pontificanti": "pontificare",
    "pontificar": "pontificare",
    "pontificaron": "pontificare",
    "pontificarono": "pontificare",
    "pontificasse": "pontificare",
    "pontificasser": "pontificare",
    "pontificassero": "pontificare",
    "pontificassi": "pontificare",
    "pontificassimo": "pontificare",
    "pontificaste": "pontificare",
    "pontificasti": "pontificare",
    "pontificata": "pontificare",
    "pontificate": "pontificare",
    "pontificati": "pontificato",
    "pontificato": "pontificare",
    "pontificava": "pontificare",
    "pontificavamo": "pontificare",
    "pontificavan": "pontificare",
    "pontificavano": "pontificare",
    "pontificavate": "pontificare",
    "pontificavi": "pontificare",
    "pontificavo": "pontificare",
    "pontifice": "pontificio",
    "pontificherai": "pontificare",
    "pontificheran": "pontificare",
    "pontificheranno": "pontificare",
    "pontificherebbe": "pontificare",
    "pontificherebber": "pontificare",
    "pontificherebbero": "pontificare",
    "pontificherei": "pontificare",
    "pontificheremmo": "pontificare",
    "pontificheremo": "pontificare",
    "pontifichereste": "pontificare",
    "pontificheresti": "pontificare",
    "pontificherete": "pontificare",
    "pontificherà": "pontificare",
    "pontificherò": "pontificare",
    "pontifichi": "pontificare",
    "pontifichiamo": "pontificare",
    "pontifichiate": "pontificare",
    "pontifichin": "pontificare",
    "pontifichino": "pontificare",
    "pontifici": "pontificio",
    "pontificia": "pontificio",
    "pontifico": "pontificare",
    "pontificò": "pontificare",
    "pontili": "pontile",
    "pontoni": "pontone",
    "ponza": "ponzare",
    "ponzai": "ponzare",
    "ponzammo": "ponzare",
    "ponzan": "ponzare",
    "ponzando": "ponzare",
    "ponzano": "ponzare",
    "ponzante": "ponzare",
    "ponzanti": "ponzare",
    "ponzar": "ponzare",
    "ponzaron": "ponzare",
    "ponzarono": "ponzare",
    "ponzasse": "ponzare",
    "ponzasser": "ponzare",
    "ponzassero": "ponzare",
    "ponzassi": "ponzare",
    "ponzassimo": "ponzare",
    "ponzaste": "ponzare",
    "ponzasti": "ponzare",
    "ponzata": "ponzare",
    "ponzate": "ponzare",
    "ponzati": "ponzare",
    "ponzato": "ponzare",
    "ponzava": "ponzare",
    "ponzavamo": "ponzare",
    "ponzavan": "ponzare",
    "ponzavano": "ponzare",
    "ponzavate": "ponzare",
    "ponzavi": "ponzare",
    "ponzavo": "ponzare",
    "ponzerai": "ponzare",
    "ponzeran": "ponzare",
    "ponzeranno": "ponzare",
    "ponzerebbe": "ponzare",
    "ponzerebber": "ponzare",
    "ponzerebbero": "ponzare",
    "ponzerei": "ponzare",
    "ponzeremmo": "ponzare",
    "ponzeremo": "ponzare",
    "ponzereste": "ponzare",
    "ponzeresti": "ponzare",
    "ponzerete": "ponzare",
    "ponzerà": "ponzare",
    "ponzerò": "ponzare",
    "ponzi": "ponzare",
    "ponziamo": "ponzare",
    "ponziate": "ponzare",
    "ponzin": "ponzare",
    "ponzino": "ponzare",
    "ponzo": "ponzare",
    "ponzò": "ponzare",
    "popola": "popolare",
    "popolai": "popolare",
    "popolammo": "popolare",
    "popolan": "popolare",
    "popolana": "popolano",
    "popolando": "popolare",
    "popolane": "popolano",
    "popolani": "popolano",
    "popolano": "popolare",
    "popolante": "popolare",
    "popolanti": "popolare",
    "popolar": "popolare",
    "popolaresca": "popolaresco",
    "popolaresche": "popolaresco",
    "popolareschi": "popolaresco",
    "popolari": "popolare",
    "popolarismi": "popolarismo",
    "popolarizza": "popolarizzare",
    "popolarizzai": "popolarizzare",
    "popolarizzammo": "popolarizzare",
    "popolarizzan": "popolarizzare",
    "popolarizzando": "popolarizzare",
    "popolarizzano": "popolarizzare",
    "popolarizzante": "popolarizzare",
    "popolarizzanti": "popolarizzare",
    "popolarizzar": "popolarizzare",
    "popolarizzaron": "popolarizzare",
    "popolarizzarono": "popolarizzare",
    "popolarizzasse": "popolarizzare",
    "popolarizzasser": "popolarizzare",
    "popolarizzassero": "popolarizzare",
    "popolarizzassi": "popolarizzare",
    "popolarizzassimo": "popolarizzare",
    "popolarizzaste": "popolarizzare",
    "popolarizzasti": "popolarizzare",
    "popolarizzata": "popolarizzare",
    "popolarizzate": "popolarizzare",
    "popolarizzati": "popolarizzare",
    "popolarizzato": "popolarizzare",
    "popolarizzava": "popolarizzare",
    "popolarizzavamo": "popolarizzare",
    "popolarizzavan": "popolarizzare",
    "popolarizzavano": "popolarizzare",
    "popolarizzavate": "popolarizzare",
    "popolarizzavi": "popolarizzare",
    "popolarizzavo": "popolarizzare",
    "popolarizzerai": "popolarizzare",
    "popolarizzeran": "popolarizzare",
    "popolarizzeranno": "popolarizzare",
    "popolarizzerebbe": "popolarizzare",
    "popolarizzerebber": "popolarizzare",
    "popolarizzerebbero": "popolarizzare",
    "popolarizzerei": "popolarizzare",
    "popolarizzeremmo": "popolarizzare",
    "popolarizzeremo": "popolarizzare",
    "popolarizzereste": "popolarizzare",
    "popolarizzeresti": "popolarizzare",
    "popolarizzerete": "popolarizzare",
    "popolarizzerà": "popolarizzare",
    "popolarizzerò": "popolarizzare",
    "popolarizzi": "popolarizzare",
    "popolarizziamo": "popolarizzare",
    "popolarizziate": "popolarizzare",
    "popolarizzin": "popolarizzare",
    "popolarizzino": "popolarizzare",
    "popolarizzo": "popolarizzare",
    "popolarizzò": "popolarizzare",
    "popolaron": "popolare",
    "popolarono": "popolare",
    "popolasse": "popolare",
    "popolasser": "popolare",
    "popolassero": "popolare",
    "popolassi": "popolare",
    "popolassimo": "popolare",
    "popolaste": "popolare",
    "popolasti": "popolare",
    "popolata": "popolare",
    "popolate": "popolare",
    "popolati": "popolare",
    "popolato": "popolare",
    "popolava": "popolare",
    "popolavamo": "popolare",
    "popolavan": "popolare",
    "popolavano": "popolare",
    "popolavate": "popolare",
    "popolavi": "popolare",
    "popolavo": "popolare",
    "popolazioni": "popolazione",
    "popolerai": "popolare",
    "popoleran": "popolare",
    "popoleranno": "popolare",
    "popolerebbe": "popolare",
    "popolerebber": "popolare",
    "popolerebbero": "popolare",
    "popolerei": "popolare",
    "popoleremmo": "popolare",
    "popoleremo": "popolare",
    "popolereste": "popolare",
    "popoleresti": "popolare",
    "popolerete": "popolare",
    "popolerà": "popolare",
    "popolerò": "popolare",
    "popoli": "popolo",
    "popoliamo": "popolare",
    "popoliate": "popolare",
    "popolin": "popolare",
    "popolini": "popolino",
    "popolino": "popolare",
    "popolo": "popolare",
    "popolosa": "popoloso",
    "popolose": "popoloso",
    "popolosi": "popoloso",
    "popolò": "popolare",
    "poppa": "poppare",
    "poppai": "poppare",
    "poppammo": "poppare",
    "poppan": "poppare",
    "poppando": "poppare",
    "poppano": "poppare",
    "poppante": "poppare",
    "poppanti": "poppare",
    "poppar": "poppare",
    "popparon": "poppare",
    "popparono": "poppare",
    "poppasse": "poppare",
    "poppasser": "poppare",
    "poppassero": "poppare",
    "poppassi": "poppare",
    "poppassimo": "poppare",
    "poppaste": "poppare",
    "poppasti": "poppare",
    "poppata": "poppare",
    "poppate": "poppata",
    "poppati": "poppare",
    "poppato": "poppare",
    "poppava": "poppare",
    "poppavamo": "poppare",
    "poppavan": "poppare",
    "poppavano": "poppare",
    "poppavate": "poppare",
    "poppavi": "poppare",
    "poppavo": "poppare",
    "poppe": "poppa",
    "popperai": "poppare",
    "popperan": "poppare",
    "popperanno": "poppare",
    "popperebbe": "poppare",
    "popperebber": "poppare",
    "popperebbero": "poppare",
    "popperei": "poppare",
    "popperemmo": "poppare",
    "popperemo": "poppare",
    "poppereste": "poppare",
    "popperesti": "poppare",
    "popperete": "poppare",
    "popperà": "poppare",
    "popperò": "poppare",
    "poppi": "poppare",
    "poppiamo": "poppare",
    "poppiate": "poppare",
    "poppin": "poppare",
    "poppino": "poppare",
    "poppo": "poppare",
    "poppò": "poppare",
    "populismi": "populismo",
    "populisti": "populista",
    "populistica": "populistico",
    "populistiche": "populistico",
    "populistici": "populistico",
    "porca": "porco",
    "porcellanata": "porcellanato",
    "porcellanate": "porcellanato",
    "porcellanati": "porcellanato",
    "porcellane": "porcellana",
    "porcelli": "porcello",
    "porcellini": "porcellino",
    "porche": "porco",
    "porcherie": "porcheria",
    "porchi": "porco",
    "porci": "porco",
    "porcilaie": "porcilaia",
    "porcina": "porcino",
    "porcine": "porcino",
    "porcini": "porcino",
    "porcospini": "porcospino",
    "pordenonesi": "pordenonese",
    "porga": "porgere",
    "porgan": "porgere",
    "porgano": "porgere",
    "porge": "porgere",
    "porgemmo": "porgere",
    "porgendo": "porgere",
    "porgente": "porgere",
    "porgenti": "porgere",
    "porger": "porgere",
    "porgerai": "porgere",
    "porgeran": "porgere",
    "porgeranno": "porgere",
    "porgerebbe": "porgere",
    "porgerebber": "porgere",
    "porgerebbero": "porgere",
    "porgerei": "porgere",
    "porgeremmo": "porgere",
    "porgeremo": "porgere",
    "porgereste": "porgere",
    "porgeresti": "porgere",
    "porgerete": "porgere",
    "porgerà": "porgere",
    "porgerò": "porgere",
    "porgesse": "porgere",
    "porgesser": "porgere",
    "porgessero": "porgere",
    "porgessi": "porgere",
    "porgessimo": "porgere",
    "porgeste": "porgere",
    "porgesti": "porgere",
    "porgete": "porgere",
    "porgeva": "porgere",
    "porgevamo": "porgere",
    "porgevan": "porgere",
    "porgevano": "porgere",
    "porgevate": "porgere",
    "porgevi": "porgere",
    "porgevo": "porgere",
    "porgi": "porgere",
    "porgiamo": "porgere",
    "porgiate": "porgere",
    "porgo": "porgere",
    "porgon": "porgere",
    "porgono": "porgere",
    "pori": "poro",
    "porna": "porno",
    "porne": "porno",
    "porni": "porno",
    "pornocassette": "pornocassetta",
    "pornodive": "pornodiva",
    "pornografi": "pornografo",
    "pornografica": "pornografico",
    "pornografiche": "pornografico",
    "pornografici": "pornografico",
    "pornografie": "pornografia",
    "porosa": "poroso",
    "porose": "poroso",
    "porosi": "poroso",
    "porporata": "porporato",
    "porporate": "porporato",
    "porporati": "porporato",
    "porpore": "porpora",
    "porporina": "porporino",
    "porporine": "porporino",
    "porporini": "porporino",
    "porr": "porre",
    "porrai": "porre",
    "porran": "porre",
    "porranno": "porre",
    "porrebbe": "porre",
    "porrebber": "porre",
    "porrebbero": "porre",
    "porrei": "porre",
    "porremmo": "porre",
    "porremo": "porre",
    "porreste": "porre",
    "porresti": "porre",
    "porrete": "porre",
    "porri": "porro",
    "porrà": "porre",
    "porrò": "porre",
    "porser": "porgere",
    "porsero": "porgere",
    "porsi": "porgere",
    "porsè": "porgere",
    "porta": "porto",
    "portabili": "portabile",
    "portaceneri": "portacenere",
    "portafogli": "portafoglio",
    "portai": "portare",
    "portali": "portale",
    "portamenti": "portamento",
    "portammo": "portare",
    "portan": "portare",
    "portando": "portare",
    "portano": "portare",
    "portante": "portare",
    "portanti": "portare",
    "portantine": "portantina",
    "portantini": "portantino",
    "portar": "portare",
    "portaron": "portare",
    "portarono": "portare",
    "portasse": "portare",
    "portasser": "portare",
    "portassero": "portare",
    "portassi": "portare",
    "portassimo": "portare",
    "portaste": "portare",
    "portasti": "portare",
    "portata": "portato",
    "portate": "portato",
    "portati": "portato",
    "portatili": "portatile",
    "portato": "portare",
    "portatori": "portatore",
    "portatrici": "portatrice",
    "portava": "portare",
    "portavamo": "portare",
    "portavan": "portare",
    "portavano": "portare",
    "portavate": "portare",
    "portavi": "portare",
    "portavo": "portare",
    "porte": "porto",
    "portelli": "portello",
    "portelloni": "portellone",
    "portenti": "portento",
    "portentosa": "portentoso",
    "portentose": "portentoso",
    "portentosi": "portentoso",
    "porterai": "portare",
    "porteran": "portare",
    "porteranno": "portare",
    "porterebbe": "portare",
    "porterebber": "portare",
    "porterebbero": "portare",
    "porterei": "portare",
    "porteremmo": "portare",
    "porteremo": "portare",
    "portereste": "portare",
    "porteresti": "portare",
    "porterete": "portare",
    "porterà": "portare",
    "porterò": "portare",
    "porti": "porto",
    "portiamo": "portare",
    "portiate": "portare",
    "porticata": "porticato",
    "porticate": "porticato",
    "porticati": "porticato",
    "porticcioli": "porticciolo",
    "portici": "portico",
    "porticine": "porticina",
    "portiere": "portiera",
    "portieri": "portiere",
    "portieroni": "portierone",
    "portin": "portare",
    "portinai": "portinaio",
    "portinaia": "portinaio",
    "portinaie": "portinaio",
    "portinerie": "portineria",
    "portino": "portare",
    "porto": "portare",
    "portoghesi": "portoghese",
    "portoncini": "portoncino",
    "portoni": "portone",
    "portoricani": "portoricano",
    "portuali": "portuale",
    "portuari": "portuario",
    "portuaria": "portuario",
    "portuarie": "portuario",
    "portò": "portare",
    "porzioni": "porzione",
    "posa": "posare",
    "posai": "posare",
    "posammo": "posare",
    "posan": "posare",
    "posando": "posare",
    "posano": "posare",
    "posante": "posare",
    "posanti": "posare",
    "posar": "posare",
    "posaron": "posare",
    "posarono": "posare",
    "posasse": "posare",
    "posasser": "posare",
    "posassero": "posare",
    "posassi": "posare",
    "posassimo": "posare",
    "posaste": "posare",
    "posasti": "posare",
    "posata": "posato",
    "posate": "posato",
    "posati": "posato",
    "posato": "posare",
    "posava": "posare",
    "posavamo": "posare",
    "posavan": "posare",
    "posavano": "posare",
    "posavate": "posare",
    "posavi": "posare",
    "posavo": "posare",
    "posdata": "posdatare",
    "posdatai": "posdatare",
    "posdatammo": "posdatare",
    "posdatan": "posdatare",
    "posdatando": "posdatare",
    "posdatano": "posdatare",
    "posdatante": "posdatare",
    "posdatanti": "posdatare",
    "posdatar": "posdatare",
    "posdataron": "posdatare",
    "posdatarono": "posdatare",
    "posdatasse": "posdatare",
    "posdatasser": "posdatare",
    "posdatassero": "posdatare",
    "posdatassi": "posdatare",
    "posdatassimo": "posdatare",
    "posdataste": "posdatare",
    "posdatasti": "posdatare",
    "posdatata": "posdatare",
    "posdatate": "posdatare",
    "posdatati": "posdatare",
    "posdatato": "posdatare",
    "posdatava": "posdatare",
    "posdatavamo": "posdatare",
    "posdatavan": "posdatare",
    "posdatavano": "posdatare",
    "posdatavate": "posdatare",
    "posdatavi": "posdatare",
    "posdatavo": "posdatare",
    "posdaterai": "posdatare",
    "posdateran": "posdatare",
    "posdateranno": "posdatare",
    "posdaterebbe": "posdatare",
    "posdaterebber": "posdatare",
    "posdaterebbero": "posdatare",
    "posdaterei": "posdatare",
    "posdateremmo": "posdatare",
    "posdateremo": "posdatare",
    "posdatereste": "posdatare",
    "posdateresti": "posdatare",
    "posdaterete": "posdatare",
    "posdaterà": "posdatare",
    "posdaterò": "posdatare",
    "posdati": "posdatare",
    "posdatiamo": "posdatare",
    "posdatiate": "posdatare",
    "posdatin": "posdatare",
    "posdatino": "posdatare",
    "posdato": "posdatare",
    "posdatò": "posdatare",
    "pose": "posa",
    "poser": "porre",
    "poserai": "posare",
    "poseran": "posare",
    "poseranno": "posare",
    "poserebbe": "posare",
    "poserebber": "posare",
    "poserebbero": "posare",
    "poserei": "posare",
    "poseremmo": "posare",
    "poseremo": "posare",
    "posereste": "posare",
    "poseresti": "posare",
    "poserete": "posare",
    "posero": "porre",
    "poserà": "posare",
    "poserò": "posare",
    "posi": "posare",
    "posiamo": "posare",
    "posiate": "posare",
    "posin": "posare",
    "posino": "posare",
    "positiva": "positivo",
    "positive": "positivo",
    "positivi": "positivo",
    "positivismi": "positivismo",
    "positiviste": "positivista",
    "positivisti": "positivista",
    "positure": "positura",
    "posiziona": "posizionare",
    "posizionai": "posizionare",
    "posizionamenti": "posizionamento",
    "posizionammo": "posizionare",
    "posizionan": "posizionare",
    "posizionando": "posizionare",
    "posizionano": "posizionare",
    "posizionante": "posizionare",
    "posizionanti": "posizionare",
    "posizionar": "posizionare",
    "posizionaron": "posizionare",
    "posizionarono": "posizionare",
    "posizionasse": "posizionare",
    "posizionasser": "posizionare",
    "posizionassero": "posizionare",
    "posizionassi": "posizionare",
    "posizionassimo": "posizionare",
    "posizionaste": "posizionare",
    "posizionasti": "posizionare",
    "posizionata": "posizionare",
    "posizionate": "posizionare",
    "posizionati": "posizionare",
    "posizionato": "posizionare",
    "posizionava": "posizionare",
    "posizionavamo": "posizionare",
    "posizionavan": "posizionare",
    "posizionavano": "posizionare",
    "posizionavate": "posizionare",
    "posizionavi": "posizionare",
    "posizionavo": "posizionare",
    "posizionerai": "posizionare",
    "posizioneran": "posizionare",
    "posizioneranno": "posizionare",
    "posizionerebbe": "posizionare",
    "posizionerebber": "posizionare",
    "posizionerebbero": "posizionare",
    "posizionerei": "posizionare",
    "posizioneremmo": "posizionare",
    "posizioneremo": "posizionare",
    "posizionereste": "posizionare",
    "posizioneresti": "posizionare",
    "posizionerete": "posizionare",
    "posizionerà": "posizionare",
    "posizionerò": "posizionare",
    "posizioni": "posizione",
    "posizioniamo": "posizionare",
    "posizioniate": "posizionare",
    "posizionin": "posizionare",
    "posizionino": "posizionare",
    "posiziono": "posizionare",
    "posizionò": "posizionare",
    "poso": "posare",
    "pospone": "posporre",
    "posponei": "posporre",
    "posponemmo": "posporre",
    "posponendo": "posporre",
    "posponente": "posporre",
    "posponenti": "posporre",
    "posponerai": "posporre",
    "posponeran": "posporre",
    "posponeranno": "posporre",
    "posponerebbe": "posporre",
    "posponerebber": "posporre",
    "posponerebbero": "posporre",
    "posponerei": "posporre",
    "posponeremmo": "posporre",
    "posponeremo": "posporre",
    "posponereste": "posporre",
    "posponeresti": "posporre",
    "posponerete": "posporre",
    "posponeron": "posporre",
    "posponerono": "posporre",
    "posponerà": "posporre",
    "posponerò": "posporre",
    "posponesse": "posporre",
    "posponesser": "posporre",
    "posponessero": "posporre",
    "posponessi": "posporre",
    "posponessimo": "posporre",
    "posponeste": "posporre",
    "posponesti": "posporre",
    "posponete": "posporre",
    "posponeva": "posporre",
    "posponevamo": "posporre",
    "posponevan": "posporre",
    "posponevano": "posporre",
    "posponevate": "posporre",
    "posponevi": "posporre",
    "posponevo": "posporre",
    "posponga": "posporre",
    "pospongan": "posporre",
    "pospongano": "posporre",
    "pospongo": "posporre",
    "pospongon": "posporre",
    "pospongono": "posporre",
    "posponi": "posporre",
    "posponiamo": "posporre",
    "posponiate": "posporre",
    "posponuta": "posporre",
    "posponute": "posporre",
    "posponuti": "posporre",
    "posponuto": "posporre",
    "posponè": "posporre",
    "posporr": "posporre",
    "possa": "potere",
    "possan": "potere",
    "possano": "potere",
    "possanze": "possanza",
    "possedano": "possedere",
    "possedei": "possedere",
    "possedemmo": "possedere",
    "posseder": "possedere",
    "possederai": "possedere",
    "possederanno": "possedere",
    "possederebbe": "possedere",
    "possederebbero": "possedere",
    "possederei": "possedere",
    "possederemmo": "possedere",
    "possederemo": "possedere",
    "possedereste": "possedere",
    "possederesti": "possedere",
    "possederete": "possedere",
    "possederon": "possedere",
    "possederono": "possedere",
    "possederà": "possedere",
    "possederò": "possedere",
    "possedesse": "possedere",
    "possedesser": "possedere",
    "possedessero": "possedere",
    "possedessi": "possedere",
    "possedessimo": "possedere",
    "possedeste": "possedere",
    "possedesti": "possedere",
    "possedete": "possedere",
    "possedeva": "possedere",
    "possedevamo": "possedere",
    "possedevano": "possedere",
    "possedevate": "possedere",
    "possedevi": "possedere",
    "possedevo": "possedere",
    "possediamo": "possedere",
    "possediate": "possedere",
    "possedimenti": "possedimento",
    "posseduta": "possedere",
    "possedute": "possedere",
    "posseduti": "possedere",
    "posseduto": "possedere",
    "possedè": "possedere",
    "possenti": "possente",
    "possessi": "possesso",
    "possessioni": "possessione",
    "possessiva": "possessivo",
    "possessive": "possessivo",
    "possessivi": "possessivo",
    "possessori": "possessorio",
    "possessoria": "possessorio",
    "possessorie": "possessorio",
    "possiamo": "potere",
    "possiate": "potere",
    "possibili": "possibile",
    "possibiliste": "possibilista",
    "possibilisti": "possibilista",
    "possidenti": "possidente",
    "possieda": "possedere",
    "possiede": "possedere",
    "possiedi": "possedere",
    "possiedo": "possedere",
    "possiedon": "possedere",
    "possiedono": "possedere",
    "posso": "potere",
    "posson": "potere",
    "possono": "potere",
    "post-bellica": "post-bellico",
    "post-belliche": "post-bellico",
    "post-bellici": "post-bellico",
    "post-comunismi": "post-comunismo",
    "post-comuniste": "post-comunista",
    "post-comunisti": "post-comunista",
    "post-elettorali": "post-elettorale",
    "post-fascisti": "post-fascista",
    "post-industriali": "post-industriale",
    "post-moderna": "post-moderno",
    "post-moderne": "post-moderno",
    "post-moderni": "post-moderno",
    "post-natalizi": "post-natalizio",
    "post-natalizia": "post-natalizio",
    "post-natalizie": "post-natalizio",
    "post-razziste": "post-razzista",
    "post-razzisti": "post-razzista",
    "post-rivoluzionari": "post-rivoluzionario",
    "post-rivoluzionaria": "post-rivoluzionario",
    "post-rivoluzionarie": "post-rivoluzionario",
    "posta": "posto",
    "postai": "postare",
    "postali": "postale",
    "postammo": "postare",
    "postan": "postare",
    "postando": "postare",
    "postano": "postare",
    "postante": "postare",
    "postanti": "postare",
    "postar": "postare",
    "postaron": "postare",
    "postarono": "postare",
    "postasse": "postare",
    "postasser": "postare",
    "postassero": "postare",
    "postassi": "postare",
    "postassimo": "postare",
    "postaste": "postare",
    "postasti": "postare",
    "postata": "postare",
    "postate": "postare",
    "postati": "postare",
    "postato": "postare",
    "postava": "postare",
    "postavamo": "postare",
    "postavan": "postare",
    "postavano": "postare",
    "postavate": "postare",
    "postavi": "postare",
    "postavo": "postare",
    "postazioni": "postazione",
    "postbellica": "postbellico",
    "postbelliche": "postbellico",
    "postbellici": "postbellico",
    "postcomunismi": "postcomunismo",
    "postcomuniste": "postcomunista",
    "postcomunisti": "postcomunista",
    "postconciliari": "postconciliare",
    "postdata": "postdatare",
    "postdatai": "postdatare",
    "postdatammo": "postdatare",
    "postdatan": "postdatare",
    "postdatando": "postdatare",
    "postdatano": "postdatare",
    "postdatante": "postdatare",
    "postdatanti": "postdatare",
    "postdatar": "postdatare",
    "postdataron": "postdatare",
    "postdatarono": "postdatare",
    "postdatasse": "postdatare",
    "postdatasser": "postdatare",
    "postdatassero": "postdatare",
    "postdatassi": "postdatare",
    "postdatassimo": "postdatare",
    "postdataste": "postdatare",
    "postdatasti": "postdatare",
    "postdatata": "postdatare",
    "postdatate": "postdatare",
    "postdatati": "postdatare",
    "postdatato": "postdatare",
    "postdatava": "postdatare",
    "postdatavamo": "postdatare",
    "postdatavan": "postdatare",
    "postdatavano": "postdatare",
    "postdatavate": "postdatare",
    "postdatavi": "postdatare",
    "postdatavo": "postdatare",
    "postdaterai": "postdatare",
    "postdateran": "postdatare",
    "postdateranno": "postdatare",
    "postdaterebbe": "postdatare",
    "postdaterebber": "postdatare",
    "postdaterebbero": "postdatare",
    "postdaterei": "postdatare",
    "postdateremmo": "postdatare",
    "postdateremo": "postdatare",
    "postdatereste": "postdatare",
    "postdateresti": "postdatare",
    "postdaterete": "postdatare",
    "postdaterà": "postdatare",
    "postdaterò": "postdatare",
    "postdati": "postdatare",
    "postdatiamo": "postdatare",
    "postdatiate": "postdatare",
    "postdatin": "postdatare",
    "postdatino": "postdatare",
    "postdato": "postdatare",
    "postdatò": "postdatare",
    "poste": "posto",
    "posteggerai": "posteggiare",
    "posteggeran": "posteggiare",
    "posteggeranno": "posteggiare",
    "posteggerebbe": "posteggiare",
    "posteggerebber": "posteggiare",
    "posteggerebbero": "posteggiare",
    "posteggerei": "posteggiare",
    "posteggeremmo": "posteggiare",
    "posteggeremo": "posteggiare",
    "posteggereste": "posteggiare",
    "posteggeresti": "posteggiare",
    "posteggerete": "posteggiare",
    "posteggerà": "posteggiare",
    "posteggerò": "posteggiare",
    "posteggi": "posteggio",
    "posteggia": "posteggiare",
    "posteggiai": "posteggiare",
    "posteggiammo": "posteggiare",
    "posteggiamo": "posteggiare",
    "posteggian": "posteggiare",
    "posteggiando": "posteggiare",
    "posteggiano": "posteggiare",
    "posteggiante": "posteggiare",
    "posteggianti": "posteggiare",
    "posteggiar": "posteggiare",
    "posteggiaron": "posteggiare",
    "posteggiarono": "posteggiare",
    "posteggiasse": "posteggiare",
    "posteggiasser": "posteggiare",
    "posteggiassero": "posteggiare",
    "posteggiassi": "posteggiare",
    "posteggiassimo": "posteggiare",
    "posteggiaste": "posteggiare",
    "posteggiasti": "posteggiare",
    "posteggiata": "posteggiare",
    "posteggiate": "posteggiare",
    "posteggiati": "posteggiare",
    "posteggiato": "posteggiare",
    "posteggiatori": "posteggiatore",
    "posteggiava": "posteggiare",
    "posteggiavamo": "posteggiare",
    "posteggiavan": "posteggiare",
    "posteggiavano": "posteggiare",
    "posteggiavate": "posteggiare",
    "posteggiavi": "posteggiare",
    "posteggiavo": "posteggiare",
    "posteggin": "posteggiare",
    "posteggino": "posteggiare",
    "posteggio": "posteggiare",
    "posteggiò": "posteggiare",
    "postelegrafonica": "postelegrafonico",
    "postelegrafoniche": "postelegrafonico",
    "postelegrafonici": "postelegrafonico",
    "posterai": "postare",
    "posteran": "postare",
    "posteranno": "postare",
    "posterebbe": "postare",
    "posterebber": "postare",
    "posterebbero": "postare",
    "posterei": "postare",
    "posteremmo": "postare",
    "posteremo": "postare",
    "postereste": "postare",
    "posteresti": "postare",
    "posterete": "postare",
    "posterga": "postergare",
    "postergai": "postergare",
    "postergammo": "postergare",
    "postergan": "postergare",
    "postergando": "postergare",
    "postergano": "postergare",
    "postergante": "postergare",
    "posterganti": "postergare",
    "postergar": "postergare",
    "postergaron": "postergare",
    "postergarono": "postergare",
    "postergasse": "postergare",
    "postergasser": "postergare",
    "postergassero": "postergare",
    "postergassi": "postergare",
    "postergassimo": "postergare",
    "postergaste": "postergare",
    "postergasti": "postergare",
    "postergata": "postergare",
    "postergate": "postergare",
    "postergati": "postergare",
    "postergato": "postergare",
    "postergava": "postergare",
    "postergavamo": "postergare",
    "postergavan": "postergare",
    "postergavano": "postergare",
    "postergavate": "postergare",
    "postergavi": "postergare",
    "postergavo": "postergare",
    "postergherai": "postergare",
    "postergheran": "postergare",
    "postergheranno": "postergare",
    "postergherebbe": "postergare",
    "postergherebber": "postergare",
    "postergherebbero": "postergare",
    "postergherei": "postergare",
    "postergheremmo": "postergare",
    "postergheremo": "postergare",
    "posterghereste": "postergare",
    "postergheresti": "postergare",
    "postergherete": "postergare",
    "postergherà": "postergare",
    "postergherò": "postergare",
    "posterghi": "postergare",
    "posterghiamo": "postergare",
    "posterghiate": "postergare",
    "posterghin": "postergare",
    "posterghino": "postergare",
    "postergo": "postergare",
    "postergò": "postergare",
    "posteri": "postero",
    "posteriori": "posteriore",
    "posterà": "postare",
    "posterò": "postare",
    "postfazioni": "postfazione",
    "posti": "posto",
    "posti-chiave": "posto-chiave",
    "postiamo": "postare",
    "postiate": "postare",
    "posticce": "posticcio",
    "posticci": "posticcio",
    "posticcia": "posticcio",
    "posticini": "posticino",
    "posticipa": "posticipare",
    "posticipai": "posticipare",
    "posticipammo": "posticipare",
    "posticipan": "posticipare",
    "posticipando": "posticipare",
    "posticipano": "posticipare",
    "posticipante": "posticipare",
    "posticipanti": "posticipare",
    "posticipar": "posticipare",
    "posticiparon": "posticipare",
    "posticiparono": "posticipare",
    "posticipasse": "posticipare",
    "posticipasser": "posticipare",
    "posticipassero": "posticipare",
    "posticipassi": "posticipare",
    "posticipassimo": "posticipare",
    "posticipaste": "posticipare",
    "posticipasti": "posticipare",
    "posticipata": "posticipare",
    "posticipate": "posticipare",
    "posticipati": "posticipare",
    "posticipato": "posticipare",
    "posticipava": "posticipare",
    "posticipavamo": "posticipare",
    "posticipavan": "posticipare",
    "posticipavano": "posticipare",
    "posticipavate": "posticipare",
    "posticipavi": "posticipare",
    "posticipavo": "posticipare",
    "posticiperai": "posticipare",
    "posticiperan": "posticipare",
    "posticiperanno": "posticipare",
    "posticiperebbe": "posticipare",
    "posticiperebber": "posticipare",
    "posticiperebbero": "posticipare",
    "posticiperei": "posticipare",
    "posticiperemmo": "posticipare",
    "posticiperemo": "posticipare",
    "posticipereste": "posticipare",
    "posticiperesti": "posticipare",
    "posticiperete": "posticipare",
    "posticiperà": "posticipare",
    "posticiperò": "posticipare",
    "posticipi": "posticipo",
    "posticipiamo": "posticipare",
    "posticipiate": "posticipare",
    "posticipin": "posticipare",
    "posticipino": "posticipare",
    "posticipo": "posticipare",
    "posticipò": "posticipare",
    "postilla": "postillare",
    "postillai": "postillare",
    "postillammo": "postillare",
    "postillan": "postillare",
    "postillando": "postillare",
    "postillano": "postillare",
    "postillante": "postillare",
    "postillanti": "postillare",
    "postillar": "postillare",
    "postillaron": "postillare",
    "postillarono": "postillare",
    "postillasse": "postillare",
    "postillasser": "postillare",
    "postillassero": "postillare",
    "postillassi": "postillare",
    "postillassimo": "postillare",
    "postillaste": "postillare",
    "postillasti": "postillare",
    "postillata": "postillare",
    "postillate": "postillare",
    "postillati": "postillare",
    "postillato": "postillare",
    "postillava": "postillare",
    "postillavamo": "postillare",
    "postillavan": "postillare",
    "postillavano": "postillare",
    "postillavate": "postillare",
    "postillavi": "postillare",
    "postillavo": "postillare",
    "postille": "postilla",
    "postillerai": "postillare",
    "postilleran": "postillare",
    "postilleranno": "postillare",
    "postillerebbe": "postillare",
    "postillerebber": "postillare",
    "postillerebbero": "postillare",
    "postillerei": "postillare",
    "postilleremmo": "postillare",
    "postilleremo": "postillare",
    "postillereste": "postillare",
    "postilleresti": "postillare",
    "postillerete": "postillare",
    "postillerà": "postillare",
    "postillerò": "postillare",
    "postilli": "postillare",
    "postilliamo": "postillare",
    "postilliate": "postillare",
    "postillin": "postillare",
    "postillino": "postillare",
    "postillo": "postillare",
    "postillò": "postillare",
    "postin": "postare",
    "postindustriali": "postindustriale",
    "postine": "postina",
    "postini": "postino",
    "postino": "postare",
    "postmissini": "postmissino",
    "postmoderna": "postmoderno",
    "postmoderne": "postmoderno",
    "postmoderni": "postmoderno",
    "posto": "postare",
    "postprandiali": "postprandiale",
    "postriboli": "postribolo",
    "postula": "postulare",
    "postulai": "postulare",
    "postulammo": "postulare",
    "postulan": "postulare",
    "postulando": "postulare",
    "postulano": "postulare",
    "postulante": "postulare",
    "postulanti": "postulare",
    "postular": "postulare",
    "postularon": "postulare",
    "postularono": "postulare",
    "postulasse": "postulare",
    "postulasser": "postulare",
    "postulassero": "postulare",
    "postulassi": "postulare",
    "postulassimo": "postulare",
    "postulaste": "postulare",
    "postulasti": "postulare",
    "postulata": "postulato",
    "postulate": "postulato",
    "postulati": "postulato",
    "postulato": "postulare",
    "postulava": "postulare",
    "postulavamo": "postulare",
    "postulavan": "postulare",
    "postulavano": "postulare",
    "postulavate": "postulare",
    "postulavi": "postulare",
    "postulavo": "postulare",
    "postulerai": "postulare",
    "postuleran": "postulare",
    "postuleranno": "postulare",
    "postulerebbe": "postulare",
    "postulerebber": "postulare",
    "postulerebbero": "postulare",
    "postulerei": "postulare",
    "postuleremmo": "postulare",
    "postuleremo": "postulare",
    "postulereste": "postulare",
    "postuleresti": "postulare",
    "postulerete": "postulare",
    "postulerà": "postulare",
    "postulerò": "postulare",
    "postuli": "postulare",
    "postuliamo": "postulare",
    "postuliate": "postulare",
    "postulin": "postulare",
    "postulino": "postulare",
    "postulo": "postulare",
    "postulò": "postulare",
    "postuma": "postumo",
    "postume": "postumo",
    "postumi": "postumo",
    "posture": "postura",
    "postò": "postare",
    "posò": "posare",
    "pota": "potare",
    "potabili": "potabile",
    "potai": "potare",
    "potammo": "potare",
    "potan": "potare",
    "potando": "potare",
    "potano": "potare",
    "potante": "potare",
    "potanti": "potare",
    "potar": "potare",
    "potaron": "potare",
    "potarono": "potare",
    "potasse": "potare",
    "potasser": "potare",
    "potassero": "potare",
    "potassi": "potare",
    "potassimo": "potare",
    "potaste": "potare",
    "potasti": "potare",
    "potata": "potare",
    "potate": "potare",
    "potati": "potare",
    "potato": "potare",
    "potature": "potatura",
    "potava": "potare",
    "potavamo": "potare",
    "potavan": "potare",
    "potavano": "potare",
    "potavate": "potare",
    "potavi": "potare",
    "potavo": "potare",
    "potei": "potere",
    "potemmo": "potere",
    "potendo": "potere",
    "potentati": "potentato",
    "potente": "potere",
    "potenti": "potere",
    "potentina": "potentino",
    "potentine": "potentino",
    "potentini": "potentino",
    "potenze": "potenza",
    "potenzi": "potenziare",
    "potenzia": "potenziare",
    "potenziai": "potenziare",
    "potenziali": "potenziale",
    "potenziamenti": "potenziamento",
    "potenziammo": "potenziare",
    "potenziamo": "potenziare",
    "potenzian": "potenziare",
    "potenziando": "potenziare",
    "potenziano": "potenziare",
    "potenziante": "potenziare",
    "potenzianti": "potenziare",
    "potenziar": "potenziare",
    "potenziaron": "potenziare",
    "potenziarono": "potenziare",
    "potenziasse": "potenziare",
    "potenziasser": "potenziare",
    "potenziassero": "potenziare",
    "potenziassi": "potenziare",
    "potenziassimo": "potenziare",
    "potenziaste": "potenziare",
    "potenziasti": "potenziare",
    "potenziata": "potenziato",
    "potenziate": "potenziato",
    "potenziati": "potenziato",
    "potenziato": "potenziare",
    "potenziava": "potenziare",
    "potenziavamo": "potenziare",
    "potenziavan": "potenziare",
    "potenziavano": "potenziare",
    "potenziavate": "potenziare",
    "potenziavi": "potenziare",
    "potenziavo": "potenziare",
    "potenzierai": "potenziare",
    "potenzieran": "potenziare",
    "potenzieranno": "potenziare",
    "potenzierebbe": "potenziare",
    "potenzierebber": "potenziare",
    "potenzierebbero": "potenziare",
    "potenzierei": "potenziare",
    "potenzieremmo": "potenziare",
    "potenzieremo": "potenziare",
    "potenziereste": "potenziare",
    "potenzieresti": "potenziare",
    "potenzierete": "potenziare",
    "potenzierà": "potenziare",
    "potenzierò": "potenziare",
    "potenzin": "potenziare",
    "potenzino": "potenziare",
    "potenzio": "potenziare",
    "potenziò": "potenziare",
    "poter": "potere",
    "poterai": "potare",
    "poteran": "potare",
    "poteranno": "potare",
    "poterebbe": "potare",
    "poterebber": "potare",
    "poterebbero": "potare",
    "poterei": "potare",
    "poteremmo": "potare",
    "poteremo": "potare",
    "potereste": "potare",
    "poteresti": "potare",
    "poterete": "potare",
    "poteri": "potere",
    "poteron": "potere",
    "poterono": "potere",
    "poterà": "potare",
    "poterò": "potare",
    "potesse": "potere",
    "potesser": "potere",
    "potessero": "potere",
    "potessi": "potere",
    "potessimo": "potere",
    "poteste": "potere",
    "potesti": "potere",
    "potete": "potere",
    "poteva": "potere",
    "potevamo": "potere",
    "potevan": "potere",
    "potevano": "potere",
    "potevate": "potere",
    "potevi": "potere",
    "potevo": "potere",
    "poti": "potare",
    "potiamo": "potare",
    "potiate": "potare",
    "potin": "potare",
    "potino": "potare",
    "poto": "potare",
    "potrai": "potere",
    "potran": "potere",
    "potranno": "potere",
    "potrebbe": "potere",
    "potrebber": "potere",
    "potrebbero": "potere",
    "potrei": "potere",
    "potremmo": "potere",
    "potremo": "potere",
    "potreste": "potere",
    "potresti": "potere",
    "potrete": "potere",
    "potrà": "potere",
    "potrò": "potere",
    "potuta": "potere",
    "potute": "potere",
    "potuti": "potere",
    "potuto": "potere",
    "potè": "potere",
    "potò": "potare",
    "povera": "povero",
    "poveracce": "poveraccia",
    "poveracci": "poveraccio",
    "povere": "povero",
    "poverella": "poverello",
    "poverelle": "poverello",
    "poverelli": "poverello",
    "poveretta": "poveretto",
    "poverette": "poveretto",
    "poveretti": "poveretto",
    "poveri": "povero",
    "poverina": "poverino",
    "poverine": "poverino",
    "poverini": "poverino",
    "pozioni": "pozione",
    "pozzanghere": "pozzanghera",
    "pozze": "pozza",
    "pozzetti": "pozzetto",
    "pozzi": "pozzo",
    "praghesi": "praghese",
    "pragmatica": "pragmatico",
    "pragmatiche": "pragmatico",
    "pragmatici": "pragmatico",
    "pragmatismi": "pragmatismo",
    "pragmatisti": "pragmatista",
    "pranza": "pranzare",
    "pranzai": "pranzare",
    "pranzammo": "pranzare",
    "pranzan": "pranzare",
    "pranzando": "pranzare",
    "pranzano": "pranzare",
    "pranzante": "pranzare",
    "pranzanti": "pranzare",
    "pranzar": "pranzare",
    "pranzaron": "pranzare",
    "pranzarono": "pranzare",
    "pranzasse": "pranzare",
    "pranzasser": "pranzare",
    "pranzassero": "pranzare",
    "pranzassi": "pranzare",
    "pranzassimo": "pranzare",
    "pranzaste": "pranzare",
    "pranzasti": "pranzare",
    "pranzata": "pranzare",
    "pranzate": "pranzare",
    "pranzati": "pranzare",
    "pranzato": "pranzare",
    "pranzava": "pranzare",
    "pranzavamo": "pranzare",
    "pranzavan": "pranzare",
    "pranzavano": "pranzare",
    "pranzavate": "pranzare",
    "pranzavi": "pranzare",
    "pranzavo": "pranzare",
    "pranzerai": "pranzare",
    "pranzeran": "pranzare",
    "pranzeranno": "pranzare",
    "pranzerebbe": "pranzare",
    "pranzerebber": "pranzare",
    "pranzerebbero": "pranzare",
    "pranzerei": "pranzare",
    "pranzeremmo": "pranzare",
    "pranzeremo": "pranzare",
    "pranzereste": "pranzare",
    "pranzeresti": "pranzare",
    "pranzerete": "pranzare",
    "pranzerà": "pranzare",
    "pranzerò": "pranzare",
    "pranzetti": "pranzetto",
    "pranzi": "pranzo",
    "pranziamo": "pranzare",
    "pranziate": "pranzare",
    "pranzin": "pranzare",
    "pranzino": "pranzare",
    "pranzo": "pranzare",
    "pranzò": "pranzare",
    "praterie": "prateria",
    "pratesi": "pratese",
    "prati": "prato",
    "pratica": "pratico",
    "praticabili": "praticabile",
    "praticai": "praticare",
    "praticammo": "praticare",
    "pratican": "praticare",
    "praticando": "praticare",
    "praticano": "praticare",
    "praticante": "praticare",
    "praticanti": "praticare",
    "praticar": "praticare",
    "praticaron": "praticare",
    "praticarono": "praticare",
    "praticasse": "praticare",
    "praticasser": "praticare",
    "praticassero": "praticare",
    "praticassi": "praticare",
    "praticassimo": "praticare",
    "praticaste": "praticare",
    "praticasti": "praticare",
    "praticata": "praticare",
    "praticate": "praticare",
    "praticati": "praticare",
    "praticato": "praticare",
    "praticava": "praticare",
    "praticavamo": "praticare",
    "praticavan": "praticare",
    "praticavano": "praticare",
    "praticavate": "praticare",
    "praticavi": "praticare",
    "praticavo": "praticare",
    "praticelli": "praticello",
    "pratiche": "pratico",
    "praticherai": "praticare",
    "praticheran": "praticare",
    "praticheranno": "praticare",
    "praticherebbe": "praticare",
    "praticherebber": "praticare",
    "praticherebbero": "praticare",
    "praticherei": "praticare",
    "praticheremmo": "praticare",
    "praticheremo": "praticare",
    "pratichereste": "praticare",
    "praticheresti": "praticare",
    "praticherete": "praticare",
    "praticherà": "praticare",
    "praticherò": "praticare",
    "pratichi": "praticare",
    "pratichiamo": "praticare",
    "pratichiate": "praticare",
    "pratichin": "praticare",
    "pratichino": "praticare",
    "pratici": "pratico",
    "pratico": "praticare",
    "praticoni": "praticone",
    "praticò": "praticare",
    "prativa": "prativo",
    "prative": "prativo",
    "prativi": "prativo",
    "pratoni": "pratone",
    "prava": "pravo",
    "prave": "pravo",
    "pravi": "pravo",
    "pre-accordi": "pre-accordo",
    "pre-condizioni": "pre-condizione",
    "pre-elettorali": "pre-elettorale",
    "pre-embrioni": "pre-embrione",
    "pre-esistenti": "pre-esistente",
    "pre-maligna": "pre-maligno",
    "pre-maligne": "pre-maligno",
    "pre-maligni": "pre-maligno",
    "pre-pensionamenti": "pre-pensionamento",
    "pre-politica": "pre-politico",
    "pre-politiche": "pre-politico",
    "pre-politici": "pre-politico",
    "pre-requisiti": "pre-requisito",
    "pre-rivoluzionari": "pre-rivoluzionario",
    "pre-rivoluzionaria": "pre-rivoluzionario",
    "pre-rivoluzionarie": "pre-rivoluzionario",
    "preallarmi": "preallarme",
    "prealpina": "prealpino",
    "prealpine": "prealpino",
    "prealpini": "prealpino",
    "preamboli": "preambolo",
    "preannuncerai": "preannunciare",
    "preannunceran": "preannunciare",
    "preannunceranno": "preannunciare",
    "preannuncerebbe": "preannunciare",
    "preannuncerebber": "preannunciare",
    "preannuncerebbero": "preannunciare",
    "preannuncerei": "preannunciare",
    "preannunceremmo": "preannunciare",
    "preannunceremo": "preannunciare",
    "preannuncereste": "preannunciare",
    "preannunceresti": "preannunciare",
    "preannuncerete": "preannunciare",
    "preannuncerà": "preannunciare",
    "preannuncerò": "preannunciare",
    "preannunci": "preannuncio",
    "preannuncia": "preannunciare",
    "preannunciai": "preannunciare",
    "preannunciammo": "preannunciare",
    "preannunciamo": "preannunciare",
    "preannuncian": "preannunciare",
    "preannunciando": "preannunciare",
    "preannunciano": "preannunciare",
    "preannunciante": "preannunciare",
    "preannuncianti": "preannunciare",
    "preannunciar": "preannunciare",
    "preannunciaron": "preannunciare",
    "preannunciarono": "preannunciare",
    "preannunciasse": "preannunciare",
    "preannunciasser": "preannunciare",
    "preannunciassero": "preannunciare",
    "preannunciassi": "preannunciare",
    "preannunciassimo": "preannunciare",
    "preannunciaste": "preannunciare",
    "preannunciasti": "preannunciare",
    "preannunciata": "preannunciare",
    "preannunciate": "preannunciare",
    "preannunciati": "preannunciare",
    "preannunciato": "preannunciare",
    "preannunciava": "preannunciare",
    "preannunciavamo": "preannunciare",
    "preannunciavan": "preannunciare",
    "preannunciavano": "preannunciare",
    "preannunciavate": "preannunciare",
    "preannunciavi": "preannunciare",
    "preannunciavo": "preannunciare",
    "preannuncin": "preannunciare",
    "preannuncino": "preannunciare",
    "preannuncio": "preannunciare",
    "preannunciò": "preannunciare",
    "preannunzi": "preannunziare",
    "preannunzia": "preannunziare",
    "preannunziai": "preannunziare",
    "preannunziammo": "preannunziare",
    "preannunziamo": "preannunziare",
    "preannunzian": "preannunziare",
    "preannunziando": "preannunziare",
    "preannunziano": "preannunziare",
    "preannunziante": "preannunziare",
    "preannunzianti": "preannunziare",
    "preannunziar": "preannunziare",
    "preannunziaron": "preannunziare",
    "preannunziarono": "preannunziare",
    "preannunziasse": "preannunziare",
    "preannunziasser": "preannunziare",
    "preannunziassero": "preannunziare",
    "preannunziassi": "preannunziare",
    "preannunziassimo": "preannunziare",
    "preannunziaste": "preannunziare",
    "preannunziasti": "preannunziare",
    "preannunziata": "preannunziare",
    "preannunziate": "preannunziare",
    "preannunziati": "preannunziare",
    "preannunziato": "preannunziare",
    "preannunziava": "preannunziare",
    "preannunziavamo": "preannunziare",
    "preannunziavan": "preannunziare",
    "preannunziavano": "preannunziare",
    "preannunziavate": "preannunziare",
    "preannunziavi": "preannunziare",
    "preannunziavo": "preannunziare",
    "preannunzierai": "preannunziare",
    "preannunzieran": "preannunziare",
    "preannunzieranno": "preannunziare",
    "preannunzierebbe": "preannunziare",
    "preannunzierebber": "preannunziare",
    "preannunzierebbero": "preannunziare",
    "preannunzierei": "preannunziare",
    "preannunzieremmo": "preannunziare",
    "preannunzieremo": "preannunziare",
    "preannunziereste": "preannunziare",
    "preannunzieresti": "preannunziare",
    "preannunzierete": "preannunziare",
    "preannunzierà": "preannunziare",
    "preannunzierò": "preannunziare",
    "preannunzin": "preannunziare",
    "preannunzino": "preannunziare",
    "preannunzio": "preannunziare",
    "preannunziò": "preannunziare",
    "preassembla": "preassemblare",
    "preassemblai": "preassemblare",
    "preassemblammo": "preassemblare",
    "preassemblan": "preassemblare",
    "preassemblando": "preassemblare",
    "preassemblano": "preassemblare",
    "preassemblante": "preassemblare",
    "preassemblanti": "preassemblare",
    "preassemblar": "preassemblare",
    "preassemblaron": "preassemblare",
    "preassemblarono": "preassemblare",
    "preassemblasse": "preassemblare",
    "preassemblasser": "preassemblare",
    "preassemblassero": "preassemblare",
    "preassemblassi": "preassemblare",
    "preassemblassimo": "preassemblare",
    "preassemblaste": "preassemblare",
    "preassemblasti": "preassemblare",
    "preassemblata": "preassemblare",
    "preassemblate": "preassemblare",
    "preassemblati": "preassemblare",
    "preassemblato": "preassemblare",
    "preassemblava": "preassemblare",
    "preassemblavamo": "preassemblare",
    "preassemblavan": "preassemblare",
    "preassemblavano": "preassemblare",
    "preassemblavate": "preassemblare",
    "preassemblavi": "preassemblare",
    "preassemblavo": "preassemblare",
    "preassemblerai": "preassemblare",
    "preassembleran": "preassemblare",
    "preassembleranno": "preassemblare",
    "preassemblerebbe": "preassemblare",
    "preassemblerebber": "preassemblare",
    "preassemblerebbero": "preassemblare",
    "preassemblerei": "preassemblare",
    "preassembleremmo": "preassemblare",
    "preassembleremo": "preassemblare",
    "preassemblereste": "preassemblare",
    "preassembleresti": "preassemblare",
    "preassemblerete": "preassemblare",
    "preassemblerà": "preassemblare",
    "preassemblerò": "preassemblare",
    "preassembli": "preassemblare",
    "preassembliamo": "preassemblare",
    "preassembliate": "preassemblare",
    "preassemblin": "preassemblare",
    "preassemblino": "preassemblare",
    "preassemblo": "preassemblare",
    "preassemblò": "preassemblare",
    "preatletica": "preatletico",
    "preatletiche": "preatletico",
    "preatletici": "preatletico",
    "preavverta": "preavvertire",
    "preavvertan": "preavvertire",
    "preavvertano": "preavvertire",
    "preavverte": "preavvertire",
    "preavvertendo": "preavvertire",
    "preavvertente": "preavvertire",
    "preavvertenti": "preavvertire",
    "preavverti": "preavvertire",
    "preavvertiamo": "preavvertire",
    "preavvertiate": "preavvertire",
    "preavvertii": "preavvertire",
    "preavvertimmo": "preavvertire",
    "preavvertir": "preavvertire",
    "preavvertirai": "preavvertire",
    "preavvertiran": "preavvertire",
    "preavvertiranno": "preavvertire",
    "preavvertirebbe": "preavvertire",
    "preavvertirebber": "preavvertire",
    "preavvertirebbero": "preavvertire",
    "preavvertirei": "preavvertire",
    "preavvertiremmo": "preavvertire",
    "preavvertiremo": "preavvertire",
    "preavvertireste": "preavvertire",
    "preavvertiresti": "preavvertire",
    "preavvertirete": "preavvertire",
    "preavvertiron": "preavvertire",
    "preavvertirono": "preavvertire",
    "preavvertirà": "preavvertire",
    "preavvertirò": "preavvertire",
    "preavvertisse": "preavvertire",
    "preavvertisser": "preavvertire",
    "preavvertissero": "preavvertire",
    "preavvertissi": "preavvertire",
    "preavvertissimo": "preavvertire",
    "preavvertiste": "preavvertire",
    "preavvertisti": "preavvertire",
    "preavvertita": "preavvertire",
    "preavvertite": "preavvertire",
    "preavvertiti": "preavvertire",
    "preavvertito": "preavvertire",
    "preavvertiva": "preavvertire",
    "preavvertivamo": "preavvertire",
    "preavvertivan": "preavvertire",
    "preavvertivano": "preavvertire",
    "preavvertivate": "preavvertire",
    "preavvertivi": "preavvertire",
    "preavvertivo": "preavvertire",
    "preavverto": "preavvertire",
    "preavverton": "preavvertire",
    "preavvertono": "preavvertire",
    "preavvertì": "preavvertire",
    "preavvisa": "preavvisare",
    "preavvisai": "preavvisare",
    "preavvisammo": "preavvisare",
    "preavvisan": "preavvisare",
    "preavvisando": "preavvisare",
    "preavvisano": "preavvisare",
    "preavvisante": "preavvisare",
    "preavvisanti": "preavvisare",
    "preavvisar": "preavvisare",
    "preavvisaron": "preavvisare",
    "preavvisarono": "preavvisare",
    "preavvisasse": "preavvisare",
    "preavvisasser": "preavvisare",
    "preavvisassero": "preavvisare",
    "preavvisassi": "preavvisare",
    "preavvisassimo": "preavvisare",
    "preavvisaste": "preavvisare",
    "preavvisasti": "preavvisare",
    "preavvisata": "preavvisare",
    "preavvisate": "preavvisare",
    "preavvisati": "preavvisare",
    "preavvisato": "preavvisare",
    "preavvisava": "preavvisare",
    "preavvisavamo": "preavvisare",
    "preavvisavan": "preavvisare",
    "preavvisavano": "preavvisare",
    "preavvisavate": "preavvisare",
    "preavvisavi": "preavvisare",
    "preavvisavo": "preavvisare",
    "preavviserai": "preavvisare",
    "preavviseran": "preavvisare",
    "preavviseranno": "preavvisare",
    "preavviserebbe": "preavvisare",
    "preavviserebber": "preavvisare",
    "preavviserebbero": "preavvisare",
    "preavviserei": "preavvisare",
    "preavviseremmo": "preavvisare",
    "preavviseremo": "preavvisare",
    "preavvisereste": "preavvisare",
    "preavviseresti": "preavvisare",
    "preavviserete": "preavvisare",
    "preavviserà": "preavvisare",
    "preavviserò": "preavvisare",
    "preavvisi": "preavviso",
    "preavvisiamo": "preavvisare",
    "preavvisiate": "preavvisare",
    "preavvisin": "preavvisare",
    "preavvisino": "preavvisare",
    "preavviso": "preavvisare",
    "preavvisò": "preavvisare",
    "prebende": "prebenda",
    "precampionata": "precampionato",
    "precampionate": "precampionato",
    "precampionati": "precampionato",
    "precari": "precario",
    "precaria": "precario",
    "precariati": "precariato",
    "precarie": "precario",
    "precauzionali": "precauzionale",
    "precauzioni": "precauzione",
    "preceda": "precedere",
    "precedan": "precedere",
    "precedano": "precedere",
    "precede": "precedere",
    "precedemmo": "precedere",
    "precedendo": "precedere",
    "precedente": "precedere",
    "precedenti": "precedere",
    "precedenze": "precedenza",
    "preceder": "precedere",
    "precederai": "precedere",
    "precederan": "precedere",
    "precederanno": "precedere",
    "precederebbe": "precedere",
    "precederebber": "precedere",
    "precederebbero": "precedere",
    "precederei": "precedere",
    "precederemmo": "precedere",
    "precederemo": "precedere",
    "precedereste": "precedere",
    "precederesti": "precedere",
    "precederete": "precedere",
    "precederà": "precedere",
    "precederò": "precedere",
    "precedesse": "precedere",
    "precedesser": "precedere",
    "precedessero": "precedere",
    "precedessi": "precedere",
    "precedessimo": "precedere",
    "precedessori": "precedessore",
    "precedeste": "precedere",
    "precedesti": "precedere",
    "precedete": "precedere",
    "precedette": "precedere",
    "precedetter": "precedere",
    "precedettero": "precedere",
    "precedetti": "precedere",
    "precedeva": "precedere",
    "precedevamo": "precedere",
    "precedevan": "precedere",
    "precedevano": "precedere",
    "precedevate": "precedere",
    "precedevi": "precedere",
    "precedevo": "precedere",
    "precedi": "precedere",
    "precediamo": "precedere",
    "precediate": "precedere",
    "precedo": "precedere",
    "precedon": "precedere",
    "precedono": "precedere",
    "preceduta": "precedere",
    "precedute": "precedere",
    "preceduti": "precedere",
    "preceduto": "precedere",
    "precendenti": "precendente",
    "precetta": "precetto",
    "precettai": "precettare",
    "precettammo": "precettare",
    "precettan": "precettare",
    "precettando": "precettare",
    "precettano": "precettare",
    "precettante": "precettare",
    "precettanti": "precettare",
    "precettar": "precettare",
    "precettaron": "precettare",
    "precettarono": "precettare",
    "precettasse": "precettare",
    "precettasser": "precettare",
    "precettassero": "precettare",
    "precettassi": "precettare",
    "precettassimo": "precettare",
    "precettaste": "precettare",
    "precettasti": "precettare",
    "precettata": "precettare",
    "precettate": "precettare",
    "precettati": "precettare",
    "precettato": "precettare",
    "precettava": "precettare",
    "precettavamo": "precettare",
    "precettavan": "precettare",
    "precettavano": "precettare",
    "precettavate": "precettare",
    "precettavi": "precettare",
    "precettavo": "precettare",
    "precettazioni": "precettazione",
    "precette": "precetto",
    "precetterai": "precettare",
    "precetteran": "precettare",
    "precetteranno": "precettare",
    "precetterebbe": "precettare",
    "precetterebber": "precettare",
    "precetterebbero": "precettare",
    "precetterei": "precettare",
    "precetteremmo": "precettare",
    "precetteremo": "precettare",
    "precettereste": "precettare",
    "precetteresti": "precettare",
    "precetterete": "precettare",
    "precetterà": "precettare",
    "precetterò": "precettare",
    "precetti": "precetto",
    "precettiamo": "precettare",
    "precettiate": "precettare",
    "precettin": "precettare",
    "precettino": "precettare",
    "precetto": "precettare",
    "precettori": "precettore",
    "precettò": "precettare",
    "precipita": "precipitare",
    "precipitai": "precipitare",
    "precipitammo": "precipitare",
    "precipitan": "precipitare",
    "precipitando": "precipitare",
    "precipitano": "precipitare",
    "precipitante": "precipitare",
    "precipitanti": "precipitare",
    "precipitar": "precipitare",
    "precipitaron": "precipitare",
    "precipitarono": "precipitare",
    "precipitasse": "precipitare",
    "precipitasser": "precipitare",
    "precipitassero": "precipitare",
    "precipitassi": "precipitare",
    "precipitassimo": "precipitare",
    "precipitaste": "precipitare",
    "precipitasti": "precipitare",
    "precipitata": "precipitato",
    "precipitate": "precipitato",
    "precipitati": "precipitato",
    "precipitato": "precipitare",
    "precipitava": "precipitare",
    "precipitavamo": "precipitare",
    "precipitavan": "precipitare",
    "precipitavano": "precipitare",
    "precipitavate": "precipitare",
    "precipitavi": "precipitare",
    "precipitavo": "precipitare",
    "precipitazioni": "precipitazione",
    "precipiterai": "precipitare",
    "precipiteran": "precipitare",
    "precipiteranno": "precipitare",
    "precipiterebbe": "precipitare",
    "precipiterebber": "precipitare",
    "precipiterebbero": "precipitare",
    "precipiterei": "precipitare",
    "precipiteremmo": "precipitare",
    "precipiteremo": "precipitare",
    "precipitereste": "precipitare",
    "precipiteresti": "precipitare",
    "precipiterete": "precipitare",
    "precipiterà": "precipitare",
    "precipiterò": "precipitare",
    "precipiti": "precipite",
    "precipitiamo": "precipitare",
    "precipitiate": "precipitare",
    "precipitin": "precipitare",
    "precipitino": "precipitare",
    "precipito": "precipitare",
    "precipitosa": "precipitoso",
    "precipitose": "precipitoso",
    "precipitosi": "precipitoso",
    "precipitò": "precipitare",
    "precipizi": "precipizio",
    "precipua": "precipuo",
    "precipue": "precipuo",
    "precipui": "precipuo",
    "precisa": "preciso",
    "precisai": "precisare",
    "precisammo": "precisare",
    "precisan": "precisare",
    "precisando": "precisare",
    "precisano": "precisare",
    "precisante": "precisare",
    "precisanti": "precisare",
    "precisar": "precisare",
    "precisaron": "precisare",
    "precisarono": "precisare",
    "precisasse": "precisare",
    "precisasser": "precisare",
    "precisassero": "precisare",
    "precisassi": "precisare",
    "precisassimo": "precisare",
    "precisaste": "precisare",
    "precisasti": "precisare",
    "precisata": "precisare",
    "precisate": "precisare",
    "precisati": "precisare",
    "precisato": "precisare",
    "precisava": "precisare",
    "precisavamo": "precisare",
    "precisavan": "precisare",
    "precisavano": "precisare",
    "precisavate": "precisare",
    "precisavi": "precisare",
    "precisavo": "precisare",
    "precisazioni": "precisazione",
    "precise": "preciso",
    "preciserai": "precisare",
    "preciseran": "precisare",
    "preciseranno": "precisare",
    "preciserebbe": "precisare",
    "preciserebber": "precisare",
    "preciserebbero": "precisare",
    "preciserei": "precisare",
    "preciseremmo": "precisare",
    "preciseremo": "precisare",
    "precisereste": "precisare",
    "preciseresti": "precisare",
    "preciserete": "precisare",
    "preciserà": "precisare",
    "preciserò": "precisare",
    "precisi": "preciso",
    "precisiamo": "precisare",
    "precisiate": "precisare",
    "precisin": "precisare",
    "precisino": "precisare",
    "precisioni": "precisione",
    "preciso": "precisare",
    "precisò": "precisare",
    "precita": "precitare",
    "precitai": "precitare",
    "precitammo": "precitare",
    "precitan": "precitare",
    "precitando": "precitare",
    "precitano": "precitare",
    "precitante": "precitare",
    "precitanti": "precitare",
    "precitar": "precitare",
    "precitaron": "precitare",
    "precitarono": "precitare",
    "precitasse": "precitare",
    "precitasser": "precitare",
    "precitassero": "precitare",
    "precitassi": "precitare",
    "precitassimo": "precitare",
    "precitaste": "precitare",
    "precitasti": "precitare",
    "precitata": "precitare",
    "precitate": "precitare",
    "precitati": "precitare",
    "precitato": "precitare",
    "precitava": "precitare",
    "precitavamo": "precitare",
    "precitavan": "precitare",
    "precitavano": "precitare",
    "precitavate": "precitare",
    "precitavi": "precitare",
    "precitavo": "precitare",
    "preciterai": "precitare",
    "preciteran": "precitare",
    "preciteranno": "precitare",
    "preciterebbe": "precitare",
    "preciterebber": "precitare",
    "preciterebbero": "precitare",
    "preciterei": "precitare",
    "preciteremmo": "precitare",
    "preciteremo": "precitare",
    "precitereste": "precitare",
    "preciteresti": "precitare",
    "preciterete": "precitare",
    "preciterà": "precitare",
    "preciterò": "precitare",
    "preciti": "precitare",
    "precitiamo": "precitare",
    "precitiate": "precitare",
    "precitin": "precitare",
    "precitino": "precitare",
    "precito": "precitare",
    "precitò": "precitare",
    "precluda": "precludere",
    "precludan": "precludere",
    "precludano": "precludere",
    "preclude": "precludere",
    "precludemmo": "precludere",
    "precludendo": "precludere",
    "precludente": "precludere",
    "precludenti": "precludere",
    "precluder": "precludere",
    "precluderai": "precludere",
    "precluderan": "precludere",
    "precluderanno": "precludere",
    "precluderebbe": "precludere",
    "precluderebber": "precludere",
    "precluderebbero": "precludere",
    "precluderei": "precludere",
    "precluderemmo": "precludere",
    "precluderemo": "precludere",
    "precludereste": "precludere",
    "precluderesti": "precludere",
    "precluderete": "precludere",
    "precluderà": "precludere",
    "precluderò": "precludere",
    "precludesse": "precludere",
    "precludesser": "precludere",
    "precludessero": "precludere",
    "precludessi": "precludere",
    "precludessimo": "precludere",
    "precludeste": "precludere",
    "precludesti": "precludere",
    "precludete": "precludere",
    "precludeva": "precludere",
    "precludevamo": "precludere",
    "precludevan": "precludere",
    "precludevano": "precludere",
    "precludevate": "precludere",
    "precludevi": "precludere",
    "precludevo": "precludere",
    "precludi": "precludere",
    "precludiamo": "precludere",
    "precludiate": "precludere",
    "precludo": "precludere",
    "precludon": "precludere",
    "precludono": "precludere",
    "preclusa": "precluso",
    "precluse": "precluso",
    "precluser": "precludere",
    "preclusero": "precludere",
    "preclusi": "precluso",
    "preclusioni": "preclusione",
    "preclusiva": "preclusivo",
    "preclusive": "preclusivo",
    "preclusivi": "preclusivo",
    "precluso": "precludere",
    "precoci": "precoce",
    "precolombiana": "precolombiano",
    "precolombiane": "precolombiano",
    "precolombiani": "precolombiano",
    "precomprima": "precomprimere",
    "precompriman": "precomprimere",
    "precomprimano": "precomprimere",
    "precomprime": "precomprimere",
    "precomprimei": "precomprimere",
    "precomprimemmo": "precomprimere",
    "precomprimendo": "precomprimere",
    "precomprimente": "precomprimere",
    "precomprimenti": "precomprimere",
    "precomprimer": "precomprimere",
    "precomprimerai": "precomprimere",
    "precomprimeran": "precomprimere",
    "precomprimeranno": "precomprimere",
    "precomprimerebbe": "precomprimere",
    "precomprimerebber": "precomprimere",
    "precomprimerebbero": "precomprimere",
    "precomprimerei": "precomprimere",
    "precomprimeremmo": "precomprimere",
    "precomprimeremo": "precomprimere",
    "precomprimereste": "precomprimere",
    "precomprimeresti": "precomprimere",
    "precomprimerete": "precomprimere",
    "precomprimeron": "precomprimere",
    "precomprimerono": "precomprimere",
    "precomprimerà": "precomprimere",
    "precomprimerò": "precomprimere",
    "precomprimesse": "precomprimere",
    "precomprimesser": "precomprimere",
    "precomprimessero": "precomprimere",
    "precomprimessi": "precomprimere",
    "precomprimessimo": "precomprimere",
    "precomprimeste": "precomprimere",
    "precomprimesti": "precomprimere",
    "precomprimete": "precomprimere",
    "precomprimeva": "precomprimere",
    "precomprimevamo": "precomprimere",
    "precomprimevan": "precomprimere",
    "precomprimevano": "precomprimere",
    "precomprimevate": "precomprimere",
    "precomprimevi": "precomprimere",
    "precomprimevo": "precomprimere",
    "precomprimi": "precomprimere",
    "precomprimiamo": "precomprimere",
    "precomprimiate": "precomprimere",
    "precomprimo": "precomprimere",
    "precomprimon": "precomprimere",
    "precomprimono": "precomprimere",
    "precomprimuta": "precomprimere",
    "precomprimute": "precomprimere",
    "precomprimuti": "precomprimere",
    "precomprimuto": "precomprimere",
    "precomprimè": "precomprimere",
    "preconcetta": "preconcetto",
    "preconcette": "preconcetto",
    "preconcetti": "preconcetto",
    "precondizioni": "precondizione",
    "preconfeziona": "preconfezionare",
    "preconfezionai": "preconfezionare",
    "preconfezionammo": "preconfezionare",
    "preconfezionan": "preconfezionare",
    "preconfezionando": "preconfezionare",
    "preconfezionano": "preconfezionare",
    "preconfezionante": "preconfezionare",
    "preconfezionanti": "preconfezionare",
    "preconfezionar": "preconfezionare",
    "preconfezionaron": "preconfezionare",
    "preconfezionarono": "preconfezionare",
    "preconfezionasse": "preconfezionare",
    "preconfezionasser": "preconfezionare",
    "preconfezionassero": "preconfezionare",
    "preconfezionassi": "preconfezionare",
    "preconfezionassimo": "preconfezionare",
    "preconfezionaste": "preconfezionare",
    "preconfezionasti": "preconfezionare",
    "preconfezionata": "preconfezionare",
    "preconfezionate": "preconfezionare",
    "preconfezionati": "preconfezionare",
    "preconfezionato": "preconfezionare",
    "preconfezionava": "preconfezionare",
    "preconfezionavamo": "preconfezionare",
    "preconfezionavan": "preconfezionare",
    "preconfezionavano": "preconfezionare",
    "preconfezionavate": "preconfezionare",
    "preconfezionavi": "preconfezionare",
    "preconfezionavo": "preconfezionare",
    "preconfezionerai": "preconfezionare",
    "preconfezioneran": "preconfezionare",
    "preconfezioneranno": "preconfezionare",
    "preconfezionerebbe": "preconfezionare",
    "preconfezionerebber": "preconfezionare",
    "preconfezionerebbero": "preconfezionare",
    "preconfezionerei": "preconfezionare",
    "preconfezioneremmo": "preconfezionare",
    "preconfezioneremo": "preconfezionare",
    "preconfezionereste": "preconfezionare",
    "preconfezioneresti": "preconfezionare",
    "preconfezionerete": "preconfezionare",
    "preconfezionerà": "preconfezionare",
    "preconfezionerò": "preconfezionare",
    "preconfezioni": "preconfezionare",
    "preconfezioniamo": "preconfezionare",
    "preconfezioniate": "preconfezionare",
    "preconfezionin": "preconfezionare",
    "preconfezionino": "preconfezionare",
    "preconfeziono": "preconfezionare",
    "preconfezionò": "preconfezionare",
    "precongressi": "precongresso",
    "precongressuali": "precongressuale",
    "preconizza": "preconizzare",
    "preconizzai": "preconizzare",
    "preconizzammo": "preconizzare",
    "preconizzan": "preconizzare",
    "preconizzando": "preconizzare",
    "preconizzano": "preconizzare",
    "preconizzante": "preconizzare",
    "preconizzanti": "preconizzare",
    "preconizzar": "preconizzare",
    "preconizzaron": "preconizzare",
    "preconizzarono": "preconizzare",
    "preconizzasse": "preconizzare",
    "preconizzasser": "preconizzare",
    "preconizzassero": "preconizzare",
    "preconizzassi": "preconizzare",
    "preconizzassimo": "preconizzare",
    "preconizzaste": "preconizzare",
    "preconizzasti": "preconizzare",
    "preconizzata": "preconizzare",
    "preconizzate": "preconizzare",
    "preconizzati": "preconizzare",
    "preconizzato": "preconizzare",
    "preconizzava": "preconizzare",
    "preconizzavamo": "preconizzare",
    "preconizzavan": "preconizzare",
    "preconizzavano": "preconizzare",
    "preconizzavate": "preconizzare",
    "preconizzavi": "preconizzare",
    "preconizzavo": "preconizzare",
    "preconizzerai": "preconizzare",
    "preconizzeran": "preconizzare",
    "preconizzeranno": "preconizzare",
    "preconizzerebbe": "preconizzare",
    "preconizzerebber": "preconizzare",
    "preconizzerebbero": "preconizzare",
    "preconizzerei": "preconizzare",
    "preconizzeremmo": "preconizzare",
    "preconizzeremo": "preconizzare",
    "preconizzereste": "preconizzare",
    "preconizzeresti": "preconizzare",
    "preconizzerete": "preconizzare",
    "preconizzerà": "preconizzare",
    "preconizzerò": "preconizzare",
    "preconizzi": "preconizzare",
    "preconizziamo": "preconizzare",
    "preconizziate": "preconizzare",
    "preconizzin": "preconizzare",
    "preconizzino": "preconizzare",
    "preconizzo": "preconizzare",
    "preconizzò": "preconizzare",
    "preconosca": "preconoscere",
    "preconoscan": "preconoscere",
    "preconoscano": "preconoscere",
    "preconosce": "preconoscere",
    "preconoscei": "preconoscere",
    "preconoscemmo": "preconoscere",
    "preconoscendo": "preconoscere",
    "preconoscente": "preconoscere",
    "preconoscenti": "preconoscere",
    "preconoscer": "preconoscere",
    "preconoscerai": "preconoscere",
    "preconosceran": "preconoscere",
    "preconosceranno": "preconoscere",
    "preconoscerebbe": "preconoscere",
    "preconoscerebber": "preconoscere",
    "preconoscerebbero": "preconoscere",
    "preconoscerei": "preconoscere",
    "preconosceremmo": "preconoscere",
    "preconosceremo": "preconoscere",
    "preconoscereste": "preconoscere",
    "preconosceresti": "preconoscere",
    "preconoscerete": "preconoscere",
    "preconosceron": "preconoscere",
    "preconoscerono": "preconoscere",
    "preconoscerà": "preconoscere",
    "preconoscerò": "preconoscere",
    "preconoscesse": "preconoscere",
    "preconoscesser": "preconoscere",
    "preconoscessero": "preconoscere",
    "preconoscessi": "preconoscere",
    "preconoscessimo": "preconoscere",
    "preconosceste": "preconoscere",
    "preconoscesti": "preconoscere",
    "preconoscete": "preconoscere",
    "preconosceva": "preconoscere",
    "preconoscevamo": "preconoscere",
    "preconoscevan": "preconoscere",
    "preconoscevano": "preconoscere",
    "preconoscevate": "preconoscere",
    "preconoscevi": "preconoscere",
    "preconoscevo": "preconoscere",
    "preconosci": "preconoscere",
    "preconosciamo": "preconoscere",
    "preconosciate": "preconoscere",
    "preconosciuta": "preconoscere",
    "preconosciute": "preconoscere",
    "preconosciuti": "preconoscere",
    "preconosciuto": "preconoscere",
    "preconosco": "preconoscere",
    "preconoscon": "preconoscere",
    "preconoscono": "preconoscere",
    "preconoscè": "preconoscere",
    "preconsuntivi": "preconsuntivo",
    "precontratti": "precontratto",
    "precorra": "precorrere",
    "precorran": "precorrere",
    "precorrano": "precorrere",
    "precorre": "precorrere",
    "precorremmo": "precorrere",
    "precorrendo": "precorrere",
    "precorrente": "precorrere",
    "precorrenti": "precorrere",
    "precorrer": "precorrere",
    "precorrerai": "precorrere",
    "precorreran": "precorrere",
    "precorreranno": "precorrere",
    "precorrerebbe": "precorrere",
    "precorrerebber": "precorrere",
    "precorrerebbero": "precorrere",
    "precorrerei": "precorrere",
    "precorreremmo": "precorrere",
    "precorreremo": "precorrere",
    "precorrereste": "precorrere",
    "precorreresti": "precorrere",
    "precorrerete": "precorrere",
    "precorrerà": "precorrere",
    "precorrerò": "precorrere",
    "precorresse": "precorrere",
    "precorresser": "precorrere",
    "precorressero": "precorrere",
    "precorressi": "precorrere",
    "precorressimo": "precorrere",
    "precorreste": "precorrere",
    "precorresti": "precorrere",
    "precorrete": "precorrere",
    "precorreva": "precorrere",
    "precorrevamo": "precorrere",
    "precorrevan": "precorrere",
    "precorrevano": "precorrere",
    "precorrevate": "precorrere",
    "precorrevi": "precorrere",
    "precorrevo": "precorrere",
    "precorri": "precorrere",
    "precorriamo": "precorrere",
    "precorriate": "precorrere",
    "precorritori": "precorritore",
    "precorritrice": "precorritore",
    "precorritrici": "precorritore",
    "precorro": "precorrere",
    "precorron": "precorrere",
    "precorrono": "precorrere",
    "precorsa": "precorrere",
    "precorse": "precorrere",
    "precorser": "precorrere",
    "precorsero": "precorrere",
    "precorsi": "precorrere",
    "precorso": "precorrere",
    "precostituendo": "precostituire",
    "precostituente": "precostituire",
    "precostituenti": "precostituire",
    "precostituiamo": "precostituire",
    "precostituiate": "precostituire",
    "precostituii": "precostituire",
    "precostituimmo": "precostituire",
    "precostituir": "precostituire",
    "precostituirai": "precostituire",
    "precostituiran": "precostituire",
    "precostituiranno": "precostituire",
    "precostituirebbe": "precostituire",
    "precostituirebber": "precostituire",
    "precostituirebbero": "precostituire",
    "precostituirei": "precostituire",
    "precostituiremmo": "precostituire",
    "precostituiremo": "precostituire",
    "precostituireste": "precostituire",
    "precostituiresti": "precostituire",
    "precostituirete": "precostituire",
    "precostituiron": "precostituire",
    "precostituirono": "precostituire",
    "precostituirà": "precostituire",
    "precostituirò": "precostituire",
    "precostituisca": "precostituire",
    "precostituiscan": "precostituire",
    "precostituiscano": "precostituire",
    "precostituisce": "precostituire",
    "precostituisci": "precostituire",
    "precostituisco": "precostituire",
    "precostituiscon": "precostituire",
    "precostituiscono": "precostituire",
    "precostituisse": "precostituire",
    "precostituisser": "precostituire",
    "precostituissero": "precostituire",
    "precostituissi": "precostituire",
    "precostituissimo": "precostituire",
    "precostituiste": "precostituire",
    "precostituisti": "precostituire",
    "precostituita": "precostituire",
    "precostituite": "precostituire",
    "precostituiti": "precostituire",
    "precostituito": "precostituire",
    "precostituiva": "precostituire",
    "precostituivamo": "precostituire",
    "precostituivan": "precostituire",
    "precostituivano": "precostituire",
    "precostituivate": "precostituire",
    "precostituivi": "precostituire",
    "precostituivo": "precostituire",
    "precostituì": "precostituire",
    "precotta": "precotto",
    "precotte": "precotto",
    "precotti": "precotto",
    "precursori": "precursore",
    "preda": "predare",
    "predai": "predare",
    "predammo": "predare",
    "predan": "predare",
    "predando": "predare",
    "predano": "predare",
    "predante": "predare",
    "predanti": "predare",
    "predar": "predare",
    "predaron": "predare",
    "predarono": "predare",
    "predasse": "predare",
    "predasser": "predare",
    "predassero": "predare",
    "predassi": "predare",
    "predassimo": "predare",
    "predaste": "predare",
    "predasti": "predare",
    "predata": "predare",
    "predate": "predare",
    "predati": "predare",
    "predato": "predare",
    "predatori": "predatore",
    "predava": "predare",
    "predavamo": "predare",
    "predavan": "predare",
    "predavano": "predare",
    "predavate": "predare",
    "predavi": "predare",
    "predavo": "predare",
    "prede": "preda",
    "predecessori": "predecessore",
    "predelle": "predella",
    "predellini": "predellino",
    "prederai": "predare",
    "prederan": "predare",
    "prederanno": "predare",
    "prederebbe": "predare",
    "prederebber": "predare",
    "prederebbero": "predare",
    "prederei": "predare",
    "prederemmo": "predare",
    "prederemo": "predare",
    "predereste": "predare",
    "prederesti": "predare",
    "prederete": "predare",
    "prederà": "predare",
    "prederò": "predare",
    "predesertica": "predesertico",
    "predesertiche": "predesertico",
    "predesertici": "predesertico",
    "predestina": "predestinare",
    "predestinai": "predestinare",
    "predestinammo": "predestinare",
    "predestinan": "predestinare",
    "predestinando": "predestinare",
    "predestinano": "predestinare",
    "predestinante": "predestinare",
    "predestinanti": "predestinare",
    "predestinar": "predestinare",
    "predestinaron": "predestinare",
    "predestinarono": "predestinare",
    "predestinasse": "predestinare",
    "predestinasser": "predestinare",
    "predestinassero": "predestinare",
    "predestinassi": "predestinare",
    "predestinassimo": "predestinare",
    "predestinaste": "predestinare",
    "predestinasti": "predestinare",
    "predestinata": "predestinato",
    "predestinate": "predestinato",
    "predestinati": "predestinato",
    "predestinato": "predestinare",
    "predestinava": "predestinare",
    "predestinavamo": "predestinare",
    "predestinavan": "predestinare",
    "predestinavano": "predestinare",
    "predestinavate": "predestinare",
    "predestinavi": "predestinare",
    "predestinavo": "predestinare",
    "predestinazioni": "predestinazione",
    "predestinerai": "predestinare",
    "predestineran": "predestinare",
    "predestineranno": "predestinare",
    "predestinerebbe": "predestinare",
    "predestinerebber": "predestinare",
    "predestinerebbero": "predestinare",
    "predestinerei": "predestinare",
    "predestineremmo": "predestinare",
    "predestineremo": "predestinare",
    "predestinereste": "predestinare",
    "predestineresti": "predestinare",
    "predestinerete": "predestinare",
    "predestinerà": "predestinare",
    "predestinerò": "predestinare",
    "predestini": "predestinare",
    "predestiniamo": "predestinare",
    "predestiniate": "predestinare",
    "predestinin": "predestinare",
    "predestinino": "predestinare",
    "predestino": "predestinare",
    "predestinò": "predestinare",
    "predetermina": "predeterminare",
    "predeterminai": "predeterminare",
    "predeterminammo": "predeterminare",
    "predeterminan": "predeterminare",
    "predeterminando": "predeterminare",
    "predeterminano": "predeterminare",
    "predeterminante": "predeterminare",
    "predeterminanti": "predeterminare",
    "predeterminar": "predeterminare",
    "predeterminaron": "predeterminare",
    "predeterminarono": "predeterminare",
    "predeterminasse": "predeterminare",
    "predeterminasser": "predeterminare",
    "predeterminassero": "predeterminare",
    "predeterminassi": "predeterminare",
    "predeterminassimo": "predeterminare",
    "predeterminaste": "predeterminare",
    "predeterminasti": "predeterminare",
    "predeterminata": "predeterminare",
    "predeterminate": "predeterminare",
    "predeterminati": "predeterminare",
    "predeterminato": "predeterminare",
    "predeterminava": "predeterminare",
    "predeterminavamo": "predeterminare",
    "predeterminavan": "predeterminare",
    "predeterminavano": "predeterminare",
    "predeterminavate": "predeterminare",
    "predeterminavi": "predeterminare",
    "predeterminavo": "predeterminare",
    "predeterminazioni": "predeterminazione",
    "predeterminerai": "predeterminare",
    "predetermineran": "predeterminare",
    "predetermineranno": "predeterminare",
    "predeterminerebbe": "predeterminare",
    "predeterminerebber": "predeterminare",
    "predeterminerebbero": "predeterminare",
    "predeterminerei": "predeterminare",
    "predetermineremmo": "predeterminare",
    "predetermineremo": "predeterminare",
    "predeterminereste": "predeterminare",
    "predetermineresti": "predeterminare",
    "predeterminerete": "predeterminare",
    "predeterminerà": "predeterminare",
    "predeterminerò": "predeterminare",
    "predetermini": "predeterminare",
    "predeterminiamo": "predeterminare",
    "predeterminiate": "predeterminare",
    "predeterminin": "predeterminare",
    "predeterminino": "predeterminare",
    "predetermino": "predeterminare",
    "predeterminò": "predeterminare",
    "predetta": "predire",
    "predette": "predire",
    "predetti": "predire",
    "predetto": "predire",
    "predi": "predare",
    "prediamo": "predare",
    "prediate": "predare",
    "predica": "predire",
    "predicai": "predicare",
    "predicammo": "predicare",
    "predican": "predire",
    "predicando": "predicare",
    "predicano": "predire",
    "predicante": "predicare",
    "predicanti": "predicare",
    "predicar": "predicare",
    "predicaron": "predicare",
    "predicarono": "predicare",
    "predicasse": "predicare",
    "predicasser": "predicare",
    "predicassero": "predicare",
    "predicassi": "predicare",
    "predicassimo": "predicare",
    "predicaste": "predicare",
    "predicasti": "predicare",
    "predicata": "predicare",
    "predicate": "predicare",
    "predicati": "predicare",
    "predicato": "predicare",
    "predicatori": "predicatore",
    "predicatrice": "predicatore",
    "predicatrici": "predicatore",
    "predicava": "predicare",
    "predicavamo": "predicare",
    "predicavan": "predicare",
    "predicavano": "predicare",
    "predicavate": "predicare",
    "predicavi": "predicare",
    "predicavo": "predicare",
    "predicazioni": "predicazione",
    "predice": "predire",
    "predicemmo": "predire",
    "predicendo": "predire",
    "predicente": "predire",
    "predicenti": "predire",
    "predicesse": "predire",
    "predicesser": "predire",
    "predicessero": "predire",
    "predicessi": "predire",
    "predicessimo": "predire",
    "prediceste": "predire",
    "predicesti": "predire",
    "prediceva": "predire",
    "predicevamo": "predire",
    "predicevan": "predire",
    "predicevano": "predire",
    "predicevate": "predire",
    "predicevi": "predire",
    "predicevo": "predire",
    "prediche": "predica",
    "predicherai": "predicare",
    "predicheran": "predicare",
    "predicheranno": "predicare",
    "predicherebbe": "predicare",
    "predicherebber": "predicare",
    "predicherebbero": "predicare",
    "predicherei": "predicare",
    "predicheremmo": "predicare",
    "predicheremo": "predicare",
    "predichereste": "predicare",
    "predicheresti": "predicare",
    "predicherete": "predicare",
    "predicherà": "predicare",
    "predicherò": "predicare",
    "predichi": "predicare",
    "predichiamo": "predicare",
    "predichiate": "predicare",
    "predichin": "predicare",
    "predichino": "predicare",
    "predici": "predire",
    "prediciamo": "predire",
    "prediciate": "predire",
    "predico": "predire",
    "predicon": "predire",
    "predicono": "predire",
    "predicozzi": "predicozzo",
    "predicò": "predicare",
    "predilesse": "prediligere",
    "predilesser": "prediligere",
    "predilessero": "prediligere",
    "predilessi": "prediligere",
    "prediletta": "prediligere",
    "predilette": "prediligere",
    "prediletti": "prediligere",
    "prediletto": "prediligere",
    "predilezioni": "predilezione",
    "prediliga": "prediligere",
    "prediligan": "prediligere",
    "prediligano": "prediligere",
    "predilige": "prediligere",
    "prediligemmo": "prediligere",
    "prediligendo": "prediligere",
    "prediligente": "prediligere",
    "prediligenti": "prediligere",
    "prediliger": "prediligere",
    "prediligerai": "prediligere",
    "prediligeran": "prediligere",
    "prediligeranno": "prediligere",
    "prediligerebbe": "prediligere",
    "prediligerebber": "prediligere",
    "prediligerebbero": "prediligere",
    "prediligerei": "prediligere",
    "prediligeremmo": "prediligere",
    "prediligeremo": "prediligere",
    "prediligereste": "prediligere",
    "prediligeresti": "prediligere",
    "prediligerete": "prediligere",
    "prediligerà": "prediligere",
    "prediligerò": "prediligere",
    "prediligesse": "prediligere",
    "prediligesser": "prediligere",
    "prediligessero": "prediligere",
    "prediligessi": "prediligere",
    "prediligessimo": "prediligere",
    "prediligeste": "prediligere",
    "prediligesti": "prediligere",
    "prediligete": "prediligere",
    "prediligeva": "prediligere",
    "prediligevamo": "prediligere",
    "prediligevan": "prediligere",
    "prediligevano": "prediligere",
    "prediligevate": "prediligere",
    "prediligevi": "prediligere",
    "prediligevo": "prediligere",
    "prediligi": "prediligere",
    "prediligiamo": "prediligere",
    "prediligiate": "prediligere",
    "prediligo": "prediligere",
    "prediligon": "prediligere",
    "prediligono": "prediligere",
    "predin": "predare",
    "predino": "predare",
    "predir": "predire",
    "predirai": "predire",
    "prediran": "predire",
    "prediranno": "predire",
    "predirebbe": "predire",
    "predirebber": "predire",
    "predirebbero": "predire",
    "predirei": "predire",
    "prediremmo": "predire",
    "prediremo": "predire",
    "predireste": "predire",
    "prediresti": "predire",
    "predirete": "predire",
    "predirà": "predire",
    "predirò": "predire",
    "predispone": "predisporre",
    "predisponemmo": "predisporre",
    "predisponendo": "predisporre",
    "predisponente": "predisporre",
    "predisponenti": "predisporre",
    "predisponesse": "predisporre",
    "predisponesser": "predisporre",
    "predisponessero": "predisporre",
    "predisponessi": "predisporre",
    "predisponessimo": "predisporre",
    "predisponeste": "predisporre",
    "predisponesti": "predisporre",
    "predisponete": "predisporre",
    "predisponeva": "predisporre",
    "predisponevamo": "predisporre",
    "predisponevan": "predisporre",
    "predisponevano": "predisporre",
    "predisponevate": "predisporre",
    "predisponevi": "predisporre",
    "predisponevo": "predisporre",
    "predisponga": "predisporre",
    "predispongan": "predisporre",
    "predispongano": "predisporre",
    "predispongo": "predisporre",
    "predispongon": "predisporre",
    "predispongono": "predisporre",
    "predisponi": "predisporre",
    "predisponiamo": "predisporre",
    "predisponiate": "predisporre",
    "predisporr": "predisporre",
    "predisporrai": "predisporre",
    "predisporran": "predisporre",
    "predisporranno": "predisporre",
    "predisporrebbe": "predisporre",
    "predisporrebber": "predisporre",
    "predisporrebbero": "predisporre",
    "predisporrei": "predisporre",
    "predisporremmo": "predisporre",
    "predisporremo": "predisporre",
    "predisporreste": "predisporre",
    "predisporresti": "predisporre",
    "predisporrete": "predisporre",
    "predisporrà": "predisporre",
    "predisporrò": "predisporre",
    "predispose": "predisporre",
    "predisposer": "predisporre",
    "predisposero": "predisporre",
    "predisposi": "predisporre",
    "predisposizioni": "predisposizione",
    "predisposta": "predisposto",
    "predisposte": "predisposto",
    "predisposti": "predisposto",
    "predisposto": "predisporre",
    "predisse": "predire",
    "predisser": "predire",
    "predissero": "predire",
    "predissi": "predire",
    "predite": "predire",
    "predizioni": "predizione",
    "predo": "predare",
    "predomina": "predominare",
    "predominai": "predominare",
    "predominammo": "predominare",
    "predominan": "predominare",
    "predominando": "predominare",
    "predominano": "predominare",
    "predominante": "predominare",
    "predominanti": "predominare",
    "predominanze": "predominanza",
    "predominar": "predominare",
    "predominaron": "predominare",
    "predominarono": "predominare",
    "predominasse": "predominare",
    "predominasser": "predominare",
    "predominassero": "predominare",
    "predominassi": "predominare",
    "predominassimo": "predominare",
    "predominaste": "predominare",
    "predominasti": "predominare",
    "predominata": "predominare",
    "predominate": "predominare",
    "predominati": "predominare",
    "predominato": "predominare",
    "predominava": "predominare",
    "predominavamo": "predominare",
    "predominavan": "predominare",
    "predominavano": "predominare",
    "predominavate": "predominare",
    "predominavi": "predominare",
    "predominavo": "predominare",
    "predominerai": "predominare",
    "predomineran": "predominare",
    "predomineranno": "predominare",
    "predominerebbe": "predominare",
    "predominerebber": "predominare",
    "predominerebbero": "predominare",
    "predominerei": "predominare",
    "predomineremmo": "predominare",
    "predomineremo": "predominare",
    "predominereste": "predominare",
    "predomineresti": "predominare",
    "predominerete": "predominare",
    "predominerà": "predominare",
    "predominerò": "predominare",
    "predomini": "predominio",
    "predominiamo": "predominare",
    "predominiate": "predominare",
    "predominin": "predominare",
    "predominino": "predominare",
    "predomino": "predominare",
    "predominò": "predominare",
    "predoni": "predone",
    "predò": "predare",
    "preelettorali": "preelettorale",
    "preesista": "preesistere",
    "preesistan": "preesistere",
    "preesistano": "preesistere",
    "preesiste": "preesistere",
    "preesistei": "preesistere",
    "preesistemmo": "preesistere",
    "preesistendo": "preesistere",
    "preesistente": "preesistere",
    "preesistenti": "preesistere",
    "preesister": "preesistere",
    "preesisterai": "preesistere",
    "preesisteran": "preesistere",
    "preesisteranno": "preesistere",
    "preesisterebbe": "preesistere",
    "preesisterebber": "preesistere",
    "preesisterebbero": "preesistere",
    "preesisterei": "preesistere",
    "preesisteremmo": "preesistere",
    "preesisteremo": "preesistere",
    "preesistereste": "preesistere",
    "preesisteresti": "preesistere",
    "preesisterete": "preesistere",
    "preesisteron": "preesistere",
    "preesisterono": "preesistere",
    "preesisterà": "preesistere",
    "preesisterò": "preesistere",
    "preesistesse": "preesistere",
    "preesistesser": "preesistere",
    "preesistessero": "preesistere",
    "preesistessi": "preesistere",
    "preesistessimo": "preesistere",
    "preesisteste": "preesistere",
    "preesistesti": "preesistere",
    "preesistete": "preesistere",
    "preesisteva": "preesistere",
    "preesistevamo": "preesistere",
    "preesistevan": "preesistere",
    "preesistevano": "preesistere",
    "preesistevate": "preesistere",
    "preesistevi": "preesistere",
    "preesistevo": "preesistere",
    "preesisti": "preesistere",
    "preesistiamo": "preesistere",
    "preesistiate": "preesistere",
    "preesisto": "preesistere",
    "preesiston": "preesistere",
    "preesistono": "preesistere",
    "preesistuta": "preesistere",
    "preesistute": "preesistere",
    "preesistuti": "preesistere",
    "preesistuto": "preesistere",
    "preesistè": "preesistere",
    "prefabbrica": "prefabbricare",
    "prefabbricai": "prefabbricare",
    "prefabbricammo": "prefabbricare",
    "prefabbrican": "prefabbricare",
    "prefabbricando": "prefabbricare",
    "prefabbricano": "prefabbricare",
    "prefabbricante": "prefabbricare",
    "prefabbricanti": "prefabbricare",
    "prefabbricar": "prefabbricare",
    "prefabbricaron": "prefabbricare",
    "prefabbricarono": "prefabbricare",
    "prefabbricasse": "prefabbricare",
    "prefabbricasser": "prefabbricare",
    "prefabbricassero": "prefabbricare",
    "prefabbricassi": "prefabbricare",
    "prefabbricassimo": "prefabbricare",
    "prefabbricaste": "prefabbricare",
    "prefabbricasti": "prefabbricare",
    "prefabbricata": "prefabbricato",
    "prefabbricate": "prefabbricato",
    "prefabbricati": "prefabbricato",
    "prefabbricato": "prefabbricare",
    "prefabbricava": "prefabbricare",
    "prefabbricavamo": "prefabbricare",
    "prefabbricavan": "prefabbricare",
    "prefabbricavano": "prefabbricare",
    "prefabbricavate": "prefabbricare",
    "prefabbricavi": "prefabbricare",
    "prefabbricavo": "prefabbricare",
    "prefabbricherai": "prefabbricare",
    "prefabbricheran": "prefabbricare",
    "prefabbricheranno": "prefabbricare",
    "prefabbricherebbe": "prefabbricare",
    "prefabbricherebber": "prefabbricare",
    "prefabbricherebbero": "prefabbricare",
    "prefabbricherei": "prefabbricare",
    "prefabbricheremmo": "prefabbricare",
    "prefabbricheremo": "prefabbricare",
    "prefabbrichereste": "prefabbricare",
    "prefabbricheresti": "prefabbricare",
    "prefabbricherete": "prefabbricare",
    "prefabbricherà": "prefabbricare",
    "prefabbricherò": "prefabbricare",
    "prefabbrichi": "prefabbricare",
    "prefabbrichiamo": "prefabbricare",
    "prefabbrichiate": "prefabbricare",
    "prefabbrichin": "prefabbricare",
    "prefabbrichino": "prefabbricare",
    "prefabbrico": "prefabbricare",
    "prefabbricò": "prefabbricare",
    "prefazioni": "prefazione",
    "preferendo": "preferire",
    "preferente": "preferire",
    "preferenti": "preferire",
    "preferenze": "preferenza",
    "preferenziali": "preferenziale",
    "preferiamo": "preferire",
    "preferiate": "preferire",
    "preferibili": "preferibile",
    "preferii": "preferire",
    "preferimmo": "preferire",
    "preferir": "preferire",
    "preferirai": "preferire",
    "preferiran": "preferire",
    "preferiranno": "preferire",
    "preferirebbe": "preferire",
    "preferirebber": "preferire",
    "preferirebbero": "preferire",
    "preferirei": "preferire",
    "preferiremmo": "preferire",
    "preferiremo": "preferire",
    "preferireste": "preferire",
    "preferiresti": "preferire",
    "preferirete": "preferire",
    "preferiron": "preferire",
    "preferirono": "preferire",
    "preferirà": "preferire",
    "preferirò": "preferire",
    "preferisca": "preferire",
    "preferiscan": "preferire",
    "preferiscano": "preferire",
    "preferisce": "preferire",
    "preferisci": "preferire",
    "preferisco": "preferire",
    "preferiscon": "preferire",
    "preferiscono": "preferire",
    "preferisse": "preferire",
    "preferisser": "preferire",
    "preferissero": "preferire",
    "preferissi": "preferire",
    "preferissimo": "preferire",
    "preferiste": "preferire",
    "preferisti": "preferire",
    "preferita": "preferito",
    "preferite": "preferito",
    "preferiti": "preferito",
    "preferito": "preferire",
    "preferiva": "preferire",
    "preferivamo": "preferire",
    "preferivan": "preferire",
    "preferivano": "preferire",
    "preferivate": "preferire",
    "preferivi": "preferire",
    "preferivo": "preferire",
    "preferì": "preferire",
    "prefestiva": "prefestivo",
    "prefestive": "prefestivo",
    "prefestivi": "prefestivo",
    "prefetti": "prefetto",
    "prefettizi": "prefettizio",
    "prefettizia": "prefettizio",
    "prefettizie": "prefettizio",
    "prefetture": "prefettura",
    "prefigga": "prefiggere",
    "prefiggan": "prefiggere",
    "prefiggano": "prefiggere",
    "prefigge": "prefiggere",
    "prefiggemmo": "prefiggere",
    "prefiggendo": "prefiggere",
    "prefiggente": "prefiggere",
    "prefiggenti": "prefiggere",
    "prefigger": "prefiggere",
    "prefiggerai": "prefiggere",
    "prefiggeran": "prefiggere",
    "prefiggeranno": "prefiggere",
    "prefiggerebbe": "prefiggere",
    "prefiggerebber": "prefiggere",
    "prefiggerebbero": "prefiggere",
    "prefiggerei": "prefiggere",
    "prefiggeremmo": "prefiggere",
    "prefiggeremo": "prefiggere",
    "prefiggereste": "prefiggere",
    "prefiggeresti": "prefiggere",
    "prefiggerete": "prefiggere",
    "prefiggerà": "prefiggere",
    "prefiggerò": "prefiggere",
    "prefiggesse": "prefiggere",
    "prefiggesser": "prefiggere",
    "prefiggessero": "prefiggere",
    "prefiggessi": "prefiggere",
    "prefiggessimo": "prefiggere",
    "prefiggeste": "prefiggere",
    "prefiggesti": "prefiggere",
    "prefiggete": "prefiggere",
    "prefiggeva": "prefiggere",
    "prefiggevamo": "prefiggere",
    "prefiggevan": "prefiggere",
    "prefiggevano": "prefiggere",
    "prefiggevate": "prefiggere",
    "prefiggevi": "prefiggere",
    "prefiggevo": "prefiggere",
    "prefiggi": "prefiggere",
    "prefiggiamo": "prefiggere",
    "prefiggiate": "prefiggere",
    "prefiggo": "prefiggere",
    "prefiggon": "prefiggere",
    "prefiggono": "prefiggere",
    "prefigura": "prefigurare",
    "prefigurai": "prefigurare",
    "prefigurammo": "prefigurare",
    "prefiguran": "prefigurare",
    "prefigurando": "prefigurare",
    "prefigurano": "prefigurare",
    "prefigurante": "prefigurare",
    "prefiguranti": "prefigurare",
    "prefigurar": "prefigurare",
    "prefiguraron": "prefigurare",
    "prefigurarono": "prefigurare",
    "prefigurasse": "prefigurare",
    "prefigurasser": "prefigurare",
    "prefigurassero": "prefigurare",
    "prefigurassi": "prefigurare",
    "prefigurassimo": "prefigurare",
    "prefiguraste": "prefigurare",
    "prefigurasti": "prefigurare",
    "prefigurata": "prefigurare",
    "prefigurate": "prefigurare",
    "prefigurati": "prefigurare",
    "prefigurato": "prefigurare",
    "prefigurava": "prefigurare",
    "prefiguravamo": "prefigurare",
    "prefiguravan": "prefigurare",
    "prefiguravano": "prefigurare",
    "prefiguravate": "prefigurare",
    "prefiguravi": "prefigurare",
    "prefiguravo": "prefigurare",
    "prefigurazioni": "prefigurazione",
    "prefigurerai": "prefigurare",
    "prefigureran": "prefigurare",
    "prefigureranno": "prefigurare",
    "prefigurerebbe": "prefigurare",
    "prefigurerebber": "prefigurare",
    "prefigurerebbero": "prefigurare",
    "prefigurerei": "prefigurare",
    "prefigureremmo": "prefigurare",
    "prefigureremo": "prefigurare",
    "prefigurereste": "prefigurare",
    "prefigureresti": "prefigurare",
    "prefigurerete": "prefigurare",
    "prefigurerà": "prefigurare",
    "prefigurerò": "prefigurare",
    "prefiguri": "prefigurare",
    "prefiguriamo": "prefigurare",
    "prefiguriate": "prefigurare",
    "prefigurin": "prefigurare",
    "prefigurino": "prefigurare",
    "prefiguro": "prefigurare",
    "prefigurò": "prefigurare",
    "prefinanzi": "prefinanziare",
    "prefinanzia": "prefinanziare",
    "prefinanziai": "prefinanziare",
    "prefinanziammo": "prefinanziare",
    "prefinanziamo": "prefinanziare",
    "prefinanzian": "prefinanziare",
    "prefinanziando": "prefinanziare",
    "prefinanziano": "prefinanziare",
    "prefinanziante": "prefinanziare",
    "prefinanzianti": "prefinanziare",
    "prefinanziar": "prefinanziare",
    "prefinanziaron": "prefinanziare",
    "prefinanziarono": "prefinanziare",
    "prefinanziasse": "prefinanziare",
    "prefinanziasser": "prefinanziare",
    "prefinanziassero": "prefinanziare",
    "prefinanziassi": "prefinanziare",
    "prefinanziassimo": "prefinanziare",
    "prefinanziaste": "prefinanziare",
    "prefinanziasti": "prefinanziare",
    "prefinanziata": "prefinanziare",
    "prefinanziate": "prefinanziare",
    "prefinanziati": "prefinanziare",
    "prefinanziato": "prefinanziare",
    "prefinanziava": "prefinanziare",
    "prefinanziavamo": "prefinanziare",
    "prefinanziavan": "prefinanziare",
    "prefinanziavano": "prefinanziare",
    "prefinanziavate": "prefinanziare",
    "prefinanziavi": "prefinanziare",
    "prefinanziavo": "prefinanziare",
    "prefinanzierai": "prefinanziare",
    "prefinanzieran": "prefinanziare",
    "prefinanzieranno": "prefinanziare",
    "prefinanzierebbe": "prefinanziare",
    "prefinanzierebber": "prefinanziare",
    "prefinanzierebbero": "prefinanziare",
    "prefinanzierei": "prefinanziare",
    "prefinanzieremmo": "prefinanziare",
    "prefinanzieremo": "prefinanziare",
    "prefinanziereste": "prefinanziare",
    "prefinanzieresti": "prefinanziare",
    "prefinanzierete": "prefinanziare",
    "prefinanzierà": "prefinanziare",
    "prefinanzierò": "prefinanziare",
    "prefinanzin": "prefinanziare",
    "prefinanzino": "prefinanziare",
    "prefinanzio": "prefinanziare",
    "prefinanziò": "prefinanziare",
    "prefissa": "prefissare",
    "prefissai": "prefissare",
    "prefissammo": "prefissare",
    "prefissan": "prefissare",
    "prefissando": "prefissare",
    "prefissano": "prefissare",
    "prefissante": "prefissare",
    "prefissanti": "prefissare",
    "prefissar": "prefissare",
    "prefissaron": "prefissare",
    "prefissarono": "prefissare",
    "prefissasse": "prefissare",
    "prefissasser": "prefissare",
    "prefissassero": "prefissare",
    "prefissassi": "prefissare",
    "prefissassimo": "prefissare",
    "prefissaste": "prefissare",
    "prefissasti": "prefissare",
    "prefissata": "prefissato",
    "prefissate": "prefissato",
    "prefissati": "prefissato",
    "prefissato": "prefissare",
    "prefissava": "prefissare",
    "prefissavamo": "prefissare",
    "prefissavan": "prefissare",
    "prefissavano": "prefissare",
    "prefissavate": "prefissare",
    "prefissavi": "prefissare",
    "prefissavo": "prefissare",
    "prefisser": "prefiggere",
    "prefisserai": "prefissare",
    "prefisseran": "prefissare",
    "prefisseranno": "prefissare",
    "prefisserebbe": "prefissare",
    "prefisserebber": "prefissare",
    "prefisserebbero": "prefissare",
    "prefisserei": "prefissare",
    "prefisseremmo": "prefissare",
    "prefisseremo": "prefissare",
    "prefissereste": "prefissare",
    "prefisseresti": "prefissare",
    "prefisserete": "prefissare",
    "prefissero": "prefiggere",
    "prefisserà": "prefissare",
    "prefisserò": "prefissare",
    "prefissi": "prefisso",
    "prefissiamo": "prefissare",
    "prefissiate": "prefissare",
    "prefissin": "prefissare",
    "prefissino": "prefissare",
    "prefisso": "prefissare",
    "prefissè": "prefiggere",
    "prefissò": "prefissare",
    "prefitta": "prefiggere",
    "prefitte": "prefiggere",
    "prefitti": "prefiggere",
    "prefitto": "prefiggere",
    "prega": "pregare",
    "pregai": "pregare",
    "pregammo": "pregare",
    "pregan": "pregare",
    "pregando": "pregare",
    "pregano": "pregare",
    "pregante": "pregare",
    "preganti": "pregare",
    "pregar": "pregare",
    "pregaron": "pregare",
    "pregarono": "pregare",
    "pregasse": "pregare",
    "pregasser": "pregare",
    "pregassero": "pregare",
    "pregassi": "pregare",
    "pregassimo": "pregare",
    "pregaste": "pregare",
    "pregasti": "pregare",
    "pregata": "pregare",
    "pregate": "pregare",
    "pregati": "pregare",
    "pregato": "pregare",
    "pregava": "pregare",
    "pregavamo": "pregare",
    "pregavan": "pregare",
    "pregavano": "pregare",
    "pregavate": "pregare",
    "pregavi": "pregare",
    "pregavo": "pregare",
    "pregerai": "pregiare",
    "pregeran": "pregiare",
    "pregeranno": "pregiare",
    "pregerebbe": "pregiare",
    "pregerebber": "pregiare",
    "pregerebbero": "pregiare",
    "pregerei": "pregiare",
    "pregeremmo": "pregiare",
    "pregeremo": "pregiare",
    "pregereste": "pregiare",
    "pregeresti": "pregiare",
    "pregerete": "pregiare",
    "pregerà": "pregiare",
    "pregerò": "pregiare",
    "pregevoli": "pregevole",
    "pregherai": "pregare",
    "pregheran": "pregare",
    "pregheranno": "pregare",
    "pregherebbe": "pregare",
    "pregherebber": "pregare",
    "pregherebbero": "pregare",
    "pregherei": "pregare",
    "pregheremmo": "pregare",
    "pregheremo": "pregare",
    "preghereste": "pregare",
    "pregheresti": "pregare",
    "pregherete": "pregare",
    "pregherà": "pregare",
    "pregherò": "pregare",
    "preghi": "pregare",
    "preghiamo": "pregare",
    "preghiate": "pregare",
    "preghiere": "preghiera",
    "preghin": "pregare",
    "preghino": "pregare",
    "pregi": "pregio",
    "pregia": "pregiare",
    "pregiai": "pregiare",
    "pregiammo": "pregiare",
    "pregiamo": "pregiare",
    "pregian": "pregiare",
    "pregiando": "pregiare",
    "pregiano": "pregiare",
    "pregiante": "pregiare",
    "pregianti": "pregiare",
    "pregiar": "pregiare",
    "pregiaron": "pregiare",
    "pregiarono": "pregiare",
    "pregiasse": "pregiare",
    "pregiasser": "pregiare",
    "pregiassero": "pregiare",
    "pregiassi": "pregiare",
    "pregiassimo": "pregiare",
    "pregiaste": "pregiare",
    "pregiasti": "pregiare",
    "pregiata": "pregiato",
    "pregiate": "pregiato",
    "pregiati": "pregiato",
    "pregiato": "pregiare",
    "pregiava": "pregiare",
    "pregiavamo": "pregiare",
    "pregiavan": "pregiare",
    "pregiavano": "pregiare",
    "pregiavate": "pregiare",
    "pregiavi": "pregiare",
    "pregiavo": "pregiare",
    "pregin": "pregiare",
    "pregino": "pregiare",
    "pregio": "pregiare",
    "pregiudica": "pregiudicare",
    "pregiudicai": "pregiudicare",
    "pregiudicammo": "pregiudicare",
    "pregiudican": "pregiudicare",
    "pregiudicando": "pregiudicare",
    "pregiudicano": "pregiudicare",
    "pregiudicante": "pregiudicare",
    "pregiudicanti": "pregiudicare",
    "pregiudicar": "pregiudicare",
    "pregiudicaron": "pregiudicare",
    "pregiudicarono": "pregiudicare",
    "pregiudicasse": "pregiudicare",
    "pregiudicasser": "pregiudicare",
    "pregiudicassero": "pregiudicare",
    "pregiudicassi": "pregiudicare",
    "pregiudicassimo": "pregiudicare",
    "pregiudicaste": "pregiudicare",
    "pregiudicasti": "pregiudicare",
    "pregiudicata": "pregiudicato",
    "pregiudicate": "pregiudicato",
    "pregiudicati": "pregiudicato",
    "pregiudicato": "pregiudicare",
    "pregiudicava": "pregiudicare",
    "pregiudicavamo": "pregiudicare",
    "pregiudicavan": "pregiudicare",
    "pregiudicavano": "pregiudicare",
    "pregiudicavate": "pregiudicare",
    "pregiudicavi": "pregiudicare",
    "pregiudicavo": "pregiudicare",
    "pregiudicherai": "pregiudicare",
    "pregiudicheran": "pregiudicare",
    "pregiudicheranno": "pregiudicare",
    "pregiudicherebbe": "pregiudicare",
    "pregiudicherebber": "pregiudicare",
    "pregiudicherebbero": "pregiudicare",
    "pregiudicherei": "pregiudicare",
    "pregiudicheremmo": "pregiudicare",
    "pregiudicheremo": "pregiudicare",
    "pregiudichereste": "pregiudicare",
    "pregiudicheresti": "pregiudicare",
    "pregiudicherete": "pregiudicare",
    "pregiudicherà": "pregiudicare",
    "pregiudicherò": "pregiudicare",
    "pregiudichi": "pregiudicare",
    "pregiudichiamo": "pregiudicare",
    "pregiudichiate": "pregiudicare",
    "pregiudichin": "pregiudicare",
    "pregiudichino": "pregiudicare",
    "pregiudico": "pregiudicare",
    "pregiudicò": "pregiudicare",
    "pregiudizi": "pregiudizio",
    "pregiudiziali": "pregiudiziale",
    "pregiudizievoli": "pregiudizievole",
    "pregiò": "pregiare",
    "pregnanti": "pregnante",
    "pregnanze": "pregnanza",
    "prego": "pregare",
    "pregressa": "pregresso",
    "pregresse": "pregresso",
    "pregressi": "pregresso",
    "pregusta": "pregustare",
    "pregustai": "pregustare",
    "pregustammo": "pregustare",
    "pregustan": "pregustare",
    "pregustando": "pregustare",
    "pregustano": "pregustare",
    "pregustante": "pregustare",
    "pregustanti": "pregustare",
    "pregustar": "pregustare",
    "pregustaron": "pregustare",
    "pregustarono": "pregustare",
    "pregustasse": "pregustare",
    "pregustasser": "pregustare",
    "pregustassero": "pregustare",
    "pregustassi": "pregustare",
    "pregustassimo": "pregustare",
    "pregustaste": "pregustare",
    "pregustasti": "pregustare",
    "pregustata": "pregustare",
    "pregustate": "pregustare",
    "pregustati": "pregustare",
    "pregustato": "pregustare",
    "pregustava": "pregustare",
    "pregustavamo": "pregustare",
    "pregustavan": "pregustare",
    "pregustavano": "pregustare",
    "pregustavate": "pregustare",
    "pregustavi": "pregustare",
    "pregustavo": "pregustare",
    "pregusterai": "pregustare",
    "pregusteran": "pregustare",
    "pregusteranno": "pregustare",
    "pregusterebbe": "pregustare",
    "pregusterebber": "pregustare",
    "pregusterebbero": "pregustare",
    "pregusterei": "pregustare",
    "pregusteremmo": "pregustare",
    "pregusteremo": "pregustare",
    "pregustereste": "pregustare",
    "pregusteresti": "pregustare",
    "pregusterete": "pregustare",
    "pregusterà": "pregustare",
    "pregusterò": "pregustare",
    "pregusti": "pregustare",
    "pregustiamo": "pregustare",
    "pregustiate": "pregustare",
    "pregustin": "pregustare",
    "pregustino": "pregustare",
    "pregusto": "pregustare",
    "pregustò": "pregustare",
    "pregò": "pregare",
    "preistorica": "preistorico",
    "preistoriche": "preistorico",
    "preistorici": "preistorico",
    "preistorie": "preistoria",
    "prelati": "prelato",
    "prelature": "prelatura",
    "prelazioni": "prelazione",
    "preleva": "prelevare",
    "prelevai": "prelevare",
    "prelevamenti": "prelevamento",
    "prelevammo": "prelevare",
    "prelevan": "prelevare",
    "prelevando": "prelevare",
    "prelevano": "prelevare",
    "prelevante": "prelevare",
    "prelevanti": "prelevare",
    "prelevar": "prelevare",
    "prelevaron": "prelevare",
    "prelevarono": "prelevare",
    "prelevasse": "prelevare",
    "prelevasser": "prelevare",
    "prelevassero": "prelevare",
    "prelevassi": "prelevare",
    "prelevassimo": "prelevare",
    "prelevaste": "prelevare",
    "prelevasti": "prelevare",
    "prelevata": "prelevare",
    "prelevate": "prelevare",
    "prelevati": "prelevare",
    "prelevato": "prelevare",
    "prelevava": "prelevare",
    "prelevavamo": "prelevare",
    "prelevavan": "prelevare",
    "prelevavano": "prelevare",
    "prelevavate": "prelevare",
    "prelevavi": "prelevare",
    "prelevavo": "prelevare",
    "preleverai": "prelevare",
    "preleveran": "prelevare",
    "preleveranno": "prelevare",
    "preleverebbe": "prelevare",
    "preleverebber": "prelevare",
    "preleverebbero": "prelevare",
    "preleverei": "prelevare",
    "preleveremmo": "prelevare",
    "preleveremo": "prelevare",
    "prelevereste": "prelevare",
    "preleveresti": "prelevare",
    "preleverete": "prelevare",
    "preleverà": "prelevare",
    "preleverò": "prelevare",
    "prelevi": "prelevare",
    "preleviamo": "prelevare",
    "preleviate": "prelevare",
    "prelevin": "prelevare",
    "prelevino": "prelevare",
    "prelevo": "prelevare",
    "prelevò": "prelevare",
    "preliba": "prelibare",
    "prelibai": "prelibare",
    "prelibammo": "prelibare",
    "preliban": "prelibare",
    "prelibando": "prelibare",
    "prelibano": "prelibare",
    "prelibante": "prelibare",
    "prelibanti": "prelibare",
    "prelibar": "prelibare",
    "prelibaron": "prelibare",
    "prelibarono": "prelibare",
    "prelibasse": "prelibare",
    "prelibasser": "prelibare",
    "prelibassero": "prelibare",
    "prelibassi": "prelibare",
    "prelibassimo": "prelibare",
    "prelibaste": "prelibare",
    "prelibasti": "prelibare",
    "prelibata": "prelibato",
    "prelibate": "prelibato",
    "prelibatezze": "prelibatezza",
    "prelibati": "prelibato",
    "prelibato": "prelibare",
    "prelibava": "prelibare",
    "prelibavamo": "prelibare",
    "prelibavan": "prelibare",
    "prelibavano": "prelibare",
    "prelibavate": "prelibare",
    "prelibavi": "prelibare",
    "prelibavo": "prelibare",
    "preliberai": "prelibare",
    "preliberan": "prelibare",
    "preliberanno": "prelibare",
    "preliberebbe": "prelibare",
    "preliberebber": "prelibare",
    "preliberebbero": "prelibare",
    "preliberei": "prelibare",
    "preliberemmo": "prelibare",
    "preliberemo": "prelibare",
    "prelibereste": "prelibare",
    "preliberesti": "prelibare",
    "preliberete": "prelibare",
    "preliberà": "prelibare",
    "preliberò": "prelibare",
    "prelibi": "prelibare",
    "prelibiamo": "prelibare",
    "prelibiate": "prelibare",
    "prelibin": "prelibare",
    "prelibino": "prelibare",
    "prelibo": "prelibare",
    "prelibò": "prelibare",
    "prelievi": "prelievo",
    "preliminari": "preliminare",
    "preluda": "preludere",
    "preludan": "preludere",
    "preludano": "preludere",
    "prelude": "preludere",
    "preludei": "preludere",
    "preludemmo": "preludere",
    "preludendo": "preludere",
    "preludente": "preludere",
    "preludenti": "preludere",
    "preluder": "preludere",
    "preluderai": "preludere",
    "preluderan": "preludere",
    "preluderanno": "preludere",
    "preluderebbe": "preludere",
    "preluderebber": "preludere",
    "preluderebbero": "preludere",
    "preluderei": "preludere",
    "preluderemmo": "preludere",
    "preluderemo": "preludere",
    "preludereste": "preludere",
    "preluderesti": "preludere",
    "preluderete": "preludere",
    "preluderon": "preludere",
    "preluderono": "preludere",
    "preluderà": "preludere",
    "preluderò": "preludere",
    "preludesse": "preludere",
    "preludesser": "preludere",
    "preludessero": "preludere",
    "preludessi": "preludere",
    "preludessimo": "preludere",
    "preludeste": "preludere",
    "preludesti": "preludere",
    "preludete": "preludere",
    "preludeva": "preludere",
    "preludevamo": "preludere",
    "preludevan": "preludere",
    "preludevano": "preludere",
    "preludevate": "preludere",
    "preludevi": "preludere",
    "preludevo": "preludere",
    "preludi": "preludio",
    "preludia": "preludiare",
    "preludiai": "preludiare",
    "preludiammo": "preludiare",
    "preludiamo": "preludiare",
    "preludian": "preludiare",
    "preludiando": "preludiare",
    "preludiano": "preludiare",
    "preludiante": "preludiare",
    "preludianti": "preludiare",
    "preludiar": "preludiare",
    "preludiaron": "preludiare",
    "preludiarono": "preludiare",
    "preludiasse": "preludiare",
    "preludiasser": "preludiare",
    "preludiassero": "preludiare",
    "preludiassi": "preludiare",
    "preludiassimo": "preludiare",
    "preludiaste": "preludiare",
    "preludiasti": "preludiare",
    "preludiata": "preludiare",
    "preludiate": "preludiare",
    "preludiati": "preludiare",
    "preludiato": "preludiare",
    "preludiava": "preludiare",
    "preludiavamo": "preludiare",
    "preludiavan": "preludiare",
    "preludiavano": "preludiare",
    "preludiavate": "preludiare",
    "preludiavi": "preludiare",
    "preludiavo": "preludiare",
    "preludierai": "preludiare",
    "preludieran": "preludiare",
    "preludieranno": "preludiare",
    "preludierebbe": "preludiare",
    "preludierebber": "preludiare",
    "preludierebbero": "preludiare",
    "preludierei": "preludiare",
    "preludieremmo": "preludiare",
    "preludieremo": "preludiare",
    "preludiereste": "preludiare",
    "preludieresti": "preludiare",
    "preludierete": "preludiare",
    "preludierà": "preludiare",
    "preludierò": "preludiare",
    "preludin": "preludiare",
    "preludino": "preludiare",
    "preludio": "preludiare",
    "preludiò": "preludiare",
    "preludo": "preludere",
    "preludon": "preludere",
    "preludono": "preludere",
    "preluduta": "preludere",
    "preludute": "preludere",
    "preluduti": "preludere",
    "preluduto": "preludere",
    "preludè": "preludere",
    "prema": "premere",
    "preman": "premere",
    "premano": "premere",
    "prematrimoniali": "prematrimoniale",
    "prematura": "prematuro",
    "premature": "prematuro",
    "prematuri": "prematuro",
    "preme": "premere",
    "premedita": "premeditare",
    "premeditai": "premeditare",
    "premeditammo": "premeditare",
    "premeditan": "premeditare",
    "premeditando": "premeditare",
    "premeditano": "premeditare",
    "premeditante": "premeditare",
    "premeditanti": "premeditare",
    "premeditar": "premeditare",
    "premeditaron": "premeditare",
    "premeditarono": "premeditare",
    "premeditasse": "premeditare",
    "premeditasser": "premeditare",
    "premeditassero": "premeditare",
    "premeditassi": "premeditare",
    "premeditassimo": "premeditare",
    "premeditaste": "premeditare",
    "premeditasti": "premeditare",
    "premeditata": "premeditare",
    "premeditate": "premeditare",
    "premeditati": "premeditare",
    "premeditato": "premeditare",
    "premeditava": "premeditare",
    "premeditavamo": "premeditare",
    "premeditavan": "premeditare",
    "premeditavano": "premeditare",
    "premeditavate": "premeditare",
    "premeditavi": "premeditare",
    "premeditavo": "premeditare",
    "premeditazioni": "premeditazione",
    "premediterai": "premeditare",
    "premediteran": "premeditare",
    "premediteranno": "premeditare",
    "premediterebbe": "premeditare",
    "premediterebber": "premeditare",
    "premediterebbero": "premeditare",
    "premediterei": "premeditare",
    "premediteremmo": "premeditare",
    "premediteremo": "premeditare",
    "premeditereste": "premeditare",
    "premediteresti": "premeditare",
    "premediterete": "premeditare",
    "premediterà": "premeditare",
    "premediterò": "premeditare",
    "premediti": "premeditare",
    "premeditiamo": "premeditare",
    "premeditiate": "premeditare",
    "premeditin": "premeditare",
    "premeditino": "premeditare",
    "premedito": "premeditare",
    "premeditò": "premeditare",
    "premei": "premere",
    "prememmo": "premere",
    "premendo": "premere",
    "premente": "premere",
    "prementi": "premere",
    "premer": "premere",
    "premerai": "premere",
    "premeran": "premere",
    "premeranno": "premere",
    "premerebbe": "premere",
    "premerebber": "premere",
    "premerebbero": "premere",
    "premerei": "premere",
    "premeremmo": "premere",
    "premeremo": "premere",
    "premereste": "premere",
    "premeresti": "premere",
    "premerete": "premere",
    "premeron": "premere",
    "premerono": "premere",
    "premerà": "premere",
    "premerò": "premere",
    "premessa": "premettere",
    "premesse": "premettere",
    "premesser": "premere",
    "premessero": "premere",
    "premessi": "premettere",
    "premessimo": "premere",
    "premesso": "premettere",
    "premeste": "premere",
    "premesti": "premere",
    "premete": "premere",
    "premetta": "premettere",
    "premettan": "premettere",
    "premettano": "premettere",
    "premette": "premettere",
    "premettemmo": "premettere",
    "premettendo": "premettere",
    "premettente": "premettere",
    "premettenti": "premettere",
    "premetter": "premettere",
    "premetterai": "premettere",
    "premetteran": "premettere",
    "premetteranno": "premettere",
    "premetterebbe": "premettere",
    "premetterebber": "premettere",
    "premetterebbero": "premettere",
    "premetterei": "premettere",
    "premetteremmo": "premettere",
    "premetteremo": "premettere",
    "premettereste": "premettere",
    "premetteresti": "premettere",
    "premetterete": "premettere",
    "premetterà": "premettere",
    "premetterò": "premettere",
    "premettesse": "premettere",
    "premettesser": "premettere",
    "premettessero": "premettere",
    "premettessi": "premettere",
    "premettessimo": "premettere",
    "premetteste": "premettere",
    "premettesti": "premettere",
    "premettete": "premettere",
    "premetteva": "premettere",
    "premettevamo": "premettere",
    "premettevan": "premettere",
    "premettevano": "premettere",
    "premettevate": "premettere",
    "premettevi": "premettere",
    "premettevo": "premettere",
    "premetti": "premettere",
    "premettiamo": "premettere",
    "premettiate": "premettere",
    "premetto": "premettere",
    "premetton": "premettere",
    "premettono": "premettere",
    "premeva": "premere",
    "premevamo": "premere",
    "premevan": "premere",
    "premevano": "premere",
    "premevate": "premere",
    "premevi": "premere",
    "premevo": "premere",
    "premi": "premio",
    "premia": "premiare",
    "premiai": "premiare",
    "premiammo": "premiare",
    "premiamo": "premiare",
    "premian": "premiare",
    "premiando": "premiare",
    "premiano": "premiare",
    "premiante": "premiare",
    "premianti": "premiare",
    "premiar": "premiare",
    "premiaron": "premiare",
    "premiarono": "premiare",
    "premiasse": "premiare",
    "premiasser": "premiare",
    "premiassero": "premiare",
    "premiassi": "premiare",
    "premiassimo": "premiare",
    "premiaste": "premiare",
    "premiasti": "premiare",
    "premiata": "premiato",
    "premiate": "premiato",
    "premiati": "premiato",
    "premiato": "premiare",
    "premiava": "premiare",
    "premiavamo": "premiare",
    "premiavan": "premiare",
    "premiavano": "premiare",
    "premiavate": "premiare",
    "premiavi": "premiare",
    "premiavo": "premiare",
    "premiazioni": "premiazione",
    "premierai": "premiare",
    "premieran": "premiare",
    "premieranno": "premiare",
    "premierati": "premierato",
    "premierebbe": "premiare",
    "premierebber": "premiare",
    "premierebbero": "premiare",
    "premierei": "premiare",
    "premieremmo": "premiare",
    "premieremo": "premiare",
    "premiereste": "premiare",
    "premieresti": "premiare",
    "premierete": "premiare",
    "premierà": "premiare",
    "premierò": "premiare",
    "premin": "premiare",
    "preminenti": "preminente",
    "preminenze": "preminenza",
    "premino": "premiare",
    "premio": "premiare",
    "premise": "premettere",
    "premiser": "premettere",
    "premisero": "premettere",
    "premisi": "premettere",
    "premiò": "premiare",
    "premo": "premere",
    "premoderna": "premoderno",
    "premoderne": "premoderno",
    "premoderni": "premoderno",
    "premon": "premere",
    "premonitori": "premonitore",
    "premonitrice": "premonitore",
    "premonitrici": "premonitore",
    "premonizioni": "premonizione",
    "premono": "premere",
    "premora": "premorire",
    "premoran": "premorire",
    "premorano": "premorire",
    "premore": "premorire",
    "premorendo": "premorire",
    "premorente": "premorire",
    "premorenti": "premorire",
    "premori": "premorire",
    "premoriamo": "premorire",
    "premoriate": "premorire",
    "premorii": "premorire",
    "premorimmo": "premorire",
    "premorir": "premorire",
    "premorirai": "premorire",
    "premoriran": "premorire",
    "premoriranno": "premorire",
    "premorirebbe": "premorire",
    "premorirebber": "premorire",
    "premorirebbero": "premorire",
    "premorirei": "premorire",
    "premoriremmo": "premorire",
    "premoriremo": "premorire",
    "premorireste": "premorire",
    "premoriresti": "premorire",
    "premorirete": "premorire",
    "premoriron": "premorire",
    "premorirono": "premorire",
    "premorirà": "premorire",
    "premorirò": "premorire",
    "premorisse": "premorire",
    "premorisser": "premorire",
    "premorissero": "premorire",
    "premorissi": "premorire",
    "premorissimo": "premorire",
    "premoriste": "premorire",
    "premoristi": "premorire",
    "premorita": "premorire",
    "premorite": "premorire",
    "premoriti": "premorire",
    "premorito": "premorire",
    "premoriva": "premorire",
    "premorivamo": "premorire",
    "premorivan": "premorire",
    "premorivano": "premorire",
    "premorivate": "premorire",
    "premorivi": "premorire",
    "premorivo": "premorire",
    "premoro": "premorire",
    "premoron": "premorire",
    "premorono": "premorire",
    "premorì": "premorire",
    "premunendo": "premunire",
    "premunente": "premunire",
    "premunenti": "premunire",
    "premuniamo": "premunire",
    "premuniate": "premunire",
    "premunii": "premunire",
    "premunimmo": "premunire",
    "premunir": "premunire",
    "premunirai": "premunire",
    "premuniran": "premunire",
    "premuniranno": "premunire",
    "premunirebbe": "premunire",
    "premunirebber": "premunire",
    "premunirebbero": "premunire",
    "premunirei": "premunire",
    "premuniremmo": "premunire",
    "premuniremo": "premunire",
    "premunireste": "premunire",
    "premuniresti": "premunire",
    "premunirete": "premunire",
    "premuniron": "premunire",
    "premunirono": "premunire",
    "premunirà": "premunire",
    "premunirò": "premunire",
    "premunisca": "premunire",
    "premuniscan": "premunire",
    "premuniscano": "premunire",
    "premunisce": "premunire",
    "premunisci": "premunire",
    "premunisco": "premunire",
    "premuniscon": "premunire",
    "premuniscono": "premunire",
    "premunisse": "premunire",
    "premunisser": "premunire",
    "premunissero": "premunire",
    "premunissi": "premunire",
    "premunissimo": "premunire",
    "premuniste": "premunire",
    "premunisti": "premunire",
    "premunita": "premunire",
    "premunite": "premunire",
    "premuniti": "premunire",
    "premunito": "premunire",
    "premuniva": "premunire",
    "premunivamo": "premunire",
    "premunivan": "premunire",
    "premunivano": "premunire",
    "premunivate": "premunire",
    "premunivi": "premunire",
    "premunivo": "premunire",
    "premunì": "premunire",
    "premura": "premurare",
    "premurai": "premurare",
    "premurammo": "premurare",
    "premuran": "premurare",
    "premurando": "premurare",
    "premurano": "premurare",
    "premurante": "premurare",
    "premuranti": "premurare",
    "premurar": "premurare",
    "premuraron": "premurare",
    "premurarono": "premurare",
    "premurasse": "premurare",
    "premurasser": "premurare",
    "premurassero": "premurare",
    "premurassi": "premurare",
    "premurassimo": "premurare",
    "premuraste": "premurare",
    "premurasti": "premurare",
    "premurata": "premurare",
    "premurate": "premurare",
    "premurati": "premurare",
    "premurato": "premurare",
    "premurava": "premurare",
    "premuravamo": "premurare",
    "premuravan": "premurare",
    "premuravano": "premurare",
    "premuravate": "premurare",
    "premuravi": "premurare",
    "premuravo": "premurare",
    "premure": "premura",
    "premurerai": "premurare",
    "premureran": "premurare",
    "premureranno": "premurare",
    "premurerebbe": "premurare",
    "premurerebber": "premurare",
    "premurerebbero": "premurare",
    "premurerei": "premurare",
    "premureremmo": "premurare",
    "premureremo": "premurare",
    "premurereste": "premurare",
    "premureresti": "premurare",
    "premurerete": "premurare",
    "premurerà": "premurare",
    "premurerò": "premurare",
    "premuri": "premurare",
    "premuriamo": "premurare",
    "premuriate": "premurare",
    "premurin": "premurare",
    "premurino": "premurare",
    "premuro": "premurare",
    "premurosa": "premuroso",
    "premurose": "premuroso",
    "premurosi": "premuroso",
    "premurò": "premurare",
    "premuta": "premere",
    "premute": "premere",
    "premuti": "premere",
    "premuto": "premere",
    "premè": "premere",
    "prenasca": "prenascere",
    "prenascan": "prenascere",
    "prenascano": "prenascere",
    "prenasce": "prenascere",
    "prenascei": "prenascere",
    "prenascemmo": "prenascere",
    "prenascendo": "prenascere",
    "prenascente": "prenascere",
    "prenascenti": "prenascere",
    "prenascer": "prenascere",
    "prenascerai": "prenascere",
    "prenasceran": "prenascere",
    "prenasceranno": "prenascere",
    "prenascerebbe": "prenascere",
    "prenascerebber": "prenascere",
    "prenascerebbero": "prenascere",
    "prenascerei": "prenascere",
    "prenasceremmo": "prenascere",
    "prenasceremo": "prenascere",
    "prenascereste": "prenascere",
    "prenasceresti": "prenascere",
    "prenascerete": "prenascere",
    "prenasceron": "prenascere",
    "prenascerono": "prenascere",
    "prenascerà": "prenascere",
    "prenascerò": "prenascere",
    "prenascesse": "prenascere",
    "prenascesser": "prenascere",
    "prenascessero": "prenascere",
    "prenascessi": "prenascere",
    "prenascessimo": "prenascere",
    "prenasceste": "prenascere",
    "prenascesti": "prenascere",
    "prenascete": "prenascere",
    "prenasceva": "prenascere",
    "prenascevamo": "prenascere",
    "prenascevan": "prenascere",
    "prenascevano": "prenascere",
    "prenascevate": "prenascere",
    "prenascevi": "prenascere",
    "prenascevo": "prenascere",
    "prenasci": "prenascere",
    "prenasciamo": "prenascere",
    "prenasciate": "prenascere",
    "prenasciuta": "prenascere",
    "prenasciute": "prenascere",
    "prenasciuti": "prenascere",
    "prenasciuto": "prenascere",
    "prenasco": "prenascere",
    "prenascon": "prenascere",
    "prenascono": "prenascere",
    "prenascè": "prenascere",
    "prenatali": "prenatale",
    "prenda": "prendere",
    "prendan": "prendere",
    "prendano": "prendere",
    "prende": "prendere",
    "prendemmo": "prendere",
    "prendendo": "prendere",
    "prendente": "prendere",
    "prendenti": "prendere",
    "prender": "prendere",
    "prenderai": "prendere",
    "prenderan": "prendere",
    "prenderanno": "prendere",
    "prenderebbe": "prendere",
    "prenderebber": "prendere",
    "prenderebbero": "prendere",
    "prenderei": "prendere",
    "prenderemmo": "prendere",
    "prenderemo": "prendere",
    "prendereste": "prendere",
    "prenderesti": "prendere",
    "prenderete": "prendere",
    "prenderà": "prendere",
    "prenderò": "prendere",
    "prendesse": "prendere",
    "prendesser": "prendere",
    "prendessero": "prendere",
    "prendessi": "prendere",
    "prendessimo": "prendere",
    "prendeste": "prendere",
    "prendesti": "prendere",
    "prendete": "prendere",
    "prendeva": "prendere",
    "prendevamo": "prendere",
    "prendevan": "prendere",
    "prendevano": "prendere",
    "prendevate": "prendere",
    "prendevi": "prendere",
    "prendevo": "prendere",
    "prendi": "prendere",
    "prendiamo": "prendere",
    "prendiate": "prendere",
    "prendisoli": "prendisole",
    "prenditori": "prenditore",
    "prendo": "prendere",
    "prendon": "prendere",
    "prendono": "prendere",
    "prenota": "prenotare",
    "prenotai": "prenotare",
    "prenotammo": "prenotare",
    "prenotan": "prenotare",
    "prenotando": "prenotare",
    "prenotano": "prenotare",
    "prenotante": "prenotare",
    "prenotanti": "prenotare",
    "prenotar": "prenotare",
    "prenotaron": "prenotare",
    "prenotarono": "prenotare",
    "prenotasse": "prenotare",
    "prenotasser": "prenotare",
    "prenotassero": "prenotare",
    "prenotassi": "prenotare",
    "prenotassimo": "prenotare",
    "prenotaste": "prenotare",
    "prenotasti": "prenotare",
    "prenotata": "prenotare",
    "prenotate": "prenotare",
    "prenotati": "prenotare",
    "prenotato": "prenotare",
    "prenotava": "prenotare",
    "prenotavamo": "prenotare",
    "prenotavan": "prenotare",
    "prenotavano": "prenotare",
    "prenotavate": "prenotare",
    "prenotavi": "prenotare",
    "prenotavo": "prenotare",
    "prenotazioni": "prenotazione",
    "prenoterai": "prenotare",
    "prenoteran": "prenotare",
    "prenoteranno": "prenotare",
    "prenoterebbe": "prenotare",
    "prenoterebber": "prenotare",
    "prenoterebbero": "prenotare",
    "prenoterei": "prenotare",
    "prenoteremmo": "prenotare",
    "prenoteremo": "prenotare",
    "prenotereste": "prenotare",
    "prenoteresti": "prenotare",
    "prenoterete": "prenotare",
    "prenoterà": "prenotare",
    "prenoterò": "prenotare",
    "prenoti": "prenotare",
    "prenotiamo": "prenotare",
    "prenotiate": "prenotare",
    "prenotin": "prenotare",
    "prenotino": "prenotare",
    "prenoto": "prenotare",
    "prenotò": "prenotare",
    "preoccupa": "preoccupare",
    "preoccupai": "preoccupare",
    "preoccupammo": "preoccupare",
    "preoccupan": "preoccupare",
    "preoccupando": "preoccupare",
    "preoccupano": "preoccupare",
    "preoccupante": "preoccupare",
    "preoccupanti": "preoccupare",
    "preoccupar": "preoccupare",
    "preoccuparon": "preoccupare",
    "preoccuparono": "preoccupare",
    "preoccupasse": "preoccupare",
    "preoccupasser": "preoccupare",
    "preoccupassero": "preoccupare",
    "preoccupassi": "preoccupare",
    "preoccupassimo": "preoccupare",
    "preoccupaste": "preoccupare",
    "preoccupasti": "preoccupare",
    "preoccupata": "preoccupato",
    "preoccupate": "preoccupato",
    "preoccupati": "preoccupato",
    "preoccupato": "preoccupare",
    "preoccupava": "preoccupare",
    "preoccupavamo": "preoccupare",
    "preoccupavan": "preoccupare",
    "preoccupavano": "preoccupare",
    "preoccupavate": "preoccupare",
    "preoccupavi": "preoccupare",
    "preoccupavo": "preoccupare",
    "preoccupazioni": "preoccupazione",
    "preoccuperai": "preoccupare",
    "preoccuperan": "preoccupare",
    "preoccuperanno": "preoccupare",
    "preoccuperebbe": "preoccupare",
    "preoccuperebber": "preoccupare",
    "preoccuperebbero": "preoccupare",
    "preoccuperei": "preoccupare",
    "preoccuperemmo": "preoccupare",
    "preoccuperemo": "preoccupare",
    "preoccupereste": "preoccupare",
    "preoccuperesti": "preoccupare",
    "preoccuperete": "preoccupare",
    "preoccuperà": "preoccupare",
    "preoccuperò": "preoccupare",
    "preoccupi": "preoccupare",
    "preoccupiamo": "preoccupare",
    "preoccupiate": "preoccupare",
    "preoccupin": "preoccupare",
    "preoccupino": "preoccupare",
    "preoccupo": "preoccupare",
    "preoccupò": "preoccupare",
    "preordina": "preordinare",
    "preordinai": "preordinare",
    "preordinammo": "preordinare",
    "preordinan": "preordinare",
    "preordinando": "preordinare",
    "preordinano": "preordinare",
    "preordinante": "preordinare",
    "preordinanti": "preordinare",
    "preordinar": "preordinare",
    "preordinaron": "preordinare",
    "preordinarono": "preordinare",
    "preordinasse": "preordinare",
    "preordinasser": "preordinare",
    "preordinassero": "preordinare",
    "preordinassi": "preordinare",
    "preordinassimo": "preordinare",
    "preordinaste": "preordinare",
    "preordinasti": "preordinare",
    "preordinata": "preordinare",
    "preordinate": "preordinare",
    "preordinati": "preordinare",
    "preordinato": "preordinare",
    "preordinava": "preordinare",
    "preordinavamo": "preordinare",
    "preordinavan": "preordinare",
    "preordinavano": "preordinare",
    "preordinavate": "preordinare",
    "preordinavi": "preordinare",
    "preordinavo": "preordinare",
    "preordinerai": "preordinare",
    "preordineran": "preordinare",
    "preordineranno": "preordinare",
    "preordinerebbe": "preordinare",
    "preordinerebber": "preordinare",
    "preordinerebbero": "preordinare",
    "preordinerei": "preordinare",
    "preordineremmo": "preordinare",
    "preordineremo": "preordinare",
    "preordinereste": "preordinare",
    "preordineresti": "preordinare",
    "preordinerete": "preordinare",
    "preordinerà": "preordinare",
    "preordinerò": "preordinare",
    "preordini": "preordinare",
    "preordiniamo": "preordinare",
    "preordiniate": "preordinare",
    "preordinin": "preordinare",
    "preordinino": "preordinare",
    "preordino": "preordinare",
    "preordinò": "preordinare",
    "prepara": "preparare",
    "preparai": "preparare",
    "preparammo": "preparare",
    "preparan": "preparare",
    "preparando": "preparare",
    "preparano": "preparare",
    "preparante": "preparare",
    "preparanti": "preparare",
    "preparar": "preparare",
    "prepararon": "preparare",
    "prepararono": "preparare",
    "preparasse": "preparare",
    "preparasser": "preparare",
    "preparassero": "preparare",
    "preparassi": "preparare",
    "preparassimo": "preparare",
    "preparaste": "preparare",
    "preparasti": "preparare",
    "preparata": "preparato",
    "preparate": "preparato",
    "preparati": "preparato",
    "preparativa": "preparativo",
    "preparative": "preparativo",
    "preparativi": "preparativo",
    "preparato": "preparare",
    "preparatori": "preparatorio",
    "preparatoria": "preparatorio",
    "preparatorie": "preparatorio",
    "preparava": "preparare",
    "preparavamo": "preparare",
    "preparavan": "preparare",
    "preparavano": "preparare",
    "preparavate": "preparare",
    "preparavi": "preparare",
    "preparavo": "preparare",
    "preparazioni": "preparazione",
    "preparerai": "preparare",
    "prepareran": "preparare",
    "prepareranno": "preparare",
    "preparerebbe": "preparare",
    "preparerebber": "preparare",
    "preparerebbero": "preparare",
    "preparerei": "preparare",
    "prepareremmo": "preparare",
    "prepareremo": "preparare",
    "preparereste": "preparare",
    "prepareresti": "preparare",
    "preparerete": "preparare",
    "preparerà": "preparare",
    "preparerò": "preparare",
    "prepari": "preparare",
    "prepariamo": "preparare",
    "prepariate": "preparare",
    "preparin": "preparare",
    "preparino": "preparare",
    "preparo": "preparare",
    "preparò": "preparare",
    "prepensionamenti": "prepensionamento",
    "prepensionati": "prepensionato",
    "prepondera": "preponderare",
    "preponderai": "preponderare",
    "preponderammo": "preponderare",
    "preponderan": "preponderare",
    "preponderando": "preponderare",
    "preponderano": "preponderare",
    "preponderante": "preponderare",
    "preponderanti": "preponderare",
    "preponderanze": "preponderanza",
    "preponderar": "preponderare",
    "preponderaron": "preponderare",
    "preponderarono": "preponderare",
    "preponderasse": "preponderare",
    "preponderasser": "preponderare",
    "preponderassero": "preponderare",
    "preponderassi": "preponderare",
    "preponderassimo": "preponderare",
    "preponderaste": "preponderare",
    "preponderasti": "preponderare",
    "preponderata": "preponderare",
    "preponderate": "preponderare",
    "preponderati": "preponderare",
    "preponderato": "preponderare",
    "preponderava": "preponderare",
    "preponderavamo": "preponderare",
    "preponderavan": "preponderare",
    "preponderavano": "preponderare",
    "preponderavate": "preponderare",
    "preponderavi": "preponderare",
    "preponderavo": "preponderare",
    "prepondererai": "preponderare",
    "prepondereran": "preponderare",
    "prepondereranno": "preponderare",
    "prepondererebbe": "preponderare",
    "prepondererebber": "preponderare",
    "prepondererebbero": "preponderare",
    "prepondererei": "preponderare",
    "prepondereremmo": "preponderare",
    "prepondereremo": "preponderare",
    "preponderereste": "preponderare",
    "prepondereresti": "preponderare",
    "prepondererete": "preponderare",
    "prepondererà": "preponderare",
    "prepondererò": "preponderare",
    "preponderi": "preponderare",
    "preponderiamo": "preponderare",
    "preponderiate": "preponderare",
    "preponderin": "preponderare",
    "preponderino": "preponderare",
    "prepondero": "preponderare",
    "preponderò": "preponderare",
    "prepone": "preporre",
    "preponemmo": "preporre",
    "preponendo": "preporre",
    "preponente": "preporre",
    "preponenti": "preporre",
    "preponesse": "preporre",
    "preponesser": "preporre",
    "preponessero": "preporre",
    "preponessi": "preporre",
    "preponessimo": "preporre",
    "preponeste": "preporre",
    "preponesti": "preporre",
    "preponete": "preporre",
    "preponeva": "preporre",
    "preponevamo": "preporre",
    "preponevan": "preporre",
    "preponevano": "preporre",
    "preponevate": "preporre",
    "preponevi": "preporre",
    "preponevo": "preporre",
    "preponga": "preporre",
    "prepongan": "preporre",
    "prepongano": "preporre",
    "prepongo": "preporre",
    "prepongon": "preporre",
    "prepongono": "preporre",
    "preponi": "preporre",
    "preponiamo": "preporre",
    "preponiate": "preporre",
    "preporr": "preporre",
    "preporrai": "preporre",
    "preporran": "preporre",
    "preporranno": "preporre",
    "preporrebbe": "preporre",
    "preporrebber": "preporre",
    "preporrebbero": "preporre",
    "preporrei": "preporre",
    "preporremmo": "preporre",
    "preporremo": "preporre",
    "preporreste": "preporre",
    "preporresti": "preporre",
    "preporrete": "preporre",
    "preporrà": "preporre",
    "preporrò": "preporre",
    "prepose": "preporre",
    "preposer": "preporre",
    "preposero": "preporre",
    "preposi": "preporre",
    "preposizioni": "preposizione",
    "preposta": "preposto",
    "preposte": "preposto",
    "preposti": "preposto",
    "preposto": "preporre",
    "prepota": "prepotere",
    "prepotan": "prepotere",
    "prepotano": "prepotere",
    "prepote": "prepotere",
    "prepotei": "prepotere",
    "prepotemmo": "prepotere",
    "prepotendo": "prepotere",
    "prepotente": "prepotere",
    "prepotenti": "prepotere",
    "prepotenze": "prepotenza",
    "prepoter": "prepotere",
    "prepoterai": "prepotere",
    "prepoteran": "prepotere",
    "prepoteranno": "prepotere",
    "prepoterebbe": "prepotere",
    "prepoterebber": "prepotere",
    "prepoterebbero": "prepotere",
    "prepoterei": "prepotere",
    "prepoteremmo": "prepotere",
    "prepoteremo": "prepotere",
    "prepotereste": "prepotere",
    "prepoteresti": "prepotere",
    "prepoterete": "prepotere",
    "prepoteron": "prepotere",
    "prepoterono": "prepotere",
    "prepoterà": "prepotere",
    "prepoterò": "prepotere",
    "prepotesse": "prepotere",
    "prepotesser": "prepotere",
    "prepotessero": "prepotere",
    "prepotessi": "prepotere",
    "prepotessimo": "prepotere",
    "prepoteste": "prepotere",
    "prepotesti": "prepotere",
    "prepotete": "prepotere",
    "prepoteva": "prepotere",
    "prepotevamo": "prepotere",
    "prepotevan": "prepotere",
    "prepotevano": "prepotere",
    "prepotevate": "prepotere",
    "prepotevi": "prepotere",
    "prepotevo": "prepotere",
    "prepoti": "prepotere",
    "prepotiamo": "prepotere",
    "prepotiate": "prepotere",
    "prepoto": "prepotere",
    "prepoton": "prepotere",
    "prepotono": "prepotere",
    "prepotuta": "prepotere",
    "prepotute": "prepotere",
    "prepotuti": "prepotere",
    "prepotuto": "prepotere",
    "prepotè": "prepotere",
    "prequalificazioni": "prequalificazione",
    "prerequisiti": "prerequisito",
    "prerogative": "prerogativa",
    "presa": "preso",
    "presaga": "presago",
    "presagendo": "presagire",
    "presagente": "presagire",
    "presagenti": "presagire",
    "presaghe": "presago",
    "presaghi": "presago",
    "presagi": "presagio",
    "presagiamo": "presagire",
    "presagiate": "presagire",
    "presagii": "presagire",
    "presagimmo": "presagire",
    "presagir": "presagire",
    "presagirai": "presagire",
    "presagiran": "presagire",
    "presagiranno": "presagire",
    "presagirebbe": "presagire",
    "presagirebber": "presagire",
    "presagirebbero": "presagire",
    "presagirei": "presagire",
    "presagiremmo": "presagire",
    "presagiremo": "presagire",
    "presagireste": "presagire",
    "presagiresti": "presagire",
    "presagirete": "presagire",
    "presagiron": "presagire",
    "presagirono": "presagire",
    "presagirà": "presagire",
    "presagirò": "presagire",
    "presagisca": "presagire",
    "presagiscan": "presagire",
    "presagiscano": "presagire",
    "presagisce": "presagire",
    "presagisci": "presagire",
    "presagisco": "presagire",
    "presagiscon": "presagire",
    "presagiscono": "presagire",
    "presagisse": "presagire",
    "presagisser": "presagire",
    "presagissero": "presagire",
    "presagissi": "presagire",
    "presagissimo": "presagire",
    "presagiste": "presagire",
    "presagisti": "presagire",
    "presagita": "presagire",
    "presagite": "presagire",
    "presagiti": "presagire",
    "presagito": "presagire",
    "presagiva": "presagire",
    "presagivamo": "presagire",
    "presagivan": "presagire",
    "presagivano": "presagire",
    "presagivate": "presagire",
    "presagivi": "presagire",
    "presagivo": "presagire",
    "presagì": "presagire",
    "presbiteri": "presbiterio",
    "presbiteriana": "presbiteriano",
    "presbiteriane": "presbiteriano",
    "presbiteriani": "presbiteriano",
    "prescegli": "prescegliere",
    "prescegliamo": "prescegliere",
    "prescegliate": "prescegliere",
    "presceglie": "prescegliere",
    "prescegliemmo": "prescegliere",
    "prescegliendo": "prescegliere",
    "prescegliente": "prescegliere",
    "presceglienti": "prescegliere",
    "presceglier": "prescegliere",
    "presceglierai": "prescegliere",
    "presceglieran": "prescegliere",
    "presceglieranno": "prescegliere",
    "presceglierebbe": "prescegliere",
    "presceglierebber": "prescegliere",
    "presceglierebbero": "prescegliere",
    "presceglierei": "prescegliere",
    "presceglieremmo": "prescegliere",
    "presceglieremo": "prescegliere",
    "prescegliereste": "prescegliere",
    "presceglieresti": "prescegliere",
    "presceglierete": "prescegliere",
    "presceglierà": "prescegliere",
    "presceglierò": "prescegliere",
    "prescegliesse": "prescegliere",
    "prescegliesser": "prescegliere",
    "prescegliessero": "prescegliere",
    "prescegliessi": "prescegliere",
    "prescegliessimo": "prescegliere",
    "presceglieste": "prescegliere",
    "prescegliesti": "prescegliere",
    "prescegliete": "prescegliere",
    "presceglieva": "prescegliere",
    "presceglievamo": "prescegliere",
    "presceglievan": "prescegliere",
    "presceglievano": "prescegliere",
    "presceglievate": "prescegliere",
    "presceglievi": "prescegliere",
    "presceglievo": "prescegliere",
    "prescelga": "prescegliere",
    "prescelgan": "prescegliere",
    "prescelgano": "prescegliere",
    "prescelgo": "prescegliere",
    "prescelgon": "prescegliere",
    "prescelgono": "prescegliere",
    "prescelser": "prescegliere",
    "prescelsero": "prescegliere",
    "prescelsi": "prescegliere",
    "prescelsè": "prescegliere",
    "prescelta": "prescelto",
    "prescelte": "prescelto",
    "prescelti": "prescelto",
    "prescelto": "prescegliere",
    "prescinda": "prescindere",
    "prescindan": "prescindere",
    "prescindano": "prescindere",
    "prescinde": "prescindere",
    "prescindemmo": "prescindere",
    "prescindendo": "prescindere",
    "prescindente": "prescindere",
    "prescindenti": "prescindere",
    "prescinder": "prescindere",
    "prescinderai": "prescindere",
    "prescinderan": "prescindere",
    "prescinderanno": "prescindere",
    "prescinderebbe": "prescindere",
    "prescinderebber": "prescindere",
    "prescinderebbero": "prescindere",
    "prescinderei": "prescindere",
    "prescinderemmo": "prescindere",
    "prescinderemo": "prescindere",
    "prescindereste": "prescindere",
    "prescinderesti": "prescindere",
    "prescinderete": "prescindere",
    "prescinderà": "prescindere",
    "prescinderò": "prescindere",
    "prescindesse": "prescindere",
    "prescindesser": "prescindere",
    "prescindessero": "prescindere",
    "prescindessi": "prescindere",
    "prescindessimo": "prescindere",
    "prescindeste": "prescindere",
    "prescindesti": "prescindere",
    "prescindete": "prescindere",
    "prescindeva": "prescindere",
    "prescindevamo": "prescindere",
    "prescindevan": "prescindere",
    "prescindevano": "prescindere",
    "prescindevate": "prescindere",
    "prescindevi": "prescindere",
    "prescindevo": "prescindere",
    "prescindi": "prescindere",
    "prescindiamo": "prescindere",
    "prescindiate": "prescindere",
    "prescindo": "prescindere",
    "prescindon": "prescindere",
    "prescindono": "prescindere",
    "prescissa": "prescindere",
    "prescisse": "prescindere",
    "prescisser": "prescindere",
    "prescissero": "prescindere",
    "prescissi": "prescindere",
    "prescisso": "prescindere",
    "prescrisse": "prescrivere",
    "prescrisser": "prescrivere",
    "prescrissero": "prescrivere",
    "prescrissi": "prescrivere",
    "prescritta": "prescrivere",
    "prescritte": "prescrivere",
    "prescritti": "prescrivere",
    "prescritto": "prescrivere",
    "prescriva": "prescrivere",
    "prescrivan": "prescrivere",
    "prescrivano": "prescrivere",
    "prescrive": "prescrivere",
    "prescrivemmo": "prescrivere",
    "prescrivendo": "prescrivere",
    "prescrivente": "prescrivere",
    "prescriventi": "prescrivere",
    "prescriver": "prescrivere",
    "prescriverai": "prescrivere",
    "prescriveran": "prescrivere",
    "prescriveranno": "prescrivere",
    "prescriverebbe": "prescrivere",
    "prescriverebber": "prescrivere",
    "prescriverebbero": "prescrivere",
    "prescriverei": "prescrivere",
    "prescriveremmo": "prescrivere",
    "prescriveremo": "prescrivere",
    "prescrivereste": "prescrivere",
    "prescriveresti": "prescrivere",
    "prescriverete": "prescrivere",
    "prescriverà": "prescrivere",
    "prescriverò": "prescrivere",
    "prescrivesse": "prescrivere",
    "prescrivesser": "prescrivere",
    "prescrivessero": "prescrivere",
    "prescrivessi": "prescrivere",
    "prescrivessimo": "prescrivere",
    "prescriveste": "prescrivere",
    "prescrivesti": "prescrivere",
    "prescrivete": "prescrivere",
    "prescriveva": "prescrivere",
    "prescrivevamo": "prescrivere",
    "prescrivevan": "prescrivere",
    "prescrivevano": "prescrivere",
    "prescrivevate": "prescrivere",
    "prescrivevi": "prescrivere",
    "prescrivevo": "prescrivere",
    "prescrivi": "prescrivere",
    "prescriviamo": "prescrivere",
    "prescriviate": "prescrivere",
    "prescrivo": "prescrivere",
    "prescrivon": "prescrivere",
    "prescrivono": "prescrivere",
    "prescrizioni": "prescrizione",
    "prese": "preso",
    "preseleziona": "preselezionare",
    "preselezionai": "preselezionare",
    "preselezionammo": "preselezionare",
    "preselezionan": "preselezionare",
    "preselezionando": "preselezionare",
    "preselezionano": "preselezionare",
    "preselezionante": "preselezionare",
    "preselezionanti": "preselezionare",
    "preselezionar": "preselezionare",
    "preselezionaron": "preselezionare",
    "preselezionarono": "preselezionare",
    "preselezionasse": "preselezionare",
    "preselezionasser": "preselezionare",
    "preselezionassero": "preselezionare",
    "preselezionassi": "preselezionare",
    "preselezionassimo": "preselezionare",
    "preselezionaste": "preselezionare",
    "preselezionasti": "preselezionare",
    "preselezionata": "preselezionare",
    "preselezionate": "preselezionare",
    "preselezionati": "preselezionare",
    "preselezionato": "preselezionare",
    "preselezionava": "preselezionare",
    "preselezionavamo": "preselezionare",
    "preselezionavan": "preselezionare",
    "preselezionavano": "preselezionare",
    "preselezionavate": "preselezionare",
    "preselezionavi": "preselezionare",
    "preselezionavo": "preselezionare",
    "preselezionerai": "preselezionare",
    "preselezioneran": "preselezionare",
    "preselezioneranno": "preselezionare",
    "preselezionerebbe": "preselezionare",
    "preselezionerebber": "preselezionare",
    "preselezionerebbero": "preselezionare",
    "preselezionerei": "preselezionare",
    "preselezioneremmo": "preselezionare",
    "preselezioneremo": "preselezionare",
    "preselezionereste": "preselezionare",
    "preselezioneresti": "preselezionare",
    "preselezionerete": "preselezionare",
    "preselezionerà": "preselezionare",
    "preselezionerò": "preselezionare",
    "preselezioni": "preselezione",
    "preselezioniamo": "preselezionare",
    "preselezioniate": "preselezionare",
    "preselezionin": "preselezionare",
    "preselezionino": "preselezionare",
    "preseleziono": "preselezionare",
    "preselezionò": "preselezionare",
    "presenta": "presentire",
    "presentabili": "presentabile",
    "presentai": "presentare",
    "presentammo": "presentare",
    "presentan": "presentire",
    "presentando": "presentare",
    "presentano": "presentire",
    "presentante": "presentare",
    "presentanti": "presentare",
    "presentar": "presentare",
    "presentaron": "presentare",
    "presentarono": "presentare",
    "presentasse": "presentare",
    "presentasser": "presentare",
    "presentassero": "presentare",
    "presentassi": "presentare",
    "presentassimo": "presentare",
    "presentaste": "presentare",
    "presentasti": "presentare",
    "presentata": "presentare",
    "presentate": "presentare",
    "presentati": "presentare",
    "presentato": "presentare",
    "presentatori": "presentatore",
    "presentatrici": "presentatrice",
    "presentava": "presentare",
    "presentavamo": "presentare",
    "presentavan": "presentare",
    "presentavano": "presentare",
    "presentavate": "presentare",
    "presentavi": "presentare",
    "presentavo": "presentare",
    "presentazioni": "presentazione",
    "presente": "presentire",
    "presentendo": "presentire",
    "presentente": "presentire",
    "presententi": "presentire",
    "presenterai": "presentare",
    "presenteran": "presentare",
    "presenteranno": "presentare",
    "presenterebbe": "presentare",
    "presenterebber": "presentare",
    "presenterebbero": "presentare",
    "presenterei": "presentare",
    "presenteremmo": "presentare",
    "presenteremo": "presentare",
    "presentereste": "presentare",
    "presenteresti": "presentare",
    "presenterete": "presentare",
    "presenterà": "presentare",
    "presenterò": "presentare",
    "presenti": "presentire",
    "presentiamo": "presentire",
    "presentiate": "presentire",
    "presentii": "presentire",
    "presentimenti": "presentimento",
    "presentimmo": "presentire",
    "presentin": "presentare",
    "presentino": "presentare",
    "presentir": "presentire",
    "presentirai": "presentire",
    "presentiran": "presentire",
    "presentiranno": "presentire",
    "presentirebbe": "presentire",
    "presentirebber": "presentire",
    "presentirebbero": "presentire",
    "presentirei": "presentire",
    "presentiremmo": "presentire",
    "presentiremo": "presentire",
    "presentireste": "presentire",
    "presentiresti": "presentire",
    "presentirete": "presentire",
    "presentiron": "presentire",
    "presentirono": "presentire",
    "presentirà": "presentire",
    "presentirò": "presentire",
    "presentisse": "presentire",
    "presentisser": "presentire",
    "presentissero": "presentire",
    "presentissi": "presentire",
    "presentissimo": "presentire",
    "presentiste": "presentire",
    "presentisti": "presentire",
    "presentita": "presentire",
    "presentite": "presentire",
    "presentiti": "presentire",
    "presentito": "presentire",
    "presentiva": "presentire",
    "presentivamo": "presentire",
    "presentivan": "presentire",
    "presentivano": "presentire",
    "presentivate": "presentire",
    "presentivi": "presentire",
    "presentivo": "presentire",
    "presento": "presentire",
    "presenton": "presentire",
    "presentono": "presentire",
    "presentì": "presentire",
    "presentò": "presentare",
    "presenze": "presenza",
    "presenzi": "presenziare",
    "presenzia": "presenziare",
    "presenziai": "presenziare",
    "presenzialismi": "presenzialismo",
    "presenzialisti": "presenzialista",
    "presenziammo": "presenziare",
    "presenziamo": "presenziare",
    "presenzian": "presenziare",
    "presenziando": "presenziare",
    "presenziano": "presenziare",
    "presenziante": "presenziare",
    "presenzianti": "presenziare",
    "presenziar": "presenziare",
    "presenziaron": "presenziare",
    "presenziarono": "presenziare",
    "presenziasse": "presenziare",
    "presenziasser": "presenziare",
    "presenziassero": "presenziare",
    "presenziassi": "presenziare",
    "presenziassimo": "presenziare",
    "presenziaste": "presenziare",
    "presenziasti": "presenziare",
    "presenziata": "presenziare",
    "presenziate": "presenziare",
    "presenziati": "presenziare",
    "presenziato": "presenziare",
    "presenziava": "presenziare",
    "presenziavamo": "presenziare",
    "presenziavan": "presenziare",
    "presenziavano": "presenziare",
    "presenziavate": "presenziare",
    "presenziavi": "presenziare",
    "presenziavo": "presenziare",
    "presenzierai": "presenziare",
    "presenzieran": "presenziare",
    "presenzieranno": "presenziare",
    "presenzierebbe": "presenziare",
    "presenzierebber": "presenziare",
    "presenzierebbero": "presenziare",
    "presenzierei": "presenziare",
    "presenzieremmo": "presenziare",
    "presenzieremo": "presenziare",
    "presenziereste": "presenziare",
    "presenzieresti": "presenziare",
    "presenzierete": "presenziare",
    "presenzierà": "presenziare",
    "presenzierò": "presenziare",
    "presenzin": "presenziare",
    "presenzino": "presenziare",
    "presenzio": "presenziare",
    "presenziò": "presenziare",
    "presepi": "presepio",
    "preser": "prendere",
    "preserali": "preserale",
    "presero": "prendere",
    "preserva": "preservare",
    "preservai": "preservare",
    "preservammo": "preservare",
    "preservan": "preservare",
    "preservando": "preservare",
    "preservano": "preservare",
    "preservante": "preservare",
    "preservanti": "preservare",
    "preservar": "preservare",
    "preservaron": "preservare",
    "preservarono": "preservare",
    "preservasse": "preservare",
    "preservasser": "preservare",
    "preservassero": "preservare",
    "preservassi": "preservare",
    "preservassimo": "preservare",
    "preservaste": "preservare",
    "preservasti": "preservare",
    "preservata": "preservare",
    "preservate": "preservare",
    "preservati": "preservare",
    "preservativa": "preservativo",
    "preservative": "preservativo",
    "preservativi": "preservativo",
    "preservato": "preservare",
    "preservava": "preservare",
    "preservavamo": "preservare",
    "preservavan": "preservare",
    "preservavano": "preservare",
    "preservavate": "preservare",
    "preservavi": "preservare",
    "preservavo": "preservare",
    "preservazioni": "preservazione",
    "preserverai": "preservare",
    "preserveran": "preservare",
    "preserveranno": "preservare",
    "preserverebbe": "preservare",
    "preserverebber": "preservare",
    "preserverebbero": "preservare",
    "preserverei": "preservare",
    "preserveremmo": "preservare",
    "preserveremo": "preservare",
    "preservereste": "preservare",
    "preserveresti": "preservare",
    "preserverete": "preservare",
    "preserverà": "preservare",
    "preserverò": "preservare",
    "preservi": "preservare",
    "preserviamo": "preservare",
    "preserviate": "preservare",
    "preservin": "preservare",
    "preservino": "preservare",
    "preservo": "preservare",
    "preservò": "preservare",
    "presi": "preso",
    "presidentesse": "presidentessa",
    "presidenti": "presidente",
    "presidenze": "presidenza",
    "presidenziali": "presidenziale",
    "presidenzialismi": "presidenzialismo",
    "presidenzialiste": "presidenzialista",
    "presidenzialisti": "presidenzialista",
    "presidi": "presidio",
    "presidia": "presidiare",
    "presidiai": "presidiare",
    "presidiammo": "presidiare",
    "presidiamo": "presidiare",
    "presidian": "presidiare",
    "presidiando": "presidiare",
    "presidiano": "presidiare",
    "presidiante": "presidiare",
    "presidianti": "presidiare",
    "presidiar": "presidiare",
    "presidiaron": "presidiare",
    "presidiarono": "presidiare",
    "presidiasse": "presidiare",
    "presidiasser": "presidiare",
    "presidiassero": "presidiare",
    "presidiassi": "presidiare",
    "presidiassimo": "presidiare",
    "presidiaste": "presidiare",
    "presidiasti": "presidiare",
    "presidiata": "presidiare",
    "presidiate": "presidiare",
    "presidiati": "presidiare",
    "presidiato": "presidiare",
    "presidiava": "presidiare",
    "presidiavamo": "presidiare",
    "presidiavan": "presidiare",
    "presidiavano": "presidiare",
    "presidiavate": "presidiare",
    "presidiavi": "presidiare",
    "presidiavo": "presidiare",
    "presidierai": "presidiare",
    "presidieran": "presidiare",
    "presidieranno": "presidiare",
    "presidierebbe": "presidiare",
    "presidierebber": "presidiare",
    "presidierebbero": "presidiare",
    "presidierei": "presidiare",
    "presidieremmo": "presidiare",
    "presidieremo": "presidiare",
    "presidiereste": "presidiare",
    "presidieresti": "presidiare",
    "presidierete": "presidiare",
    "presidierà": "presidiare",
    "presidierò": "presidiare",
    "presidii": "presidio",
    "presidin": "presidiare",
    "presidino": "presidiare",
    "presidio": "presidiare",
    "presidiò": "presidiare",
    "presieda": "presiedere",
    "presiedan": "presiedere",
    "presiedano": "presiedere",
    "presiede": "presiedere",
    "presiedei": "presiedere",
    "presiedemmo": "presiedere",
    "presiedendo": "presiedere",
    "presiedente": "presiedere",
    "presiedenti": "presiedere",
    "presieder": "presiedere",
    "presiederai": "presiedere",
    "presiederan": "presiedere",
    "presiederanno": "presiedere",
    "presiederebbe": "presiedere",
    "presiederebber": "presiedere",
    "presiederebbero": "presiedere",
    "presiederei": "presiedere",
    "presiederemmo": "presiedere",
    "presiederemo": "presiedere",
    "presiedereste": "presiedere",
    "presiederesti": "presiedere",
    "presiederete": "presiedere",
    "presiederon": "presiedere",
    "presiederono": "presiedere",
    "presiederà": "presiedere",
    "presiederò": "presiedere",
    "presiedesse": "presiedere",
    "presiedesser": "presiedere",
    "presiedessero": "presiedere",
    "presiedessi": "presiedere",
    "presiedessimo": "presiedere",
    "presiedeste": "presiedere",
    "presiedesti": "presiedere",
    "presiedete": "presiedere",
    "presiedeva": "presiedere",
    "presiedevamo": "presiedere",
    "presiedevan": "presiedere",
    "presiedevano": "presiedere",
    "presiedevate": "presiedere",
    "presiedevi": "presiedere",
    "presiedevo": "presiedere",
    "presiedi": "presiedere",
    "presiediamo": "presiedere",
    "presiediate": "presiedere",
    "presiedo": "presiedere",
    "presiedon": "presiedere",
    "presiedono": "presiedere",
    "presieduta": "presiedere",
    "presiedute": "presiedere",
    "presieduti": "presiedere",
    "presieduto": "presiedere",
    "presiedè": "presiedere",
    "preso": "prendere",
    "pressa": "pressare",
    "pressai": "pressare",
    "pressammo": "pressare",
    "pressan": "pressare",
    "pressando": "pressare",
    "pressano": "pressare",
    "pressante": "pressare",
    "pressanti": "pressare",
    "pressappochismi": "pressappochismo",
    "pressar": "pressare",
    "pressaron": "pressare",
    "pressarono": "pressare",
    "pressasse": "pressare",
    "pressasser": "pressare",
    "pressassero": "pressare",
    "pressassi": "pressare",
    "pressassimo": "pressare",
    "pressaste": "pressare",
    "pressasti": "pressare",
    "pressata": "pressare",
    "pressate": "pressare",
    "pressati": "pressare",
    "pressato": "pressare",
    "pressava": "pressare",
    "pressavamo": "pressare",
    "pressavan": "pressare",
    "pressavano": "pressare",
    "pressavate": "pressare",
    "pressavi": "pressare",
    "pressavo": "pressare",
    "presse": "pressa",
    "presserai": "pressare",
    "presseran": "pressare",
    "presseranno": "pressare",
    "presserebbe": "pressare",
    "presserebber": "pressare",
    "presserebbero": "pressare",
    "presserei": "pressare",
    "presseremmo": "pressare",
    "presseremo": "pressare",
    "pressereste": "pressare",
    "presseresti": "pressare",
    "presserete": "pressare",
    "presserà": "pressare",
    "presserò": "pressare",
    "pressi": "pressare",
    "pressiamo": "pressare",
    "pressiate": "pressare",
    "pressin": "pressare",
    "pressino": "pressare",
    "pressioni": "pressione",
    "presso": "pressare",
    "pressurizza": "pressurizzare",
    "pressurizzai": "pressurizzare",
    "pressurizzammo": "pressurizzare",
    "pressurizzan": "pressurizzare",
    "pressurizzando": "pressurizzare",
    "pressurizzano": "pressurizzare",
    "pressurizzante": "pressurizzare",
    "pressurizzanti": "pressurizzare",
    "pressurizzar": "pressurizzare",
    "pressurizzaron": "pressurizzare",
    "pressurizzarono": "pressurizzare",
    "pressurizzasse": "pressurizzare",
    "pressurizzasser": "pressurizzare",
    "pressurizzassero": "pressurizzare",
    "pressurizzassi": "pressurizzare",
    "pressurizzassimo": "pressurizzare",
    "pressurizzaste": "pressurizzare",
    "pressurizzasti": "pressurizzare",
    "pressurizzata": "pressurizzare",
    "pressurizzate": "pressurizzare",
    "pressurizzati": "pressurizzare",
    "pressurizzato": "pressurizzare",
    "pressurizzava": "pressurizzare",
    "pressurizzavamo": "pressurizzare",
    "pressurizzavan": "pressurizzare",
    "pressurizzavano": "pressurizzare",
    "pressurizzavate": "pressurizzare",
    "pressurizzavi": "pressurizzare",
    "pressurizzavo": "pressurizzare",
    "pressurizzerai": "pressurizzare",
    "pressurizzeran": "pressurizzare",
    "pressurizzeranno": "pressurizzare",
    "pressurizzerebbe": "pressurizzare",
    "pressurizzerebber": "pressurizzare",
    "pressurizzerebbero": "pressurizzare",
    "pressurizzerei": "pressurizzare",
    "pressurizzeremmo": "pressurizzare",
    "pressurizzeremo": "pressurizzare",
    "pressurizzereste": "pressurizzare",
    "pressurizzeresti": "pressurizzare",
    "pressurizzerete": "pressurizzare",
    "pressurizzerà": "pressurizzare",
    "pressurizzerò": "pressurizzare",
    "pressurizzi": "pressurizzare",
    "pressurizziamo": "pressurizzare",
    "pressurizziate": "pressurizzare",
    "pressurizzin": "pressurizzare",
    "pressurizzino": "pressurizzare",
    "pressurizzo": "pressurizzare",
    "pressurizzò": "pressurizzare",
    "pressò": "pressare",
    "presta": "presto",
    "prestabila": "prestabilire",
    "prestabilan": "prestabilire",
    "prestabilano": "prestabilire",
    "prestabile": "prestabilire",
    "prestabilendo": "prestabilire",
    "prestabilente": "prestabilire",
    "prestabilenti": "prestabilire",
    "prestabili": "prestabilire",
    "prestabiliamo": "prestabilire",
    "prestabiliate": "prestabilire",
    "prestabilii": "prestabilire",
    "prestabilimmo": "prestabilire",
    "prestabilir": "prestabilire",
    "prestabilirai": "prestabilire",
    "prestabiliran": "prestabilire",
    "prestabiliranno": "prestabilire",
    "prestabilirebbe": "prestabilire",
    "prestabilirebber": "prestabilire",
    "prestabilirebbero": "prestabilire",
    "prestabilirei": "prestabilire",
    "prestabiliremmo": "prestabilire",
    "prestabiliremo": "prestabilire",
    "prestabilireste": "prestabilire",
    "prestabiliresti": "prestabilire",
    "prestabilirete": "prestabilire",
    "prestabiliron": "prestabilire",
    "prestabilirono": "prestabilire",
    "prestabilirà": "prestabilire",
    "prestabilirò": "prestabilire",
    "prestabilisse": "prestabilire",
    "prestabilisser": "prestabilire",
    "prestabilissero": "prestabilire",
    "prestabilissi": "prestabilire",
    "prestabilissimo": "prestabilire",
    "prestabiliste": "prestabilire",
    "prestabilisti": "prestabilire",
    "prestabilita": "prestabilire",
    "prestabilite": "prestabilire",
    "prestabiliti": "prestabilire",
    "prestabilito": "prestabilire",
    "prestabiliva": "prestabilire",
    "prestabilivamo": "prestabilire",
    "prestabilivan": "prestabilire",
    "prestabilivano": "prestabilire",
    "prestabilivate": "prestabilire",
    "prestabilivi": "prestabilire",
    "prestabilivo": "prestabilire",
    "prestabilo": "prestabilire",
    "prestabilon": "prestabilire",
    "prestabilono": "prestabilire",
    "prestabilì": "prestabilire",
    "prestai": "prestare",
    "prestammo": "prestare",
    "prestan": "prestare",
    "prestando": "prestare",
    "prestano": "prestare",
    "prestanomi": "prestanome",
    "prestante": "prestare",
    "prestanti": "prestare",
    "prestanze": "prestanza",
    "prestar": "prestare",
    "prestaron": "prestare",
    "prestarono": "prestare",
    "prestasse": "prestare",
    "prestasser": "prestare",
    "prestassero": "prestare",
    "prestassi": "prestare",
    "prestassimo": "prestare",
    "prestaste": "prestare",
    "prestasti": "prestare",
    "prestata": "prestare",
    "prestate": "prestare",
    "prestati": "prestare",
    "prestato": "prestare",
    "prestatori": "prestatore",
    "prestava": "prestare",
    "prestavamo": "prestare",
    "prestavan": "prestare",
    "prestavano": "prestare",
    "prestavate": "prestare",
    "prestavi": "prestare",
    "prestavo": "prestare",
    "prestazioni": "prestazione",
    "preste": "presto",
    "presterai": "prestare",
    "presteran": "prestare",
    "presteranno": "prestare",
    "presterebbe": "prestare",
    "presterebber": "prestare",
    "presterebbero": "prestare",
    "presterei": "prestare",
    "presteremmo": "prestare",
    "presteremo": "prestare",
    "prestereste": "prestare",
    "presteresti": "prestare",
    "presterete": "prestare",
    "presterà": "prestare",
    "presterò": "prestare",
    "presti": "presto",
    "prestiamo": "prestare",
    "prestiate": "prestare",
    "prestigi": "prestigio",
    "prestigiatori": "prestigiatore",
    "prestigiosa": "prestigioso",
    "prestigiose": "prestigioso",
    "prestigiosi": "prestigioso",
    "prestin": "prestare",
    "prestino": "prestare",
    "prestiti": "prestito",
    "presto": "prestare",
    "prestò": "prestare",
    "presuli": "presule",
    "presuma": "presumere",
    "presuman": "presumere",
    "presumano": "presumere",
    "presume": "presumere",
    "presumemmo": "presumere",
    "presumendo": "presumere",
    "presumente": "presumere",
    "presumenti": "presumere",
    "presumer": "presumere",
    "presumerai": "presumere",
    "presumeran": "presumere",
    "presumeranno": "presumere",
    "presumerebbe": "presumere",
    "presumerebber": "presumere",
    "presumerebbero": "presumere",
    "presumerei": "presumere",
    "presumeremmo": "presumere",
    "presumeremo": "presumere",
    "presumereste": "presumere",
    "presumeresti": "presumere",
    "presumerete": "presumere",
    "presumerà": "presumere",
    "presumerò": "presumere",
    "presumesse": "presumere",
    "presumesser": "presumere",
    "presumessero": "presumere",
    "presumessi": "presumere",
    "presumessimo": "presumere",
    "presumeste": "presumere",
    "presumesti": "presumere",
    "presumete": "presumere",
    "presumeva": "presumere",
    "presumevamo": "presumere",
    "presumevan": "presumere",
    "presumevano": "presumere",
    "presumevate": "presumere",
    "presumevi": "presumere",
    "presumevo": "presumere",
    "presumi": "presumere",
    "presumiamo": "presumere",
    "presumiate": "presumere",
    "presumibili": "presumibile",
    "presumo": "presumere",
    "presumon": "presumere",
    "presumono": "presumere",
    "presunse": "presumere",
    "presunser": "presumere",
    "presunsero": "presumere",
    "presunsi": "presumere",
    "presunta": "presunto",
    "presunte": "presunto",
    "presunti": "presunto",
    "presuntiva": "presuntivo",
    "presuntive": "presuntivo",
    "presuntivi": "presuntivo",
    "presunto": "presumere",
    "presuntuosa": "presuntuoso",
    "presuntuose": "presuntuoso",
    "presuntuosi": "presuntuoso",
    "presunzioni": "presunzione",
    "presuppone": "presupporre",
    "presupponemmo": "presupporre",
    "presupponendo": "presupporre",
    "presupponente": "presupporre",
    "presupponenti": "presupporre",
    "presupponesse": "presupporre",
    "presupponesser": "presupporre",
    "presupponessero": "presupporre",
    "presupponessi": "presupporre",
    "presupponessimo": "presupporre",
    "presupponeste": "presupporre",
    "presupponesti": "presupporre",
    "presupponete": "presupporre",
    "presupponeva": "presupporre",
    "presupponevamo": "presupporre",
    "presupponevan": "presupporre",
    "presupponevano": "presupporre",
    "presupponevate": "presupporre",
    "presupponevi": "presupporre",
    "presupponevo": "presupporre",
    "presupponga": "presupporre",
    "presuppongan": "presupporre",
    "presuppongano": "presupporre",
    "presuppongo": "presupporre",
    "presuppongon": "presupporre",
    "presuppongono": "presupporre",
    "presupponi": "presupporre",
    "presupponiamo": "presupporre",
    "presupponiate": "presupporre",
    "presupporr": "presupporre",
    "presupporrai": "presupporre",
    "presupporran": "presupporre",
    "presupporranno": "presupporre",
    "presupporrebbe": "presupporre",
    "presupporrebber": "presupporre",
    "presupporrebbero": "presupporre",
    "presupporrei": "presupporre",
    "presupporremmo": "presupporre",
    "presupporremo": "presupporre",
    "presupporreste": "presupporre",
    "presupporresti": "presupporre",
    "presupporrete": "presupporre",
    "presupporrà": "presupporre",
    "presupporrò": "presupporre",
    "presuppose": "presupporre",
    "presupposer": "presupporre",
    "presupposero": "presupporre",
    "presupposi": "presupporre",
    "presupposta": "presupporre",
    "presupposte": "presupporre",
    "presupposti": "presupposto",
    "presupposto": "presupporre",
    "presè": "prendere",
    "pretenda": "pretendere",
    "pretendan": "pretendere",
    "pretendano": "pretendere",
    "pretende": "pretendere",
    "pretendemmo": "pretendere",
    "pretendendo": "pretendere",
    "pretendente": "pretendere",
    "pretendenti": "pretendere",
    "pretender": "pretendere",
    "pretenderai": "pretendere",
    "pretenderan": "pretendere",
    "pretenderanno": "pretendere",
    "pretenderebbe": "pretendere",
    "pretenderebber": "pretendere",
    "pretenderebbero": "pretendere",
    "pretenderei": "pretendere",
    "pretenderemmo": "pretendere",
    "pretenderemo": "pretendere",
    "pretendereste": "pretendere",
    "pretenderesti": "pretendere",
    "pretenderete": "pretendere",
    "pretenderà": "pretendere",
    "pretenderò": "pretendere",
    "pretendesse": "pretendere",
    "pretendesser": "pretendere",
    "pretendessero": "pretendere",
    "pretendessi": "pretendere",
    "pretendessimo": "pretendere",
    "pretendeste": "pretendere",
    "pretendesti": "pretendere",
    "pretendete": "pretendere",
    "pretendeva": "pretendere",
    "pretendevamo": "pretendere",
    "pretendevan": "pretendere",
    "pretendevano": "pretendere",
    "pretendevate": "pretendere",
    "pretendevi": "pretendere",
    "pretendevo": "pretendere",
    "pretendi": "pretendere",
    "pretendiamo": "pretendere",
    "pretendiate": "pretendere",
    "pretendo": "pretendere",
    "pretendon": "pretendere",
    "pretendono": "pretendere",
    "pretensionatori": "pretensionatore",
    "pretenziosa": "pretenzioso",
    "pretenziose": "pretenzioso",
    "pretenziosi": "pretenzioso",
    "preterintenzionali": "preterintenzionale",
    "pretesa": "preteso",
    "pretese": "preteso",
    "preteser": "pretendere",
    "pretesero": "pretendere",
    "pretesi": "preteso",
    "preteso": "pretendere",
    "pretesti": "pretesto",
    "pretestuosa": "pretestuoso",
    "pretestuose": "pretestuoso",
    "pretestuosi": "pretestuoso",
    "pretesè": "pretendere",
    "preti": "prete",
    "pretini": "pretino",
    "pretori": "pretorio",
    "pretoria": "pretorio",
    "pretoriani": "pretoriano",
    "pretorie": "pretorio",
    "pretta": "pretto",
    "prette": "pretto",
    "pretti": "pretto",
    "preture": "pretura",
    "prevale": "prevalere",
    "prevalemmo": "prevalere",
    "prevalendo": "prevalere",
    "prevalente": "prevalere",
    "prevalenti": "prevalere",
    "prevaler": "prevalere",
    "prevalesse": "prevalere",
    "prevalesser": "prevalere",
    "prevalessero": "prevalere",
    "prevalessi": "prevalere",
    "prevalessimo": "prevalere",
    "prevaleste": "prevalere",
    "prevalesti": "prevalere",
    "prevalete": "prevalere",
    "prevaleva": "prevalere",
    "prevalevamo": "prevalere",
    "prevalevan": "prevalere",
    "prevalevano": "prevalere",
    "prevalevate": "prevalere",
    "prevalevi": "prevalere",
    "prevalevo": "prevalere",
    "prevalga": "prevalere",
    "prevalgan": "prevalere",
    "prevalgano": "prevalere",
    "prevalgo": "prevalere",
    "prevalgon": "prevalere",
    "prevalgono": "prevalere",
    "prevali": "prevalere",
    "prevaliamo": "prevalere",
    "prevaliate": "prevalere",
    "prevalsa": "prevalere",
    "prevalse": "prevalere",
    "prevalser": "prevalere",
    "prevalsero": "prevalere",
    "prevalsi": "prevalere",
    "prevalso": "prevalere",
    "prevarica": "prevaricare",
    "prevaricai": "prevaricare",
    "prevaricammo": "prevaricare",
    "prevarican": "prevaricare",
    "prevaricando": "prevaricare",
    "prevaricano": "prevaricare",
    "prevaricante": "prevaricare",
    "prevaricanti": "prevaricare",
    "prevaricar": "prevaricare",
    "prevaricaron": "prevaricare",
    "prevaricarono": "prevaricare",
    "prevaricasse": "prevaricare",
    "prevaricasser": "prevaricare",
    "prevaricassero": "prevaricare",
    "prevaricassi": "prevaricare",
    "prevaricassimo": "prevaricare",
    "prevaricaste": "prevaricare",
    "prevaricasti": "prevaricare",
    "prevaricata": "prevaricare",
    "prevaricate": "prevaricare",
    "prevaricati": "prevaricare",
    "prevaricato": "prevaricare",
    "prevaricatori": "prevaricatore",
    "prevaricatrice": "prevaricatore",
    "prevaricatrici": "prevaricatore",
    "prevaricava": "prevaricare",
    "prevaricavamo": "prevaricare",
    "prevaricavan": "prevaricare",
    "prevaricavano": "prevaricare",
    "prevaricavate": "prevaricare",
    "prevaricavi": "prevaricare",
    "prevaricavo": "prevaricare",
    "prevaricazioni": "prevaricazione",
    "prevaricherai": "prevaricare",
    "prevaricheran": "prevaricare",
    "prevaricheranno": "prevaricare",
    "prevaricherebbe": "prevaricare",
    "prevaricherebber": "prevaricare",
    "prevaricherebbero": "prevaricare",
    "prevaricherei": "prevaricare",
    "prevaricheremmo": "prevaricare",
    "prevaricheremo": "prevaricare",
    "prevarichereste": "prevaricare",
    "prevaricheresti": "prevaricare",
    "prevaricherete": "prevaricare",
    "prevaricherà": "prevaricare",
    "prevaricherò": "prevaricare",
    "prevarichi": "prevaricare",
    "prevarichiamo": "prevaricare",
    "prevarichiate": "prevaricare",
    "prevarichin": "prevaricare",
    "prevarichino": "prevaricare",
    "prevarico": "prevaricare",
    "prevaricò": "prevaricare",
    "prevarrai": "prevalere",
    "prevarran": "prevalere",
    "prevarranno": "prevalere",
    "prevarrebbe": "prevalere",
    "prevarrebber": "prevalere",
    "prevarrebbero": "prevalere",
    "prevarrei": "prevalere",
    "prevarremmo": "prevalere",
    "prevarremo": "prevalere",
    "prevarreste": "prevalere",
    "prevarresti": "prevalere",
    "prevarrete": "prevalere",
    "prevarrà": "prevalere",
    "prevarrò": "prevalere",
    "preveda": "prevedere",
    "prevedan": "prevedere",
    "prevedano": "prevedere",
    "prevede": "prevedere",
    "prevedemmo": "prevedere",
    "prevedendo": "prevedere",
    "prevedente": "prevedere",
    "prevedenti": "prevedere",
    "preveder": "prevedere",
    "prevedesse": "prevedere",
    "prevedesser": "prevedere",
    "prevedessero": "prevedere",
    "prevedessi": "prevedere",
    "prevedessimo": "prevedere",
    "prevedeste": "prevedere",
    "prevedesti": "prevedere",
    "prevedete": "prevedere",
    "prevedeva": "prevedere",
    "prevedevamo": "prevedere",
    "prevedevan": "prevedere",
    "prevedevano": "prevedere",
    "prevedevate": "prevedere",
    "prevedevi": "prevedere",
    "prevedevo": "prevedere",
    "prevedi": "prevedere",
    "prevediamo": "prevedere",
    "prevediate": "prevedere",
    "prevedibili": "prevedibile",
    "prevedo": "prevedere",
    "prevedon": "prevedere",
    "prevedono": "prevedere",
    "prevedrai": "prevedere",
    "prevedran": "prevedere",
    "prevedranno": "prevedere",
    "prevedrebbe": "prevedere",
    "prevedrebber": "prevedere",
    "prevedrebbero": "prevedere",
    "prevedrei": "prevedere",
    "prevedremmo": "prevedere",
    "prevedremo": "prevedere",
    "prevedreste": "prevedere",
    "prevedresti": "prevedere",
    "prevedrete": "prevedere",
    "prevedrà": "prevedere",
    "prevedrò": "prevedere",
    "preveduta": "prevedere",
    "prevedute": "prevedere",
    "preveduti": "prevedere",
    "preveduto": "prevedere",
    "preveggenti": "preveggente",
    "preveggenze": "preveggenza",
    "prevendite": "prevendita",
    "prevenendo": "prevenire",
    "prevenga": "prevenire",
    "prevengan": "prevenire",
    "prevengano": "prevenire",
    "prevengo": "prevenire",
    "prevengon": "prevenire",
    "prevengono": "prevenire",
    "preveniamo": "prevenire",
    "preveniate": "prevenire",
    "preveniente": "prevenire",
    "prevenienti": "prevenire",
    "prevenimmo": "prevenire",
    "prevenir": "prevenire",
    "prevenisse": "prevenire",
    "prevenisser": "prevenire",
    "prevenissero": "prevenire",
    "prevenissi": "prevenire",
    "prevenissimo": "prevenire",
    "preveniste": "prevenire",
    "prevenisti": "prevenire",
    "prevenite": "prevenire",
    "preveniva": "prevenire",
    "prevenivamo": "prevenire",
    "prevenivan": "prevenire",
    "prevenivano": "prevenire",
    "prevenivate": "prevenire",
    "prevenivi": "prevenire",
    "prevenivo": "prevenire",
    "prevenne": "prevenire",
    "prevenner": "prevenire",
    "prevennero": "prevenire",
    "prevenni": "prevenire",
    "preventiva": "preventivo",
    "preventivai": "preventivare",
    "preventivammo": "preventivare",
    "preventivan": "preventivare",
    "preventivando": "preventivare",
    "preventivano": "preventivare",
    "preventivante": "preventivare",
    "preventivanti": "preventivare",
    "preventivar": "preventivare",
    "preventivaron": "preventivare",
    "preventivarono": "preventivare",
    "preventivasse": "preventivare",
    "preventivasser": "preventivare",
    "preventivassero": "preventivare",
    "preventivassi": "preventivare",
    "preventivassimo": "preventivare",
    "preventivaste": "preventivare",
    "preventivasti": "preventivare",
    "preventivata": "preventivare",
    "preventivate": "preventivare",
    "preventivati": "preventivare",
    "preventivato": "preventivare",
    "preventivava": "preventivare",
    "preventivavamo": "preventivare",
    "preventivavan": "preventivare",
    "preventivavano": "preventivare",
    "preventivavate": "preventivare",
    "preventivavi": "preventivare",
    "preventivavo": "preventivare",
    "preventive": "preventivo",
    "preventiverai": "preventivare",
    "preventiveran": "preventivare",
    "preventiveranno": "preventivare",
    "preventiverebbe": "preventivare",
    "preventiverebber": "preventivare",
    "preventiverebbero": "preventivare",
    "preventiverei": "preventivare",
    "preventiveremmo": "preventivare",
    "preventiveremo": "preventivare",
    "preventivereste": "preventivare",
    "preventiveresti": "preventivare",
    "preventiverete": "preventivare",
    "preventiverà": "preventivare",
    "preventiverò": "preventivare",
    "preventivi": "preventivo",
    "preventiviamo": "preventivare",
    "preventiviate": "preventivare",
    "preventivin": "preventivare",
    "preventivino": "preventivare",
    "preventivo": "preventivare",
    "preventivò": "preventivare",
    "prevenuta": "prevenuto",
    "prevenute": "prevenuto",
    "prevenuti": "prevenuto",
    "prevenuto": "prevenire",
    "prevenzioni": "prevenzione",
    "preverrai": "prevenire",
    "preverran": "prevenire",
    "preverranno": "prevenire",
    "preverrebbe": "prevenire",
    "preverrebber": "prevenire",
    "preverrebbero": "prevenire",
    "preverrei": "prevenire",
    "preverremmo": "prevenire",
    "preverremo": "prevenire",
    "preverreste": "prevenire",
    "preverresti": "prevenire",
    "preverrete": "prevenire",
    "preverrà": "prevenire",
    "preverrò": "prevenire",
    "previ": "previo",
    "previa": "previo",
    "previde": "prevedere",
    "previdenti": "previdente",
    "previdenze": "previdenza",
    "previdenziali": "previdenziale",
    "previder": "prevedere",
    "previdero": "prevedere",
    "previdi": "prevedere",
    "previe": "previo",
    "previene": "prevenire",
    "previeni": "prevenire",
    "previsionali": "previsionale",
    "previsioni": "previsione",
    "previsoni": "previsone",
    "prevista": "previsto",
    "previste": "previsto",
    "previsti": "previsto",
    "preziosa": "prezioso",
    "preziose": "prezioso",
    "preziosi": "prezioso",
    "preziosismi": "preziosismo",
    "prezzemoli": "prezzemolo",
    "prezzi": "prezzo",
    "prezzola": "prezzolare",
    "prezzolai": "prezzolare",
    "prezzolammo": "prezzolare",
    "prezzolan": "prezzolare",
    "prezzolando": "prezzolare",
    "prezzolano": "prezzolare",
    "prezzolante": "prezzolare",
    "prezzolanti": "prezzolare",
    "prezzolar": "prezzolare",
    "prezzolaron": "prezzolare",
    "prezzolarono": "prezzolare",
    "prezzolasse": "prezzolare",
    "prezzolasser": "prezzolare",
    "prezzolassero": "prezzolare",
    "prezzolassi": "prezzolare",
    "prezzolassimo": "prezzolare",
    "prezzolaste": "prezzolare",
    "prezzolasti": "prezzolare",
    "prezzolata": "prezzolato",
    "prezzolate": "prezzolato",
    "prezzolati": "prezzolato",
    "prezzolato": "prezzolare",
    "prezzolava": "prezzolare",
    "prezzolavamo": "prezzolare",
    "prezzolavan": "prezzolare",
    "prezzolavano": "prezzolare",
    "prezzolavate": "prezzolare",
    "prezzolavi": "prezzolare",
    "prezzolavo": "prezzolare",
    "prezzolerai": "prezzolare",
    "prezzoleran": "prezzolare",
    "prezzoleranno": "prezzolare",
    "prezzolerebbe": "prezzolare",
    "prezzolerebber": "prezzolare",
    "prezzolerebbero": "prezzolare",
    "prezzolerei": "prezzolare",
    "prezzoleremmo": "prezzolare",
    "prezzoleremo": "prezzolare",
    "prezzolereste": "prezzolare",
    "prezzoleresti": "prezzolare",
    "prezzolerete": "prezzolare",
    "prezzolerà": "prezzolare",
    "prezzolerò": "prezzolare",
    "prezzoli": "prezzolare",
    "prezzoliamo": "prezzolare",
    "prezzoliate": "prezzolare",
    "prezzolin": "prezzolare",
    "prezzolino": "prezzolare",
    "prezzolo": "prezzolare",
    "prezzolò": "prezzolare",
    "prigioneri": "prigionero",
    "prigioni": "prigione",
    "prigionie": "prigionia",
    "prigioniera": "prigioniero",
    "prigioniere": "prigioniero",
    "prigionieri": "prigioniero",
    "prilla": "prillare",
    "prillai": "prillare",
    "prillammo": "prillare",
    "prillan": "prillare",
    "prillando": "prillare",
    "prillano": "prillare",
    "prillante": "prillare",
    "prillanti": "prillare",
    "prillar": "prillare",
    "prillaron": "prillare",
    "prillarono": "prillare",
    "prillasse": "prillare",
    "prillasser": "prillare",
    "prillassero": "prillare",
    "prillassi": "prillare",
    "prillassimo": "prillare",
    "prillaste": "prillare",
    "prillasti": "prillare",
    "prillata": "prillare",
    "prillate": "prillare",
    "prillati": "prillare",
    "prillato": "prillare",
    "prillava": "prillare",
    "prillavamo": "prillare",
    "prillavan": "prillare",
    "prillavano": "prillare",
    "prillavate": "prillare",
    "prillavi": "prillare",
    "prillavo": "prillare",
    "prillerai": "prillare",
    "prilleran": "prillare",
    "prilleranno": "prillare",
    "prillerebbe": "prillare",
    "prillerebber": "prillare",
    "prillerebbero": "prillare",
    "prillerei": "prillare",
    "prilleremmo": "prillare",
    "prilleremo": "prillare",
    "prillereste": "prillare",
    "prilleresti": "prillare",
    "prillerete": "prillare",
    "prillerà": "prillare",
    "prillerò": "prillare",
    "prilli": "prillare",
    "prilliamo": "prillare",
    "prilliate": "prillare",
    "prillin": "prillare",
    "prillino": "prillare",
    "prillo": "prillare",
    "prillò": "prillare",
    "prima": "primo",
    "primari": "primario",
    "primaria": "primario",
    "primarie": "primario",
    "primati": "primato",
    "primatisti": "primatista",
    "primattori": "primattore",
    "primavere": "primavera",
    "primavere-estati": "primavera-estate",
    "primaverili": "primaverile",
    "primazie": "primazia",
    "prime": "primo",
    "primedonne": "primadonna",
    "primeggerai": "primeggiare",
    "primeggeran": "primeggiare",
    "primeggeranno": "primeggiare",
    "primeggerebbe": "primeggiare",
    "primeggerebber": "primeggiare",
    "primeggerebbero": "primeggiare",
    "primeggerei": "primeggiare",
    "primeggeremmo": "primeggiare",
    "primeggeremo": "primeggiare",
    "primeggereste": "primeggiare",
    "primeggeresti": "primeggiare",
    "primeggerete": "primeggiare",
    "primeggerà": "primeggiare",
    "primeggerò": "primeggiare",
    "primeggi": "primeggiare",
    "primeggia": "primeggiare",
    "primeggiai": "primeggiare",
    "primeggiammo": "primeggiare",
    "primeggiamo": "primeggiare",
    "primeggian": "primeggiare",
    "primeggiando": "primeggiare",
    "primeggiano": "primeggiare",
    "primeggiante": "primeggiare",
    "primeggianti": "primeggiare",
    "primeggiar": "primeggiare",
    "primeggiaron": "primeggiare",
    "primeggiarono": "primeggiare",
    "primeggiasse": "primeggiare",
    "primeggiasser": "primeggiare",
    "primeggiassero": "primeggiare",
    "primeggiassi": "primeggiare",
    "primeggiassimo": "primeggiare",
    "primeggiaste": "primeggiare",
    "primeggiasti": "primeggiare",
    "primeggiata": "primeggiare",
    "primeggiate": "primeggiare",
    "primeggiati": "primeggiare",
    "primeggiato": "primeggiare",
    "primeggiava": "primeggiare",
    "primeggiavamo": "primeggiare",
    "primeggiavan": "primeggiare",
    "primeggiavano": "primeggiare",
    "primeggiavate": "primeggiare",
    "primeggiavi": "primeggiare",
    "primeggiavo": "primeggiare",
    "primeggin": "primeggiare",
    "primeggino": "primeggiare",
    "primeggio": "primeggiare",
    "primeggiò": "primeggiare",
    "primi": "primo",
    "primigeni": "primigenio",
    "primigenia": "primigenio",
    "primigenie": "primigenio",
    "primitiva": "primitivo",
    "primitive": "primitivo",
    "primitivi": "primitivo",
    "primitivismi": "primitivismo",
    "primizie": "primizia",
    "primogenita": "primogenito",
    "primogenite": "primogenito",
    "primogeniti": "primogenito",
    "primogeniture": "primogenitura",
    "primordi": "primordio",
    "primordiali": "primordiale",
    "primule": "primula",
    "principali": "principale",
    "principati": "principato",
    "principesca": "principesco",
    "principesche": "principesco",
    "principeschi": "principesco",
    "principesse": "principessa",
    "principessine": "principessina",
    "principi": "principiare",
    "principia": "principiare",
    "principiai": "principiare",
    "principiammo": "principiare",
    "principiamo": "principiare",
    "principian": "principiare",
    "principiando": "principiare",
    "principiano": "principiare",
    "principiante": "principiare",
    "principianti": "principiare",
    "principiar": "principiare",
    "principiaron": "principiare",
    "principiarono": "principiare",
    "principiasse": "principiare",
    "principiasser": "principiare",
    "principiassero": "principiare",
    "principiassi": "principiare",
    "principiassimo": "principiare",
    "principiaste": "principiare",
    "principiasti": "principiare",
    "principiata": "principiare",
    "principiate": "principiare",
    "principiati": "principiare",
    "principiato": "principiare",
    "principiava": "principiare",
    "principiavamo": "principiare",
    "principiavan": "principiare",
    "principiavano": "principiare",
    "principiavate": "principiare",
    "principiavi": "principiare",
    "principiavo": "principiare",
    "principierai": "principiare",
    "principieran": "principiare",
    "principieranno": "principiare",
    "principierebbe": "principiare",
    "principierebber": "principiare",
    "principierebbero": "principiare",
    "principierei": "principiare",
    "principieremmo": "principiare",
    "principieremo": "principiare",
    "principiereste": "principiare",
    "principieresti": "principiare",
    "principierete": "principiare",
    "principierà": "principiare",
    "principierò": "principiare",
    "principii": "principio",
    "principin": "principiare",
    "principini": "principino",
    "principino": "principiare",
    "principio": "principiare",
    "principiò": "principiare",
    "princìpi": "princìpio",
    "priori": "priore",
    "prioritari": "prioritario",
    "prioritaria": "prioritario",
    "prioritarie": "prioritario",
    "prisca": "prisco",
    "prische": "prisco",
    "prischi": "prisco",
    "prismi": "prisma",
    "pristina": "pristino",
    "pristine": "pristino",
    "pristini": "pristino",
    "priva": "privo",
    "privai": "privare",
    "privammo": "privare",
    "privan": "privare",
    "privando": "privare",
    "privano": "privare",
    "privante": "privare",
    "privanti": "privare",
    "privar": "privare",
    "privaron": "privare",
    "privarono": "privare",
    "privasse": "privare",
    "privasser": "privare",
    "privassero": "privare",
    "privassi": "privare",
    "privassimo": "privare",
    "privaste": "privare",
    "privasti": "privare",
    "privata": "privato",
    "private": "privato",
    "privati": "privato",
    "privatisti": "privatista",
    "privatizza": "privatizzare",
    "privatizzai": "privatizzare",
    "privatizzammo": "privatizzare",
    "privatizzan": "privatizzare",
    "privatizzando": "privatizzare",
    "privatizzano": "privatizzare",
    "privatizzante": "privatizzare",
    "privatizzanti": "privatizzare",
    "privatizzar": "privatizzare",
    "privatizzaron": "privatizzare",
    "privatizzarono": "privatizzare",
    "privatizzasse": "privatizzare",
    "privatizzasser": "privatizzare",
    "privatizzassero": "privatizzare",
    "privatizzassi": "privatizzare",
    "privatizzassimo": "privatizzare",
    "privatizzaste": "privatizzare",
    "privatizzasti": "privatizzare",
    "privatizzata": "privatizzare",
    "privatizzate": "privatizzare",
    "privatizzati": "privatizzare",
    "privatizzato": "privatizzare",
    "privatizzatori": "privatizzatore",
    "privatizzava": "privatizzare",
    "privatizzavamo": "privatizzare",
    "privatizzavan": "privatizzare",
    "privatizzavano": "privatizzare",
    "privatizzavate": "privatizzare",
    "privatizzavi": "privatizzare",
    "privatizzavo": "privatizzare",
    "privatizzazioni": "privatizzazione",
    "privatizzerai": "privatizzare",
    "privatizzeran": "privatizzare",
    "privatizzeranno": "privatizzare",
    "privatizzerebbe": "privatizzare",
    "privatizzerebber": "privatizzare",
    "privatizzerebbero": "privatizzare",
    "privatizzerei": "privatizzare",
    "privatizzeremmo": "privatizzare",
    "privatizzeremo": "privatizzare",
    "privatizzereste": "privatizzare",
    "privatizzeresti": "privatizzare",
    "privatizzerete": "privatizzare",
    "privatizzerà": "privatizzare",
    "privatizzerò": "privatizzare",
    "privatizzi": "privatizzare",
    "privatizziamo": "privatizzare",
    "privatizziate": "privatizzare",
    "privatizzin": "privatizzare",
    "privatizzino": "privatizzare",
    "privatizzo": "privatizzare",
    "privatizzò": "privatizzare",
    "privato": "privare",
    "privava": "privare",
    "privavamo": "privare",
    "privavan": "privare",
    "privavano": "privare",
    "privavate": "privare",
    "privavi": "privare",
    "privavo": "privare",
    "privazioni": "privazione",
    "prive": "privo",
    "priverai": "privare",
    "priveran": "privare",
    "priveranno": "privare",
    "priverebbe": "privare",
    "priverebber": "privare",
    "priverebbero": "privare",
    "priverei": "privare",
    "priveremmo": "privare",
    "priveremo": "privare",
    "privereste": "privare",
    "priveresti": "privare",
    "priverete": "privare",
    "priverà": "privare",
    "priverò": "privare",
    "privi": "privo",
    "priviamo": "privare",
    "priviate": "privare",
    "privilegerai": "privilegiare",
    "privilegeran": "privilegiare",
    "privilegeranno": "privilegiare",
    "privilegerebbe": "privilegiare",
    "privilegerebber": "privilegiare",
    "privilegerebbero": "privilegiare",
    "privilegerei": "privilegiare",
    "privilegeremmo": "privilegiare",
    "privilegeremo": "privilegiare",
    "privilegereste": "privilegiare",
    "privilegeresti": "privilegiare",
    "privilegerete": "privilegiare",
    "privilegerà": "privilegiare",
    "privilegerò": "privilegiare",
    "privilegi": "privilegio",
    "privilegia": "privilegiare",
    "privilegiai": "privilegiare",
    "privilegiammo": "privilegiare",
    "privilegiamo": "privilegiare",
    "privilegian": "privilegiare",
    "privilegiando": "privilegiare",
    "privilegiano": "privilegiare",
    "privilegiante": "privilegiare",
    "privilegianti": "privilegiare",
    "privilegiar": "privilegiare",
    "privilegiaron": "privilegiare",
    "privilegiarono": "privilegiare",
    "privilegiasse": "privilegiare",
    "privilegiasser": "privilegiare",
    "privilegiassero": "privilegiare",
    "privilegiassi": "privilegiare",
    "privilegiassimo": "privilegiare",
    "privilegiaste": "privilegiare",
    "privilegiasti": "privilegiare",
    "privilegiata": "privilegiato",
    "privilegiate": "privilegiato",
    "privilegiati": "privilegiato",
    "privilegiato": "privilegiare",
    "privilegiava": "privilegiare",
    "privilegiavamo": "privilegiare",
    "privilegiavan": "privilegiare",
    "privilegiavano": "privilegiare",
    "privilegiavate": "privilegiare",
    "privilegiavi": "privilegiare",
    "privilegiavo": "privilegiare",
    "privilegin": "privilegiare",
    "privilegino": "privilegiare",
    "privilegio": "privilegiare",
    "privilegiò": "privilegiare",
    "privin": "privare",
    "privino": "privare",
    "privo": "privare",
    "privò": "privare",
    "proba": "probo",
    "probabili": "probabile",
    "probabilistica": "probabilistico",
    "probabilistiche": "probabilistico",
    "probabilistici": "probabilistico",
    "probanti": "probante",
    "probatori": "probatorio",
    "probatoria": "probatorio",
    "probatorie": "probatorio",
    "probe": "probo",
    "probi": "probo",
    "probiviri": "proboviro",
    "problematica": "problematico",
    "problematiche": "problematico",
    "problematici": "problematico",
    "problemi": "problema",
    "problemini": "problemino",
    "procaccerai": "procacciare",
    "procacceran": "procacciare",
    "procacceranno": "procacciare",
    "procaccerebbe": "procacciare",
    "procaccerebber": "procacciare",
    "procaccerebbero": "procacciare",
    "procaccerei": "procacciare",
    "procacceremmo": "procacciare",
    "procacceremo": "procacciare",
    "procaccereste": "procacciare",
    "procacceresti": "procacciare",
    "procaccerete": "procacciare",
    "procaccerà": "procacciare",
    "procaccerò": "procacciare",
    "procacci": "procacciare",
    "procaccia": "procacciare",
    "procacciai": "procacciare",
    "procacciammo": "procacciare",
    "procacciamo": "procacciare",
    "procaccian": "procacciare",
    "procacciando": "procacciare",
    "procacciano": "procacciare",
    "procacciante": "procacciare",
    "procaccianti": "procacciare",
    "procacciar": "procacciare",
    "procacciaron": "procacciare",
    "procacciarono": "procacciare",
    "procacciasse": "procacciare",
    "procacciasser": "procacciare",
    "procacciassero": "procacciare",
    "procacciassi": "procacciare",
    "procacciassimo": "procacciare",
    "procacciaste": "procacciare",
    "procacciasti": "procacciare",
    "procacciata": "procacciare",
    "procacciate": "procacciare",
    "procacciati": "procacciare",
    "procacciato": "procacciare",
    "procacciatori": "procacciatore",
    "procacciava": "procacciare",
    "procacciavamo": "procacciare",
    "procacciavan": "procacciare",
    "procacciavano": "procacciare",
    "procacciavate": "procacciare",
    "procacciavi": "procacciare",
    "procacciavo": "procacciare",
    "procaccin": "procacciare",
    "procaccino": "procacciare",
    "procaccio": "procacciare",
    "procacciò": "procacciare",
    "procaci": "procace",
    "proccupazioni": "proccupazione",
    "proceda": "procedere",
    "procedan": "procedere",
    "procedano": "procedere",
    "procede": "procedere",
    "procedemmo": "procedere",
    "procedendo": "procedere",
    "procedente": "procedere",
    "procedenti": "procedere",
    "proceder": "procedere",
    "procederai": "procedere",
    "procederan": "procedere",
    "procederanno": "procedere",
    "procederebbe": "procedere",
    "procederebber": "procedere",
    "procederebbero": "procedere",
    "procederei": "procedere",
    "procederemmo": "procedere",
    "procederemo": "procedere",
    "procedereste": "procedere",
    "procederesti": "procedere",
    "procederete": "procedere",
    "procederà": "procedere",
    "procederò": "procedere",
    "procedesse": "procedere",
    "procedesser": "procedere",
    "procedessero": "procedere",
    "procedessi": "procedere",
    "procedessimo": "procedere",
    "procedeste": "procedere",
    "procedesti": "procedere",
    "procedete": "procedere",
    "procedette": "procedere",
    "procedetter": "procedere",
    "procedettero": "procedere",
    "procedetti": "procedere",
    "procedeva": "procedere",
    "procedevamo": "procedere",
    "procedevan": "procedere",
    "procedevano": "procedere",
    "procedevate": "procedere",
    "procedevi": "procedere",
    "procedevo": "procedere",
    "procedi": "procedere",
    "procediamo": "procedere",
    "procediate": "procedere",
    "procedimenti": "procedimento",
    "procedo": "procedere",
    "procedon": "procedere",
    "procedono": "procedere",
    "procedurali": "procedurale",
    "procedure": "procedura",
    "proceduta": "procedere",
    "procedute": "procedere",
    "proceduti": "procedere",
    "proceduto": "procedere",
    "procellosa": "procelloso",
    "procellose": "procelloso",
    "procellosi": "procelloso",
    "processa": "processare",
    "processabili": "processabile",
    "processai": "processare",
    "processammo": "processare",
    "processan": "processare",
    "processando": "processare",
    "processano": "processare",
    "processante": "processare",
    "processanti": "processare",
    "processar": "processare",
    "processaron": "processare",
    "processarono": "processare",
    "processasse": "processare",
    "processasser": "processare",
    "processassero": "processare",
    "processassi": "processare",
    "processassimo": "processare",
    "processaste": "processare",
    "processasti": "processare",
    "processata": "processare",
    "processate": "processare",
    "processati": "processare",
    "processato": "processare",
    "processava": "processare",
    "processavamo": "processare",
    "processavan": "processare",
    "processavano": "processare",
    "processavate": "processare",
    "processavi": "processare",
    "processavo": "processare",
    "processerai": "processare",
    "processeran": "processare",
    "processeranno": "processare",
    "processerebbe": "processare",
    "processerebber": "processare",
    "processerebbero": "processare",
    "processerei": "processare",
    "processeremmo": "processare",
    "processeremo": "processare",
    "processereste": "processare",
    "processeresti": "processare",
    "processerete": "processare",
    "processerà": "processare",
    "processerò": "processare",
    "processi": "processo",
    "processiamo": "processare",
    "processiate": "processare",
    "processin": "processare",
    "processino": "processare",
    "processioni": "processione",
    "processo": "processare",
    "processoni": "processone",
    "processori": "processore",
    "processuali": "processuale",
    "processò": "processare",
    "proclama": "proclamare",
    "proclamai": "proclamare",
    "proclamammo": "proclamare",
    "proclaman": "proclamare",
    "proclamando": "proclamare",
    "proclamano": "proclamare",
    "proclamante": "proclamare",
    "proclamanti": "proclamare",
    "proclamar": "proclamare",
    "proclamaron": "proclamare",
    "proclamarono": "proclamare",
    "proclamasse": "proclamare",
    "proclamasser": "proclamare",
    "proclamassero": "proclamare",
    "proclamassi": "proclamare",
    "proclamassimo": "proclamare",
    "proclamaste": "proclamare",
    "proclamasti": "proclamare",
    "proclamata": "proclamare",
    "proclamate": "proclamare",
    "proclamati": "proclamare",
    "proclamato": "proclamare",
    "proclamava": "proclamare",
    "proclamavamo": "proclamare",
    "proclamavan": "proclamare",
    "proclamavano": "proclamare",
    "proclamavate": "proclamare",
    "proclamavi": "proclamare",
    "proclamavo": "proclamare",
    "proclamazioni": "proclamazione",
    "proclamerai": "proclamare",
    "proclameran": "proclamare",
    "proclameranno": "proclamare",
    "proclamerebbe": "proclamare",
    "proclamerebber": "proclamare",
    "proclamerebbero": "proclamare",
    "proclamerei": "proclamare",
    "proclameremmo": "proclamare",
    "proclameremo": "proclamare",
    "proclamereste": "proclamare",
    "proclameresti": "proclamare",
    "proclamerete": "proclamare",
    "proclamerà": "proclamare",
    "proclamerò": "proclamare",
    "proclami": "proclamare",
    "proclamiamo": "proclamare",
    "proclamiate": "proclamare",
    "proclamin": "proclamare",
    "proclamino": "proclamare",
    "proclamo": "proclamare",
    "proclamò": "proclamare",
    "proclivi": "proclive",
    "procomba": "procombere",
    "procomban": "procombere",
    "procombano": "procombere",
    "procombe": "procombere",
    "procombei": "procombere",
    "procombemmo": "procombere",
    "procombendo": "procombere",
    "procombente": "procombere",
    "procombenti": "procombere",
    "procomber": "procombere",
    "procomberai": "procombere",
    "procomberan": "procombere",
    "procomberanno": "procombere",
    "procomberebbe": "procombere",
    "procomberebber": "procombere",
    "procomberebbero": "procombere",
    "procomberei": "procombere",
    "procomberemmo": "procombere",
    "procomberemo": "procombere",
    "procombereste": "procombere",
    "procomberesti": "procombere",
    "procomberete": "procombere",
    "procomberon": "procombere",
    "procomberono": "procombere",
    "procomberà": "procombere",
    "procomberò": "procombere",
    "procombesse": "procombere",
    "procombesser": "procombere",
    "procombessero": "procombere",
    "procombessi": "procombere",
    "procombessimo": "procombere",
    "procombeste": "procombere",
    "procombesti": "procombere",
    "procombete": "procombere",
    "procombeva": "procombere",
    "procombevamo": "procombere",
    "procombevan": "procombere",
    "procombevano": "procombere",
    "procombevate": "procombere",
    "procombevi": "procombere",
    "procombevo": "procombere",
    "procombi": "procombere",
    "procombiamo": "procombere",
    "procombiate": "procombere",
    "procombo": "procombere",
    "procombon": "procombere",
    "procombono": "procombere",
    "procombuta": "procombere",
    "procombute": "procombere",
    "procombuti": "procombere",
    "procombuto": "procombere",
    "procombè": "procombere",
    "proconsoli": "proconsole",
    "procrastina": "procrastinare",
    "procrastinai": "procrastinare",
    "procrastinammo": "procrastinare",
    "procrastinan": "procrastinare",
    "procrastinando": "procrastinare",
    "procrastinano": "procrastinare",
    "procrastinante": "procrastinare",
    "procrastinanti": "procrastinare",
    "procrastinar": "procrastinare",
    "procrastinaron": "procrastinare",
    "procrastinarono": "procrastinare",
    "procrastinasse": "procrastinare",
    "procrastinasser": "procrastinare",
    "procrastinassero": "procrastinare",
    "procrastinassi": "procrastinare",
    "procrastinassimo": "procrastinare",
    "procrastinaste": "procrastinare",
    "procrastinasti": "procrastinare",
    "procrastinata": "procrastinare",
    "procrastinate": "procrastinare",
    "procrastinati": "procrastinare",
    "procrastinato": "procrastinare",
    "procrastinava": "procrastinare",
    "procrastinavamo": "procrastinare",
    "procrastinavan": "procrastinare",
    "procrastinavano": "procrastinare",
    "procrastinavate": "procrastinare",
    "procrastinavi": "procrastinare",
    "procrastinavo": "procrastinare",
    "procrastinerai": "procrastinare",
    "procrastineran": "procrastinare",
    "procrastineranno": "procrastinare",
    "procrastinerebbe": "procrastinare",
    "procrastinerebber": "procrastinare",
    "procrastinerebbero": "procrastinare",
    "procrastinerei": "procrastinare",
    "procrastineremmo": "procrastinare",
    "procrastineremo": "procrastinare",
    "procrastinereste": "procrastinare",
    "procrastineresti": "procrastinare",
    "procrastinerete": "procrastinare",
    "procrastinerà": "procrastinare",
    "procrastinerò": "procrastinare",
    "procrastini": "procrastinare",
    "procrastiniamo": "procrastinare",
    "procrastiniate": "procrastinare",
    "procrastinin": "procrastinare",
    "procrastinino": "procrastinare",
    "procrastino": "procrastinare",
    "procrastinò": "procrastinare",
    "procrea": "procreare",
    "procreai": "procreare",
    "procreammo": "procreare",
    "procrean": "procreare",
    "procreando": "procreare",
    "procreano": "procreare",
    "procreante": "procreare",
    "procreanti": "procreare",
    "procrear": "procreare",
    "procrearon": "procreare",
    "procrearono": "procreare",
    "procreasse": "procreare",
    "procreasser": "procreare",
    "procreassero": "procreare",
    "procreassi": "procreare",
    "procreassimo": "procreare",
    "procreaste": "procreare",
    "procreasti": "procreare",
    "procreata": "procreare",
    "procreate": "procreare",
    "procreati": "procreare",
    "procreato": "procreare",
    "procreava": "procreare",
    "procreavamo": "procreare",
    "procreavan": "procreare",
    "procreavano": "procreare",
    "procreavate": "procreare",
    "procreavi": "procreare",
    "procreavo": "procreare",
    "procreazioni": "procreazione",
    "procreerai": "procreare",
    "procreeran": "procreare",
    "procreeranno": "procreare",
    "procreerebbe": "procreare",
    "procreerebber": "procreare",
    "procreerebbero": "procreare",
    "procreerei": "procreare",
    "procreeremmo": "procreare",
    "procreeremo": "procreare",
    "procreereste": "procreare",
    "procreeresti": "procreare",
    "procreerete": "procreare",
    "procreerà": "procreare",
    "procreerò": "procreare",
    "procrei": "procreare",
    "procreiamo": "procreare",
    "procreiate": "procreare",
    "procrein": "procreare",
    "procreino": "procreare",
    "procreo": "procreare",
    "procreò": "procreare",
    "procura": "procurare",
    "procurai": "procurare",
    "procurammo": "procurare",
    "procuran": "procurare",
    "procurando": "procurare",
    "procurano": "procurare",
    "procurante": "procurare",
    "procuranti": "procurare",
    "procurar": "procurare",
    "procuraron": "procurare",
    "procurarono": "procurare",
    "procurasse": "procurare",
    "procurasser": "procurare",
    "procurassero": "procurare",
    "procurassi": "procurare",
    "procurassimo": "procurare",
    "procuraste": "procurare",
    "procurasti": "procurare",
    "procurata": "procurare",
    "procurate": "procurare",
    "procurati": "procurare",
    "procurato": "procurare",
    "procuratori": "procuratore",
    "procurava": "procurare",
    "procuravamo": "procurare",
    "procuravan": "procurare",
    "procuravano": "procurare",
    "procuravate": "procurare",
    "procuravi": "procurare",
    "procuravo": "procurare",
    "procure": "procura",
    "procurerai": "procurare",
    "procureran": "procurare",
    "procureranno": "procurare",
    "procurerebbe": "procurare",
    "procurerebber": "procurare",
    "procurerebbero": "procurare",
    "procurerei": "procurare",
    "procureremmo": "procurare",
    "procureremo": "procurare",
    "procurereste": "procurare",
    "procureresti": "procurare",
    "procurerete": "procurare",
    "procurerà": "procurare",
    "procurerò": "procurare",
    "procuri": "procurare",
    "procuriamo": "procurare",
    "procuriate": "procurare",
    "procurin": "procurare",
    "procurino": "procurare",
    "procuro": "procurare",
    "procurò": "procurare",
    "prodezze": "prodezza",
    "prodi": "prode",
    "prodian-dipietriste": "prodian-dipietrista",
    "prodian-dipietristi": "prodian-dipietrista",
    "prodiana": "prodiano",
    "prodiane": "prodiano",
    "prodiani": "prodiano",
    "prodiga": "prodigo",
    "prodigai": "prodigare",
    "prodigammo": "prodigare",
    "prodigan": "prodigare",
    "prodigando": "prodigare",
    "prodigano": "prodigare",
    "prodigante": "prodigare",
    "prodiganti": "prodigare",
    "prodigar": "prodigare",
    "prodigaron": "prodigare",
    "prodigarono": "prodigare",
    "prodigasse": "prodigare",
    "prodigasser": "prodigare",
    "prodigassero": "prodigare",
    "prodigassi": "prodigare",
    "prodigassimo": "prodigare",
    "prodigaste": "prodigare",
    "prodigasti": "prodigare",
    "prodigata": "prodigare",
    "prodigate": "prodigare",
    "prodigati": "prodigare",
    "prodigato": "prodigare",
    "prodigava": "prodigare",
    "prodigavamo": "prodigare",
    "prodigavan": "prodigare",
    "prodigavano": "prodigare",
    "prodigavate": "prodigare",
    "prodigavi": "prodigare",
    "prodigavo": "prodigare",
    "prodighe": "prodigo",
    "prodigherai": "prodigare",
    "prodigheran": "prodigare",
    "prodigheranno": "prodigare",
    "prodigherebbe": "prodigare",
    "prodigherebber": "prodigare",
    "prodigherebbero": "prodigare",
    "prodigherei": "prodigare",
    "prodigheremmo": "prodigare",
    "prodigheremo": "prodigare",
    "prodighereste": "prodigare",
    "prodigheresti": "prodigare",
    "prodigherete": "prodigare",
    "prodigherà": "prodigare",
    "prodigherò": "prodigare",
    "prodighi": "prodigo",
    "prodighiamo": "prodigare",
    "prodighiate": "prodigare",
    "prodighin": "prodigare",
    "prodighino": "prodigare",
    "prodigi": "prodigio",
    "prodigia": "prodigio",
    "prodigie": "prodigio",
    "prodigiosa": "prodigioso",
    "prodigiose": "prodigioso",
    "prodigiosi": "prodigioso",
    "prodigo": "prodigare",
    "prodigò": "prodigare",
    "proditori": "proditorio",
    "proditoria": "proditorio",
    "proditorie": "proditorio",
    "prodotta": "produrre",
    "prodotte": "produrre",
    "prodotti": "produrre",
    "prodotto": "produrre",
    "prodromi": "prodromo",
    "produca": "produrre",
    "producan": "produrre",
    "producano": "produrre",
    "produce": "produrre",
    "producemmo": "produrre",
    "producendo": "produrre",
    "producente": "produrre",
    "producenti": "produrre",
    "producesse": "produrre",
    "producesser": "produrre",
    "producessero": "produrre",
    "producessi": "produrre",
    "producessimo": "produrre",
    "produceste": "produrre",
    "producesti": "produrre",
    "producete": "produrre",
    "produceva": "produrre",
    "producevamo": "produrre",
    "producevan": "produrre",
    "producevano": "produrre",
    "producevate": "produrre",
    "producevi": "produrre",
    "producevo": "produrre",
    "produci": "produrre",
    "produciamo": "produrre",
    "produciate": "produrre",
    "produco": "produrre",
    "producon": "produrre",
    "producono": "produrre",
    "produrr": "produrre",
    "produrrai": "produrre",
    "produrran": "produrre",
    "produrranno": "produrre",
    "produrrebbe": "produrre",
    "produrrebber": "produrre",
    "produrrebbero": "produrre",
    "produrrei": "produrre",
    "produrremmo": "produrre",
    "produrremo": "produrre",
    "produrreste": "produrre",
    "produrresti": "produrre",
    "produrrete": "produrre",
    "produrrà": "produrre",
    "produrrò": "produrre",
    "produsse": "produrre",
    "produsser": "produrre",
    "produssero": "produrre",
    "produssi": "produrre",
    "produttiva": "produttivo",
    "produttive": "produttivo",
    "produttivi": "produttivo",
    "produttori": "produttore",
    "produttrice": "produttore",
    "produttrici": "produttrice",
    "produzioni": "produzione",
    "profana": "profano",
    "profanai": "profanare",
    "profanammo": "profanare",
    "profanan": "profanare",
    "profanando": "profanare",
    "profanano": "profanare",
    "profanante": "profanare",
    "profananti": "profanare",
    "profanar": "profanare",
    "profanaron": "profanare",
    "profanarono": "profanare",
    "profanasse": "profanare",
    "profanasser": "profanare",
    "profanassero": "profanare",
    "profanassi": "profanare",
    "profanassimo": "profanare",
    "profanaste": "profanare",
    "profanasti": "profanare",
    "profanata": "profanare",
    "profanate": "profanare",
    "profanati": "profanare",
    "profanato": "profanare",
    "profanatori": "profanatore",
    "profanava": "profanare",
    "profanavamo": "profanare",
    "profanavan": "profanare",
    "profanavano": "profanare",
    "profanavate": "profanare",
    "profanavi": "profanare",
    "profanavo": "profanare",
    "profanazioni": "profanazione",
    "profane": "profano",
    "profanerai": "profanare",
    "profaneran": "profanare",
    "profaneranno": "profanare",
    "profanerebbe": "profanare",
    "profanerebber": "profanare",
    "profanerebbero": "profanare",
    "profanerei": "profanare",
    "profaneremmo": "profanare",
    "profaneremo": "profanare",
    "profanereste": "profanare",
    "profaneresti": "profanare",
    "profanerete": "profanare",
    "profanerà": "profanare",
    "profanerò": "profanare",
    "profani": "profano",
    "profaniamo": "profanare",
    "profaniate": "profanare",
    "profanin": "profanare",
    "profanino": "profanare",
    "profano": "profanare",
    "profanò": "profanare",
    "proferendo": "proferire",
    "proferente": "proferire",
    "proferenti": "proferire",
    "proferiamo": "proferire",
    "proferiate": "proferire",
    "proferii": "proferire",
    "proferimmo": "proferire",
    "proferir": "proferire",
    "proferirai": "proferire",
    "proferiran": "proferire",
    "proferiranno": "proferire",
    "proferirebbe": "proferire",
    "proferirebber": "proferire",
    "proferirebbero": "proferire",
    "proferirei": "proferire",
    "proferiremmo": "proferire",
    "proferiremo": "proferire",
    "proferireste": "proferire",
    "proferiresti": "proferire",
    "proferirete": "proferire",
    "proferiron": "proferire",
    "proferirono": "proferire",
    "proferirà": "proferire",
    "proferirò": "proferire",
    "proferisca": "proferire",
    "proferiscan": "proferire",
    "proferiscano": "proferire",
    "proferisce": "proferire",
    "proferisci": "proferire",
    "proferisco": "proferire",
    "proferiscon": "proferire",
    "proferiscono": "proferire",
    "proferisse": "proferire",
    "proferisser": "proferire",
    "proferissero": "proferire",
    "proferissi": "proferire",
    "proferissimo": "proferire",
    "proferiste": "proferire",
    "proferisti": "proferire",
    "proferita": "proferire",
    "proferite": "proferire",
    "proferiti": "proferire",
    "proferito": "proferire",
    "proferiva": "proferire",
    "proferivamo": "proferire",
    "proferivan": "proferire",
    "proferivano": "proferire",
    "proferivate": "proferire",
    "proferivi": "proferire",
    "proferivo": "proferire",
    "proferì": "proferire",
    "professa": "professo",
    "professai": "professare",
    "professammo": "professare",
    "professan": "professare",
    "professando": "professare",
    "professano": "professare",
    "professante": "professare",
    "professanti": "professare",
    "professar": "professare",
    "professaron": "professare",
    "professarono": "professare",
    "professasse": "professare",
    "professasser": "professare",
    "professassero": "professare",
    "professassi": "professare",
    "professassimo": "professare",
    "professaste": "professare",
    "professasti": "professare",
    "professata": "professare",
    "professate": "professare",
    "professati": "professare",
    "professato": "professare",
    "professava": "professare",
    "professavamo": "professare",
    "professavan": "professare",
    "professavano": "professare",
    "professavate": "professare",
    "professavi": "professare",
    "professavo": "professare",
    "professe": "professo",
    "professerai": "professare",
    "professeran": "professare",
    "professeranno": "professare",
    "professerebbe": "professare",
    "professerebber": "professare",
    "professerebbero": "professare",
    "professerei": "professare",
    "professeremmo": "professare",
    "professeremo": "professare",
    "professereste": "professare",
    "professeresti": "professare",
    "professerete": "professare",
    "professerà": "professare",
    "professerò": "professare",
    "professi": "professo",
    "professiamo": "professare",
    "professiate": "professare",
    "professin": "professare",
    "professino": "professare",
    "professionali": "professionale",
    "professionalizza": "professionalizzare",
    "professionalizzai": "professionalizzare",
    "professionalizzammo": "professionalizzare",
    "professionalizzan": "professionalizzare",
    "professionalizzando": "professionalizzare",
    "professionalizzano": "professionalizzare",
    "professionalizzante": "professionalizzare",
    "professionalizzanti": "professionalizzare",
    "professionalizzar": "professionalizzare",
    "professionalizzaron": "professionalizzare",
    "professionalizzarono": "professionalizzare",
    "professionalizzasse": "professionalizzare",
    "professionalizzasser": "professionalizzare",
    "professionalizzassero": "professionalizzare",
    "professionalizzassi": "professionalizzare",
    "professionalizzassimo": "professionalizzare",
    "professionalizzaste": "professionalizzare",
    "professionalizzasti": "professionalizzare",
    "professionalizzata": "professionalizzare",
    "professionalizzate": "professionalizzare",
    "professionalizzati": "professionalizzare",
    "professionalizzato": "professionalizzare",
    "professionalizzava": "professionalizzare",
    "professionalizzavamo": "professionalizzare",
    "professionalizzavan": "professionalizzare",
    "professionalizzavano": "professionalizzare",
    "professionalizzavate": "professionalizzare",
    "professionalizzavi": "professionalizzare",
    "professionalizzavo": "professionalizzare",
    "professionalizzerai": "professionalizzare",
    "professionalizzeran": "professionalizzare",
    "professionalizzeranno": "professionalizzare",
    "professionalizzerebbe": "professionalizzare",
    "professionalizzerebber": "professionalizzare",
    "professionalizzerebbero": "professionalizzare",
    "professionalizzerei": "professionalizzare",
    "professionalizzeremmo": "professionalizzare",
    "professionalizzeremo": "professionalizzare",
    "professionalizzereste": "professionalizzare",
    "professionalizzeresti": "professionalizzare",
    "professionalizzerete": "professionalizzare",
    "professionalizzerà": "professionalizzare",
    "professionalizzerò": "professionalizzare",
    "professionalizzi": "professionalizzare",
    "professionalizziamo": "professionalizzare",
    "professionalizziate": "professionalizzare",
    "professionalizzin": "professionalizzare",
    "professionalizzino": "professionalizzare",
    "professionalizzo": "professionalizzare",
    "professionalizzò": "professionalizzare",
    "professioni": "professione",
    "professionismi": "professionismo",
    "professioniste": "professionista",
    "professionisti": "professionista",
    "professionistica": "professionistico",
    "professionistiche": "professionistico",
    "professionistici": "professionistico",
    "professo": "professare",
    "professor": "professore",
    "professorali": "professorale",
    "professoresse": "professoressa",
    "professori": "professore",
    "professorini": "professorino",
    "professoroni": "professorone",
    "professò": "professare",
    "profeta": "profetare",
    "profetai": "profetare",
    "profetammo": "profetare",
    "profetan": "profetare",
    "profetando": "profetare",
    "profetano": "profetare",
    "profetante": "profetare",
    "profetanti": "profetare",
    "profetar": "profetare",
    "profetaron": "profetare",
    "profetarono": "profetare",
    "profetasse": "profetare",
    "profetasser": "profetare",
    "profetassero": "profetare",
    "profetassi": "profetare",
    "profetassimo": "profetare",
    "profetaste": "profetare",
    "profetasti": "profetare",
    "profetata": "profetare",
    "profetate": "profetare",
    "profetati": "profetare",
    "profetato": "profetare",
    "profetava": "profetare",
    "profetavamo": "profetare",
    "profetavan": "profetare",
    "profetavano": "profetare",
    "profetavate": "profetare",
    "profetavi": "profetare",
    "profetavo": "profetare",
    "profeterai": "profetare",
    "profeteran": "profetare",
    "profeteranno": "profetare",
    "profeterebbe": "profetare",
    "profeterebber": "profetare",
    "profeterebbero": "profetare",
    "profeterei": "profetare",
    "profeteremmo": "profetare",
    "profeteremo": "profetare",
    "profetereste": "profetare",
    "profeteresti": "profetare",
    "profeterete": "profetare",
    "profeterà": "profetare",
    "profeterò": "profetare",
    "profeti": "profetare",
    "profetiamo": "profetare",
    "profetiate": "profetare",
    "profetica": "profetico",
    "profetiche": "profetico",
    "profetici": "profetico",
    "profetin": "profetare",
    "profetino": "profetare",
    "profetizza": "profetizzare",
    "profetizzai": "profetizzare",
    "profetizzammo": "profetizzare",
    "profetizzan": "profetizzare",
    "profetizzando": "profetizzare",
    "profetizzano": "profetizzare",
    "profetizzante": "profetizzare",
    "profetizzanti": "profetizzare",
    "profetizzar": "profetizzare",
    "profetizzaron": "profetizzare",
    "profetizzarono": "profetizzare",
    "profetizzasse": "profetizzare",
    "profetizzasser": "profetizzare",
    "profetizzassero": "profetizzare",
    "profetizzassi": "profetizzare",
    "profetizzassimo": "profetizzare",
    "profetizzaste": "profetizzare",
    "profetizzasti": "profetizzare",
    "profetizzata": "profetizzare",
    "profetizzate": "profetizzare",
    "profetizzati": "profetizzare",
    "profetizzato": "profetizzare",
    "profetizzava": "profetizzare",
    "profetizzavamo": "profetizzare",
    "profetizzavan": "profetizzare",
    "profetizzavano": "profetizzare",
    "profetizzavate": "profetizzare",
    "profetizzavi": "profetizzare",
    "profetizzavo": "profetizzare",
    "profetizzerai": "profetizzare",
    "profetizzeran": "profetizzare",
    "profetizzeranno": "profetizzare",
    "profetizzerebbe": "profetizzare",
    "profetizzerebber": "profetizzare",
    "profetizzerebbero": "profetizzare",
    "profetizzerei": "profetizzare",
    "profetizzeremmo": "profetizzare",
    "profetizzeremo": "profetizzare",
    "profetizzereste": "profetizzare",
    "profetizzeresti": "profetizzare",
    "profetizzerete": "profetizzare",
    "profetizzerà": "profetizzare",
    "profetizzerò": "profetizzare",
    "profetizzi": "profetizzare",
    "profetizziamo": "profetizzare",
    "profetizziate": "profetizzare",
    "profetizzin": "profetizzare",
    "profetizzino": "profetizzare",
    "profetizzo": "profetizzare",
    "profetizzò": "profetizzare",
    "profeto": "profetare",
    "profetò": "profetare",
    "profezie": "profezia",
    "profferendo": "profferire",
    "profferente": "profferire",
    "profferenti": "profferire",
    "profferiamo": "profferire",
    "profferiate": "profferire",
    "profferii": "profferire",
    "profferimmo": "profferire",
    "profferir": "profferire",
    "profferirai": "profferire",
    "profferiran": "profferire",
    "profferiranno": "profferire",
    "profferirebbe": "profferire",
    "profferirebber": "profferire",
    "profferirebbero": "profferire",
    "profferirei": "profferire",
    "profferiremmo": "profferire",
    "profferiremo": "profferire",
    "profferireste": "profferire",
    "profferiresti": "profferire",
    "profferirete": "profferire",
    "profferiron": "profferire",
    "profferirono": "profferire",
    "profferirà": "profferire",
    "profferirò": "profferire",
    "profferisca": "profferire",
    "profferiscan": "profferire",
    "profferiscano": "profferire",
    "profferisce": "profferire",
    "profferisci": "profferire",
    "profferisco": "profferire",
    "profferiscon": "profferire",
    "profferiscono": "profferire",
    "profferisse": "profferire",
    "profferisser": "profferire",
    "profferissero": "profferire",
    "profferissi": "profferire",
    "profferissimo": "profferire",
    "profferiste": "profferire",
    "profferisti": "profferire",
    "profferita": "profferire",
    "profferite": "profferire",
    "profferiti": "profferire",
    "profferito": "profferire",
    "profferiva": "profferire",
    "profferivamo": "profferire",
    "profferivan": "profferire",
    "profferivano": "profferire",
    "profferivate": "profferire",
    "profferivi": "profferire",
    "profferivo": "profferire",
    "profferte": "profferta",
    "profferì": "profferire",
    "proficua": "proficuo",
    "proficue": "proficuo",
    "proficui": "proficuo",
    "profila": "profilare",
    "profilai": "profilare",
    "profilammo": "profilare",
    "profilan": "profilare",
    "profilando": "profilare",
    "profilano": "profilare",
    "profilante": "profilare",
    "profilanti": "profilare",
    "profilar": "profilare",
    "profilaron": "profilare",
    "profilarono": "profilare",
    "profilasse": "profilare",
    "profilasser": "profilare",
    "profilassero": "profilare",
    "profilassi": "profilare",
    "profilassimo": "profilare",
    "profilaste": "profilare",
    "profilasti": "profilare",
    "profilata": "profilato",
    "profilate": "profilato",
    "profilati": "profilato",
    "profilato": "profilare",
    "profilattica": "profilattico",
    "profilattiche": "profilattico",
    "profilattici": "profilattico",
    "profilava": "profilare",
    "profilavamo": "profilare",
    "profilavan": "profilare",
    "profilavano": "profilare",
    "profilavate": "profilare",
    "profilavi": "profilare",
    "profilavo": "profilare",
    "profilerai": "profilare",
    "profileran": "profilare",
    "profileranno": "profilare",
    "profilerebbe": "profilare",
    "profilerebber": "profilare",
    "profilerebbero": "profilare",
    "profilerei": "profilare",
    "profileremmo": "profilare",
    "profileremo": "profilare",
    "profilereste": "profilare",
    "profileresti": "profilare",
    "profilerete": "profilare",
    "profilerà": "profilare",
    "profilerò": "profilare",
    "profili": "profilo",
    "profiliamo": "profilare",
    "profiliate": "profilare",
    "profilin": "profilare",
    "profilino": "profilare",
    "profilo": "profilare",
    "profilò": "profilare",
    "profitta": "profittare",
    "profittai": "profittare",
    "profittammo": "profittare",
    "profittan": "profittare",
    "profittando": "profittare",
    "profittano": "profittare",
    "profittante": "profittare",
    "profittanti": "profittare",
    "profittar": "profittare",
    "profittaron": "profittare",
    "profittarono": "profittare",
    "profittasse": "profittare",
    "profittasser": "profittare",
    "profittassero": "profittare",
    "profittassi": "profittare",
    "profittassimo": "profittare",
    "profittaste": "profittare",
    "profittasti": "profittare",
    "profittata": "profittare",
    "profittate": "profittare",
    "profittati": "profittare",
    "profittato": "profittare",
    "profittatori": "profittatore",
    "profittava": "profittare",
    "profittavamo": "profittare",
    "profittavan": "profittare",
    "profittavano": "profittare",
    "profittavate": "profittare",
    "profittavi": "profittare",
    "profittavo": "profittare",
    "profitterai": "profittare",
    "profitteran": "profittare",
    "profitteranno": "profittare",
    "profitterebbe": "profittare",
    "profitterebber": "profittare",
    "profitterebbero": "profittare",
    "profitterei": "profittare",
    "profitteremmo": "profittare",
    "profitteremo": "profittare",
    "profittereste": "profittare",
    "profitteresti": "profittare",
    "profitterete": "profittare",
    "profitterà": "profittare",
    "profitterò": "profittare",
    "profittevoli": "profittevole",
    "profitti": "profitto",
    "profittiamo": "profittare",
    "profittiate": "profittare",
    "profittin": "profittare",
    "profittino": "profittare",
    "profitto": "profittare",
    "profittò": "profittare",
    "profluvi": "profluvio",
    "profonda": "profondo",
    "profondai": "profondare",
    "profondammo": "profondare",
    "profondan": "profondere",
    "profondando": "profondare",
    "profondano": "profondere",
    "profondante": "profondare",
    "profondanti": "profondare",
    "profondar": "profondare",
    "profondaron": "profondare",
    "profondarono": "profondare",
    "profondasse": "profondare",
    "profondasser": "profondare",
    "profondassero": "profondare",
    "profondassi": "profondare",
    "profondassimo": "profondare",
    "profondaste": "profondare",
    "profondasti": "profondare",
    "profondata": "profondare",
    "profondate": "profondare",
    "profondati": "profondare",
    "profondato": "profondare",
    "profondava": "profondare",
    "profondavamo": "profondare",
    "profondavan": "profondare",
    "profondavano": "profondare",
    "profondavate": "profondare",
    "profondavi": "profondare",
    "profondavo": "profondare",
    "profonde": "profondo",
    "profondemmo": "profondere",
    "profondendo": "profondere",
    "profondente": "profondere",
    "profondenti": "profondere",
    "profonder": "profondere",
    "profonderai": "profondere",
    "profonderan": "profondere",
    "profonderanno": "profondere",
    "profonderebbe": "profondere",
    "profonderebber": "profondere",
    "profonderebbero": "profondere",
    "profonderei": "profondere",
    "profonderemmo": "profondere",
    "profonderemo": "profondere",
    "profondereste": "profondere",
    "profonderesti": "profondere",
    "profonderete": "profondere",
    "profonderà": "profondere",
    "profonderò": "profondere",
    "profondesse": "profondere",
    "profondesser": "profondere",
    "profondessero": "profondere",
    "profondessi": "profondere",
    "profondessimo": "profondere",
    "profondeste": "profondere",
    "profondesti": "profondere",
    "profondete": "profondere",
    "profondeva": "profondere",
    "profondevamo": "profondere",
    "profondevan": "profondere",
    "profondevano": "profondere",
    "profondevate": "profondere",
    "profondevi": "profondere",
    "profondevo": "profondere",
    "profondi": "profondo",
    "profondiamo": "profondere",
    "profondiate": "profondere",
    "profondin": "profondare",
    "profondino": "profondare",
    "profondo": "profondere",
    "profondon": "profondere",
    "profondono": "profondere",
    "profondò": "profondare",
    "profuga": "profugo",
    "profughe": "profugo",
    "profughi": "profugo",
    "profuma": "profumare",
    "profumai": "profumare",
    "profumammo": "profumare",
    "profuman": "profumare",
    "profumando": "profumare",
    "profumano": "profumare",
    "profumante": "profumare",
    "profumanti": "profumare",
    "profumar": "profumare",
    "profumaron": "profumare",
    "profumarono": "profumare",
    "profumasse": "profumare",
    "profumasser": "profumare",
    "profumassero": "profumare",
    "profumassi": "profumare",
    "profumassimo": "profumare",
    "profumaste": "profumare",
    "profumasti": "profumare",
    "profumata": "profumato",
    "profumate": "profumato",
    "profumati": "profumato",
    "profumato": "profumare",
    "profumava": "profumare",
    "profumavamo": "profumare",
    "profumavan": "profumare",
    "profumavano": "profumare",
    "profumavate": "profumare",
    "profumavi": "profumare",
    "profumavo": "profumare",
    "profumerai": "profumare",
    "profumeran": "profumare",
    "profumeranno": "profumare",
    "profumerebbe": "profumare",
    "profumerebber": "profumare",
    "profumerebbero": "profumare",
    "profumerei": "profumare",
    "profumeremmo": "profumare",
    "profumeremo": "profumare",
    "profumereste": "profumare",
    "profumeresti": "profumare",
    "profumerete": "profumare",
    "profumerie": "profumeria",
    "profumerà": "profumare",
    "profumerò": "profumare",
    "profumi": "profumo",
    "profumiamo": "profumare",
    "profumiate": "profumare",
    "profumieri": "profumiere",
    "profumin": "profumare",
    "profumino": "profumare",
    "profumo": "profumare",
    "profumò": "profumare",
    "profusa": "profuso",
    "profuse": "profuso",
    "profuser": "profondere",
    "profusero": "profondere",
    "profusi": "profuso",
    "profusioni": "profusione",
    "profuso": "profondere",
    "progenitori": "progenitore",
    "progenitrici": "progenitrice",
    "progestinici": "progestinico",
    "progetta": "progettare",
    "progettai": "progettare",
    "progettammo": "progettare",
    "progettan": "progettare",
    "progettando": "progettare",
    "progettano": "progettare",
    "progettante": "progettare",
    "progettanti": "progettare",
    "progettar": "progettare",
    "progettaron": "progettare",
    "progettarono": "progettare",
    "progettasse": "progettare",
    "progettasser": "progettare",
    "progettassero": "progettare",
    "progettassi": "progettare",
    "progettassimo": "progettare",
    "progettaste": "progettare",
    "progettasti": "progettare",
    "progettata": "progettare",
    "progettate": "progettare",
    "progettati": "progettare",
    "progettato": "progettare",
    "progettatori": "progettatore",
    "progettava": "progettare",
    "progettavamo": "progettare",
    "progettavan": "progettare",
    "progettavano": "progettare",
    "progettavate": "progettare",
    "progettavi": "progettare",
    "progettavo": "progettare",
    "progettazioni": "progettazione",
    "progetterai": "progettare",
    "progetteran": "progettare",
    "progetteranno": "progettare",
    "progetterebbe": "progettare",
    "progetterebber": "progettare",
    "progetterebbero": "progettare",
    "progetterei": "progettare",
    "progetteremmo": "progettare",
    "progetteremo": "progettare",
    "progettereste": "progettare",
    "progetteresti": "progettare",
    "progetterete": "progettare",
    "progetterà": "progettare",
    "progetterò": "progettare",
    "progetti": "progetto",
    "progettiamo": "progettare",
    "progettiate": "progettare",
    "progettin": "progettare",
    "progettino": "progettare",
    "progettisti": "progettista",
    "progetto": "progettare",
    "progettuali": "progettuale",
    "progettò": "progettare",
    "programi": "programa",
    "programma": "programmare",
    "programmai": "programmare",
    "programmammo": "programmare",
    "programman": "programmare",
    "programmando": "programmare",
    "programmano": "programmare",
    "programmante": "programmare",
    "programmanti": "programmare",
    "programmar": "programmare",
    "programmaron": "programmare",
    "programmarono": "programmare",
    "programmasse": "programmare",
    "programmasser": "programmare",
    "programmassero": "programmare",
    "programmassi": "programmare",
    "programmassimo": "programmare",
    "programmaste": "programmare",
    "programmasti": "programmare",
    "programmata": "programmato",
    "programmate": "programmato",
    "programmati": "programmato",
    "programmatica": "programmatico",
    "programmatiche": "programmatico",
    "programmatici": "programmatico",
    "programmato": "programmare",
    "programmatori": "programmatore",
    "programmava": "programmare",
    "programmavamo": "programmare",
    "programmavan": "programmare",
    "programmavano": "programmare",
    "programmavate": "programmare",
    "programmavi": "programmare",
    "programmavo": "programmare",
    "programmazioni": "programmazione",
    "programmerai": "programmare",
    "programmeran": "programmare",
    "programmeranno": "programmare",
    "programmerebbe": "programmare",
    "programmerebber": "programmare",
    "programmerebbero": "programmare",
    "programmerei": "programmare",
    "programmeremmo": "programmare",
    "programmeremo": "programmare",
    "programmereste": "programmare",
    "programmeresti": "programmare",
    "programmerete": "programmare",
    "programmerà": "programmare",
    "programmerò": "programmare",
    "programmi": "programmare",
    "programmiamo": "programmare",
    "programmiate": "programmare",
    "programmin": "programmare",
    "programmino": "programmare",
    "programmisti": "programmista",
    "programmmi": "programmma",
    "programmo": "programmare",
    "programmò": "programmare",
    "progredendo": "progredire",
    "progredente": "progredire",
    "progredenti": "progredire",
    "progrediamo": "progredire",
    "progrediate": "progredire",
    "progredii": "progredire",
    "progredimmo": "progredire",
    "progredir": "progredire",
    "progredirai": "progredire",
    "progrediran": "progredire",
    "progrediranno": "progredire",
    "progredirebbe": "progredire",
    "progredirebber": "progredire",
    "progredirebbero": "progredire",
    "progredirei": "progredire",
    "progrediremmo": "progredire",
    "progrediremo": "progredire",
    "progredireste": "progredire",
    "progrediresti": "progredire",
    "progredirete": "progredire",
    "progrediron": "progredire",
    "progredirono": "progredire",
    "progredirà": "progredire",
    "progredirò": "progredire",
    "progredisca": "progredire",
    "progrediscan": "progredire",
    "progrediscano": "progredire",
    "progredisce": "progredire",
    "progredisci": "progredire",
    "progredisco": "progredire",
    "progrediscon": "progredire",
    "progrediscono": "progredire",
    "progredisse": "progredire",
    "progredisser": "progredire",
    "progredissero": "progredire",
    "progredissi": "progredire",
    "progredissimo": "progredire",
    "progrediste": "progredire",
    "progredisti": "progredire",
    "progredita": "progredito",
    "progredite": "progredito",
    "progrediti": "progredito",
    "progredito": "progredire",
    "progrediva": "progredire",
    "progredivamo": "progredire",
    "progredivan": "progredire",
    "progredivano": "progredire",
    "progredivate": "progredire",
    "progredivi": "progredire",
    "progredivo": "progredire",
    "progredì": "progredire",
    "progressi": "progresso",
    "progressioni": "progressione",
    "progressismi": "progressismo",
    "progressiste": "progressista",
    "progressisti": "progressista",
    "progressiva": "progressivo",
    "progressive": "progressivo",
    "progressivi": "progressivo",
    "proibendo": "proibire",
    "proibente": "proibire",
    "proibenti": "proibire",
    "proibiamo": "proibire",
    "proibiate": "proibire",
    "proibii": "proibire",
    "proibimmo": "proibire",
    "proibir": "proibire",
    "proibirai": "proibire",
    "proibiran": "proibire",
    "proibiranno": "proibire",
    "proibirebbe": "proibire",
    "proibirebber": "proibire",
    "proibirebbero": "proibire",
    "proibirei": "proibire",
    "proibiremmo": "proibire",
    "proibiremo": "proibire",
    "proibireste": "proibire",
    "proibiresti": "proibire",
    "proibirete": "proibire",
    "proibiron": "proibire",
    "proibirono": "proibire",
    "proibirà": "proibire",
    "proibirò": "proibire",
    "proibisca": "proibire",
    "proibiscan": "proibire",
    "proibiscano": "proibire",
    "proibisce": "proibire",
    "proibisci": "proibire",
    "proibisco": "proibire",
    "proibiscon": "proibire",
    "proibiscono": "proibire",
    "proibisse": "proibire",
    "proibisser": "proibire",
    "proibissero": "proibire",
    "proibissi": "proibire",
    "proibissimo": "proibire",
    "proibiste": "proibire",
    "proibisti": "proibire",
    "proibita": "proibito",
    "proibite": "proibito",
    "proibiti": "proibito",
    "proibitiva": "proibitivo",
    "proibitive": "proibitivo",
    "proibitivi": "proibitivo",
    "proibito": "proibire",
    "proibiva": "proibire",
    "proibivamo": "proibire",
    "proibivan": "proibire",
    "proibivano": "proibire",
    "proibivate": "proibire",
    "proibivi": "proibire",
    "proibivo": "proibire",
    "proibizioni": "proibizione",
    "proibizionismi": "proibizionismo",
    "proibizioniste": "proibizionista",
    "proibizionisti": "proibizionista",
    "proibì": "proibire",
    "proietta": "proiettare",
    "proiettai": "proiettare",
    "proiettammo": "proiettare",
    "proiettan": "proiettare",
    "proiettando": "proiettare",
    "proiettano": "proiettare",
    "proiettante": "proiettare",
    "proiettanti": "proiettare",
    "proiettar": "proiettare",
    "proiettaron": "proiettare",
    "proiettarono": "proiettare",
    "proiettasse": "proiettare",
    "proiettasser": "proiettare",
    "proiettassero": "proiettare",
    "proiettassi": "proiettare",
    "proiettassimo": "proiettare",
    "proiettaste": "proiettare",
    "proiettasti": "proiettare",
    "proiettata": "proiettare",
    "proiettate": "proiettare",
    "proiettati": "proiettare",
    "proiettato": "proiettare",
    "proiettava": "proiettare",
    "proiettavamo": "proiettare",
    "proiettavan": "proiettare",
    "proiettavano": "proiettare",
    "proiettavate": "proiettare",
    "proiettavi": "proiettare",
    "proiettavo": "proiettare",
    "proietterai": "proiettare",
    "proietteran": "proiettare",
    "proietteranno": "proiettare",
    "proietterebbe": "proiettare",
    "proietterebber": "proiettare",
    "proietterebbero": "proiettare",
    "proietterei": "proiettare",
    "proietteremmo": "proiettare",
    "proietteremo": "proiettare",
    "proiettereste": "proiettare",
    "proietteresti": "proiettare",
    "proietterete": "proiettare",
    "proietterà": "proiettare",
    "proietterò": "proiettare",
    "proietti": "proiettare",
    "proiettiamo": "proiettare",
    "proiettiate": "proiettare",
    "proiettili": "proiettile",
    "proiettin": "proiettare",
    "proiettino": "proiettare",
    "proietto": "proiettare",
    "proiettori": "proiettore",
    "proiettò": "proiettare",
    "proiezioni": "proiezione",
    "proiezionisti": "proiezionista",
    "proletari": "proletario",
    "proletaria": "proletario",
    "proletariati": "proletariato",
    "proletarie": "proletario",
    "proletarizza": "proletarizzare",
    "proletarizzai": "proletarizzare",
    "proletarizzammo": "proletarizzare",
    "proletarizzan": "proletarizzare",
    "proletarizzando": "proletarizzare",
    "proletarizzano": "proletarizzare",
    "proletarizzante": "proletarizzare",
    "proletarizzanti": "proletarizzare",
    "proletarizzar": "proletarizzare",
    "proletarizzaron": "proletarizzare",
    "proletarizzarono": "proletarizzare",
    "proletarizzasse": "proletarizzare",
    "proletarizzasser": "proletarizzare",
    "proletarizzassero": "proletarizzare",
    "proletarizzassi": "proletarizzare",
    "proletarizzassimo": "proletarizzare",
    "proletarizzaste": "proletarizzare",
    "proletarizzasti": "proletarizzare",
    "proletarizzata": "proletarizzare",
    "proletarizzate": "proletarizzare",
    "proletarizzati": "proletarizzare",
    "proletarizzato": "proletarizzare",
    "proletarizzava": "proletarizzare",
    "proletarizzavamo": "proletarizzare",
    "proletarizzavan": "proletarizzare",
    "proletarizzavano": "proletarizzare",
    "proletarizzavate": "proletarizzare",
    "proletarizzavi": "proletarizzare",
    "proletarizzavo": "proletarizzare",
    "proletarizzerai": "proletarizzare",
    "proletarizzeran": "proletarizzare",
    "proletarizzeranno": "proletarizzare",
    "proletarizzerebbe": "proletarizzare",
    "proletarizzerebber": "proletarizzare",
    "proletarizzerebbero": "proletarizzare",
    "proletarizzerei": "proletarizzare",
    "proletarizzeremmo": "proletarizzare",
    "proletarizzeremo": "proletarizzare",
    "proletarizzereste": "proletarizzare",
    "proletarizzeresti": "proletarizzare",
    "proletarizzerete": "proletarizzare",
    "proletarizzerà": "proletarizzare",
    "proletarizzerò": "proletarizzare",
    "proletarizzi": "proletarizzare",
    "proletarizziamo": "proletarizzare",
    "proletarizziate": "proletarizzare",
    "proletarizzin": "proletarizzare",
    "proletarizzino": "proletarizzare",
    "proletarizzo": "proletarizzare",
    "proletarizzò": "proletarizzare",
    "proli": "prole",
    "prolifera": "proliferare",
    "proliferai": "proliferare",
    "proliferammo": "proliferare",
    "proliferan": "proliferare",
    "proliferando": "proliferare",
    "proliferano": "proliferare",
    "proliferante": "proliferare",
    "proliferanti": "proliferare",
    "proliferar": "proliferare",
    "proliferaron": "proliferare",
    "proliferarono": "proliferare",
    "proliferasse": "proliferare",
    "proliferasser": "proliferare",
    "proliferassero": "proliferare",
    "proliferassi": "proliferare",
    "proliferassimo": "proliferare",
    "proliferaste": "proliferare",
    "proliferasti": "proliferare",
    "proliferata": "proliferare",
    "proliferate": "proliferare",
    "proliferati": "proliferare",
    "proliferato": "proliferare",
    "proliferava": "proliferare",
    "proliferavamo": "proliferare",
    "proliferavan": "proliferare",
    "proliferavano": "proliferare",
    "proliferavate": "proliferare",
    "proliferavi": "proliferare",
    "proliferavo": "proliferare",
    "proliferazioni": "proliferazione",
    "prolifererai": "proliferare",
    "prolifereran": "proliferare",
    "prolifereranno": "proliferare",
    "prolifererebbe": "proliferare",
    "prolifererebber": "proliferare",
    "prolifererebbero": "proliferare",
    "prolifererei": "proliferare",
    "prolifereremmo": "proliferare",
    "prolifereremo": "proliferare",
    "proliferereste": "proliferare",
    "prolifereresti": "proliferare",
    "prolifererete": "proliferare",
    "prolifererà": "proliferare",
    "prolifererò": "proliferare",
    "proliferi": "proliferare",
    "proliferiamo": "proliferare",
    "proliferiate": "proliferare",
    "proliferin": "proliferare",
    "proliferino": "proliferare",
    "prolifero": "proliferare",
    "proliferò": "proliferare",
    "prolifica": "prolifico",
    "prolificai": "prolificare",
    "prolificammo": "prolificare",
    "prolifican": "prolificare",
    "prolificando": "prolificare",
    "prolificano": "prolificare",
    "prolificante": "prolificare",
    "prolificanti": "prolificare",
    "prolificar": "prolificare",
    "prolificaron": "prolificare",
    "prolificarono": "prolificare",
    "prolificasse": "prolificare",
    "prolificasser": "prolificare",
    "prolificassero": "prolificare",
    "prolificassi": "prolificare",
    "prolificassimo": "prolificare",
    "prolificaste": "prolificare",
    "prolificasti": "prolificare",
    "prolificata": "prolificare",
    "prolificate": "prolificare",
    "prolificati": "prolificare",
    "prolificato": "prolificare",
    "prolificava": "prolificare",
    "prolificavamo": "prolificare",
    "prolificavan": "prolificare",
    "prolificavano": "prolificare",
    "prolificavate": "prolificare",
    "prolificavi": "prolificare",
    "prolificavo": "prolificare",
    "prolifiche": "prolifico",
    "prolificherai": "prolificare",
    "prolificheran": "prolificare",
    "prolificheranno": "prolificare",
    "prolificherebbe": "prolificare",
    "prolificherebber": "prolificare",
    "prolificherebbero": "prolificare",
    "prolificherei": "prolificare",
    "prolificheremmo": "prolificare",
    "prolificheremo": "prolificare",
    "prolifichereste": "prolificare",
    "prolificheresti": "prolificare",
    "prolificherete": "prolificare",
    "prolificherà": "prolificare",
    "prolificherò": "prolificare",
    "prolifichi": "prolificare",
    "prolifichiamo": "prolificare",
    "prolifichiate": "prolificare",
    "prolifichin": "prolificare",
    "prolifichino": "prolificare",
    "prolifici": "prolifico",
    "prolifico": "prolificare",
    "prolificò": "prolificare",
    "prolissa": "prolisso",
    "prolisse": "prolisso",
    "prolissi": "prolisso",
    "prologhi": "prologo",
    "prolunga": "prolungare",
    "prolungai": "prolungare",
    "prolungamenti": "prolungamento",
    "prolungammo": "prolungare",
    "prolungan": "prolungare",
    "prolungando": "prolungare",
    "prolungano": "prolungare",
    "prolungante": "prolungare",
    "prolunganti": "prolungare",
    "prolungar": "prolungare",
    "prolungaron": "prolungare",
    "prolungarono": "prolungare",
    "prolungasse": "prolungare",
    "prolungasser": "prolungare",
    "prolungassero": "prolungare",
    "prolungassi": "prolungare",
    "prolungassimo": "prolungare",
    "prolungaste": "prolungare",
    "prolungasti": "prolungare",
    "prolungata": "prolungato",
    "prolungate": "prolungato",
    "prolungati": "prolungato",
    "prolungato": "prolungare",
    "prolungava": "prolungare",
    "prolungavamo": "prolungare",
    "prolungavan": "prolungare",
    "prolungavano": "prolungare",
    "prolungavate": "prolungare",
    "prolungavi": "prolungare",
    "prolungavo": "prolungare",
    "prolungherai": "prolungare",
    "prolungheran": "prolungare",
    "prolungheranno": "prolungare",
    "prolungherebbe": "prolungare",
    "prolungherebber": "prolungare",
    "prolungherebbero": "prolungare",
    "prolungherei": "prolungare",
    "prolungheremmo": "prolungare",
    "prolungheremo": "prolungare",
    "prolunghereste": "prolungare",
    "prolungheresti": "prolungare",
    "prolungherete": "prolungare",
    "prolungherà": "prolungare",
    "prolungherò": "prolungare",
    "prolunghi": "prolungare",
    "prolunghiamo": "prolungare",
    "prolunghiate": "prolungare",
    "prolunghin": "prolungare",
    "prolunghino": "prolungare",
    "prolungo": "prolungare",
    "prolungò": "prolungare",
    "prolusioni": "prolusione",
    "promessa": "promettere",
    "promesse": "promettere",
    "promessi": "promettere",
    "promesso": "promettere",
    "prometta": "promettere",
    "promettan": "promettere",
    "promettano": "promettere",
    "promette": "promettere",
    "promettemmo": "promettere",
    "promettendo": "promettere",
    "promettente": "promettere",
    "promettenti": "promettere",
    "prometter": "promettere",
    "prometterai": "promettere",
    "prometteran": "promettere",
    "prometteranno": "promettere",
    "prometterebbe": "promettere",
    "prometterebber": "promettere",
    "prometterebbero": "promettere",
    "prometterei": "promettere",
    "prometteremmo": "promettere",
    "prometteremo": "promettere",
    "promettereste": "promettere",
    "prometteresti": "promettere",
    "prometterete": "promettere",
    "prometterà": "promettere",
    "prometterò": "promettere",
    "promettesse": "promettere",
    "promettesser": "promettere",
    "promettessero": "promettere",
    "promettessi": "promettere",
    "promettessimo": "promettere",
    "prometteste": "promettere",
    "promettesti": "promettere",
    "promettete": "promettere",
    "prometteva": "promettere",
    "promettevamo": "promettere",
    "promettevan": "promettere",
    "promettevano": "promettere",
    "promettevate": "promettere",
    "promettevi": "promettere",
    "promettevo": "promettere",
    "prometti": "promettere",
    "promettiamo": "promettere",
    "promettiate": "promettere",
    "prometto": "promettere",
    "prometton": "promettere",
    "promettono": "promettere",
    "promiscua": "promiscuo",
    "promiscue": "promiscuo",
    "promiscui": "promiscuo",
    "promise": "promettere",
    "promiser": "promettere",
    "promisero": "promettere",
    "promisi": "promettere",
    "promontori": "promontorio",
    "promossa": "promuovere",
    "promosse": "promuovere",
    "promosser": "promuovere",
    "promossero": "promuovere",
    "promossi": "promuovere",
    "promosso": "promuovere",
    "promotori": "promotore",
    "promotrice": "promotore",
    "promotrici": "promotrice",
    "promozionali": "promozionale",
    "promozioni": "promozione",
    "promulga": "promulgare",
    "promulgai": "promulgare",
    "promulgammo": "promulgare",
    "promulgan": "promulgare",
    "promulgando": "promulgare",
    "promulgano": "promulgare",
    "promulgante": "promulgare",
    "promulganti": "promulgare",
    "promulgar": "promulgare",
    "promulgaron": "promulgare",
    "promulgarono": "promulgare",
    "promulgasse": "promulgare",
    "promulgasser": "promulgare",
    "promulgassero": "promulgare",
    "promulgassi": "promulgare",
    "promulgassimo": "promulgare",
    "promulgaste": "promulgare",
    "promulgasti": "promulgare",
    "promulgata": "promulgare",
    "promulgate": "promulgare",
    "promulgati": "promulgare",
    "promulgato": "promulgare",
    "promulgava": "promulgare",
    "promulgavamo": "promulgare",
    "promulgavan": "promulgare",
    "promulgavano": "promulgare",
    "promulgavate": "promulgare",
    "promulgavi": "promulgare",
    "promulgavo": "promulgare",
    "promulgazioni": "promulgazione",
    "promulgherai": "promulgare",
    "promulgheran": "promulgare",
    "promulgheranno": "promulgare",
    "promulgherebbe": "promulgare",
    "promulgherebber": "promulgare",
    "promulgherebbero": "promulgare",
    "promulgherei": "promulgare",
    "promulgheremmo": "promulgare",
    "promulgheremo": "promulgare",
    "promulghereste": "promulgare",
    "promulgheresti": "promulgare",
    "promulgherete": "promulgare",
    "promulgherà": "promulgare",
    "promulgherò": "promulgare",
    "promulghi": "promulgare",
    "promulghiamo": "promulgare",
    "promulghiate": "promulgare",
    "promulghin": "promulgare",
    "promulghino": "promulgare",
    "promulgo": "promulgare",
    "promulgò": "promulgare",
    "promuova": "promuovere",
    "promuovan": "promuovere",
    "promuovano": "promuovere",
    "promuove": "promuovere",
    "promuovemmo": "promuovere",
    "promuovendo": "promuovere",
    "promuovente": "promuovere",
    "promuoventi": "promuovere",
    "promuover": "promuovere",
    "promuoverai": "promuovere",
    "promuoveran": "promuovere",
    "promuoveranno": "promuovere",
    "promuoverebbe": "promuovere",
    "promuoverebber": "promuovere",
    "promuoverebbero": "promuovere",
    "promuoverei": "promuovere",
    "promuoveremmo": "promuovere",
    "promuoveremo": "promuovere",
    "promuovereste": "promuovere",
    "promuoveresti": "promuovere",
    "promuoverete": "promuovere",
    "promuoverà": "promuovere",
    "promuoverò": "promuovere",
    "promuovesse": "promuovere",
    "promuovesser": "promuovere",
    "promuovessero": "promuovere",
    "promuovessi": "promuovere",
    "promuovessimo": "promuovere",
    "promuoveste": "promuovere",
    "promuovesti": "promuovere",
    "promuovete": "promuovere",
    "promuoveva": "promuovere",
    "promuovevamo": "promuovere",
    "promuovevan": "promuovere",
    "promuovevano": "promuovere",
    "promuovevate": "promuovere",
    "promuovevi": "promuovere",
    "promuovevo": "promuovere",
    "promuovi": "promuovere",
    "promuoviamo": "promuovere",
    "promuoviate": "promuovere",
    "promuovo": "promuovere",
    "promuovon": "promuovere",
    "promuovono": "promuovere",
    "prona": "prono",
    "prone": "prono",
    "proni": "prono",
    "pronipoti": "pronipote",
    "pronomi": "pronome",
    "pronominali": "pronominale",
    "pronostica": "pronosticare",
    "pronosticai": "pronosticare",
    "pronosticammo": "pronosticare",
    "pronostican": "pronosticare",
    "pronosticando": "pronosticare",
    "pronosticano": "pronosticare",
    "pronosticante": "pronosticare",
    "pronosticanti": "pronosticare",
    "pronosticar": "pronosticare",
    "pronosticaron": "pronosticare",
    "pronosticarono": "pronosticare",
    "pronosticasse": "pronosticare",
    "pronosticasser": "pronosticare",
    "pronosticassero": "pronosticare",
    "pronosticassi": "pronosticare",
    "pronosticassimo": "pronosticare",
    "pronosticaste": "pronosticare",
    "pronosticasti": "pronosticare",
    "pronosticata": "pronosticare",
    "pronosticate": "pronosticare",
    "pronosticati": "pronosticare",
    "pronosticato": "pronosticare",
    "pronosticava": "pronosticare",
    "pronosticavamo": "pronosticare",
    "pronosticavan": "pronosticare",
    "pronosticavano": "pronosticare",
    "pronosticavate": "pronosticare",
    "pronosticavi": "pronosticare",
    "pronosticavo": "pronosticare",
    "pronosticherai": "pronosticare",
    "pronosticheran": "pronosticare",
    "pronosticheranno": "pronosticare",
    "pronosticherebbe": "pronosticare",
    "pronosticherebber": "pronosticare",
    "pronosticherebbero": "pronosticare",
    "pronosticherei": "pronosticare",
    "pronosticheremmo": "pronosticare",
    "pronosticheremo": "pronosticare",
    "pronostichereste": "pronosticare",
    "pronosticheresti": "pronosticare",
    "pronosticherete": "pronosticare",
    "pronosticherà": "pronosticare",
    "pronosticherò": "pronosticare",
    "pronostichi": "pronosticare",
    "pronostichiamo": "pronosticare",
    "pronostichiate": "pronosticare",
    "pronostichin": "pronosticare",
    "pronostichino": "pronosticare",
    "pronostici": "pronostico",
    "pronostico": "pronosticare",
    "pronosticò": "pronosticare",
    "pronta": "pronto",
    "pronte": "pronto",
    "prontezze": "prontezza",
    "pronti": "pronto",
    "prontuari": "prontuario",
    "pronunce": "pronuncia",
    "pronuncerai": "pronunciare",
    "pronunceran": "pronunciare",
    "pronunceranno": "pronunciare",
    "pronuncerebbe": "pronunciare",
    "pronuncerebber": "pronunciare",
    "pronuncerebbero": "pronunciare",
    "pronuncerei": "pronunciare",
    "pronunceremmo": "pronunciare",
    "pronunceremo": "pronunciare",
    "pronuncereste": "pronunciare",
    "pronunceresti": "pronunciare",
    "pronuncerete": "pronunciare",
    "pronuncerà": "pronunciare",
    "pronuncerò": "pronunciare",
    "pronunci": "pronunciare",
    "pronuncia": "pronunciare",
    "pronunciai": "pronunciare",
    "pronunciamenti": "pronunciamento",
    "pronunciammo": "pronunciare",
    "pronunciamo": "pronunciare",
    "pronuncian": "pronunciare",
    "pronunciando": "pronunciare",
    "pronunciano": "pronunciare",
    "pronunciante": "pronunciare",
    "pronuncianti": "pronunciare",
    "pronunciar": "pronunciare",
    "pronunciaron": "pronunciare",
    "pronunciarono": "pronunciare",
    "pronunciasse": "pronunciare",
    "pronunciasser": "pronunciare",
    "pronunciassero": "pronunciare",
    "pronunciassi": "pronunciare",
    "pronunciassimo": "pronunciare",
    "pronunciaste": "pronunciare",
    "pronunciasti": "pronunciare",
    "pronunciata": "pronunciato",
    "pronunciate": "pronunciato",
    "pronunciati": "pronunciato",
    "pronunciato": "pronunciare",
    "pronunciava": "pronunciare",
    "pronunciavamo": "pronunciare",
    "pronunciavan": "pronunciare",
    "pronunciavano": "pronunciare",
    "pronunciavate": "pronunciare",
    "pronunciavi": "pronunciare",
    "pronunciavo": "pronunciare",
    "pronuncin": "pronunciare",
    "pronuncino": "pronunciare",
    "pronuncio": "pronunciare",
    "pronunciò": "pronunciare",
    "pronunzi": "pronunziare",
    "pronunzia": "pronunziare",
    "pronunziai": "pronunziare",
    "pronunziammo": "pronunziare",
    "pronunziamo": "pronunziare",
    "pronunzian": "pronunziare",
    "pronunziando": "pronunziare",
    "pronunziano": "pronunziare",
    "pronunziante": "pronunziare",
    "pronunzianti": "pronunziare",
    "pronunziar": "pronunziare",
    "pronunziaron": "pronunziare",
    "pronunziarono": "pronunziare",
    "pronunziasse": "pronunziare",
    "pronunziasser": "pronunziare",
    "pronunziassero": "pronunziare",
    "pronunziassi": "pronunziare",
    "pronunziassimo": "pronunziare",
    "pronunziaste": "pronunziare",
    "pronunziasti": "pronunziare",
    "pronunziata": "pronunziare",
    "pronunziate": "pronunziare",
    "pronunziati": "pronunziare",
    "pronunziato": "pronunziare",
    "pronunziava": "pronunziare",
    "pronunziavamo": "pronunziare",
    "pronunziavan": "pronunziare",
    "pronunziavano": "pronunziare",
    "pronunziavate": "pronunziare",
    "pronunziavi": "pronunziare",
    "pronunziavo": "pronunziare",
    "pronunzie": "pronunzia",
    "pronunzierai": "pronunziare",
    "pronunzieran": "pronunziare",
    "pronunzieranno": "pronunziare",
    "pronunzierebbe": "pronunziare",
    "pronunzierebber": "pronunziare",
    "pronunzierebbero": "pronunziare",
    "pronunzierei": "pronunziare",
    "pronunzieremmo": "pronunziare",
    "pronunzieremo": "pronunziare",
    "pronunziereste": "pronunziare",
    "pronunzieresti": "pronunziare",
    "pronunzierete": "pronunziare",
    "pronunzierà": "pronunziare",
    "pronunzierò": "pronunziare",
    "pronunzin": "pronunziare",
    "pronunzino": "pronunziare",
    "pronunzio": "pronunziare",
    "pronunziò": "pronunziare",
    "propaga": "propagare",
    "propagai": "propagare",
    "propagammo": "propagare",
    "propagan": "propagare",
    "propaganda": "propagandare",
    "propagandai": "propagandare",
    "propagandammo": "propagandare",
    "propagandan": "propagandare",
    "propagandando": "propagandare",
    "propagandano": "propagandare",
    "propagandante": "propagandare",
    "propagandanti": "propagandare",
    "propagandar": "propagandare",
    "propagandaron": "propagandare",
    "propagandarono": "propagandare",
    "propagandasse": "propagandare",
    "propagandasser": "propagandare",
    "propagandassero": "propagandare",
    "propagandassi": "propagandare",
    "propagandassimo": "propagandare",
    "propagandaste": "propagandare",
    "propagandasti": "propagandare",
    "propagandata": "propagandare",
    "propagandate": "propagandare",
    "propagandati": "propagandare",
    "propagandato": "propagandare",
    "propagandava": "propagandare",
    "propagandavamo": "propagandare",
    "propagandavan": "propagandare",
    "propagandavano": "propagandare",
    "propagandavate": "propagandare",
    "propagandavi": "propagandare",
    "propagandavo": "propagandare",
    "propagande": "propaganda",
    "propaganderai": "propagandare",
    "propaganderan": "propagandare",
    "propaganderanno": "propagandare",
    "propaganderebbe": "propagandare",
    "propaganderebber": "propagandare",
    "propaganderebbero": "propagandare",
    "propaganderei": "propagandare",
    "propaganderemmo": "propagandare",
    "propaganderemo": "propagandare",
    "propagandereste": "propagandare",
    "propaganderesti": "propagandare",
    "propaganderete": "propagandare",
    "propaganderà": "propagandare",
    "propaganderò": "propagandare",
    "propagandi": "propagandare",
    "propagandiamo": "propagandare",
    "propagandiate": "propagandare",
    "propagandin": "propagandare",
    "propagandino": "propagandare",
    "propagandisti": "propagandista",
    "propagandistica": "propagandistico",
    "propagandistiche": "propagandistico",
    "propagandistici": "propagandistico",
    "propagando": "propagare",
    "propagandò": "propagandare",
    "propagano": "propagare",
    "propagante": "propagare",
    "propaganti": "propagare",
    "propagar": "propagare",
    "propagaron": "propagare",
    "propagarono": "propagare",
    "propagasse": "propagare",
    "propagasser": "propagare",
    "propagassero": "propagare",
    "propagassi": "propagare",
    "propagassimo": "propagare",
    "propagaste": "propagare",
    "propagasti": "propagare",
    "propagata": "propagare",
    "propagate": "propagare",
    "propagati": "propagare",
    "propagato": "propagare",
    "propagatori": "propagatore",
    "propagava": "propagare",
    "propagavamo": "propagare",
    "propagavan": "propagare",
    "propagavano": "propagare",
    "propagavate": "propagare",
    "propagavi": "propagare",
    "propagavo": "propagare",
    "propagazioni": "propagazione",
    "propaggina": "propagginare",
    "propagginai": "propagginare",
    "propagginammo": "propagginare",
    "propagginan": "propagginare",
    "propagginando": "propagginare",
    "propagginano": "propagginare",
    "propagginante": "propagginare",
    "propagginanti": "propagginare",
    "propagginar": "propagginare",
    "propagginaron": "propagginare",
    "propagginarono": "propagginare",
    "propagginasse": "propagginare",
    "propagginasser": "propagginare",
    "propagginassero": "propagginare",
    "propagginassi": "propagginare",
    "propagginassimo": "propagginare",
    "propagginaste": "propagginare",
    "propagginasti": "propagginare",
    "propagginata": "propagginare",
    "propagginate": "propagginare",
    "propagginati": "propagginare",
    "propagginato": "propagginare",
    "propagginava": "propagginare",
    "propagginavamo": "propagginare",
    "propagginavan": "propagginare",
    "propagginavano": "propagginare",
    "propagginavate": "propagginare",
    "propagginavi": "propagginare",
    "propagginavo": "propagginare",
    "propagginerai": "propagginare",
    "propaggineran": "propagginare",
    "propaggineranno": "propagginare",
    "propagginerebbe": "propagginare",
    "propagginerebber": "propagginare",
    "propagginerebbero": "propagginare",
    "propagginerei": "propagginare",
    "propaggineremmo": "propagginare",
    "propaggineremo": "propagginare",
    "propagginereste": "propagginare",
    "propaggineresti": "propagginare",
    "propagginerete": "propagginare",
    "propagginerà": "propagginare",
    "propagginerò": "propagginare",
    "propaggini": "propaggine",
    "propagginiamo": "propagginare",
    "propagginiate": "propagginare",
    "propagginin": "propagginare",
    "propagginino": "propagginare",
    "propaggino": "propagginare",
    "propagginò": "propagginare",
    "propagherai": "propagare",
    "propagheran": "propagare",
    "propagheranno": "propagare",
    "propagherebbe": "propagare",
    "propagherebber": "propagare",
    "propagherebbero": "propagare",
    "propagherei": "propagare",
    "propagheremmo": "propagare",
    "propagheremo": "propagare",
    "propaghereste": "propagare",
    "propagheresti": "propagare",
    "propagherete": "propagare",
    "propagherà": "propagare",
    "propagherò": "propagare",
    "propaghi": "propagare",
    "propaghiamo": "propagare",
    "propaghiate": "propagare",
    "propaghin": "propagare",
    "propaghino": "propagare",
    "propago": "propagare",
    "propagò": "propagare",
    "propala": "propalare",
    "propalai": "propalare",
    "propalammo": "propalare",
    "propalan": "propalare",
    "propalando": "propalare",
    "propalano": "propalare",
    "propalante": "propalare",
    "propalanti": "propalare",
    "propalar": "propalare",
    "propalaron": "propalare",
    "propalarono": "propalare",
    "propalasse": "propalare",
    "propalasser": "propalare",
    "propalassero": "propalare",
    "propalassi": "propalare",
    "propalassimo": "propalare",
    "propalaste": "propalare",
    "propalasti": "propalare",
    "propalata": "propalare",
    "propalate": "propalare",
    "propalati": "propalare",
    "propalato": "propalare",
    "propalava": "propalare",
    "propalavamo": "propalare",
    "propalavan": "propalare",
    "propalavano": "propalare",
    "propalavate": "propalare",
    "propalavi": "propalare",
    "propalavo": "propalare",
    "propalerai": "propalare",
    "propaleran": "propalare",
    "propaleranno": "propalare",
    "propalerebbe": "propalare",
    "propalerebber": "propalare",
    "propalerebbero": "propalare",
    "propalerei": "propalare",
    "propaleremmo": "propalare",
    "propaleremo": "propalare",
    "propalereste": "propalare",
    "propaleresti": "propalare",
    "propalerete": "propalare",
    "propalerà": "propalare",
    "propalerò": "propalare",
    "propali": "propalare",
    "propaliamo": "propalare",
    "propaliate": "propalare",
    "propalin": "propalare",
    "propalino": "propalare",
    "propalo": "propalare",
    "propalò": "propalare",
    "propedeutica": "propedeutico",
    "propedeutiche": "propedeutico",
    "propedeutici": "propedeutico",
    "propellenti": "propellente",
    "propenda": "propendere",
    "propendan": "propendere",
    "propendano": "propendere",
    "propende": "propendere",
    "propendemmo": "propendere",
    "propendendo": "propendere",
    "propendente": "propendere",
    "propendenti": "propendere",
    "propender": "propendere",
    "propenderai": "propendere",
    "propenderan": "propendere",
    "propenderanno": "propendere",
    "propenderebbe": "propendere",
    "propenderebber": "propendere",
    "propenderebbero": "propendere",
    "propenderei": "propendere",
    "propenderemmo": "propendere",
    "propenderemo": "propendere",
    "propendereste": "propendere",
    "propenderesti": "propendere",
    "propenderete": "propendere",
    "propenderà": "propendere",
    "propenderò": "propendere",
    "propendesse": "propendere",
    "propendesser": "propendere",
    "propendessero": "propendere",
    "propendessi": "propendere",
    "propendessimo": "propendere",
    "propendeste": "propendere",
    "propendesti": "propendere",
    "propendete": "propendere",
    "propendeva": "propendere",
    "propendevamo": "propendere",
    "propendevan": "propendere",
    "propendevano": "propendere",
    "propendevate": "propendere",
    "propendevi": "propendere",
    "propendevo": "propendere",
    "propendi": "propendere",
    "propendiamo": "propendere",
    "propendiate": "propendere",
    "propendo": "propendere",
    "propendon": "propendere",
    "propendono": "propendere",
    "propensa": "propenso",
    "propense": "propenso",
    "propensi": "propenso",
    "propensioni": "propensione",
    "propesa": "propendere",
    "propese": "propendere",
    "propeser": "propendere",
    "propesero": "propendere",
    "propesi": "propendere",
    "propeso": "propendere",
    "propesè": "propendere",
    "propina": "propinare",
    "propinai": "propinare",
    "propinammo": "propinare",
    "propinan": "propinare",
    "propinando": "propinare",
    "propinano": "propinare",
    "propinante": "propinare",
    "propinanti": "propinare",
    "propinar": "propinare",
    "propinaron": "propinare",
    "propinarono": "propinare",
    "propinasse": "propinare",
    "propinasser": "propinare",
    "propinassero": "propinare",
    "propinassi": "propinare",
    "propinassimo": "propinare",
    "propinaste": "propinare",
    "propinasti": "propinare",
    "propinata": "propinare",
    "propinate": "propinare",
    "propinati": "propinare",
    "propinato": "propinare",
    "propinava": "propinare",
    "propinavamo": "propinare",
    "propinavan": "propinare",
    "propinavano": "propinare",
    "propinavate": "propinare",
    "propinavi": "propinare",
    "propinavo": "propinare",
    "propinerai": "propinare",
    "propineran": "propinare",
    "propineranno": "propinare",
    "propinerebbe": "propinare",
    "propinerebber": "propinare",
    "propinerebbero": "propinare",
    "propinerei": "propinare",
    "propineremmo": "propinare",
    "propineremo": "propinare",
    "propinereste": "propinare",
    "propineresti": "propinare",
    "propinerete": "propinare",
    "propinerà": "propinare",
    "propinerò": "propinare",
    "propini": "propinare",
    "propiniamo": "propinare",
    "propiniate": "propinare",
    "propinin": "propinare",
    "propinino": "propinare",
    "propino": "propinare",
    "propinò": "propinare",
    "propizi": "propizio",
    "propizia": "propizio",
    "propiziai": "propiziare",
    "propiziammo": "propiziare",
    "propiziamo": "propiziare",
    "propizian": "propiziare",
    "propiziando": "propiziare",
    "propiziano": "propiziare",
    "propiziante": "propiziare",
    "propizianti": "propiziare",
    "propiziar": "propiziare",
    "propiziaron": "propiziare",
    "propiziarono": "propiziare",
    "propiziasse": "propiziare",
    "propiziasser": "propiziare",
    "propiziassero": "propiziare",
    "propiziassi": "propiziare",
    "propiziassimo": "propiziare",
    "propiziaste": "propiziare",
    "propiziasti": "propiziare",
    "propiziata": "propiziare",
    "propiziate": "propiziare",
    "propiziati": "propiziare",
    "propiziato": "propiziare",
    "propiziatori": "propiziatorio",
    "propiziatoria": "propiziatorio",
    "propiziatorie": "propiziatorio",
    "propiziatrice": "propiziatore",
    "propiziatrici": "propiziatore",
    "propiziava": "propiziare",
    "propiziavamo": "propiziare",
    "propiziavan": "propiziare",
    "propiziavano": "propiziare",
    "propiziavate": "propiziare",
    "propiziavi": "propiziare",
    "propiziavo": "propiziare",
    "propizie": "propizio",
    "propizierai": "propiziare",
    "propizieran": "propiziare",
    "propizieranno": "propiziare",
    "propizierebbe": "propiziare",
    "propizierebber": "propiziare",
    "propizierebbero": "propiziare",
    "propizierei": "propiziare",
    "propizieremmo": "propiziare",
    "propizieremo": "propiziare",
    "propiziereste": "propiziare",
    "propizieresti": "propiziare",
    "propizierete": "propiziare",
    "propizierà": "propiziare",
    "propizierò": "propiziare",
    "propizin": "propiziare",
    "propizino": "propiziare",
    "propizio": "propiziare",
    "propiziò": "propiziare",
    "propone": "proporre",
    "proponemmo": "proporre",
    "proponendo": "proporre",
    "proponente": "proporre",
    "proponenti": "proporre",
    "proponesse": "proporre",
    "proponesser": "proporre",
    "proponessero": "proporre",
    "proponessi": "proporre",
    "proponessimo": "proporre",
    "proponeste": "proporre",
    "proponesti": "proporre",
    "proponete": "proporre",
    "proponeva": "proporre",
    "proponevamo": "proporre",
    "proponevan": "proporre",
    "proponevano": "proporre",
    "proponevate": "proporre",
    "proponevi": "proporre",
    "proponevo": "proporre",
    "proponga": "proporre",
    "propongan": "proporre",
    "propongano": "proporre",
    "propongo": "proporre",
    "propongon": "proporre",
    "propongono": "proporre",
    "proponi": "proporre",
    "proponiamo": "proporre",
    "proponiate": "proporre",
    "proponibili": "proponibile",
    "proponimenti": "proponimento",
    "proporr": "proporre",
    "proporrai": "proporre",
    "proporran": "proporre",
    "proporranno": "proporre",
    "proporrebbe": "proporre",
    "proporrebber": "proporre",
    "proporrebbero": "proporre",
    "proporrei": "proporre",
    "proporremmo": "proporre",
    "proporremo": "proporre",
    "proporreste": "proporre",
    "proporresti": "proporre",
    "proporrete": "proporre",
    "proporrà": "proporre",
    "proporrò": "proporre",
    "proporziona": "proporzionare",
    "proporzionai": "proporzionare",
    "proporzionali": "proporzionale",
    "proporzionalismi": "proporzionalismo",
    "proporzionalisti": "proporzionalista",
    "proporzionammo": "proporzionare",
    "proporzionan": "proporzionare",
    "proporzionando": "proporzionare",
    "proporzionano": "proporzionare",
    "proporzionante": "proporzionare",
    "proporzionanti": "proporzionare",
    "proporzionar": "proporzionare",
    "proporzionaron": "proporzionare",
    "proporzionarono": "proporzionare",
    "proporzionasse": "proporzionare",
    "proporzionasser": "proporzionare",
    "proporzionassero": "proporzionare",
    "proporzionassi": "proporzionare",
    "proporzionassimo": "proporzionare",
    "proporzionaste": "proporzionare",
    "proporzionasti": "proporzionare",
    "proporzionata": "proporzionato",
    "proporzionate": "proporzionato",
    "proporzionati": "proporzionato",
    "proporzionato": "proporzionare",
    "proporzionava": "proporzionare",
    "proporzionavamo": "proporzionare",
    "proporzionavan": "proporzionare",
    "proporzionavano": "proporzionare",
    "proporzionavate": "proporzionare",
    "proporzionavi": "proporzionare",
    "proporzionavo": "proporzionare",
    "proporzionerai": "proporzionare",
    "proporzioneran": "proporzionare",
    "proporzioneranno": "proporzionare",
    "proporzionerebbe": "proporzionare",
    "proporzionerebber": "proporzionare",
    "proporzionerebbero": "proporzionare",
    "proporzionerei": "proporzionare",
    "proporzioneremmo": "proporzionare",
    "proporzioneremo": "proporzionare",
    "proporzionereste": "proporzionare",
    "proporzioneresti": "proporzionare",
    "proporzionerete": "proporzionare",
    "proporzionerà": "proporzionare",
    "proporzionerò": "proporzionare",
    "proporzioni": "proporzione",
    "proporzioniamo": "proporzionare",
    "proporzioniate": "proporzionare",
    "proporzionin": "proporzionare",
    "proporzionino": "proporzionare",
    "proporziono": "proporzionare",
    "proporzionò": "proporzionare",
    "propose": "proporre",
    "proposer": "proporre",
    "proposero": "proporre",
    "proposi": "proporre",
    "propositi": "proposito",
    "propositiva": "propositivo",
    "propositive": "propositivo",
    "propositivi": "propositivo",
    "proposizioni": "proposizione",
    "proposta": "proporre",
    "proposte": "proposta",
    "proposti": "proporre",
    "proposto": "proporre",
    "propri": "proprio",
    "propria": "proprio",
    "proprie": "proprio",
    "proprietari": "proprietario",
    "proprietaria": "proprietario",
    "proprietarie": "proprietario",
    "propugna": "propugnare",
    "propugnai": "propugnare",
    "propugnammo": "propugnare",
    "propugnan": "propugnare",
    "propugnando": "propugnare",
    "propugnano": "propugnare",
    "propugnante": "propugnare",
    "propugnanti": "propugnare",
    "propugnar": "propugnare",
    "propugnaron": "propugnare",
    "propugnarono": "propugnare",
    "propugnasse": "propugnare",
    "propugnasser": "propugnare",
    "propugnassero": "propugnare",
    "propugnassi": "propugnare",
    "propugnassimo": "propugnare",
    "propugnaste": "propugnare",
    "propugnasti": "propugnare",
    "propugnata": "propugnare",
    "propugnate": "propugnare",
    "propugnati": "propugnare",
    "propugnato": "propugnare",
    "propugnatori": "propugnatore",
    "propugnava": "propugnare",
    "propugnavamo": "propugnare",
    "propugnavan": "propugnare",
    "propugnavano": "propugnare",
    "propugnavate": "propugnare",
    "propugnavi": "propugnare",
    "propugnavo": "propugnare",
    "propugnerai": "propugnare",
    "propugneran": "propugnare",
    "propugneranno": "propugnare",
    "propugnerebbe": "propugnare",
    "propugnerebber": "propugnare",
    "propugnerebbero": "propugnare",
    "propugnerei": "propugnare",
    "propugneremmo": "propugnare",
    "propugneremo": "propugnare",
    "propugnereste": "propugnare",
    "propugneresti": "propugnare",
    "propugnerete": "propugnare",
    "propugnerà": "propugnare",
    "propugnerò": "propugnare",
    "propugni": "propugnare",
    "propugniamo": "propugnare",
    "propugniate": "propugnare",
    "propugnin": "propugnare",
    "propugnino": "propugnare",
    "propugno": "propugnare",
    "propugnò": "propugnare",
    "propulsioni": "propulsione",
    "propulsiva": "propulsivo",
    "propulsive": "propulsivo",
    "propulsivi": "propulsivo",
    "propulsori": "propulsore",
    "proroga": "prorogare",
    "prorogabili": "prorogabile",
    "prorogai": "prorogare",
    "prorogammo": "prorogare",
    "prorogan": "prorogare",
    "prorogando": "prorogare",
    "prorogano": "prorogare",
    "prorogante": "prorogare",
    "proroganti": "prorogare",
    "prorogar": "prorogare",
    "prorogaron": "prorogare",
    "prorogarono": "prorogare",
    "prorogasse": "prorogare",
    "prorogasser": "prorogare",
    "prorogassero": "prorogare",
    "prorogassi": "prorogare",
    "prorogassimo": "prorogare",
    "prorogaste": "prorogare",
    "prorogasti": "prorogare",
    "prorogata": "prorogare",
    "prorogate": "prorogare",
    "prorogati": "prorogare",
    "prorogationes": "prorogatio",
    "prorogato": "prorogare",
    "prorogava": "prorogare",
    "prorogavamo": "prorogare",
    "prorogavan": "prorogare",
    "prorogavano": "prorogare",
    "prorogavate": "prorogare",
    "prorogavi": "prorogare",
    "prorogavo": "prorogare",
    "proroghe": "proroga",
    "prorogherai": "prorogare",
    "prorogheran": "prorogare",
    "prorogheranno": "prorogare",
    "prorogherebbe": "prorogare",
    "prorogherebber": "prorogare",
    "prorogherebbero": "prorogare",
    "prorogherei": "prorogare",
    "prorogheremmo": "prorogare",
    "prorogheremo": "prorogare",
    "proroghereste": "prorogare",
    "prorogheresti": "prorogare",
    "prorogherete": "prorogare",
    "prorogherà": "prorogare",
    "prorogherò": "prorogare",
    "proroghi": "prorogare",
    "proroghiamo": "prorogare",
    "proroghiate": "prorogare",
    "proroghin": "prorogare",
    "proroghino": "prorogare",
    "prorogo": "prorogare",
    "prorogò": "prorogare",
    "prorompa": "prorompere",
    "prorompan": "prorompere",
    "prorompano": "prorompere",
    "prorompe": "prorompere",
    "prorompemmo": "prorompere",
    "prorompendo": "prorompere",
    "prorompente": "prorompere",
    "prorompenti": "prorompere",
    "proromper": "prorompere",
    "proromperai": "prorompere",
    "proromperan": "prorompere",
    "proromperanno": "prorompere",
    "proromperebbe": "prorompere",
    "proromperebber": "prorompere",
    "proromperebbero": "prorompere",
    "proromperei": "prorompere",
    "proromperemmo": "prorompere",
    "proromperemo": "prorompere",
    "prorompereste": "prorompere",
    "proromperesti": "prorompere",
    "proromperete": "prorompere",
    "proromperà": "prorompere",
    "proromperò": "prorompere",
    "prorompesse": "prorompere",
    "prorompesser": "prorompere",
    "prorompessero": "prorompere",
    "prorompessi": "prorompere",
    "prorompessimo": "prorompere",
    "prorompeste": "prorompere",
    "prorompesti": "prorompere",
    "prorompete": "prorompere",
    "prorompeva": "prorompere",
    "prorompevamo": "prorompere",
    "prorompevan": "prorompere",
    "prorompevano": "prorompere",
    "prorompevate": "prorompere",
    "prorompevi": "prorompere",
    "prorompevo": "prorompere",
    "prorompi": "prorompere",
    "prorompiamo": "prorompere",
    "prorompiate": "prorompere",
    "prorompo": "prorompere",
    "prorompon": "prorompere",
    "prorompono": "prorompere",
    "prorotta": "prorompere",
    "prorotte": "prorompere",
    "prorotti": "prorompere",
    "prorotto": "prorompere",
    "proruppe": "prorompere",
    "prorupper": "prorompere",
    "proruppero": "prorompere",
    "proruppi": "prorompere",
    "prosaica": "prosaico",
    "prosaiche": "prosaico",
    "prosaici": "prosaico",
    "prosatori": "prosatore",
    "proscenii": "proscenio",
    "prosciogli": "prosciogliere",
    "prosciogliamo": "prosciogliere",
    "prosciogliate": "prosciogliere",
    "proscioglie": "prosciogliere",
    "prosciogliemmo": "prosciogliere",
    "prosciogliendo": "prosciogliere",
    "prosciogliente": "prosciogliere",
    "proscioglienti": "prosciogliere",
    "proscioglier": "prosciogliere",
    "proscioglierai": "prosciogliere",
    "proscioglieran": "prosciogliere",
    "proscioglieranno": "prosciogliere",
    "proscioglierebbe": "prosciogliere",
    "proscioglierebber": "prosciogliere",
    "proscioglierebbero": "prosciogliere",
    "proscioglierei": "prosciogliere",
    "proscioglieremmo": "prosciogliere",
    "proscioglieremo": "prosciogliere",
    "prosciogliereste": "prosciogliere",
    "proscioglieresti": "prosciogliere",
    "proscioglierete": "prosciogliere",
    "proscioglierà": "prosciogliere",
    "proscioglierò": "prosciogliere",
    "prosciogliesse": "prosciogliere",
    "prosciogliesser": "prosciogliere",
    "prosciogliessero": "prosciogliere",
    "prosciogliessi": "prosciogliere",
    "prosciogliessimo": "prosciogliere",
    "proscioglieste": "prosciogliere",
    "prosciogliesti": "prosciogliere",
    "prosciogliete": "prosciogliere",
    "proscioglieva": "prosciogliere",
    "proscioglievamo": "prosciogliere",
    "proscioglievan": "prosciogliere",
    "proscioglievano": "prosciogliere",
    "proscioglievate": "prosciogliere",
    "proscioglievi": "prosciogliere",
    "proscioglievo": "prosciogliere",
    "proscioglimenti": "proscioglimento",
    "prosciolga": "prosciogliere",
    "prosciolgan": "prosciogliere",
    "prosciolgano": "prosciogliere",
    "prosciolgo": "prosciogliere",
    "prosciolgon": "prosciogliere",
    "prosciolgono": "prosciogliere",
    "prosciolse": "prosciogliere",
    "prosciolser": "prosciogliere",
    "prosciolsero": "prosciogliere",
    "prosciolsi": "prosciogliere",
    "prosciolta": "prosciogliere",
    "prosciolte": "prosciogliere",
    "prosciolti": "prosciogliere",
    "prosciolto": "prosciogliere",
    "prosciuga": "prosciugare",
    "prosciugai": "prosciugare",
    "prosciugamenti": "prosciugamento",
    "prosciugammo": "prosciugare",
    "prosciugan": "prosciugare",
    "prosciugando": "prosciugare",
    "prosciugano": "prosciugare",
    "prosciugante": "prosciugare",
    "prosciuganti": "prosciugare",
    "prosciugar": "prosciugare",
    "prosciugaron": "prosciugare",
    "prosciugarono": "prosciugare",
    "prosciugasse": "prosciugare",
    "prosciugasser": "prosciugare",
    "prosciugassero": "prosciugare",
    "prosciugassi": "prosciugare",
    "prosciugassimo": "prosciugare",
    "prosciugaste": "prosciugare",
    "prosciugasti": "prosciugare",
    "prosciugata": "prosciugare",
    "prosciugate": "prosciugare",
    "prosciugati": "prosciugare",
    "prosciugato": "prosciugare",
    "prosciugava": "prosciugare",
    "prosciugavamo": "prosciugare",
    "prosciugavan": "prosciugare",
    "prosciugavano": "prosciugare",
    "prosciugavate": "prosciugare",
    "prosciugavi": "prosciugare",
    "prosciugavo": "prosciugare",
    "prosciugherai": "prosciugare",
    "prosciugheran": "prosciugare",
    "prosciugheranno": "prosciugare",
    "prosciugherebbe": "prosciugare",
    "prosciugherebber": "prosciugare",
    "prosciugherebbero": "prosciugare",
    "prosciugherei": "prosciugare",
    "prosciugheremmo": "prosciugare",
    "prosciugheremo": "prosciugare",
    "prosciughereste": "prosciugare",
    "prosciugheresti": "prosciugare",
    "prosciugherete": "prosciugare",
    "prosciugherà": "prosciugare",
    "prosciugherò": "prosciugare",
    "prosciughi": "prosciugare",
    "prosciughiamo": "prosciugare",
    "prosciughiate": "prosciugare",
    "prosciughin": "prosciugare",
    "prosciughino": "prosciugare",
    "prosciugo": "prosciugare",
    "prosciugò": "prosciugare",
    "prosciutti": "prosciutto",
    "proscrisse": "proscrivere",
    "proscrisser": "proscrivere",
    "proscrissero": "proscrivere",
    "proscrissi": "proscrivere",
    "proscritta": "proscrivere",
    "proscritte": "proscrivere",
    "proscritti": "proscrivere",
    "proscritto": "proscrivere",
    "proscriva": "proscrivere",
    "proscrivan": "proscrivere",
    "proscrivano": "proscrivere",
    "proscrive": "proscrivere",
    "proscrivemmo": "proscrivere",
    "proscrivendo": "proscrivere",
    "proscrivente": "proscrivere",
    "proscriventi": "proscrivere",
    "proscriver": "proscrivere",
    "proscriverai": "proscrivere",
    "proscriveran": "proscrivere",
    "proscriveranno": "proscrivere",
    "proscriverebbe": "proscrivere",
    "proscriverebber": "proscrivere",
    "proscriverebbero": "proscrivere",
    "proscriverei": "proscrivere",
    "proscriveremmo": "proscrivere",
    "proscriveremo": "proscrivere",
    "proscrivereste": "proscrivere",
    "proscriveresti": "proscrivere",
    "proscriverete": "proscrivere",
    "proscriverà": "proscrivere",
    "proscriverò": "proscrivere",
    "proscrivesse": "proscrivere",
    "proscrivesser": "proscrivere",
    "proscrivessero": "proscrivere",
    "proscrivessi": "proscrivere",
    "proscrivessimo": "proscrivere",
    "proscriveste": "proscrivere",
    "proscrivesti": "proscrivere",
    "proscrivete": "proscrivere",
    "proscriveva": "proscrivere",
    "proscrivevamo": "proscrivere",
    "proscrivevan": "proscrivere",
    "proscrivevano": "proscrivere",
    "proscrivevate": "proscrivere",
    "proscrivevi": "proscrivere",
    "proscrivevo": "proscrivere",
    "proscrivi": "proscrivere",
    "proscriviamo": "proscrivere",
    "proscriviate": "proscrivere",
    "proscrivo": "proscrivere",
    "proscrivon": "proscrivere",
    "proscrivono": "proscrivere",
    "prosecuzioni": "prosecuzione",
    "prosegua": "proseguire",
    "proseguan": "proseguire",
    "proseguano": "proseguire",
    "prosegue": "proseguire",
    "proseguendo": "proseguire",
    "proseguente": "proseguire",
    "proseguenti": "proseguire",
    "prosegui": "proseguire",
    "proseguiamo": "proseguire",
    "proseguiate": "proseguire",
    "proseguii": "proseguire",
    "proseguimenti": "proseguimento",
    "proseguimmo": "proseguire",
    "proseguir": "proseguire",
    "proseguirai": "proseguire",
    "proseguiran": "proseguire",
    "proseguiranno": "proseguire",
    "proseguirebbe": "proseguire",
    "proseguirebber": "proseguire",
    "proseguirebbero": "proseguire",
    "proseguirei": "proseguire",
    "proseguiremmo": "proseguire",
    "proseguiremo": "proseguire",
    "proseguireste": "proseguire",
    "proseguiresti": "proseguire",
    "proseguirete": "proseguire",
    "proseguiron": "proseguire",
    "proseguirono": "proseguire",
    "proseguirà": "proseguire",
    "proseguirò": "proseguire",
    "proseguisse": "proseguire",
    "proseguisser": "proseguire",
    "proseguissero": "proseguire",
    "proseguissi": "proseguire",
    "proseguissimo": "proseguire",
    "proseguiste": "proseguire",
    "proseguisti": "proseguire",
    "proseguita": "proseguire",
    "proseguite": "proseguire",
    "proseguiti": "proseguire",
    "proseguito": "proseguire",
    "proseguiva": "proseguire",
    "proseguivamo": "proseguire",
    "proseguivan": "proseguire",
    "proseguivano": "proseguire",
    "proseguivate": "proseguire",
    "proseguivi": "proseguire",
    "proseguivo": "proseguire",
    "proseguo": "proseguire",
    "proseguon": "proseguire",
    "proseguono": "proseguire",
    "proseguì": "proseguire",
    "proselitismi": "proselitismo",
    "prosiegui": "prosieguo",
    "prosindaci": "prosindaco",
    "prosopopee": "prosopopea",
    "prospera": "prospero",
    "prosperai": "prosperare",
    "prosperammo": "prosperare",
    "prosperan": "prosperare",
    "prosperando": "prosperare",
    "prosperano": "prosperare",
    "prosperante": "prosperare",
    "prosperanti": "prosperare",
    "prosperar": "prosperare",
    "prosperaron": "prosperare",
    "prosperarono": "prosperare",
    "prosperasse": "prosperare",
    "prosperasser": "prosperare",
    "prosperassero": "prosperare",
    "prosperassi": "prosperare",
    "prosperassimo": "prosperare",
    "prosperaste": "prosperare",
    "prosperasti": "prosperare",
    "prosperata": "prosperare",
    "prosperate": "prosperare",
    "prosperati": "prosperare",
    "prosperato": "prosperare",
    "prosperava": "prosperare",
    "prosperavamo": "prosperare",
    "prosperavan": "prosperare",
    "prosperavano": "prosperare",
    "prosperavate": "prosperare",
    "prosperavi": "prosperare",
    "prosperavo": "prosperare",
    "prospere": "prospero",
    "prospererai": "prosperare",
    "prospereran": "prosperare",
    "prospereranno": "prosperare",
    "prospererebbe": "prosperare",
    "prospererebber": "prosperare",
    "prospererebbero": "prosperare",
    "prospererei": "prosperare",
    "prospereremmo": "prosperare",
    "prospereremo": "prosperare",
    "prosperereste": "prosperare",
    "prospereresti": "prosperare",
    "prospererete": "prosperare",
    "prospererà": "prosperare",
    "prospererò": "prosperare",
    "prosperi": "prospero",
    "prosperiamo": "prosperare",
    "prosperiate": "prosperare",
    "prosperin": "prosperare",
    "prosperino": "prosperare",
    "prospero": "prosperare",
    "prosperosa": "prosperoso",
    "prosperose": "prosperoso",
    "prosperosi": "prosperoso",
    "prosperò": "prosperare",
    "prospetta": "prospettare",
    "prospettai": "prospettare",
    "prospettammo": "prospettare",
    "prospettan": "prospettare",
    "prospettando": "prospettare",
    "prospettano": "prospettare",
    "prospettante": "prospettare",
    "prospettanti": "prospettare",
    "prospettar": "prospettare",
    "prospettaron": "prospettare",
    "prospettarono": "prospettare",
    "prospettasse": "prospettare",
    "prospettasser": "prospettare",
    "prospettassero": "prospettare",
    "prospettassi": "prospettare",
    "prospettassimo": "prospettare",
    "prospettaste": "prospettare",
    "prospettasti": "prospettare",
    "prospettata": "prospettare",
    "prospettate": "prospettare",
    "prospettati": "prospettare",
    "prospettato": "prospettare",
    "prospettava": "prospettare",
    "prospettavamo": "prospettare",
    "prospettavan": "prospettare",
    "prospettavano": "prospettare",
    "prospettavate": "prospettare",
    "prospettavi": "prospettare",
    "prospettavo": "prospettare",
    "prospettazioni": "prospettazione",
    "prospetterai": "prospettare",
    "prospetteran": "prospettare",
    "prospetteranno": "prospettare",
    "prospetterebbe": "prospettare",
    "prospetterebber": "prospettare",
    "prospetterebbero": "prospettare",
    "prospetterei": "prospettare",
    "prospetteremmo": "prospettare",
    "prospetteremo": "prospettare",
    "prospettereste": "prospettare",
    "prospetteresti": "prospettare",
    "prospetterete": "prospettare",
    "prospetterà": "prospettare",
    "prospetterò": "prospettare",
    "prospetti": "prospetto",
    "prospettiamo": "prospettare",
    "prospettiate": "prospettare",
    "prospettica": "prospettico",
    "prospettiche": "prospettico",
    "prospettici": "prospettico",
    "prospettin": "prospettare",
    "prospettino": "prospettare",
    "prospettiva": "prospettivo",
    "prospettive": "prospettivo",
    "prospettivi": "prospettivo",
    "prospetto": "prospettare",
    "prospettò": "prospettare",
    "prospezioni": "prospezione",
    "prospicienti": "prospiciente",
    "prossima": "prossimo",
    "prossime": "prossimo",
    "prossimi": "prossimo",
    "prostaglandine": "prostaglandina",
    "prostatica": "prostatico",
    "prostatiche": "prostatico",
    "prostatici": "prostatico",
    "prosterna": "prosternare",
    "prosternai": "prosternare",
    "prosternammo": "prosternare",
    "prosternan": "prosternare",
    "prosternando": "prosternare",
    "prosternano": "prosternare",
    "prosternante": "prosternare",
    "prosternanti": "prosternare",
    "prosternar": "prosternare",
    "prosternaron": "prosternare",
    "prosternarono": "prosternare",
    "prosternasse": "prosternare",
    "prosternasser": "prosternare",
    "prosternassero": "prosternare",
    "prosternassi": "prosternare",
    "prosternassimo": "prosternare",
    "prosternaste": "prosternare",
    "prosternasti": "prosternare",
    "prosternata": "prosternare",
    "prosternate": "prosternare",
    "prosternati": "prosternare",
    "prosternato": "prosternare",
    "prosternava": "prosternare",
    "prosternavamo": "prosternare",
    "prosternavan": "prosternare",
    "prosternavano": "prosternare",
    "prosternavate": "prosternare",
    "prosternavi": "prosternare",
    "prosternavo": "prosternare",
    "prosternerai": "prosternare",
    "prosterneran": "prosternare",
    "prosterneranno": "prosternare",
    "prosternerebbe": "prosternare",
    "prosternerebber": "prosternare",
    "prosternerebbero": "prosternare",
    "prosternerei": "prosternare",
    "prosterneremmo": "prosternare",
    "prosterneremo": "prosternare",
    "prosternereste": "prosternare",
    "prosterneresti": "prosternare",
    "prosternerete": "prosternare",
    "prosternerà": "prosternare",
    "prosternerò": "prosternare",
    "prosterni": "prosternare",
    "prosterniamo": "prosternare",
    "prosterniate": "prosternare",
    "prosternin": "prosternare",
    "prosternino": "prosternare",
    "prosterno": "prosternare",
    "prosternò": "prosternare",
    "prostituendo": "prostituire",
    "prostituente": "prostituire",
    "prostituenti": "prostituire",
    "prostituiamo": "prostituire",
    "prostituiate": "prostituire",
    "prostituii": "prostituire",
    "prostituimmo": "prostituire",
    "prostituir": "prostituire",
    "prostituirai": "prostituire",
    "prostituiran": "prostituire",
    "prostituiranno": "prostituire",
    "prostituirebbe": "prostituire",
    "prostituirebber": "prostituire",
    "prostituirebbero": "prostituire",
    "prostituirei": "prostituire",
    "prostituiremmo": "prostituire",
    "prostituiremo": "prostituire",
    "prostituireste": "prostituire",
    "prostituiresti": "prostituire",
    "prostituirete": "prostituire",
    "prostituiron": "prostituire",
    "prostituirono": "prostituire",
    "prostituirà": "prostituire",
    "prostituirò": "prostituire",
    "prostituisca": "prostituire",
    "prostituiscan": "prostituire",
    "prostituiscano": "prostituire",
    "prostituisce": "prostituire",
    "prostituisci": "prostituire",
    "prostituisco": "prostituire",
    "prostituiscon": "prostituire",
    "prostituiscono": "prostituire",
    "prostituisse": "prostituire",
    "prostituisser": "prostituire",
    "prostituissero": "prostituire",
    "prostituissi": "prostituire",
    "prostituissimo": "prostituire",
    "prostituiste": "prostituire",
    "prostituisti": "prostituire",
    "prostituita": "prostituire",
    "prostituite": "prostituire",
    "prostituiti": "prostituire",
    "prostituito": "prostituire",
    "prostituiva": "prostituire",
    "prostituivamo": "prostituire",
    "prostituivan": "prostituire",
    "prostituivano": "prostituire",
    "prostituivate": "prostituire",
    "prostituivi": "prostituire",
    "prostituivo": "prostituire",
    "prostitute": "prostituta",
    "prostituti": "prostituto",
    "prostituzioni": "prostituzione",
    "prostituì": "prostituire",
    "prostra": "prostrare",
    "prostrai": "prostrare",
    "prostrammo": "prostrare",
    "prostran": "prostrare",
    "prostrando": "prostrare",
    "prostrano": "prostrare",
    "prostrante": "prostrare",
    "prostranti": "prostrare",
    "prostrar": "prostrare",
    "prostraron": "prostrare",
    "prostrarono": "prostrare",
    "prostrasse": "prostrare",
    "prostrasser": "prostrare",
    "prostrassero": "prostrare",
    "prostrassi": "prostrare",
    "prostrassimo": "prostrare",
    "prostraste": "prostrare",
    "prostrasti": "prostrare",
    "prostrata": "prostrare",
    "prostrate": "prostrare",
    "prostrati": "prostrare",
    "prostrato": "prostrare",
    "prostrava": "prostrare",
    "prostravamo": "prostrare",
    "prostravan": "prostrare",
    "prostravano": "prostrare",
    "prostravate": "prostrare",
    "prostravi": "prostrare",
    "prostravo": "prostrare",
    "prostrazioni": "prostrazione",
    "prostrerai": "prostrare",
    "prostreran": "prostrare",
    "prostreranno": "prostrare",
    "prostrerebbe": "prostrare",
    "prostrerebber": "prostrare",
    "prostrerebbero": "prostrare",
    "prostrerei": "prostrare",
    "prostreremmo": "prostrare",
    "prostreremo": "prostrare",
    "prostrereste": "prostrare",
    "prostreresti": "prostrare",
    "prostrerete": "prostrare",
    "prostrerà": "prostrare",
    "prostrerò": "prostrare",
    "prostri": "prostrare",
    "prostriamo": "prostrare",
    "prostriate": "prostrare",
    "prostrin": "prostrare",
    "prostrino": "prostrare",
    "prostro": "prostrare",
    "prostrò": "prostrare",
    "protagonismi": "protagonismo",
    "protagoniste": "protagonista",
    "protagonisti": "protagonista",
    "protegga": "proteggere",
    "proteggan": "proteggere",
    "proteggano": "proteggere",
    "protegge": "proteggere",
    "proteggemmo": "proteggere",
    "proteggendo": "proteggere",
    "proteggente": "proteggere",
    "proteggenti": "proteggere",
    "protegger": "proteggere",
    "proteggerai": "proteggere",
    "proteggeran": "proteggere",
    "proteggeranno": "proteggere",
    "proteggerebbe": "proteggere",
    "proteggerebber": "proteggere",
    "proteggerebbero": "proteggere",
    "proteggerei": "proteggere",
    "proteggeremmo": "proteggere",
    "proteggeremo": "proteggere",
    "proteggereste": "proteggere",
    "proteggeresti": "proteggere",
    "proteggerete": "proteggere",
    "proteggerà": "proteggere",
    "proteggerò": "proteggere",
    "proteggesse": "proteggere",
    "proteggesser": "proteggere",
    "proteggessero": "proteggere",
    "proteggessi": "proteggere",
    "proteggessimo": "proteggere",
    "proteggeste": "proteggere",
    "proteggesti": "proteggere",
    "proteggete": "proteggere",
    "proteggeva": "proteggere",
    "proteggevamo": "proteggere",
    "proteggevan": "proteggere",
    "proteggevano": "proteggere",
    "proteggevate": "proteggere",
    "proteggevi": "proteggere",
    "proteggevo": "proteggere",
    "proteggi": "proteggere",
    "proteggiamo": "proteggere",
    "proteggiate": "proteggere",
    "proteggo": "proteggere",
    "proteggon": "proteggere",
    "proteggono": "proteggere",
    "proteica": "proteico",
    "proteiche": "proteico",
    "proteici": "proteico",
    "proteiformi": "proteiforme",
    "proteine": "proteina",
    "protenda": "protendere",
    "protendan": "protendere",
    "protendano": "protendere",
    "protende": "protendere",
    "protendemmo": "protendere",
    "protendendo": "protendere",
    "protendente": "protendere",
    "protendenti": "protendere",
    "protender": "protendere",
    "protenderai": "protendere",
    "protenderan": "protendere",
    "protenderanno": "protendere",
    "protenderebbe": "protendere",
    "protenderebber": "protendere",
    "protenderebbero": "protendere",
    "protenderei": "protendere",
    "protenderemmo": "protendere",
    "protenderemo": "protendere",
    "protendereste": "protendere",
    "protenderesti": "protendere",
    "protenderete": "protendere",
    "protenderà": "protendere",
    "protenderò": "protendere",
    "protendesse": "protendere",
    "protendesser": "protendere",
    "protendessero": "protendere",
    "protendessi": "protendere",
    "protendessimo": "protendere",
    "protendeste": "protendere",
    "protendesti": "protendere",
    "protendete": "protendere",
    "protendeva": "protendere",
    "protendevamo": "protendere",
    "protendevan": "protendere",
    "protendevano": "protendere",
    "protendevate": "protendere",
    "protendevi": "protendere",
    "protendevo": "protendere",
    "protendi": "protendere",
    "protendiamo": "protendere",
    "protendiate": "protendere",
    "protendo": "protendere",
    "protendon": "protendere",
    "protendono": "protendere",
    "proterva": "protervo",
    "proterve": "protervo",
    "protervi": "protervo",
    "protervie": "protervia",
    "protesa": "protendere",
    "protese": "protendere",
    "proteser": "protendere",
    "protesero": "protendere",
    "protesi": "protendere",
    "proteso": "protendere",
    "protesser": "proteggere",
    "protessero": "proteggere",
    "protessi": "proteggere",
    "protessè": "proteggere",
    "protesta": "protestare",
    "protestai": "protestare",
    "protestammo": "protestare",
    "protestan": "protestare",
    "protestando": "protestare",
    "protestano": "protestare",
    "protestante": "protestare",
    "protestanti": "protestare",
    "protestar": "protestare",
    "protestaron": "protestare",
    "protestarono": "protestare",
    "protestasse": "protestare",
    "protestasser": "protestare",
    "protestassero": "protestare",
    "protestassi": "protestare",
    "protestassimo": "protestare",
    "protestaste": "protestare",
    "protestasti": "protestare",
    "protestata": "protestare",
    "protestatari": "protestatario",
    "protestataria": "protestatario",
    "protestatarie": "protestatario",
    "protestate": "protestare",
    "protestati": "protestare",
    "protestato": "protestare",
    "protestava": "protestare",
    "protestavamo": "protestare",
    "protestavan": "protestare",
    "protestavano": "protestare",
    "protestavate": "protestare",
    "protestavi": "protestare",
    "protestavo": "protestare",
    "proteste": "protesta",
    "protesterai": "protestare",
    "protesteran": "protestare",
    "protesteranno": "protestare",
    "protesterebbe": "protestare",
    "protesterebber": "protestare",
    "protesterebbero": "protestare",
    "protesterei": "protestare",
    "protesteremmo": "protestare",
    "protesteremo": "protestare",
    "protestereste": "protestare",
    "protesteresti": "protestare",
    "protesterete": "protestare",
    "protesterà": "protestare",
    "protesterò": "protestare",
    "protesti": "protesto",
    "protestiamo": "protestare",
    "protestiate": "protestare",
    "protestin": "protestare",
    "protestino": "protestare",
    "protesto": "protestare",
    "protestò": "protestare",
    "protesè": "protendere",
    "protetta": "protetto",
    "protette": "protetto",
    "protetti": "protetto",
    "protettiva": "protettivo",
    "protettive": "protettivo",
    "protettivi": "protettivo",
    "protetto": "proteggere",
    "protettorati": "protettorato",
    "protettori": "protettore",
    "protettrice": "protettore",
    "protettrici": "protettore",
    "protezioni": "protezione",
    "protezionismi": "protezionismo",
    "protezioniste": "protezionista",
    "protezionisti": "protezionista",
    "protezionistica": "protezionistico",
    "protezionistiche": "protezionistico",
    "protezionistici": "protezionistico",
    "protocolla": "protocollare",
    "protocollai": "protocollare",
    "protocollammo": "protocollare",
    "protocollan": "protocollare",
    "protocollando": "protocollare",
    "protocollano": "protocollare",
    "protocollante": "protocollare",
    "protocollanti": "protocollare",
    "protocollar": "protocollare",
    "protocollari": "protocollare",
    "protocollaron": "protocollare",
    "protocollarono": "protocollare",
    "protocollasse": "protocollare",
    "protocollasser": "protocollare",
    "protocollassero": "protocollare",
    "protocollassi": "protocollare",
    "protocollassimo": "protocollare",
    "protocollaste": "protocollare",
    "protocollasti": "protocollare",
    "protocollata": "protocollare",
    "protocollate": "protocollare",
    "protocollati": "protocollare",
    "protocollato": "protocollare",
    "protocollava": "protocollare",
    "protocollavamo": "protocollare",
    "protocollavan": "protocollare",
    "protocollavano": "protocollare",
    "protocollavate": "protocollare",
    "protocollavi": "protocollare",
    "protocollavo": "protocollare",
    "protocollerai": "protocollare",
    "protocolleran": "protocollare",
    "protocolleranno": "protocollare",
    "protocollerebbe": "protocollare",
    "protocollerebber": "protocollare",
    "protocollerebbero": "protocollare",
    "protocollerei": "protocollare",
    "protocolleremmo": "protocollare",
    "protocolleremo": "protocollare",
    "protocollereste": "protocollare",
    "protocolleresti": "protocollare",
    "protocollerete": "protocollare",
    "protocollerà": "protocollare",
    "protocollerò": "protocollare",
    "protocolli": "protocollo",
    "protocolliamo": "protocollare",
    "protocolliate": "protocollare",
    "protocollin": "protocollare",
    "protocollino": "protocollare",
    "protocollo": "protocollare",
    "protocollò": "protocollare",
    "protoni": "protone",
    "protoromantica": "protoromantico",
    "protoromantiche": "protoromantico",
    "protoromantici": "protoromantico",
    "prototipa": "prototipo",
    "prototipe": "prototipo",
    "prototipi": "prototipo",
    "protozoi": "protozoo",
    "protrae": "protrarre",
    "protraemmo": "protrarre",
    "protraendo": "protrarre",
    "protraente": "protrarre",
    "protraenti": "protrarre",
    "protraesse": "protrarre",
    "protraesser": "protrarre",
    "protraessero": "protrarre",
    "protraessi": "protrarre",
    "protraessimo": "protrarre",
    "protraeste": "protrarre",
    "protraesti": "protrarre",
    "protraete": "protrarre",
    "protraeva": "protrarre",
    "protraevamo": "protrarre",
    "protraevan": "protrarre",
    "protraevano": "protrarre",
    "protraevate": "protrarre",
    "protraevi": "protrarre",
    "protraevo": "protrarre",
    "protragga": "protrarre",
    "protraggan": "protrarre",
    "protraggano": "protrarre",
    "protraggo": "protrarre",
    "protraggon": "protrarre",
    "protraggono": "protrarre",
    "protrai": "protrarre",
    "protraiamo": "protrarre",
    "protraiate": "protrarre",
    "protrarr": "protrarre",
    "protrarrai": "protrarre",
    "protrarran": "protrarre",
    "protrarranno": "protrarre",
    "protrarrebbe": "protrarre",
    "protrarrebber": "protrarre",
    "protrarrebbero": "protrarre",
    "protrarrei": "protrarre",
    "protrarremmo": "protrarre",
    "protrarremo": "protrarre",
    "protrarreste": "protrarre",
    "protrarresti": "protrarre",
    "protrarrete": "protrarre",
    "protrarrà": "protrarre",
    "protrarrò": "protrarre",
    "protrasse": "protrarre",
    "protrasser": "protrarre",
    "protrassero": "protrarre",
    "protrassi": "protrarre",
    "protratta": "protrarre",
    "protratte": "protrarre",
    "protratti": "protrarre",
    "protratto": "protrarre",
    "protuberanze": "protuberanza",
    "prova": "provare",
    "provai": "provare",
    "provammo": "provare",
    "provan": "provare",
    "provando": "provare",
    "provano": "provare",
    "provante": "provare",
    "provanti": "provare",
    "provar": "provare",
    "provaron": "provare",
    "provarono": "provare",
    "provasse": "provare",
    "provasser": "provare",
    "provassero": "provare",
    "provassi": "provare",
    "provassimo": "provare",
    "provaste": "provare",
    "provasti": "provare",
    "provata": "provato",
    "provate": "provato",
    "provati": "provato",
    "provato": "provare",
    "provava": "provare",
    "provavamo": "provare",
    "provavan": "provare",
    "provavano": "provare",
    "provavate": "provare",
    "provavi": "provare",
    "provavo": "provare",
    "prove": "prova",
    "provedimenti": "provedimento",
    "provenendo": "provenire",
    "provenga": "provenire",
    "provengan": "provenire",
    "provengano": "provenire",
    "provengo": "provenire",
    "provengon": "provenire",
    "provengono": "provenire",
    "proveniamo": "provenire",
    "proveniate": "provenire",
    "proveniendo": "provenire",
    "proveniente": "provenire",
    "provenienti": "provenire",
    "provenienze": "provenienza",
    "provenimmo": "provenire",
    "provenir": "provenire",
    "provenisse": "provenire",
    "provenisser": "provenire",
    "provenissero": "provenire",
    "provenissi": "provenire",
    "provenissimo": "provenire",
    "proveniste": "provenire",
    "provenisti": "provenire",
    "provenite": "provenire",
    "proveniva": "provenire",
    "provenivamo": "provenire",
    "provenivan": "provenire",
    "provenivano": "provenire",
    "provenivate": "provenire",
    "provenivi": "provenire",
    "provenivo": "provenire",
    "provenne": "provenire",
    "provenner": "provenire",
    "provennero": "provenire",
    "provenni": "provenire",
    "proventi": "provento",
    "provenuta": "provenire",
    "provenute": "provenire",
    "provenuti": "provenire",
    "provenuto": "provenire",
    "provenzali": "provenzale",
    "proverai": "provare",
    "proveran": "provare",
    "proveranno": "provare",
    "proverbi": "proverbio",
    "proverbiali": "proverbiale",
    "proverebbe": "provare",
    "proverebber": "provare",
    "proverebbero": "provare",
    "proverei": "provare",
    "proveremmo": "provare",
    "proveremo": "provare",
    "provereste": "provare",
    "proveresti": "provare",
    "proverete": "provare",
    "proverrai": "provenire",
    "proverran": "provenire",
    "proverranno": "provenire",
    "proverrebbe": "provenire",
    "proverrebber": "provenire",
    "proverrebbero": "provenire",
    "proverrei": "provenire",
    "proverremmo": "provenire",
    "proverremo": "provenire",
    "proverreste": "provenire",
    "proverresti": "provenire",
    "proverrete": "provenire",
    "proverrà": "provenire",
    "proverrò": "provenire",
    "proverà": "provare",
    "proverò": "provare",
    "provetta": "provetto",
    "provette": "provetto",
    "provetti": "provetto",
    "provi": "provare",
    "proviamo": "provare",
    "proviate": "provare",
    "proviene": "provenire",
    "provieni": "provenire",
    "provin": "provare",
    "province": "provincia",
    "provinciali": "provinciale",
    "provincialismi": "provincialismo",
    "provincializza": "provincializzare",
    "provincializzai": "provincializzare",
    "provincializzammo": "provincializzare",
    "provincializzan": "provincializzare",
    "provincializzando": "provincializzare",
    "provincializzano": "provincializzare",
    "provincializzante": "provincializzare",
    "provincializzanti": "provincializzare",
    "provincializzar": "provincializzare",
    "provincializzaron": "provincializzare",
    "provincializzarono": "provincializzare",
    "provincializzasse": "provincializzare",
    "provincializzasser": "provincializzare",
    "provincializzassero": "provincializzare",
    "provincializzassi": "provincializzare",
    "provincializzassimo": "provincializzare",
    "provincializzaste": "provincializzare",
    "provincializzasti": "provincializzare",
    "provincializzata": "provincializzare",
    "provincializzate": "provincializzare",
    "provincializzati": "provincializzare",
    "provincializzato": "provincializzare",
    "provincializzava": "provincializzare",
    "provincializzavamo": "provincializzare",
    "provincializzavan": "provincializzare",
    "provincializzavano": "provincializzare",
    "provincializzavate": "provincializzare",
    "provincializzavi": "provincializzare",
    "provincializzavo": "provincializzare",
    "provincializzerai": "provincializzare",
    "provincializzeran": "provincializzare",
    "provincializzeranno": "provincializzare",
    "provincializzerebbe": "provincializzare",
    "provincializzerebber": "provincializzare",
    "provincializzerebbero": "provincializzare",
    "provincializzerei": "provincializzare",
    "provincializzeremmo": "provincializzare",
    "provincializzeremo": "provincializzare",
    "provincializzereste": "provincializzare",
    "provincializzeresti": "provincializzare",
    "provincializzerete": "provincializzare",
    "provincializzerà": "provincializzare",
    "provincializzerò": "provincializzare",
    "provincializzi": "provincializzare",
    "provincializziamo": "provincializzare",
    "provincializziate": "provincializzare",
    "provincializzin": "provincializzare",
    "provincializzino": "provincializzare",
    "provincializzo": "provincializzare",
    "provincializzò": "provincializzare",
    "provincie": "provincia",
    "provini": "provino",
    "provino": "provare",
    "provo": "provare",
    "provoca": "provocare",
    "provocai": "provocare",
    "provocammo": "provocare",
    "provocan": "provocare",
    "provocando": "provocare",
    "provocano": "provocare",
    "provocante": "provocare",
    "provocanti": "provocare",
    "provocar": "provocare",
    "provocaron": "provocare",
    "provocarono": "provocare",
    "provocasse": "provocare",
    "provocasser": "provocare",
    "provocassero": "provocare",
    "provocassi": "provocare",
    "provocassimo": "provocare",
    "provocaste": "provocare",
    "provocasti": "provocare",
    "provocata": "provocare",
    "provocate": "provocare",
    "provocati": "provocare",
    "provocato": "provocare",
    "provocatori": "provocatorio",
    "provocatoria": "provocatorio",
    "provocatorie": "provocatorio",
    "provocatrice": "provocatore",
    "provocatrici": "provocatore",
    "provocava": "provocare",
    "provocavamo": "provocare",
    "provocavan": "provocare",
    "provocavano": "provocare",
    "provocavate": "provocare",
    "provocavi": "provocare",
    "provocavo": "provocare",
    "provocazioni": "provocazione",
    "provocherai": "provocare",
    "provocheran": "provocare",
    "provocheranno": "provocare",
    "provocherebbe": "provocare",
    "provocherebber": "provocare",
    "provocherebbero": "provocare",
    "provocherei": "provocare",
    "provocheremmo": "provocare",
    "provocheremo": "provocare",
    "provochereste": "provocare",
    "provocheresti": "provocare",
    "provocherete": "provocare",
    "provocherà": "provocare",
    "provocherò": "provocare",
    "provochi": "provocare",
    "provochiamo": "provocare",
    "provochiate": "provocare",
    "provochin": "provocare",
    "provochino": "provocare",
    "provoco": "provocare",
    "provocò": "provocare",
    "provveda": "provvedere",
    "provvedan": "provvedere",
    "provvedano": "provvedere",
    "provvede": "provvedere",
    "provvedemmo": "provvedere",
    "provvedendo": "provvedere",
    "provvedente": "provvedere",
    "provvedenti": "provvedere",
    "provveder": "provvedere",
    "provvedesse": "provvedere",
    "provvedesser": "provvedere",
    "provvedessero": "provvedere",
    "provvedessi": "provvedere",
    "provvedessimo": "provvedere",
    "provvedeste": "provvedere",
    "provvedesti": "provvedere",
    "provvedete": "provvedere",
    "provvedeva": "provvedere",
    "provvedevamo": "provvedere",
    "provvedevan": "provvedere",
    "provvedevano": "provvedere",
    "provvedevate": "provvedere",
    "provvedevi": "provvedere",
    "provvedevo": "provvedere",
    "provvedi": "provvedere",
    "provvediamo": "provvedere",
    "provvediate": "provvedere",
    "provvedimenti": "provvedimento",
    "provveditorati": "provveditorato",
    "provveditori": "provveditore",
    "provvedo": "provvedere",
    "provvedon": "provvedere",
    "provvedono": "provvedere",
    "provvedrai": "provvedere",
    "provvedran": "provvedere",
    "provvedranno": "provvedere",
    "provvedrebbe": "provvedere",
    "provvedrebber": "provvedere",
    "provvedrebbero": "provvedere",
    "provvedrei": "provvedere",
    "provvedremmo": "provvedere",
    "provvedremo": "provvedere",
    "provvedreste": "provvedere",
    "provvedresti": "provvedere",
    "provvedrete": "provvedere",
    "provvedrà": "provvedere",
    "provvedrò": "provvedere",
    "provveduta": "provveduto",
    "provvedute": "provveduto",
    "provveduti": "provveduto",
    "provveduto": "provvedere",
    "provvida": "provvido",
    "provvide": "provvido",
    "provvidenze": "provvidenza",
    "provvidenziali": "provvidenziale",
    "provvider": "provvedere",
    "provvidero": "provvedere",
    "provvidi": "provvido",
    "provvigioni": "provvigione",
    "provvisionali": "provvisionale",
    "provvisori": "provvisorio",
    "provvisoria": "provvisorio",
    "provvisorie": "provvisorio",
    "provviste": "provvista",
    "provò": "provare",
    "prozii": "prozio",
    "pruda": "prudere",
    "prudan": "prudere",
    "prudano": "prudere",
    "prude": "prudere",
    "prudei": "prudere",
    "prudemmo": "prudere",
    "prudendo": "prudere",
    "prudente": "prudere",
    "prudenti": "prudere",
    "prudenze": "prudenza",
    "prudenziali": "prudenziale",
    "pruder": "prudere",
    "pruderai": "prudere",
    "pruderan": "prudere",
    "pruderanno": "prudere",
    "pruderebbe": "prudere",
    "pruderebber": "prudere",
    "pruderebbero": "prudere",
    "pruderei": "prudere",
    "pruderemmo": "prudere",
    "pruderemo": "prudere",
    "prudereste": "prudere",
    "pruderesti": "prudere",
    "pruderete": "prudere",
    "pruderon": "prudere",
    "pruderono": "prudere",
    "pruderà": "prudere",
    "pruderò": "prudere",
    "prudesse": "prudere",
    "prudesser": "prudere",
    "prudessero": "prudere",
    "prudessi": "prudere",
    "prudessimo": "prudere",
    "prudeste": "prudere",
    "prudesti": "prudere",
    "prudete": "prudere",
    "prudeva": "prudere",
    "prudevamo": "prudere",
    "prudevan": "prudere",
    "prudevano": "prudere",
    "prudevate": "prudere",
    "prudevi": "prudere",
    "prudevo": "prudere",
    "prudi": "prudere",
    "prudiamo": "prudere",
    "prudiate": "prudere",
    "prudo": "prudere",
    "prudon": "prudere",
    "prudono": "prudere",
    "pruduta": "prudere",
    "prudute": "prudere",
    "pruduti": "prudere",
    "pruduto": "prudere",
    "prudè": "prudere",
    "prue": "prua",
    "prugne": "prugna",
    "pruriti": "prurito",
    "prussiani": "prussiano",
    "prìncipi": "prìncipe",
    "pseudonima": "pseudonimo",
    "pseudonime": "pseudonimo",
    "pseudonimi": "pseudonimo",
    "pseudopopolari": "pseudopopolare",
    "pseudoscienze": "pseudoscienza",
    "psicanalisti": "psicanalista",
    "psicanalitica": "psicanalitico",
    "psicanalitiche": "psicanalitico",
    "psicanalitici": "psicanalitico",
    "psicanalizza": "psicanalizzare",
    "psicanalizzai": "psicanalizzare",
    "psicanalizzammo": "psicanalizzare",
    "psicanalizzan": "psicanalizzare",
    "psicanalizzando": "psicanalizzare",
    "psicanalizzano": "psicanalizzare",
    "psicanalizzante": "psicanalizzare",
    "psicanalizzanti": "psicanalizzare",
    "psicanalizzar": "psicanalizzare",
    "psicanalizzaron": "psicanalizzare",
    "psicanalizzarono": "psicanalizzare",
    "psicanalizzasse": "psicanalizzare",
    "psicanalizzasser": "psicanalizzare",
    "psicanalizzassero": "psicanalizzare",
    "psicanalizzassi": "psicanalizzare",
    "psicanalizzassimo": "psicanalizzare",
    "psicanalizzaste": "psicanalizzare",
    "psicanalizzasti": "psicanalizzare",
    "psicanalizzata": "psicanalizzare",
    "psicanalizzate": "psicanalizzare",
    "psicanalizzati": "psicanalizzare",
    "psicanalizzato": "psicanalizzare",
    "psicanalizzava": "psicanalizzare",
    "psicanalizzavamo": "psicanalizzare",
    "psicanalizzavan": "psicanalizzare",
    "psicanalizzavano": "psicanalizzare",
    "psicanalizzavate": "psicanalizzare",
    "psicanalizzavi": "psicanalizzare",
    "psicanalizzavo": "psicanalizzare",
    "psicanalizzerai": "psicanalizzare",
    "psicanalizzeran": "psicanalizzare",
    "psicanalizzeranno": "psicanalizzare",
    "psicanalizzerebbe": "psicanalizzare",
    "psicanalizzerebber": "psicanalizzare",
    "psicanalizzerebbero": "psicanalizzare",
    "psicanalizzerei": "psicanalizzare",
    "psicanalizzeremmo": "psicanalizzare",
    "psicanalizzeremo": "psicanalizzare",
    "psicanalizzereste": "psicanalizzare",
    "psicanalizzeresti": "psicanalizzare",
    "psicanalizzerete": "psicanalizzare",
    "psicanalizzerà": "psicanalizzare",
    "psicanalizzerò": "psicanalizzare",
    "psicanalizzi": "psicanalizzare",
    "psicanalizziamo": "psicanalizzare",
    "psicanalizziate": "psicanalizzare",
    "psicanalizzin": "psicanalizzare",
    "psicanalizzino": "psicanalizzare",
    "psicanalizzo": "psicanalizzare",
    "psicanalizzò": "psicanalizzare",
    "psichedelica": "psichedelico",
    "psichedeliche": "psichedelico",
    "psichedelici": "psichedelico",
    "psichiatre": "psichiatra",
    "psichiatri": "psichiatra",
    "psichiatrica": "psichiatrico",
    "psichiatriche": "psichiatrico",
    "psichiatrici": "psichiatrico",
    "psichiatrie": "psichiatria",
    "psichica": "psichico",
    "psichiche": "psichico",
    "psichici": "psichico",
    "psico-fisica": "psico-fisico",
    "psico-fisiche": "psico-fisico",
    "psico-fisici": "psico-fisico",
    "psicoanaliste": "psicoanalista",
    "psicoanalisti": "psicoanalista",
    "psicodrammi": "psicodramma",
    "psicofarmaci": "psicofarmaco",
    "psicofisica": "psicofisico",
    "psicofisiche": "psicofisico",
    "psicofisici": "psicofisico",
    "psicologhe": "psicologa",
    "psicologi": "psicologo",
    "psicologica": "psicologico",
    "psicologiche": "psicologico",
    "psicologici": "psicologico",
    "psicologie": "psicologia",
    "psicologismi": "psicologismo",
    "psicopatica": "psicopatico",
    "psicopatiche": "psicopatico",
    "psicopatici": "psicopatico",
    "psicopatie": "psicopatia",
    "psicopatologie": "psicopatologia",
    "psicosomatica": "psicosomatico",
    "psicosomatiche": "psicosomatico",
    "psicosomatici": "psicosomatico",
    "psicoterapeuti": "psicoterapeuta",
    "psicoterapeutica": "psicoterapeutico",
    "psicoterapeutiche": "psicoterapeutico",
    "psicoterapeutici": "psicoterapeutico",
    "psicoterapie": "psicoterapia",
    "psicotica": "psicotico",
    "psicotiche": "psicotico",
    "psicotici": "psicotico",
    "psicotropa": "psicotropo",
    "psicotrope": "psicotropo",
    "psicotropi": "psicotropo",
    "pubalgie": "pubalgia",
    "pubblica": "pubblico",
    "pubblicabili": "pubblicabile",
    "pubblicai": "pubblicare",
    "pubblicammo": "pubblicare",
    "pubblican": "pubblicare",
    "pubblicando": "pubblicare",
    "pubblicano": "pubblicare",
    "pubblicante": "pubblicare",
    "pubblicanti": "pubblicare",
    "pubblicar": "pubblicare",
    "pubblicaron": "pubblicare",
    "pubblicarono": "pubblicare",
    "pubblicasse": "pubblicare",
    "pubblicasser": "pubblicare",
    "pubblicassero": "pubblicare",
    "pubblicassi": "pubblicare",
    "pubblicassimo": "pubblicare",
    "pubblicaste": "pubblicare",
    "pubblicasti": "pubblicare",
    "pubblicata": "pubblicare",
    "pubblicate": "pubblicare",
    "pubblicati": "pubblicare",
    "pubblicato": "pubblicare",
    "pubblicava": "pubblicare",
    "pubblicavamo": "pubblicare",
    "pubblicavan": "pubblicare",
    "pubblicavano": "pubblicare",
    "pubblicavate": "pubblicare",
    "pubblicavi": "pubblicare",
    "pubblicavo": "pubblicare",
    "pubblicazioni": "pubblicazione",
    "pubbliche": "pubblico",
    "pubblicherai": "pubblicare",
    "pubblicheran": "pubblicare",
    "pubblicheranno": "pubblicare",
    "pubblicherebbe": "pubblicare",
    "pubblicherebber": "pubblicare",
    "pubblicherebbero": "pubblicare",
    "pubblicherei": "pubblicare",
    "pubblicheremmo": "pubblicare",
    "pubblicheremo": "pubblicare",
    "pubblichereste": "pubblicare",
    "pubblicheresti": "pubblicare",
    "pubblicherete": "pubblicare",
    "pubblicherà": "pubblicare",
    "pubblicherò": "pubblicare",
    "pubblichi": "pubblicare",
    "pubblichiamo": "pubblicare",
    "pubblichiate": "pubblicare",
    "pubblichin": "pubblicare",
    "pubblichino": "pubblicare",
    "pubblici": "pubblico",
    "pubblicisti": "pubblicista",
    "pubblicistica": "pubblicistico",
    "pubblicistiche": "pubblicistico",
    "pubblicistici": "pubblicistico",
    "pubblicitari": "pubblicitario",
    "pubblicitaria": "pubblicitario",
    "pubblicitarie": "pubblicitario",
    "pubblicizza": "pubblicizzare",
    "pubblicizzai": "pubblicizzare",
    "pubblicizzammo": "pubblicizzare",
    "pubblicizzan": "pubblicizzare",
    "pubblicizzando": "pubblicizzare",
    "pubblicizzano": "pubblicizzare",
    "pubblicizzante": "pubblicizzare",
    "pubblicizzanti": "pubblicizzare",
    "pubblicizzar": "pubblicizzare",
    "pubblicizzaron": "pubblicizzare",
    "pubblicizzarono": "pubblicizzare",
    "pubblicizzasse": "pubblicizzare",
    "pubblicizzasser": "pubblicizzare",
    "pubblicizzassero": "pubblicizzare",
    "pubblicizzassi": "pubblicizzare",
    "pubblicizzassimo": "pubblicizzare",
    "pubblicizzaste": "pubblicizzare",
    "pubblicizzasti": "pubblicizzare",
    "pubblicizzata": "pubblicizzare",
    "pubblicizzate": "pubblicizzare",
    "pubblicizzati": "pubblicizzare",
    "pubblicizzato": "pubblicizzare",
    "pubblicizzava": "pubblicizzare",
    "pubblicizzavamo": "pubblicizzare",
    "pubblicizzavan": "pubblicizzare",
    "pubblicizzavano": "pubblicizzare",
    "pubblicizzavate": "pubblicizzare",
    "pubblicizzavi": "pubblicizzare",
    "pubblicizzavo": "pubblicizzare",
    "pubblicizzazioni": "pubblicizzazione",
    "pubblicizzerai": "pubblicizzare",
    "pubblicizzeran": "pubblicizzare",
    "pubblicizzeranno": "pubblicizzare",
    "pubblicizzerebbe": "pubblicizzare",
    "pubblicizzerebber": "pubblicizzare",
    "pubblicizzerebbero": "pubblicizzare",
    "pubblicizzerei": "pubblicizzare",
    "pubblicizzeremmo": "pubblicizzare",
    "pubblicizzeremo": "pubblicizzare",
    "pubblicizzereste": "pubblicizzare",
    "pubblicizzeresti": "pubblicizzare",
    "pubblicizzerete": "pubblicizzare",
    "pubblicizzerà": "pubblicizzare",
    "pubblicizzerò": "pubblicizzare",
    "pubblicizzi": "pubblicizzare",
    "pubblicizziamo": "pubblicizzare",
    "pubblicizziate": "pubblicizzare",
    "pubblicizzin": "pubblicizzare",
    "pubblicizzino": "pubblicizzare",
    "pubblicizzo": "pubblicizzare",
    "pubblicizzò": "pubblicizzare",
    "pubblico": "pubblicare",
    "pubblico-mutualistica": "pubblico-mutualistico",
    "pubblico-mutualistiche": "pubblico-mutualistico",
    "pubblico-mutualistici": "pubblico-mutualistico",
    "pubblico-privata": "pubblico-privato",
    "pubblico-private": "pubblico-privato",
    "pubblico-privati": "pubblico-privato",
    "pubblicò": "pubblicare",
    "puberali": "puberale",
    "pubi": "pube",
    "pucciniana": "pucciniano",
    "pucciniane": "pucciniano",
    "pucciniani": "pucciniano",
    "pudibonda": "pudibondo",
    "pudibonde": "pudibondo",
    "pudibondi": "pudibondo",
    "pudica": "pudico",
    "pudiche": "pudico",
    "pudichi": "pudico",
    "pudici": "pudico",
    "pudicizie": "pudicizia",
    "pudori": "pudore",
    "pueblos": "pueblo",
    "puerili": "puerile",
    "puerperali": "puerperale",
    "puerpere": "puerpera",
    "puffi": "puffo",
    "pugilati": "pugilato",
    "pugili": "pugile",
    "pugilistica": "pugilistico",
    "pugilistiche": "pugilistico",
    "pugilistici": "pugilistico",
    "pugliesi": "pugliese",
    "pugna": "pugnare",
    "pugnai": "pugnare",
    "pugnala": "pugnalare",
    "pugnalai": "pugnalare",
    "pugnalammo": "pugnalare",
    "pugnalan": "pugnalare",
    "pugnalando": "pugnalare",
    "pugnalano": "pugnalare",
    "pugnalante": "pugnalare",
    "pugnalanti": "pugnalare",
    "pugnalar": "pugnalare",
    "pugnalaron": "pugnalare",
    "pugnalarono": "pugnalare",
    "pugnalasse": "pugnalare",
    "pugnalasser": "pugnalare",
    "pugnalassero": "pugnalare",
    "pugnalassi": "pugnalare",
    "pugnalassimo": "pugnalare",
    "pugnalaste": "pugnalare",
    "pugnalasti": "pugnalare",
    "pugnalata": "pugnalare",
    "pugnalate": "pugnalata",
    "pugnalati": "pugnalare",
    "pugnalato": "pugnalare",
    "pugnalatori": "pugnalatore",
    "pugnalava": "pugnalare",
    "pugnalavamo": "pugnalare",
    "pugnalavan": "pugnalare",
    "pugnalavano": "pugnalare",
    "pugnalavate": "pugnalare",
    "pugnalavi": "pugnalare",
    "pugnalavo": "pugnalare",
    "pugnalerai": "pugnalare",
    "pugnaleran": "pugnalare",
    "pugnaleranno": "pugnalare",
    "pugnalerebbe": "pugnalare",
    "pugnalerebber": "pugnalare",
    "pugnalerebbero": "pugnalare",
    "pugnalerei": "pugnalare",
    "pugnaleremmo": "pugnalare",
    "pugnaleremo": "pugnalare",
    "pugnalereste": "pugnalare",
    "pugnaleresti": "pugnalare",
    "pugnalerete": "pugnalare",
    "pugnalerà": "pugnalare",
    "pugnalerò": "pugnalare",
    "pugnali": "pugnale",
    "pugnaliamo": "pugnalare",
    "pugnaliate": "pugnalare",
    "pugnalin": "pugnalare",
    "pugnalino": "pugnalare",
    "pugnalo": "pugnalare",
    "pugnalò": "pugnalare",
    "pugnammo": "pugnare",
    "pugnan": "pugnare",
    "pugnando": "pugnare",
    "pugnano": "pugnare",
    "pugnante": "pugnare",
    "pugnanti": "pugnare",
    "pugnar": "pugnare",
    "pugnaron": "pugnare",
    "pugnarono": "pugnare",
    "pugnasse": "pugnare",
    "pugnasser": "pugnare",
    "pugnassero": "pugnare",
    "pugnassi": "pugnare",
    "pugnassimo": "pugnare",
    "pugnaste": "pugnare",
    "pugnasti": "pugnare",
    "pugnata": "pugnare",
    "pugnate": "pugnare",
    "pugnati": "pugnare",
    "pugnato": "pugnare",
    "pugnava": "pugnare",
    "pugnavamo": "pugnare",
    "pugnavan": "pugnare",
    "pugnavano": "pugnare",
    "pugnavate": "pugnare",
    "pugnavi": "pugnare",
    "pugnavo": "pugnare",
    "pugnerai": "pugnare",
    "pugneran": "pugnare",
    "pugneranno": "pugnare",
    "pugnerebbe": "pugnare",
    "pugnerebber": "pugnare",
    "pugnerebbero": "pugnare",
    "pugnerei": "pugnare",
    "pugneremmo": "pugnare",
    "pugneremo": "pugnare",
    "pugnereste": "pugnare",
    "pugneresti": "pugnare",
    "pugnerete": "pugnare",
    "pugnerà": "pugnare",
    "pugnerò": "pugnare",
    "pugni": "pugno",
    "pugniamo": "pugnare",
    "pugniate": "pugnare",
    "pugnin": "pugnare",
    "pugnino": "pugnare",
    "pugno": "pugnare",
    "pugnò": "pugnare",
    "pulci": "pulce",
    "pulcini": "pulcino",
    "puledri": "puledro",
    "pulendo": "pulire",
    "pulente": "pulire",
    "pulenti": "pulire",
    "puliamo": "pulire",
    "puliate": "pulire",
    "pulii": "pulire",
    "pulimmo": "pulire",
    "pulir": "pulire",
    "pulirai": "pulire",
    "puliran": "pulire",
    "puliranno": "pulire",
    "pulirebbe": "pulire",
    "pulirebber": "pulire",
    "pulirebbero": "pulire",
    "pulirei": "pulire",
    "puliremmo": "pulire",
    "puliremo": "pulire",
    "pulireste": "pulire",
    "puliresti": "pulire",
    "pulirete": "pulire",
    "puliron": "pulire",
    "pulirono": "pulire",
    "pulirà": "pulire",
    "pulirò": "pulire",
    "pulisca": "pulire",
    "puliscan": "pulire",
    "puliscano": "pulire",
    "pulisce": "pulire",
    "pulisci": "pulire",
    "pulisco": "pulire",
    "puliscon": "pulire",
    "puliscono": "pulire",
    "pulisse": "pulire",
    "pulisser": "pulire",
    "pulissero": "pulire",
    "pulissi": "pulire",
    "pulissimo": "pulire",
    "puliste": "pulire",
    "pulisti": "pulire",
    "pulita": "pulito",
    "pulite": "pulito",
    "puliti": "pulito",
    "pulito": "pulire",
    "pulitori": "pulitore",
    "puliture": "pulitura",
    "puliva": "pulire",
    "pulivamo": "pulire",
    "pulivan": "pulire",
    "pulivano": "pulire",
    "pulivate": "pulire",
    "pulivi": "pulire",
    "pulivo": "pulire",
    "pulizie": "pulizia",
    "pullmini": "pullmino",
    "pullula": "pullulare",
    "pullulai": "pullulare",
    "pullulammo": "pullulare",
    "pullulan": "pullulare",
    "pullulando": "pullulare",
    "pullulano": "pullulare",
    "pullulante": "pullulare",
    "pullulanti": "pullulare",
    "pullular": "pullulare",
    "pullularon": "pullulare",
    "pullularono": "pullulare",
    "pullulasse": "pullulare",
    "pullulasser": "pullulare",
    "pullulassero": "pullulare",
    "pullulassi": "pullulare",
    "pullulassimo": "pullulare",
    "pullulaste": "pullulare",
    "pullulasti": "pullulare",
    "pullulata": "pullulare",
    "pullulate": "pullulare",
    "pullulati": "pullulare",
    "pullulato": "pullulare",
    "pullulava": "pullulare",
    "pullulavamo": "pullulare",
    "pullulavan": "pullulare",
    "pullulavano": "pullulare",
    "pullulavate": "pullulare",
    "pullulavi": "pullulare",
    "pullulavo": "pullulare",
    "pullulerai": "pullulare",
    "pulluleran": "pullulare",
    "pulluleranno": "pullulare",
    "pullulerebbe": "pullulare",
    "pullulerebber": "pullulare",
    "pullulerebbero": "pullulare",
    "pullulerei": "pullulare",
    "pulluleremmo": "pullulare",
    "pulluleremo": "pullulare",
    "pullulereste": "pullulare",
    "pulluleresti": "pullulare",
    "pullulerete": "pullulare",
    "pullulerà": "pullulare",
    "pullulerò": "pullulare",
    "pulluli": "pullulare",
    "pulluliamo": "pullulare",
    "pulluliate": "pullulare",
    "pullulin": "pullulare",
    "pullulino": "pullulare",
    "pullulo": "pullulare",
    "pullulò": "pullulare",
    "pulmini": "pulmino",
    "pulpiti": "pulpito",
    "pulsa": "pulsare",
    "pulsai": "pulsare",
    "pulsammo": "pulsare",
    "pulsan": "pulsare",
    "pulsando": "pulsare",
    "pulsano": "pulsare",
    "pulsante": "pulsare",
    "pulsanti": "pulsare",
    "pulsar": "pulsare",
    "pulsaron": "pulsare",
    "pulsarono": "pulsare",
    "pulsasse": "pulsare",
    "pulsasser": "pulsare",
    "pulsassero": "pulsare",
    "pulsassi": "pulsare",
    "pulsassimo": "pulsare",
    "pulsaste": "pulsare",
    "pulsasti": "pulsare",
    "pulsata": "pulsare",
    "pulsate": "pulsare",
    "pulsati": "pulsare",
    "pulsato": "pulsare",
    "pulsava": "pulsare",
    "pulsavamo": "pulsare",
    "pulsavan": "pulsare",
    "pulsavano": "pulsare",
    "pulsavate": "pulsare",
    "pulsavi": "pulsare",
    "pulsavo": "pulsare",
    "pulsazioni": "pulsazione",
    "pulserai": "pulsare",
    "pulseran": "pulsare",
    "pulseranno": "pulsare",
    "pulserebbe": "pulsare",
    "pulserebber": "pulsare",
    "pulserebbero": "pulsare",
    "pulserei": "pulsare",
    "pulseremmo": "pulsare",
    "pulseremo": "pulsare",
    "pulsereste": "pulsare",
    "pulseresti": "pulsare",
    "pulserete": "pulsare",
    "pulserà": "pulsare",
    "pulserò": "pulsare",
    "pulsi": "pulsare",
    "pulsiamo": "pulsare",
    "pulsiate": "pulsare",
    "pulsin": "pulsare",
    "pulsino": "pulsare",
    "pulsioni": "pulsione",
    "pulso": "pulsare",
    "pulsò": "pulsare",
    "pulvina": "pulvinare",
    "pulvinai": "pulvinare",
    "pulvinammo": "pulvinare",
    "pulvinan": "pulvinare",
    "pulvinando": "pulvinare",
    "pulvinano": "pulvinare",
    "pulvinante": "pulvinare",
    "pulvinanti": "pulvinare",
    "pulvinar": "pulvinare",
    "pulvinaron": "pulvinare",
    "pulvinarono": "pulvinare",
    "pulvinasse": "pulvinare",
    "pulvinasser": "pulvinare",
    "pulvinassero": "pulvinare",
    "pulvinassi": "pulvinare",
    "pulvinassimo": "pulvinare",
    "pulvinaste": "pulvinare",
    "pulvinasti": "pulvinare",
    "pulvinata": "pulvinare",
    "pulvinate": "pulvinare",
    "pulvinati": "pulvinare",
    "pulvinato": "pulvinare",
    "pulvinava": "pulvinare",
    "pulvinavamo": "pulvinare",
    "pulvinavan": "pulvinare",
    "pulvinavano": "pulvinare",
    "pulvinavate": "pulvinare",
    "pulvinavi": "pulvinare",
    "pulvinavo": "pulvinare",
    "pulvinerai": "pulvinare",
    "pulvineran": "pulvinare",
    "pulvineranno": "pulvinare",
    "pulvinerebbe": "pulvinare",
    "pulvinerebber": "pulvinare",
    "pulvinerebbero": "pulvinare",
    "pulvinerei": "pulvinare",
    "pulvineremmo": "pulvinare",
    "pulvineremo": "pulvinare",
    "pulvinereste": "pulvinare",
    "pulvineresti": "pulvinare",
    "pulvinerete": "pulvinare",
    "pulvinerà": "pulvinare",
    "pulvinerò": "pulvinare",
    "pulvini": "pulvinare",
    "pulviniamo": "pulvinare",
    "pulviniate": "pulvinare",
    "pulvinin": "pulvinare",
    "pulvinino": "pulvinare",
    "pulvino": "pulvinare",
    "pulvinò": "pulvinare",
    "pulviscolari": "pulviscolare",
    "pulviscoli": "pulviscolo",
    "pulì": "pulire",
    "punendo": "punire",
    "punente": "punire",
    "punenti": "punire",
    "punga": "pungere",
    "pungan": "pungere",
    "pungano": "pungere",
    "punge": "pungere",
    "pungemmo": "pungere",
    "pungendo": "pungere",
    "pungente": "pungere",
    "pungenti": "pungere",
    "punger": "pungere",
    "pungerai": "pungere",
    "pungeran": "pungere",
    "pungeranno": "pungere",
    "pungerebbe": "pungere",
    "pungerebber": "pungere",
    "pungerebbero": "pungere",
    "pungerei": "pungere",
    "pungeremmo": "pungere",
    "pungeremo": "pungere",
    "pungereste": "pungere",
    "pungeresti": "pungere",
    "pungerete": "pungere",
    "pungerà": "pungere",
    "pungerò": "pungere",
    "pungesse": "pungere",
    "pungesser": "pungere",
    "pungessero": "pungere",
    "pungessi": "pungere",
    "pungessimo": "pungere",
    "pungeste": "pungere",
    "pungesti": "pungere",
    "pungete": "pungere",
    "pungeva": "pungere",
    "pungevamo": "pungere",
    "pungevan": "pungere",
    "pungevano": "pungere",
    "pungevate": "pungere",
    "pungevi": "pungere",
    "pungevo": "pungere",
    "pungi": "pungere",
    "pungiamo": "pungere",
    "pungiate": "pungere",
    "pungiglioni": "pungiglione",
    "pungo": "pungere",
    "pungola": "pungolare",
    "pungolai": "pungolare",
    "pungolammo": "pungolare",
    "pungolan": "pungolare",
    "pungolando": "pungolare",
    "pungolano": "pungolare",
    "pungolante": "pungolare",
    "pungolanti": "pungolare",
    "pungolar": "pungolare",
    "pungolaron": "pungolare",
    "pungolarono": "pungolare",
    "pungolasse": "pungolare",
    "pungolasser": "pungolare",
    "pungolassero": "pungolare",
    "pungolassi": "pungolare",
    "pungolassimo": "pungolare",
    "pungolaste": "pungolare",
    "pungolasti": "pungolare",
    "pungolata": "pungolare",
    "pungolate": "pungolare",
    "pungolati": "pungolare",
    "pungolato": "pungolare",
    "pungolava": "pungolare",
    "pungolavamo": "pungolare",
    "pungolavan": "pungolare",
    "pungolavano": "pungolare",
    "pungolavate": "pungolare",
    "pungolavi": "pungolare",
    "pungolavo": "pungolare",
    "pungolerai": "pungolare",
    "pungoleran": "pungolare",
    "pungoleranno": "pungolare",
    "pungolerebbe": "pungolare",
    "pungolerebber": "pungolare",
    "pungolerebbero": "pungolare",
    "pungolerei": "pungolare",
    "pungoleremmo": "pungolare",
    "pungoleremo": "pungolare",
    "pungolereste": "pungolare",
    "pungoleresti": "pungolare",
    "pungolerete": "pungolare",
    "pungolerà": "pungolare",
    "pungolerò": "pungolare",
    "pungoli": "pungolo",
    "pungoliamo": "pungolare",
    "pungoliate": "pungolare",
    "pungolin": "pungolare",
    "pungolino": "pungolare",
    "pungolo": "pungolare",
    "pungolò": "pungolare",
    "pungon": "pungere",
    "pungono": "pungere",
    "puniamo": "punire",
    "puniate": "punire",
    "punibili": "punibile",
    "punii": "punire",
    "punimmo": "punire",
    "punir": "punire",
    "punirai": "punire",
    "puniran": "punire",
    "puniranno": "punire",
    "punirebbe": "punire",
    "punirebber": "punire",
    "punirebbero": "punire",
    "punirei": "punire",
    "puniremmo": "punire",
    "puniremo": "punire",
    "punireste": "punire",
    "puniresti": "punire",
    "punirete": "punire",
    "puniron": "punire",
    "punirono": "punire",
    "punirà": "punire",
    "punirò": "punire",
    "punisca": "punire",
    "puniscan": "punire",
    "puniscano": "punire",
    "punisce": "punire",
    "punisci": "punire",
    "punisco": "punire",
    "puniscon": "punire",
    "puniscono": "punire",
    "punisse": "punire",
    "punisser": "punire",
    "punissero": "punire",
    "punissi": "punire",
    "punissimo": "punire",
    "puniste": "punire",
    "punisti": "punire",
    "punita": "punire",
    "punite": "punire",
    "puniti": "punire",
    "punitiva": "punitivo",
    "punitive": "punitivo",
    "punitivi": "punitivo",
    "punito": "punire",
    "puniva": "punire",
    "punivamo": "punire",
    "punivan": "punire",
    "punivano": "punire",
    "punivate": "punire",
    "punivi": "punire",
    "punivo": "punire",
    "punizioni": "punizione",
    "punser": "pungere",
    "punsero": "pungere",
    "punsi": "pungere",
    "punsè": "pungere",
    "punta": "punto",
    "puntai": "puntare",
    "puntammo": "puntare",
    "puntan": "puntare",
    "puntando": "puntare",
    "puntano": "puntare",
    "puntante": "puntare",
    "puntanti": "puntare",
    "puntar": "puntare",
    "puntaron": "puntare",
    "puntarono": "puntare",
    "puntasse": "puntare",
    "puntasser": "puntare",
    "puntassero": "puntare",
    "puntassi": "puntare",
    "puntassimo": "puntare",
    "puntaste": "puntare",
    "puntasti": "puntare",
    "puntata": "puntato",
    "puntate": "puntato",
    "puntati": "puntato",
    "puntatine": "puntatina",
    "puntato": "puntare",
    "puntava": "puntare",
    "puntavamo": "puntare",
    "puntavan": "puntare",
    "puntavano": "puntare",
    "puntavate": "puntare",
    "puntavi": "puntare",
    "puntavo": "puntare",
    "punte": "punto",
    "punteggerai": "punteggiare",
    "punteggeran": "punteggiare",
    "punteggeranno": "punteggiare",
    "punteggerebbe": "punteggiare",
    "punteggerebber": "punteggiare",
    "punteggerebbero": "punteggiare",
    "punteggerei": "punteggiare",
    "punteggeremmo": "punteggiare",
    "punteggeremo": "punteggiare",
    "punteggereste": "punteggiare",
    "punteggeresti": "punteggiare",
    "punteggerete": "punteggiare",
    "punteggerà": "punteggiare",
    "punteggerò": "punteggiare",
    "punteggi": "punteggio",
    "punteggia": "punteggiare",
    "punteggiai": "punteggiare",
    "punteggiammo": "punteggiare",
    "punteggiamo": "punteggiare",
    "punteggian": "punteggiare",
    "punteggiando": "punteggiare",
    "punteggiano": "punteggiare",
    "punteggiante": "punteggiare",
    "punteggianti": "punteggiare",
    "punteggiar": "punteggiare",
    "punteggiaron": "punteggiare",
    "punteggiarono": "punteggiare",
    "punteggiasse": "punteggiare",
    "punteggiasser": "punteggiare",
    "punteggiassero": "punteggiare",
    "punteggiassi": "punteggiare",
    "punteggiassimo": "punteggiare",
    "punteggiaste": "punteggiare",
    "punteggiasti": "punteggiare",
    "punteggiata": "punteggiare",
    "punteggiate": "punteggiare",
    "punteggiati": "punteggiare",
    "punteggiato": "punteggiare",
    "punteggiature": "punteggiatura",
    "punteggiava": "punteggiare",
    "punteggiavamo": "punteggiare",
    "punteggiavan": "punteggiare",
    "punteggiavano": "punteggiare",
    "punteggiavate": "punteggiare",
    "punteggiavi": "punteggiare",
    "punteggiavo": "punteggiare",
    "punteggin": "punteggiare",
    "punteggino": "punteggiare",
    "punteggio": "punteggiare",
    "punteggiò": "punteggiare",
    "puntella": "puntellare",
    "puntellai": "puntellare",
    "puntellammo": "puntellare",
    "puntellan": "puntellare",
    "puntellando": "puntellare",
    "puntellano": "puntellare",
    "puntellante": "puntellare",
    "puntellanti": "puntellare",
    "puntellar": "puntellare",
    "puntellaron": "puntellare",
    "puntellarono": "puntellare",
    "puntellasse": "puntellare",
    "puntellasser": "puntellare",
    "puntellassero": "puntellare",
    "puntellassi": "puntellare",
    "puntellassimo": "puntellare",
    "puntellaste": "puntellare",
    "puntellasti": "puntellare",
    "puntellata": "puntellare",
    "puntellate": "puntellare",
    "puntellati": "puntellare",
    "puntellato": "puntellare",
    "puntellava": "puntellare",
    "puntellavamo": "puntellare",
    "puntellavan": "puntellare",
    "puntellavano": "puntellare",
    "puntellavate": "puntellare",
    "puntellavi": "puntellare",
    "puntellavo": "puntellare",
    "puntellerai": "puntellare",
    "puntelleran": "puntellare",
    "puntelleranno": "puntellare",
    "puntellerebbe": "puntellare",
    "puntellerebber": "puntellare",
    "puntellerebbero": "puntellare",
    "puntellerei": "puntellare",
    "puntelleremmo": "puntellare",
    "puntelleremo": "puntellare",
    "puntellereste": "puntellare",
    "puntelleresti": "puntellare",
    "puntellerete": "puntellare",
    "puntellerà": "puntellare",
    "puntellerò": "puntellare",
    "puntelli": "puntello",
    "puntelliamo": "puntellare",
    "puntelliate": "puntellare",
    "puntellin": "puntellare",
    "puntellino": "puntellare",
    "puntello": "puntellare",
    "puntellò": "puntellare",
    "punterai": "puntare",
    "punteran": "puntare",
    "punteranno": "puntare",
    "punterebbe": "puntare",
    "punterebber": "puntare",
    "punterebbero": "puntare",
    "punterei": "puntare",
    "punteremmo": "puntare",
    "punteremo": "puntare",
    "puntereste": "puntare",
    "punteresti": "puntare",
    "punterete": "puntare",
    "punteruoli": "punteruolo",
    "punterà": "puntare",
    "punterò": "puntare",
    "punti": "punto",
    "punti-chiave": "punto-chiave",
    "puntiamo": "puntare",
    "puntiate": "puntare",
    "punticini": "punticino",
    "puntigli": "puntiglio",
    "puntigliosa": "puntiglioso",
    "puntigliose": "puntiglioso",
    "puntigliosi": "puntiglioso",
    "puntin": "puntare",
    "puntine": "puntina",
    "puntini": "puntino",
    "puntino": "puntare",
    "punto": "puntare",
    "puntolini": "puntolino",
    "puntuali": "puntuale",
    "puntualizza": "puntualizzare",
    "puntualizzai": "puntualizzare",
    "puntualizzammo": "puntualizzare",
    "puntualizzan": "puntualizzare",
    "puntualizzando": "puntualizzare",
    "puntualizzano": "puntualizzare",
    "puntualizzante": "puntualizzare",
    "puntualizzanti": "puntualizzare",
    "puntualizzar": "puntualizzare",
    "puntualizzaron": "puntualizzare",
    "puntualizzarono": "puntualizzare",
    "puntualizzasse": "puntualizzare",
    "puntualizzasser": "puntualizzare",
    "puntualizzassero": "puntualizzare",
    "puntualizzassi": "puntualizzare",
    "puntualizzassimo": "puntualizzare",
    "puntualizzaste": "puntualizzare",
    "puntualizzasti": "puntualizzare",
    "puntualizzata": "puntualizzare",
    "puntualizzate": "puntualizzare",
    "puntualizzati": "puntualizzare",
    "puntualizzato": "puntualizzare",
    "puntualizzava": "puntualizzare",
    "puntualizzavamo": "puntualizzare",
    "puntualizzavan": "puntualizzare",
    "puntualizzavano": "puntualizzare",
    "puntualizzavate": "puntualizzare",
    "puntualizzavi": "puntualizzare",
    "puntualizzavo": "puntualizzare",
    "puntualizzazioni": "puntualizzazione",
    "puntualizzerai": "puntualizzare",
    "puntualizzeran": "puntualizzare",
    "puntualizzeranno": "puntualizzare",
    "puntualizzerebbe": "puntualizzare",
    "puntualizzerebber": "puntualizzare",
    "puntualizzerebbero": "puntualizzare",
    "puntualizzerei": "puntualizzare",
    "puntualizzeremmo": "puntualizzare",
    "puntualizzeremo": "puntualizzare",
    "puntualizzereste": "puntualizzare",
    "puntualizzeresti": "puntualizzare",
    "puntualizzerete": "puntualizzare",
    "puntualizzerà": "puntualizzare",
    "puntualizzerò": "puntualizzare",
    "puntualizzi": "puntualizzare",
    "puntualizziamo": "puntualizzare",
    "puntualizziate": "puntualizzare",
    "puntualizzin": "puntualizzare",
    "puntualizzino": "puntualizzare",
    "puntualizzo": "puntualizzare",
    "puntualizzò": "puntualizzare",
    "punture": "puntura",
    "puntuta": "puntuto",
    "puntute": "puntuto",
    "puntuti": "puntuto",
    "puntò": "puntare",
    "punzecchi": "punzecchiare",
    "punzecchia": "punzecchiare",
    "punzecchiai": "punzecchiare",
    "punzecchiammo": "punzecchiare",
    "punzecchiamo": "punzecchiare",
    "punzecchian": "punzecchiare",
    "punzecchiando": "punzecchiare",
    "punzecchiano": "punzecchiare",
    "punzecchiante": "punzecchiare",
    "punzecchianti": "punzecchiare",
    "punzecchiar": "punzecchiare",
    "punzecchiaron": "punzecchiare",
    "punzecchiarono": "punzecchiare",
    "punzecchiasse": "punzecchiare",
    "punzecchiasser": "punzecchiare",
    "punzecchiassero": "punzecchiare",
    "punzecchiassi": "punzecchiare",
    "punzecchiassimo": "punzecchiare",
    "punzecchiaste": "punzecchiare",
    "punzecchiasti": "punzecchiare",
    "punzecchiata": "punzecchiare",
    "punzecchiate": "punzecchiare",
    "punzecchiati": "punzecchiare",
    "punzecchiato": "punzecchiare",
    "punzecchiature": "punzecchiatura",
    "punzecchiava": "punzecchiare",
    "punzecchiavamo": "punzecchiare",
    "punzecchiavan": "punzecchiare",
    "punzecchiavano": "punzecchiare",
    "punzecchiavate": "punzecchiare",
    "punzecchiavi": "punzecchiare",
    "punzecchiavo": "punzecchiare",
    "punzecchierai": "punzecchiare",
    "punzecchieran": "punzecchiare",
    "punzecchieranno": "punzecchiare",
    "punzecchierebbe": "punzecchiare",
    "punzecchierebber": "punzecchiare",
    "punzecchierebbero": "punzecchiare",
    "punzecchierei": "punzecchiare",
    "punzecchieremmo": "punzecchiare",
    "punzecchieremo": "punzecchiare",
    "punzecchiereste": "punzecchiare",
    "punzecchieresti": "punzecchiare",
    "punzecchierete": "punzecchiare",
    "punzecchierà": "punzecchiare",
    "punzecchierò": "punzecchiare",
    "punzecchin": "punzecchiare",
    "punzecchino": "punzecchiare",
    "punzecchio": "punzecchiare",
    "punzecchiò": "punzecchiare",
    "punzona": "punzonare",
    "punzonai": "punzonare",
    "punzonammo": "punzonare",
    "punzonan": "punzonare",
    "punzonando": "punzonare",
    "punzonano": "punzonare",
    "punzonante": "punzonare",
    "punzonanti": "punzonare",
    "punzonar": "punzonare",
    "punzonaron": "punzonare",
    "punzonarono": "punzonare",
    "punzonasse": "punzonare",
    "punzonasser": "punzonare",
    "punzonassero": "punzonare",
    "punzonassi": "punzonare",
    "punzonassimo": "punzonare",
    "punzonaste": "punzonare",
    "punzonasti": "punzonare",
    "punzonata": "punzonare",
    "punzonate": "punzonare",
    "punzonati": "punzonare",
    "punzonato": "punzonare",
    "punzonava": "punzonare",
    "punzonavamo": "punzonare",
    "punzonavan": "punzonare",
    "punzonavano": "punzonare",
    "punzonavate": "punzonare",
    "punzonavi": "punzonare",
    "punzonavo": "punzonare",
    "punzonerai": "punzonare",
    "punzoneran": "punzonare",
    "punzoneranno": "punzonare",
    "punzonerebbe": "punzonare",
    "punzonerebber": "punzonare",
    "punzonerebbero": "punzonare",
    "punzonerei": "punzonare",
    "punzoneremmo": "punzonare",
    "punzoneremo": "punzonare",
    "punzonereste": "punzonare",
    "punzoneresti": "punzonare",
    "punzonerete": "punzonare",
    "punzonerà": "punzonare",
    "punzonerò": "punzonare",
    "punzoni": "punzone",
    "punzoniamo": "punzonare",
    "punzoniate": "punzonare",
    "punzonin": "punzonare",
    "punzonino": "punzonare",
    "punzono": "punzonare",
    "punzonò": "punzonare",
    "punì": "punire",
    "puoi": "potere",
    "pupari": "puparo",
    "pupazzetti": "pupazzetto",
    "pupazzi": "pupazzo",
    "pupazzoni": "pupazzone",
    "pupe": "pupa",
    "pupi": "pupo",
    "pupille": "pupilla",
    "pupilli": "pupillo",
    "pura": "puro",
    "pure": "puro",
    "purezze": "purezza",
    "purga": "purgare",
    "purgai": "purgare",
    "purgammo": "purgare",
    "purgan": "purgare",
    "purgando": "purgare",
    "purgano": "purgare",
    "purgante": "purgare",
    "purganti": "purgare",
    "purgar": "purgare",
    "purgaron": "purgare",
    "purgarono": "purgare",
    "purgasse": "purgare",
    "purgasser": "purgare",
    "purgassero": "purgare",
    "purgassi": "purgare",
    "purgassimo": "purgare",
    "purgaste": "purgare",
    "purgasti": "purgare",
    "purgata": "purgare",
    "purgate": "purgare",
    "purgati": "purgare",
    "purgato": "purgare",
    "purgatori": "purgatorio",
    "purgava": "purgare",
    "purgavamo": "purgare",
    "purgavan": "purgare",
    "purgavano": "purgare",
    "purgavate": "purgare",
    "purgavi": "purgare",
    "purgavo": "purgare",
    "purghe": "purga",
    "purgherai": "purgare",
    "purgheran": "purgare",
    "purgheranno": "purgare",
    "purgherebbe": "purgare",
    "purgherebber": "purgare",
    "purgherebbero": "purgare",
    "purgherei": "purgare",
    "purgheremmo": "purgare",
    "purgheremo": "purgare",
    "purghereste": "purgare",
    "purgheresti": "purgare",
    "purgherete": "purgare",
    "purgherà": "purgare",
    "purgherò": "purgare",
    "purghi": "purgare",
    "purghiamo": "purgare",
    "purghiate": "purgare",
    "purghin": "purgare",
    "purghino": "purgare",
    "purgo": "purgare",
    "purgò": "purgare",
    "puri": "puro",
    "purifica": "purificare",
    "purificai": "purificare",
    "purificammo": "purificare",
    "purifican": "purificare",
    "purificando": "purificare",
    "purificano": "purificare",
    "purificante": "purificare",
    "purificanti": "purificare",
    "purificar": "purificare",
    "purificaron": "purificare",
    "purificarono": "purificare",
    "purificasse": "purificare",
    "purificasser": "purificare",
    "purificassero": "purificare",
    "purificassi": "purificare",
    "purificassimo": "purificare",
    "purificaste": "purificare",
    "purificasti": "purificare",
    "purificata": "purificare",
    "purificate": "purificare",
    "purificati": "purificare",
    "purificato": "purificare",
    "purificatori": "purificatorio",
    "purificatoria": "purificatorio",
    "purificatorie": "purificatorio",
    "purificatrice": "purificatore",
    "purificatrici": "purificatore",
    "purificava": "purificare",
    "purificavamo": "purificare",
    "purificavan": "purificare",
    "purificavano": "purificare",
    "purificavate": "purificare",
    "purificavi": "purificare",
    "purificavo": "purificare",
    "purificazioni": "purificazione",
    "purificherai": "purificare",
    "purificheran": "purificare",
    "purificheranno": "purificare",
    "purificherebbe": "purificare",
    "purificherebber": "purificare",
    "purificherebbero": "purificare",
    "purificherei": "purificare",
    "purificheremmo": "purificare",
    "purificheremo": "purificare",
    "purifichereste": "purificare",
    "purificheresti": "purificare",
    "purificherete": "purificare",
    "purificherà": "purificare",
    "purificherò": "purificare",
    "purifichi": "purificare",
    "purifichiamo": "purificare",
    "purifichiate": "purificare",
    "purifichin": "purificare",
    "purifichino": "purificare",
    "purifico": "purificare",
    "purificò": "purificare",
    "purismi": "purismo",
    "puristi": "purista",
    "puritana": "puritano",
    "puritane": "puritano",
    "puritanesimi": "puritanesimo",
    "puritani": "puritano",
    "purosangui": "purosangue",
    "purulenta": "purulento",
    "purulente": "purulento",
    "purulenti": "purulento",
    "pusillanimi": "pusillanime",
    "pustole": "pustola",
    "puta": "putire",
    "putan": "putire",
    "putano": "putire",
    "putativa": "putativo",
    "putative": "putativo",
    "putativi": "putativo",
    "pute": "putire",
    "putendo": "putire",
    "putente": "putire",
    "putenti": "putire",
    "puti": "putire",
    "putiamo": "putire",
    "putiate": "putire",
    "putiferi": "putiferio",
    "putii": "putire",
    "putimmo": "putire",
    "putir": "putire",
    "putirai": "putire",
    "putiran": "putire",
    "putiranno": "putire",
    "putirebbe": "putire",
    "putirebber": "putire",
    "putirebbero": "putire",
    "putirei": "putire",
    "putiremmo": "putire",
    "putiremo": "putire",
    "putireste": "putire",
    "putiresti": "putire",
    "putirete": "putire",
    "putiron": "putire",
    "putirono": "putire",
    "putirà": "putire",
    "putirò": "putire",
    "putisse": "putire",
    "putisser": "putire",
    "putissero": "putire",
    "putissi": "putire",
    "putissimo": "putire",
    "putiste": "putire",
    "putisti": "putire",
    "putita": "putire",
    "putite": "putire",
    "putiti": "putire",
    "putito": "putire",
    "putiva": "putire",
    "putivamo": "putire",
    "putivan": "putire",
    "putivano": "putire",
    "putivate": "putire",
    "putivi": "putire",
    "putivo": "putire",
    "puto": "putire",
    "puton": "putire",
    "putono": "putire",
    "putrefa": "putrefare",
    "putrefa'": "putrefare",
    "putrefaccia": "putrefare",
    "putrefacciamo": "putrefare",
    "putrefaccian": "putrefare",
    "putrefacciano": "putrefare",
    "putrefacciate": "putrefare",
    "putrefaccio": "putrefare",
    "putrefacemmo": "putrefare",
    "putrefacendo": "putrefare",
    "putrefacente": "putrefare",
    "putrefacenti": "putrefare",
    "putrefacesse": "putrefare",
    "putrefacesser": "putrefare",
    "putrefacessero": "putrefare",
    "putrefacessi": "putrefare",
    "putrefacessimo": "putrefare",
    "putrefaceste": "putrefare",
    "putrefacesti": "putrefare",
    "putrefaceva": "putrefare",
    "putrefacevamo": "putrefare",
    "putrefacevan": "putrefare",
    "putrefacevano": "putrefare",
    "putrefacevate": "putrefare",
    "putrefacevi": "putrefare",
    "putrefacevo": "putrefare",
    "putrefai": "putrefare",
    "putrefan": "putrefare",
    "putrefanno": "putrefare",
    "putrefar": "putrefare",
    "putrefarai": "putrefare",
    "putrefaran": "putrefare",
    "putrefaranno": "putrefare",
    "putrefarebbe": "putrefare",
    "putrefarebber": "putrefare",
    "putrefarebbero": "putrefare",
    "putrefarei": "putrefare",
    "putrefaremmo": "putrefare",
    "putrefaremo": "putrefare",
    "putrefareste": "putrefare",
    "putrefaresti": "putrefare",
    "putrefarete": "putrefare",
    "putrefarà": "putrefare",
    "putrefarò": "putrefare",
    "putrefate": "putrefare",
    "putrefatta": "putrefare",
    "putrefatte": "putrefare",
    "putrefatti": "putrefare",
    "putrefatto": "putrefare",
    "putrefazioni": "putrefazione",
    "putrefece": "putrefare",
    "putrefecer": "putrefare",
    "putrefecero": "putrefare",
    "putrefeci": "putrefare",
    "putrelle": "putrella",
    "putrida": "putrido",
    "putride": "putrido",
    "putridi": "putrido",
    "puttanate": "puttanata",
    "puttane": "puttana",
    "puttanelle": "puttanella",
    "puttanone": "puttanona",
    "putti": "putto",
    "puttini": "puttino",
    "putì": "putire",
    "puzza": "puzzare",
    "puzzai": "puzzare",
    "puzzammo": "puzzare",
    "puzzan": "puzzare",
    "puzzando": "puzzare",
    "puzzano": "puzzare",
    "puzzante": "puzzare",
    "puzzanti": "puzzare",
    "puzzar": "puzzare",
    "puzzaron": "puzzare",
    "puzzarono": "puzzare",
    "puzzasse": "puzzare",
    "puzzasser": "puzzare",
    "puzzassero": "puzzare",
    "puzzassi": "puzzare",
    "puzzassimo": "puzzare",
    "puzzaste": "puzzare",
    "puzzasti": "puzzare",
    "puzzata": "puzzare",
    "puzzate": "puzzare",
    "puzzati": "puzzare",
    "puzzato": "puzzare",
    "puzzava": "puzzare",
    "puzzavamo": "puzzare",
    "puzzavan": "puzzare",
    "puzzavano": "puzzare",
    "puzzavate": "puzzare",
    "puzzavi": "puzzare",
    "puzzavo": "puzzare",
    "puzze": "puzza",
    "puzzerai": "puzzare",
    "puzzeran": "puzzare",
    "puzzeranno": "puzzare",
    "puzzerebbe": "puzzare",
    "puzzerebber": "puzzare",
    "puzzerebbero": "puzzare",
    "puzzerei": "puzzare",
    "puzzeremmo": "puzzare",
    "puzzeremo": "puzzare",
    "puzzereste": "puzzare",
    "puzzeresti": "puzzare",
    "puzzerete": "puzzare",
    "puzzerà": "puzzare",
    "puzzerò": "puzzare",
    "puzzi": "puzzare",
    "puzziamo": "puzzare",
    "puzziate": "puzzare",
    "puzzin": "puzzare",
    "puzzino": "puzzare",
    "puzzo": "puzzare",
    "puzzolenti": "puzzolente",
    "puzzò": "puzzare",
    "può": "potere",
    "pò": "po'",
    "quaccheri": "quacchero",
    "quadernetti": "quadernetto",
    "quaderni": "quaderno",
    "quadra": "quadro",
    "quadrai": "quadrare",
    "quadrammo": "quadrare",
    "quadran": "quadrare",
    "quadrando": "quadrare",
    "quadrangolari": "quadrangolare",
    "quadrano": "quadrare",
    "quadrante": "quadrare",
    "quadranti": "quadrare",
    "quadrar": "quadrare",
    "quadraron": "quadrare",
    "quadrarono": "quadrare",
    "quadrasse": "quadrare",
    "quadrasser": "quadrare",
    "quadrassero": "quadrare",
    "quadrassi": "quadrare",
    "quadrassimo": "quadrare",
    "quadraste": "quadrare",
    "quadrasti": "quadrare",
    "quadrata": "quadrato",
    "quadrate": "quadrato",
    "quadrati": "quadrato",
    "quadratini": "quadratino",
    "quadrato": "quadrare",
    "quadrature": "quadratura",
    "quadrava": "quadrare",
    "quadravamo": "quadrare",
    "quadravan": "quadrare",
    "quadravano": "quadrare",
    "quadravate": "quadrare",
    "quadravi": "quadrare",
    "quadravo": "quadrare",
    "quadre": "quadro",
    "quadrerai": "quadrare",
    "quadreran": "quadrare",
    "quadreranno": "quadrare",
    "quadrerebbe": "quadrare",
    "quadrerebber": "quadrare",
    "quadrerebbero": "quadrare",
    "quadrerei": "quadrare",
    "quadreremmo": "quadrare",
    "quadreremo": "quadrare",
    "quadrereste": "quadrare",
    "quadreresti": "quadrare",
    "quadrerete": "quadrare",
    "quadrerie": "quadreria",
    "quadrerà": "quadrare",
    "quadrerò": "quadrare",
    "quadretta": "quadrettare",
    "quadrettai": "quadrettare",
    "quadrettammo": "quadrettare",
    "quadrettan": "quadrettare",
    "quadrettando": "quadrettare",
    "quadrettano": "quadrettare",
    "quadrettante": "quadrettare",
    "quadrettanti": "quadrettare",
    "quadrettar": "quadrettare",
    "quadrettaron": "quadrettare",
    "quadrettarono": "quadrettare",
    "quadrettasse": "quadrettare",
    "quadrettasser": "quadrettare",
    "quadrettassero": "quadrettare",
    "quadrettassi": "quadrettare",
    "quadrettassimo": "quadrettare",
    "quadrettaste": "quadrettare",
    "quadrettasti": "quadrettare",
    "quadrettata": "quadrettato",
    "quadrettate": "quadrettato",
    "quadrettati": "quadrettato",
    "quadrettato": "quadrettare",
    "quadrettava": "quadrettare",
    "quadrettavamo": "quadrettare",
    "quadrettavan": "quadrettare",
    "quadrettavano": "quadrettare",
    "quadrettavate": "quadrettare",
    "quadrettavi": "quadrettare",
    "quadrettavo": "quadrettare",
    "quadretterai": "quadrettare",
    "quadretteran": "quadrettare",
    "quadretteranno": "quadrettare",
    "quadretterebbe": "quadrettare",
    "quadretterebber": "quadrettare",
    "quadretterebbero": "quadrettare",
    "quadretterei": "quadrettare",
    "quadretteremmo": "quadrettare",
    "quadretteremo": "quadrettare",
    "quadrettereste": "quadrettare",
    "quadretteresti": "quadrettare",
    "quadretterete": "quadrettare",
    "quadretterà": "quadrettare",
    "quadretterò": "quadrettare",
    "quadretti": "quadretto",
    "quadrettiamo": "quadrettare",
    "quadrettiate": "quadrettare",
    "quadrettin": "quadrettare",
    "quadrettino": "quadrettare",
    "quadretto": "quadrettare",
    "quadrettò": "quadrettare",
    "quadri": "quadro",
    "quadriamo": "quadrare",
    "quadriate": "quadrare",
    "quadricicli": "quadriciclo",
    "quadricipiti": "quadricipite",
    "quadriennali": "quadriennale",
    "quadriennii": "quadriennio",
    "quadriglie": "quadriglia",
    "quadrilateri": "quadrilatero",
    "quadrimestrali": "quadrimestrale",
    "quadrimotori": "quadrimotore",
    "quadrin": "quadrare",
    "quadrino": "quadrare",
    "quadriparta": "quadripartire",
    "quadripartan": "quadripartire",
    "quadripartano": "quadripartire",
    "quadriparte": "quadripartire",
    "quadripartendo": "quadripartire",
    "quadripartente": "quadripartire",
    "quadripartenti": "quadripartire",
    "quadriparti": "quadripartire",
    "quadripartiamo": "quadripartire",
    "quadripartiate": "quadripartire",
    "quadripartii": "quadripartire",
    "quadripartimmo": "quadripartire",
    "quadripartir": "quadripartire",
    "quadripartirai": "quadripartire",
    "quadripartiran": "quadripartire",
    "quadripartiranno": "quadripartire",
    "quadripartirebbe": "quadripartire",
    "quadripartirebber": "quadripartire",
    "quadripartirebbero": "quadripartire",
    "quadripartirei": "quadripartire",
    "quadripartiremmo": "quadripartire",
    "quadripartiremo": "quadripartire",
    "quadripartireste": "quadripartire",
    "quadripartiresti": "quadripartire",
    "quadripartirete": "quadripartire",
    "quadripartiron": "quadripartire",
    "quadripartirono": "quadripartire",
    "quadripartirà": "quadripartire",
    "quadripartirò": "quadripartire",
    "quadripartisse": "quadripartire",
    "quadripartisser": "quadripartire",
    "quadripartissero": "quadripartire",
    "quadripartissi": "quadripartire",
    "quadripartissimo": "quadripartire",
    "quadripartiste": "quadripartire",
    "quadripartisti": "quadripartire",
    "quadripartita": "quadripartito",
    "quadripartite": "quadripartito",
    "quadripartiti": "quadripartito",
    "quadripartito": "quadripartire",
    "quadripartiva": "quadripartire",
    "quadripartivamo": "quadripartire",
    "quadripartivan": "quadripartire",
    "quadripartivano": "quadripartire",
    "quadripartivate": "quadripartire",
    "quadripartivi": "quadripartire",
    "quadripartivo": "quadripartire",
    "quadriparto": "quadripartire",
    "quadriparton": "quadripartire",
    "quadripartono": "quadripartire",
    "quadripartì": "quadripartire",
    "quadro": "quadrare",
    "quadrumviri": "quadrumviro",
    "quadrupedi": "quadrupede",
    "quadrupla": "quadruplo",
    "quadruple": "quadruplo",
    "quadrupli": "quadruplo",
    "quadruplica": "quadruplicare",
    "quadruplicai": "quadruplicare",
    "quadruplicamenti": "quadruplicamento",
    "quadruplicammo": "quadruplicare",
    "quadruplican": "quadruplicare",
    "quadruplicando": "quadruplicare",
    "quadruplicano": "quadruplicare",
    "quadruplicante": "quadruplicare",
    "quadruplicanti": "quadruplicare",
    "quadruplicar": "quadruplicare",
    "quadruplicaron": "quadruplicare",
    "quadruplicarono": "quadruplicare",
    "quadruplicasse": "quadruplicare",
    "quadruplicasser": "quadruplicare",
    "quadruplicassero": "quadruplicare",
    "quadruplicassi": "quadruplicare",
    "quadruplicassimo": "quadruplicare",
    "quadruplicaste": "quadruplicare",
    "quadruplicasti": "quadruplicare",
    "quadruplicata": "quadruplicare",
    "quadruplicate": "quadruplicare",
    "quadruplicati": "quadruplicare",
    "quadruplicato": "quadruplicare",
    "quadruplicava": "quadruplicare",
    "quadruplicavamo": "quadruplicare",
    "quadruplicavan": "quadruplicare",
    "quadruplicavano": "quadruplicare",
    "quadruplicavate": "quadruplicare",
    "quadruplicavi": "quadruplicare",
    "quadruplicavo": "quadruplicare",
    "quadruplicherai": "quadruplicare",
    "quadruplicheran": "quadruplicare",
    "quadruplicheranno": "quadruplicare",
    "quadruplicherebbe": "quadruplicare",
    "quadruplicherebber": "quadruplicare",
    "quadruplicherebbero": "quadruplicare",
    "quadruplicherei": "quadruplicare",
    "quadruplicheremmo": "quadruplicare",
    "quadruplicheremo": "quadruplicare",
    "quadruplichereste": "quadruplicare",
    "quadruplicheresti": "quadruplicare",
    "quadruplicherete": "quadruplicare",
    "quadruplicherà": "quadruplicare",
    "quadruplicherò": "quadruplicare",
    "quadruplichi": "quadruplicare",
    "quadruplichiamo": "quadruplicare",
    "quadruplichiate": "quadruplicare",
    "quadruplichin": "quadruplicare",
    "quadruplichino": "quadruplicare",
    "quadruplici": "quadruplice",
    "quadruplico": "quadruplicare",
    "quadruplicò": "quadruplicare",
    "quadrò": "quadrare",
    "quaglie": "quaglia",
    "quali": "quale",
    "qualifica": "qualificare",
    "qualificai": "qualificare",
    "qualificammo": "qualificare",
    "qualifican": "qualificare",
    "qualificando": "qualificare",
    "qualificano": "qualificare",
    "qualificante": "qualificare",
    "qualificanti": "qualificare",
    "qualificar": "qualificare",
    "qualificaron": "qualificare",
    "qualificarono": "qualificare",
    "qualificasse": "qualificare",
    "qualificasser": "qualificare",
    "qualificassero": "qualificare",
    "qualificassi": "qualificare",
    "qualificassimo": "qualificare",
    "qualificaste": "qualificare",
    "qualificasti": "qualificare",
    "qualificata": "qualificato",
    "qualificate": "qualificato",
    "qualificati": "qualificato",
    "qualificato": "qualificare",
    "qualificava": "qualificare",
    "qualificavamo": "qualificare",
    "qualificavan": "qualificare",
    "qualificavano": "qualificare",
    "qualificavate": "qualificare",
    "qualificavi": "qualificare",
    "qualificavo": "qualificare",
    "qualificazioni": "qualificazione",
    "qualifiche": "qualifica",
    "qualificherai": "qualificare",
    "qualificheran": "qualificare",
    "qualificheranno": "qualificare",
    "qualificherebbe": "qualificare",
    "qualificherebber": "qualificare",
    "qualificherebbero": "qualificare",
    "qualificherei": "qualificare",
    "qualificheremmo": "qualificare",
    "qualificheremo": "qualificare",
    "qualifichereste": "qualificare",
    "qualificheresti": "qualificare",
    "qualificherete": "qualificare",
    "qualificherà": "qualificare",
    "qualificherò": "qualificare",
    "qualifichi": "qualificare",
    "qualifichiamo": "qualificare",
    "qualifichiate": "qualificare",
    "qualifichin": "qualificare",
    "qualifichino": "qualificare",
    "qualifico": "qualificare",
    "qualificò": "qualificare",
    "qualitativa": "qualitativo",
    "qualitative": "qualitativo",
    "qualitativi": "qualitativo",
    "qualunquismi": "qualunquismo",
    "qualunquiste": "qualunquista",
    "qualunquisti": "qualunquista",
    "qualunquistica": "qualunquistico",
    "qualunquistiche": "qualunquistico",
    "qualunquistici": "qualunquistico",
    "quanta": "quanto",
    "quante": "quanto",
    "quanti": "quanto",
    "quantica": "quantico",
    "quantiche": "quantico",
    "quantici": "quantico",
    "quantifica": "quantificare",
    "quantificabili": "quantificabile",
    "quantificai": "quantificare",
    "quantificammo": "quantificare",
    "quantifican": "quantificare",
    "quantificando": "quantificare",
    "quantificano": "quantificare",
    "quantificante": "quantificare",
    "quantificanti": "quantificare",
    "quantificar": "quantificare",
    "quantificaron": "quantificare",
    "quantificarono": "quantificare",
    "quantificasse": "quantificare",
    "quantificasser": "quantificare",
    "quantificassero": "quantificare",
    "quantificassi": "quantificare",
    "quantificassimo": "quantificare",
    "quantificaste": "quantificare",
    "quantificasti": "quantificare",
    "quantificata": "quantificare",
    "quantificate": "quantificare",
    "quantificati": "quantificare",
    "quantificato": "quantificare",
    "quantificava": "quantificare",
    "quantificavamo": "quantificare",
    "quantificavan": "quantificare",
    "quantificavano": "quantificare",
    "quantificavate": "quantificare",
    "quantificavi": "quantificare",
    "quantificavo": "quantificare",
    "quantificazioni": "quantificazione",
    "quantificherai": "quantificare",
    "quantificheran": "quantificare",
    "quantificheranno": "quantificare",
    "quantificherebbe": "quantificare",
    "quantificherebber": "quantificare",
    "quantificherebbero": "quantificare",
    "quantificherei": "quantificare",
    "quantificheremmo": "quantificare",
    "quantificheremo": "quantificare",
    "quantifichereste": "quantificare",
    "quantificheresti": "quantificare",
    "quantificherete": "quantificare",
    "quantificherà": "quantificare",
    "quantificherò": "quantificare",
    "quantifichi": "quantificare",
    "quantifichiamo": "quantificare",
    "quantifichiate": "quantificare",
    "quantifichin": "quantificare",
    "quantifichino": "quantificare",
    "quantifico": "quantificare",
    "quantificò": "quantificare",
    "quantitativa": "quantitativo",
    "quantitative": "quantitativo",
    "quantitativi": "quantitativo",
    "quantizza": "quantizzare",
    "quantizzai": "quantizzare",
    "quantizzammo": "quantizzare",
    "quantizzan": "quantizzare",
    "quantizzando": "quantizzare",
    "quantizzano": "quantizzare",
    "quantizzante": "quantizzare",
    "quantizzanti": "quantizzare",
    "quantizzar": "quantizzare",
    "quantizzaron": "quantizzare",
    "quantizzarono": "quantizzare",
    "quantizzasse": "quantizzare",
    "quantizzasser": "quantizzare",
    "quantizzassero": "quantizzare",
    "quantizzassi": "quantizzare",
    "quantizzassimo": "quantizzare",
    "quantizzaste": "quantizzare",
    "quantizzasti": "quantizzare",
    "quantizzata": "quantizzare",
    "quantizzate": "quantizzare",
    "quantizzati": "quantizzare",
    "quantizzato": "quantizzare",
    "quantizzava": "quantizzare",
    "quantizzavamo": "quantizzare",
    "quantizzavan": "quantizzare",
    "quantizzavano": "quantizzare",
    "quantizzavate": "quantizzare",
    "quantizzavi": "quantizzare",
    "quantizzavo": "quantizzare",
    "quantizzerai": "quantizzare",
    "quantizzeran": "quantizzare",
    "quantizzeranno": "quantizzare",
    "quantizzerebbe": "quantizzare",
    "quantizzerebber": "quantizzare",
    "quantizzerebbero": "quantizzare",
    "quantizzerei": "quantizzare",
    "quantizzeremmo": "quantizzare",
    "quantizzeremo": "quantizzare",
    "quantizzereste": "quantizzare",
    "quantizzeresti": "quantizzare",
    "quantizzerete": "quantizzare",
    "quantizzerà": "quantizzare",
    "quantizzerò": "quantizzare",
    "quantizzi": "quantizzare",
    "quantizziamo": "quantizzare",
    "quantizziate": "quantizzare",
    "quantizzin": "quantizzare",
    "quantizzino": "quantizzare",
    "quantizzo": "quantizzare",
    "quantizzò": "quantizzare",
    "quarantacinquesima": "quarantacinquesimo",
    "quarantacinquesime": "quarantacinquesimo",
    "quarantacinquesimi": "quarantacinquesimo",
    "quarantaduesima": "quarantaduesimo",
    "quarantaduesime": "quarantaduesimo",
    "quarantaduesimi": "quarantaduesimo",
    "quarantanovesima": "quarantanovesimo",
    "quarantanovesime": "quarantanovesimo",
    "quarantanovesimi": "quarantanovesimo",
    "quarantaquattresima": "quarantaquattresimo",
    "quarantaquattresime": "quarantaquattresimo",
    "quarantaquattresimi": "quarantaquattresimo",
    "quarantaseiesima": "quarantaseiesimo",
    "quarantaseiesime": "quarantaseiesimo",
    "quarantaseiesimi": "quarantaseiesimo",
    "quarantasettesima": "quarantasettesimo",
    "quarantasettesime": "quarantasettesimo",
    "quarantasettesimi": "quarantasettesimo",
    "quarantatreesima": "quarantatreesimo",
    "quarantatreesime": "quarantatreesimo",
    "quarantatreesimi": "quarantatreesimo",
    "quarantene": "quarantena",
    "quarantennali": "quarantennale",
    "quarantenni": "quarantennio",
    "quarantesima": "quarantesimo",
    "quarantesime": "quarantesimo",
    "quarantesimi": "quarantesimo",
    "quarantine": "quarantina",
    "quarantottesima": "quarantottesimo",
    "quarantottesime": "quarantottesimo",
    "quarantottesimi": "quarantottesimo",
    "quarantunesima": "quarantunesimo",
    "quarantunesime": "quarantunesimo",
    "quarantunesimi": "quarantunesimo",
    "quaresimali": "quaresimale",
    "quarta": "quarto",
    "quarte": "quarto",
    "quartetti": "quartetto",
    "quarti": "quarto",
    "quartier": "quartiere",
    "quartieri": "quartiere",
    "quartine": "quartina",
    "quarzi": "quarzo",
    "quatta": "quatto",
    "quatte": "quatto",
    "quatti": "quatto",
    "quattordicenni": "quattordicenne",
    "quattordicesima": "quattordicesimo",
    "quattordicesime": "quattordicesimo",
    "quattordicesimi": "quattordicesimo",
    "quattrini": "quattrino",
    "quattrocentesca": "quattrocentesco",
    "quattrocentesche": "quattrocentesco",
    "quattrocenteschi": "quattrocentesco",
    "quattrocentesima": "quattrocentesimo",
    "quattrocentesime": "quattrocentesimo",
    "quattrocentesimi": "quattrocentesimo",
    "quattrocentisti": "quattrocentista",
    "quattrocentocinquantesima": "quattrocentocinquantesimo",
    "quattrocentocinquantesime": "quattrocentocinquantesimo",
    "quattrocentocinquantesimi": "quattrocentocinquantesimo",
    "quattrocentodecima": "quattrocentodecimo",
    "quattrocentodecime": "quattrocentodecimo",
    "quattrocentodecimi": "quattrocentodecimo",
    "quattrocentonovantesima": "quattrocentonovantesimo",
    "quattrocentonovantesime": "quattrocentonovantesimo",
    "quattrocentonovantesimi": "quattrocentonovantesimo",
    "quattrocentoquarantesima": "quattrocentoquarantesimo",
    "quattrocentoquarantesime": "quattrocentoquarantesimo",
    "quattrocentoquarantesimi": "quattrocentoquarantesimo",
    "quattrocentosessantesima": "quattrocentosessantesimo",
    "quattrocentosessantesime": "quattrocentosessantesimo",
    "quattrocentosessantesimi": "quattrocentosessantesimo",
    "quattrocentosettantesima": "quattrocentosettantesimo",
    "quattrocentosettantesime": "quattrocentosettantesimo",
    "quattrocentosettantesimi": "quattrocentosettantesimo",
    "quattrocentotrentesima": "quattrocentotrentesimo",
    "quattrocentotrentesime": "quattrocentotrentesimo",
    "quattrocentotrentesimi": "quattrocentotrentesimo",
    "quattrocentottantesima": "quattrocentottantesimo",
    "quattrocentottantesime": "quattrocentottantesimo",
    "quattrocentottantesimi": "quattrocentottantesimo",
    "quattrocentoventesima": "quattrocentoventesimo",
    "quattrocentoventesime": "quattrocentoventesimo",
    "quattrocentoventesimi": "quattrocentoventesimo",
    "quattromillesima": "quattromillesimo",
    "quattromillesime": "quattromillesimo",
    "quattromillesimi": "quattromillesimo",
    "quegli": "quello",
    "quei": "quello",
    "quel": "quello",
    "quell'": "quello",
    "quella": "quello",
    "quelle": "quello",
    "quelli": "quello",
    "querce": "quercia",
    "quercina": "quercino",
    "quercine": "quercino",
    "quercini": "quercino",
    "querela": "querelare",
    "querelai": "querelare",
    "querelammo": "querelare",
    "querelan": "querelare",
    "querelando": "querelare",
    "querelano": "querelare",
    "querelante": "querelare",
    "querelanti": "querelare",
    "querelar": "querelare",
    "querelaron": "querelare",
    "querelarono": "querelare",
    "querelasse": "querelare",
    "querelasser": "querelare",
    "querelassero": "querelare",
    "querelassi": "querelare",
    "querelassimo": "querelare",
    "querelaste": "querelare",
    "querelasti": "querelare",
    "querelata": "querelare",
    "querelate": "querelare",
    "querelati": "querelare",
    "querelato": "querelare",
    "querelava": "querelare",
    "querelavamo": "querelare",
    "querelavan": "querelare",
    "querelavano": "querelare",
    "querelavate": "querelare",
    "querelavi": "querelare",
    "querelavo": "querelare",
    "querele": "querela",
    "querelerai": "querelare",
    "quereleran": "querelare",
    "quereleranno": "querelare",
    "querelerebbe": "querelare",
    "querelerebber": "querelare",
    "querelerebbero": "querelare",
    "querelerei": "querelare",
    "quereleremmo": "querelare",
    "quereleremo": "querelare",
    "querelereste": "querelare",
    "quereleresti": "querelare",
    "querelerete": "querelare",
    "querelerà": "querelare",
    "querelerò": "querelare",
    "quereli": "querelare",
    "quereliamo": "querelare",
    "quereliate": "querelare",
    "querelin": "querelare",
    "querelino": "querelare",
    "querelo": "querelare",
    "querelò": "querelare",
    "querimonie": "querimonia",
    "querula": "querulo",
    "querule": "querulo",
    "queruli": "querulo",
    "quesiti": "quesito",
    "quest'": "questo",
    "questa": "questo",
    "queste": "questo",
    "questi": "questo",
    "questiona": "questionare",
    "questionai": "questionare",
    "questionammo": "questionare",
    "questionan": "questionare",
    "questionando": "questionare",
    "questionano": "questionare",
    "questionante": "questionare",
    "questionanti": "questionare",
    "questionar": "questionare",
    "questionari": "questionario",
    "questionaron": "questionare",
    "questionarono": "questionare",
    "questionasse": "questionare",
    "questionasser": "questionare",
    "questionassero": "questionare",
    "questionassi": "questionare",
    "questionassimo": "questionare",
    "questionaste": "questionare",
    "questionasti": "questionare",
    "questionata": "questionare",
    "questionate": "questionare",
    "questionati": "questionare",
    "questionato": "questionare",
    "questionava": "questionare",
    "questionavamo": "questionare",
    "questionavan": "questionare",
    "questionavano": "questionare",
    "questionavate": "questionare",
    "questionavi": "questionare",
    "questionavo": "questionare",
    "questionerai": "questionare",
    "questioneran": "questionare",
    "questioneranno": "questionare",
    "questionerebbe": "questionare",
    "questionerebber": "questionare",
    "questionerebbero": "questionare",
    "questionerei": "questionare",
    "questioneremmo": "questionare",
    "questioneremo": "questionare",
    "questionereste": "questionare",
    "questioneresti": "questionare",
    "questionerete": "questionare",
    "questionerà": "questionare",
    "questionerò": "questionare",
    "questioni": "questione",
    "questioniamo": "questionare",
    "questioniate": "questionare",
    "questionin": "questionare",
    "questionino": "questionare",
    "questiono": "questionare",
    "questionò": "questionare",
    "questori": "questore",
    "questua": "questuare",
    "questuai": "questuare",
    "questuammo": "questuare",
    "questuan": "questuare",
    "questuando": "questuare",
    "questuano": "questuare",
    "questuante": "questuare",
    "questuanti": "questuare",
    "questuar": "questuare",
    "questuaron": "questuare",
    "questuarono": "questuare",
    "questuasse": "questuare",
    "questuasser": "questuare",
    "questuassero": "questuare",
    "questuassi": "questuare",
    "questuassimo": "questuare",
    "questuaste": "questuare",
    "questuasti": "questuare",
    "questuata": "questuare",
    "questuate": "questuare",
    "questuati": "questuare",
    "questuato": "questuare",
    "questuava": "questuare",
    "questuavamo": "questuare",
    "questuavan": "questuare",
    "questuavano": "questuare",
    "questuavate": "questuare",
    "questuavi": "questuare",
    "questuavo": "questuare",
    "questue": "questua",
    "questuerai": "questuare",
    "questueran": "questuare",
    "questueranno": "questuare",
    "questuerebbe": "questuare",
    "questuerebber": "questuare",
    "questuerebbero": "questuare",
    "questuerei": "questuare",
    "questueremmo": "questuare",
    "questueremo": "questuare",
    "questuereste": "questuare",
    "questueresti": "questuare",
    "questuerete": "questuare",
    "questuerà": "questuare",
    "questuerò": "questuare",
    "questui": "questuare",
    "questuiamo": "questuare",
    "questuiate": "questuare",
    "questuin": "questuare",
    "questuino": "questuare",
    "questuo": "questuare",
    "questure": "questura",
    "questurini": "questurino",
    "questuò": "questuare",
    "quieta": "quieto",
    "quietai": "quietare",
    "quietammo": "quietare",
    "quietan": "quietare",
    "quietando": "quietare",
    "quietano": "quietare",
    "quietante": "quietare",
    "quietanti": "quietare",
    "quietanze": "quietanza",
    "quietar": "quietare",
    "quietaron": "quietare",
    "quietarono": "quietare",
    "quietasse": "quietare",
    "quietasser": "quietare",
    "quietassero": "quietare",
    "quietassi": "quietare",
    "quietassimo": "quietare",
    "quietaste": "quietare",
    "quietasti": "quietare",
    "quietata": "quietare",
    "quietate": "quietare",
    "quietati": "quietare",
    "quietato": "quietare",
    "quietava": "quietare",
    "quietavamo": "quietare",
    "quietavan": "quietare",
    "quietavano": "quietare",
    "quietavate": "quietare",
    "quietavi": "quietare",
    "quietavo": "quietare",
    "quiete": "quieto",
    "quieterai": "quietare",
    "quieteran": "quietare",
    "quieteranno": "quietare",
    "quieterebbe": "quietare",
    "quieterebber": "quietare",
    "quieterebbero": "quietare",
    "quieterei": "quietare",
    "quieteremmo": "quietare",
    "quieteremo": "quietare",
    "quietereste": "quietare",
    "quieteresti": "quietare",
    "quieterete": "quietare",
    "quieterà": "quietare",
    "quieterò": "quietare",
    "quieti": "quieto",
    "quietiamo": "quietare",
    "quietiate": "quietare",
    "quietin": "quietare",
    "quietino": "quietare",
    "quieto": "quietare",
    "quietò": "quietare",
    "quindicenni": "quindicenne",
    "quindicennii": "quindicennio",
    "quindicesima": "quindicesimo",
    "quindicesime": "quindicesimo",
    "quindicesimi": "quindicesimo",
    "quindicinali": "quindicinale",
    "quindicine": "quindicina",
    "quinquennali": "quinquennale",
    "quinquennii": "quinquennio",
    "quinta": "quinto",
    "quintali": "quintale",
    "quinte": "quinto",
    "quintessenze": "quintessenza",
    "quintetti": "quintetto",
    "quinti": "quinto",
    "quintultima": "quintultimo",
    "quintultime": "quintultimo",
    "quintultimi": "quintultimo",
    "quintupla": "quintuplo",
    "quintuple": "quintuplo",
    "quintupli": "quintuplo",
    "quintuplica": "quintuplicare",
    "quintuplicai": "quintuplicare",
    "quintuplicammo": "quintuplicare",
    "quintuplican": "quintuplicare",
    "quintuplicando": "quintuplicare",
    "quintuplicano": "quintuplicare",
    "quintuplicante": "quintuplicare",
    "quintuplicanti": "quintuplicare",
    "quintuplicar": "quintuplicare",
    "quintuplicaron": "quintuplicare",
    "quintuplicarono": "quintuplicare",
    "quintuplicasse": "quintuplicare",
    "quintuplicasser": "quintuplicare",
    "quintuplicassero": "quintuplicare",
    "quintuplicassi": "quintuplicare",
    "quintuplicassimo": "quintuplicare",
    "quintuplicaste": "quintuplicare",
    "quintuplicasti": "quintuplicare",
    "quintuplicata": "quintuplicare",
    "quintuplicate": "quintuplicare",
    "quintuplicati": "quintuplicare",
    "quintuplicato": "quintuplicare",
    "quintuplicava": "quintuplicare",
    "quintuplicavamo": "quintuplicare",
    "quintuplicavan": "quintuplicare",
    "quintuplicavano": "quintuplicare",
    "quintuplicavate": "quintuplicare",
    "quintuplicavi": "quintuplicare",
    "quintuplicavo": "quintuplicare",
    "quintuplicherai": "quintuplicare",
    "quintuplicheran": "quintuplicare",
    "quintuplicheranno": "quintuplicare",
    "quintuplicherebbe": "quintuplicare",
    "quintuplicherebber": "quintuplicare",
    "quintuplicherebbero": "quintuplicare",
    "quintuplicherei": "quintuplicare",
    "quintuplicheremmo": "quintuplicare",
    "quintuplicheremo": "quintuplicare",
    "quintuplichereste": "quintuplicare",
    "quintuplicheresti": "quintuplicare",
    "quintuplicherete": "quintuplicare",
    "quintuplicherà": "quintuplicare",
    "quintuplicherò": "quintuplicare",
    "quintuplichi": "quintuplicare",
    "quintuplichiamo": "quintuplicare",
    "quintuplichiate": "quintuplicare",
    "quintuplichin": "quintuplicare",
    "quintuplichino": "quintuplicare",
    "quintuplico": "quintuplicare",
    "quintuplicò": "quintuplicare",
    "quisquilie": "quisquilia",
    "quota": "quotare",
    "quotai": "quotare",
    "quotammo": "quotare",
    "quotan": "quotare",
    "quotando": "quotare",
    "quotano": "quotare",
    "quotante": "quotare",
    "quotanti": "quotare",
    "quotar": "quotare",
    "quotaron": "quotare",
    "quotarono": "quotare",
    "quotasse": "quotare",
    "quotasser": "quotare",
    "quotassero": "quotare",
    "quotassi": "quotare",
    "quotassimo": "quotare",
    "quotaste": "quotare",
    "quotasti": "quotare",
    "quotata": "quotato",
    "quotate": "quotato",
    "quotati": "quotato",
    "quotato": "quotare",
    "quotava": "quotare",
    "quotavamo": "quotare",
    "quotavan": "quotare",
    "quotavano": "quotare",
    "quotavate": "quotare",
    "quotavi": "quotare",
    "quotavo": "quotare",
    "quotazioni": "quotazione",
    "quote": "quota",
    "quoterai": "quotare",
    "quoteran": "quotare",
    "quoteranno": "quotare",
    "quoterebbe": "quotare",
    "quoterebber": "quotare",
    "quoterebbero": "quotare",
    "quoterei": "quotare",
    "quoteremmo": "quotare",
    "quoteremo": "quotare",
    "quotereste": "quotare",
    "quoteresti": "quotare",
    "quoterete": "quotare",
    "quoterà": "quotare",
    "quoterò": "quotare",
    "quoti": "quotare",
    "quotiamo": "quotare",
    "quotiate": "quotare",
    "quotidiana": "quotidiano",
    "quotidiane": "quotidiano",
    "quotidiani": "quotidiano",
    "quotin": "quotare",
    "quotino": "quotare",
    "quoto": "quotare",
    "quotò": "quotare",
    "quozienti": "quoziente",
    "rabbercerai": "rabberciare",
    "rabberceran": "rabberciare",
    "rabberceranno": "rabberciare",
    "rabbercerebbe": "rabberciare",
    "rabbercerebber": "rabberciare",
    "rabbercerebbero": "rabberciare",
    "rabbercerei": "rabberciare",
    "rabberceremmo": "rabberciare",
    "rabberceremo": "rabberciare",
    "rabbercereste": "rabberciare",
    "rabberceresti": "rabberciare",
    "rabbercerete": "rabberciare",
    "rabbercerà": "rabberciare",
    "rabbercerò": "rabberciare",
    "rabberci": "rabberciare",
    "rabbercia": "rabberciare",
    "rabberciai": "rabberciare",
    "rabberciammo": "rabberciare",
    "rabberciamo": "rabberciare",
    "rabbercian": "rabberciare",
    "rabberciando": "rabberciare",
    "rabberciano": "rabberciare",
    "rabberciante": "rabberciare",
    "rabbercianti": "rabberciare",
    "rabberciar": "rabberciare",
    "rabberciaron": "rabberciare",
    "rabberciarono": "rabberciare",
    "rabberciasse": "rabberciare",
    "rabberciasser": "rabberciare",
    "rabberciassero": "rabberciare",
    "rabberciassi": "rabberciare",
    "rabberciassimo": "rabberciare",
    "rabberciaste": "rabberciare",
    "rabberciasti": "rabberciare",
    "rabberciata": "rabberciare",
    "rabberciate": "rabberciare",
    "rabberciati": "rabberciare",
    "rabberciato": "rabberciare",
    "rabberciava": "rabberciare",
    "rabberciavamo": "rabberciare",
    "rabberciavan": "rabberciare",
    "rabberciavano": "rabberciare",
    "rabberciavate": "rabberciare",
    "rabberciavi": "rabberciare",
    "rabberciavo": "rabberciare",
    "rabbercin": "rabberciare",
    "rabbercino": "rabberciare",
    "rabbercio": "rabberciare",
    "rabberciò": "rabberciare",
    "rabbie": "rabbia",
    "rabbini": "rabbino",
    "rabbiosa": "rabbioso",
    "rabbiose": "rabbioso",
    "rabbiosi": "rabbioso",
    "rabbona": "rabbonire",
    "rabbonan": "rabbonire",
    "rabbonano": "rabbonire",
    "rabbone": "rabbonire",
    "rabbonendo": "rabbonire",
    "rabbonente": "rabbonire",
    "rabbonenti": "rabbonire",
    "rabboni": "rabbonire",
    "rabboniamo": "rabbonire",
    "rabboniate": "rabbonire",
    "rabbonii": "rabbonire",
    "rabbonimmo": "rabbonire",
    "rabbonir": "rabbonire",
    "rabbonirai": "rabbonire",
    "rabboniran": "rabbonire",
    "rabboniranno": "rabbonire",
    "rabbonirebbe": "rabbonire",
    "rabbonirebber": "rabbonire",
    "rabbonirebbero": "rabbonire",
    "rabbonirei": "rabbonire",
    "rabboniremmo": "rabbonire",
    "rabboniremo": "rabbonire",
    "rabbonireste": "rabbonire",
    "rabboniresti": "rabbonire",
    "rabbonirete": "rabbonire",
    "rabboniron": "rabbonire",
    "rabbonirono": "rabbonire",
    "rabbonirà": "rabbonire",
    "rabbonirò": "rabbonire",
    "rabbonisse": "rabbonire",
    "rabbonisser": "rabbonire",
    "rabbonissero": "rabbonire",
    "rabbonissi": "rabbonire",
    "rabbonissimo": "rabbonire",
    "rabboniste": "rabbonire",
    "rabbonisti": "rabbonire",
    "rabbonita": "rabbonire",
    "rabbonite": "rabbonire",
    "rabboniti": "rabbonire",
    "rabbonito": "rabbonire",
    "rabboniva": "rabbonire",
    "rabbonivamo": "rabbonire",
    "rabbonivan": "rabbonire",
    "rabbonivano": "rabbonire",
    "rabbonivate": "rabbonire",
    "rabbonivi": "rabbonire",
    "rabbonivo": "rabbonire",
    "rabbono": "rabbonire",
    "rabbonon": "rabbonire",
    "rabbonono": "rabbonire",
    "rabbonì": "rabbonire",
    "rabbrivida": "rabbrividire",
    "rabbrividan": "rabbrividire",
    "rabbrividano": "rabbrividire",
    "rabbrivide": "rabbrividire",
    "rabbrividendo": "rabbrividire",
    "rabbrividente": "rabbrividire",
    "rabbrividenti": "rabbrividire",
    "rabbrividi": "rabbrividire",
    "rabbrividiamo": "rabbrividire",
    "rabbrividiate": "rabbrividire",
    "rabbrividii": "rabbrividire",
    "rabbrividimmo": "rabbrividire",
    "rabbrividir": "rabbrividire",
    "rabbrividirai": "rabbrividire",
    "rabbrividiran": "rabbrividire",
    "rabbrividiranno": "rabbrividire",
    "rabbrividirebbe": "rabbrividire",
    "rabbrividirebber": "rabbrividire",
    "rabbrividirebbero": "rabbrividire",
    "rabbrividirei": "rabbrividire",
    "rabbrividiremmo": "rabbrividire",
    "rabbrividiremo": "rabbrividire",
    "rabbrividireste": "rabbrividire",
    "rabbrividiresti": "rabbrividire",
    "rabbrividirete": "rabbrividire",
    "rabbrividiron": "rabbrividire",
    "rabbrividirono": "rabbrividire",
    "rabbrividirà": "rabbrividire",
    "rabbrividirò": "rabbrividire",
    "rabbrividisse": "rabbrividire",
    "rabbrividisser": "rabbrividire",
    "rabbrividissero": "rabbrividire",
    "rabbrividissi": "rabbrividire",
    "rabbrividissimo": "rabbrividire",
    "rabbrividiste": "rabbrividire",
    "rabbrividisti": "rabbrividire",
    "rabbrividita": "rabbrividire",
    "rabbrividite": "rabbrividire",
    "rabbrividiti": "rabbrividire",
    "rabbrividito": "rabbrividire",
    "rabbrividiva": "rabbrividire",
    "rabbrividivamo": "rabbrividire",
    "rabbrividivan": "rabbrividire",
    "rabbrividivano": "rabbrividire",
    "rabbrividivate": "rabbrividire",
    "rabbrividivi": "rabbrividire",
    "rabbrividivo": "rabbrividire",
    "rabbrivido": "rabbrividire",
    "rabbrividon": "rabbrividire",
    "rabbrividono": "rabbrividire",
    "rabbrividì": "rabbrividire",
    "rabbuffa": "rabbuffare",
    "rabbuffai": "rabbuffare",
    "rabbuffammo": "rabbuffare",
    "rabbuffan": "rabbuffare",
    "rabbuffando": "rabbuffare",
    "rabbuffano": "rabbuffare",
    "rabbuffante": "rabbuffare",
    "rabbuffanti": "rabbuffare",
    "rabbuffar": "rabbuffare",
    "rabbuffaron": "rabbuffare",
    "rabbuffarono": "rabbuffare",
    "rabbuffasse": "rabbuffare",
    "rabbuffasser": "rabbuffare",
    "rabbuffassero": "rabbuffare",
    "rabbuffassi": "rabbuffare",
    "rabbuffassimo": "rabbuffare",
    "rabbuffaste": "rabbuffare",
    "rabbuffasti": "rabbuffare",
    "rabbuffata": "rabbuffare",
    "rabbuffate": "rabbuffare",
    "rabbuffati": "rabbuffare",
    "rabbuffato": "rabbuffare",
    "rabbuffava": "rabbuffare",
    "rabbuffavamo": "rabbuffare",
    "rabbuffavan": "rabbuffare",
    "rabbuffavano": "rabbuffare",
    "rabbuffavate": "rabbuffare",
    "rabbuffavi": "rabbuffare",
    "rabbuffavo": "rabbuffare",
    "rabbufferai": "rabbuffare",
    "rabbufferan": "rabbuffare",
    "rabbufferanno": "rabbuffare",
    "rabbufferebbe": "rabbuffare",
    "rabbufferebber": "rabbuffare",
    "rabbufferebbero": "rabbuffare",
    "rabbufferei": "rabbuffare",
    "rabbufferemmo": "rabbuffare",
    "rabbufferemo": "rabbuffare",
    "rabbuffereste": "rabbuffare",
    "rabbufferesti": "rabbuffare",
    "rabbufferete": "rabbuffare",
    "rabbufferà": "rabbuffare",
    "rabbufferò": "rabbuffare",
    "rabbuffi": "rabbuffo",
    "rabbuffiamo": "rabbuffare",
    "rabbuffiate": "rabbuffare",
    "rabbuffin": "rabbuffare",
    "rabbuffino": "rabbuffare",
    "rabbuffo": "rabbuffare",
    "rabbuffò": "rabbuffare",
    "rabbui": "rabbuiare",
    "rabbuia": "rabbuiare",
    "rabbuiai": "rabbuiare",
    "rabbuiammo": "rabbuiare",
    "rabbuiamo": "rabbuiare",
    "rabbuian": "rabbuiare",
    "rabbuiando": "rabbuiare",
    "rabbuiano": "rabbuiare",
    "rabbuiante": "rabbuiare",
    "rabbuianti": "rabbuiare",
    "rabbuiar": "rabbuiare",
    "rabbuiaron": "rabbuiare",
    "rabbuiarono": "rabbuiare",
    "rabbuiasse": "rabbuiare",
    "rabbuiasser": "rabbuiare",
    "rabbuiassero": "rabbuiare",
    "rabbuiassi": "rabbuiare",
    "rabbuiassimo": "rabbuiare",
    "rabbuiaste": "rabbuiare",
    "rabbuiasti": "rabbuiare",
    "rabbuiata": "rabbuiare",
    "rabbuiate": "rabbuiare",
    "rabbuiati": "rabbuiare",
    "rabbuiato": "rabbuiare",
    "rabbuiava": "rabbuiare",
    "rabbuiavamo": "rabbuiare",
    "rabbuiavan": "rabbuiare",
    "rabbuiavano": "rabbuiare",
    "rabbuiavate": "rabbuiare",
    "rabbuiavi": "rabbuiare",
    "rabbuiavo": "rabbuiare",
    "rabbuierai": "rabbuiare",
    "rabbuieran": "rabbuiare",
    "rabbuieranno": "rabbuiare",
    "rabbuierebbe": "rabbuiare",
    "rabbuierebber": "rabbuiare",
    "rabbuierebbero": "rabbuiare",
    "rabbuierei": "rabbuiare",
    "rabbuieremmo": "rabbuiare",
    "rabbuieremo": "rabbuiare",
    "rabbuiereste": "rabbuiare",
    "rabbuieresti": "rabbuiare",
    "rabbuierete": "rabbuiare",
    "rabbuierà": "rabbuiare",
    "rabbuierò": "rabbuiare",
    "rabbuin": "rabbuiare",
    "rabbuino": "rabbuiare",
    "rabbuio": "rabbuiare",
    "rabbuiò": "rabbuiare",
    "rabdomanti": "rabdomante",
    "rabesca": "rabescare",
    "rabescai": "rabescare",
    "rabescammo": "rabescare",
    "rabescan": "rabescare",
    "rabescando": "rabescare",
    "rabescano": "rabescare",
    "rabescante": "rabescare",
    "rabescanti": "rabescare",
    "rabescar": "rabescare",
    "rabescaron": "rabescare",
    "rabescarono": "rabescare",
    "rabescasse": "rabescare",
    "rabescasser": "rabescare",
    "rabescassero": "rabescare",
    "rabescassi": "rabescare",
    "rabescassimo": "rabescare",
    "rabescaste": "rabescare",
    "rabescasti": "rabescare",
    "rabescata": "rabescare",
    "rabescate": "rabescare",
    "rabescati": "rabescare",
    "rabescato": "rabescare",
    "rabescava": "rabescare",
    "rabescavamo": "rabescare",
    "rabescavan": "rabescare",
    "rabescavano": "rabescare",
    "rabescavate": "rabescare",
    "rabescavi": "rabescare",
    "rabescavo": "rabescare",
    "rabescherai": "rabescare",
    "rabescheran": "rabescare",
    "rabescheranno": "rabescare",
    "rabescherebbe": "rabescare",
    "rabescherebber": "rabescare",
    "rabescherebbero": "rabescare",
    "rabescherei": "rabescare",
    "rabescheremmo": "rabescare",
    "rabescheremo": "rabescare",
    "rabeschereste": "rabescare",
    "rabescheresti": "rabescare",
    "rabescherete": "rabescare",
    "rabescherà": "rabescare",
    "rabescherò": "rabescare",
    "rabeschi": "rabescare",
    "rabeschiamo": "rabescare",
    "rabeschiate": "rabescare",
    "rabeschin": "rabescare",
    "rabeschino": "rabescare",
    "rabesco": "rabescare",
    "rabescò": "rabescare",
    "rabicana": "rabicano",
    "rabicane": "rabicano",
    "rabicani": "rabicano",
    "racalmutesi": "racalmutese",
    "racca": "raccare",
    "raccai": "raccare",
    "raccammo": "raccare",
    "raccan": "raccare",
    "raccando": "raccare",
    "raccano": "raccare",
    "raccante": "raccare",
    "raccanti": "raccare",
    "raccapezza": "raccapezzare",
    "raccapezzai": "raccapezzare",
    "raccapezzammo": "raccapezzare",
    "raccapezzan": "raccapezzare",
    "raccapezzando": "raccapezzare",
    "raccapezzano": "raccapezzare",
    "raccapezzante": "raccapezzare",
    "raccapezzanti": "raccapezzare",
    "raccapezzar": "raccapezzare",
    "raccapezzaron": "raccapezzare",
    "raccapezzarono": "raccapezzare",
    "raccapezzasse": "raccapezzare",
    "raccapezzasser": "raccapezzare",
    "raccapezzassero": "raccapezzare",
    "raccapezzassi": "raccapezzare",
    "raccapezzassimo": "raccapezzare",
    "raccapezzaste": "raccapezzare",
    "raccapezzasti": "raccapezzare",
    "raccapezzata": "raccapezzare",
    "raccapezzate": "raccapezzare",
    "raccapezzati": "raccapezzare",
    "raccapezzato": "raccapezzare",
    "raccapezzava": "raccapezzare",
    "raccapezzavamo": "raccapezzare",
    "raccapezzavan": "raccapezzare",
    "raccapezzavano": "raccapezzare",
    "raccapezzavate": "raccapezzare",
    "raccapezzavi": "raccapezzare",
    "raccapezzavo": "raccapezzare",
    "raccapezzerai": "raccapezzare",
    "raccapezzeran": "raccapezzare",
    "raccapezzeranno": "raccapezzare",
    "raccapezzerebbe": "raccapezzare",
    "raccapezzerebber": "raccapezzare",
    "raccapezzerebbero": "raccapezzare",
    "raccapezzerei": "raccapezzare",
    "raccapezzeremmo": "raccapezzare",
    "raccapezzeremo": "raccapezzare",
    "raccapezzereste": "raccapezzare",
    "raccapezzeresti": "raccapezzare",
    "raccapezzerete": "raccapezzare",
    "raccapezzerà": "raccapezzare",
    "raccapezzerò": "raccapezzare",
    "raccapezzi": "raccapezzare",
    "raccapezziamo": "raccapezzare",
    "raccapezziate": "raccapezzare",
    "raccapezzin": "raccapezzare",
    "raccapezzino": "raccapezzare",
    "raccapezzo": "raccapezzare",
    "raccapezzò": "raccapezzare",
    "raccapriccerai": "raccapricciare",
    "raccapricceran": "raccapricciare",
    "raccapricceranno": "raccapricciare",
    "raccapriccerebbe": "raccapricciare",
    "raccapriccerebber": "raccapricciare",
    "raccapriccerebbero": "raccapricciare",
    "raccapriccerei": "raccapricciare",
    "raccapricceremmo": "raccapricciare",
    "raccapricceremo": "raccapricciare",
    "raccapriccereste": "raccapricciare",
    "raccapricceresti": "raccapricciare",
    "raccapriccerete": "raccapricciare",
    "raccapriccerà": "raccapricciare",
    "raccapriccerò": "raccapricciare",
    "raccapricci": "raccapricciare",
    "raccapriccia": "raccapricciare",
    "raccapricciai": "raccapricciare",
    "raccapricciammo": "raccapricciare",
    "raccapricciamo": "raccapricciare",
    "raccapriccian": "raccapricciare",
    "raccapricciando": "raccapricciare",
    "raccapricciano": "raccapricciare",
    "raccapricciante": "raccapricciare",
    "raccapriccianti": "raccapricciare",
    "raccapricciar": "raccapricciare",
    "raccapricciaron": "raccapricciare",
    "raccapricciarono": "raccapricciare",
    "raccapricciasse": "raccapricciare",
    "raccapricciasser": "raccapricciare",
    "raccapricciassero": "raccapricciare",
    "raccapricciassi": "raccapricciare",
    "raccapricciassimo": "raccapricciare",
    "raccapricciaste": "raccapricciare",
    "raccapricciasti": "raccapricciare",
    "raccapricciata": "raccapricciare",
    "raccapricciate": "raccapricciare",
    "raccapricciati": "raccapricciare",
    "raccapricciato": "raccapricciare",
    "raccapricciava": "raccapricciare",
    "raccapricciavamo": "raccapricciare",
    "raccapricciavan": "raccapricciare",
    "raccapricciavano": "raccapricciare",
    "raccapricciavate": "raccapricciare",
    "raccapricciavi": "raccapricciare",
    "raccapricciavo": "raccapricciare",
    "raccapriccin": "raccapricciare",
    "raccapriccino": "raccapricciare",
    "raccapriccio": "raccapricciare",
    "raccapricciò": "raccapricciare",
    "raccar": "raccare",
    "raccaron": "raccare",
    "raccarono": "raccare",
    "raccasse": "raccare",
    "raccasser": "raccare",
    "raccassero": "raccare",
    "raccassi": "raccare",
    "raccassimo": "raccare",
    "raccaste": "raccare",
    "raccasti": "raccare",
    "raccata": "raccare",
    "raccate": "raccare",
    "raccati": "raccare",
    "raccato": "raccare",
    "raccatta": "raccattare",
    "raccattai": "raccattare",
    "raccattammo": "raccattare",
    "raccattan": "raccattare",
    "raccattando": "raccattare",
    "raccattano": "raccattare",
    "raccattante": "raccattare",
    "raccattanti": "raccattare",
    "raccattar": "raccattare",
    "raccattaron": "raccattare",
    "raccattarono": "raccattare",
    "raccattasse": "raccattare",
    "raccattasser": "raccattare",
    "raccattassero": "raccattare",
    "raccattassi": "raccattare",
    "raccattassimo": "raccattare",
    "raccattaste": "raccattare",
    "raccattasti": "raccattare",
    "raccattata": "raccattare",
    "raccattate": "raccattare",
    "raccattati": "raccattare",
    "raccattato": "raccattare",
    "raccattava": "raccattare",
    "raccattavamo": "raccattare",
    "raccattavan": "raccattare",
    "raccattavano": "raccattare",
    "raccattavate": "raccattare",
    "raccattavi": "raccattare",
    "raccattavo": "raccattare",
    "raccatterai": "raccattare",
    "raccatteran": "raccattare",
    "raccatteranno": "raccattare",
    "raccatterebbe": "raccattare",
    "raccatterebber": "raccattare",
    "raccatterebbero": "raccattare",
    "raccatterei": "raccattare",
    "raccatteremmo": "raccattare",
    "raccatteremo": "raccattare",
    "raccattereste": "raccattare",
    "raccatteresti": "raccattare",
    "raccatterete": "raccattare",
    "raccatterà": "raccattare",
    "raccatterò": "raccattare",
    "raccatti": "raccattare",
    "raccattiamo": "raccattare",
    "raccattiate": "raccattare",
    "raccattin": "raccattare",
    "raccattino": "raccattare",
    "raccatto": "raccattare",
    "raccattò": "raccattare",
    "raccava": "raccare",
    "raccavamo": "raccare",
    "raccavan": "raccare",
    "raccavano": "raccare",
    "raccavate": "raccare",
    "raccavi": "raccare",
    "raccavo": "raccare",
    "raccherai": "raccare",
    "raccheran": "raccare",
    "raccheranno": "raccare",
    "raccherebbe": "raccare",
    "raccherebber": "raccare",
    "raccherebbero": "raccare",
    "raccherei": "raccare",
    "raccheremmo": "raccare",
    "raccheremo": "raccare",
    "racchereste": "raccare",
    "raccheresti": "raccare",
    "raccherete": "raccare",
    "raccherà": "raccare",
    "raccherò": "raccare",
    "racchette": "racchetta",
    "racchettoni": "racchettone",
    "racchi": "raccare",
    "racchiamo": "raccare",
    "racchiate": "raccare",
    "racchin": "raccare",
    "racchino": "raccare",
    "racchiuda": "racchiudere",
    "racchiudan": "racchiudere",
    "racchiudano": "racchiudere",
    "racchiude": "racchiudere",
    "racchiudemmo": "racchiudere",
    "racchiudendo": "racchiudere",
    "racchiudente": "racchiudere",
    "racchiudenti": "racchiudere",
    "racchiuder": "racchiudere",
    "racchiuderai": "racchiudere",
    "racchiuderan": "racchiudere",
    "racchiuderanno": "racchiudere",
    "racchiuderebbe": "racchiudere",
    "racchiuderebber": "racchiudere",
    "racchiuderebbero": "racchiudere",
    "racchiuderei": "racchiudere",
    "racchiuderemmo": "racchiudere",
    "racchiuderemo": "racchiudere",
    "racchiudereste": "racchiudere",
    "racchiuderesti": "racchiudere",
    "racchiuderete": "racchiudere",
    "racchiuderà": "racchiudere",
    "racchiuderò": "racchiudere",
    "racchiudesse": "racchiudere",
    "racchiudesser": "racchiudere",
    "racchiudessero": "racchiudere",
    "racchiudessi": "racchiudere",
    "racchiudessimo": "racchiudere",
    "racchiudeste": "racchiudere",
    "racchiudesti": "racchiudere",
    "racchiudete": "racchiudere",
    "racchiudeva": "racchiudere",
    "racchiudevamo": "racchiudere",
    "racchiudevan": "racchiudere",
    "racchiudevano": "racchiudere",
    "racchiudevate": "racchiudere",
    "racchiudevi": "racchiudere",
    "racchiudevo": "racchiudere",
    "racchiudi": "racchiudere",
    "racchiudiamo": "racchiudere",
    "racchiudiate": "racchiudere",
    "racchiudo": "racchiudere",
    "racchiudon": "racchiudere",
    "racchiudono": "racchiudere",
    "racchiusa": "racchiudere",
    "racchiuse": "racchiudere",
    "racchiuser": "racchiudere",
    "racchiusero": "racchiudere",
    "racchiusi": "racchiudere",
    "racchiuso": "racchiudere",
    "racco": "raccare",
    "raccogli": "raccogliere",
    "raccogliamo": "raccogliere",
    "raccogliate": "raccogliere",
    "raccoglie": "raccogliere",
    "raccogliemmo": "raccogliere",
    "raccogliendo": "raccogliere",
    "raccogliente": "raccogliere",
    "raccoglienti": "raccogliere",
    "raccoglier": "raccogliere",
    "raccoglierai": "raccogliere",
    "raccoglieran": "raccogliere",
    "raccoglieranno": "raccogliere",
    "raccoglierebbe": "raccogliere",
    "raccoglierebber": "raccogliere",
    "raccoglierebbero": "raccogliere",
    "raccoglierei": "raccogliere",
    "raccoglieremmo": "raccogliere",
    "raccoglieremo": "raccogliere",
    "raccogliereste": "raccogliere",
    "raccoglieresti": "raccogliere",
    "raccoglierete": "raccogliere",
    "raccoglierà": "raccogliere",
    "raccoglierò": "raccogliere",
    "raccogliesse": "raccogliere",
    "raccogliesser": "raccogliere",
    "raccogliessero": "raccogliere",
    "raccogliessi": "raccogliere",
    "raccogliessimo": "raccogliere",
    "raccoglieste": "raccogliere",
    "raccogliesti": "raccogliere",
    "raccogliete": "raccogliere",
    "raccoglieva": "raccogliere",
    "raccoglievamo": "raccogliere",
    "raccoglievan": "raccogliere",
    "raccoglievano": "raccogliere",
    "raccoglievate": "raccogliere",
    "raccoglievi": "raccogliere",
    "raccoglievo": "raccogliere",
    "raccoglimenti": "raccoglimento",
    "raccogliticce": "raccogliticcio",
    "raccogliticci": "raccogliticcio",
    "raccogliticcia": "raccogliticcio",
    "raccoglitori": "raccoglitore",
    "raccolga": "raccogliere",
    "raccolgan": "raccogliere",
    "raccolgano": "raccogliere",
    "raccolgo": "raccogliere",
    "raccolgon": "raccogliere",
    "raccolgono": "raccogliere",
    "raccolse": "raccogliere",
    "raccolser": "raccogliere",
    "raccolsero": "raccogliere",
    "raccolsi": "raccogliere",
    "raccolta": "raccolto",
    "raccolte": "raccolto",
    "raccolti": "raccolto",
    "raccolto": "raccogliere",
    "raccomanda": "raccomandare",
    "raccomandabili": "raccomandabile",
    "raccomandai": "raccomandare",
    "raccomandammo": "raccomandare",
    "raccomandan": "raccomandare",
    "raccomandando": "raccomandare",
    "raccomandano": "raccomandare",
    "raccomandante": "raccomandare",
    "raccomandanti": "raccomandare",
    "raccomandar": "raccomandare",
    "raccomandaron": "raccomandare",
    "raccomandarono": "raccomandare",
    "raccomandasse": "raccomandare",
    "raccomandasser": "raccomandare",
    "raccomandassero": "raccomandare",
    "raccomandassi": "raccomandare",
    "raccomandassimo": "raccomandare",
    "raccomandaste": "raccomandare",
    "raccomandasti": "raccomandare",
    "raccomandata": "raccomandato",
    "raccomandate": "raccomandato",
    "raccomandati": "raccomandato",
    "raccomandato": "raccomandare",
    "raccomandava": "raccomandare",
    "raccomandavamo": "raccomandare",
    "raccomandavan": "raccomandare",
    "raccomandavano": "raccomandare",
    "raccomandavate": "raccomandare",
    "raccomandavi": "raccomandare",
    "raccomandavo": "raccomandare",
    "raccomandazioni": "raccomandazione",
    "raccomanderai": "raccomandare",
    "raccomanderan": "raccomandare",
    "raccomanderanno": "raccomandare",
    "raccomanderebbe": "raccomandare",
    "raccomanderebber": "raccomandare",
    "raccomanderebbero": "raccomandare",
    "raccomanderei": "raccomandare",
    "raccomanderemmo": "raccomandare",
    "raccomanderemo": "raccomandare",
    "raccomandereste": "raccomandare",
    "raccomanderesti": "raccomandare",
    "raccomanderete": "raccomandare",
    "raccomanderà": "raccomandare",
    "raccomanderò": "raccomandare",
    "raccomandi": "raccomandare",
    "raccomandiamo": "raccomandare",
    "raccomandiate": "raccomandare",
    "raccomandin": "raccomandare",
    "raccomandino": "raccomandare",
    "raccomando": "raccomandare",
    "raccomandò": "raccomandare",
    "racconcerai": "racconciare",
    "racconceran": "racconciare",
    "racconceranno": "racconciare",
    "racconcerebbe": "racconciare",
    "racconcerebber": "racconciare",
    "racconcerebbero": "racconciare",
    "racconcerei": "racconciare",
    "racconceremmo": "racconciare",
    "racconceremo": "racconciare",
    "racconcereste": "racconciare",
    "racconceresti": "racconciare",
    "racconcerete": "racconciare",
    "racconcerà": "racconciare",
    "racconcerò": "racconciare",
    "racconci": "racconciare",
    "racconcia": "racconciare",
    "racconciai": "racconciare",
    "racconciammo": "racconciare",
    "racconciamo": "racconciare",
    "racconcian": "racconciare",
    "racconciando": "racconciare",
    "racconciano": "racconciare",
    "racconciante": "racconciare",
    "racconcianti": "racconciare",
    "racconciar": "racconciare",
    "racconciaron": "racconciare",
    "racconciarono": "racconciare",
    "racconciasse": "racconciare",
    "racconciasser": "racconciare",
    "racconciassero": "racconciare",
    "racconciassi": "racconciare",
    "racconciassimo": "racconciare",
    "racconciaste": "racconciare",
    "racconciasti": "racconciare",
    "racconciata": "racconciare",
    "racconciate": "racconciare",
    "racconciati": "racconciare",
    "racconciato": "racconciare",
    "racconciava": "racconciare",
    "racconciavamo": "racconciare",
    "racconciavan": "racconciare",
    "racconciavano": "racconciare",
    "racconciavate": "racconciare",
    "racconciavi": "racconciare",
    "racconciavo": "racconciare",
    "racconcin": "racconciare",
    "racconcino": "racconciare",
    "racconcio": "racconciare",
    "racconciò": "racconciare",
    "racconta": "raccontare",
    "raccontabili": "raccontabile",
    "raccontai": "raccontare",
    "raccontammo": "raccontare",
    "raccontan": "raccontare",
    "raccontando": "raccontare",
    "raccontano": "raccontare",
    "raccontante": "raccontare",
    "raccontanti": "raccontare",
    "raccontar": "raccontare",
    "raccontaron": "raccontare",
    "raccontarono": "raccontare",
    "raccontasse": "raccontare",
    "raccontasser": "raccontare",
    "raccontassero": "raccontare",
    "raccontassi": "raccontare",
    "raccontassimo": "raccontare",
    "raccontaste": "raccontare",
    "raccontasti": "raccontare",
    "raccontata": "raccontare",
    "raccontate": "raccontare",
    "raccontati": "raccontare",
    "raccontato": "raccontare",
    "raccontatori": "raccontatore",
    "raccontava": "raccontare",
    "raccontavamo": "raccontare",
    "raccontavan": "raccontare",
    "raccontavano": "raccontare",
    "raccontavate": "raccontare",
    "raccontavi": "raccontare",
    "raccontavo": "raccontare",
    "racconterai": "raccontare",
    "racconteran": "raccontare",
    "racconteranno": "raccontare",
    "racconterebbe": "raccontare",
    "racconterebber": "raccontare",
    "racconterebbero": "raccontare",
    "racconterei": "raccontare",
    "racconteremmo": "raccontare",
    "racconteremo": "raccontare",
    "raccontereste": "raccontare",
    "racconteresti": "raccontare",
    "racconterete": "raccontare",
    "racconterà": "raccontare",
    "racconterò": "raccontare",
    "racconti": "racconto",
    "raccontiamo": "raccontare",
    "raccontiate": "raccontare",
    "raccontin": "raccontare",
    "raccontini": "raccontino",
    "raccontino": "raccontare",
    "racconto": "raccontare",
    "raccontò": "raccontare",
    "raccorcerai": "raccorciare",
    "raccorceran": "raccorciare",
    "raccorceranno": "raccorciare",
    "raccorcerebbe": "raccorciare",
    "raccorcerebber": "raccorciare",
    "raccorcerebbero": "raccorciare",
    "raccorcerei": "raccorciare",
    "raccorceremmo": "raccorciare",
    "raccorceremo": "raccorciare",
    "raccorcereste": "raccorciare",
    "raccorceresti": "raccorciare",
    "raccorcerete": "raccorciare",
    "raccorcerà": "raccorciare",
    "raccorcerò": "raccorciare",
    "raccorci": "raccorciare",
    "raccorcia": "raccorciare",
    "raccorciai": "raccorciare",
    "raccorciammo": "raccorciare",
    "raccorciamo": "raccorciare",
    "raccorcian": "raccorciare",
    "raccorciando": "raccorciare",
    "raccorciano": "raccorciare",
    "raccorciante": "raccorciare",
    "raccorcianti": "raccorciare",
    "raccorciar": "raccorciare",
    "raccorciaron": "raccorciare",
    "raccorciarono": "raccorciare",
    "raccorciasse": "raccorciare",
    "raccorciasser": "raccorciare",
    "raccorciassero": "raccorciare",
    "raccorciassi": "raccorciare",
    "raccorciassimo": "raccorciare",
    "raccorciaste": "raccorciare",
    "raccorciasti": "raccorciare",
    "raccorciata": "raccorciare",
    "raccorciate": "raccorciare",
    "raccorciati": "raccorciare",
    "raccorciato": "raccorciare",
    "raccorciava": "raccorciare",
    "raccorciavamo": "raccorciare",
    "raccorciavan": "raccorciare",
    "raccorciavano": "raccorciare",
    "raccorciavate": "raccorciare",
    "raccorciavi": "raccorciare",
    "raccorciavo": "raccorciare",
    "raccorcin": "raccorciare",
    "raccorcino": "raccorciare",
    "raccorcio": "raccorciare",
    "raccorciò": "raccorciare",
    "raccorda": "raccordare",
    "raccordai": "raccordare",
    "raccordammo": "raccordare",
    "raccordan": "raccordare",
    "raccordando": "raccordare",
    "raccordano": "raccordare",
    "raccordante": "raccordare",
    "raccordanti": "raccordare",
    "raccordar": "raccordare",
    "raccordaron": "raccordare",
    "raccordarono": "raccordare",
    "raccordasse": "raccordare",
    "raccordasser": "raccordare",
    "raccordassero": "raccordare",
    "raccordassi": "raccordare",
    "raccordassimo": "raccordare",
    "raccordaste": "raccordare",
    "raccordasti": "raccordare",
    "raccordata": "raccordare",
    "raccordate": "raccordare",
    "raccordati": "raccordare",
    "raccordato": "raccordare",
    "raccordava": "raccordare",
    "raccordavamo": "raccordare",
    "raccordavan": "raccordare",
    "raccordavano": "raccordare",
    "raccordavate": "raccordare",
    "raccordavi": "raccordare",
    "raccordavo": "raccordare",
    "raccorderai": "raccordare",
    "raccorderan": "raccordare",
    "raccorderanno": "raccordare",
    "raccorderebbe": "raccordare",
    "raccorderebber": "raccordare",
    "raccorderebbero": "raccordare",
    "raccorderei": "raccordare",
    "raccorderemmo": "raccordare",
    "raccorderemo": "raccordare",
    "raccordereste": "raccordare",
    "raccorderesti": "raccordare",
    "raccorderete": "raccordare",
    "raccorderà": "raccordare",
    "raccorderò": "raccordare",
    "raccordi": "raccordo",
    "raccordiamo": "raccordare",
    "raccordiate": "raccordare",
    "raccordin": "raccordare",
    "raccordino": "raccordare",
    "raccordo": "raccordare",
    "raccordò": "raccordare",
    "raccosta": "raccostare",
    "raccostai": "raccostare",
    "raccostammo": "raccostare",
    "raccostan": "raccostare",
    "raccostando": "raccostare",
    "raccostano": "raccostare",
    "raccostante": "raccostare",
    "raccostanti": "raccostare",
    "raccostar": "raccostare",
    "raccostaron": "raccostare",
    "raccostarono": "raccostare",
    "raccostasse": "raccostare",
    "raccostasser": "raccostare",
    "raccostassero": "raccostare",
    "raccostassi": "raccostare",
    "raccostassimo": "raccostare",
    "raccostaste": "raccostare",
    "raccostasti": "raccostare",
    "raccostata": "raccostare",
    "raccostate": "raccostare",
    "raccostati": "raccostare",
    "raccostato": "raccostare",
    "raccostava": "raccostare",
    "raccostavamo": "raccostare",
    "raccostavan": "raccostare",
    "raccostavano": "raccostare",
    "raccostavate": "raccostare",
    "raccostavi": "raccostare",
    "raccostavo": "raccostare",
    "raccosterai": "raccostare",
    "raccosteran": "raccostare",
    "raccosteranno": "raccostare",
    "raccosterebbe": "raccostare",
    "raccosterebber": "raccostare",
    "raccosterebbero": "raccostare",
    "raccosterei": "raccostare",
    "raccosteremmo": "raccostare",
    "raccosteremo": "raccostare",
    "raccostereste": "raccostare",
    "raccosteresti": "raccostare",
    "raccosterete": "raccostare",
    "raccosterà": "raccostare",
    "raccosterò": "raccostare",
    "raccosti": "raccostare",
    "raccostiamo": "raccostare",
    "raccostiate": "raccostare",
    "raccostin": "raccostare",
    "raccostino": "raccostare",
    "raccosto": "raccostare",
    "raccostò": "raccostare",
    "raccozza": "raccozzare",
    "raccozzai": "raccozzare",
    "raccozzammo": "raccozzare",
    "raccozzan": "raccozzare",
    "raccozzando": "raccozzare",
    "raccozzano": "raccozzare",
    "raccozzante": "raccozzare",
    "raccozzanti": "raccozzare",
    "raccozzar": "raccozzare",
    "raccozzaron": "raccozzare",
    "raccozzarono": "raccozzare",
    "raccozzasse": "raccozzare",
    "raccozzasser": "raccozzare",
    "raccozzassero": "raccozzare",
    "raccozzassi": "raccozzare",
    "raccozzassimo": "raccozzare",
    "raccozzaste": "raccozzare",
    "raccozzasti": "raccozzare",
    "raccozzata": "raccozzare",
    "raccozzate": "raccozzare",
    "raccozzati": "raccozzare",
    "raccozzato": "raccozzare",
    "raccozzava": "raccozzare",
    "raccozzavamo": "raccozzare",
    "raccozzavan": "raccozzare",
    "raccozzavano": "raccozzare",
    "raccozzavate": "raccozzare",
    "raccozzavi": "raccozzare",
    "raccozzavo": "raccozzare",
    "raccozzerai": "raccozzare",
    "raccozzeran": "raccozzare",
    "raccozzeranno": "raccozzare",
    "raccozzerebbe": "raccozzare",
    "raccozzerebber": "raccozzare",
    "raccozzerebbero": "raccozzare",
    "raccozzerei": "raccozzare",
    "raccozzeremmo": "raccozzare",
    "raccozzeremo": "raccozzare",
    "raccozzereste": "raccozzare",
    "raccozzeresti": "raccozzare",
    "raccozzerete": "raccozzare",
    "raccozzerà": "raccozzare",
    "raccozzerò": "raccozzare",
    "raccozzi": "raccozzare",
    "raccozziamo": "raccozzare",
    "raccozziate": "raccozzare",
    "raccozzin": "raccozzare",
    "raccozzino": "raccozzare",
    "raccozzo": "raccozzare",
    "raccozzò": "raccozzare",
    "raccò": "raccare",
    "rachidea": "rachideo",
    "rachidee": "rachideo",
    "rachidei": "rachideo",
    "rachitica": "rachitico",
    "rachitiche": "rachitico",
    "rachitici": "rachitico",
    "racimola": "racimolare",
    "racimolai": "racimolare",
    "racimolammo": "racimolare",
    "racimolan": "racimolare",
    "racimolando": "racimolare",
    "racimolano": "racimolare",
    "racimolante": "racimolare",
    "racimolanti": "racimolare",
    "racimolar": "racimolare",
    "racimolaron": "racimolare",
    "racimolarono": "racimolare",
    "racimolasse": "racimolare",
    "racimolasser": "racimolare",
    "racimolassero": "racimolare",
    "racimolassi": "racimolare",
    "racimolassimo": "racimolare",
    "racimolaste": "racimolare",
    "racimolasti": "racimolare",
    "racimolata": "racimolare",
    "racimolate": "racimolare",
    "racimolati": "racimolare",
    "racimolato": "racimolare",
    "racimolava": "racimolare",
    "racimolavamo": "racimolare",
    "racimolavan": "racimolare",
    "racimolavano": "racimolare",
    "racimolavate": "racimolare",
    "racimolavi": "racimolare",
    "racimolavo": "racimolare",
    "racimolerai": "racimolare",
    "racimoleran": "racimolare",
    "racimoleranno": "racimolare",
    "racimolerebbe": "racimolare",
    "racimolerebber": "racimolare",
    "racimolerebbero": "racimolare",
    "racimolerei": "racimolare",
    "racimoleremmo": "racimolare",
    "racimoleremo": "racimolare",
    "racimolereste": "racimolare",
    "racimoleresti": "racimolare",
    "racimolerete": "racimolare",
    "racimolerà": "racimolare",
    "racimolerò": "racimolare",
    "racimoli": "racimolare",
    "racimoliamo": "racimolare",
    "racimoliate": "racimolare",
    "racimolin": "racimolare",
    "racimolino": "racimolare",
    "racimolo": "racimolare",
    "racimolò": "racimolare",
    "rada": "rado",
    "radan": "radere",
    "radano": "radere",
    "radaristi": "radarista",
    "raddensa": "raddensare",
    "raddensai": "raddensare",
    "raddensammo": "raddensare",
    "raddensan": "raddensare",
    "raddensando": "raddensare",
    "raddensano": "raddensare",
    "raddensante": "raddensare",
    "raddensanti": "raddensare",
    "raddensar": "raddensare",
    "raddensaron": "raddensare",
    "raddensarono": "raddensare",
    "raddensasse": "raddensare",
    "raddensasser": "raddensare",
    "raddensassero": "raddensare",
    "raddensassi": "raddensare",
    "raddensassimo": "raddensare",
    "raddensaste": "raddensare",
    "raddensasti": "raddensare",
    "raddensata": "raddensare",
    "raddensate": "raddensare",
    "raddensati": "raddensare",
    "raddensato": "raddensare",
    "raddensava": "raddensare",
    "raddensavamo": "raddensare",
    "raddensavan": "raddensare",
    "raddensavano": "raddensare",
    "raddensavate": "raddensare",
    "raddensavi": "raddensare",
    "raddensavo": "raddensare",
    "raddenserai": "raddensare",
    "raddenseran": "raddensare",
    "raddenseranno": "raddensare",
    "raddenserebbe": "raddensare",
    "raddenserebber": "raddensare",
    "raddenserebbero": "raddensare",
    "raddenserei": "raddensare",
    "raddenseremmo": "raddensare",
    "raddenseremo": "raddensare",
    "raddensereste": "raddensare",
    "raddenseresti": "raddensare",
    "raddenserete": "raddensare",
    "raddenserà": "raddensare",
    "raddenserò": "raddensare",
    "raddensi": "raddensare",
    "raddensiamo": "raddensare",
    "raddensiate": "raddensare",
    "raddensin": "raddensare",
    "raddensino": "raddensare",
    "raddenso": "raddensare",
    "raddensò": "raddensare",
    "raddolca": "raddolcire",
    "raddolcan": "raddolcire",
    "raddolcano": "raddolcire",
    "raddolce": "raddolcire",
    "raddolcendo": "raddolcire",
    "raddolcente": "raddolcire",
    "raddolcenti": "raddolcire",
    "raddolci": "raddolcire",
    "raddolciamo": "raddolcire",
    "raddolciate": "raddolcire",
    "raddolcii": "raddolcire",
    "raddolcimmo": "raddolcire",
    "raddolcir": "raddolcire",
    "raddolcirai": "raddolcire",
    "raddolciran": "raddolcire",
    "raddolciranno": "raddolcire",
    "raddolcirebbe": "raddolcire",
    "raddolcirebber": "raddolcire",
    "raddolcirebbero": "raddolcire",
    "raddolcirei": "raddolcire",
    "raddolciremmo": "raddolcire",
    "raddolciremo": "raddolcire",
    "raddolcireste": "raddolcire",
    "raddolciresti": "raddolcire",
    "raddolcirete": "raddolcire",
    "raddolciron": "raddolcire",
    "raddolcirono": "raddolcire",
    "raddolcirà": "raddolcire",
    "raddolcirò": "raddolcire",
    "raddolcisse": "raddolcire",
    "raddolcisser": "raddolcire",
    "raddolcissero": "raddolcire",
    "raddolcissi": "raddolcire",
    "raddolcissimo": "raddolcire",
    "raddolciste": "raddolcire",
    "raddolcisti": "raddolcire",
    "raddolcita": "raddolcire",
    "raddolcite": "raddolcire",
    "raddolciti": "raddolcire",
    "raddolcito": "raddolcire",
    "raddolciva": "raddolcire",
    "raddolcivamo": "raddolcire",
    "raddolcivan": "raddolcire",
    "raddolcivano": "raddolcire",
    "raddolcivate": "raddolcire",
    "raddolcivi": "raddolcire",
    "raddolcivo": "raddolcire",
    "raddolco": "raddolcire",
    "raddolcon": "raddolcire",
    "raddolcono": "raddolcire",
    "raddolcì": "raddolcire",
    "raddoppi": "raddoppio",
    "raddoppia": "raddoppiare",
    "raddoppiai": "raddoppiare",
    "raddoppiamenti": "raddoppiamento",
    "raddoppiammo": "raddoppiare",
    "raddoppiamo": "raddoppiare",
    "raddoppian": "raddoppiare",
    "raddoppiando": "raddoppiare",
    "raddoppiano": "raddoppiare",
    "raddoppiante": "raddoppiare",
    "raddoppianti": "raddoppiare",
    "raddoppiar": "raddoppiare",
    "raddoppiaron": "raddoppiare",
    "raddoppiarono": "raddoppiare",
    "raddoppiasse": "raddoppiare",
    "raddoppiasser": "raddoppiare",
    "raddoppiassero": "raddoppiare",
    "raddoppiassi": "raddoppiare",
    "raddoppiassimo": "raddoppiare",
    "raddoppiaste": "raddoppiare",
    "raddoppiasti": "raddoppiare",
    "raddoppiata": "raddoppiato",
    "raddoppiate": "raddoppiato",
    "raddoppiati": "raddoppiato",
    "raddoppiato": "raddoppiare",
    "raddoppiava": "raddoppiare",
    "raddoppiavamo": "raddoppiare",
    "raddoppiavan": "raddoppiare",
    "raddoppiavano": "raddoppiare",
    "raddoppiavate": "raddoppiare",
    "raddoppiavi": "raddoppiare",
    "raddoppiavo": "raddoppiare",
    "raddoppierai": "raddoppiare",
    "raddoppieran": "raddoppiare",
    "raddoppieranno": "raddoppiare",
    "raddoppierebbe": "raddoppiare",
    "raddoppierebber": "raddoppiare",
    "raddoppierebbero": "raddoppiare",
    "raddoppierei": "raddoppiare",
    "raddoppieremmo": "raddoppiare",
    "raddoppieremo": "raddoppiare",
    "raddoppiereste": "raddoppiare",
    "raddoppieresti": "raddoppiare",
    "raddoppierete": "raddoppiare",
    "raddoppierà": "raddoppiare",
    "raddoppierò": "raddoppiare",
    "raddoppin": "raddoppiare",
    "raddoppino": "raddoppiare",
    "raddoppio": "raddoppiare",
    "raddoppiò": "raddoppiare",
    "raddrizza": "raddrizzare",
    "raddrizzai": "raddrizzare",
    "raddrizzamenti": "raddrizzamento",
    "raddrizzammo": "raddrizzare",
    "raddrizzan": "raddrizzare",
    "raddrizzando": "raddrizzare",
    "raddrizzano": "raddrizzare",
    "raddrizzante": "raddrizzare",
    "raddrizzanti": "raddrizzare",
    "raddrizzar": "raddrizzare",
    "raddrizzaron": "raddrizzare",
    "raddrizzarono": "raddrizzare",
    "raddrizzasse": "raddrizzare",
    "raddrizzasser": "raddrizzare",
    "raddrizzassero": "raddrizzare",
    "raddrizzassi": "raddrizzare",
    "raddrizzassimo": "raddrizzare",
    "raddrizzaste": "raddrizzare",
    "raddrizzasti": "raddrizzare",
    "raddrizzata": "raddrizzare",
    "raddrizzate": "raddrizzare",
    "raddrizzati": "raddrizzare",
    "raddrizzato": "raddrizzare",
    "raddrizzava": "raddrizzare",
    "raddrizzavamo": "raddrizzare",
    "raddrizzavan": "raddrizzare",
    "raddrizzavano": "raddrizzare",
    "raddrizzavate": "raddrizzare",
    "raddrizzavi": "raddrizzare",
    "raddrizzavo": "raddrizzare",
    "raddrizzerai": "raddrizzare",
    "raddrizzeran": "raddrizzare",
    "raddrizzeranno": "raddrizzare",
    "raddrizzerebbe": "raddrizzare",
    "raddrizzerebber": "raddrizzare",
    "raddrizzerebbero": "raddrizzare",
    "raddrizzerei": "raddrizzare",
    "raddrizzeremmo": "raddrizzare",
    "raddrizzeremo": "raddrizzare",
    "raddrizzereste": "raddrizzare",
    "raddrizzeresti": "raddrizzare",
    "raddrizzerete": "raddrizzare",
    "raddrizzerà": "raddrizzare",
    "raddrizzerò": "raddrizzare",
    "raddrizzi": "raddrizzare",
    "raddrizziamo": "raddrizzare",
    "raddrizziate": "raddrizzare",
    "raddrizzin": "raddrizzare",
    "raddrizzino": "raddrizzare",
    "raddrizzo": "raddrizzare",
    "raddrizzò": "raddrizzare",
    "rade": "rado",
    "radei": "radere",
    "rademmo": "radere",
    "radendo": "radere",
    "radente": "radere",
    "radenti": "radere",
    "rader": "radere",
    "raderai": "radere",
    "raderan": "radere",
    "raderanno": "radere",
    "raderebbe": "radere",
    "raderebber": "radere",
    "raderebbero": "radere",
    "raderei": "radere",
    "raderemmo": "radere",
    "raderemo": "radere",
    "radereste": "radere",
    "raderesti": "radere",
    "raderete": "radere",
    "raderon": "radere",
    "raderono": "radere",
    "raderà": "radere",
    "raderò": "radere",
    "radesse": "radere",
    "radesser": "radere",
    "radessero": "radere",
    "radessi": "radere",
    "radessimo": "radere",
    "radeste": "radere",
    "radesti": "radere",
    "radete": "radere",
    "radeva": "radere",
    "radevamo": "radere",
    "radevan": "radere",
    "radevano": "radere",
    "radevate": "radere",
    "radevi": "radere",
    "radevo": "radere",
    "radi": "rado",
    "radia": "radiare",
    "radiai": "radiare",
    "radiali": "radiale",
    "radiammo": "radiare",
    "radiamo": "radiare",
    "radian": "radiare",
    "radiando": "radiare",
    "radiano": "radiare",
    "radiante": "radiare",
    "radianti": "radiare",
    "radiar": "radiare",
    "radiaron": "radiare",
    "radiarono": "radiare",
    "radiasse": "radiare",
    "radiasser": "radiare",
    "radiassero": "radiare",
    "radiassi": "radiare",
    "radiassimo": "radiare",
    "radiaste": "radiare",
    "radiasti": "radiare",
    "radiata": "radiare",
    "radiate": "radiare",
    "radiati": "radiare",
    "radiato": "radiare",
    "radiatori": "radiatore",
    "radiava": "radiare",
    "radiavamo": "radiare",
    "radiavan": "radiare",
    "radiavano": "radiare",
    "radiavate": "radiare",
    "radiavi": "radiare",
    "radiavo": "radiare",
    "radiazioni": "radiazione",
    "radica": "radicare",
    "radicai": "radicare",
    "radicali": "radicale",
    "radicalismi": "radicalismo",
    "radicalizzazioni": "radicalizzazione",
    "radicamenti": "radicamento",
    "radicammo": "radicare",
    "radican": "radicare",
    "radicando": "radicare",
    "radicano": "radicare",
    "radicante": "radicare",
    "radicanti": "radicare",
    "radicar": "radicare",
    "radicaron": "radicare",
    "radicarono": "radicare",
    "radicasse": "radicare",
    "radicasser": "radicare",
    "radicassero": "radicare",
    "radicassi": "radicare",
    "radicassimo": "radicare",
    "radicaste": "radicare",
    "radicasti": "radicare",
    "radicata": "radicato",
    "radicate": "radicato",
    "radicati": "radicato",
    "radicato": "radicare",
    "radicava": "radicare",
    "radicavamo": "radicare",
    "radicavan": "radicare",
    "radicavano": "radicare",
    "radicavate": "radicare",
    "radicavi": "radicare",
    "radicavo": "radicare",
    "radicherai": "radicare",
    "radicheran": "radicare",
    "radicheranno": "radicare",
    "radicherebbe": "radicare",
    "radicherebber": "radicare",
    "radicherebbero": "radicare",
    "radicherei": "radicare",
    "radicheremmo": "radicare",
    "radicheremo": "radicare",
    "radichereste": "radicare",
    "radicheresti": "radicare",
    "radicherete": "radicare",
    "radicherà": "radicare",
    "radicherò": "radicare",
    "radichi": "radicare",
    "radichiamo": "radicare",
    "radichiate": "radicare",
    "radichin": "radicare",
    "radichino": "radicare",
    "radici": "radice",
    "radico": "radicare",
    "radicò": "radicare",
    "radierai": "radiare",
    "radieran": "radiare",
    "radieranno": "radiare",
    "radierebbe": "radiare",
    "radierebber": "radiare",
    "radierebbero": "radiare",
    "radierei": "radiare",
    "radieremmo": "radiare",
    "radieremo": "radiare",
    "radiereste": "radiare",
    "radieresti": "radiare",
    "radierete": "radiare",
    "radierà": "radiare",
    "radierò": "radiare",
    "radii": "radio",
    "radin": "radiare",
    "radino": "radiare",
    "radio": "radiare",
    "radioamatori": "radioamatore",
    "radioascoltatori": "radioascoltatore",
    "radioassista": "radioassistere",
    "radioassistan": "radioassistere",
    "radioassistano": "radioassistere",
    "radioassiste": "radioassistere",
    "radioassistei": "radioassistere",
    "radioassistemmo": "radioassistere",
    "radioassistendo": "radioassistere",
    "radioassistente": "radioassistere",
    "radioassistenti": "radioassistere",
    "radioassistenze": "radioassistenza",
    "radioassister": "radioassistere",
    "radioassisterai": "radioassistere",
    "radioassisteran": "radioassistere",
    "radioassisteranno": "radioassistere",
    "radioassisterebbe": "radioassistere",
    "radioassisterebber": "radioassistere",
    "radioassisterebbero": "radioassistere",
    "radioassisterei": "radioassistere",
    "radioassisteremmo": "radioassistere",
    "radioassisteremo": "radioassistere",
    "radioassistereste": "radioassistere",
    "radioassisteresti": "radioassistere",
    "radioassisterete": "radioassistere",
    "radioassisteron": "radioassistere",
    "radioassisterono": "radioassistere",
    "radioassisterà": "radioassistere",
    "radioassisterò": "radioassistere",
    "radioassistesse": "radioassistere",
    "radioassistesser": "radioassistere",
    "radioassistessero": "radioassistere",
    "radioassistessi": "radioassistere",
    "radioassistessimo": "radioassistere",
    "radioassisteste": "radioassistere",
    "radioassistesti": "radioassistere",
    "radioassistete": "radioassistere",
    "radioassisteva": "radioassistere",
    "radioassistevamo": "radioassistere",
    "radioassistevan": "radioassistere",
    "radioassistevano": "radioassistere",
    "radioassistevate": "radioassistere",
    "radioassistevi": "radioassistere",
    "radioassistevo": "radioassistere",
    "radioassisti": "radioassistere",
    "radioassistiamo": "radioassistere",
    "radioassistiate": "radioassistere",
    "radioassisto": "radioassistere",
    "radioassiston": "radioassistere",
    "radioassistono": "radioassistere",
    "radioassistuta": "radioassistere",
    "radioassistute": "radioassistere",
    "radioassistuti": "radioassistere",
    "radioassistuto": "radioassistere",
    "radioassistè": "radioassistere",
    "radioattiva": "radioattivo",
    "radioattive": "radioattivo",
    "radioattivi": "radioattivo",
    "radiocomanda": "radiocomandare",
    "radiocomandai": "radiocomandare",
    "radiocomandammo": "radiocomandare",
    "radiocomandan": "radiocomandare",
    "radiocomandando": "radiocomandare",
    "radiocomandano": "radiocomandare",
    "radiocomandante": "radiocomandare",
    "radiocomandanti": "radiocomandare",
    "radiocomandar": "radiocomandare",
    "radiocomandaron": "radiocomandare",
    "radiocomandarono": "radiocomandare",
    "radiocomandasse": "radiocomandare",
    "radiocomandasser": "radiocomandare",
    "radiocomandassero": "radiocomandare",
    "radiocomandassi": "radiocomandare",
    "radiocomandassimo": "radiocomandare",
    "radiocomandaste": "radiocomandare",
    "radiocomandasti": "radiocomandare",
    "radiocomandata": "radiocomandato",
    "radiocomandate": "radiocomandato",
    "radiocomandati": "radiocomandato",
    "radiocomandato": "radiocomandare",
    "radiocomandava": "radiocomandare",
    "radiocomandavamo": "radiocomandare",
    "radiocomandavan": "radiocomandare",
    "radiocomandavano": "radiocomandare",
    "radiocomandavate": "radiocomandare",
    "radiocomandavi": "radiocomandare",
    "radiocomandavo": "radiocomandare",
    "radiocomanderai": "radiocomandare",
    "radiocomanderan": "radiocomandare",
    "radiocomanderanno": "radiocomandare",
    "radiocomanderebbe": "radiocomandare",
    "radiocomanderebber": "radiocomandare",
    "radiocomanderebbero": "radiocomandare",
    "radiocomanderei": "radiocomandare",
    "radiocomanderemmo": "radiocomandare",
    "radiocomanderemo": "radiocomandare",
    "radiocomandereste": "radiocomandare",
    "radiocomanderesti": "radiocomandare",
    "radiocomanderete": "radiocomandare",
    "radiocomanderà": "radiocomandare",
    "radiocomanderò": "radiocomandare",
    "radiocomandi": "radiocomandare",
    "radiocomandiamo": "radiocomandare",
    "radiocomandiate": "radiocomandare",
    "radiocomandin": "radiocomandare",
    "radiocomandino": "radiocomandare",
    "radiocomando": "radiocomandare",
    "radiocomandò": "radiocomandare",
    "radiocronache": "radiocronaca",
    "radiocronisti": "radiocronista",
    "radiodiffonda": "radiodiffondere",
    "radiodiffondan": "radiodiffondere",
    "radiodiffondano": "radiodiffondere",
    "radiodiffonde": "radiodiffondere",
    "radiodiffondemmo": "radiodiffondere",
    "radiodiffondendo": "radiodiffondere",
    "radiodiffondente": "radiodiffondere",
    "radiodiffondenti": "radiodiffondere",
    "radiodiffonder": "radiodiffondere",
    "radiodiffonderai": "radiodiffondere",
    "radiodiffonderan": "radiodiffondere",
    "radiodiffonderanno": "radiodiffondere",
    "radiodiffonderebbe": "radiodiffondere",
    "radiodiffonderebber": "radiodiffondere",
    "radiodiffonderebbero": "radiodiffondere",
    "radiodiffonderei": "radiodiffondere",
    "radiodiffonderemmo": "radiodiffondere",
    "radiodiffonderemo": "radiodiffondere",
    "radiodiffondereste": "radiodiffondere",
    "radiodiffonderesti": "radiodiffondere",
    "radiodiffonderete": "radiodiffondere",
    "radiodiffonderà": "radiodiffondere",
    "radiodiffonderò": "radiodiffondere",
    "radiodiffondesse": "radiodiffondere",
    "radiodiffondesser": "radiodiffondere",
    "radiodiffondessero": "radiodiffondere",
    "radiodiffondessi": "radiodiffondere",
    "radiodiffondessimo": "radiodiffondere",
    "radiodiffondeste": "radiodiffondere",
    "radiodiffondesti": "radiodiffondere",
    "radiodiffondete": "radiodiffondere",
    "radiodiffondeva": "radiodiffondere",
    "radiodiffondevamo": "radiodiffondere",
    "radiodiffondevan": "radiodiffondere",
    "radiodiffondevano": "radiodiffondere",
    "radiodiffondevate": "radiodiffondere",
    "radiodiffondevi": "radiodiffondere",
    "radiodiffondevo": "radiodiffondere",
    "radiodiffondi": "radiodiffondere",
    "radiodiffondiamo": "radiodiffondere",
    "radiodiffondiate": "radiodiffondere",
    "radiodiffondo": "radiodiffondere",
    "radiodiffondon": "radiodiffondere",
    "radiodiffondono": "radiodiffondere",
    "radiodiffusa": "radiodiffondere",
    "radiodiffuse": "radiodiffondere",
    "radiodiffuser": "radiodiffondere",
    "radiodiffusero": "radiodiffondere",
    "radiodiffusi": "radiodiffondere",
    "radiodiffusioni": "radiodiffusione",
    "radiodiffuso": "radiodiffondere",
    "radiodrammi": "radiodramma",
    "radioelettrica": "radioelettrico",
    "radioelettriche": "radioelettrico",
    "radioelettrici": "radioelettrico",
    "radiofonica": "radiofonico",
    "radiofoniche": "radiofonico",
    "radiofonici": "radiofonico",
    "radiofonie": "radiofonia",
    "radiogiornali": "radiogiornale",
    "radiogoniometri": "radiogoniometro",
    "radiografa": "radiografare",
    "radiografai": "radiografare",
    "radiografammo": "radiografare",
    "radiografan": "radiografare",
    "radiografando": "radiografare",
    "radiografano": "radiografare",
    "radiografante": "radiografare",
    "radiografanti": "radiografare",
    "radiografar": "radiografare",
    "radiografaron": "radiografare",
    "radiografarono": "radiografare",
    "radiografasse": "radiografare",
    "radiografasser": "radiografare",
    "radiografassero": "radiografare",
    "radiografassi": "radiografare",
    "radiografassimo": "radiografare",
    "radiografaste": "radiografare",
    "radiografasti": "radiografare",
    "radiografata": "radiografare",
    "radiografate": "radiografare",
    "radiografati": "radiografare",
    "radiografato": "radiografare",
    "radiografava": "radiografare",
    "radiografavamo": "radiografare",
    "radiografavan": "radiografare",
    "radiografavano": "radiografare",
    "radiografavate": "radiografare",
    "radiografavi": "radiografare",
    "radiografavo": "radiografare",
    "radiograferai": "radiografare",
    "radiograferan": "radiografare",
    "radiograferanno": "radiografare",
    "radiograferebbe": "radiografare",
    "radiograferebber": "radiografare",
    "radiograferebbero": "radiografare",
    "radiograferei": "radiografare",
    "radiograferemmo": "radiografare",
    "radiograferemo": "radiografare",
    "radiografereste": "radiografare",
    "radiograferesti": "radiografare",
    "radiograferete": "radiografare",
    "radiograferà": "radiografare",
    "radiograferò": "radiografare",
    "radiografi": "radiografare",
    "radiografiamo": "radiografare",
    "radiografiate": "radiografare",
    "radiografica": "radiografico",
    "radiografiche": "radiografico",
    "radiografici": "radiografico",
    "radiografie": "radiografia",
    "radiografin": "radiografare",
    "radiografino": "radiografare",
    "radiografo": "radiografare",
    "radiografò": "radiografare",
    "radioline": "radiolina",
    "radiologi": "radiologo",
    "radiologica": "radiologico",
    "radiologiche": "radiologico",
    "radiologici": "radiologico",
    "radiomicrofoni": "radiomicrofono",
    "radiosa": "radioso",
    "radiose": "radioso",
    "radiosi": "radioso",
    "radiotecnica": "radiotecnico",
    "radiotecniche": "radiotecnico",
    "radiotecnici": "radiotecnico",
    "radiotelefoni": "radiotelefono",
    "radiotelescopi": "radiotelescopio",
    "radiotelevisioni": "radiotelevisione",
    "radiotelevisiva": "radiotelevisivo",
    "radiotelevisive": "radiotelevisivo",
    "radiotelevisivi": "radiotelevisivo",
    "radioterapie": "radioterapia",
    "radiotrasmessa": "radiotrasmettere",
    "radiotrasmesse": "radiotrasmettere",
    "radiotrasmessi": "radiotrasmettere",
    "radiotrasmesso": "radiotrasmettere",
    "radiotrasmetta": "radiotrasmettere",
    "radiotrasmettan": "radiotrasmettere",
    "radiotrasmettano": "radiotrasmettere",
    "radiotrasmette": "radiotrasmettere",
    "radiotrasmettemmo": "radiotrasmettere",
    "radiotrasmettendo": "radiotrasmettere",
    "radiotrasmettente": "radiotrasmettere",
    "radiotrasmettenti": "radiotrasmettere",
    "radiotrasmetter": "radiotrasmettere",
    "radiotrasmetterai": "radiotrasmettere",
    "radiotrasmetteran": "radiotrasmettere",
    "radiotrasmetteranno": "radiotrasmettere",
    "radiotrasmetterebbe": "radiotrasmettere",
    "radiotrasmetterebber": "radiotrasmettere",
    "radiotrasmetterebbero": "radiotrasmettere",
    "radiotrasmetterei": "radiotrasmettere",
    "radiotrasmetteremmo": "radiotrasmettere",
    "radiotrasmetteremo": "radiotrasmettere",
    "radiotrasmettereste": "radiotrasmettere",
    "radiotrasmetteresti": "radiotrasmettere",
    "radiotrasmetterete": "radiotrasmettere",
    "radiotrasmetterà": "radiotrasmettere",
    "radiotrasmetterò": "radiotrasmettere",
    "radiotrasmettesse": "radiotrasmettere",
    "radiotrasmettesser": "radiotrasmettere",
    "radiotrasmettessero": "radiotrasmettere",
    "radiotrasmettessi": "radiotrasmettere",
    "radiotrasmettessimo": "radiotrasmettere",
    "radiotrasmetteste": "radiotrasmettere",
    "radiotrasmettesti": "radiotrasmettere",
    "radiotrasmettete": "radiotrasmettere",
    "radiotrasmetteva": "radiotrasmettere",
    "radiotrasmettevamo": "radiotrasmettere",
    "radiotrasmettevan": "radiotrasmettere",
    "radiotrasmettevano": "radiotrasmettere",
    "radiotrasmettevate": "radiotrasmettere",
    "radiotrasmettevi": "radiotrasmettere",
    "radiotrasmettevo": "radiotrasmettere",
    "radiotrasmetti": "radiotrasmettere",
    "radiotrasmettiamo": "radiotrasmettere",
    "radiotrasmettiate": "radiotrasmettere",
    "radiotrasmetto": "radiotrasmettere",
    "radiotrasmetton": "radiotrasmettere",
    "radiotrasmettono": "radiotrasmettere",
    "radiotrasmise": "radiotrasmettere",
    "radiotrasmiser": "radiotrasmettere",
    "radiotrasmisero": "radiotrasmettere",
    "radiotrasmisi": "radiotrasmettere",
    "radiò": "radiare",
    "rado": "radere",
    "radon": "radere",
    "radono": "radere",
    "raduna": "radunare",
    "radunai": "radunare",
    "radunammo": "radunare",
    "radunan": "radunare",
    "radunando": "radunare",
    "radunano": "radunare",
    "radunante": "radunare",
    "radunanti": "radunare",
    "radunar": "radunare",
    "radunaron": "radunare",
    "radunarono": "radunare",
    "radunasse": "radunare",
    "radunasser": "radunare",
    "radunassero": "radunare",
    "radunassi": "radunare",
    "radunassimo": "radunare",
    "radunaste": "radunare",
    "radunasti": "radunare",
    "radunata": "radunare",
    "radunate": "radunare",
    "radunati": "radunare",
    "radunato": "radunare",
    "radunava": "radunare",
    "radunavamo": "radunare",
    "radunavan": "radunare",
    "radunavano": "radunare",
    "radunavate": "radunare",
    "radunavi": "radunare",
    "radunavo": "radunare",
    "radunerai": "radunare",
    "raduneran": "radunare",
    "raduneranno": "radunare",
    "radunerebbe": "radunare",
    "radunerebber": "radunare",
    "radunerebbero": "radunare",
    "radunerei": "radunare",
    "raduneremmo": "radunare",
    "raduneremo": "radunare",
    "radunereste": "radunare",
    "raduneresti": "radunare",
    "radunerete": "radunare",
    "radunerà": "radunare",
    "radunerò": "radunare",
    "raduni": "raduno",
    "raduniamo": "radunare",
    "raduniate": "radunare",
    "radunin": "radunare",
    "radunino": "radunare",
    "raduno": "radunare",
    "radunò": "radunare",
    "radure": "radura",
    "raduta": "radere",
    "radute": "radere",
    "raduti": "radere",
    "raduto": "radere",
    "radè": "radere",
    "raffazzona": "raffazzonare",
    "raffazzonai": "raffazzonare",
    "raffazzonammo": "raffazzonare",
    "raffazzonan": "raffazzonare",
    "raffazzonando": "raffazzonare",
    "raffazzonano": "raffazzonare",
    "raffazzonante": "raffazzonare",
    "raffazzonanti": "raffazzonare",
    "raffazzonar": "raffazzonare",
    "raffazzonaron": "raffazzonare",
    "raffazzonarono": "raffazzonare",
    "raffazzonasse": "raffazzonare",
    "raffazzonasser": "raffazzonare",
    "raffazzonassero": "raffazzonare",
    "raffazzonassi": "raffazzonare",
    "raffazzonassimo": "raffazzonare",
    "raffazzonaste": "raffazzonare",
    "raffazzonasti": "raffazzonare",
    "raffazzonata": "raffazzonare",
    "raffazzonate": "raffazzonare",
    "raffazzonati": "raffazzonare",
    "raffazzonato": "raffazzonare",
    "raffazzonava": "raffazzonare",
    "raffazzonavamo": "raffazzonare",
    "raffazzonavan": "raffazzonare",
    "raffazzonavano": "raffazzonare",
    "raffazzonavate": "raffazzonare",
    "raffazzonavi": "raffazzonare",
    "raffazzonavo": "raffazzonare",
    "raffazzonerai": "raffazzonare",
    "raffazzoneran": "raffazzonare",
    "raffazzoneranno": "raffazzonare",
    "raffazzonerebbe": "raffazzonare",
    "raffazzonerebber": "raffazzonare",
    "raffazzonerebbero": "raffazzonare",
    "raffazzonerei": "raffazzonare",
    "raffazzoneremmo": "raffazzonare",
    "raffazzoneremo": "raffazzonare",
    "raffazzonereste": "raffazzonare",
    "raffazzoneresti": "raffazzonare",
    "raffazzonerete": "raffazzonare",
    "raffazzonerà": "raffazzonare",
    "raffazzonerò": "raffazzonare",
    "raffazzoni": "raffazzonare",
    "raffazzoniamo": "raffazzonare",
    "raffazzoniate": "raffazzonare",
    "raffazzonin": "raffazzonare",
    "raffazzonino": "raffazzonare",
    "raffazzono": "raffazzonare",
    "raffazzonò": "raffazzonare",
    "rafferma": "raffermo",
    "raffermai": "raffermare",
    "raffermammo": "raffermare",
    "rafferman": "raffermare",
    "raffermando": "raffermare",
    "raffermano": "raffermare",
    "raffermante": "raffermare",
    "raffermanti": "raffermare",
    "raffermar": "raffermare",
    "raffermaron": "raffermare",
    "raffermarono": "raffermare",
    "raffermasse": "raffermare",
    "raffermasser": "raffermare",
    "raffermassero": "raffermare",
    "raffermassi": "raffermare",
    "raffermassimo": "raffermare",
    "raffermaste": "raffermare",
    "raffermasti": "raffermare",
    "raffermata": "raffermare",
    "raffermate": "raffermare",
    "raffermati": "raffermare",
    "raffermato": "raffermare",
    "raffermava": "raffermare",
    "raffermavamo": "raffermare",
    "raffermavan": "raffermare",
    "raffermavano": "raffermare",
    "raffermavate": "raffermare",
    "raffermavi": "raffermare",
    "raffermavo": "raffermare",
    "rafferme": "raffermo",
    "raffermerai": "raffermare",
    "raffermeran": "raffermare",
    "raffermeranno": "raffermare",
    "raffermerebbe": "raffermare",
    "raffermerebber": "raffermare",
    "raffermerebbero": "raffermare",
    "raffermerei": "raffermare",
    "raffermeremmo": "raffermare",
    "raffermeremo": "raffermare",
    "raffermereste": "raffermare",
    "raffermeresti": "raffermare",
    "raffermerete": "raffermare",
    "raffermerà": "raffermare",
    "raffermerò": "raffermare",
    "raffermi": "raffermo",
    "raffermiamo": "raffermare",
    "raffermiate": "raffermare",
    "raffermin": "raffermare",
    "raffermino": "raffermare",
    "raffermo": "raffermare",
    "raffermò": "raffermare",
    "raffiche": "raffica",
    "raffigura": "raffigurare",
    "raffigurai": "raffigurare",
    "raffigurammo": "raffigurare",
    "raffiguran": "raffigurare",
    "raffigurando": "raffigurare",
    "raffigurano": "raffigurare",
    "raffigurante": "raffigurare",
    "raffiguranti": "raffigurare",
    "raffigurar": "raffigurare",
    "raffiguraron": "raffigurare",
    "raffigurarono": "raffigurare",
    "raffigurasse": "raffigurare",
    "raffigurasser": "raffigurare",
    "raffigurassero": "raffigurare",
    "raffigurassi": "raffigurare",
    "raffigurassimo": "raffigurare",
    "raffiguraste": "raffigurare",
    "raffigurasti": "raffigurare",
    "raffigurata": "raffigurare",
    "raffigurate": "raffigurare",
    "raffigurati": "raffigurare",
    "raffigurato": "raffigurare",
    "raffigurava": "raffigurare",
    "raffiguravamo": "raffigurare",
    "raffiguravan": "raffigurare",
    "raffiguravano": "raffigurare",
    "raffiguravate": "raffigurare",
    "raffiguravi": "raffigurare",
    "raffiguravo": "raffigurare",
    "raffigurazioni": "raffigurazione",
    "raffigurerai": "raffigurare",
    "raffigureran": "raffigurare",
    "raffigureranno": "raffigurare",
    "raffigurerebbe": "raffigurare",
    "raffigurerebber": "raffigurare",
    "raffigurerebbero": "raffigurare",
    "raffigurerei": "raffigurare",
    "raffigureremmo": "raffigurare",
    "raffigureremo": "raffigurare",
    "raffigurereste": "raffigurare",
    "raffigureresti": "raffigurare",
    "raffigurerete": "raffigurare",
    "raffigurerà": "raffigurare",
    "raffigurerò": "raffigurare",
    "raffiguri": "raffigurare",
    "raffiguriamo": "raffigurare",
    "raffiguriate": "raffigurare",
    "raffigurin": "raffigurare",
    "raffigurino": "raffigurare",
    "raffiguro": "raffigurare",
    "raffigurò": "raffigurare",
    "raffina": "raffinare",
    "raffinai": "raffinare",
    "raffinammo": "raffinare",
    "raffinan": "raffinare",
    "raffinando": "raffinare",
    "raffinano": "raffinare",
    "raffinante": "raffinare",
    "raffinanti": "raffinare",
    "raffinar": "raffinare",
    "raffinaron": "raffinare",
    "raffinarono": "raffinare",
    "raffinasse": "raffinare",
    "raffinasser": "raffinare",
    "raffinassero": "raffinare",
    "raffinassi": "raffinare",
    "raffinassimo": "raffinare",
    "raffinaste": "raffinare",
    "raffinasti": "raffinare",
    "raffinata": "raffinato",
    "raffinate": "raffinato",
    "raffinatezze": "raffinatezza",
    "raffinati": "raffinato",
    "raffinato": "raffinare",
    "raffinatori": "raffinatore",
    "raffinava": "raffinare",
    "raffinavamo": "raffinare",
    "raffinavan": "raffinare",
    "raffinavano": "raffinare",
    "raffinavate": "raffinare",
    "raffinavi": "raffinare",
    "raffinavo": "raffinare",
    "raffinazioni": "raffinazione",
    "raffinerai": "raffinare",
    "raffineran": "raffinare",
    "raffineranno": "raffinare",
    "raffinerebbe": "raffinare",
    "raffinerebber": "raffinare",
    "raffinerebbero": "raffinare",
    "raffinerei": "raffinare",
    "raffineremmo": "raffinare",
    "raffineremo": "raffinare",
    "raffinereste": "raffinare",
    "raffineresti": "raffinare",
    "raffinerete": "raffinare",
    "raffinerie": "raffineria",
    "raffinerà": "raffinare",
    "raffinerò": "raffinare",
    "raffini": "raffinare",
    "raffiniamo": "raffinare",
    "raffiniate": "raffinare",
    "raffinin": "raffinare",
    "raffinino": "raffinare",
    "raffino": "raffinare",
    "raffinò": "raffinare",
    "rafforza": "rafforzare",
    "rafforzai": "rafforzare",
    "rafforzamenti": "rafforzamento",
    "rafforzammo": "rafforzare",
    "rafforzan": "rafforzare",
    "rafforzando": "rafforzare",
    "rafforzano": "rafforzare",
    "rafforzante": "rafforzare",
    "rafforzanti": "rafforzare",
    "rafforzar": "rafforzare",
    "rafforzaron": "rafforzare",
    "rafforzarono": "rafforzare",
    "rafforzasse": "rafforzare",
    "rafforzasser": "rafforzare",
    "rafforzassero": "rafforzare",
    "rafforzassi": "rafforzare",
    "rafforzassimo": "rafforzare",
    "rafforzaste": "rafforzare",
    "rafforzasti": "rafforzare",
    "rafforzata": "rafforzato",
    "rafforzate": "rafforzato",
    "rafforzati": "rafforzato",
    "rafforzativa": "rafforzativo",
    "rafforzative": "rafforzativo",
    "rafforzativi": "rafforzativo",
    "rafforzato": "rafforzare",
    "rafforzava": "rafforzare",
    "rafforzavamo": "rafforzare",
    "rafforzavan": "rafforzare",
    "rafforzavano": "rafforzare",
    "rafforzavate": "rafforzare",
    "rafforzavi": "rafforzare",
    "rafforzavo": "rafforzare",
    "rafforzerai": "rafforzare",
    "rafforzeran": "rafforzare",
    "rafforzeranno": "rafforzare",
    "rafforzerebbe": "rafforzare",
    "rafforzerebber": "rafforzare",
    "rafforzerebbero": "rafforzare",
    "rafforzerei": "rafforzare",
    "rafforzeremmo": "rafforzare",
    "rafforzeremo": "rafforzare",
    "rafforzereste": "rafforzare",
    "rafforzeresti": "rafforzare",
    "rafforzerete": "rafforzare",
    "rafforzerà": "rafforzare",
    "rafforzerò": "rafforzare",
    "rafforzi": "rafforzare",
    "rafforziamo": "rafforzare",
    "rafforziate": "rafforzare",
    "rafforzin": "rafforzare",
    "rafforzino": "rafforzare",
    "rafforzo": "rafforzare",
    "rafforzò": "rafforzare",
    "raffredda": "raffreddare",
    "raffreddai": "raffreddare",
    "raffreddamenti": "raffreddamento",
    "raffreddammo": "raffreddare",
    "raffreddan": "raffreddare",
    "raffreddando": "raffreddare",
    "raffreddano": "raffreddare",
    "raffreddante": "raffreddare",
    "raffreddanti": "raffreddare",
    "raffreddar": "raffreddare",
    "raffreddaron": "raffreddare",
    "raffreddarono": "raffreddare",
    "raffreddasse": "raffreddare",
    "raffreddasser": "raffreddare",
    "raffreddassero": "raffreddare",
    "raffreddassi": "raffreddare",
    "raffreddassimo": "raffreddare",
    "raffreddaste": "raffreddare",
    "raffreddasti": "raffreddare",
    "raffreddata": "raffreddato",
    "raffreddate": "raffreddato",
    "raffreddati": "raffreddato",
    "raffreddato": "raffreddare",
    "raffreddava": "raffreddare",
    "raffreddavamo": "raffreddare",
    "raffreddavan": "raffreddare",
    "raffreddavano": "raffreddare",
    "raffreddavate": "raffreddare",
    "raffreddavi": "raffreddare",
    "raffreddavo": "raffreddare",
    "raffredderai": "raffreddare",
    "raffredderan": "raffreddare",
    "raffredderanno": "raffreddare",
    "raffredderebbe": "raffreddare",
    "raffredderebber": "raffreddare",
    "raffredderebbero": "raffreddare",
    "raffredderei": "raffreddare",
    "raffredderemmo": "raffreddare",
    "raffredderemo": "raffreddare",
    "raffreddereste": "raffreddare",
    "raffredderesti": "raffreddare",
    "raffredderete": "raffreddare",
    "raffredderà": "raffreddare",
    "raffredderò": "raffreddare",
    "raffreddi": "raffreddare",
    "raffreddiamo": "raffreddare",
    "raffreddiate": "raffreddare",
    "raffreddin": "raffreddare",
    "raffreddino": "raffreddare",
    "raffreddo": "raffreddare",
    "raffreddori": "raffreddore",
    "raffreddò": "raffreddare",
    "raffrena": "raffrenare",
    "raffrenai": "raffrenare",
    "raffrenammo": "raffrenare",
    "raffrenan": "raffrenare",
    "raffrenando": "raffrenare",
    "raffrenano": "raffrenare",
    "raffrenante": "raffrenare",
    "raffrenanti": "raffrenare",
    "raffrenar": "raffrenare",
    "raffrenaron": "raffrenare",
    "raffrenarono": "raffrenare",
    "raffrenasse": "raffrenare",
    "raffrenasser": "raffrenare",
    "raffrenassero": "raffrenare",
    "raffrenassi": "raffrenare",
    "raffrenassimo": "raffrenare",
    "raffrenaste": "raffrenare",
    "raffrenasti": "raffrenare",
    "raffrenata": "raffrenare",
    "raffrenate": "raffrenare",
    "raffrenati": "raffrenare",
    "raffrenato": "raffrenare",
    "raffrenava": "raffrenare",
    "raffrenavamo": "raffrenare",
    "raffrenavan": "raffrenare",
    "raffrenavano": "raffrenare",
    "raffrenavate": "raffrenare",
    "raffrenavi": "raffrenare",
    "raffrenavo": "raffrenare",
    "raffrenerai": "raffrenare",
    "raffreneran": "raffrenare",
    "raffreneranno": "raffrenare",
    "raffrenerebbe": "raffrenare",
    "raffrenerebber": "raffrenare",
    "raffrenerebbero": "raffrenare",
    "raffrenerei": "raffrenare",
    "raffreneremmo": "raffrenare",
    "raffreneremo": "raffrenare",
    "raffrenereste": "raffrenare",
    "raffreneresti": "raffrenare",
    "raffrenerete": "raffrenare",
    "raffrenerà": "raffrenare",
    "raffrenerò": "raffrenare",
    "raffreni": "raffrenare",
    "raffreniamo": "raffrenare",
    "raffreniate": "raffrenare",
    "raffrenin": "raffrenare",
    "raffrenino": "raffrenare",
    "raffreno": "raffrenare",
    "raffrenò": "raffrenare",
    "raffronta": "raffrontare",
    "raffrontai": "raffrontare",
    "raffrontammo": "raffrontare",
    "raffrontan": "raffrontare",
    "raffrontando": "raffrontare",
    "raffrontano": "raffrontare",
    "raffrontante": "raffrontare",
    "raffrontanti": "raffrontare",
    "raffrontar": "raffrontare",
    "raffrontaron": "raffrontare",
    "raffrontarono": "raffrontare",
    "raffrontasse": "raffrontare",
    "raffrontasser": "raffrontare",
    "raffrontassero": "raffrontare",
    "raffrontassi": "raffrontare",
    "raffrontassimo": "raffrontare",
    "raffrontaste": "raffrontare",
    "raffrontasti": "raffrontare",
    "raffrontata": "raffrontare",
    "raffrontate": "raffrontare",
    "raffrontati": "raffrontare",
    "raffrontato": "raffrontare",
    "raffrontava": "raffrontare",
    "raffrontavamo": "raffrontare",
    "raffrontavan": "raffrontare",
    "raffrontavano": "raffrontare",
    "raffrontavate": "raffrontare",
    "raffrontavi": "raffrontare",
    "raffrontavo": "raffrontare",
    "raffronterai": "raffrontare",
    "raffronteran": "raffrontare",
    "raffronteranno": "raffrontare",
    "raffronterebbe": "raffrontare",
    "raffronterebber": "raffrontare",
    "raffronterebbero": "raffrontare",
    "raffronterei": "raffrontare",
    "raffronteremmo": "raffrontare",
    "raffronteremo": "raffrontare",
    "raffrontereste": "raffrontare",
    "raffronteresti": "raffrontare",
    "raffronterete": "raffrontare",
    "raffronterà": "raffrontare",
    "raffronterò": "raffrontare",
    "raffronti": "raffronto",
    "raffrontiamo": "raffrontare",
    "raffrontiate": "raffrontare",
    "raffrontin": "raffrontare",
    "raffrontino": "raffrontare",
    "raffronto": "raffrontare",
    "raffrontò": "raffrontare",
    "ragazzacci": "ragazzaccio",
    "ragazzate": "ragazzata",
    "ragazze": "ragazza",
    "ragazzette": "ragazzetta",
    "ragazzetti": "ragazzetto",
    "ragazzi": "ragazzo",
    "ragazzine": "ragazzina",
    "ragazzini": "ragazzino",
    "ragazzone": "ragazzona",
    "ragazzoni": "ragazzone",
    "ragazzotte": "ragazzotta",
    "ragazzotti": "ragazzotto",
    "raggela": "raggelare",
    "raggelai": "raggelare",
    "raggelammo": "raggelare",
    "raggelan": "raggelare",
    "raggelando": "raggelare",
    "raggelano": "raggelare",
    "raggelante": "raggelare",
    "raggelanti": "raggelare",
    "raggelar": "raggelare",
    "raggelaron": "raggelare",
    "raggelarono": "raggelare",
    "raggelasse": "raggelare",
    "raggelasser": "raggelare",
    "raggelassero": "raggelare",
    "raggelassi": "raggelare",
    "raggelassimo": "raggelare",
    "raggelaste": "raggelare",
    "raggelasti": "raggelare",
    "raggelata": "raggelare",
    "raggelate": "raggelare",
    "raggelati": "raggelare",
    "raggelato": "raggelare",
    "raggelava": "raggelare",
    "raggelavamo": "raggelare",
    "raggelavan": "raggelare",
    "raggelavano": "raggelare",
    "raggelavate": "raggelare",
    "raggelavi": "raggelare",
    "raggelavo": "raggelare",
    "raggelerai": "raggelare",
    "raggeleran": "raggelare",
    "raggeleranno": "raggelare",
    "raggelerebbe": "raggelare",
    "raggelerebber": "raggelare",
    "raggelerebbero": "raggelare",
    "raggelerei": "raggelare",
    "raggeleremmo": "raggelare",
    "raggeleremo": "raggelare",
    "raggelereste": "raggelare",
    "raggeleresti": "raggelare",
    "raggelerete": "raggelare",
    "raggelerà": "raggelare",
    "raggelerò": "raggelare",
    "raggeli": "raggelare",
    "raggeliamo": "raggelare",
    "raggeliate": "raggelare",
    "raggelin": "raggelare",
    "raggelino": "raggelare",
    "raggelo": "raggelare",
    "raggelò": "raggelare",
    "raggerai": "raggiare",
    "raggeran": "raggiare",
    "raggeranno": "raggiare",
    "raggerebbe": "raggiare",
    "raggerebber": "raggiare",
    "raggerebbero": "raggiare",
    "raggerei": "raggiare",
    "raggeremmo": "raggiare",
    "raggeremo": "raggiare",
    "raggereste": "raggiare",
    "raggeresti": "raggiare",
    "raggerete": "raggiare",
    "raggerà": "raggiare",
    "raggerò": "raggiare",
    "raggi": "raggio",
    "raggia": "raggiare",
    "raggiai": "raggiare",
    "raggiammo": "raggiare",
    "raggiamo": "raggiare",
    "raggian": "raggiare",
    "raggiando": "raggiare",
    "raggiano": "raggiare",
    "raggiante": "raggiare",
    "raggianti": "raggiare",
    "raggiar": "raggiare",
    "raggiaron": "raggiare",
    "raggiarono": "raggiare",
    "raggiasse": "raggiare",
    "raggiasser": "raggiare",
    "raggiassero": "raggiare",
    "raggiassi": "raggiare",
    "raggiassimo": "raggiare",
    "raggiaste": "raggiare",
    "raggiasti": "raggiare",
    "raggiata": "raggiare",
    "raggiate": "raggiare",
    "raggiati": "raggiare",
    "raggiato": "raggiare",
    "raggiava": "raggiare",
    "raggiavamo": "raggiare",
    "raggiavan": "raggiare",
    "raggiavano": "raggiare",
    "raggiavate": "raggiare",
    "raggiavi": "raggiare",
    "raggiavo": "raggiare",
    "raggin": "raggiare",
    "raggino": "raggiare",
    "raggio": "raggiare",
    "raggira": "raggirare",
    "raggirai": "raggirare",
    "raggirammo": "raggirare",
    "raggiran": "raggirare",
    "raggirando": "raggirare",
    "raggirano": "raggirare",
    "raggirante": "raggirare",
    "raggiranti": "raggirare",
    "raggirar": "raggirare",
    "raggiraron": "raggirare",
    "raggirarono": "raggirare",
    "raggirasse": "raggirare",
    "raggirasser": "raggirare",
    "raggirassero": "raggirare",
    "raggirassi": "raggirare",
    "raggirassimo": "raggirare",
    "raggiraste": "raggirare",
    "raggirasti": "raggirare",
    "raggirata": "raggirare",
    "raggirate": "raggirare",
    "raggirati": "raggirare",
    "raggirato": "raggirare",
    "raggirava": "raggirare",
    "raggiravamo": "raggirare",
    "raggiravan": "raggirare",
    "raggiravano": "raggirare",
    "raggiravate": "raggirare",
    "raggiravi": "raggirare",
    "raggiravo": "raggirare",
    "raggirerai": "raggirare",
    "raggireran": "raggirare",
    "raggireranno": "raggirare",
    "raggirerebbe": "raggirare",
    "raggirerebber": "raggirare",
    "raggirerebbero": "raggirare",
    "raggirerei": "raggirare",
    "raggireremmo": "raggirare",
    "raggireremo": "raggirare",
    "raggirereste": "raggirare",
    "raggireresti": "raggirare",
    "raggirerete": "raggirare",
    "raggirerà": "raggirare",
    "raggirerò": "raggirare",
    "raggiri": "raggiro",
    "raggiriamo": "raggirare",
    "raggiriate": "raggirare",
    "raggirin": "raggirare",
    "raggirino": "raggirare",
    "raggiro": "raggirare",
    "raggirò": "raggirare",
    "raggiunga": "raggiungere",
    "raggiungan": "raggiungere",
    "raggiungano": "raggiungere",
    "raggiunge": "raggiungere",
    "raggiungemmo": "raggiungere",
    "raggiungendo": "raggiungere",
    "raggiungente": "raggiungere",
    "raggiungenti": "raggiungere",
    "raggiunger": "raggiungere",
    "raggiungerai": "raggiungere",
    "raggiungeran": "raggiungere",
    "raggiungeranno": "raggiungere",
    "raggiungerebbe": "raggiungere",
    "raggiungerebber": "raggiungere",
    "raggiungerebbero": "raggiungere",
    "raggiungerei": "raggiungere",
    "raggiungeremmo": "raggiungere",
    "raggiungeremo": "raggiungere",
    "raggiungereste": "raggiungere",
    "raggiungeresti": "raggiungere",
    "raggiungerete": "raggiungere",
    "raggiungerà": "raggiungere",
    "raggiungerò": "raggiungere",
    "raggiungesse": "raggiungere",
    "raggiungesser": "raggiungere",
    "raggiungessero": "raggiungere",
    "raggiungessi": "raggiungere",
    "raggiungessimo": "raggiungere",
    "raggiungeste": "raggiungere",
    "raggiungesti": "raggiungere",
    "raggiungete": "raggiungere",
    "raggiungeva": "raggiungere",
    "raggiungevamo": "raggiungere",
    "raggiungevan": "raggiungere",
    "raggiungevano": "raggiungere",
    "raggiungevate": "raggiungere",
    "raggiungevi": "raggiungere",
    "raggiungevo": "raggiungere",
    "raggiungi": "raggiungere",
    "raggiungiamo": "raggiungere",
    "raggiungiate": "raggiungere",
    "raggiungibili": "raggiungibile",
    "raggiungimenti": "raggiungimento",
    "raggiungo": "raggiungere",
    "raggiungon": "raggiungere",
    "raggiungono": "raggiungere",
    "raggiunse": "raggiungere",
    "raggiunser": "raggiungere",
    "raggiunsero": "raggiungere",
    "raggiunsi": "raggiungere",
    "raggiunta": "raggiungere",
    "raggiunte": "raggiungere",
    "raggiunti": "raggiungere",
    "raggiunto": "raggiungere",
    "raggiusta": "raggiustare",
    "raggiustai": "raggiustare",
    "raggiustammo": "raggiustare",
    "raggiustan": "raggiustare",
    "raggiustando": "raggiustare",
    "raggiustano": "raggiustare",
    "raggiustante": "raggiustare",
    "raggiustanti": "raggiustare",
    "raggiustar": "raggiustare",
    "raggiustaron": "raggiustare",
    "raggiustarono": "raggiustare",
    "raggiustasse": "raggiustare",
    "raggiustasser": "raggiustare",
    "raggiustassero": "raggiustare",
    "raggiustassi": "raggiustare",
    "raggiustassimo": "raggiustare",
    "raggiustaste": "raggiustare",
    "raggiustasti": "raggiustare",
    "raggiustata": "raggiustare",
    "raggiustate": "raggiustare",
    "raggiustati": "raggiustare",
    "raggiustato": "raggiustare",
    "raggiustava": "raggiustare",
    "raggiustavamo": "raggiustare",
    "raggiustavan": "raggiustare",
    "raggiustavano": "raggiustare",
    "raggiustavate": "raggiustare",
    "raggiustavi": "raggiustare",
    "raggiustavo": "raggiustare",
    "raggiusterai": "raggiustare",
    "raggiusteran": "raggiustare",
    "raggiusteranno": "raggiustare",
    "raggiusterebbe": "raggiustare",
    "raggiusterebber": "raggiustare",
    "raggiusterebbero": "raggiustare",
    "raggiusterei": "raggiustare",
    "raggiusteremmo": "raggiustare",
    "raggiusteremo": "raggiustare",
    "raggiustereste": "raggiustare",
    "raggiusteresti": "raggiustare",
    "raggiusterete": "raggiustare",
    "raggiusterà": "raggiustare",
    "raggiusterò": "raggiustare",
    "raggiusti": "raggiustare",
    "raggiustiamo": "raggiustare",
    "raggiustiate": "raggiustare",
    "raggiustin": "raggiustare",
    "raggiustino": "raggiustare",
    "raggiusto": "raggiustare",
    "raggiustò": "raggiustare",
    "raggiò": "raggiare",
    "raggomitola": "raggomitolare",
    "raggomitolai": "raggomitolare",
    "raggomitolammo": "raggomitolare",
    "raggomitolan": "raggomitolare",
    "raggomitolando": "raggomitolare",
    "raggomitolano": "raggomitolare",
    "raggomitolante": "raggomitolare",
    "raggomitolanti": "raggomitolare",
    "raggomitolar": "raggomitolare",
    "raggomitolaron": "raggomitolare",
    "raggomitolarono": "raggomitolare",
    "raggomitolasse": "raggomitolare",
    "raggomitolasser": "raggomitolare",
    "raggomitolassero": "raggomitolare",
    "raggomitolassi": "raggomitolare",
    "raggomitolassimo": "raggomitolare",
    "raggomitolaste": "raggomitolare",
    "raggomitolasti": "raggomitolare",
    "raggomitolata": "raggomitolare",
    "raggomitolate": "raggomitolare",
    "raggomitolati": "raggomitolare",
    "raggomitolato": "raggomitolare",
    "raggomitolava": "raggomitolare",
    "raggomitolavamo": "raggomitolare",
    "raggomitolavan": "raggomitolare",
    "raggomitolavano": "raggomitolare",
    "raggomitolavate": "raggomitolare",
    "raggomitolavi": "raggomitolare",
    "raggomitolavo": "raggomitolare",
    "raggomitolerai": "raggomitolare",
    "raggomitoleran": "raggomitolare",
    "raggomitoleranno": "raggomitolare",
    "raggomitolerebbe": "raggomitolare",
    "raggomitolerebber": "raggomitolare",
    "raggomitolerebbero": "raggomitolare",
    "raggomitolerei": "raggomitolare",
    "raggomitoleremmo": "raggomitolare",
    "raggomitoleremo": "raggomitolare",
    "raggomitolereste": "raggomitolare",
    "raggomitoleresti": "raggomitolare",
    "raggomitolerete": "raggomitolare",
    "raggomitolerà": "raggomitolare",
    "raggomitolerò": "raggomitolare",
    "raggomitoli": "raggomitolare",
    "raggomitoliamo": "raggomitolare",
    "raggomitoliate": "raggomitolare",
    "raggomitolin": "raggomitolare",
    "raggomitolino": "raggomitolare",
    "raggomitolo": "raggomitolare",
    "raggomitolò": "raggomitolare",
    "raggranella": "raggranellare",
    "raggranellai": "raggranellare",
    "raggranellammo": "raggranellare",
    "raggranellan": "raggranellare",
    "raggranellando": "raggranellare",
    "raggranellano": "raggranellare",
    "raggranellante": "raggranellare",
    "raggranellanti": "raggranellare",
    "raggranellar": "raggranellare",
    "raggranellaron": "raggranellare",
    "raggranellarono": "raggranellare",
    "raggranellasse": "raggranellare",
    "raggranellasser": "raggranellare",
    "raggranellassero": "raggranellare",
    "raggranellassi": "raggranellare",
    "raggranellassimo": "raggranellare",
    "raggranellaste": "raggranellare",
    "raggranellasti": "raggranellare",
    "raggranellata": "raggranellare",
    "raggranellate": "raggranellare",
    "raggranellati": "raggranellare",
    "raggranellato": "raggranellare",
    "raggranellava": "raggranellare",
    "raggranellavamo": "raggranellare",
    "raggranellavan": "raggranellare",
    "raggranellavano": "raggranellare",
    "raggranellavate": "raggranellare",
    "raggranellavi": "raggranellare",
    "raggranellavo": "raggranellare",
    "raggranellerai": "raggranellare",
    "raggranelleran": "raggranellare",
    "raggranelleranno": "raggranellare",
    "raggranellerebbe": "raggranellare",
    "raggranellerebber": "raggranellare",
    "raggranellerebbero": "raggranellare",
    "raggranellerei": "raggranellare",
    "raggranelleremmo": "raggranellare",
    "raggranelleremo": "raggranellare",
    "raggranellereste": "raggranellare",
    "raggranelleresti": "raggranellare",
    "raggranellerete": "raggranellare",
    "raggranellerà": "raggranellare",
    "raggranellerò": "raggranellare",
    "raggranelli": "raggranellare",
    "raggranelliamo": "raggranellare",
    "raggranelliate": "raggranellare",
    "raggranellin": "raggranellare",
    "raggranellino": "raggranellare",
    "raggranello": "raggranellare",
    "raggranellò": "raggranellare",
    "raggrinza": "raggrinzire",
    "raggrinzai": "raggrinzare",
    "raggrinzammo": "raggrinzare",
    "raggrinzan": "raggrinzire",
    "raggrinzando": "raggrinzare",
    "raggrinzano": "raggrinzire",
    "raggrinzante": "raggrinzare",
    "raggrinzanti": "raggrinzare",
    "raggrinzar": "raggrinzare",
    "raggrinzaron": "raggrinzare",
    "raggrinzarono": "raggrinzare",
    "raggrinzasse": "raggrinzare",
    "raggrinzasser": "raggrinzare",
    "raggrinzassero": "raggrinzare",
    "raggrinzassi": "raggrinzare",
    "raggrinzassimo": "raggrinzare",
    "raggrinzaste": "raggrinzare",
    "raggrinzasti": "raggrinzare",
    "raggrinzata": "raggrinzare",
    "raggrinzate": "raggrinzare",
    "raggrinzati": "raggrinzare",
    "raggrinzato": "raggrinzare",
    "raggrinzava": "raggrinzare",
    "raggrinzavamo": "raggrinzare",
    "raggrinzavan": "raggrinzare",
    "raggrinzavano": "raggrinzare",
    "raggrinzavate": "raggrinzare",
    "raggrinzavi": "raggrinzare",
    "raggrinzavo": "raggrinzare",
    "raggrinze": "raggrinzire",
    "raggrinzendo": "raggrinzire",
    "raggrinzente": "raggrinzire",
    "raggrinzenti": "raggrinzire",
    "raggrinzerai": "raggrinzare",
    "raggrinzeran": "raggrinzare",
    "raggrinzeranno": "raggrinzare",
    "raggrinzerebbe": "raggrinzare",
    "raggrinzerebber": "raggrinzare",
    "raggrinzerebbero": "raggrinzare",
    "raggrinzerei": "raggrinzare",
    "raggrinzeremmo": "raggrinzare",
    "raggrinzeremo": "raggrinzare",
    "raggrinzereste": "raggrinzare",
    "raggrinzeresti": "raggrinzare",
    "raggrinzerete": "raggrinzare",
    "raggrinzerà": "raggrinzare",
    "raggrinzerò": "raggrinzare",
    "raggrinzi": "raggrinzire",
    "raggrinziamo": "raggrinzire",
    "raggrinziate": "raggrinzire",
    "raggrinzii": "raggrinzire",
    "raggrinzimmo": "raggrinzire",
    "raggrinzin": "raggrinzare",
    "raggrinzino": "raggrinzare",
    "raggrinzir": "raggrinzire",
    "raggrinzirai": "raggrinzire",
    "raggrinziran": "raggrinzire",
    "raggrinziranno": "raggrinzire",
    "raggrinzirebbe": "raggrinzire",
    "raggrinzirebber": "raggrinzire",
    "raggrinzirebbero": "raggrinzire",
    "raggrinzirei": "raggrinzire",
    "raggrinziremmo": "raggrinzire",
    "raggrinziremo": "raggrinzire",
    "raggrinzireste": "raggrinzire",
    "raggrinziresti": "raggrinzire",
    "raggrinzirete": "raggrinzire",
    "raggrinziron": "raggrinzire",
    "raggrinzirono": "raggrinzire",
    "raggrinzirà": "raggrinzire",
    "raggrinzirò": "raggrinzire",
    "raggrinzisse": "raggrinzire",
    "raggrinzisser": "raggrinzire",
    "raggrinzissero": "raggrinzire",
    "raggrinzissi": "raggrinzire",
    "raggrinzissimo": "raggrinzire",
    "raggrinziste": "raggrinzire",
    "raggrinzisti": "raggrinzire",
    "raggrinzita": "raggrinzire",
    "raggrinzite": "raggrinzire",
    "raggrinziti": "raggrinzire",
    "raggrinzito": "raggrinzire",
    "raggrinziva": "raggrinzire",
    "raggrinzivamo": "raggrinzire",
    "raggrinzivan": "raggrinzire",
    "raggrinzivano": "raggrinzire",
    "raggrinzivate": "raggrinzire",
    "raggrinzivi": "raggrinzire",
    "raggrinzivo": "raggrinzire",
    "raggrinzo": "raggrinzire",
    "raggrinzon": "raggrinzire",
    "raggrinzono": "raggrinzire",
    "raggrinzì": "raggrinzire",
    "raggrinzò": "raggrinzare",
    "raggruma": "raggrumare",
    "raggrumai": "raggrumare",
    "raggrumammo": "raggrumare",
    "raggruman": "raggrumare",
    "raggrumando": "raggrumare",
    "raggrumano": "raggrumare",
    "raggrumante": "raggrumare",
    "raggrumanti": "raggrumare",
    "raggrumar": "raggrumare",
    "raggrumaron": "raggrumare",
    "raggrumarono": "raggrumare",
    "raggrumasse": "raggrumare",
    "raggrumasser": "raggrumare",
    "raggrumassero": "raggrumare",
    "raggrumassi": "raggrumare",
    "raggrumassimo": "raggrumare",
    "raggrumaste": "raggrumare",
    "raggrumasti": "raggrumare",
    "raggrumata": "raggrumare",
    "raggrumate": "raggrumare",
    "raggrumati": "raggrumare",
    "raggrumato": "raggrumare",
    "raggrumava": "raggrumare",
    "raggrumavamo": "raggrumare",
    "raggrumavan": "raggrumare",
    "raggrumavano": "raggrumare",
    "raggrumavate": "raggrumare",
    "raggrumavi": "raggrumare",
    "raggrumavo": "raggrumare",
    "raggrumerai": "raggrumare",
    "raggrumeran": "raggrumare",
    "raggrumeranno": "raggrumare",
    "raggrumerebbe": "raggrumare",
    "raggrumerebber": "raggrumare",
    "raggrumerebbero": "raggrumare",
    "raggrumerei": "raggrumare",
    "raggrumeremmo": "raggrumare",
    "raggrumeremo": "raggrumare",
    "raggrumereste": "raggrumare",
    "raggrumeresti": "raggrumare",
    "raggrumerete": "raggrumare",
    "raggrumerà": "raggrumare",
    "raggrumerò": "raggrumare",
    "raggrumi": "raggrumare",
    "raggrumiamo": "raggrumare",
    "raggrumiate": "raggrumare",
    "raggrumin": "raggrumare",
    "raggrumino": "raggrumare",
    "raggrumo": "raggrumare",
    "raggrumò": "raggrumare",
    "raggruppa": "raggruppare",
    "raggruppai": "raggruppare",
    "raggruppamenti": "raggruppamento",
    "raggruppammo": "raggruppare",
    "raggruppan": "raggruppare",
    "raggruppando": "raggruppare",
    "raggruppano": "raggruppare",
    "raggruppante": "raggruppare",
    "raggruppanti": "raggruppare",
    "raggruppar": "raggruppare",
    "raggrupparon": "raggruppare",
    "raggrupparono": "raggruppare",
    "raggruppasse": "raggruppare",
    "raggruppasser": "raggruppare",
    "raggruppassero": "raggruppare",
    "raggruppassi": "raggruppare",
    "raggruppassimo": "raggruppare",
    "raggruppaste": "raggruppare",
    "raggruppasti": "raggruppare",
    "raggruppata": "raggruppare",
    "raggruppate": "raggruppare",
    "raggruppati": "raggruppare",
    "raggruppato": "raggruppare",
    "raggruppava": "raggruppare",
    "raggruppavamo": "raggruppare",
    "raggruppavan": "raggruppare",
    "raggruppavano": "raggruppare",
    "raggruppavate": "raggruppare",
    "raggruppavi": "raggruppare",
    "raggruppavo": "raggruppare",
    "raggrupperai": "raggruppare",
    "raggrupperan": "raggruppare",
    "raggrupperanno": "raggruppare",
    "raggrupperebbe": "raggruppare",
    "raggrupperebber": "raggruppare",
    "raggrupperebbero": "raggruppare",
    "raggrupperei": "raggruppare",
    "raggrupperemmo": "raggruppare",
    "raggrupperemo": "raggruppare",
    "raggruppereste": "raggruppare",
    "raggrupperesti": "raggruppare",
    "raggrupperete": "raggruppare",
    "raggrupperà": "raggruppare",
    "raggrupperò": "raggruppare",
    "raggruppi": "raggruppare",
    "raggruppiamo": "raggruppare",
    "raggruppiate": "raggruppare",
    "raggruppin": "raggruppare",
    "raggruppino": "raggruppare",
    "raggruppo": "raggruppare",
    "raggruppò": "raggruppare",
    "raggruzzola": "raggruzzolare",
    "raggruzzolai": "raggruzzolare",
    "raggruzzolammo": "raggruzzolare",
    "raggruzzolan": "raggruzzolare",
    "raggruzzolando": "raggruzzolare",
    "raggruzzolano": "raggruzzolare",
    "raggruzzolante": "raggruzzolare",
    "raggruzzolanti": "raggruzzolare",
    "raggruzzolar": "raggruzzolare",
    "raggruzzolaron": "raggruzzolare",
    "raggruzzolarono": "raggruzzolare",
    "raggruzzolasse": "raggruzzolare",
    "raggruzzolasser": "raggruzzolare",
    "raggruzzolassero": "raggruzzolare",
    "raggruzzolassi": "raggruzzolare",
    "raggruzzolassimo": "raggruzzolare",
    "raggruzzolaste": "raggruzzolare",
    "raggruzzolasti": "raggruzzolare",
    "raggruzzolata": "raggruzzolare",
    "raggruzzolate": "raggruzzolare",
    "raggruzzolati": "raggruzzolare",
    "raggruzzolato": "raggruzzolare",
    "raggruzzolava": "raggruzzolare",
    "raggruzzolavamo": "raggruzzolare",
    "raggruzzolavan": "raggruzzolare",
    "raggruzzolavano": "raggruzzolare",
    "raggruzzolavate": "raggruzzolare",
    "raggruzzolavi": "raggruzzolare",
    "raggruzzolavo": "raggruzzolare",
    "raggruzzolerai": "raggruzzolare",
    "raggruzzoleran": "raggruzzolare",
    "raggruzzoleranno": "raggruzzolare",
    "raggruzzolerebbe": "raggruzzolare",
    "raggruzzolerebber": "raggruzzolare",
    "raggruzzolerebbero": "raggruzzolare",
    "raggruzzolerei": "raggruzzolare",
    "raggruzzoleremmo": "raggruzzolare",
    "raggruzzoleremo": "raggruzzolare",
    "raggruzzolereste": "raggruzzolare",
    "raggruzzoleresti": "raggruzzolare",
    "raggruzzolerete": "raggruzzolare",
    "raggruzzolerà": "raggruzzolare",
    "raggruzzolerò": "raggruzzolare",
    "raggruzzoli": "raggruzzolare",
    "raggruzzoliamo": "raggruzzolare",
    "raggruzzoliate": "raggruzzolare",
    "raggruzzolin": "raggruzzolare",
    "raggruzzolino": "raggruzzolare",
    "raggruzzolo": "raggruzzolare",
    "raggruzzolò": "raggruzzolare",
    "ragguagli": "ragguaglio",
    "ragguaglia": "ragguagliare",
    "ragguagliai": "ragguagliare",
    "ragguagliammo": "ragguagliare",
    "ragguagliamo": "ragguagliare",
    "ragguaglian": "ragguagliare",
    "ragguagliando": "ragguagliare",
    "ragguagliano": "ragguagliare",
    "ragguagliante": "ragguagliare",
    "ragguaglianti": "ragguagliare",
    "ragguagliar": "ragguagliare",
    "ragguagliaron": "ragguagliare",
    "ragguagliarono": "ragguagliare",
    "ragguagliasse": "ragguagliare",
    "ragguagliasser": "ragguagliare",
    "ragguagliassero": "ragguagliare",
    "ragguagliassi": "ragguagliare",
    "ragguagliassimo": "ragguagliare",
    "ragguagliaste": "ragguagliare",
    "ragguagliasti": "ragguagliare",
    "ragguagliata": "ragguagliare",
    "ragguagliate": "ragguagliare",
    "ragguagliati": "ragguagliare",
    "ragguagliato": "ragguagliare",
    "ragguagliava": "ragguagliare",
    "ragguagliavamo": "ragguagliare",
    "ragguagliavan": "ragguagliare",
    "ragguagliavano": "ragguagliare",
    "ragguagliavate": "ragguagliare",
    "ragguagliavi": "ragguagliare",
    "ragguagliavo": "ragguagliare",
    "ragguaglierai": "ragguagliare",
    "ragguaglieran": "ragguagliare",
    "ragguaglieranno": "ragguagliare",
    "ragguaglierebbe": "ragguagliare",
    "ragguaglierebber": "ragguagliare",
    "ragguaglierebbero": "ragguagliare",
    "ragguaglierei": "ragguagliare",
    "ragguaglieremmo": "ragguagliare",
    "ragguaglieremo": "ragguagliare",
    "ragguagliereste": "ragguagliare",
    "ragguaglieresti": "ragguagliare",
    "ragguaglierete": "ragguagliare",
    "ragguaglierà": "ragguagliare",
    "ragguaglierò": "ragguagliare",
    "ragguaglin": "ragguagliare",
    "ragguaglino": "ragguagliare",
    "ragguaglio": "ragguagliare",
    "ragguagliò": "ragguagliare",
    "ragguardevoli": "ragguardevole",
    "ragion": "ragione",
    "ragiona": "ragionare",
    "ragionai": "ragionare",
    "ragionamenti": "ragionamento",
    "ragionammo": "ragionare",
    "ragionan": "ragionare",
    "ragionando": "ragionare",
    "ragionano": "ragionare",
    "ragionante": "ragionare",
    "ragionanti": "ragionare",
    "ragionar": "ragionare",
    "ragionaron": "ragionare",
    "ragionarono": "ragionare",
    "ragionasse": "ragionare",
    "ragionasser": "ragionare",
    "ragionassero": "ragionare",
    "ragionassi": "ragionare",
    "ragionassimo": "ragionare",
    "ragionaste": "ragionare",
    "ragionasti": "ragionare",
    "ragionata": "ragionato",
    "ragionate": "ragionato",
    "ragionati": "ragionato",
    "ragionato": "ragionare",
    "ragionava": "ragionare",
    "ragionavamo": "ragionare",
    "ragionavan": "ragionare",
    "ragionavano": "ragionare",
    "ragionavate": "ragionare",
    "ragionavi": "ragionare",
    "ragionavo": "ragionare",
    "ragionerai": "ragionare",
    "ragioneran": "ragionare",
    "ragioneranno": "ragionare",
    "ragionerebbe": "ragionare",
    "ragionerebber": "ragionare",
    "ragionerebbero": "ragionare",
    "ragionerei": "ragionare",
    "ragioneremmo": "ragionare",
    "ragioneremo": "ragionare",
    "ragionereste": "ragionare",
    "ragioneresti": "ragionare",
    "ragionerete": "ragionare",
    "ragionerie": "ragioneria",
    "ragionerà": "ragionare",
    "ragionerò": "ragionare",
    "ragionevolezze": "ragionevolezza",
    "ragionevoli": "ragionevole",
    "ragioni": "ragione",
    "ragioniamo": "ragionare",
    "ragioniate": "ragionare",
    "ragionieri": "ragioniere",
    "ragionieristica": "ragionieristico",
    "ragionieristiche": "ragionieristico",
    "ragionieristici": "ragionieristico",
    "ragionin": "ragionare",
    "ragionino": "ragionare",
    "ragiono": "ragionare",
    "ragionò": "ragionare",
    "ragli": "raglio",
    "raglia": "ragliare",
    "ragliai": "ragliare",
    "ragliammo": "ragliare",
    "ragliamo": "ragliare",
    "raglian": "ragliare",
    "ragliando": "ragliare",
    "ragliano": "ragliare",
    "ragliante": "ragliare",
    "raglianti": "ragliare",
    "ragliar": "ragliare",
    "ragliaron": "ragliare",
    "ragliarono": "ragliare",
    "ragliasse": "ragliare",
    "ragliasser": "ragliare",
    "ragliassero": "ragliare",
    "ragliassi": "ragliare",
    "ragliassimo": "ragliare",
    "ragliaste": "ragliare",
    "ragliasti": "ragliare",
    "ragliata": "ragliare",
    "ragliate": "ragliare",
    "ragliati": "ragliare",
    "ragliato": "ragliare",
    "ragliava": "ragliare",
    "ragliavamo": "ragliare",
    "ragliavan": "ragliare",
    "ragliavano": "ragliare",
    "ragliavate": "ragliare",
    "ragliavi": "ragliare",
    "ragliavo": "ragliare",
    "raglierai": "ragliare",
    "raglieran": "ragliare",
    "raglieranno": "ragliare",
    "raglierebbe": "ragliare",
    "raglierebber": "ragliare",
    "raglierebbero": "ragliare",
    "raglierei": "ragliare",
    "raglieremmo": "ragliare",
    "raglieremo": "ragliare",
    "ragliereste": "ragliare",
    "raglieresti": "ragliare",
    "raglierete": "ragliare",
    "raglierà": "ragliare",
    "raglierò": "ragliare",
    "raglin": "ragliare",
    "raglino": "ragliare",
    "raglio": "ragliare",
    "ragliò": "ragliare",
    "ragnatele": "ragnatela",
    "ragni": "ragno",
    "rallegra": "rallegrare",
    "rallegrai": "rallegrare",
    "rallegrammo": "rallegrare",
    "rallegran": "rallegrare",
    "rallegrando": "rallegrare",
    "rallegrano": "rallegrare",
    "rallegrante": "rallegrare",
    "rallegranti": "rallegrare",
    "rallegrar": "rallegrare",
    "rallegraron": "rallegrare",
    "rallegrarono": "rallegrare",
    "rallegrasse": "rallegrare",
    "rallegrasser": "rallegrare",
    "rallegrassero": "rallegrare",
    "rallegrassi": "rallegrare",
    "rallegrassimo": "rallegrare",
    "rallegraste": "rallegrare",
    "rallegrasti": "rallegrare",
    "rallegrata": "rallegrare",
    "rallegrate": "rallegrare",
    "rallegrati": "rallegrare",
    "rallegrato": "rallegrare",
    "rallegrava": "rallegrare",
    "rallegravamo": "rallegrare",
    "rallegravan": "rallegrare",
    "rallegravano": "rallegrare",
    "rallegravate": "rallegrare",
    "rallegravi": "rallegrare",
    "rallegravo": "rallegrare",
    "rallegrerai": "rallegrare",
    "rallegreran": "rallegrare",
    "rallegreranno": "rallegrare",
    "rallegrerebbe": "rallegrare",
    "rallegrerebber": "rallegrare",
    "rallegrerebbero": "rallegrare",
    "rallegrerei": "rallegrare",
    "rallegreremmo": "rallegrare",
    "rallegreremo": "rallegrare",
    "rallegrereste": "rallegrare",
    "rallegreresti": "rallegrare",
    "rallegrerete": "rallegrare",
    "rallegrerà": "rallegrare",
    "rallegrerò": "rallegrare",
    "rallegri": "rallegrare",
    "rallegriamo": "rallegrare",
    "rallegriate": "rallegrare",
    "rallegrin": "rallegrare",
    "rallegrino": "rallegrare",
    "rallegro": "rallegrare",
    "rallegrò": "rallegrare",
    "rallenta": "rallentare",
    "rallentai": "rallentare",
    "rallentamenti": "rallentamento",
    "rallentammo": "rallentare",
    "rallentan": "rallentare",
    "rallentando": "rallentare",
    "rallentano": "rallentare",
    "rallentante": "rallentare",
    "rallentanti": "rallentare",
    "rallentar": "rallentare",
    "rallentaron": "rallentare",
    "rallentarono": "rallentare",
    "rallentasse": "rallentare",
    "rallentasser": "rallentare",
    "rallentassero": "rallentare",
    "rallentassi": "rallentare",
    "rallentassimo": "rallentare",
    "rallentaste": "rallentare",
    "rallentasti": "rallentare",
    "rallentata": "rallentare",
    "rallentate": "rallentare",
    "rallentati": "rallentare",
    "rallentato": "rallentare",
    "rallentatori": "rallentatore",
    "rallentava": "rallentare",
    "rallentavamo": "rallentare",
    "rallentavan": "rallentare",
    "rallentavano": "rallentare",
    "rallentavate": "rallentare",
    "rallentavi": "rallentare",
    "rallentavo": "rallentare",
    "rallenterai": "rallentare",
    "rallenteran": "rallentare",
    "rallenteranno": "rallentare",
    "rallenterebbe": "rallentare",
    "rallenterebber": "rallentare",
    "rallenterebbero": "rallentare",
    "rallenterei": "rallentare",
    "rallenteremmo": "rallentare",
    "rallenteremo": "rallentare",
    "rallentereste": "rallentare",
    "rallenteresti": "rallentare",
    "rallenterete": "rallentare",
    "rallenterà": "rallentare",
    "rallenterò": "rallentare",
    "rallenti": "rallentare",
    "rallentiamo": "rallentare",
    "rallentiate": "rallentare",
    "rallentin": "rallentare",
    "rallentino": "rallentare",
    "rallento": "rallentare",
    "rallentò": "rallentare",
    "rallies": "rally",
    "rama": "ramare",
    "ramai": "ramare",
    "ramammo": "ramare",
    "raman": "ramare",
    "ramando": "ramare",
    "ramano": "ramare",
    "ramante": "ramare",
    "ramanti": "ramare",
    "ramanzine": "ramanzina",
    "ramar": "ramare",
    "ramaron": "ramare",
    "ramarono": "ramare",
    "ramasse": "ramare",
    "ramasser": "ramare",
    "ramassero": "ramare",
    "ramassi": "ramare",
    "ramassimo": "ramare",
    "ramaste": "ramare",
    "ramasti": "ramare",
    "ramata": "ramato",
    "ramate": "ramato",
    "ramati": "ramato",
    "ramato": "ramare",
    "ramava": "ramare",
    "ramavamo": "ramare",
    "ramavan": "ramare",
    "ramavano": "ramare",
    "ramavate": "ramare",
    "ramavi": "ramare",
    "ramavo": "ramare",
    "ramazza": "ramazzare",
    "ramazzai": "ramazzare",
    "ramazzammo": "ramazzare",
    "ramazzan": "ramazzare",
    "ramazzando": "ramazzare",
    "ramazzano": "ramazzare",
    "ramazzante": "ramazzare",
    "ramazzanti": "ramazzare",
    "ramazzar": "ramazzare",
    "ramazzaron": "ramazzare",
    "ramazzarono": "ramazzare",
    "ramazzasse": "ramazzare",
    "ramazzasser": "ramazzare",
    "ramazzassero": "ramazzare",
    "ramazzassi": "ramazzare",
    "ramazzassimo": "ramazzare",
    "ramazzaste": "ramazzare",
    "ramazzasti": "ramazzare",
    "ramazzata": "ramazzare",
    "ramazzate": "ramazzare",
    "ramazzati": "ramazzare",
    "ramazzato": "ramazzare",
    "ramazzava": "ramazzare",
    "ramazzavamo": "ramazzare",
    "ramazzavan": "ramazzare",
    "ramazzavano": "ramazzare",
    "ramazzavate": "ramazzare",
    "ramazzavi": "ramazzare",
    "ramazzavo": "ramazzare",
    "ramazze": "ramazza",
    "ramazzerai": "ramazzare",
    "ramazzeran": "ramazzare",
    "ramazzeranno": "ramazzare",
    "ramazzerebbe": "ramazzare",
    "ramazzerebber": "ramazzare",
    "ramazzerebbero": "ramazzare",
    "ramazzerei": "ramazzare",
    "ramazzeremmo": "ramazzare",
    "ramazzeremo": "ramazzare",
    "ramazzereste": "ramazzare",
    "ramazzeresti": "ramazzare",
    "ramazzerete": "ramazzare",
    "ramazzerà": "ramazzare",
    "ramazzerò": "ramazzare",
    "ramazzi": "ramazzare",
    "ramazziamo": "ramazzare",
    "ramazziate": "ramazzare",
    "ramazzin": "ramazzare",
    "ramazzino": "ramazzare",
    "ramazzo": "ramazzare",
    "ramazzò": "ramazzare",
    "ramerai": "ramare",
    "rameran": "ramare",
    "rameranno": "ramare",
    "ramerebbe": "ramare",
    "ramerebber": "ramare",
    "ramerebbero": "ramare",
    "ramerei": "ramare",
    "rameremmo": "ramare",
    "rameremo": "ramare",
    "ramereste": "ramare",
    "rameresti": "ramare",
    "ramerete": "ramare",
    "ramerà": "ramare",
    "ramerò": "ramare",
    "rametti": "rametto",
    "rami": "ramo",
    "ramiamo": "ramare",
    "ramiate": "ramare",
    "ramifica": "ramificare",
    "ramificai": "ramificare",
    "ramificammo": "ramificare",
    "ramifican": "ramificare",
    "ramificando": "ramificare",
    "ramificano": "ramificare",
    "ramificante": "ramificare",
    "ramificanti": "ramificare",
    "ramificar": "ramificare",
    "ramificaron": "ramificare",
    "ramificarono": "ramificare",
    "ramificasse": "ramificare",
    "ramificasser": "ramificare",
    "ramificassero": "ramificare",
    "ramificassi": "ramificare",
    "ramificassimo": "ramificare",
    "ramificaste": "ramificare",
    "ramificasti": "ramificare",
    "ramificata": "ramificato",
    "ramificate": "ramificato",
    "ramificati": "ramificato",
    "ramificato": "ramificare",
    "ramificava": "ramificare",
    "ramificavamo": "ramificare",
    "ramificavan": "ramificare",
    "ramificavano": "ramificare",
    "ramificavate": "ramificare",
    "ramificavi": "ramificare",
    "ramificavo": "ramificare",
    "ramificazioni": "ramificazione",
    "ramificherai": "ramificare",
    "ramificheran": "ramificare",
    "ramificheranno": "ramificare",
    "ramificherebbe": "ramificare",
    "ramificherebber": "ramificare",
    "ramificherebbero": "ramificare",
    "ramificherei": "ramificare",
    "ramificheremmo": "ramificare",
    "ramificheremo": "ramificare",
    "ramifichereste": "ramificare",
    "ramificheresti": "ramificare",
    "ramificherete": "ramificare",
    "ramificherà": "ramificare",
    "ramificherò": "ramificare",
    "ramifichi": "ramificare",
    "ramifichiamo": "ramificare",
    "ramifichiate": "ramificare",
    "ramifichin": "ramificare",
    "ramifichino": "ramificare",
    "ramifico": "ramificare",
    "ramificò": "ramificare",
    "ramin": "ramare",
    "ramino": "ramare",
    "rammarica": "rammaricare",
    "rammaricai": "rammaricare",
    "rammaricammo": "rammaricare",
    "rammarican": "rammaricare",
    "rammaricando": "rammaricare",
    "rammaricano": "rammaricare",
    "rammaricante": "rammaricare",
    "rammaricanti": "rammaricare",
    "rammaricar": "rammaricare",
    "rammaricaron": "rammaricare",
    "rammaricarono": "rammaricare",
    "rammaricasse": "rammaricare",
    "rammaricasser": "rammaricare",
    "rammaricassero": "rammaricare",
    "rammaricassi": "rammaricare",
    "rammaricassimo": "rammaricare",
    "rammaricaste": "rammaricare",
    "rammaricasti": "rammaricare",
    "rammaricata": "rammaricare",
    "rammaricate": "rammaricare",
    "rammaricati": "rammaricare",
    "rammaricato": "rammaricare",
    "rammaricava": "rammaricare",
    "rammaricavamo": "rammaricare",
    "rammaricavan": "rammaricare",
    "rammaricavano": "rammaricare",
    "rammaricavate": "rammaricare",
    "rammaricavi": "rammaricare",
    "rammaricavo": "rammaricare",
    "rammaricherai": "rammaricare",
    "rammaricheran": "rammaricare",
    "rammaricheranno": "rammaricare",
    "rammaricherebbe": "rammaricare",
    "rammaricherebber": "rammaricare",
    "rammaricherebbero": "rammaricare",
    "rammaricherei": "rammaricare",
    "rammaricheremmo": "rammaricare",
    "rammaricheremo": "rammaricare",
    "rammarichereste": "rammaricare",
    "rammaricheresti": "rammaricare",
    "rammaricherete": "rammaricare",
    "rammaricherà": "rammaricare",
    "rammaricherò": "rammaricare",
    "rammarichi": "rammarico",
    "rammarichiamo": "rammaricare",
    "rammarichiate": "rammaricare",
    "rammarichin": "rammaricare",
    "rammarichino": "rammaricare",
    "rammarico": "rammaricare",
    "rammaricò": "rammaricare",
    "rammenda": "rammendare",
    "rammendai": "rammendare",
    "rammendammo": "rammendare",
    "rammendan": "rammendare",
    "rammendando": "rammendare",
    "rammendano": "rammendare",
    "rammendante": "rammendare",
    "rammendanti": "rammendare",
    "rammendar": "rammendare",
    "rammendaron": "rammendare",
    "rammendarono": "rammendare",
    "rammendasse": "rammendare",
    "rammendasser": "rammendare",
    "rammendassero": "rammendare",
    "rammendassi": "rammendare",
    "rammendassimo": "rammendare",
    "rammendaste": "rammendare",
    "rammendasti": "rammendare",
    "rammendata": "rammendare",
    "rammendate": "rammendare",
    "rammendati": "rammendare",
    "rammendato": "rammendare",
    "rammendava": "rammendare",
    "rammendavamo": "rammendare",
    "rammendavan": "rammendare",
    "rammendavano": "rammendare",
    "rammendavate": "rammendare",
    "rammendavi": "rammendare",
    "rammendavo": "rammendare",
    "rammenderai": "rammendare",
    "rammenderan": "rammendare",
    "rammenderanno": "rammendare",
    "rammenderebbe": "rammendare",
    "rammenderebber": "rammendare",
    "rammenderebbero": "rammendare",
    "rammenderei": "rammendare",
    "rammenderemmo": "rammendare",
    "rammenderemo": "rammendare",
    "rammendereste": "rammendare",
    "rammenderesti": "rammendare",
    "rammenderete": "rammendare",
    "rammenderà": "rammendare",
    "rammenderò": "rammendare",
    "rammendi": "rammendare",
    "rammendiamo": "rammendare",
    "rammendiate": "rammendare",
    "rammendin": "rammendare",
    "rammendino": "rammendare",
    "rammendo": "rammendare",
    "rammendò": "rammendare",
    "rammenta": "rammentare",
    "rammentai": "rammentare",
    "rammentammo": "rammentare",
    "rammentan": "rammentare",
    "rammentando": "rammentare",
    "rammentano": "rammentare",
    "rammentante": "rammentare",
    "rammentanti": "rammentare",
    "rammentar": "rammentare",
    "rammentaron": "rammentare",
    "rammentarono": "rammentare",
    "rammentasse": "rammentare",
    "rammentasser": "rammentare",
    "rammentassero": "rammentare",
    "rammentassi": "rammentare",
    "rammentassimo": "rammentare",
    "rammentaste": "rammentare",
    "rammentasti": "rammentare",
    "rammentata": "rammentare",
    "rammentate": "rammentare",
    "rammentati": "rammentare",
    "rammentato": "rammentare",
    "rammentava": "rammentare",
    "rammentavamo": "rammentare",
    "rammentavan": "rammentare",
    "rammentavano": "rammentare",
    "rammentavate": "rammentare",
    "rammentavi": "rammentare",
    "rammentavo": "rammentare",
    "rammenterai": "rammentare",
    "rammenteran": "rammentare",
    "rammenteranno": "rammentare",
    "rammenterebbe": "rammentare",
    "rammenterebber": "rammentare",
    "rammenterebbero": "rammentare",
    "rammenterei": "rammentare",
    "rammenteremmo": "rammentare",
    "rammenteremo": "rammentare",
    "rammentereste": "rammentare",
    "rammenteresti": "rammentare",
    "rammenterete": "rammentare",
    "rammenterà": "rammentare",
    "rammenterò": "rammentare",
    "rammenti": "rammentare",
    "rammentiamo": "rammentare",
    "rammentiate": "rammentare",
    "rammentin": "rammentare",
    "rammentino": "rammentare",
    "rammento": "rammentare",
    "rammentò": "rammentare",
    "rammoderna": "rammodernare",
    "rammodernai": "rammodernare",
    "rammodernammo": "rammodernare",
    "rammodernan": "rammodernare",
    "rammodernando": "rammodernare",
    "rammodernano": "rammodernare",
    "rammodernante": "rammodernare",
    "rammodernanti": "rammodernare",
    "rammodernar": "rammodernare",
    "rammodernaron": "rammodernare",
    "rammodernarono": "rammodernare",
    "rammodernasse": "rammodernare",
    "rammodernasser": "rammodernare",
    "rammodernassero": "rammodernare",
    "rammodernassi": "rammodernare",
    "rammodernassimo": "rammodernare",
    "rammodernaste": "rammodernare",
    "rammodernasti": "rammodernare",
    "rammodernata": "rammodernare",
    "rammodernate": "rammodernare",
    "rammodernati": "rammodernare",
    "rammodernato": "rammodernare",
    "rammodernava": "rammodernare",
    "rammodernavamo": "rammodernare",
    "rammodernavan": "rammodernare",
    "rammodernavano": "rammodernare",
    "rammodernavate": "rammodernare",
    "rammodernavi": "rammodernare",
    "rammodernavo": "rammodernare",
    "rammodernerai": "rammodernare",
    "rammoderneran": "rammodernare",
    "rammoderneranno": "rammodernare",
    "rammodernerebbe": "rammodernare",
    "rammodernerebber": "rammodernare",
    "rammodernerebbero": "rammodernare",
    "rammodernerei": "rammodernare",
    "rammoderneremmo": "rammodernare",
    "rammoderneremo": "rammodernare",
    "rammodernereste": "rammodernare",
    "rammoderneresti": "rammodernare",
    "rammodernerete": "rammodernare",
    "rammodernerà": "rammodernare",
    "rammodernerò": "rammodernare",
    "rammoderni": "rammodernare",
    "rammoderniamo": "rammodernare",
    "rammoderniate": "rammodernare",
    "rammodernin": "rammodernare",
    "rammodernino": "rammodernare",
    "rammoderno": "rammodernare",
    "rammodernò": "rammodernare",
    "rammolla": "rammollire",
    "rammollan": "rammollire",
    "rammollano": "rammollire",
    "rammolle": "rammollire",
    "rammollendo": "rammollire",
    "rammollente": "rammollire",
    "rammollenti": "rammollire",
    "rammolli": "rammollire",
    "rammolliamo": "rammollire",
    "rammolliate": "rammollire",
    "rammollii": "rammollire",
    "rammollimmo": "rammollire",
    "rammollir": "rammollire",
    "rammollirai": "rammollire",
    "rammolliran": "rammollire",
    "rammolliranno": "rammollire",
    "rammollirebbe": "rammollire",
    "rammollirebber": "rammollire",
    "rammollirebbero": "rammollire",
    "rammollirei": "rammollire",
    "rammolliremmo": "rammollire",
    "rammolliremo": "rammollire",
    "rammollireste": "rammollire",
    "rammolliresti": "rammollire",
    "rammollirete": "rammollire",
    "rammolliron": "rammollire",
    "rammollirono": "rammollire",
    "rammollirà": "rammollire",
    "rammollirò": "rammollire",
    "rammollisse": "rammollire",
    "rammollisser": "rammollire",
    "rammollissero": "rammollire",
    "rammollissi": "rammollire",
    "rammollissimo": "rammollire",
    "rammolliste": "rammollire",
    "rammollisti": "rammollire",
    "rammollita": "rammollire",
    "rammollite": "rammollire",
    "rammolliti": "rammollire",
    "rammollito": "rammollire",
    "rammolliva": "rammollire",
    "rammollivamo": "rammollire",
    "rammollivan": "rammollire",
    "rammollivano": "rammollire",
    "rammollivate": "rammollire",
    "rammollivi": "rammollire",
    "rammollivo": "rammollire",
    "rammollo": "rammollire",
    "rammollon": "rammollire",
    "rammollono": "rammollire",
    "rammollì": "rammollire",
    "ramo": "ramare",
    "ramoscelli": "ramoscello",
    "rampa": "rampare",
    "rampai": "rampare",
    "rampammo": "rampare",
    "rampan": "rampare",
    "rampando": "rampare",
    "rampano": "rampare",
    "rampanta": "rampanto",
    "rampante": "rampare",
    "rampanti": "rampare",
    "rampantismi": "rampantismo",
    "rampar": "rampare",
    "ramparon": "rampare",
    "ramparono": "rampare",
    "rampasse": "rampare",
    "rampasser": "rampare",
    "rampassero": "rampare",
    "rampassi": "rampare",
    "rampassimo": "rampare",
    "rampaste": "rampare",
    "rampasti": "rampare",
    "rampata": "rampare",
    "rampate": "rampare",
    "rampati": "rampare",
    "rampato": "rampare",
    "rampava": "rampare",
    "rampavamo": "rampare",
    "rampavan": "rampare",
    "rampavano": "rampare",
    "rampavate": "rampare",
    "rampavi": "rampare",
    "rampavo": "rampare",
    "rampe": "rampa",
    "ramperai": "rampare",
    "ramperan": "rampare",
    "ramperanno": "rampare",
    "ramperebbe": "rampare",
    "ramperebber": "rampare",
    "ramperebbero": "rampare",
    "ramperei": "rampare",
    "ramperemmo": "rampare",
    "ramperemo": "rampare",
    "rampereste": "rampare",
    "ramperesti": "rampare",
    "ramperete": "rampare",
    "ramperà": "rampare",
    "ramperò": "rampare",
    "rampi": "rampare",
    "rampiamo": "rampare",
    "rampiate": "rampare",
    "rampica": "rampicare",
    "rampicai": "rampicare",
    "rampicammo": "rampicare",
    "rampican": "rampicare",
    "rampicando": "rampicare",
    "rampicano": "rampicare",
    "rampicante": "rampicare",
    "rampicanti": "rampicare",
    "rampicar": "rampicare",
    "rampicaron": "rampicare",
    "rampicarono": "rampicare",
    "rampicasse": "rampicare",
    "rampicasser": "rampicare",
    "rampicassero": "rampicare",
    "rampicassi": "rampicare",
    "rampicassimo": "rampicare",
    "rampicaste": "rampicare",
    "rampicasti": "rampicare",
    "rampicata": "rampicare",
    "rampicate": "rampicare",
    "rampicati": "rampicare",
    "rampicato": "rampicare",
    "rampicava": "rampicare",
    "rampicavamo": "rampicare",
    "rampicavan": "rampicare",
    "rampicavano": "rampicare",
    "rampicavate": "rampicare",
    "rampicavi": "rampicare",
    "rampicavo": "rampicare",
    "rampicherai": "rampicare",
    "rampicheran": "rampicare",
    "rampicheranno": "rampicare",
    "rampicherebbe": "rampicare",
    "rampicherebber": "rampicare",
    "rampicherebbero": "rampicare",
    "rampicherei": "rampicare",
    "rampicheremmo": "rampicare",
    "rampicheremo": "rampicare",
    "rampichereste": "rampicare",
    "rampicheresti": "rampicare",
    "rampicherete": "rampicare",
    "rampicherà": "rampicare",
    "rampicherò": "rampicare",
    "rampichi": "rampicare",
    "rampichiamo": "rampicare",
    "rampichiate": "rampicare",
    "rampichin": "rampicare",
    "rampichino": "rampicare",
    "rampico": "rampicare",
    "rampicò": "rampicare",
    "rampin": "rampare",
    "rampini": "rampino",
    "rampino": "rampare",
    "rampo": "rampare",
    "rampogna": "rampognare",
    "rampognai": "rampognare",
    "rampognammo": "rampognare",
    "rampognan": "rampognare",
    "rampognando": "rampognare",
    "rampognano": "rampognare",
    "rampognante": "rampognare",
    "rampognanti": "rampognare",
    "rampognar": "rampognare",
    "rampognaron": "rampognare",
    "rampognarono": "rampognare",
    "rampognasse": "rampognare",
    "rampognasser": "rampognare",
    "rampognassero": "rampognare",
    "rampognassi": "rampognare",
    "rampognassimo": "rampognare",
    "rampognaste": "rampognare",
    "rampognasti": "rampognare",
    "rampognata": "rampognare",
    "rampognate": "rampognare",
    "rampognati": "rampognare",
    "rampognato": "rampognare",
    "rampognava": "rampognare",
    "rampognavamo": "rampognare",
    "rampognavan": "rampognare",
    "rampognavano": "rampognare",
    "rampognavate": "rampognare",
    "rampognavi": "rampognare",
    "rampognavo": "rampognare",
    "rampogne": "rampogna",
    "rampognerai": "rampognare",
    "rampogneran": "rampognare",
    "rampogneranno": "rampognare",
    "rampognerebbe": "rampognare",
    "rampognerebber": "rampognare",
    "rampognerebbero": "rampognare",
    "rampognerei": "rampognare",
    "rampogneremmo": "rampognare",
    "rampogneremo": "rampognare",
    "rampognereste": "rampognare",
    "rampogneresti": "rampognare",
    "rampognerete": "rampognare",
    "rampognerà": "rampognare",
    "rampognerò": "rampognare",
    "rampogni": "rampognare",
    "rampogniamo": "rampognare",
    "rampogniate": "rampognare",
    "rampognin": "rampognare",
    "rampognino": "rampognare",
    "rampogno": "rampognare",
    "rampognò": "rampognare",
    "rampolla": "rampollare",
    "rampollai": "rampollare",
    "rampollammo": "rampollare",
    "rampollan": "rampollare",
    "rampollando": "rampollare",
    "rampollano": "rampollare",
    "rampollante": "rampollare",
    "rampollanti": "rampollare",
    "rampollar": "rampollare",
    "rampollaron": "rampollare",
    "rampollarono": "rampollare",
    "rampollasse": "rampollare",
    "rampollasser": "rampollare",
    "rampollassero": "rampollare",
    "rampollassi": "rampollare",
    "rampollassimo": "rampollare",
    "rampollaste": "rampollare",
    "rampollasti": "rampollare",
    "rampollata": "rampollare",
    "rampollate": "rampollare",
    "rampollati": "rampollare",
    "rampollato": "rampollare",
    "rampollava": "rampollare",
    "rampollavamo": "rampollare",
    "rampollavan": "rampollare",
    "rampollavano": "rampollare",
    "rampollavate": "rampollare",
    "rampollavi": "rampollare",
    "rampollavo": "rampollare",
    "rampollerai": "rampollare",
    "rampolleran": "rampollare",
    "rampolleranno": "rampollare",
    "rampollerebbe": "rampollare",
    "rampollerebber": "rampollare",
    "rampollerebbero": "rampollare",
    "rampollerei": "rampollare",
    "rampolleremmo": "rampollare",
    "rampolleremo": "rampollare",
    "rampollereste": "rampollare",
    "rampolleresti": "rampollare",
    "rampollerete": "rampollare",
    "rampollerà": "rampollare",
    "rampollerò": "rampollare",
    "rampolli": "rampollo",
    "rampolliamo": "rampollare",
    "rampolliate": "rampollare",
    "rampollin": "rampollare",
    "rampollino": "rampollare",
    "rampollo": "rampollare",
    "rampollò": "rampollare",
    "ramponi": "rampone",
    "rampò": "rampare",
    "ramò": "ramare",
    "rance": "rancio",
    "ranci": "rancio",
    "rancia": "rancio",
    "rancida": "rancido",
    "rancide": "rancido",
    "rancidi": "rancido",
    "rancori": "rancore",
    "rancorosa": "rancoroso",
    "rancorose": "rancoroso",
    "rancorosi": "rancoroso",
    "randagi": "randagio",
    "randagia": "randagio",
    "randagie": "randagio",
    "rande": "randa",
    "randella": "randellare",
    "randellai": "randellare",
    "randellammo": "randellare",
    "randellan": "randellare",
    "randellando": "randellare",
    "randellano": "randellare",
    "randellante": "randellare",
    "randellanti": "randellare",
    "randellar": "randellare",
    "randellaron": "randellare",
    "randellarono": "randellare",
    "randellasse": "randellare",
    "randellasser": "randellare",
    "randellassero": "randellare",
    "randellassi": "randellare",
    "randellassimo": "randellare",
    "randellaste": "randellare",
    "randellasti": "randellare",
    "randellata": "randellare",
    "randellate": "randellata",
    "randellati": "randellare",
    "randellato": "randellare",
    "randellava": "randellare",
    "randellavamo": "randellare",
    "randellavan": "randellare",
    "randellavano": "randellare",
    "randellavate": "randellare",
    "randellavi": "randellare",
    "randellavo": "randellare",
    "randellerai": "randellare",
    "randelleran": "randellare",
    "randelleranno": "randellare",
    "randellerebbe": "randellare",
    "randellerebber": "randellare",
    "randellerebbero": "randellare",
    "randellerei": "randellare",
    "randelleremmo": "randellare",
    "randelleremo": "randellare",
    "randellereste": "randellare",
    "randelleresti": "randellare",
    "randellerete": "randellare",
    "randellerà": "randellare",
    "randellerò": "randellare",
    "randelli": "randello",
    "randelliamo": "randellare",
    "randelliate": "randellare",
    "randellin": "randellare",
    "randellino": "randellare",
    "randello": "randellare",
    "randellò": "randellare",
    "rane": "rana",
    "ranghi": "rango",
    "rannicchi": "rannicchiare",
    "rannicchia": "rannicchiare",
    "rannicchiai": "rannicchiare",
    "rannicchiammo": "rannicchiare",
    "rannicchiamo": "rannicchiare",
    "rannicchian": "rannicchiare",
    "rannicchiando": "rannicchiare",
    "rannicchiano": "rannicchiare",
    "rannicchiante": "rannicchiare",
    "rannicchianti": "rannicchiare",
    "rannicchiar": "rannicchiare",
    "rannicchiaron": "rannicchiare",
    "rannicchiarono": "rannicchiare",
    "rannicchiasse": "rannicchiare",
    "rannicchiasser": "rannicchiare",
    "rannicchiassero": "rannicchiare",
    "rannicchiassi": "rannicchiare",
    "rannicchiassimo": "rannicchiare",
    "rannicchiaste": "rannicchiare",
    "rannicchiasti": "rannicchiare",
    "rannicchiata": "rannicchiare",
    "rannicchiate": "rannicchiare",
    "rannicchiati": "rannicchiare",
    "rannicchiato": "rannicchiare",
    "rannicchiava": "rannicchiare",
    "rannicchiavamo": "rannicchiare",
    "rannicchiavan": "rannicchiare",
    "rannicchiavano": "rannicchiare",
    "rannicchiavate": "rannicchiare",
    "rannicchiavi": "rannicchiare",
    "rannicchiavo": "rannicchiare",
    "rannicchierai": "rannicchiare",
    "rannicchieran": "rannicchiare",
    "rannicchieranno": "rannicchiare",
    "rannicchierebbe": "rannicchiare",
    "rannicchierebber": "rannicchiare",
    "rannicchierebbero": "rannicchiare",
    "rannicchierei": "rannicchiare",
    "rannicchieremmo": "rannicchiare",
    "rannicchieremo": "rannicchiare",
    "rannicchiereste": "rannicchiare",
    "rannicchieresti": "rannicchiare",
    "rannicchierete": "rannicchiare",
    "rannicchierà": "rannicchiare",
    "rannicchierò": "rannicchiare",
    "rannicchin": "rannicchiare",
    "rannicchino": "rannicchiare",
    "rannicchio": "rannicchiare",
    "rannicchiò": "rannicchiare",
    "rannuvola": "rannuvolare",
    "rannuvolai": "rannuvolare",
    "rannuvolammo": "rannuvolare",
    "rannuvolan": "rannuvolare",
    "rannuvolando": "rannuvolare",
    "rannuvolano": "rannuvolare",
    "rannuvolante": "rannuvolare",
    "rannuvolanti": "rannuvolare",
    "rannuvolar": "rannuvolare",
    "rannuvolaron": "rannuvolare",
    "rannuvolarono": "rannuvolare",
    "rannuvolasse": "rannuvolare",
    "rannuvolasser": "rannuvolare",
    "rannuvolassero": "rannuvolare",
    "rannuvolassi": "rannuvolare",
    "rannuvolassimo": "rannuvolare",
    "rannuvolaste": "rannuvolare",
    "rannuvolasti": "rannuvolare",
    "rannuvolata": "rannuvolare",
    "rannuvolate": "rannuvolare",
    "rannuvolati": "rannuvolare",
    "rannuvolato": "rannuvolare",
    "rannuvolava": "rannuvolare",
    "rannuvolavamo": "rannuvolare",
    "rannuvolavan": "rannuvolare",
    "rannuvolavano": "rannuvolare",
    "rannuvolavate": "rannuvolare",
    "rannuvolavi": "rannuvolare",
    "rannuvolavo": "rannuvolare",
    "rannuvolerai": "rannuvolare",
    "rannuvoleran": "rannuvolare",
    "rannuvoleranno": "rannuvolare",
    "rannuvolerebbe": "rannuvolare",
    "rannuvolerebber": "rannuvolare",
    "rannuvolerebbero": "rannuvolare",
    "rannuvolerei": "rannuvolare",
    "rannuvoleremmo": "rannuvolare",
    "rannuvoleremo": "rannuvolare",
    "rannuvolereste": "rannuvolare",
    "rannuvoleresti": "rannuvolare",
    "rannuvolerete": "rannuvolare",
    "rannuvolerà": "rannuvolare",
    "rannuvolerò": "rannuvolare",
    "rannuvoli": "rannuvolare",
    "rannuvoliamo": "rannuvolare",
    "rannuvoliate": "rannuvolare",
    "rannuvolin": "rannuvolare",
    "rannuvolino": "rannuvolare",
    "rannuvolo": "rannuvolare",
    "rannuvolò": "rannuvolare",
    "ranocchi": "ranocchio",
    "ranocchie": "ranocchia",
    "rantola": "rantolare",
    "rantolai": "rantolare",
    "rantolammo": "rantolare",
    "rantolan": "rantolare",
    "rantolando": "rantolare",
    "rantolano": "rantolare",
    "rantolante": "rantolare",
    "rantolanti": "rantolare",
    "rantolar": "rantolare",
    "rantolaron": "rantolare",
    "rantolarono": "rantolare",
    "rantolasse": "rantolare",
    "rantolasser": "rantolare",
    "rantolassero": "rantolare",
    "rantolassi": "rantolare",
    "rantolassimo": "rantolare",
    "rantolaste": "rantolare",
    "rantolasti": "rantolare",
    "rantolata": "rantolare",
    "rantolate": "rantolare",
    "rantolati": "rantolare",
    "rantolato": "rantolare",
    "rantolava": "rantolare",
    "rantolavamo": "rantolare",
    "rantolavan": "rantolare",
    "rantolavano": "rantolare",
    "rantolavate": "rantolare",
    "rantolavi": "rantolare",
    "rantolavo": "rantolare",
    "rantolerai": "rantolare",
    "rantoleran": "rantolare",
    "rantoleranno": "rantolare",
    "rantolerebbe": "rantolare",
    "rantolerebber": "rantolare",
    "rantolerebbero": "rantolare",
    "rantolerei": "rantolare",
    "rantoleremmo": "rantolare",
    "rantoleremo": "rantolare",
    "rantolereste": "rantolare",
    "rantoleresti": "rantolare",
    "rantolerete": "rantolare",
    "rantolerà": "rantolare",
    "rantolerò": "rantolare",
    "rantoli": "rantolo",
    "rantoliamo": "rantolare",
    "rantoliate": "rantolare",
    "rantolin": "rantolare",
    "rantolino": "rantolare",
    "rantolo": "rantolare",
    "rantolò": "rantolare",
    "rapa": "rapare",
    "rapaci": "rapace",
    "rapai": "rapare",
    "rapammo": "rapare",
    "rapan": "rapare",
    "rapando": "rapare",
    "rapano": "rapare",
    "rapante": "rapare",
    "rapanti": "rapare",
    "rapar": "rapare",
    "raparon": "rapare",
    "raparono": "rapare",
    "rapasse": "rapare",
    "rapasser": "rapare",
    "rapassero": "rapare",
    "rapassi": "rapare",
    "rapassimo": "rapare",
    "rapaste": "rapare",
    "rapasti": "rapare",
    "rapata": "rapare",
    "rapate": "rapare",
    "rapati": "rapare",
    "rapato": "rapare",
    "rapava": "rapare",
    "rapavamo": "rapare",
    "rapavan": "rapare",
    "rapavano": "rapare",
    "rapavate": "rapare",
    "rapavi": "rapare",
    "rapavo": "rapare",
    "rape": "rapa",
    "rapendo": "rapire",
    "rapente": "rapire",
    "rapenti": "rapire",
    "raperai": "rapare",
    "raperan": "rapare",
    "raperanno": "rapare",
    "raperebbe": "rapare",
    "raperebber": "rapare",
    "raperebbero": "rapare",
    "raperei": "rapare",
    "raperemmo": "rapare",
    "raperemo": "rapare",
    "rapereste": "rapare",
    "raperesti": "rapare",
    "raperete": "rapare",
    "raperà": "rapare",
    "raperò": "rapare",
    "rapi": "rapare",
    "rapiamo": "rapire",
    "rapiate": "rapire",
    "rapida": "rapido",
    "rapide": "rapido",
    "rapidi": "rapido",
    "rapii": "rapire",
    "rapimenti": "rapimento",
    "rapimmo": "rapire",
    "rapin": "rapare",
    "rapina": "rapinare",
    "rapinai": "rapinare",
    "rapinammo": "rapinare",
    "rapinan": "rapinare",
    "rapinando": "rapinare",
    "rapinano": "rapinare",
    "rapinante": "rapinare",
    "rapinanti": "rapinare",
    "rapinar": "rapinare",
    "rapinaron": "rapinare",
    "rapinarono": "rapinare",
    "rapinasse": "rapinare",
    "rapinasser": "rapinare",
    "rapinassero": "rapinare",
    "rapinassi": "rapinare",
    "rapinassimo": "rapinare",
    "rapinaste": "rapinare",
    "rapinasti": "rapinare",
    "rapinata": "rapinare",
    "rapinate": "rapinare",
    "rapinati": "rapinato",
    "rapinato": "rapinare",
    "rapinatori": "rapinatore",
    "rapinava": "rapinare",
    "rapinavamo": "rapinare",
    "rapinavan": "rapinare",
    "rapinavano": "rapinare",
    "rapinavate": "rapinare",
    "rapinavi": "rapinare",
    "rapinavo": "rapinare",
    "rapine": "rapina",
    "rapinerai": "rapinare",
    "rapineran": "rapinare",
    "rapineranno": "rapinare",
    "rapinerebbe": "rapinare",
    "rapinerebber": "rapinare",
    "rapinerebbero": "rapinare",
    "rapinerei": "rapinare",
    "rapineremmo": "rapinare",
    "rapineremo": "rapinare",
    "rapinereste": "rapinare",
    "rapineresti": "rapinare",
    "rapinerete": "rapinare",
    "rapinerà": "rapinare",
    "rapinerò": "rapinare",
    "rapini": "rapinare",
    "rapiniamo": "rapinare",
    "rapiniate": "rapinare",
    "rapinin": "rapinare",
    "rapinino": "rapinare",
    "rapino": "rapinare",
    "rapinosa": "rapinoso",
    "rapinose": "rapinoso",
    "rapinosi": "rapinoso",
    "rapinò": "rapinare",
    "rapir": "rapire",
    "rapirai": "rapire",
    "rapiran": "rapire",
    "rapiranno": "rapire",
    "rapirebbe": "rapire",
    "rapirebber": "rapire",
    "rapirebbero": "rapire",
    "rapirei": "rapire",
    "rapiremmo": "rapire",
    "rapiremo": "rapire",
    "rapireste": "rapire",
    "rapiresti": "rapire",
    "rapirete": "rapire",
    "rapiron": "rapire",
    "rapirono": "rapire",
    "rapirà": "rapire",
    "rapirò": "rapire",
    "rapisca": "rapire",
    "rapiscan": "rapire",
    "rapiscano": "rapire",
    "rapisce": "rapire",
    "rapisci": "rapire",
    "rapisco": "rapire",
    "rapiscon": "rapire",
    "rapiscono": "rapire",
    "rapisse": "rapire",
    "rapisser": "rapire",
    "rapissero": "rapire",
    "rapissi": "rapire",
    "rapissimo": "rapire",
    "rapiste": "rapire",
    "rapisti": "rapire",
    "rapita": "rapito",
    "rapite": "rapito",
    "rapiti": "rapito",
    "rapito": "rapire",
    "rapitori": "rapitore",
    "rapitrice": "rapitore",
    "rapitrici": "rapitore",
    "rapiva": "rapire",
    "rapivamo": "rapire",
    "rapivan": "rapire",
    "rapivano": "rapire",
    "rapivate": "rapire",
    "rapivi": "rapire",
    "rapivo": "rapire",
    "rapo": "rapare",
    "rappacifica": "rappacificare",
    "rappacificai": "rappacificare",
    "rappacificammo": "rappacificare",
    "rappacifican": "rappacificare",
    "rappacificando": "rappacificare",
    "rappacificano": "rappacificare",
    "rappacificante": "rappacificare",
    "rappacificanti": "rappacificare",
    "rappacificar": "rappacificare",
    "rappacificaron": "rappacificare",
    "rappacificarono": "rappacificare",
    "rappacificasse": "rappacificare",
    "rappacificasser": "rappacificare",
    "rappacificassero": "rappacificare",
    "rappacificassi": "rappacificare",
    "rappacificassimo": "rappacificare",
    "rappacificaste": "rappacificare",
    "rappacificasti": "rappacificare",
    "rappacificata": "rappacificare",
    "rappacificate": "rappacificare",
    "rappacificati": "rappacificare",
    "rappacificato": "rappacificare",
    "rappacificava": "rappacificare",
    "rappacificavamo": "rappacificare",
    "rappacificavan": "rappacificare",
    "rappacificavano": "rappacificare",
    "rappacificavate": "rappacificare",
    "rappacificavi": "rappacificare",
    "rappacificavo": "rappacificare",
    "rappacificazioni": "rappacificazione",
    "rappacificherai": "rappacificare",
    "rappacificheran": "rappacificare",
    "rappacificheranno": "rappacificare",
    "rappacificherebbe": "rappacificare",
    "rappacificherebber": "rappacificare",
    "rappacificherebbero": "rappacificare",
    "rappacificherei": "rappacificare",
    "rappacificheremmo": "rappacificare",
    "rappacificheremo": "rappacificare",
    "rappacifichereste": "rappacificare",
    "rappacificheresti": "rappacificare",
    "rappacificherete": "rappacificare",
    "rappacificherà": "rappacificare",
    "rappacificherò": "rappacificare",
    "rappacifichi": "rappacificare",
    "rappacifichiamo": "rappacificare",
    "rappacifichiate": "rappacificare",
    "rappacifichin": "rappacificare",
    "rappacifichino": "rappacificare",
    "rappacifico": "rappacificare",
    "rappacificò": "rappacificare",
    "rappattuma": "rappattumare",
    "rappattumai": "rappattumare",
    "rappattumammo": "rappattumare",
    "rappattuman": "rappattumare",
    "rappattumando": "rappattumare",
    "rappattumano": "rappattumare",
    "rappattumante": "rappattumare",
    "rappattumanti": "rappattumare",
    "rappattumar": "rappattumare",
    "rappattumaron": "rappattumare",
    "rappattumarono": "rappattumare",
    "rappattumasse": "rappattumare",
    "rappattumasser": "rappattumare",
    "rappattumassero": "rappattumare",
    "rappattumassi": "rappattumare",
    "rappattumassimo": "rappattumare",
    "rappattumaste": "rappattumare",
    "rappattumasti": "rappattumare",
    "rappattumata": "rappattumare",
    "rappattumate": "rappattumare",
    "rappattumati": "rappattumare",
    "rappattumato": "rappattumare",
    "rappattumava": "rappattumare",
    "rappattumavamo": "rappattumare",
    "rappattumavan": "rappattumare",
    "rappattumavano": "rappattumare",
    "rappattumavate": "rappattumare",
    "rappattumavi": "rappattumare",
    "rappattumavo": "rappattumare",
    "rappattumerai": "rappattumare",
    "rappattumeran": "rappattumare",
    "rappattumeranno": "rappattumare",
    "rappattumerebbe": "rappattumare",
    "rappattumerebber": "rappattumare",
    "rappattumerebbero": "rappattumare",
    "rappattumerei": "rappattumare",
    "rappattumeremmo": "rappattumare",
    "rappattumeremo": "rappattumare",
    "rappattumereste": "rappattumare",
    "rappattumeresti": "rappattumare",
    "rappattumerete": "rappattumare",
    "rappattumerà": "rappattumare",
    "rappattumerò": "rappattumare",
    "rappattumi": "rappattumare",
    "rappattumiamo": "rappattumare",
    "rappattumiate": "rappattumare",
    "rappattumin": "rappattumare",
    "rappattumino": "rappattumare",
    "rappattumo": "rappattumare",
    "rappattumò": "rappattumare",
    "rappezza": "rappezzare",
    "rappezzai": "rappezzare",
    "rappezzammo": "rappezzare",
    "rappezzan": "rappezzare",
    "rappezzando": "rappezzare",
    "rappezzano": "rappezzare",
    "rappezzante": "rappezzare",
    "rappezzanti": "rappezzare",
    "rappezzar": "rappezzare",
    "rappezzaron": "rappezzare",
    "rappezzarono": "rappezzare",
    "rappezzasse": "rappezzare",
    "rappezzasser": "rappezzare",
    "rappezzassero": "rappezzare",
    "rappezzassi": "rappezzare",
    "rappezzassimo": "rappezzare",
    "rappezzaste": "rappezzare",
    "rappezzasti": "rappezzare",
    "rappezzata": "rappezzare",
    "rappezzate": "rappezzare",
    "rappezzati": "rappezzare",
    "rappezzato": "rappezzare",
    "rappezzava": "rappezzare",
    "rappezzavamo": "rappezzare",
    "rappezzavan": "rappezzare",
    "rappezzavano": "rappezzare",
    "rappezzavate": "rappezzare",
    "rappezzavi": "rappezzare",
    "rappezzavo": "rappezzare",
    "rappezzerai": "rappezzare",
    "rappezzeran": "rappezzare",
    "rappezzeranno": "rappezzare",
    "rappezzerebbe": "rappezzare",
    "rappezzerebber": "rappezzare",
    "rappezzerebbero": "rappezzare",
    "rappezzerei": "rappezzare",
    "rappezzeremmo": "rappezzare",
    "rappezzeremo": "rappezzare",
    "rappezzereste": "rappezzare",
    "rappezzeresti": "rappezzare",
    "rappezzerete": "rappezzare",
    "rappezzerà": "rappezzare",
    "rappezzerò": "rappezzare",
    "rappezzi": "rappezzare",
    "rappezziamo": "rappezzare",
    "rappezziate": "rappezzare",
    "rappezzin": "rappezzare",
    "rappezzino": "rappezzare",
    "rappezzo": "rappezzare",
    "rappezzò": "rappezzare",
    "rapporta": "rapportare",
    "rapportabili": "rapportabile",
    "rapportai": "rapportare",
    "rapportammo": "rapportare",
    "rapportan": "rapportare",
    "rapportando": "rapportare",
    "rapportano": "rapportare",
    "rapportante": "rapportare",
    "rapportanti": "rapportare",
    "rapportar": "rapportare",
    "rapportaron": "rapportare",
    "rapportarono": "rapportare",
    "rapportasse": "rapportare",
    "rapportasser": "rapportare",
    "rapportassero": "rapportare",
    "rapportassi": "rapportare",
    "rapportassimo": "rapportare",
    "rapportaste": "rapportare",
    "rapportasti": "rapportare",
    "rapportata": "rapportare",
    "rapportate": "rapportare",
    "rapportati": "rapportare",
    "rapportato": "rapportare",
    "rapportava": "rapportare",
    "rapportavamo": "rapportare",
    "rapportavan": "rapportare",
    "rapportavano": "rapportare",
    "rapportavate": "rapportare",
    "rapportavi": "rapportare",
    "rapportavo": "rapportare",
    "rapporterai": "rapportare",
    "rapporteran": "rapportare",
    "rapporteranno": "rapportare",
    "rapporterebbe": "rapportare",
    "rapporterebber": "rapportare",
    "rapporterebbero": "rapportare",
    "rapporterei": "rapportare",
    "rapporteremmo": "rapportare",
    "rapporteremo": "rapportare",
    "rapportereste": "rapportare",
    "rapporteresti": "rapportare",
    "rapporterete": "rapportare",
    "rapporterà": "rapportare",
    "rapporterò": "rapportare",
    "rapporti": "rapporto",
    "rapportiamo": "rapportare",
    "rapportiate": "rapportare",
    "rapportin": "rapportare",
    "rapportino": "rapportare",
    "rapporto": "rapportare",
    "rapportò": "rapportare",
    "rappporti": "rappporto",
    "rapprenda": "rapprendere",
    "rapprendan": "rapprendere",
    "rapprendano": "rapprendere",
    "rapprende": "rapprendere",
    "rapprendemmo": "rapprendere",
    "rapprendendo": "rapprendere",
    "rapprendente": "rapprendere",
    "rapprendenti": "rapprendere",
    "rapprender": "rapprendere",
    "rapprenderai": "rapprendere",
    "rapprenderan": "rapprendere",
    "rapprenderanno": "rapprendere",
    "rapprenderebbe": "rapprendere",
    "rapprenderebber": "rapprendere",
    "rapprenderebbero": "rapprendere",
    "rapprenderei": "rapprendere",
    "rapprenderemmo": "rapprendere",
    "rapprenderemo": "rapprendere",
    "rapprendereste": "rapprendere",
    "rapprenderesti": "rapprendere",
    "rapprenderete": "rapprendere",
    "rapprenderà": "rapprendere",
    "rapprenderò": "rapprendere",
    "rapprendesse": "rapprendere",
    "rapprendesser": "rapprendere",
    "rapprendessero": "rapprendere",
    "rapprendessi": "rapprendere",
    "rapprendessimo": "rapprendere",
    "rapprendeste": "rapprendere",
    "rapprendesti": "rapprendere",
    "rapprendete": "rapprendere",
    "rapprendeva": "rapprendere",
    "rapprendevamo": "rapprendere",
    "rapprendevan": "rapprendere",
    "rapprendevano": "rapprendere",
    "rapprendevate": "rapprendere",
    "rapprendevi": "rapprendere",
    "rapprendevo": "rapprendere",
    "rapprendi": "rapprendere",
    "rapprendiamo": "rapprendere",
    "rapprendiate": "rapprendere",
    "rapprendo": "rapprendere",
    "rapprendon": "rapprendere",
    "rapprendono": "rapprendere",
    "rappresa": "rapprendere",
    "rappresaglie": "rappresaglia",
    "rapprese": "rapprendere",
    "rappresenta": "rappresentare",
    "rappresentabili": "rappresentabile",
    "rappresentai": "rappresentare",
    "rappresentammo": "rappresentare",
    "rappresentan": "rappresentare",
    "rappresentando": "rappresentare",
    "rappresentano": "rappresentare",
    "rappresentante": "rappresentare",
    "rappresentanti": "rappresentare",
    "rappresentanze": "rappresentanza",
    "rappresentar": "rappresentare",
    "rappresentaron": "rappresentare",
    "rappresentarono": "rappresentare",
    "rappresentasse": "rappresentare",
    "rappresentasser": "rappresentare",
    "rappresentassero": "rappresentare",
    "rappresentassi": "rappresentare",
    "rappresentassimo": "rappresentare",
    "rappresentaste": "rappresentare",
    "rappresentasti": "rappresentare",
    "rappresentata": "rappresentare",
    "rappresentate": "rappresentare",
    "rappresentati": "rappresentare",
    "rappresentativa": "rappresentativo",
    "rappresentative": "rappresentativo",
    "rappresentativi": "rappresentativo",
    "rappresentato": "rappresentare",
    "rappresentava": "rappresentare",
    "rappresentavamo": "rappresentare",
    "rappresentavan": "rappresentare",
    "rappresentavano": "rappresentare",
    "rappresentavate": "rappresentare",
    "rappresentavi": "rappresentare",
    "rappresentavo": "rappresentare",
    "rappresentazioni": "rappresentazione",
    "rappresenterai": "rappresentare",
    "rappresenteran": "rappresentare",
    "rappresenteranno": "rappresentare",
    "rappresenterebbe": "rappresentare",
    "rappresenterebber": "rappresentare",
    "rappresenterebbero": "rappresentare",
    "rappresenterei": "rappresentare",
    "rappresenteremmo": "rappresentare",
    "rappresenteremo": "rappresentare",
    "rappresentereste": "rappresentare",
    "rappresenteresti": "rappresentare",
    "rappresenterete": "rappresentare",
    "rappresenterà": "rappresentare",
    "rappresenterò": "rappresentare",
    "rappresenti": "rappresentare",
    "rappresentiamo": "rappresentare",
    "rappresentiate": "rappresentare",
    "rappresentin": "rappresentare",
    "rappresentino": "rappresentare",
    "rappresento": "rappresentare",
    "rappresentò": "rappresentare",
    "rappreser": "rapprendere",
    "rappresero": "rapprendere",
    "rappresi": "rapprendere",
    "rappreso": "rapprendere",
    "rappresè": "rapprendere",
    "rapsodi": "rapsodo",
    "rapsodica": "rapsodico",
    "rapsodiche": "rapsodico",
    "rapsodici": "rapsodico",
    "rapì": "rapire",
    "rapò": "rapare",
    "rara": "raro",
    "rare": "raro",
    "rarefa": "rarefare",
    "rarefa'": "rarefare",
    "rarefaccia": "rarefare",
    "rarefacciamo": "rarefare",
    "rarefaccian": "rarefare",
    "rarefacciano": "rarefare",
    "rarefacciate": "rarefare",
    "rarefaccio": "rarefare",
    "rarefacemmo": "rarefare",
    "rarefacendo": "rarefare",
    "rarefacente": "rarefare",
    "rarefacenti": "rarefare",
    "rarefacesse": "rarefare",
    "rarefacesser": "rarefare",
    "rarefacessero": "rarefare",
    "rarefacessi": "rarefare",
    "rarefacessimo": "rarefare",
    "rarefaceste": "rarefare",
    "rarefacesti": "rarefare",
    "rarefaceva": "rarefare",
    "rarefacevamo": "rarefare",
    "rarefacevan": "rarefare",
    "rarefacevano": "rarefare",
    "rarefacevate": "rarefare",
    "rarefacevi": "rarefare",
    "rarefacevo": "rarefare",
    "rarefai": "rarefare",
    "rarefan": "rarefare",
    "rarefanno": "rarefare",
    "rarefar": "rarefare",
    "rarefarai": "rarefare",
    "rarefaran": "rarefare",
    "rarefaranno": "rarefare",
    "rarefarebbe": "rarefare",
    "rarefarebber": "rarefare",
    "rarefarebbero": "rarefare",
    "rarefarei": "rarefare",
    "rarefaremmo": "rarefare",
    "rarefaremo": "rarefare",
    "rarefareste": "rarefare",
    "rarefaresti": "rarefare",
    "rarefarete": "rarefare",
    "rarefarà": "rarefare",
    "rarefarò": "rarefare",
    "rarefate": "rarefare",
    "rarefatta": "rarefare",
    "rarefatte": "rarefare",
    "rarefatti": "rarefare",
    "rarefatto": "rarefare",
    "rarefazioni": "rarefazione",
    "rarefece": "rarefare",
    "rarefecer": "rarefare",
    "rarefecero": "rarefare",
    "rarefeci": "rarefare",
    "rari": "raro",
    "rasa": "raso",
    "rasai": "rasare",
    "rasammo": "rasare",
    "rasan": "rasare",
    "rasando": "rasare",
    "rasano": "rasare",
    "rasante": "rasare",
    "rasanti": "rasare",
    "rasar": "rasare",
    "rasaron": "rasare",
    "rasarono": "rasare",
    "rasasse": "rasare",
    "rasasser": "rasare",
    "rasassero": "rasare",
    "rasassi": "rasare",
    "rasassimo": "rasare",
    "rasaste": "rasare",
    "rasasti": "rasare",
    "rasata": "rasato",
    "rasate": "rasato",
    "rasati": "rasato",
    "rasato": "rasare",
    "rasature": "rasatura",
    "rasava": "rasare",
    "rasavamo": "rasare",
    "rasavan": "rasare",
    "rasavano": "rasare",
    "rasavate": "rasare",
    "rasavi": "rasare",
    "rasavo": "rasare",
    "raschi": "raschiare",
    "raschia": "raschiare",
    "raschiai": "raschiare",
    "raschiammo": "raschiare",
    "raschiamo": "raschiare",
    "raschian": "raschiare",
    "raschiando": "raschiare",
    "raschiano": "raschiare",
    "raschiante": "raschiare",
    "raschianti": "raschiare",
    "raschiar": "raschiare",
    "raschiaron": "raschiare",
    "raschiarono": "raschiare",
    "raschiasse": "raschiare",
    "raschiasser": "raschiare",
    "raschiassero": "raschiare",
    "raschiassi": "raschiare",
    "raschiassimo": "raschiare",
    "raschiaste": "raschiare",
    "raschiasti": "raschiare",
    "raschiata": "raschiare",
    "raschiate": "raschiare",
    "raschiati": "raschiare",
    "raschiato": "raschiare",
    "raschiava": "raschiare",
    "raschiavamo": "raschiare",
    "raschiavan": "raschiare",
    "raschiavano": "raschiare",
    "raschiavate": "raschiare",
    "raschiavi": "raschiare",
    "raschiavo": "raschiare",
    "raschierai": "raschiare",
    "raschieran": "raschiare",
    "raschieranno": "raschiare",
    "raschierebbe": "raschiare",
    "raschierebber": "raschiare",
    "raschierebbero": "raschiare",
    "raschierei": "raschiare",
    "raschieremmo": "raschiare",
    "raschieremo": "raschiare",
    "raschiereste": "raschiare",
    "raschieresti": "raschiare",
    "raschierete": "raschiare",
    "raschierà": "raschiare",
    "raschierò": "raschiare",
    "raschin": "raschiare",
    "raschino": "raschiare",
    "raschio": "raschiare",
    "raschiò": "raschiare",
    "rasciuga": "rasciugare",
    "rasciugai": "rasciugare",
    "rasciugammo": "rasciugare",
    "rasciugan": "rasciugare",
    "rasciugando": "rasciugare",
    "rasciugano": "rasciugare",
    "rasciugante": "rasciugare",
    "rasciuganti": "rasciugare",
    "rasciugar": "rasciugare",
    "rasciugaron": "rasciugare",
    "rasciugarono": "rasciugare",
    "rasciugasse": "rasciugare",
    "rasciugasser": "rasciugare",
    "rasciugassero": "rasciugare",
    "rasciugassi": "rasciugare",
    "rasciugassimo": "rasciugare",
    "rasciugaste": "rasciugare",
    "rasciugasti": "rasciugare",
    "rasciugata": "rasciugare",
    "rasciugate": "rasciugare",
    "rasciugati": "rasciugare",
    "rasciugato": "rasciugare",
    "rasciugava": "rasciugare",
    "rasciugavamo": "rasciugare",
    "rasciugavan": "rasciugare",
    "rasciugavano": "rasciugare",
    "rasciugavate": "rasciugare",
    "rasciugavi": "rasciugare",
    "rasciugavo": "rasciugare",
    "rasciugherai": "rasciugare",
    "rasciugheran": "rasciugare",
    "rasciugheranno": "rasciugare",
    "rasciugherebbe": "rasciugare",
    "rasciugherebber": "rasciugare",
    "rasciugherebbero": "rasciugare",
    "rasciugherei": "rasciugare",
    "rasciugheremmo": "rasciugare",
    "rasciugheremo": "rasciugare",
    "rasciughereste": "rasciugare",
    "rasciugheresti": "rasciugare",
    "rasciugherete": "rasciugare",
    "rasciugherà": "rasciugare",
    "rasciugherò": "rasciugare",
    "rasciughi": "rasciugare",
    "rasciughiamo": "rasciugare",
    "rasciughiate": "rasciugare",
    "rasciughin": "rasciugare",
    "rasciughino": "rasciugare",
    "rasciugo": "rasciugare",
    "rasciugò": "rasciugare",
    "rase": "raso",
    "rasenta": "rasentare",
    "rasentai": "rasentare",
    "rasentammo": "rasentare",
    "rasentan": "rasentare",
    "rasentando": "rasentare",
    "rasentano": "rasentare",
    "rasentante": "rasentare",
    "rasentanti": "rasentare",
    "rasentar": "rasentare",
    "rasentaron": "rasentare",
    "rasentarono": "rasentare",
    "rasentasse": "rasentare",
    "rasentasser": "rasentare",
    "rasentassero": "rasentare",
    "rasentassi": "rasentare",
    "rasentassimo": "rasentare",
    "rasentaste": "rasentare",
    "rasentasti": "rasentare",
    "rasentata": "rasentare",
    "rasentate": "rasentare",
    "rasentati": "rasentare",
    "rasentato": "rasentare",
    "rasentava": "rasentare",
    "rasentavamo": "rasentare",
    "rasentavan": "rasentare",
    "rasentavano": "rasentare",
    "rasentavate": "rasentare",
    "rasentavi": "rasentare",
    "rasentavo": "rasentare",
    "rasenterai": "rasentare",
    "rasenteran": "rasentare",
    "rasenteranno": "rasentare",
    "rasenterebbe": "rasentare",
    "rasenterebber": "rasentare",
    "rasenterebbero": "rasentare",
    "rasenterei": "rasentare",
    "rasenteremmo": "rasentare",
    "rasenteremo": "rasentare",
    "rasentereste": "rasentare",
    "rasenteresti": "rasentare",
    "rasenterete": "rasentare",
    "rasenterà": "rasentare",
    "rasenterò": "rasentare",
    "rasenti": "rasentare",
    "rasentiamo": "rasentare",
    "rasentiate": "rasentare",
    "rasentin": "rasentare",
    "rasentino": "rasentare",
    "rasento": "rasentare",
    "rasentò": "rasentare",
    "raserai": "rasare",
    "raseran": "rasare",
    "raseranno": "rasare",
    "raserebbe": "rasare",
    "raserebber": "rasare",
    "raserebbero": "rasare",
    "raserei": "rasare",
    "raseremmo": "rasare",
    "raseremo": "rasare",
    "rasereste": "rasare",
    "raseresti": "rasare",
    "raserete": "rasare",
    "raserà": "rasare",
    "raserò": "rasare",
    "rasi": "raso",
    "rasiamo": "rasare",
    "rasiate": "rasare",
    "rasin": "rasare",
    "rasino": "rasare",
    "raso": "rasare",
    "rasoi": "rasoio",
    "rasoiate": "rasoiata",
    "raspa": "raspare",
    "raspai": "raspare",
    "raspammo": "raspare",
    "raspan": "raspare",
    "raspando": "raspare",
    "raspano": "raspare",
    "raspante": "raspare",
    "raspanti": "raspare",
    "raspar": "raspare",
    "rasparon": "raspare",
    "rasparono": "raspare",
    "raspasse": "raspare",
    "raspasser": "raspare",
    "raspassero": "raspare",
    "raspassi": "raspare",
    "raspassimo": "raspare",
    "raspaste": "raspare",
    "raspasti": "raspare",
    "raspata": "raspare",
    "raspate": "raspare",
    "raspati": "raspare",
    "raspato": "raspare",
    "raspava": "raspare",
    "raspavamo": "raspare",
    "raspavan": "raspare",
    "raspavano": "raspare",
    "raspavate": "raspare",
    "raspavi": "raspare",
    "raspavo": "raspare",
    "rasperai": "raspare",
    "rasperan": "raspare",
    "rasperanno": "raspare",
    "rasperebbe": "raspare",
    "rasperebber": "raspare",
    "rasperebbero": "raspare",
    "rasperei": "raspare",
    "rasperemmo": "raspare",
    "rasperemo": "raspare",
    "raspereste": "raspare",
    "rasperesti": "raspare",
    "rasperete": "raspare",
    "rasperà": "raspare",
    "rasperò": "raspare",
    "raspi": "raspare",
    "raspiamo": "raspare",
    "raspiate": "raspare",
    "raspin": "raspare",
    "raspino": "raspare",
    "raspo": "raspare",
    "raspò": "raspare",
    "rassega": "rassegare",
    "rassegai": "rassegare",
    "rassegammo": "rassegare",
    "rassegan": "rassegare",
    "rassegando": "rassegare",
    "rassegano": "rassegare",
    "rassegante": "rassegare",
    "rasseganti": "rassegare",
    "rassegar": "rassegare",
    "rassegaron": "rassegare",
    "rassegarono": "rassegare",
    "rassegasse": "rassegare",
    "rassegasser": "rassegare",
    "rassegassero": "rassegare",
    "rassegassi": "rassegare",
    "rassegassimo": "rassegare",
    "rassegaste": "rassegare",
    "rassegasti": "rassegare",
    "rassegata": "rassegare",
    "rassegate": "rassegare",
    "rassegati": "rassegare",
    "rassegato": "rassegare",
    "rassegava": "rassegare",
    "rassegavamo": "rassegare",
    "rassegavan": "rassegare",
    "rassegavano": "rassegare",
    "rassegavate": "rassegare",
    "rassegavi": "rassegare",
    "rassegavo": "rassegare",
    "rassegherai": "rassegare",
    "rassegheran": "rassegare",
    "rassegheranno": "rassegare",
    "rassegherebbe": "rassegare",
    "rassegherebber": "rassegare",
    "rassegherebbero": "rassegare",
    "rassegherei": "rassegare",
    "rassegheremmo": "rassegare",
    "rassegheremo": "rassegare",
    "rasseghereste": "rassegare",
    "rassegheresti": "rassegare",
    "rassegherete": "rassegare",
    "rassegherà": "rassegare",
    "rassegherò": "rassegare",
    "rasseghi": "rassegare",
    "rasseghiamo": "rassegare",
    "rasseghiate": "rassegare",
    "rasseghin": "rassegare",
    "rasseghino": "rassegare",
    "rassegna": "rassegnare",
    "rassegnai": "rassegnare",
    "rassegnammo": "rassegnare",
    "rassegnan": "rassegnare",
    "rassegnando": "rassegnare",
    "rassegnano": "rassegnare",
    "rassegnante": "rassegnare",
    "rassegnanti": "rassegnare",
    "rassegnar": "rassegnare",
    "rassegnaron": "rassegnare",
    "rassegnarono": "rassegnare",
    "rassegnasse": "rassegnare",
    "rassegnasser": "rassegnare",
    "rassegnassero": "rassegnare",
    "rassegnassi": "rassegnare",
    "rassegnassimo": "rassegnare",
    "rassegnaste": "rassegnare",
    "rassegnasti": "rassegnare",
    "rassegnata": "rassegnato",
    "rassegnate": "rassegnato",
    "rassegnati": "rassegnato",
    "rassegnato": "rassegnare",
    "rassegnava": "rassegnare",
    "rassegnavamo": "rassegnare",
    "rassegnavan": "rassegnare",
    "rassegnavano": "rassegnare",
    "rassegnavate": "rassegnare",
    "rassegnavi": "rassegnare",
    "rassegnavo": "rassegnare",
    "rassegnazioni": "rassegnazione",
    "rassegne": "rassegna",
    "rassegnerai": "rassegnare",
    "rassegneran": "rassegnare",
    "rassegneranno": "rassegnare",
    "rassegnerebbe": "rassegnare",
    "rassegnerebber": "rassegnare",
    "rassegnerebbero": "rassegnare",
    "rassegnerei": "rassegnare",
    "rassegneremmo": "rassegnare",
    "rassegneremo": "rassegnare",
    "rassegnereste": "rassegnare",
    "rassegneresti": "rassegnare",
    "rassegnerete": "rassegnare",
    "rassegnerà": "rassegnare",
    "rassegnerò": "rassegnare",
    "rassegni": "rassegnare",
    "rassegniamo": "rassegnare",
    "rassegniate": "rassegnare",
    "rassegnin": "rassegnare",
    "rassegnino": "rassegnare",
    "rassegno": "rassegnare",
    "rassegnò": "rassegnare",
    "rassego": "rassegare",
    "rassegò": "rassegare",
    "rasserena": "rasserenare",
    "rasserenai": "rasserenare",
    "rasserenamenti": "rasserenamento",
    "rasserenammo": "rasserenare",
    "rasserenan": "rasserenare",
    "rasserenando": "rasserenare",
    "rasserenano": "rasserenare",
    "rasserenante": "rasserenare",
    "rasserenanti": "rasserenare",
    "rasserenar": "rasserenare",
    "rasserenaron": "rasserenare",
    "rasserenarono": "rasserenare",
    "rasserenasse": "rasserenare",
    "rasserenasser": "rasserenare",
    "rasserenassero": "rasserenare",
    "rasserenassi": "rasserenare",
    "rasserenassimo": "rasserenare",
    "rasserenaste": "rasserenare",
    "rasserenasti": "rasserenare",
    "rasserenata": "rasserenare",
    "rasserenate": "rasserenare",
    "rasserenati": "rasserenare",
    "rasserenato": "rasserenare",
    "rasserenava": "rasserenare",
    "rasserenavamo": "rasserenare",
    "rasserenavan": "rasserenare",
    "rasserenavano": "rasserenare",
    "rasserenavate": "rasserenare",
    "rasserenavi": "rasserenare",
    "rasserenavo": "rasserenare",
    "rasserenerai": "rasserenare",
    "rassereneran": "rasserenare",
    "rassereneranno": "rasserenare",
    "rasserenerebbe": "rasserenare",
    "rasserenerebber": "rasserenare",
    "rasserenerebbero": "rasserenare",
    "rasserenerei": "rasserenare",
    "rassereneremmo": "rasserenare",
    "rassereneremo": "rasserenare",
    "rasserenereste": "rasserenare",
    "rassereneresti": "rasserenare",
    "rasserenerete": "rasserenare",
    "rasserenerà": "rasserenare",
    "rasserenerò": "rasserenare",
    "rassereni": "rasserenare",
    "rassereniamo": "rasserenare",
    "rassereniate": "rasserenare",
    "rasserenin": "rasserenare",
    "rasserenino": "rasserenare",
    "rassereno": "rasserenare",
    "rasserenò": "rasserenare",
    "rassetta": "rassettare",
    "rassettai": "rassettare",
    "rassettammo": "rassettare",
    "rassettan": "rassettare",
    "rassettando": "rassettare",
    "rassettano": "rassettare",
    "rassettante": "rassettare",
    "rassettanti": "rassettare",
    "rassettar": "rassettare",
    "rassettaron": "rassettare",
    "rassettarono": "rassettare",
    "rassettasse": "rassettare",
    "rassettasser": "rassettare",
    "rassettassero": "rassettare",
    "rassettassi": "rassettare",
    "rassettassimo": "rassettare",
    "rassettaste": "rassettare",
    "rassettasti": "rassettare",
    "rassettata": "rassettare",
    "rassettate": "rassettare",
    "rassettati": "rassettare",
    "rassettato": "rassettare",
    "rassettava": "rassettare",
    "rassettavamo": "rassettare",
    "rassettavan": "rassettare",
    "rassettavano": "rassettare",
    "rassettavate": "rassettare",
    "rassettavi": "rassettare",
    "rassettavo": "rassettare",
    "rassetterai": "rassettare",
    "rassetteran": "rassettare",
    "rassetteranno": "rassettare",
    "rassetterebbe": "rassettare",
    "rassetterebber": "rassettare",
    "rassetterebbero": "rassettare",
    "rassetterei": "rassettare",
    "rassetteremmo": "rassettare",
    "rassetteremo": "rassettare",
    "rassettereste": "rassettare",
    "rassetteresti": "rassettare",
    "rassetterete": "rassettare",
    "rassetterà": "rassettare",
    "rassetterò": "rassettare",
    "rassetti": "rassettare",
    "rassettiamo": "rassettare",
    "rassettiate": "rassettare",
    "rassettin": "rassettare",
    "rassettino": "rassettare",
    "rassetto": "rassettare",
    "rassettò": "rassettare",
    "rassicura": "rassicurare",
    "rassicurai": "rassicurare",
    "rassicurammo": "rassicurare",
    "rassicuran": "rassicurare",
    "rassicurando": "rassicurare",
    "rassicurano": "rassicurare",
    "rassicurante": "rassicurare",
    "rassicuranti": "rassicurare",
    "rassicurar": "rassicurare",
    "rassicuraron": "rassicurare",
    "rassicurarono": "rassicurare",
    "rassicurasse": "rassicurare",
    "rassicurasser": "rassicurare",
    "rassicurassero": "rassicurare",
    "rassicurassi": "rassicurare",
    "rassicurassimo": "rassicurare",
    "rassicuraste": "rassicurare",
    "rassicurasti": "rassicurare",
    "rassicurata": "rassicurare",
    "rassicurate": "rassicurare",
    "rassicurati": "rassicurare",
    "rassicurato": "rassicurare",
    "rassicurava": "rassicurare",
    "rassicuravamo": "rassicurare",
    "rassicuravan": "rassicurare",
    "rassicuravano": "rassicurare",
    "rassicuravate": "rassicurare",
    "rassicuravi": "rassicurare",
    "rassicuravo": "rassicurare",
    "rassicurazioni": "rassicurazione",
    "rassicurerai": "rassicurare",
    "rassicureran": "rassicurare",
    "rassicureranno": "rassicurare",
    "rassicurerebbe": "rassicurare",
    "rassicurerebber": "rassicurare",
    "rassicurerebbero": "rassicurare",
    "rassicurerei": "rassicurare",
    "rassicureremmo": "rassicurare",
    "rassicureremo": "rassicurare",
    "rassicurereste": "rassicurare",
    "rassicureresti": "rassicurare",
    "rassicurerete": "rassicurare",
    "rassicurerà": "rassicurare",
    "rassicurerò": "rassicurare",
    "rassicuri": "rassicurare",
    "rassicuriamo": "rassicurare",
    "rassicuriate": "rassicurare",
    "rassicurin": "rassicurare",
    "rassicurino": "rassicurare",
    "rassicuro": "rassicurare",
    "rassicurò": "rassicurare",
    "rassoda": "rassodare",
    "rassodai": "rassodare",
    "rassodammo": "rassodare",
    "rassodan": "rassodare",
    "rassodando": "rassodare",
    "rassodano": "rassodare",
    "rassodante": "rassodare",
    "rassodanti": "rassodare",
    "rassodar": "rassodare",
    "rassodaron": "rassodare",
    "rassodarono": "rassodare",
    "rassodasse": "rassodare",
    "rassodasser": "rassodare",
    "rassodassero": "rassodare",
    "rassodassi": "rassodare",
    "rassodassimo": "rassodare",
    "rassodaste": "rassodare",
    "rassodasti": "rassodare",
    "rassodata": "rassodare",
    "rassodate": "rassodare",
    "rassodati": "rassodare",
    "rassodato": "rassodare",
    "rassodava": "rassodare",
    "rassodavamo": "rassodare",
    "rassodavan": "rassodare",
    "rassodavano": "rassodare",
    "rassodavate": "rassodare",
    "rassodavi": "rassodare",
    "rassodavo": "rassodare",
    "rassoderai": "rassodare",
    "rassoderan": "rassodare",
    "rassoderanno": "rassodare",
    "rassoderebbe": "rassodare",
    "rassoderebber": "rassodare",
    "rassoderebbero": "rassodare",
    "rassoderei": "rassodare",
    "rassoderemmo": "rassodare",
    "rassoderemo": "rassodare",
    "rassodereste": "rassodare",
    "rassoderesti": "rassodare",
    "rassoderete": "rassodare",
    "rassoderà": "rassodare",
    "rassoderò": "rassodare",
    "rassodi": "rassodare",
    "rassodiamo": "rassodare",
    "rassodiate": "rassodare",
    "rassodin": "rassodare",
    "rassodino": "rassodare",
    "rassodo": "rassodare",
    "rassodò": "rassodare",
    "rassomigli": "rassomigliare",
    "rassomiglia": "rassomigliare",
    "rassomigliai": "rassomigliare",
    "rassomigliammo": "rassomigliare",
    "rassomigliamo": "rassomigliare",
    "rassomiglian": "rassomigliare",
    "rassomigliando": "rassomigliare",
    "rassomigliano": "rassomigliare",
    "rassomigliante": "rassomigliare",
    "rassomiglianti": "rassomigliare",
    "rassomiglianze": "rassomiglianza",
    "rassomigliar": "rassomigliare",
    "rassomigliaron": "rassomigliare",
    "rassomigliarono": "rassomigliare",
    "rassomigliasse": "rassomigliare",
    "rassomigliasser": "rassomigliare",
    "rassomigliassero": "rassomigliare",
    "rassomigliassi": "rassomigliare",
    "rassomigliassimo": "rassomigliare",
    "rassomigliaste": "rassomigliare",
    "rassomigliasti": "rassomigliare",
    "rassomigliata": "rassomigliare",
    "rassomigliate": "rassomigliare",
    "rassomigliati": "rassomigliare",
    "rassomigliato": "rassomigliare",
    "rassomigliava": "rassomigliare",
    "rassomigliavamo": "rassomigliare",
    "rassomigliavan": "rassomigliare",
    "rassomigliavano": "rassomigliare",
    "rassomigliavate": "rassomigliare",
    "rassomigliavi": "rassomigliare",
    "rassomigliavo": "rassomigliare",
    "rassomiglierai": "rassomigliare",
    "rassomiglieran": "rassomigliare",
    "rassomiglieranno": "rassomigliare",
    "rassomiglierebbe": "rassomigliare",
    "rassomiglierebber": "rassomigliare",
    "rassomiglierebbero": "rassomigliare",
    "rassomiglierei": "rassomigliare",
    "rassomiglieremmo": "rassomigliare",
    "rassomiglieremo": "rassomigliare",
    "rassomigliereste": "rassomigliare",
    "rassomiglieresti": "rassomigliare",
    "rassomiglierete": "rassomigliare",
    "rassomiglierà": "rassomigliare",
    "rassomiglierò": "rassomigliare",
    "rassomiglin": "rassomigliare",
    "rassomiglino": "rassomigliare",
    "rassomiglio": "rassomigliare",
    "rassomigliò": "rassomigliare",
    "rastrella": "rastrellare",
    "rastrellai": "rastrellare",
    "rastrellamenti": "rastrellamento",
    "rastrellammo": "rastrellare",
    "rastrellan": "rastrellare",
    "rastrellando": "rastrellare",
    "rastrellano": "rastrellare",
    "rastrellante": "rastrellare",
    "rastrellanti": "rastrellare",
    "rastrellar": "rastrellare",
    "rastrellaron": "rastrellare",
    "rastrellarono": "rastrellare",
    "rastrellasse": "rastrellare",
    "rastrellasser": "rastrellare",
    "rastrellassero": "rastrellare",
    "rastrellassi": "rastrellare",
    "rastrellassimo": "rastrellare",
    "rastrellaste": "rastrellare",
    "rastrellasti": "rastrellare",
    "rastrellata": "rastrellare",
    "rastrellate": "rastrellare",
    "rastrellati": "rastrellare",
    "rastrellato": "rastrellare",
    "rastrellatori": "rastrellatore",
    "rastrellava": "rastrellare",
    "rastrellavamo": "rastrellare",
    "rastrellavan": "rastrellare",
    "rastrellavano": "rastrellare",
    "rastrellavate": "rastrellare",
    "rastrellavi": "rastrellare",
    "rastrellavo": "rastrellare",
    "rastrellerai": "rastrellare",
    "rastrelleran": "rastrellare",
    "rastrelleranno": "rastrellare",
    "rastrellerebbe": "rastrellare",
    "rastrellerebber": "rastrellare",
    "rastrellerebbero": "rastrellare",
    "rastrellerei": "rastrellare",
    "rastrelleremmo": "rastrellare",
    "rastrelleremo": "rastrellare",
    "rastrellereste": "rastrellare",
    "rastrelleresti": "rastrellare",
    "rastrellerete": "rastrellare",
    "rastrellerà": "rastrellare",
    "rastrellerò": "rastrellare",
    "rastrelli": "rastrellare",
    "rastrelliamo": "rastrellare",
    "rastrelliate": "rastrellare",
    "rastrellin": "rastrellare",
    "rastrellino": "rastrellare",
    "rastrello": "rastrellare",
    "rastrellò": "rastrellare",
    "rastrema": "rastremare",
    "rastremai": "rastremare",
    "rastremammo": "rastremare",
    "rastreman": "rastremare",
    "rastremando": "rastremare",
    "rastremano": "rastremare",
    "rastremante": "rastremare",
    "rastremanti": "rastremare",
    "rastremar": "rastremare",
    "rastremaron": "rastremare",
    "rastremarono": "rastremare",
    "rastremasse": "rastremare",
    "rastremasser": "rastremare",
    "rastremassero": "rastremare",
    "rastremassi": "rastremare",
    "rastremassimo": "rastremare",
    "rastremaste": "rastremare",
    "rastremasti": "rastremare",
    "rastremata": "rastremare",
    "rastremate": "rastremare",
    "rastremati": "rastremare",
    "rastremato": "rastremare",
    "rastremava": "rastremare",
    "rastremavamo": "rastremare",
    "rastremavan": "rastremare",
    "rastremavano": "rastremare",
    "rastremavate": "rastremare",
    "rastremavi": "rastremare",
    "rastremavo": "rastremare",
    "rastremerai": "rastremare",
    "rastremeran": "rastremare",
    "rastremeranno": "rastremare",
    "rastremerebbe": "rastremare",
    "rastremerebber": "rastremare",
    "rastremerebbero": "rastremare",
    "rastremerei": "rastremare",
    "rastremeremmo": "rastremare",
    "rastremeremo": "rastremare",
    "rastremereste": "rastremare",
    "rastremeresti": "rastremare",
    "rastremerete": "rastremare",
    "rastremerà": "rastremare",
    "rastremerò": "rastremare",
    "rastremi": "rastremare",
    "rastremiamo": "rastremare",
    "rastremiate": "rastremare",
    "rastremin": "rastremare",
    "rastremino": "rastremare",
    "rastremo": "rastremare",
    "rastremò": "rastremare",
    "rasò": "rasare",
    "rata": "rato",
    "rate": "rato",
    "ratea": "rateare",
    "rateai": "rateare",
    "rateali": "rateale",
    "rateammo": "rateare",
    "ratean": "rateare",
    "rateando": "rateare",
    "rateano": "rateare",
    "rateante": "rateare",
    "rateanti": "rateare",
    "ratear": "rateare",
    "ratearon": "rateare",
    "ratearono": "rateare",
    "rateasse": "rateare",
    "rateasser": "rateare",
    "rateassero": "rateare",
    "rateassi": "rateare",
    "rateassimo": "rateare",
    "rateaste": "rateare",
    "rateasti": "rateare",
    "rateata": "rateare",
    "rateate": "rateare",
    "rateati": "rateare",
    "rateato": "rateare",
    "rateava": "rateare",
    "rateavamo": "rateare",
    "rateavan": "rateare",
    "rateavano": "rateare",
    "rateavate": "rateare",
    "rateavi": "rateare",
    "rateavo": "rateare",
    "rateazioni": "rateazione",
    "rateerai": "rateare",
    "rateeran": "rateare",
    "rateeranno": "rateare",
    "rateerebbe": "rateare",
    "rateerebber": "rateare",
    "rateerebbero": "rateare",
    "rateerei": "rateare",
    "rateeremmo": "rateare",
    "rateeremo": "rateare",
    "rateereste": "rateare",
    "rateeresti": "rateare",
    "rateerete": "rateare",
    "rateerà": "rateare",
    "rateerò": "rateare",
    "ratei": "rateo",
    "rateiamo": "rateare",
    "rateiate": "rateare",
    "ratein": "rateare",
    "rateino": "rateare",
    "rateizza": "rateizzare",
    "rateizzai": "rateizzare",
    "rateizzammo": "rateizzare",
    "rateizzan": "rateizzare",
    "rateizzando": "rateizzare",
    "rateizzano": "rateizzare",
    "rateizzante": "rateizzare",
    "rateizzanti": "rateizzare",
    "rateizzar": "rateizzare",
    "rateizzaron": "rateizzare",
    "rateizzarono": "rateizzare",
    "rateizzasse": "rateizzare",
    "rateizzasser": "rateizzare",
    "rateizzassero": "rateizzare",
    "rateizzassi": "rateizzare",
    "rateizzassimo": "rateizzare",
    "rateizzaste": "rateizzare",
    "rateizzasti": "rateizzare",
    "rateizzata": "rateizzare",
    "rateizzate": "rateizzare",
    "rateizzati": "rateizzare",
    "rateizzato": "rateizzare",
    "rateizzava": "rateizzare",
    "rateizzavamo": "rateizzare",
    "rateizzavan": "rateizzare",
    "rateizzavano": "rateizzare",
    "rateizzavate": "rateizzare",
    "rateizzavi": "rateizzare",
    "rateizzavo": "rateizzare",
    "rateizzazioni": "rateizzazione",
    "rateizzerai": "rateizzare",
    "rateizzeran": "rateizzare",
    "rateizzeranno": "rateizzare",
    "rateizzerebbe": "rateizzare",
    "rateizzerebber": "rateizzare",
    "rateizzerebbero": "rateizzare",
    "rateizzerei": "rateizzare",
    "rateizzeremmo": "rateizzare",
    "rateizzeremo": "rateizzare",
    "rateizzereste": "rateizzare",
    "rateizzeresti": "rateizzare",
    "rateizzerete": "rateizzare",
    "rateizzerà": "rateizzare",
    "rateizzerò": "rateizzare",
    "rateizzi": "rateizzare",
    "rateizziamo": "rateizzare",
    "rateizziate": "rateizzare",
    "rateizzin": "rateizzare",
    "rateizzino": "rateizzare",
    "rateizzo": "rateizzare",
    "rateizzò": "rateizzare",
    "rateo": "rateare",
    "rateò": "rateare",
    "rati": "rato",
    "ratifica": "ratificare",
    "ratificai": "ratificare",
    "ratificammo": "ratificare",
    "ratifican": "ratificare",
    "ratificando": "ratificare",
    "ratificano": "ratificare",
    "ratificante": "ratificare",
    "ratificanti": "ratificare",
    "ratificar": "ratificare",
    "ratificaron": "ratificare",
    "ratificarono": "ratificare",
    "ratificasse": "ratificare",
    "ratificasser": "ratificare",
    "ratificassero": "ratificare",
    "ratificassi": "ratificare",
    "ratificassimo": "ratificare",
    "ratificaste": "ratificare",
    "ratificasti": "ratificare",
    "ratificata": "ratificare",
    "ratificate": "ratificare",
    "ratificati": "ratificare",
    "ratificato": "ratificare",
    "ratificava": "ratificare",
    "ratificavamo": "ratificare",
    "ratificavan": "ratificare",
    "ratificavano": "ratificare",
    "ratificavate": "ratificare",
    "ratificavi": "ratificare",
    "ratificavo": "ratificare",
    "ratifiche": "ratifica",
    "ratificherai": "ratificare",
    "ratificheran": "ratificare",
    "ratificheranno": "ratificare",
    "ratificherebbe": "ratificare",
    "ratificherebber": "ratificare",
    "ratificherebbero": "ratificare",
    "ratificherei": "ratificare",
    "ratificheremmo": "ratificare",
    "ratificheremo": "ratificare",
    "ratifichereste": "ratificare",
    "ratificheresti": "ratificare",
    "ratificherete": "ratificare",
    "ratificherà": "ratificare",
    "ratificherò": "ratificare",
    "ratifichi": "ratificare",
    "ratifichiamo": "ratificare",
    "ratifichiate": "ratificare",
    "ratifichin": "ratificare",
    "ratifichino": "ratificare",
    "ratifico": "ratificare",
    "ratificò": "ratificare",
    "rationes": "ratio",
    "ratios": "ratio",
    "ratta": "ratto",
    "ratte": "ratto",
    "rattene": "rattenere",
    "rattenei": "rattenere",
    "rattenemmo": "rattenere",
    "rattenendo": "rattenere",
    "rattenente": "rattenere",
    "rattenenti": "rattenere",
    "rattener": "rattenere",
    "rattenerai": "rattenere",
    "ratteneran": "rattenere",
    "ratteneranno": "rattenere",
    "rattenerebbe": "rattenere",
    "rattenerebber": "rattenere",
    "rattenerebbero": "rattenere",
    "rattenerei": "rattenere",
    "ratteneremmo": "rattenere",
    "ratteneremo": "rattenere",
    "rattenereste": "rattenere",
    "ratteneresti": "rattenere",
    "rattenerete": "rattenere",
    "ratteneron": "rattenere",
    "rattenerono": "rattenere",
    "rattenerà": "rattenere",
    "rattenerò": "rattenere",
    "rattenesse": "rattenere",
    "rattenesser": "rattenere",
    "rattenessero": "rattenere",
    "rattenessi": "rattenere",
    "rattenessimo": "rattenere",
    "ratteneste": "rattenere",
    "rattenesti": "rattenere",
    "rattenete": "rattenere",
    "ratteneva": "rattenere",
    "rattenevamo": "rattenere",
    "rattenevan": "rattenere",
    "rattenevano": "rattenere",
    "rattenevate": "rattenere",
    "rattenevi": "rattenere",
    "rattenevo": "rattenere",
    "rattenga": "rattenere",
    "rattengan": "rattenere",
    "rattengano": "rattenere",
    "rattengo": "rattenere",
    "rattengon": "rattenere",
    "rattengono": "rattenere",
    "ratteni": "rattenere",
    "ratteniamo": "rattenere",
    "ratteniate": "rattenere",
    "rattenuta": "rattenere",
    "rattenute": "rattenere",
    "rattenuti": "rattenere",
    "rattenuto": "rattenere",
    "rattenè": "rattenere",
    "ratti": "ratto",
    "rattizza": "rattizzare",
    "rattizzai": "rattizzare",
    "rattizzammo": "rattizzare",
    "rattizzan": "rattizzare",
    "rattizzando": "rattizzare",
    "rattizzano": "rattizzare",
    "rattizzante": "rattizzare",
    "rattizzanti": "rattizzare",
    "rattizzar": "rattizzare",
    "rattizzaron": "rattizzare",
    "rattizzarono": "rattizzare",
    "rattizzasse": "rattizzare",
    "rattizzasser": "rattizzare",
    "rattizzassero": "rattizzare",
    "rattizzassi": "rattizzare",
    "rattizzassimo": "rattizzare",
    "rattizzaste": "rattizzare",
    "rattizzasti": "rattizzare",
    "rattizzata": "rattizzare",
    "rattizzate": "rattizzare",
    "rattizzati": "rattizzare",
    "rattizzato": "rattizzare",
    "rattizzava": "rattizzare",
    "rattizzavamo": "rattizzare",
    "rattizzavan": "rattizzare",
    "rattizzavano": "rattizzare",
    "rattizzavate": "rattizzare",
    "rattizzavi": "rattizzare",
    "rattizzavo": "rattizzare",
    "rattizzerai": "rattizzare",
    "rattizzeran": "rattizzare",
    "rattizzeranno": "rattizzare",
    "rattizzerebbe": "rattizzare",
    "rattizzerebber": "rattizzare",
    "rattizzerebbero": "rattizzare",
    "rattizzerei": "rattizzare",
    "rattizzeremmo": "rattizzare",
    "rattizzeremo": "rattizzare",
    "rattizzereste": "rattizzare",
    "rattizzeresti": "rattizzare",
    "rattizzerete": "rattizzare",
    "rattizzerà": "rattizzare",
    "rattizzerò": "rattizzare",
    "rattizzi": "rattizzare",
    "rattizziamo": "rattizzare",
    "rattizziate": "rattizzare",
    "rattizzin": "rattizzare",
    "rattizzino": "rattizzare",
    "rattizzo": "rattizzare",
    "rattizzò": "rattizzare",
    "rattoppa": "rattoppare",
    "rattoppai": "rattoppare",
    "rattoppammo": "rattoppare",
    "rattoppan": "rattoppare",
    "rattoppando": "rattoppare",
    "rattoppano": "rattoppare",
    "rattoppante": "rattoppare",
    "rattoppanti": "rattoppare",
    "rattoppar": "rattoppare",
    "rattopparon": "rattoppare",
    "rattopparono": "rattoppare",
    "rattoppasse": "rattoppare",
    "rattoppasser": "rattoppare",
    "rattoppassero": "rattoppare",
    "rattoppassi": "rattoppare",
    "rattoppassimo": "rattoppare",
    "rattoppaste": "rattoppare",
    "rattoppasti": "rattoppare",
    "rattoppata": "rattoppare",
    "rattoppate": "rattoppare",
    "rattoppati": "rattoppare",
    "rattoppato": "rattoppare",
    "rattoppava": "rattoppare",
    "rattoppavamo": "rattoppare",
    "rattoppavan": "rattoppare",
    "rattoppavano": "rattoppare",
    "rattoppavate": "rattoppare",
    "rattoppavi": "rattoppare",
    "rattoppavo": "rattoppare",
    "rattopperai": "rattoppare",
    "rattopperan": "rattoppare",
    "rattopperanno": "rattoppare",
    "rattopperebbe": "rattoppare",
    "rattopperebber": "rattoppare",
    "rattopperebbero": "rattoppare",
    "rattopperei": "rattoppare",
    "rattopperemmo": "rattoppare",
    "rattopperemo": "rattoppare",
    "rattoppereste": "rattoppare",
    "rattopperesti": "rattoppare",
    "rattopperete": "rattoppare",
    "rattopperà": "rattoppare",
    "rattopperò": "rattoppare",
    "rattoppi": "rattoppare",
    "rattoppiamo": "rattoppare",
    "rattoppiate": "rattoppare",
    "rattoppin": "rattoppare",
    "rattoppino": "rattoppare",
    "rattoppo": "rattoppare",
    "rattoppò": "rattoppare",
    "rattrappa": "rattrappire",
    "rattrappan": "rattrappire",
    "rattrappano": "rattrappire",
    "rattrappe": "rattrappire",
    "rattrappendo": "rattrappire",
    "rattrappente": "rattrappire",
    "rattrappenti": "rattrappire",
    "rattrappi": "rattrappire",
    "rattrappiamo": "rattrappire",
    "rattrappiate": "rattrappire",
    "rattrappii": "rattrappire",
    "rattrappimmo": "rattrappire",
    "rattrappir": "rattrappire",
    "rattrappirai": "rattrappire",
    "rattrappiran": "rattrappire",
    "rattrappiranno": "rattrappire",
    "rattrappirebbe": "rattrappire",
    "rattrappirebber": "rattrappire",
    "rattrappirebbero": "rattrappire",
    "rattrappirei": "rattrappire",
    "rattrappiremmo": "rattrappire",
    "rattrappiremo": "rattrappire",
    "rattrappireste": "rattrappire",
    "rattrappiresti": "rattrappire",
    "rattrappirete": "rattrappire",
    "rattrappiron": "rattrappire",
    "rattrappirono": "rattrappire",
    "rattrappirà": "rattrappire",
    "rattrappirò": "rattrappire",
    "rattrappisse": "rattrappire",
    "rattrappisser": "rattrappire",
    "rattrappissero": "rattrappire",
    "rattrappissi": "rattrappire",
    "rattrappissimo": "rattrappire",
    "rattrappiste": "rattrappire",
    "rattrappisti": "rattrappire",
    "rattrappita": "rattrappire",
    "rattrappite": "rattrappire",
    "rattrappiti": "rattrappire",
    "rattrappito": "rattrappire",
    "rattrappiva": "rattrappire",
    "rattrappivamo": "rattrappire",
    "rattrappivan": "rattrappire",
    "rattrappivano": "rattrappire",
    "rattrappivate": "rattrappire",
    "rattrappivi": "rattrappire",
    "rattrappivo": "rattrappire",
    "rattrappo": "rattrappire",
    "rattrappon": "rattrappire",
    "rattrappono": "rattrappire",
    "rattrappì": "rattrappire",
    "rattrista": "rattristare",
    "rattristai": "rattristare",
    "rattristammo": "rattristare",
    "rattristan": "rattristare",
    "rattristando": "rattristare",
    "rattristano": "rattristare",
    "rattristante": "rattristare",
    "rattristanti": "rattristare",
    "rattristar": "rattristare",
    "rattristaron": "rattristare",
    "rattristarono": "rattristare",
    "rattristasse": "rattristare",
    "rattristasser": "rattristare",
    "rattristassero": "rattristare",
    "rattristassi": "rattristare",
    "rattristassimo": "rattristare",
    "rattristaste": "rattristare",
    "rattristasti": "rattristare",
    "rattristata": "rattristare",
    "rattristate": "rattristare",
    "rattristati": "rattristare",
    "rattristato": "rattristare",
    "rattristava": "rattristare",
    "rattristavamo": "rattristare",
    "rattristavan": "rattristare",
    "rattristavano": "rattristare",
    "rattristavate": "rattristare",
    "rattristavi": "rattristare",
    "rattristavo": "rattristare",
    "rattristerai": "rattristare",
    "rattristeran": "rattristare",
    "rattristeranno": "rattristare",
    "rattristerebbe": "rattristare",
    "rattristerebber": "rattristare",
    "rattristerebbero": "rattristare",
    "rattristerei": "rattristare",
    "rattristeremmo": "rattristare",
    "rattristeremo": "rattristare",
    "rattristereste": "rattristare",
    "rattristeresti": "rattristare",
    "rattristerete": "rattristare",
    "rattristerà": "rattristare",
    "rattristerò": "rattristare",
    "rattristi": "rattristare",
    "rattristiamo": "rattristare",
    "rattristiate": "rattristare",
    "rattristin": "rattristare",
    "rattristino": "rattristare",
    "rattristo": "rattristare",
    "rattristò": "rattristare",
    "raucedini": "raucedine",
    "rautiana": "rautiano",
    "rautiane": "rautiano",
    "rautiani": "rautiano",
    "ravennati": "ravennate",
    "ravioli": "raviolo",
    "ravveda": "ravvedere",
    "ravvedan": "ravvedere",
    "ravvedano": "ravvedere",
    "ravvede": "ravvedere",
    "ravvedei": "ravvedere",
    "ravvedemmo": "ravvedere",
    "ravvedendo": "ravvedere",
    "ravveder": "ravvedere",
    "ravvederai": "ravvedere",
    "ravvederan": "ravvedere",
    "ravvederanno": "ravvedere",
    "ravvederebbe": "ravvedere",
    "ravvederebber": "ravvedere",
    "ravvederebbero": "ravvedere",
    "ravvederei": "ravvedere",
    "ravvederemmo": "ravvedere",
    "ravvederemo": "ravvedere",
    "ravvedereste": "ravvedere",
    "ravvederesti": "ravvedere",
    "ravvederete": "ravvedere",
    "ravvederon": "ravvedere",
    "ravvederono": "ravvedere",
    "ravvederà": "ravvedere",
    "ravvederò": "ravvedere",
    "ravvedesse": "ravvedere",
    "ravvedesser": "ravvedere",
    "ravvedessero": "ravvedere",
    "ravvedessi": "ravvedere",
    "ravvedessimo": "ravvedere",
    "ravvedeste": "ravvedere",
    "ravvedesti": "ravvedere",
    "ravvedete": "ravvedere",
    "ravvedeva": "ravvedere",
    "ravvedevamo": "ravvedere",
    "ravvedevan": "ravvedere",
    "ravvedevano": "ravvedere",
    "ravvedevate": "ravvedere",
    "ravvedevi": "ravvedere",
    "ravvedevo": "ravvedere",
    "ravvedi": "ravvedere",
    "ravvediamo": "ravvedere",
    "ravvediate": "ravvedere",
    "ravvedimenti": "ravvedimento",
    "ravvedo": "ravvedere",
    "ravvedon": "ravvedere",
    "ravvedono": "ravvedere",
    "ravveduta": "ravvedere",
    "ravvedute": "ravvedere",
    "ravveduti": "ravvedere",
    "ravveduto": "ravvedere",
    "ravvedè": "ravvedere",
    "ravvi": "ravviare",
    "ravvia": "ravviare",
    "ravviai": "ravviare",
    "ravviammo": "ravviare",
    "ravviamo": "ravviare",
    "ravvian": "ravviare",
    "ravviando": "ravviare",
    "ravviano": "ravviare",
    "ravviante": "ravviare",
    "ravvianti": "ravviare",
    "ravviar": "ravviare",
    "ravviaron": "ravviare",
    "ravviarono": "ravviare",
    "ravviasse": "ravviare",
    "ravviasser": "ravviare",
    "ravviassero": "ravviare",
    "ravviassi": "ravviare",
    "ravviassimo": "ravviare",
    "ravviaste": "ravviare",
    "ravviasti": "ravviare",
    "ravviata": "ravviare",
    "ravviate": "ravviare",
    "ravviati": "ravviare",
    "ravviato": "ravviare",
    "ravviava": "ravviare",
    "ravviavamo": "ravviare",
    "ravviavan": "ravviare",
    "ravviavano": "ravviare",
    "ravviavate": "ravviare",
    "ravviavi": "ravviare",
    "ravviavo": "ravviare",
    "ravvicina": "ravvicinare",
    "ravvicinai": "ravvicinare",
    "ravvicinamenti": "ravvicinamento",
    "ravvicinammo": "ravvicinare",
    "ravvicinan": "ravvicinare",
    "ravvicinando": "ravvicinare",
    "ravvicinano": "ravvicinare",
    "ravvicinante": "ravvicinare",
    "ravvicinanti": "ravvicinare",
    "ravvicinar": "ravvicinare",
    "ravvicinaron": "ravvicinare",
    "ravvicinarono": "ravvicinare",
    "ravvicinasse": "ravvicinare",
    "ravvicinasser": "ravvicinare",
    "ravvicinassero": "ravvicinare",
    "ravvicinassi": "ravvicinare",
    "ravvicinassimo": "ravvicinare",
    "ravvicinaste": "ravvicinare",
    "ravvicinasti": "ravvicinare",
    "ravvicinata": "ravvicinare",
    "ravvicinate": "ravvicinare",
    "ravvicinati": "ravvicinare",
    "ravvicinato": "ravvicinare",
    "ravvicinava": "ravvicinare",
    "ravvicinavamo": "ravvicinare",
    "ravvicinavan": "ravvicinare",
    "ravvicinavano": "ravvicinare",
    "ravvicinavate": "ravvicinare",
    "ravvicinavi": "ravvicinare",
    "ravvicinavo": "ravvicinare",
    "ravvicinerai": "ravvicinare",
    "ravvicineran": "ravvicinare",
    "ravvicineranno": "ravvicinare",
    "ravvicinerebbe": "ravvicinare",
    "ravvicinerebber": "ravvicinare",
    "ravvicinerebbero": "ravvicinare",
    "ravvicinerei": "ravvicinare",
    "ravvicineremmo": "ravvicinare",
    "ravvicineremo": "ravvicinare",
    "ravvicinereste": "ravvicinare",
    "ravvicineresti": "ravvicinare",
    "ravvicinerete": "ravvicinare",
    "ravvicinerà": "ravvicinare",
    "ravvicinerò": "ravvicinare",
    "ravvicini": "ravvicinare",
    "ravviciniamo": "ravvicinare",
    "ravviciniate": "ravvicinare",
    "ravvicinin": "ravvicinare",
    "ravvicinino": "ravvicinare",
    "ravvicino": "ravvicinare",
    "ravvicinò": "ravvicinare",
    "ravvierai": "ravviare",
    "ravvieran": "ravviare",
    "ravvieranno": "ravviare",
    "ravvierebbe": "ravviare",
    "ravvierebber": "ravviare",
    "ravvierebbero": "ravviare",
    "ravvierei": "ravviare",
    "ravvieremmo": "ravviare",
    "ravvieremo": "ravviare",
    "ravviereste": "ravviare",
    "ravvieresti": "ravviare",
    "ravvierete": "ravviare",
    "ravvierà": "ravviare",
    "ravvierò": "ravviare",
    "ravvin": "ravviare",
    "ravvino": "ravviare",
    "ravvio": "ravviare",
    "ravvisa": "ravvisare",
    "ravvisabili": "ravvisabile",
    "ravvisai": "ravvisare",
    "ravvisammo": "ravvisare",
    "ravvisan": "ravvisare",
    "ravvisando": "ravvisare",
    "ravvisano": "ravvisare",
    "ravvisante": "ravvisare",
    "ravvisanti": "ravvisare",
    "ravvisar": "ravvisare",
    "ravvisaron": "ravvisare",
    "ravvisarono": "ravvisare",
    "ravvisasse": "ravvisare",
    "ravvisasser": "ravvisare",
    "ravvisassero": "ravvisare",
    "ravvisassi": "ravvisare",
    "ravvisassimo": "ravvisare",
    "ravvisaste": "ravvisare",
    "ravvisasti": "ravvisare",
    "ravvisata": "ravvisare",
    "ravvisate": "ravvisare",
    "ravvisati": "ravvisare",
    "ravvisato": "ravvisare",
    "ravvisava": "ravvisare",
    "ravvisavamo": "ravvisare",
    "ravvisavan": "ravvisare",
    "ravvisavano": "ravvisare",
    "ravvisavate": "ravvisare",
    "ravvisavi": "ravvisare",
    "ravvisavo": "ravvisare",
    "ravviserai": "ravvisare",
    "ravviseran": "ravvisare",
    "ravviseranno": "ravvisare",
    "ravviserebbe": "ravvisare",
    "ravviserebber": "ravvisare",
    "ravviserebbero": "ravvisare",
    "ravviserei": "ravvisare",
    "ravviseremmo": "ravvisare",
    "ravviseremo": "ravvisare",
    "ravvisereste": "ravvisare",
    "ravviseresti": "ravvisare",
    "ravviserete": "ravvisare",
    "ravviserà": "ravvisare",
    "ravviserò": "ravvisare",
    "ravvisi": "ravvisare",
    "ravvisiamo": "ravvisare",
    "ravvisiate": "ravvisare",
    "ravvisin": "ravvisare",
    "ravvisino": "ravvisare",
    "ravviso": "ravvisare",
    "ravvisò": "ravvisare",
    "ravviò": "ravviare",
    "ravvolga": "ravvolgere",
    "ravvolgan": "ravvolgere",
    "ravvolgano": "ravvolgere",
    "ravvolge": "ravvolgere",
    "ravvolgei": "ravvolgere",
    "ravvolgemmo": "ravvolgere",
    "ravvolgendo": "ravvolgere",
    "ravvolgente": "ravvolgere",
    "ravvolgenti": "ravvolgere",
    "ravvolger": "ravvolgere",
    "ravvolgerai": "ravvolgere",
    "ravvolgeran": "ravvolgere",
    "ravvolgeranno": "ravvolgere",
    "ravvolgerebbe": "ravvolgere",
    "ravvolgerebber": "ravvolgere",
    "ravvolgerebbero": "ravvolgere",
    "ravvolgerei": "ravvolgere",
    "ravvolgeremmo": "ravvolgere",
    "ravvolgeremo": "ravvolgere",
    "ravvolgereste": "ravvolgere",
    "ravvolgeresti": "ravvolgere",
    "ravvolgerete": "ravvolgere",
    "ravvolgeron": "ravvolgere",
    "ravvolgerono": "ravvolgere",
    "ravvolgerà": "ravvolgere",
    "ravvolgerò": "ravvolgere",
    "ravvolgesse": "ravvolgere",
    "ravvolgesser": "ravvolgere",
    "ravvolgessero": "ravvolgere",
    "ravvolgessi": "ravvolgere",
    "ravvolgessimo": "ravvolgere",
    "ravvolgeste": "ravvolgere",
    "ravvolgesti": "ravvolgere",
    "ravvolgete": "ravvolgere",
    "ravvolgeva": "ravvolgere",
    "ravvolgevamo": "ravvolgere",
    "ravvolgevan": "ravvolgere",
    "ravvolgevano": "ravvolgere",
    "ravvolgevate": "ravvolgere",
    "ravvolgevi": "ravvolgere",
    "ravvolgevo": "ravvolgere",
    "ravvolgi": "ravvolgere",
    "ravvolgiamo": "ravvolgere",
    "ravvolgiate": "ravvolgere",
    "ravvolgo": "ravvolgere",
    "ravvolgon": "ravvolgere",
    "ravvolgono": "ravvolgere",
    "ravvolgè": "ravvolgere",
    "ravvolta": "ravvolgere",
    "ravvolte": "ravvolgere",
    "ravvolti": "ravvolgere",
    "ravvolto": "ravvolgere",
    "ravvoltola": "ravvoltolare",
    "ravvoltolai": "ravvoltolare",
    "ravvoltolammo": "ravvoltolare",
    "ravvoltolan": "ravvoltolare",
    "ravvoltolando": "ravvoltolare",
    "ravvoltolano": "ravvoltolare",
    "ravvoltolante": "ravvoltolare",
    "ravvoltolanti": "ravvoltolare",
    "ravvoltolar": "ravvoltolare",
    "ravvoltolaron": "ravvoltolare",
    "ravvoltolarono": "ravvoltolare",
    "ravvoltolasse": "ravvoltolare",
    "ravvoltolasser": "ravvoltolare",
    "ravvoltolassero": "ravvoltolare",
    "ravvoltolassi": "ravvoltolare",
    "ravvoltolassimo": "ravvoltolare",
    "ravvoltolaste": "ravvoltolare",
    "ravvoltolasti": "ravvoltolare",
    "ravvoltolata": "ravvoltolare",
    "ravvoltolate": "ravvoltolare",
    "ravvoltolati": "ravvoltolare",
    "ravvoltolato": "ravvoltolare",
    "ravvoltolava": "ravvoltolare",
    "ravvoltolavamo": "ravvoltolare",
    "ravvoltolavan": "ravvoltolare",
    "ravvoltolavano": "ravvoltolare",
    "ravvoltolavate": "ravvoltolare",
    "ravvoltolavi": "ravvoltolare",
    "ravvoltolavo": "ravvoltolare",
    "ravvoltolerai": "ravvoltolare",
    "ravvoltoleran": "ravvoltolare",
    "ravvoltoleranno": "ravvoltolare",
    "ravvoltolerebbe": "ravvoltolare",
    "ravvoltolerebber": "ravvoltolare",
    "ravvoltolerebbero": "ravvoltolare",
    "ravvoltolerei": "ravvoltolare",
    "ravvoltoleremmo": "ravvoltolare",
    "ravvoltoleremo": "ravvoltolare",
    "ravvoltolereste": "ravvoltolare",
    "ravvoltoleresti": "ravvoltolare",
    "ravvoltolerete": "ravvoltolare",
    "ravvoltolerà": "ravvoltolare",
    "ravvoltolerò": "ravvoltolare",
    "ravvoltoli": "ravvoltolare",
    "ravvoltoliamo": "ravvoltolare",
    "ravvoltoliate": "ravvoltolare",
    "ravvoltolin": "ravvoltolare",
    "ravvoltolino": "ravvoltolare",
    "ravvoltolo": "ravvoltolare",
    "ravvoltolò": "ravvoltolare",
    "raziocina": "raziocinare",
    "raziocinai": "raziocinare",
    "raziocinammo": "raziocinare",
    "raziocinan": "raziocinare",
    "raziocinando": "raziocinare",
    "raziocinano": "raziocinare",
    "raziocinante": "raziocinare",
    "raziocinanti": "raziocinare",
    "raziocinar": "raziocinare",
    "raziocinaron": "raziocinare",
    "raziocinarono": "raziocinare",
    "raziocinasse": "raziocinare",
    "raziocinasser": "raziocinare",
    "raziocinassero": "raziocinare",
    "raziocinassi": "raziocinare",
    "raziocinassimo": "raziocinare",
    "raziocinaste": "raziocinare",
    "raziocinasti": "raziocinare",
    "raziocinata": "raziocinare",
    "raziocinate": "raziocinare",
    "raziocinati": "raziocinare",
    "raziocinato": "raziocinare",
    "raziocinava": "raziocinare",
    "raziocinavamo": "raziocinare",
    "raziocinavan": "raziocinare",
    "raziocinavano": "raziocinare",
    "raziocinavate": "raziocinare",
    "raziocinavi": "raziocinare",
    "raziocinavo": "raziocinare",
    "raziocinerai": "raziocinare",
    "raziocineran": "raziocinare",
    "raziocineranno": "raziocinare",
    "raziocinerebbe": "raziocinare",
    "raziocinerebber": "raziocinare",
    "raziocinerebbero": "raziocinare",
    "raziocinerei": "raziocinare",
    "raziocineremmo": "raziocinare",
    "raziocineremo": "raziocinare",
    "raziocinereste": "raziocinare",
    "raziocineresti": "raziocinare",
    "raziocinerete": "raziocinare",
    "raziocinerà": "raziocinare",
    "raziocinerò": "raziocinare",
    "raziocini": "raziocinio",
    "raziociniamo": "raziocinare",
    "raziociniate": "raziocinare",
    "raziocinin": "raziocinare",
    "raziocinino": "raziocinare",
    "raziocino": "raziocinare",
    "raziocinò": "raziocinare",
    "raziona": "razionare",
    "razionai": "razionare",
    "razionali": "razionale",
    "razionalismi": "razionalismo",
    "razionalisti": "razionalista",
    "razionalistica": "razionalistico",
    "razionalistiche": "razionalistico",
    "razionalistici": "razionalistico",
    "razionalizza": "razionalizzare",
    "razionalizzai": "razionalizzare",
    "razionalizzammo": "razionalizzare",
    "razionalizzan": "razionalizzare",
    "razionalizzando": "razionalizzare",
    "razionalizzano": "razionalizzare",
    "razionalizzante": "razionalizzare",
    "razionalizzanti": "razionalizzare",
    "razionalizzar": "razionalizzare",
    "razionalizzaron": "razionalizzare",
    "razionalizzarono": "razionalizzare",
    "razionalizzasse": "razionalizzare",
    "razionalizzasser": "razionalizzare",
    "razionalizzassero": "razionalizzare",
    "razionalizzassi": "razionalizzare",
    "razionalizzassimo": "razionalizzare",
    "razionalizzaste": "razionalizzare",
    "razionalizzasti": "razionalizzare",
    "razionalizzata": "razionalizzare",
    "razionalizzate": "razionalizzare",
    "razionalizzati": "razionalizzare",
    "razionalizzato": "razionalizzare",
    "razionalizzava": "razionalizzare",
    "razionalizzavamo": "razionalizzare",
    "razionalizzavan": "razionalizzare",
    "razionalizzavano": "razionalizzare",
    "razionalizzavate": "razionalizzare",
    "razionalizzavi": "razionalizzare",
    "razionalizzavo": "razionalizzare",
    "razionalizzazioni": "razionalizzazione",
    "razionalizzerai": "razionalizzare",
    "razionalizzeran": "razionalizzare",
    "razionalizzeranno": "razionalizzare",
    "razionalizzerebbe": "razionalizzare",
    "razionalizzerebber": "razionalizzare",
    "razionalizzerebbero": "razionalizzare",
    "razionalizzerei": "razionalizzare",
    "razionalizzeremmo": "razionalizzare",
    "razionalizzeremo": "razionalizzare",
    "razionalizzereste": "razionalizzare",
    "razionalizzeresti": "razionalizzare",
    "razionalizzerete": "razionalizzare",
    "razionalizzerà": "razionalizzare",
    "razionalizzerò": "razionalizzare",
    "razionalizzi": "razionalizzare",
    "razionalizziamo": "razionalizzare",
    "razionalizziate": "razionalizzare",
    "razionalizzin": "razionalizzare",
    "razionalizzino": "razionalizzare",
    "razionalizzo": "razionalizzare",
    "razionalizzò": "razionalizzare",
    "razionamenti": "razionamento",
    "razionammo": "razionare",
    "razionan": "razionare",
    "razionando": "razionare",
    "razionano": "razionare",
    "razionante": "razionare",
    "razionanti": "razionare",
    "razionar": "razionare",
    "razionaron": "razionare",
    "razionarono": "razionare",
    "razionasse": "razionare",
    "razionasser": "razionare",
    "razionassero": "razionare",
    "razionassi": "razionare",
    "razionassimo": "razionare",
    "razionaste": "razionare",
    "razionasti": "razionare",
    "razionata": "razionare",
    "razionate": "razionare",
    "razionati": "razionare",
    "razionato": "razionare",
    "razionava": "razionare",
    "razionavamo": "razionare",
    "razionavan": "razionare",
    "razionavano": "razionare",
    "razionavate": "razionare",
    "razionavi": "razionare",
    "razionavo": "razionare",
    "razionerai": "razionare",
    "razioneran": "razionare",
    "razioneranno": "razionare",
    "razionerebbe": "razionare",
    "razionerebber": "razionare",
    "razionerebbero": "razionare",
    "razionerei": "razionare",
    "razioneremmo": "razionare",
    "razioneremo": "razionare",
    "razionereste": "razionare",
    "razioneresti": "razionare",
    "razionerete": "razionare",
    "razionerà": "razionare",
    "razionerò": "razionare",
    "razioni": "razione",
    "razioniamo": "razionare",
    "razioniate": "razionare",
    "razionin": "razionare",
    "razionino": "razionare",
    "raziono": "razionare",
    "razionò": "razionare",
    "razze": "razza",
    "razzetti": "razzetto",
    "razzi": "razzo",
    "razzia": "razziare",
    "razziai": "razziare",
    "razziali": "razziale",
    "razziammo": "razziare",
    "razziamo": "razziare",
    "razzian": "razziare",
    "razziando": "razziare",
    "razziano": "razziare",
    "razziante": "razziare",
    "razzianti": "razziare",
    "razziar": "razziare",
    "razziaron": "razziare",
    "razziarono": "razziare",
    "razziasse": "razziare",
    "razziasser": "razziare",
    "razziassero": "razziare",
    "razziassi": "razziare",
    "razziassimo": "razziare",
    "razziaste": "razziare",
    "razziasti": "razziare",
    "razziata": "razziare",
    "razziate": "razziare",
    "razziati": "razziare",
    "razziato": "razziare",
    "razziava": "razziare",
    "razziavamo": "razziare",
    "razziavan": "razziare",
    "razziavano": "razziare",
    "razziavate": "razziare",
    "razziavi": "razziare",
    "razziavo": "razziare",
    "razzie": "razzia",
    "razzierai": "razziare",
    "razzieran": "razziare",
    "razzieranno": "razziare",
    "razzierebbe": "razziare",
    "razzierebber": "razziare",
    "razzierebbero": "razziare",
    "razzierei": "razziare",
    "razzieremmo": "razziare",
    "razzieremo": "razziare",
    "razziereste": "razziare",
    "razzieresti": "razziare",
    "razzierete": "razziare",
    "razzierà": "razziare",
    "razzierò": "razziare",
    "razzin": "razziare",
    "razzino": "razziare",
    "razzio": "razziare",
    "razzismi": "razzismo",
    "razziste": "razzista",
    "razzisti": "razzista",
    "razzistica": "razzistico",
    "razzistiche": "razzistico",
    "razzistici": "razzistico",
    "razziò": "razziare",
    "razzola": "razzolare",
    "razzolai": "razzolare",
    "razzolammo": "razzolare",
    "razzolan": "razzolare",
    "razzolando": "razzolare",
    "razzolano": "razzolare",
    "razzolante": "razzolare",
    "razzolanti": "razzolare",
    "razzolar": "razzolare",
    "razzolaron": "razzolare",
    "razzolarono": "razzolare",
    "razzolasse": "razzolare",
    "razzolasser": "razzolare",
    "razzolassero": "razzolare",
    "razzolassi": "razzolare",
    "razzolassimo": "razzolare",
    "razzolaste": "razzolare",
    "razzolasti": "razzolare",
    "razzolata": "razzolare",
    "razzolate": "razzolare",
    "razzolati": "razzolare",
    "razzolato": "razzolare",
    "razzolava": "razzolare",
    "razzolavamo": "razzolare",
    "razzolavan": "razzolare",
    "razzolavano": "razzolare",
    "razzolavate": "razzolare",
    "razzolavi": "razzolare",
    "razzolavo": "razzolare",
    "razzolerai": "razzolare",
    "razzoleran": "razzolare",
    "razzoleranno": "razzolare",
    "razzolerebbe": "razzolare",
    "razzolerebber": "razzolare",
    "razzolerebbero": "razzolare",
    "razzolerei": "razzolare",
    "razzoleremmo": "razzolare",
    "razzoleremo": "razzolare",
    "razzolereste": "razzolare",
    "razzoleresti": "razzolare",
    "razzolerete": "razzolare",
    "razzolerà": "razzolare",
    "razzolerò": "razzolare",
    "razzoli": "razzolare",
    "razzoliamo": "razzolare",
    "razzoliate": "razzolare",
    "razzolin": "razzolare",
    "razzolino": "razzolare",
    "razzolo": "razzolare",
    "razzolò": "razzolare",
    "re-inietta": "re-iniettare",
    "re-iniettai": "re-iniettare",
    "re-iniettammo": "re-iniettare",
    "re-iniettan": "re-iniettare",
    "re-iniettando": "re-iniettare",
    "re-iniettano": "re-iniettare",
    "re-iniettante": "re-iniettare",
    "re-iniettanti": "re-iniettare",
    "re-iniettar": "re-iniettare",
    "re-iniettaron": "re-iniettare",
    "re-iniettarono": "re-iniettare",
    "re-iniettasse": "re-iniettare",
    "re-iniettasser": "re-iniettare",
    "re-iniettassero": "re-iniettare",
    "re-iniettassi": "re-iniettare",
    "re-iniettassimo": "re-iniettare",
    "re-iniettaste": "re-iniettare",
    "re-iniettasti": "re-iniettare",
    "re-iniettata": "re-iniettare",
    "re-iniettate": "re-iniettare",
    "re-iniettati": "re-iniettare",
    "re-iniettato": "re-iniettare",
    "re-iniettava": "re-iniettare",
    "re-iniettavamo": "re-iniettare",
    "re-iniettavan": "re-iniettare",
    "re-iniettavano": "re-iniettare",
    "re-iniettavate": "re-iniettare",
    "re-iniettavi": "re-iniettare",
    "re-iniettavo": "re-iniettare",
    "re-inietterai": "re-iniettare",
    "re-inietteran": "re-iniettare",
    "re-inietteranno": "re-iniettare",
    "re-inietterebbe": "re-iniettare",
    "re-inietterebber": "re-iniettare",
    "re-inietterebbero": "re-iniettare",
    "re-inietterei": "re-iniettare",
    "re-inietteremmo": "re-iniettare",
    "re-inietteremo": "re-iniettare",
    "re-iniettereste": "re-iniettare",
    "re-inietteresti": "re-iniettare",
    "re-inietterete": "re-iniettare",
    "re-inietterà": "re-iniettare",
    "re-inietterò": "re-iniettare",
    "re-inietti": "re-iniettare",
    "re-iniettiamo": "re-iniettare",
    "re-iniettiate": "re-iniettare",
    "re-iniettin": "re-iniettare",
    "re-iniettino": "re-iniettare",
    "re-inietto": "re-iniettare",
    "re-iniettò": "re-iniettare",
    "rea": "reo",
    "reaganiana": "reaganiano",
    "reaganiane": "reaganiano",
    "reaganiani": "reaganiano",
    "reaganismi": "reaganismo",
    "reagendo": "reagire",
    "reagente": "reagire",
    "reagenti": "reagire",
    "reagiamo": "reagire",
    "reagiate": "reagire",
    "reagii": "reagire",
    "reagimmo": "reagire",
    "reagir": "reagire",
    "reagirai": "reagire",
    "reagiran": "reagire",
    "reagiranno": "reagire",
    "reagirebbe": "reagire",
    "reagirebber": "reagire",
    "reagirebbero": "reagire",
    "reagirei": "reagire",
    "reagiremmo": "reagire",
    "reagiremo": "reagire",
    "reagireste": "reagire",
    "reagiresti": "reagire",
    "reagirete": "reagire",
    "reagiron": "reagire",
    "reagirono": "reagire",
    "reagirà": "reagire",
    "reagirò": "reagire",
    "reagisca": "reagire",
    "reagiscan": "reagire",
    "reagiscano": "reagire",
    "reagisce": "reagire",
    "reagisci": "reagire",
    "reagisco": "reagire",
    "reagiscon": "reagire",
    "reagiscono": "reagire",
    "reagisse": "reagire",
    "reagisser": "reagire",
    "reagissero": "reagire",
    "reagissi": "reagire",
    "reagissimo": "reagire",
    "reagiste": "reagire",
    "reagisti": "reagire",
    "reagita": "reagire",
    "reagite": "reagire",
    "reagiti": "reagire",
    "reagito": "reagire",
    "reagiva": "reagire",
    "reagivamo": "reagire",
    "reagivan": "reagire",
    "reagivano": "reagire",
    "reagivate": "reagire",
    "reagivi": "reagire",
    "reagivo": "reagire",
    "reagì": "reagire",
    "reali": "reale",
    "realismi": "realismo",
    "realiste": "realista",
    "realisti": "realista",
    "realistica": "realistico",
    "realistiche": "realistico",
    "realistici": "realistico",
    "realizza": "realizzare",
    "realizzabili": "realizzabile",
    "realizzai": "realizzare",
    "realizzammo": "realizzare",
    "realizzan": "realizzare",
    "realizzando": "realizzare",
    "realizzano": "realizzare",
    "realizzante": "realizzare",
    "realizzanti": "realizzare",
    "realizzar": "realizzare",
    "realizzaron": "realizzare",
    "realizzarono": "realizzare",
    "realizzasse": "realizzare",
    "realizzasser": "realizzare",
    "realizzassero": "realizzare",
    "realizzassi": "realizzare",
    "realizzassimo": "realizzare",
    "realizzaste": "realizzare",
    "realizzasti": "realizzare",
    "realizzata": "realizzare",
    "realizzate": "realizzare",
    "realizzati": "realizzare",
    "realizzato": "realizzare",
    "realizzatori": "realizzatore",
    "realizzava": "realizzare",
    "realizzavamo": "realizzare",
    "realizzavan": "realizzare",
    "realizzavano": "realizzare",
    "realizzavate": "realizzare",
    "realizzavi": "realizzare",
    "realizzavo": "realizzare",
    "realizzazioni": "realizzazione",
    "realizzerai": "realizzare",
    "realizzeran": "realizzare",
    "realizzeranno": "realizzare",
    "realizzerebbe": "realizzare",
    "realizzerebber": "realizzare",
    "realizzerebbero": "realizzare",
    "realizzerei": "realizzare",
    "realizzeremmo": "realizzare",
    "realizzeremo": "realizzare",
    "realizzereste": "realizzare",
    "realizzeresti": "realizzare",
    "realizzerete": "realizzare",
    "realizzerà": "realizzare",
    "realizzerò": "realizzare",
    "realizzi": "realizzo",
    "realizziamo": "realizzare",
    "realizziate": "realizzare",
    "realizzin": "realizzare",
    "realizzino": "realizzare",
    "realizzo": "realizzare",
    "realizzò": "realizzare",
    "reami": "reame",
    "reati": "reato",
    "reattiva": "reattivo",
    "reattive": "reattivo",
    "reattivi": "reattivo",
    "reattori": "reattore",
    "reazionari": "reazionario",
    "reazionaria": "reazionario",
    "reazionarie": "reazionario",
    "reazioni": "reazione",
    "reboanti": "reboante",
    "reca": "recere",
    "recai": "recare",
    "recalcitra": "recalcitrare",
    "recalcitrai": "recalcitrare",
    "recalcitrammo": "recalcitrare",
    "recalcitran": "recalcitrare",
    "recalcitrando": "recalcitrare",
    "recalcitrano": "recalcitrare",
    "recalcitrante": "recalcitrare",
    "recalcitranti": "recalcitrare",
    "recalcitrar": "recalcitrare",
    "recalcitraron": "recalcitrare",
    "recalcitrarono": "recalcitrare",
    "recalcitrasse": "recalcitrare",
    "recalcitrasser": "recalcitrare",
    "recalcitrassero": "recalcitrare",
    "recalcitrassi": "recalcitrare",
    "recalcitrassimo": "recalcitrare",
    "recalcitraste": "recalcitrare",
    "recalcitrasti": "recalcitrare",
    "recalcitrata": "recalcitrare",
    "recalcitrate": "recalcitrare",
    "recalcitrati": "recalcitrare",
    "recalcitrato": "recalcitrare",
    "recalcitrava": "recalcitrare",
    "recalcitravamo": "recalcitrare",
    "recalcitravan": "recalcitrare",
    "recalcitravano": "recalcitrare",
    "recalcitravate": "recalcitrare",
    "recalcitravi": "recalcitrare",
    "recalcitravo": "recalcitrare",
    "recalcitrerai": "recalcitrare",
    "recalcitreran": "recalcitrare",
    "recalcitreranno": "recalcitrare",
    "recalcitrerebbe": "recalcitrare",
    "recalcitrerebber": "recalcitrare",
    "recalcitrerebbero": "recalcitrare",
    "recalcitrerei": "recalcitrare",
    "recalcitreremmo": "recalcitrare",
    "recalcitreremo": "recalcitrare",
    "recalcitrereste": "recalcitrare",
    "recalcitreresti": "recalcitrare",
    "recalcitrerete": "recalcitrare",
    "recalcitrerà": "recalcitrare",
    "recalcitrerò": "recalcitrare",
    "recalcitri": "recalcitrare",
    "recalcitriamo": "recalcitrare",
    "recalcitriate": "recalcitrare",
    "recalcitrin": "recalcitrare",
    "recalcitrino": "recalcitrare",
    "recalcitro": "recalcitrare",
    "recalcitrò": "recalcitrare",
    "recammo": "recare",
    "recan": "recere",
    "recando": "recare",
    "recano": "recere",
    "recante": "recare",
    "recanti": "recare",
    "recapita": "recapitare",
    "recapitai": "recapitare",
    "recapitammo": "recapitare",
    "recapitan": "recapitare",
    "recapitando": "recapitare",
    "recapitano": "recapitare",
    "recapitante": "recapitare",
    "recapitanti": "recapitare",
    "recapitar": "recapitare",
    "recapitaron": "recapitare",
    "recapitarono": "recapitare",
    "recapitasse": "recapitare",
    "recapitasser": "recapitare",
    "recapitassero": "recapitare",
    "recapitassi": "recapitare",
    "recapitassimo": "recapitare",
    "recapitaste": "recapitare",
    "recapitasti": "recapitare",
    "recapitata": "recapitare",
    "recapitate": "recapitare",
    "recapitati": "recapitare",
    "recapitato": "recapitare",
    "recapitava": "recapitare",
    "recapitavamo": "recapitare",
    "recapitavan": "recapitare",
    "recapitavano": "recapitare",
    "recapitavate": "recapitare",
    "recapitavi": "recapitare",
    "recapitavo": "recapitare",
    "recapiterai": "recapitare",
    "recapiteran": "recapitare",
    "recapiteranno": "recapitare",
    "recapiterebbe": "recapitare",
    "recapiterebber": "recapitare",
    "recapiterebbero": "recapitare",
    "recapiterei": "recapitare",
    "recapiteremmo": "recapitare",
    "recapiteremo": "recapitare",
    "recapitereste": "recapitare",
    "recapiteresti": "recapitare",
    "recapiterete": "recapitare",
    "recapiterà": "recapitare",
    "recapiterò": "recapitare",
    "recapiti": "recapito",
    "recapitiamo": "recapitare",
    "recapitiate": "recapitare",
    "recapitin": "recapitare",
    "recapitino": "recapitare",
    "recapito": "recapitare",
    "recapitò": "recapitare",
    "recar": "recare",
    "recaron": "recare",
    "recarono": "recare",
    "recasse": "recare",
    "recasser": "recare",
    "recassero": "recare",
    "recassi": "recare",
    "recassimo": "recare",
    "recaste": "recare",
    "recasti": "recare",
    "recata": "recare",
    "recate": "recare",
    "recati": "recare",
    "recato": "recare",
    "recava": "recare",
    "recavamo": "recare",
    "recavan": "recare",
    "recavano": "recare",
    "recavate": "recare",
    "recavi": "recare",
    "recavo": "recare",
    "rece": "recere",
    "receda": "recedere",
    "recedan": "recedere",
    "recedano": "recedere",
    "recede": "recedere",
    "recedei": "recedere",
    "recedemmo": "recedere",
    "recedendo": "recedere",
    "recedente": "recedere",
    "recedenti": "recedere",
    "receder": "recedere",
    "recederai": "recedere",
    "recederan": "recedere",
    "recederanno": "recedere",
    "recederebbe": "recedere",
    "recederebber": "recedere",
    "recederebbero": "recedere",
    "recederei": "recedere",
    "recederemmo": "recedere",
    "recederemo": "recedere",
    "recedereste": "recedere",
    "recederesti": "recedere",
    "recederete": "recedere",
    "recederon": "recedere",
    "recederono": "recedere",
    "recederà": "recedere",
    "recederò": "recedere",
    "recedesse": "recedere",
    "recedesser": "recedere",
    "recedessero": "recedere",
    "recedessi": "recedere",
    "recedessimo": "recedere",
    "recedeste": "recedere",
    "recedesti": "recedere",
    "recedete": "recedere",
    "recedeva": "recedere",
    "recedevamo": "recedere",
    "recedevan": "recedere",
    "recedevano": "recedere",
    "recedevate": "recedere",
    "recedevi": "recedere",
    "recedevo": "recedere",
    "recedi": "recedere",
    "recediamo": "recedere",
    "recediate": "recedere",
    "recedo": "recedere",
    "recedon": "recedere",
    "recedono": "recedere",
    "receduta": "recedere",
    "recedute": "recedere",
    "receduti": "recedere",
    "receduto": "recedere",
    "recedè": "recedere",
    "recei": "recere",
    "recemmo": "recere",
    "recendo": "recere",
    "recensendo": "recensire",
    "recensente": "recensire",
    "recensenti": "recensire",
    "recensiamo": "recensire",
    "recensiate": "recensire",
    "recensii": "recensire",
    "recensimmo": "recensire",
    "recensioni": "recensione",
    "recensir": "recensire",
    "recensirai": "recensire",
    "recensiran": "recensire",
    "recensiranno": "recensire",
    "recensirebbe": "recensire",
    "recensirebber": "recensire",
    "recensirebbero": "recensire",
    "recensirei": "recensire",
    "recensiremmo": "recensire",
    "recensiremo": "recensire",
    "recensireste": "recensire",
    "recensiresti": "recensire",
    "recensirete": "recensire",
    "recensiron": "recensire",
    "recensirono": "recensire",
    "recensirà": "recensire",
    "recensirò": "recensire",
    "recensisca": "recensire",
    "recensiscan": "recensire",
    "recensiscano": "recensire",
    "recensisce": "recensire",
    "recensisci": "recensire",
    "recensisco": "recensire",
    "recensiscon": "recensire",
    "recensiscono": "recensire",
    "recensisse": "recensire",
    "recensisser": "recensire",
    "recensissero": "recensire",
    "recensissi": "recensire",
    "recensissimo": "recensire",
    "recensiste": "recensire",
    "recensisti": "recensire",
    "recensita": "recensire",
    "recensite": "recensire",
    "recensiti": "recensire",
    "recensito": "recensire",
    "recensiva": "recensire",
    "recensivamo": "recensire",
    "recensivan": "recensire",
    "recensivano": "recensire",
    "recensivate": "recensire",
    "recensivi": "recensire",
    "recensivo": "recensire",
    "recensori": "recensore",
    "recensì": "recensire",
    "recente": "recere",
    "recenti": "recere",
    "recependo": "recepire",
    "recepente": "recepire",
    "recepenti": "recepire",
    "recepiamo": "recepire",
    "recepiate": "recepire",
    "recepii": "recepire",
    "recepimenti": "recepimento",
    "recepimmo": "recepire",
    "recepir": "recepire",
    "recepirai": "recepire",
    "recepiran": "recepire",
    "recepiranno": "recepire",
    "recepirebbe": "recepire",
    "recepirebber": "recepire",
    "recepirebbero": "recepire",
    "recepirei": "recepire",
    "recepiremmo": "recepire",
    "recepiremo": "recepire",
    "recepireste": "recepire",
    "recepiresti": "recepire",
    "recepirete": "recepire",
    "recepiron": "recepire",
    "recepirono": "recepire",
    "recepirà": "recepire",
    "recepirò": "recepire",
    "recepisca": "recepire",
    "recepiscan": "recepire",
    "recepiscano": "recepire",
    "recepisce": "recepire",
    "recepisci": "recepire",
    "recepisco": "recepire",
    "recepiscon": "recepire",
    "recepiscono": "recepire",
    "recepisse": "recepire",
    "recepisser": "recepire",
    "recepissero": "recepire",
    "recepissi": "recepire",
    "recepissimo": "recepire",
    "recepiste": "recepire",
    "recepisti": "recepire",
    "recepita": "recepire",
    "recepite": "recepire",
    "recepiti": "recepire",
    "recepito": "recepire",
    "recepiva": "recepire",
    "recepivamo": "recepire",
    "recepivan": "recepire",
    "recepivano": "recepire",
    "recepivate": "recepire",
    "recepivi": "recepire",
    "recepivo": "recepire",
    "recepì": "recepire",
    "recer": "recere",
    "recerai": "recere",
    "receran": "recere",
    "receranno": "recere",
    "recerebbe": "recere",
    "recerebber": "recere",
    "recerebbero": "recere",
    "recerei": "recere",
    "receremmo": "recere",
    "receremo": "recere",
    "recereste": "recere",
    "receresti": "recere",
    "recerete": "recere",
    "receron": "recere",
    "recerono": "recere",
    "recerà": "recere",
    "recerò": "recere",
    "recesse": "recere",
    "recesser": "recere",
    "recessero": "recere",
    "recessi": "recesso",
    "recessimo": "recere",
    "recessioni": "recessione",
    "recessiva": "recessivo",
    "recessive": "recessivo",
    "recessivi": "recessivo",
    "receste": "recere",
    "recesti": "recere",
    "recete": "recere",
    "recettiva": "recettivo",
    "recettive": "recettivo",
    "recettivi": "recettivo",
    "recettori": "recettore",
    "receva": "recere",
    "recevamo": "recere",
    "recevan": "recere",
    "recevano": "recere",
    "recevate": "recere",
    "recevi": "recere",
    "recevo": "recere",
    "recherai": "recare",
    "recheran": "recare",
    "recheranno": "recare",
    "recherebbe": "recare",
    "recherebber": "recare",
    "recherebbero": "recare",
    "recherei": "recare",
    "recheremmo": "recare",
    "recheremo": "recare",
    "rechereste": "recare",
    "recheresti": "recare",
    "recherete": "recare",
    "recherà": "recare",
    "recherò": "recare",
    "rechi": "recare",
    "rechiamo": "recare",
    "rechiate": "recare",
    "rechin": "recare",
    "rechino": "recare",
    "reci": "recere",
    "reciamo": "recere",
    "reciate": "recere",
    "recida": "recidere",
    "recidan": "recidere",
    "recidano": "recidere",
    "recide": "recidere",
    "recidemmo": "recidere",
    "recidendo": "recidere",
    "recidente": "recidere",
    "recidenti": "recidere",
    "recider": "recidere",
    "reciderai": "recidere",
    "recideran": "recidere",
    "recideranno": "recidere",
    "reciderebbe": "recidere",
    "reciderebber": "recidere",
    "reciderebbero": "recidere",
    "reciderei": "recidere",
    "recideremmo": "recidere",
    "recideremo": "recidere",
    "recidereste": "recidere",
    "recideresti": "recidere",
    "reciderete": "recidere",
    "reciderà": "recidere",
    "reciderò": "recidere",
    "recidesse": "recidere",
    "recidesser": "recidere",
    "recidessero": "recidere",
    "recidessi": "recidere",
    "recidessimo": "recidere",
    "recideste": "recidere",
    "recidesti": "recidere",
    "recidete": "recidere",
    "recideva": "recidere",
    "recidevamo": "recidere",
    "recidevan": "recidere",
    "recidevano": "recidere",
    "recidevate": "recidere",
    "recidevi": "recidere",
    "recidevo": "recidere",
    "recidi": "recidere",
    "recidiamo": "recidere",
    "recidiate": "recidere",
    "recidiva": "recidivo",
    "recidivai": "recidivare",
    "recidivammo": "recidivare",
    "recidivan": "recidivare",
    "recidivando": "recidivare",
    "recidivano": "recidivare",
    "recidivante": "recidivare",
    "recidivanti": "recidivare",
    "recidivar": "recidivare",
    "recidivaron": "recidivare",
    "recidivarono": "recidivare",
    "recidivasse": "recidivare",
    "recidivasser": "recidivare",
    "recidivassero": "recidivare",
    "recidivassi": "recidivare",
    "recidivassimo": "recidivare",
    "recidivaste": "recidivare",
    "recidivasti": "recidivare",
    "recidivata": "recidivare",
    "recidivate": "recidivare",
    "recidivati": "recidivare",
    "recidivato": "recidivare",
    "recidivava": "recidivare",
    "recidivavamo": "recidivare",
    "recidivavan": "recidivare",
    "recidivavano": "recidivare",
    "recidivavate": "recidivare",
    "recidivavi": "recidivare",
    "recidivavo": "recidivare",
    "recidive": "recidivo",
    "recidiverai": "recidivare",
    "recidiveran": "recidivare",
    "recidiveranno": "recidivare",
    "recidiverebbe": "recidivare",
    "recidiverebber": "recidivare",
    "recidiverebbero": "recidivare",
    "recidiverei": "recidivare",
    "recidiveremmo": "recidivare",
    "recidiveremo": "recidivare",
    "recidivereste": "recidivare",
    "recidiveresti": "recidivare",
    "recidiverete": "recidivare",
    "recidiverà": "recidivare",
    "recidiverò": "recidivare",
    "recidivi": "recidivo",
    "recidiviamo": "recidivare",
    "recidiviate": "recidivare",
    "recidivin": "recidivare",
    "recidivino": "recidivare",
    "recidivo": "recidivare",
    "recidivò": "recidivare",
    "recido": "recidere",
    "recidon": "recidere",
    "recidono": "recidere",
    "recinga": "recingere",
    "recingan": "recingere",
    "recingano": "recingere",
    "recinge": "recingere",
    "recingemmo": "recingere",
    "recingendo": "recingere",
    "recingente": "recingere",
    "recingenti": "recingere",
    "recinger": "recingere",
    "recingerai": "recingere",
    "recingeran": "recingere",
    "recingeranno": "recingere",
    "recingerebbe": "recingere",
    "recingerebber": "recingere",
    "recingerebbero": "recingere",
    "recingerei": "recingere",
    "recingeremmo": "recingere",
    "recingeremo": "recingere",
    "recingereste": "recingere",
    "recingeresti": "recingere",
    "recingerete": "recingere",
    "recingerà": "recingere",
    "recingerò": "recingere",
    "recingesse": "recingere",
    "recingesser": "recingere",
    "recingessero": "recingere",
    "recingessi": "recingere",
    "recingessimo": "recingere",
    "recingeste": "recingere",
    "recingesti": "recingere",
    "recingete": "recingere",
    "recingeva": "recingere",
    "recingevamo": "recingere",
    "recingevan": "recingere",
    "recingevano": "recingere",
    "recingevate": "recingere",
    "recingevi": "recingere",
    "recingevo": "recingere",
    "recingi": "recingere",
    "recingiamo": "recingere",
    "recingiate": "recingere",
    "recingo": "recingere",
    "recingon": "recingere",
    "recingono": "recingere",
    "recinser": "recingere",
    "recinsero": "recingere",
    "recinsi": "recingere",
    "recinsè": "recingere",
    "recinta": "recinto",
    "recintai": "recintare",
    "recintammo": "recintare",
    "recintan": "recintare",
    "recintando": "recintare",
    "recintano": "recintare",
    "recintante": "recintare",
    "recintanti": "recintare",
    "recintar": "recintare",
    "recintaron": "recintare",
    "recintarono": "recintare",
    "recintasse": "recintare",
    "recintasser": "recintare",
    "recintassero": "recintare",
    "recintassi": "recintare",
    "recintassimo": "recintare",
    "recintaste": "recintare",
    "recintasti": "recintare",
    "recintata": "recintare",
    "recintate": "recintare",
    "recintati": "recintare",
    "recintato": "recintare",
    "recintava": "recintare",
    "recintavamo": "recintare",
    "recintavan": "recintare",
    "recintavano": "recintare",
    "recintavate": "recintare",
    "recintavi": "recintare",
    "recintavo": "recintare",
    "recinte": "recinto",
    "recinterai": "recintare",
    "recinteran": "recintare",
    "recinteranno": "recintare",
    "recinterebbe": "recintare",
    "recinterebber": "recintare",
    "recinterebbero": "recintare",
    "recinterei": "recintare",
    "recinteremmo": "recintare",
    "recinteremo": "recintare",
    "recintereste": "recintare",
    "recinteresti": "recintare",
    "recinterete": "recintare",
    "recinterà": "recintare",
    "recinterò": "recintare",
    "recinti": "recinto",
    "recintiamo": "recintare",
    "recintiate": "recintare",
    "recintin": "recintare",
    "recintino": "recintare",
    "recinto": "recintare",
    "recintò": "recintare",
    "recinzioni": "recinzione",
    "recipienti": "recipiente",
    "reciproca": "reciproco",
    "reciprocai": "reciprocare",
    "reciprocammo": "reciprocare",
    "reciprocan": "reciprocare",
    "reciprocando": "reciprocare",
    "reciprocano": "reciprocare",
    "reciprocante": "reciprocare",
    "reciprocanti": "reciprocare",
    "reciprocar": "reciprocare",
    "reciprocaron": "reciprocare",
    "reciprocarono": "reciprocare",
    "reciprocasse": "reciprocare",
    "reciprocasser": "reciprocare",
    "reciprocassero": "reciprocare",
    "reciprocassi": "reciprocare",
    "reciprocassimo": "reciprocare",
    "reciprocaste": "reciprocare",
    "reciprocasti": "reciprocare",
    "reciprocata": "reciprocare",
    "reciprocate": "reciprocare",
    "reciprocati": "reciprocare",
    "reciprocato": "reciprocare",
    "reciprocava": "reciprocare",
    "reciprocavamo": "reciprocare",
    "reciprocavan": "reciprocare",
    "reciprocavano": "reciprocare",
    "reciprocavate": "reciprocare",
    "reciprocavi": "reciprocare",
    "reciprocavo": "reciprocare",
    "reciproche": "reciproco",
    "reciprocherai": "reciprocare",
    "reciprocheran": "reciprocare",
    "reciprocheranno": "reciprocare",
    "reciprocherebbe": "reciprocare",
    "reciprocherebber": "reciprocare",
    "reciprocherebbero": "reciprocare",
    "reciprocherei": "reciprocare",
    "reciprocheremmo": "reciprocare",
    "reciprocheremo": "reciprocare",
    "reciprochereste": "reciprocare",
    "reciprocheresti": "reciprocare",
    "reciprocherete": "reciprocare",
    "reciprocherà": "reciprocare",
    "reciprocherò": "reciprocare",
    "reciprochi": "reciprocare",
    "reciprochiamo": "reciprocare",
    "reciprochiate": "reciprocare",
    "reciprochin": "reciprocare",
    "reciprochino": "reciprocare",
    "reciproci": "reciproco",
    "reciproco": "reciprocare",
    "reciprocò": "reciprocare",
    "recisa": "reciso",
    "recise": "reciso",
    "reciser": "recidere",
    "recisero": "recidere",
    "recisi": "reciso",
    "reciso": "recidere",
    "recita": "recitare",
    "recitai": "recitare",
    "recitammo": "recitare",
    "recitan": "recitare",
    "recitando": "recitare",
    "recitano": "recitare",
    "recitante": "recitare",
    "recitanti": "recitare",
    "recitar": "recitare",
    "recitaron": "recitare",
    "recitarono": "recitare",
    "recitasse": "recitare",
    "recitasser": "recitare",
    "recitassero": "recitare",
    "recitassi": "recitare",
    "recitassimo": "recitare",
    "recitaste": "recitare",
    "recitasti": "recitare",
    "recitata": "recitare",
    "recitate": "recitare",
    "recitati": "recitare",
    "recitativa": "recitativo",
    "recitative": "recitativo",
    "recitativi": "recitativo",
    "recitato": "recitare",
    "recitava": "recitare",
    "recitavamo": "recitare",
    "recitavan": "recitare",
    "recitavano": "recitare",
    "recitavate": "recitare",
    "recitavi": "recitare",
    "recitavo": "recitare",
    "recitazioni": "recitazione",
    "recite": "recita",
    "reciterai": "recitare",
    "reciteran": "recitare",
    "reciteranno": "recitare",
    "reciterebbe": "recitare",
    "reciterebber": "recitare",
    "reciterebbero": "recitare",
    "reciterei": "recitare",
    "reciteremmo": "recitare",
    "reciteremo": "recitare",
    "recitereste": "recitare",
    "reciteresti": "recitare",
    "reciterete": "recitare",
    "reciterà": "recitare",
    "reciterò": "recitare",
    "reciti": "recitare",
    "recitiamo": "recitare",
    "recitiate": "recitare",
    "recitin": "recitare",
    "recitino": "recitare",
    "recito": "recitare",
    "recitò": "recitare",
    "reciuta": "recere",
    "reciute": "recere",
    "reciuti": "recere",
    "reciuto": "recere",
    "reclama": "reclamare",
    "reclamai": "reclamare",
    "reclamammo": "reclamare",
    "reclaman": "reclamare",
    "reclamando": "reclamare",
    "reclamano": "reclamare",
    "reclamante": "reclamare",
    "reclamanti": "reclamare",
    "reclamar": "reclamare",
    "reclamaron": "reclamare",
    "reclamarono": "reclamare",
    "reclamasse": "reclamare",
    "reclamasser": "reclamare",
    "reclamassero": "reclamare",
    "reclamassi": "reclamare",
    "reclamassimo": "reclamare",
    "reclamaste": "reclamare",
    "reclamasti": "reclamare",
    "reclamata": "reclamare",
    "reclamate": "reclamare",
    "reclamati": "reclamare",
    "reclamato": "reclamare",
    "reclamava": "reclamare",
    "reclamavamo": "reclamare",
    "reclamavan": "reclamare",
    "reclamavano": "reclamare",
    "reclamavate": "reclamare",
    "reclamavi": "reclamare",
    "reclamavo": "reclamare",
    "reclamerai": "reclamare",
    "reclameran": "reclamare",
    "reclameranno": "reclamare",
    "reclamerebbe": "reclamare",
    "reclamerebber": "reclamare",
    "reclamerebbero": "reclamare",
    "reclamerei": "reclamare",
    "reclameremmo": "reclamare",
    "reclameremo": "reclamare",
    "reclamereste": "reclamare",
    "reclameresti": "reclamare",
    "reclamerete": "reclamare",
    "reclamerà": "reclamare",
    "reclamerò": "reclamare",
    "reclami": "reclamo",
    "reclamiamo": "reclamare",
    "reclamiate": "reclamare",
    "reclamin": "reclamare",
    "reclamino": "reclamare",
    "reclamistica": "reclamistico",
    "reclamistiche": "reclamistico",
    "reclamistici": "reclamistico",
    "reclamizza": "reclamizzare",
    "reclamizzai": "reclamizzare",
    "reclamizzammo": "reclamizzare",
    "reclamizzan": "reclamizzare",
    "reclamizzando": "reclamizzare",
    "reclamizzano": "reclamizzare",
    "reclamizzante": "reclamizzare",
    "reclamizzanti": "reclamizzare",
    "reclamizzar": "reclamizzare",
    "reclamizzaron": "reclamizzare",
    "reclamizzarono": "reclamizzare",
    "reclamizzasse": "reclamizzare",
    "reclamizzasser": "reclamizzare",
    "reclamizzassero": "reclamizzare",
    "reclamizzassi": "reclamizzare",
    "reclamizzassimo": "reclamizzare",
    "reclamizzaste": "reclamizzare",
    "reclamizzasti": "reclamizzare",
    "reclamizzata": "reclamizzare",
    "reclamizzate": "reclamizzare",
    "reclamizzati": "reclamizzare",
    "reclamizzato": "reclamizzare",
    "reclamizzava": "reclamizzare",
    "reclamizzavamo": "reclamizzare",
    "reclamizzavan": "reclamizzare",
    "reclamizzavano": "reclamizzare",
    "reclamizzavate": "reclamizzare",
    "reclamizzavi": "reclamizzare",
    "reclamizzavo": "reclamizzare",
    "reclamizzerai": "reclamizzare",
    "reclamizzeran": "reclamizzare",
    "reclamizzeranno": "reclamizzare",
    "reclamizzerebbe": "reclamizzare",
    "reclamizzerebber": "reclamizzare",
    "reclamizzerebbero": "reclamizzare",
    "reclamizzerei": "reclamizzare",
    "reclamizzeremmo": "reclamizzare",
    "reclamizzeremo": "reclamizzare",
    "reclamizzereste": "reclamizzare",
    "reclamizzeresti": "reclamizzare",
    "reclamizzerete": "reclamizzare",
    "reclamizzerà": "reclamizzare",
    "reclamizzerò": "reclamizzare",
    "reclamizzi": "reclamizzare",
    "reclamizziamo": "reclamizzare",
    "reclamizziate": "reclamizzare",
    "reclamizzin": "reclamizzare",
    "reclamizzino": "reclamizzare",
    "reclamizzo": "reclamizzare",
    "reclamizzò": "reclamizzare",
    "reclamo": "reclamare",
    "reclamò": "reclamare",
    "reclina": "reclinare",
    "reclinai": "reclinare",
    "reclinammo": "reclinare",
    "reclinan": "reclinare",
    "reclinando": "reclinare",
    "reclinano": "reclinare",
    "reclinante": "reclinare",
    "reclinanti": "reclinare",
    "reclinar": "reclinare",
    "reclinaron": "reclinare",
    "reclinarono": "reclinare",
    "reclinasse": "reclinare",
    "reclinasser": "reclinare",
    "reclinassero": "reclinare",
    "reclinassi": "reclinare",
    "reclinassimo": "reclinare",
    "reclinaste": "reclinare",
    "reclinasti": "reclinare",
    "reclinata": "reclinare",
    "reclinate": "reclinare",
    "reclinati": "reclinare",
    "reclinato": "reclinare",
    "reclinava": "reclinare",
    "reclinavamo": "reclinare",
    "reclinavan": "reclinare",
    "reclinavano": "reclinare",
    "reclinavate": "reclinare",
    "reclinavi": "reclinare",
    "reclinavo": "reclinare",
    "reclinerai": "reclinare",
    "reclineran": "reclinare",
    "reclineranno": "reclinare",
    "reclinerebbe": "reclinare",
    "reclinerebber": "reclinare",
    "reclinerebbero": "reclinare",
    "reclinerei": "reclinare",
    "reclineremmo": "reclinare",
    "reclineremo": "reclinare",
    "reclinereste": "reclinare",
    "reclineresti": "reclinare",
    "reclinerete": "reclinare",
    "reclinerà": "reclinare",
    "reclinerò": "reclinare",
    "reclini": "reclinare",
    "recliniamo": "reclinare",
    "recliniate": "reclinare",
    "reclinin": "reclinare",
    "reclinino": "reclinare",
    "reclino": "reclinare",
    "reclinò": "reclinare",
    "recluda": "recludere",
    "recludan": "recludere",
    "recludano": "recludere",
    "reclude": "recludere",
    "recludemmo": "recludere",
    "recludendo": "recludere",
    "recludente": "recludere",
    "recludenti": "recludere",
    "recluder": "recludere",
    "recluderai": "recludere",
    "recluderan": "recludere",
    "recluderanno": "recludere",
    "recluderebbe": "recludere",
    "recluderebber": "recludere",
    "recluderebbero": "recludere",
    "recluderei": "recludere",
    "recluderemmo": "recludere",
    "recluderemo": "recludere",
    "recludereste": "recludere",
    "recluderesti": "recludere",
    "recluderete": "recludere",
    "recluderà": "recludere",
    "recluderò": "recludere",
    "recludesse": "recludere",
    "recludesser": "recludere",
    "recludessero": "recludere",
    "recludessi": "recludere",
    "recludessimo": "recludere",
    "recludeste": "recludere",
    "recludesti": "recludere",
    "recludete": "recludere",
    "recludeva": "recludere",
    "recludevamo": "recludere",
    "recludevan": "recludere",
    "recludevano": "recludere",
    "recludevate": "recludere",
    "recludevi": "recludere",
    "recludevo": "recludere",
    "recludi": "recludere",
    "recludiamo": "recludere",
    "recludiate": "recludere",
    "recludo": "recludere",
    "recludon": "recludere",
    "recludono": "recludere",
    "reclusa": "recluso",
    "recluse": "recluso",
    "recluser": "recludere",
    "reclusero": "recludere",
    "reclusi": "recluso",
    "reclusioni": "reclusione",
    "recluso": "recludere",
    "reclusori": "reclusorio",
    "recluta": "reclutare",
    "reclutai": "reclutare",
    "reclutamenti": "reclutamento",
    "reclutammo": "reclutare",
    "reclutan": "reclutare",
    "reclutando": "reclutare",
    "reclutano": "reclutare",
    "reclutante": "reclutare",
    "reclutanti": "reclutare",
    "reclutar": "reclutare",
    "reclutaron": "reclutare",
    "reclutarono": "reclutare",
    "reclutasse": "reclutare",
    "reclutasser": "reclutare",
    "reclutassero": "reclutare",
    "reclutassi": "reclutare",
    "reclutassimo": "reclutare",
    "reclutaste": "reclutare",
    "reclutasti": "reclutare",
    "reclutata": "reclutare",
    "reclutate": "reclutare",
    "reclutati": "reclutare",
    "reclutato": "reclutare",
    "reclutatori": "reclutatore",
    "reclutava": "reclutare",
    "reclutavamo": "reclutare",
    "reclutavan": "reclutare",
    "reclutavano": "reclutare",
    "reclutavate": "reclutare",
    "reclutavi": "reclutare",
    "reclutavo": "reclutare",
    "reclute": "recluta",
    "recluterai": "reclutare",
    "recluteran": "reclutare",
    "recluteranno": "reclutare",
    "recluterebbe": "reclutare",
    "recluterebber": "reclutare",
    "recluterebbero": "reclutare",
    "recluterei": "reclutare",
    "recluteremmo": "reclutare",
    "recluteremo": "reclutare",
    "reclutereste": "reclutare",
    "recluteresti": "reclutare",
    "recluterete": "reclutare",
    "recluterà": "reclutare",
    "recluterò": "reclutare",
    "recluti": "reclutare",
    "reclutiamo": "reclutare",
    "reclutiate": "reclutare",
    "reclutin": "reclutare",
    "reclutino": "reclutare",
    "recluto": "reclutare",
    "reclutò": "reclutare",
    "reco": "recere",
    "recon": "recere",
    "recondita": "recondito",
    "recondite": "recondito",
    "reconditi": "recondito",
    "recono": "recere",
    "recrimina": "recriminare",
    "recriminai": "recriminare",
    "recriminammo": "recriminare",
    "recriminan": "recriminare",
    "recriminando": "recriminare",
    "recriminano": "recriminare",
    "recriminante": "recriminare",
    "recriminanti": "recriminare",
    "recriminar": "recriminare",
    "recriminaron": "recriminare",
    "recriminarono": "recriminare",
    "recriminasse": "recriminare",
    "recriminasser": "recriminare",
    "recriminassero": "recriminare",
    "recriminassi": "recriminare",
    "recriminassimo": "recriminare",
    "recriminaste": "recriminare",
    "recriminasti": "recriminare",
    "recriminata": "recriminare",
    "recriminate": "recriminare",
    "recriminati": "recriminare",
    "recriminato": "recriminare",
    "recriminava": "recriminare",
    "recriminavamo": "recriminare",
    "recriminavan": "recriminare",
    "recriminavano": "recriminare",
    "recriminavate": "recriminare",
    "recriminavi": "recriminare",
    "recriminavo": "recriminare",
    "recriminazioni": "recriminazione",
    "recriminerai": "recriminare",
    "recrimineran": "recriminare",
    "recrimineranno": "recriminare",
    "recriminerebbe": "recriminare",
    "recriminerebber": "recriminare",
    "recriminerebbero": "recriminare",
    "recriminerei": "recriminare",
    "recrimineremmo": "recriminare",
    "recrimineremo": "recriminare",
    "recriminereste": "recriminare",
    "recrimineresti": "recriminare",
    "recriminerete": "recriminare",
    "recriminerà": "recriminare",
    "recriminerò": "recriminare",
    "recrimini": "recriminare",
    "recriminiamo": "recriminare",
    "recriminiate": "recriminare",
    "recriminin": "recriminare",
    "recriminino": "recriminare",
    "recrimino": "recriminare",
    "recriminò": "recriminare",
    "recrudescenze": "recrudescenza",
    "recupera": "recuperare",
    "recuperabili": "recuperabile",
    "recuperai": "recuperare",
    "recuperammo": "recuperare",
    "recuperan": "recuperare",
    "recuperando": "recuperare",
    "recuperano": "recuperare",
    "recuperante": "recuperare",
    "recuperanti": "recuperare",
    "recuperar": "recuperare",
    "recuperaron": "recuperare",
    "recuperarono": "recuperare",
    "recuperasse": "recuperare",
    "recuperasser": "recuperare",
    "recuperassero": "recuperare",
    "recuperassi": "recuperare",
    "recuperassimo": "recuperare",
    "recuperaste": "recuperare",
    "recuperasti": "recuperare",
    "recuperata": "recuperare",
    "recuperate": "recuperare",
    "recuperati": "recuperare",
    "recuperato": "recuperare",
    "recuperava": "recuperare",
    "recuperavamo": "recuperare",
    "recuperavan": "recuperare",
    "recuperavano": "recuperare",
    "recuperavate": "recuperare",
    "recuperavi": "recuperare",
    "recuperavo": "recuperare",
    "recupererai": "recuperare",
    "recupereran": "recuperare",
    "recupereranno": "recuperare",
    "recupererebbe": "recuperare",
    "recupererebber": "recuperare",
    "recupererebbero": "recuperare",
    "recupererei": "recuperare",
    "recupereremmo": "recuperare",
    "recupereremo": "recuperare",
    "recuperereste": "recuperare",
    "recupereresti": "recuperare",
    "recupererete": "recuperare",
    "recupererà": "recuperare",
    "recupererò": "recuperare",
    "recuperi": "recupero",
    "recuperiamo": "recuperare",
    "recuperiate": "recuperare",
    "recuperin": "recuperare",
    "recuperino": "recuperare",
    "recupero": "recuperare",
    "recuperò": "recuperare",
    "recè": "recere",
    "recò": "recare",
    "redarguendo": "redarguire",
    "redarguente": "redarguire",
    "redarguenti": "redarguire",
    "redarguiamo": "redarguire",
    "redarguiate": "redarguire",
    "redarguii": "redarguire",
    "redarguimmo": "redarguire",
    "redarguir": "redarguire",
    "redarguirai": "redarguire",
    "redarguiran": "redarguire",
    "redarguiranno": "redarguire",
    "redarguirebbe": "redarguire",
    "redarguirebber": "redarguire",
    "redarguirebbero": "redarguire",
    "redarguirei": "redarguire",
    "redarguiremmo": "redarguire",
    "redarguiremo": "redarguire",
    "redarguireste": "redarguire",
    "redarguiresti": "redarguire",
    "redarguirete": "redarguire",
    "redarguiron": "redarguire",
    "redarguirono": "redarguire",
    "redarguirà": "redarguire",
    "redarguirò": "redarguire",
    "redarguisca": "redarguire",
    "redarguiscan": "redarguire",
    "redarguiscano": "redarguire",
    "redarguisce": "redarguire",
    "redarguisci": "redarguire",
    "redarguisco": "redarguire",
    "redarguiscon": "redarguire",
    "redarguiscono": "redarguire",
    "redarguisse": "redarguire",
    "redarguisser": "redarguire",
    "redarguissero": "redarguire",
    "redarguissi": "redarguire",
    "redarguissimo": "redarguire",
    "redarguiste": "redarguire",
    "redarguisti": "redarguire",
    "redarguita": "redarguire",
    "redarguite": "redarguire",
    "redarguiti": "redarguire",
    "redarguito": "redarguire",
    "redarguiva": "redarguire",
    "redarguivamo": "redarguire",
    "redarguivan": "redarguire",
    "redarguivano": "redarguire",
    "redarguivate": "redarguire",
    "redarguivi": "redarguire",
    "redarguivo": "redarguire",
    "redarguì": "redarguire",
    "redatta": "redatto",
    "redatte": "redatto",
    "redatti": "redatto",
    "redattori": "redattore",
    "redattrici": "redattrice",
    "redazionali": "redazionale",
    "redazioni": "redazione",
    "redditi": "reddito",
    "redditizi": "redditizio",
    "redditizia": "redditizio",
    "redditizie": "redditizio",
    "redditometri": "redditometro",
    "redenta": "redento",
    "redente": "redento",
    "redenti": "redento",
    "redentori": "redentore",
    "redentrice": "redentore",
    "redentrici": "redentore",
    "redenzioni": "redenzione",
    "rediga": "redigere",
    "redigan": "redigere",
    "redigano": "redigere",
    "redige": "redigere",
    "redigei": "redigere",
    "redigemmo": "redigere",
    "redigendo": "redigere",
    "redigente": "redigere",
    "redigenti": "redigere",
    "rediger": "redigere",
    "redigerai": "redigere",
    "redigeran": "redigere",
    "redigeranno": "redigere",
    "redigerebbe": "redigere",
    "redigerebber": "redigere",
    "redigerebbero": "redigere",
    "redigerei": "redigere",
    "redigeremmo": "redigere",
    "redigeremo": "redigere",
    "redigereste": "redigere",
    "redigeresti": "redigere",
    "redigerete": "redigere",
    "redigeron": "redigere",
    "redigerono": "redigere",
    "redigerà": "redigere",
    "redigerò": "redigere",
    "redigesse": "redigere",
    "redigesser": "redigere",
    "redigessero": "redigere",
    "redigessi": "redigere",
    "redigessimo": "redigere",
    "redigeste": "redigere",
    "redigesti": "redigere",
    "redigete": "redigere",
    "redigeva": "redigere",
    "redigevamo": "redigere",
    "redigevan": "redigere",
    "redigevano": "redigere",
    "redigevate": "redigere",
    "redigevi": "redigere",
    "redigevo": "redigere",
    "redigi": "redigere",
    "redigiamo": "redigere",
    "redigiate": "redigere",
    "redigiuta": "redigere",
    "redigiute": "redigere",
    "redigiuti": "redigere",
    "redigiuto": "redigere",
    "redigo": "redigere",
    "redigon": "redigere",
    "redigono": "redigere",
    "redigè": "redigere",
    "redimibili": "redimibile",
    "redingotes": "redingote",
    "redini": "redine",
    "redistribua": "redistribuire",
    "redistribuan": "redistribuire",
    "redistribuano": "redistribuire",
    "redistribue": "redistribuire",
    "redistribuendo": "redistribuire",
    "redistribuente": "redistribuire",
    "redistribuenti": "redistribuire",
    "redistribui": "redistribuire",
    "redistribuiamo": "redistribuire",
    "redistribuiate": "redistribuire",
    "redistribuii": "redistribuire",
    "redistribuimmo": "redistribuire",
    "redistribuir": "redistribuire",
    "redistribuirai": "redistribuire",
    "redistribuiran": "redistribuire",
    "redistribuiranno": "redistribuire",
    "redistribuirebbe": "redistribuire",
    "redistribuirebber": "redistribuire",
    "redistribuirebbero": "redistribuire",
    "redistribuirei": "redistribuire",
    "redistribuiremmo": "redistribuire",
    "redistribuiremo": "redistribuire",
    "redistribuireste": "redistribuire",
    "redistribuiresti": "redistribuire",
    "redistribuirete": "redistribuire",
    "redistribuiron": "redistribuire",
    "redistribuirono": "redistribuire",
    "redistribuirà": "redistribuire",
    "redistribuirò": "redistribuire",
    "redistribuisse": "redistribuire",
    "redistribuisser": "redistribuire",
    "redistribuissero": "redistribuire",
    "redistribuissi": "redistribuire",
    "redistribuissimo": "redistribuire",
    "redistribuiste": "redistribuire",
    "redistribuisti": "redistribuire",
    "redistribuita": "redistribuire",
    "redistribuite": "redistribuire",
    "redistribuiti": "redistribuire",
    "redistribuito": "redistribuire",
    "redistribuiva": "redistribuire",
    "redistribuivamo": "redistribuire",
    "redistribuivan": "redistribuire",
    "redistribuivano": "redistribuire",
    "redistribuivate": "redistribuire",
    "redistribuivi": "redistribuire",
    "redistribuivo": "redistribuire",
    "redistribuo": "redistribuire",
    "redistribuon": "redistribuire",
    "redistribuono": "redistribuire",
    "redistribuzioni": "redistribuzione",
    "redistribuì": "redistribuire",
    "rediviva": "redivivo",
    "redivive": "redivivo",
    "redivivi": "redivivo",
    "reduci": "reduce",
    "ree": "reo",
    "referendari": "referendario",
    "referendaria": "referendario",
    "referendarie": "referendario",
    "referenti": "referente",
    "referenze": "referenza",
    "referenzi": "referenziare",
    "referenzia": "referenziare",
    "referenziai": "referenziare",
    "referenziammo": "referenziare",
    "referenziamo": "referenziare",
    "referenzian": "referenziare",
    "referenziando": "referenziare",
    "referenziano": "referenziare",
    "referenziante": "referenziare",
    "referenzianti": "referenziare",
    "referenziar": "referenziare",
    "referenziaron": "referenziare",
    "referenziarono": "referenziare",
    "referenziasse": "referenziare",
    "referenziasser": "referenziare",
    "referenziassero": "referenziare",
    "referenziassi": "referenziare",
    "referenziassimo": "referenziare",
    "referenziaste": "referenziare",
    "referenziasti": "referenziare",
    "referenziata": "referenziare",
    "referenziate": "referenziare",
    "referenziati": "referenziare",
    "referenziato": "referenziare",
    "referenziava": "referenziare",
    "referenziavamo": "referenziare",
    "referenziavan": "referenziare",
    "referenziavano": "referenziare",
    "referenziavate": "referenziare",
    "referenziavi": "referenziare",
    "referenziavo": "referenziare",
    "referenzierai": "referenziare",
    "referenzieran": "referenziare",
    "referenzieranno": "referenziare",
    "referenzierebbe": "referenziare",
    "referenzierebber": "referenziare",
    "referenzierebbero": "referenziare",
    "referenzierei": "referenziare",
    "referenzieremmo": "referenziare",
    "referenzieremo": "referenziare",
    "referenziereste": "referenziare",
    "referenzieresti": "referenziare",
    "referenzierete": "referenziare",
    "referenzierà": "referenziare",
    "referenzierò": "referenziare",
    "referenzin": "referenziare",
    "referenzino": "referenziare",
    "referenzio": "referenziare",
    "referenziò": "referenziare",
    "referti": "referto",
    "refettori": "refettorio",
    "refezioni": "refezione",
    "reflua": "refluo",
    "reflue": "refluo",
    "reflui": "refluo",
    "refoli": "refolo",
    "refrattari": "refrattario",
    "refrattaria": "refrattario",
    "refrattarie": "refrattario",
    "refrigera": "refrigerare",
    "refrigerai": "refrigerare",
    "refrigerammo": "refrigerare",
    "refrigeran": "refrigerare",
    "refrigerando": "refrigerare",
    "refrigerano": "refrigerare",
    "refrigerante": "refrigerare",
    "refrigeranti": "refrigerare",
    "refrigerar": "refrigerare",
    "refrigeraron": "refrigerare",
    "refrigerarono": "refrigerare",
    "refrigerasse": "refrigerare",
    "refrigerasser": "refrigerare",
    "refrigerassero": "refrigerare",
    "refrigerassi": "refrigerare",
    "refrigerassimo": "refrigerare",
    "refrigeraste": "refrigerare",
    "refrigerasti": "refrigerare",
    "refrigerata": "refrigerare",
    "refrigerate": "refrigerare",
    "refrigerati": "refrigerare",
    "refrigerato": "refrigerare",
    "refrigerava": "refrigerare",
    "refrigeravamo": "refrigerare",
    "refrigeravan": "refrigerare",
    "refrigeravano": "refrigerare",
    "refrigeravate": "refrigerare",
    "refrigeravi": "refrigerare",
    "refrigeravo": "refrigerare",
    "refrigererai": "refrigerare",
    "refrigereran": "refrigerare",
    "refrigereranno": "refrigerare",
    "refrigererebbe": "refrigerare",
    "refrigererebber": "refrigerare",
    "refrigererebbero": "refrigerare",
    "refrigererei": "refrigerare",
    "refrigereremmo": "refrigerare",
    "refrigereremo": "refrigerare",
    "refrigerereste": "refrigerare",
    "refrigereresti": "refrigerare",
    "refrigererete": "refrigerare",
    "refrigererà": "refrigerare",
    "refrigererò": "refrigerare",
    "refrigeri": "refrigerare",
    "refrigeriamo": "refrigerare",
    "refrigeriate": "refrigerare",
    "refrigerin": "refrigerare",
    "refrigerino": "refrigerare",
    "refrigero": "refrigerare",
    "refrigerò": "refrigerare",
    "refurtive": "refurtiva",
    "refusi": "refuso",
    "regala": "regalare",
    "regalai": "regalare",
    "regalammo": "regalare",
    "regalan": "regalare",
    "regalando": "regalare",
    "regalano": "regalare",
    "regalante": "regalare",
    "regalanti": "regalare",
    "regalar": "regalare",
    "regalaron": "regalare",
    "regalarono": "regalare",
    "regalasse": "regalare",
    "regalasser": "regalare",
    "regalassero": "regalare",
    "regalassi": "regalare",
    "regalassimo": "regalare",
    "regalaste": "regalare",
    "regalasti": "regalare",
    "regalata": "regalare",
    "regalate": "regalare",
    "regalati": "regalare",
    "regalato": "regalare",
    "regalava": "regalare",
    "regalavamo": "regalare",
    "regalavan": "regalare",
    "regalavano": "regalare",
    "regalavate": "regalare",
    "regalavi": "regalare",
    "regalavo": "regalare",
    "regalerai": "regalare",
    "regaleran": "regalare",
    "regaleranno": "regalare",
    "regalerebbe": "regalare",
    "regalerebber": "regalare",
    "regalerebbero": "regalare",
    "regalerei": "regalare",
    "regaleremmo": "regalare",
    "regaleremo": "regalare",
    "regalereste": "regalare",
    "regaleresti": "regalare",
    "regalerete": "regalare",
    "regalerà": "regalare",
    "regalerò": "regalare",
    "regali": "regalo",
    "regaliamo": "regalare",
    "regaliate": "regalare",
    "regalie": "regalia",
    "regalin": "regalare",
    "regalini": "regalino",
    "regalino": "regalare",
    "regalo": "regalare",
    "regalò": "regalare",
    "regata": "regatare",
    "regatai": "regatare",
    "regatammo": "regatare",
    "regatan": "regatare",
    "regatando": "regatare",
    "regatano": "regatare",
    "regatante": "regatare",
    "regatanti": "regatare",
    "regatar": "regatare",
    "regataron": "regatare",
    "regatarono": "regatare",
    "regatasse": "regatare",
    "regatasser": "regatare",
    "regatassero": "regatare",
    "regatassi": "regatare",
    "regatassimo": "regatare",
    "regataste": "regatare",
    "regatasti": "regatare",
    "regatata": "regatare",
    "regatate": "regatare",
    "regatati": "regatare",
    "regatato": "regatare",
    "regatava": "regatare",
    "regatavamo": "regatare",
    "regatavan": "regatare",
    "regatavano": "regatare",
    "regatavate": "regatare",
    "regatavi": "regatare",
    "regatavo": "regatare",
    "regate": "regata",
    "regaterai": "regatare",
    "regateran": "regatare",
    "regateranno": "regatare",
    "regaterebbe": "regatare",
    "regaterebber": "regatare",
    "regaterebbero": "regatare",
    "regaterei": "regatare",
    "regateremmo": "regatare",
    "regateremo": "regatare",
    "regatereste": "regatare",
    "regateresti": "regatare",
    "regaterete": "regatare",
    "regaterà": "regatare",
    "regaterò": "regatare",
    "regati": "regatare",
    "regatiamo": "regatare",
    "regatiate": "regatare",
    "regatin": "regatare",
    "regatino": "regatare",
    "regato": "regatare",
    "regatò": "regatare",
    "regga": "reggere",
    "reggan": "reggere",
    "reggano": "reggere",
    "regge": "reggia",
    "reggemmo": "reggere",
    "reggendo": "reggere",
    "reggente": "reggere",
    "reggenti": "reggere",
    "reggenze": "reggenza",
    "regger": "reggere",
    "reggerai": "reggere",
    "reggeran": "reggere",
    "reggeranno": "reggere",
    "reggerebbe": "reggere",
    "reggerebber": "reggere",
    "reggerebbero": "reggere",
    "reggerei": "reggere",
    "reggeremmo": "reggere",
    "reggeremo": "reggere",
    "reggereste": "reggere",
    "reggeresti": "reggere",
    "reggerete": "reggere",
    "reggerà": "reggere",
    "reggerò": "reggere",
    "reggesse": "reggere",
    "reggesser": "reggere",
    "reggessero": "reggere",
    "reggessi": "reggere",
    "reggessimo": "reggere",
    "reggeste": "reggere",
    "reggesti": "reggere",
    "reggete": "reggere",
    "reggeva": "reggere",
    "reggevamo": "reggere",
    "reggevan": "reggere",
    "reggevano": "reggere",
    "reggevate": "reggere",
    "reggevi": "reggere",
    "reggevo": "reggere",
    "reggi": "reggere",
    "reggiamo": "reggere",
    "reggiana": "reggiano",
    "reggiane": "reggiano",
    "reggiani": "reggiano",
    "reggiate": "reggere",
    "reggimenti": "reggimento",
    "reggina": "reggino",
    "reggine": "reggino",
    "reggini": "reggino",
    "reggipetti": "reggipetto",
    "reggiseni": "reggiseno",
    "reggitori": "reggitore",
    "reggo": "reggere",
    "reggon": "reggere",
    "reggono": "reggere",
    "regi": "regio",
    "regia": "regio",
    "regicidi": "regicidio",
    "regie": "regio",
    "regimi": "regime",
    "regine": "regina",
    "reginette": "reginetta",
    "regionali": "regionale",
    "regionalismi": "regionalismo",
    "regionaliste": "regionalista",
    "regionalisti": "regionalista",
    "regionalistica": "regionalistico",
    "regionalistiche": "regionalistico",
    "regionalistici": "regionalistico",
    "regionalizza": "regionalizzare",
    "regionalizzai": "regionalizzare",
    "regionalizzammo": "regionalizzare",
    "regionalizzan": "regionalizzare",
    "regionalizzando": "regionalizzare",
    "regionalizzano": "regionalizzare",
    "regionalizzante": "regionalizzare",
    "regionalizzanti": "regionalizzare",
    "regionalizzar": "regionalizzare",
    "regionalizzaron": "regionalizzare",
    "regionalizzarono": "regionalizzare",
    "regionalizzasse": "regionalizzare",
    "regionalizzasser": "regionalizzare",
    "regionalizzassero": "regionalizzare",
    "regionalizzassi": "regionalizzare",
    "regionalizzassimo": "regionalizzare",
    "regionalizzaste": "regionalizzare",
    "regionalizzasti": "regionalizzare",
    "regionalizzata": "regionalizzare",
    "regionalizzate": "regionalizzare",
    "regionalizzati": "regionalizzare",
    "regionalizzato": "regionalizzare",
    "regionalizzava": "regionalizzare",
    "regionalizzavamo": "regionalizzare",
    "regionalizzavan": "regionalizzare",
    "regionalizzavano": "regionalizzare",
    "regionalizzavate": "regionalizzare",
    "regionalizzavi": "regionalizzare",
    "regionalizzavo": "regionalizzare",
    "regionalizzazioni": "regionalizzazione",
    "regionalizzerai": "regionalizzare",
    "regionalizzeran": "regionalizzare",
    "regionalizzeranno": "regionalizzare",
    "regionalizzerebbe": "regionalizzare",
    "regionalizzerebber": "regionalizzare",
    "regionalizzerebbero": "regionalizzare",
    "regionalizzerei": "regionalizzare",
    "regionalizzeremmo": "regionalizzare",
    "regionalizzeremo": "regionalizzare",
    "regionalizzereste": "regionalizzare",
    "regionalizzeresti": "regionalizzare",
    "regionalizzerete": "regionalizzare",
    "regionalizzerà": "regionalizzare",
    "regionalizzerò": "regionalizzare",
    "regionalizzi": "regionalizzare",
    "regionalizziamo": "regionalizzare",
    "regionalizziate": "regionalizzare",
    "regionalizzin": "regionalizzare",
    "regionalizzino": "regionalizzare",
    "regionalizzo": "regionalizzare",
    "regionalizzò": "regionalizzare",
    "regioni": "regione",
    "registe": "regista",
    "registi": "regista",
    "registra": "registrare",
    "registrai": "registrare",
    "registrammo": "registrare",
    "registran": "registrare",
    "registrando": "registrare",
    "registrano": "registrare",
    "registrante": "registrare",
    "registranti": "registrare",
    "registrar": "registrare",
    "registraron": "registrare",
    "registrarono": "registrare",
    "registrasse": "registrare",
    "registrasser": "registrare",
    "registrassero": "registrare",
    "registrassi": "registrare",
    "registrassimo": "registrare",
    "registraste": "registrare",
    "registrasti": "registrare",
    "registrata": "registrare",
    "registrate": "registrare",
    "registrati": "registrare",
    "registrato": "registrare",
    "registratori": "registratore",
    "registratrice": "registratore",
    "registratrici": "registratore",
    "registrava": "registrare",
    "registravamo": "registrare",
    "registravan": "registrare",
    "registravano": "registrare",
    "registravate": "registrare",
    "registravi": "registrare",
    "registravo": "registrare",
    "registrazioni": "registrazione",
    "registrerai": "registrare",
    "registreran": "registrare",
    "registreranno": "registrare",
    "registrerebbe": "registrare",
    "registrerebber": "registrare",
    "registrerebbero": "registrare",
    "registrerei": "registrare",
    "registreremmo": "registrare",
    "registreremo": "registrare",
    "registrereste": "registrare",
    "registreresti": "registrare",
    "registrerete": "registrare",
    "registrerà": "registrare",
    "registrerò": "registrare",
    "registri": "registro",
    "registriamo": "registrare",
    "registriate": "registrare",
    "registrin": "registrare",
    "registrino": "registrare",
    "registro": "registrare",
    "registrò": "registrare",
    "regna": "regnare",
    "regnai": "regnare",
    "regnammo": "regnare",
    "regnan": "regnare",
    "regnando": "regnare",
    "regnano": "regnare",
    "regnante": "regnare",
    "regnanti": "regnare",
    "regnar": "regnare",
    "regnaron": "regnare",
    "regnarono": "regnare",
    "regnasse": "regnare",
    "regnasser": "regnare",
    "regnassero": "regnare",
    "regnassi": "regnare",
    "regnassimo": "regnare",
    "regnaste": "regnare",
    "regnasti": "regnare",
    "regnata": "regnare",
    "regnate": "regnare",
    "regnati": "regnare",
    "regnato": "regnare",
    "regnava": "regnare",
    "regnavamo": "regnare",
    "regnavan": "regnare",
    "regnavano": "regnare",
    "regnavate": "regnare",
    "regnavi": "regnare",
    "regnavo": "regnare",
    "regnerai": "regnare",
    "regneran": "regnare",
    "regneranno": "regnare",
    "regnerebbe": "regnare",
    "regnerebber": "regnare",
    "regnerebbero": "regnare",
    "regnerei": "regnare",
    "regneremmo": "regnare",
    "regneremo": "regnare",
    "regnereste": "regnare",
    "regneresti": "regnare",
    "regnerete": "regnare",
    "regnerà": "regnare",
    "regnerò": "regnare",
    "regni": "regno",
    "regniamo": "regnare",
    "regniate": "regnare",
    "regnin": "regnare",
    "regnino": "regnare",
    "regno": "regnare",
    "regnò": "regnare",
    "regola": "regolare",
    "regolabili": "regolabile",
    "regolai": "regolare",
    "regolamenta": "regolamentare",
    "regolamentai": "regolamentare",
    "regolamentammo": "regolamentare",
    "regolamentan": "regolamentare",
    "regolamentando": "regolamentare",
    "regolamentano": "regolamentare",
    "regolamentante": "regolamentare",
    "regolamentanti": "regolamentare",
    "regolamentar": "regolamentare",
    "regolamentari": "regolamentare",
    "regolamentaron": "regolamentare",
    "regolamentarono": "regolamentare",
    "regolamentasse": "regolamentare",
    "regolamentasser": "regolamentare",
    "regolamentassero": "regolamentare",
    "regolamentassi": "regolamentare",
    "regolamentassimo": "regolamentare",
    "regolamentaste": "regolamentare",
    "regolamentasti": "regolamentare",
    "regolamentata": "regolamentare",
    "regolamentate": "regolamentare",
    "regolamentati": "regolamentare",
    "regolamentato": "regolamentare",
    "regolamentava": "regolamentare",
    "regolamentavamo": "regolamentare",
    "regolamentavan": "regolamentare",
    "regolamentavano": "regolamentare",
    "regolamentavate": "regolamentare",
    "regolamentavi": "regolamentare",
    "regolamentavo": "regolamentare",
    "regolamentazioni": "regolamentazione",
    "regolamenterai": "regolamentare",
    "regolamenteran": "regolamentare",
    "regolamenteranno": "regolamentare",
    "regolamenterebbe": "regolamentare",
    "regolamenterebber": "regolamentare",
    "regolamenterebbero": "regolamentare",
    "regolamenterei": "regolamentare",
    "regolamenteremmo": "regolamentare",
    "regolamenteremo": "regolamentare",
    "regolamentereste": "regolamentare",
    "regolamenteresti": "regolamentare",
    "regolamenterete": "regolamentare",
    "regolamenterà": "regolamentare",
    "regolamenterò": "regolamentare",
    "regolamenti": "regolamento",
    "regolamentiamo": "regolamentare",
    "regolamentiate": "regolamentare",
    "regolamentin": "regolamentare",
    "regolamentino": "regolamentare",
    "regolamento": "regolamentare",
    "regolamentò": "regolamentare",
    "regolammo": "regolare",
    "regolan": "regolare",
    "regolando": "regolare",
    "regolano": "regolare",
    "regolante": "regolare",
    "regolanti": "regolare",
    "regolar": "regolare",
    "regolari": "regolare",
    "regolaristi": "regolarista",
    "regolarizza": "regolarizzare",
    "regolarizzai": "regolarizzare",
    "regolarizzammo": "regolarizzare",
    "regolarizzan": "regolarizzare",
    "regolarizzando": "regolarizzare",
    "regolarizzano": "regolarizzare",
    "regolarizzante": "regolarizzare",
    "regolarizzanti": "regolarizzare",
    "regolarizzar": "regolarizzare",
    "regolarizzaron": "regolarizzare",
    "regolarizzarono": "regolarizzare",
    "regolarizzasse": "regolarizzare",
    "regolarizzasser": "regolarizzare",
    "regolarizzassero": "regolarizzare",
    "regolarizzassi": "regolarizzare",
    "regolarizzassimo": "regolarizzare",
    "regolarizzaste": "regolarizzare",
    "regolarizzasti": "regolarizzare",
    "regolarizzata": "regolarizzare",
    "regolarizzate": "regolarizzare",
    "regolarizzati": "regolarizzare",
    "regolarizzato": "regolarizzare",
    "regolarizzava": "regolarizzare",
    "regolarizzavamo": "regolarizzare",
    "regolarizzavan": "regolarizzare",
    "regolarizzavano": "regolarizzare",
    "regolarizzavate": "regolarizzare",
    "regolarizzavi": "regolarizzare",
    "regolarizzavo": "regolarizzare",
    "regolarizzazioni": "regolarizzazione",
    "regolarizzerai": "regolarizzare",
    "regolarizzeran": "regolarizzare",
    "regolarizzeranno": "regolarizzare",
    "regolarizzerebbe": "regolarizzare",
    "regolarizzerebber": "regolarizzare",
    "regolarizzerebbero": "regolarizzare",
    "regolarizzerei": "regolarizzare",
    "regolarizzeremmo": "regolarizzare",
    "regolarizzeremo": "regolarizzare",
    "regolarizzereste": "regolarizzare",
    "regolarizzeresti": "regolarizzare",
    "regolarizzerete": "regolarizzare",
    "regolarizzerà": "regolarizzare",
    "regolarizzerò": "regolarizzare",
    "regolarizzi": "regolarizzare",
    "regolarizziamo": "regolarizzare",
    "regolarizziate": "regolarizzare",
    "regolarizzin": "regolarizzare",
    "regolarizzino": "regolarizzare",
    "regolarizzo": "regolarizzare",
    "regolarizzò": "regolarizzare",
    "regolaron": "regolare",
    "regolarono": "regolare",
    "regolasse": "regolare",
    "regolasser": "regolare",
    "regolassero": "regolare",
    "regolassi": "regolare",
    "regolassimo": "regolare",
    "regolaste": "regolare",
    "regolasti": "regolare",
    "regolata": "regolato",
    "regolate": "regolato",
    "regolati": "regolato",
    "regolato": "regolare",
    "regolatori": "regolatore",
    "regolatrice": "regolatore",
    "regolatrici": "regolatore",
    "regolava": "regolare",
    "regolavamo": "regolare",
    "regolavan": "regolare",
    "regolavano": "regolare",
    "regolavate": "regolare",
    "regolavi": "regolare",
    "regolavo": "regolare",
    "regolazioni": "regolazione",
    "regole": "regola",
    "regolerai": "regolare",
    "regoleran": "regolare",
    "regoleranno": "regolare",
    "regolerebbe": "regolare",
    "regolerebber": "regolare",
    "regolerebbero": "regolare",
    "regolerei": "regolare",
    "regoleremmo": "regolare",
    "regoleremo": "regolare",
    "regolereste": "regolare",
    "regoleresti": "regolare",
    "regolerete": "regolare",
    "regolerà": "regolare",
    "regolerò": "regolare",
    "regolette": "regoletta",
    "regoli": "regolare",
    "regoliamo": "regolare",
    "regoliate": "regolare",
    "regolin": "regolare",
    "regolino": "regolare",
    "regolo": "regolare",
    "regolò": "regolare",
    "regredendo": "regredire",
    "regredente": "regredire",
    "regredenti": "regredire",
    "regrediamo": "regredire",
    "regrediate": "regredire",
    "regredii": "regredire",
    "regredimmo": "regredire",
    "regredir": "regredire",
    "regredirai": "regredire",
    "regrediran": "regredire",
    "regrediranno": "regredire",
    "regredirebbe": "regredire",
    "regredirebber": "regredire",
    "regredirebbero": "regredire",
    "regredirei": "regredire",
    "regrediremmo": "regredire",
    "regrediremo": "regredire",
    "regredireste": "regredire",
    "regrediresti": "regredire",
    "regredirete": "regredire",
    "regrediron": "regredire",
    "regredirono": "regredire",
    "regredirà": "regredire",
    "regredirò": "regredire",
    "regredisca": "regredire",
    "regrediscan": "regredire",
    "regrediscano": "regredire",
    "regredisce": "regredire",
    "regredisci": "regredire",
    "regredisco": "regredire",
    "regrediscon": "regredire",
    "regrediscono": "regredire",
    "regredisse": "regredire",
    "regredisser": "regredire",
    "regredissero": "regredire",
    "regredissi": "regredire",
    "regredissimo": "regredire",
    "regrediste": "regredire",
    "regredisti": "regredire",
    "regredita": "regredire",
    "regredite": "regredire",
    "regrediti": "regredire",
    "regredito": "regredire",
    "regrediva": "regredire",
    "regredivamo": "regredire",
    "regredivan": "regredire",
    "regredivano": "regredire",
    "regredivate": "regredire",
    "regredivi": "regredire",
    "regredivo": "regredire",
    "regredì": "regredire",
    "regressi": "regresso",
    "regressioni": "regressione",
    "regressiva": "regressivo",
    "regressive": "regressivo",
    "regressivi": "regressivo",
    "regìe": "regìa",
    "rei": "reo",
    "reietta": "reietto",
    "reiette": "reietto",
    "reietti": "reietto",
    "reimbarca": "reimbarcare",
    "reimbarcai": "reimbarcare",
    "reimbarcammo": "reimbarcare",
    "reimbarcan": "reimbarcare",
    "reimbarcando": "reimbarcare",
    "reimbarcano": "reimbarcare",
    "reimbarcante": "reimbarcare",
    "reimbarcanti": "reimbarcare",
    "reimbarcar": "reimbarcare",
    "reimbarcaron": "reimbarcare",
    "reimbarcarono": "reimbarcare",
    "reimbarcasse": "reimbarcare",
    "reimbarcasser": "reimbarcare",
    "reimbarcassero": "reimbarcare",
    "reimbarcassi": "reimbarcare",
    "reimbarcassimo": "reimbarcare",
    "reimbarcaste": "reimbarcare",
    "reimbarcasti": "reimbarcare",
    "reimbarcata": "reimbarcare",
    "reimbarcate": "reimbarcare",
    "reimbarcati": "reimbarcare",
    "reimbarcato": "reimbarcare",
    "reimbarcava": "reimbarcare",
    "reimbarcavamo": "reimbarcare",
    "reimbarcavan": "reimbarcare",
    "reimbarcavano": "reimbarcare",
    "reimbarcavate": "reimbarcare",
    "reimbarcavi": "reimbarcare",
    "reimbarcavo": "reimbarcare",
    "reimbarcherai": "reimbarcare",
    "reimbarcheran": "reimbarcare",
    "reimbarcheranno": "reimbarcare",
    "reimbarcherebbe": "reimbarcare",
    "reimbarcherebber": "reimbarcare",
    "reimbarcherebbero": "reimbarcare",
    "reimbarcherei": "reimbarcare",
    "reimbarcheremmo": "reimbarcare",
    "reimbarcheremo": "reimbarcare",
    "reimbarchereste": "reimbarcare",
    "reimbarcheresti": "reimbarcare",
    "reimbarcherete": "reimbarcare",
    "reimbarcherà": "reimbarcare",
    "reimbarcherò": "reimbarcare",
    "reimbarchi": "reimbarcare",
    "reimbarchiamo": "reimbarcare",
    "reimbarchiate": "reimbarcare",
    "reimbarchin": "reimbarcare",
    "reimbarchino": "reimbarcare",
    "reimbarco": "reimbarcare",
    "reimbarcò": "reimbarcare",
    "reimpiega": "reimpiegare",
    "reimpiegai": "reimpiegare",
    "reimpiegammo": "reimpiegare",
    "reimpiegan": "reimpiegare",
    "reimpiegando": "reimpiegare",
    "reimpiegano": "reimpiegare",
    "reimpiegante": "reimpiegare",
    "reimpieganti": "reimpiegare",
    "reimpiegar": "reimpiegare",
    "reimpiegaron": "reimpiegare",
    "reimpiegarono": "reimpiegare",
    "reimpiegasse": "reimpiegare",
    "reimpiegasser": "reimpiegare",
    "reimpiegassero": "reimpiegare",
    "reimpiegassi": "reimpiegare",
    "reimpiegassimo": "reimpiegare",
    "reimpiegaste": "reimpiegare",
    "reimpiegasti": "reimpiegare",
    "reimpiegata": "reimpiegare",
    "reimpiegate": "reimpiegare",
    "reimpiegati": "reimpiegare",
    "reimpiegato": "reimpiegare",
    "reimpiegava": "reimpiegare",
    "reimpiegavamo": "reimpiegare",
    "reimpiegavan": "reimpiegare",
    "reimpiegavano": "reimpiegare",
    "reimpiegavate": "reimpiegare",
    "reimpiegavi": "reimpiegare",
    "reimpiegavo": "reimpiegare",
    "reimpiegherai": "reimpiegare",
    "reimpiegheran": "reimpiegare",
    "reimpiegheranno": "reimpiegare",
    "reimpiegherebbe": "reimpiegare",
    "reimpiegherebber": "reimpiegare",
    "reimpiegherebbero": "reimpiegare",
    "reimpiegherei": "reimpiegare",
    "reimpiegheremmo": "reimpiegare",
    "reimpiegheremo": "reimpiegare",
    "reimpieghereste": "reimpiegare",
    "reimpiegheresti": "reimpiegare",
    "reimpiegherete": "reimpiegare",
    "reimpiegherà": "reimpiegare",
    "reimpiegherò": "reimpiegare",
    "reimpieghi": "reimpiegare",
    "reimpieghiamo": "reimpiegare",
    "reimpieghiate": "reimpiegare",
    "reimpieghin": "reimpiegare",
    "reimpieghino": "reimpiegare",
    "reimpiego": "reimpiegare",
    "reimpiegò": "reimpiegare",
    "reimporta": "reimportare",
    "reimportai": "reimportare",
    "reimportammo": "reimportare",
    "reimportan": "reimportare",
    "reimportando": "reimportare",
    "reimportano": "reimportare",
    "reimportante": "reimportare",
    "reimportanti": "reimportare",
    "reimportar": "reimportare",
    "reimportaron": "reimportare",
    "reimportarono": "reimportare",
    "reimportasse": "reimportare",
    "reimportasser": "reimportare",
    "reimportassero": "reimportare",
    "reimportassi": "reimportare",
    "reimportassimo": "reimportare",
    "reimportaste": "reimportare",
    "reimportasti": "reimportare",
    "reimportata": "reimportare",
    "reimportate": "reimportare",
    "reimportati": "reimportare",
    "reimportato": "reimportare",
    "reimportava": "reimportare",
    "reimportavamo": "reimportare",
    "reimportavan": "reimportare",
    "reimportavano": "reimportare",
    "reimportavate": "reimportare",
    "reimportavi": "reimportare",
    "reimportavo": "reimportare",
    "reimporterai": "reimportare",
    "reimporteran": "reimportare",
    "reimporteranno": "reimportare",
    "reimporterebbe": "reimportare",
    "reimporterebber": "reimportare",
    "reimporterebbero": "reimportare",
    "reimporterei": "reimportare",
    "reimporteremmo": "reimportare",
    "reimporteremo": "reimportare",
    "reimportereste": "reimportare",
    "reimporteresti": "reimportare",
    "reimporterete": "reimportare",
    "reimporterà": "reimportare",
    "reimporterò": "reimportare",
    "reimporti": "reimportare",
    "reimportiamo": "reimportare",
    "reimportiate": "reimportare",
    "reimportin": "reimportare",
    "reimportino": "reimportare",
    "reimporto": "reimportare",
    "reimportò": "reimportare",
    "reincarichi": "reincarico",
    "reincarna": "reincarnare",
    "reincarnai": "reincarnare",
    "reincarnammo": "reincarnare",
    "reincarnan": "reincarnare",
    "reincarnando": "reincarnare",
    "reincarnano": "reincarnare",
    "reincarnante": "reincarnare",
    "reincarnanti": "reincarnare",
    "reincarnar": "reincarnare",
    "reincarnaron": "reincarnare",
    "reincarnarono": "reincarnare",
    "reincarnasse": "reincarnare",
    "reincarnasser": "reincarnare",
    "reincarnassero": "reincarnare",
    "reincarnassi": "reincarnare",
    "reincarnassimo": "reincarnare",
    "reincarnaste": "reincarnare",
    "reincarnasti": "reincarnare",
    "reincarnata": "reincarnare",
    "reincarnate": "reincarnare",
    "reincarnati": "reincarnare",
    "reincarnato": "reincarnare",
    "reincarnava": "reincarnare",
    "reincarnavamo": "reincarnare",
    "reincarnavan": "reincarnare",
    "reincarnavano": "reincarnare",
    "reincarnavate": "reincarnare",
    "reincarnavi": "reincarnare",
    "reincarnavo": "reincarnare",
    "reincarnazioni": "reincarnazione",
    "reincarnerai": "reincarnare",
    "reincarneran": "reincarnare",
    "reincarneranno": "reincarnare",
    "reincarnerebbe": "reincarnare",
    "reincarnerebber": "reincarnare",
    "reincarnerebbero": "reincarnare",
    "reincarnerei": "reincarnare",
    "reincarneremmo": "reincarnare",
    "reincarneremo": "reincarnare",
    "reincarnereste": "reincarnare",
    "reincarneresti": "reincarnare",
    "reincarnerete": "reincarnare",
    "reincarnerà": "reincarnare",
    "reincarnerò": "reincarnare",
    "reincarni": "reincarnare",
    "reincarniamo": "reincarnare",
    "reincarniate": "reincarnare",
    "reincarnin": "reincarnare",
    "reincarnino": "reincarnare",
    "reincarno": "reincarnare",
    "reincarnò": "reincarnare",
    "reindustrializzazioni": "reindustrializzazione",
    "reingressi": "reingresso",
    "reinnesta": "reinnestare",
    "reinnestai": "reinnestare",
    "reinnestammo": "reinnestare",
    "reinnestan": "reinnestare",
    "reinnestando": "reinnestare",
    "reinnestano": "reinnestare",
    "reinnestante": "reinnestare",
    "reinnestanti": "reinnestare",
    "reinnestar": "reinnestare",
    "reinnestaron": "reinnestare",
    "reinnestarono": "reinnestare",
    "reinnestasse": "reinnestare",
    "reinnestasser": "reinnestare",
    "reinnestassero": "reinnestare",
    "reinnestassi": "reinnestare",
    "reinnestassimo": "reinnestare",
    "reinnestaste": "reinnestare",
    "reinnestasti": "reinnestare",
    "reinnestata": "reinnestare",
    "reinnestate": "reinnestare",
    "reinnestati": "reinnestare",
    "reinnestato": "reinnestare",
    "reinnestava": "reinnestare",
    "reinnestavamo": "reinnestare",
    "reinnestavan": "reinnestare",
    "reinnestavano": "reinnestare",
    "reinnestavate": "reinnestare",
    "reinnestavi": "reinnestare",
    "reinnestavo": "reinnestare",
    "reinnesterai": "reinnestare",
    "reinnesteran": "reinnestare",
    "reinnesteranno": "reinnestare",
    "reinnesterebbe": "reinnestare",
    "reinnesterebber": "reinnestare",
    "reinnesterebbero": "reinnestare",
    "reinnesterei": "reinnestare",
    "reinnesteremmo": "reinnestare",
    "reinnesteremo": "reinnestare",
    "reinnestereste": "reinnestare",
    "reinnesteresti": "reinnestare",
    "reinnesterete": "reinnestare",
    "reinnesterà": "reinnestare",
    "reinnesterò": "reinnestare",
    "reinnesti": "reinnestare",
    "reinnestiamo": "reinnestare",
    "reinnestiate": "reinnestare",
    "reinnestin": "reinnestare",
    "reinnestino": "reinnestare",
    "reinnesto": "reinnestare",
    "reinnestò": "reinnestare",
    "reinsedi": "reinsediare",
    "reinsedia": "reinsediare",
    "reinsediai": "reinsediare",
    "reinsediammo": "reinsediare",
    "reinsediamo": "reinsediare",
    "reinsedian": "reinsediare",
    "reinsediando": "reinsediare",
    "reinsediano": "reinsediare",
    "reinsediante": "reinsediare",
    "reinsedianti": "reinsediare",
    "reinsediar": "reinsediare",
    "reinsediaron": "reinsediare",
    "reinsediarono": "reinsediare",
    "reinsediasse": "reinsediare",
    "reinsediasser": "reinsediare",
    "reinsediassero": "reinsediare",
    "reinsediassi": "reinsediare",
    "reinsediassimo": "reinsediare",
    "reinsediaste": "reinsediare",
    "reinsediasti": "reinsediare",
    "reinsediata": "reinsediare",
    "reinsediate": "reinsediare",
    "reinsediati": "reinsediare",
    "reinsediato": "reinsediare",
    "reinsediava": "reinsediare",
    "reinsediavamo": "reinsediare",
    "reinsediavan": "reinsediare",
    "reinsediavano": "reinsediare",
    "reinsediavate": "reinsediare",
    "reinsediavi": "reinsediare",
    "reinsediavo": "reinsediare",
    "reinsedierai": "reinsediare",
    "reinsedieran": "reinsediare",
    "reinsedieranno": "reinsediare",
    "reinsedierebbe": "reinsediare",
    "reinsedierebber": "reinsediare",
    "reinsedierebbero": "reinsediare",
    "reinsedierei": "reinsediare",
    "reinsedieremmo": "reinsediare",
    "reinsedieremo": "reinsediare",
    "reinsediereste": "reinsediare",
    "reinsedieresti": "reinsediare",
    "reinsedierete": "reinsediare",
    "reinsedierà": "reinsediare",
    "reinsedierò": "reinsediare",
    "reinsedin": "reinsediare",
    "reinsedino": "reinsediare",
    "reinsedio": "reinsediare",
    "reinsediò": "reinsediare",
    "reinserendo": "reinserire",
    "reinserente": "reinserire",
    "reinserenti": "reinserire",
    "reinseriamo": "reinserire",
    "reinseriate": "reinserire",
    "reinserii": "reinserire",
    "reinserimenti": "reinserimento",
    "reinserimmo": "reinserire",
    "reinserir": "reinserire",
    "reinserirai": "reinserire",
    "reinseriran": "reinserire",
    "reinseriranno": "reinserire",
    "reinserirebbe": "reinserire",
    "reinserirebber": "reinserire",
    "reinserirebbero": "reinserire",
    "reinserirei": "reinserire",
    "reinseriremmo": "reinserire",
    "reinseriremo": "reinserire",
    "reinserireste": "reinserire",
    "reinseriresti": "reinserire",
    "reinserirete": "reinserire",
    "reinseriron": "reinserire",
    "reinserirono": "reinserire",
    "reinserirà": "reinserire",
    "reinserirò": "reinserire",
    "reinserisca": "reinserire",
    "reinseriscan": "reinserire",
    "reinseriscano": "reinserire",
    "reinserisce": "reinserire",
    "reinserisci": "reinserire",
    "reinserisco": "reinserire",
    "reinseriscon": "reinserire",
    "reinseriscono": "reinserire",
    "reinserisse": "reinserire",
    "reinserisser": "reinserire",
    "reinserissero": "reinserire",
    "reinserissi": "reinserire",
    "reinserissimo": "reinserire",
    "reinseriste": "reinserire",
    "reinseristi": "reinserire",
    "reinserita": "reinserire",
    "reinserite": "reinserire",
    "reinseriti": "reinserire",
    "reinserito": "reinserire",
    "reinseriva": "reinserire",
    "reinserivamo": "reinserire",
    "reinserivan": "reinserire",
    "reinserivano": "reinserire",
    "reinserivate": "reinserire",
    "reinserivi": "reinserire",
    "reinserivo": "reinserire",
    "reinserì": "reinserire",
    "reintegra": "reintegrare",
    "reintegrai": "reintegrare",
    "reintegrammo": "reintegrare",
    "reintegran": "reintegrare",
    "reintegrando": "reintegrare",
    "reintegrano": "reintegrare",
    "reintegrante": "reintegrare",
    "reintegranti": "reintegrare",
    "reintegrar": "reintegrare",
    "reintegraron": "reintegrare",
    "reintegrarono": "reintegrare",
    "reintegrasse": "reintegrare",
    "reintegrasser": "reintegrare",
    "reintegrassero": "reintegrare",
    "reintegrassi": "reintegrare",
    "reintegrassimo": "reintegrare",
    "reintegraste": "reintegrare",
    "reintegrasti": "reintegrare",
    "reintegrata": "reintegrare",
    "reintegrate": "reintegrare",
    "reintegrati": "reintegrare",
    "reintegrato": "reintegrare",
    "reintegratori": "reintegratore",
    "reintegrava": "reintegrare",
    "reintegravamo": "reintegrare",
    "reintegravan": "reintegrare",
    "reintegravano": "reintegrare",
    "reintegravate": "reintegrare",
    "reintegravi": "reintegrare",
    "reintegravo": "reintegrare",
    "reintegrazioni": "reintegrazione",
    "reintegrerai": "reintegrare",
    "reintegreran": "reintegrare",
    "reintegreranno": "reintegrare",
    "reintegrerebbe": "reintegrare",
    "reintegrerebber": "reintegrare",
    "reintegrerebbero": "reintegrare",
    "reintegrerei": "reintegrare",
    "reintegreremmo": "reintegrare",
    "reintegreremo": "reintegrare",
    "reintegrereste": "reintegrare",
    "reintegreresti": "reintegrare",
    "reintegrerete": "reintegrare",
    "reintegrerà": "reintegrare",
    "reintegrerò": "reintegrare",
    "reintegri": "reintegro",
    "reintegriamo": "reintegrare",
    "reintegriate": "reintegrare",
    "reintegrin": "reintegrare",
    "reintegrino": "reintegrare",
    "reintegro": "reintegrare",
    "reintegrò": "reintegrare",
    "reinterpreta": "reinterpretare",
    "reinterpretai": "reinterpretare",
    "reinterpretammo": "reinterpretare",
    "reinterpretan": "reinterpretare",
    "reinterpretando": "reinterpretare",
    "reinterpretano": "reinterpretare",
    "reinterpretante": "reinterpretare",
    "reinterpretanti": "reinterpretare",
    "reinterpretar": "reinterpretare",
    "reinterpretaron": "reinterpretare",
    "reinterpretarono": "reinterpretare",
    "reinterpretasse": "reinterpretare",
    "reinterpretasser": "reinterpretare",
    "reinterpretassero": "reinterpretare",
    "reinterpretassi": "reinterpretare",
    "reinterpretassimo": "reinterpretare",
    "reinterpretaste": "reinterpretare",
    "reinterpretasti": "reinterpretare",
    "reinterpretata": "reinterpretare",
    "reinterpretate": "reinterpretare",
    "reinterpretati": "reinterpretare",
    "reinterpretato": "reinterpretare",
    "reinterpretava": "reinterpretare",
    "reinterpretavamo": "reinterpretare",
    "reinterpretavan": "reinterpretare",
    "reinterpretavano": "reinterpretare",
    "reinterpretavate": "reinterpretare",
    "reinterpretavi": "reinterpretare",
    "reinterpretavo": "reinterpretare",
    "reinterpretazioni": "reinterpretazione",
    "reinterpreterai": "reinterpretare",
    "reinterpreteran": "reinterpretare",
    "reinterpreteranno": "reinterpretare",
    "reinterpreterebbe": "reinterpretare",
    "reinterpreterebber": "reinterpretare",
    "reinterpreterebbero": "reinterpretare",
    "reinterpreterei": "reinterpretare",
    "reinterpreteremmo": "reinterpretare",
    "reinterpreteremo": "reinterpretare",
    "reinterpretereste": "reinterpretare",
    "reinterpreteresti": "reinterpretare",
    "reinterpreterete": "reinterpretare",
    "reinterpreterà": "reinterpretare",
    "reinterpreterò": "reinterpretare",
    "reinterpreti": "reinterpretare",
    "reinterpretiamo": "reinterpretare",
    "reinterpretiate": "reinterpretare",
    "reinterpretin": "reinterpretare",
    "reinterpretino": "reinterpretare",
    "reinterpreto": "reinterpretare",
    "reinterpretò": "reinterpretare",
    "reintroduzioni": "reintroduzione",
    "reinventa": "reinventare",
    "reinventai": "reinventare",
    "reinventammo": "reinventare",
    "reinventan": "reinventare",
    "reinventando": "reinventare",
    "reinventano": "reinventare",
    "reinventante": "reinventare",
    "reinventanti": "reinventare",
    "reinventar": "reinventare",
    "reinventaron": "reinventare",
    "reinventarono": "reinventare",
    "reinventasse": "reinventare",
    "reinventasser": "reinventare",
    "reinventassero": "reinventare",
    "reinventassi": "reinventare",
    "reinventassimo": "reinventare",
    "reinventaste": "reinventare",
    "reinventasti": "reinventare",
    "reinventata": "reinventare",
    "reinventate": "reinventare",
    "reinventati": "reinventare",
    "reinventato": "reinventare",
    "reinventava": "reinventare",
    "reinventavamo": "reinventare",
    "reinventavan": "reinventare",
    "reinventavano": "reinventare",
    "reinventavate": "reinventare",
    "reinventavi": "reinventare",
    "reinventavo": "reinventare",
    "reinventerai": "reinventare",
    "reinventeran": "reinventare",
    "reinventeranno": "reinventare",
    "reinventerebbe": "reinventare",
    "reinventerebber": "reinventare",
    "reinventerebbero": "reinventare",
    "reinventerei": "reinventare",
    "reinventeremmo": "reinventare",
    "reinventeremo": "reinventare",
    "reinventereste": "reinventare",
    "reinventeresti": "reinventare",
    "reinventerete": "reinventare",
    "reinventerà": "reinventare",
    "reinventerò": "reinventare",
    "reinventi": "reinventare",
    "reinventiamo": "reinventare",
    "reinventiate": "reinventare",
    "reinventin": "reinventare",
    "reinventino": "reinventare",
    "reinvento": "reinventare",
    "reinventò": "reinventare",
    "reinvenzioni": "reinvenzione",
    "reinvesta": "reinvestire",
    "reinvestan": "reinvestire",
    "reinvestano": "reinvestire",
    "reinveste": "reinvestire",
    "reinvestendo": "reinvestire",
    "reinvestente": "reinvestire",
    "reinvestenti": "reinvestire",
    "reinvesti": "reinvestire",
    "reinvestiamo": "reinvestire",
    "reinvestiate": "reinvestire",
    "reinvestii": "reinvestire",
    "reinvestimenti": "reinvestimento",
    "reinvestimmo": "reinvestire",
    "reinvestir": "reinvestire",
    "reinvestirai": "reinvestire",
    "reinvestiran": "reinvestire",
    "reinvestiranno": "reinvestire",
    "reinvestirebbe": "reinvestire",
    "reinvestirebber": "reinvestire",
    "reinvestirebbero": "reinvestire",
    "reinvestirei": "reinvestire",
    "reinvestiremmo": "reinvestire",
    "reinvestiremo": "reinvestire",
    "reinvestireste": "reinvestire",
    "reinvestiresti": "reinvestire",
    "reinvestirete": "reinvestire",
    "reinvestiron": "reinvestire",
    "reinvestirono": "reinvestire",
    "reinvestirà": "reinvestire",
    "reinvestirò": "reinvestire",
    "reinvestisse": "reinvestire",
    "reinvestisser": "reinvestire",
    "reinvestissero": "reinvestire",
    "reinvestissi": "reinvestire",
    "reinvestissimo": "reinvestire",
    "reinvestiste": "reinvestire",
    "reinvestisti": "reinvestire",
    "reinvestita": "reinvestire",
    "reinvestite": "reinvestire",
    "reinvestiti": "reinvestire",
    "reinvestito": "reinvestire",
    "reinvestiva": "reinvestire",
    "reinvestivamo": "reinvestire",
    "reinvestivan": "reinvestire",
    "reinvestivano": "reinvestire",
    "reinvestivate": "reinvestire",
    "reinvestivi": "reinvestire",
    "reinvestivo": "reinvestire",
    "reinvesto": "reinvestire",
    "reinveston": "reinvestire",
    "reinvestono": "reinvestire",
    "reinvestì": "reinvestire",
    "reiscriva": "reiscrivere",
    "reiscrivan": "reiscrivere",
    "reiscrivano": "reiscrivere",
    "reiscrive": "reiscrivere",
    "reiscrivei": "reiscrivere",
    "reiscrivemmo": "reiscrivere",
    "reiscrivendo": "reiscrivere",
    "reiscrivente": "reiscrivere",
    "reiscriventi": "reiscrivere",
    "reiscriver": "reiscrivere",
    "reiscriverai": "reiscrivere",
    "reiscriveran": "reiscrivere",
    "reiscriveranno": "reiscrivere",
    "reiscriverebbe": "reiscrivere",
    "reiscriverebber": "reiscrivere",
    "reiscriverebbero": "reiscrivere",
    "reiscriverei": "reiscrivere",
    "reiscriveremmo": "reiscrivere",
    "reiscriveremo": "reiscrivere",
    "reiscrivereste": "reiscrivere",
    "reiscriveresti": "reiscrivere",
    "reiscriverete": "reiscrivere",
    "reiscriveron": "reiscrivere",
    "reiscriverono": "reiscrivere",
    "reiscriverà": "reiscrivere",
    "reiscriverò": "reiscrivere",
    "reiscrivesse": "reiscrivere",
    "reiscrivesser": "reiscrivere",
    "reiscrivessero": "reiscrivere",
    "reiscrivessi": "reiscrivere",
    "reiscrivessimo": "reiscrivere",
    "reiscriveste": "reiscrivere",
    "reiscrivesti": "reiscrivere",
    "reiscrivete": "reiscrivere",
    "reiscriveva": "reiscrivere",
    "reiscrivevamo": "reiscrivere",
    "reiscrivevan": "reiscrivere",
    "reiscrivevano": "reiscrivere",
    "reiscrivevate": "reiscrivere",
    "reiscrivevi": "reiscrivere",
    "reiscrivevo": "reiscrivere",
    "reiscrivi": "reiscrivere",
    "reiscriviamo": "reiscrivere",
    "reiscriviate": "reiscrivere",
    "reiscrivo": "reiscrivere",
    "reiscrivon": "reiscrivere",
    "reiscrivono": "reiscrivere",
    "reiscrivuta": "reiscrivere",
    "reiscrivute": "reiscrivere",
    "reiscrivuti": "reiscrivere",
    "reiscrivuto": "reiscrivere",
    "reiscrivè": "reiscrivere",
    "reitera": "reiterare",
    "reiterai": "reiterare",
    "reiterammo": "reiterare",
    "reiteran": "reiterare",
    "reiterando": "reiterare",
    "reiterano": "reiterare",
    "reiterante": "reiterare",
    "reiteranti": "reiterare",
    "reiterar": "reiterare",
    "reiteraron": "reiterare",
    "reiterarono": "reiterare",
    "reiterasse": "reiterare",
    "reiterasser": "reiterare",
    "reiterassero": "reiterare",
    "reiterassi": "reiterare",
    "reiterassimo": "reiterare",
    "reiteraste": "reiterare",
    "reiterasti": "reiterare",
    "reiterata": "reiterato",
    "reiterate": "reiterato",
    "reiterati": "reiterato",
    "reiterato": "reiterare",
    "reiterava": "reiterare",
    "reiteravamo": "reiterare",
    "reiteravan": "reiterare",
    "reiteravano": "reiterare",
    "reiteravate": "reiterare",
    "reiteravi": "reiterare",
    "reiteravo": "reiterare",
    "reiterazioni": "reiterazione",
    "reitererai": "reiterare",
    "reitereran": "reiterare",
    "reitereranno": "reiterare",
    "reitererebbe": "reiterare",
    "reitererebber": "reiterare",
    "reitererebbero": "reiterare",
    "reitererei": "reiterare",
    "reitereremmo": "reiterare",
    "reitereremo": "reiterare",
    "reiterereste": "reiterare",
    "reitereresti": "reiterare",
    "reitererete": "reiterare",
    "reitererà": "reiterare",
    "reitererò": "reiterare",
    "reiteri": "reiterare",
    "reiteriamo": "reiterare",
    "reiteriate": "reiterare",
    "reiterin": "reiterare",
    "reiterino": "reiterare",
    "reitero": "reiterare",
    "reiterò": "reiterare",
    "relativa": "relativo",
    "relative": "relativo",
    "relativi": "relativo",
    "relativismi": "relativismo",
    "relativistica": "relativistico",
    "relativistiche": "relativistico",
    "relativistici": "relativistico",
    "relativizza": "relativizzare",
    "relativizzai": "relativizzare",
    "relativizzammo": "relativizzare",
    "relativizzan": "relativizzare",
    "relativizzando": "relativizzare",
    "relativizzano": "relativizzare",
    "relativizzante": "relativizzare",
    "relativizzanti": "relativizzare",
    "relativizzar": "relativizzare",
    "relativizzaron": "relativizzare",
    "relativizzarono": "relativizzare",
    "relativizzasse": "relativizzare",
    "relativizzasser": "relativizzare",
    "relativizzassero": "relativizzare",
    "relativizzassi": "relativizzare",
    "relativizzassimo": "relativizzare",
    "relativizzaste": "relativizzare",
    "relativizzasti": "relativizzare",
    "relativizzata": "relativizzare",
    "relativizzate": "relativizzare",
    "relativizzati": "relativizzare",
    "relativizzato": "relativizzare",
    "relativizzava": "relativizzare",
    "relativizzavamo": "relativizzare",
    "relativizzavan": "relativizzare",
    "relativizzavano": "relativizzare",
    "relativizzavate": "relativizzare",
    "relativizzavi": "relativizzare",
    "relativizzavo": "relativizzare",
    "relativizzerai": "relativizzare",
    "relativizzeran": "relativizzare",
    "relativizzeranno": "relativizzare",
    "relativizzerebbe": "relativizzare",
    "relativizzerebber": "relativizzare",
    "relativizzerebbero": "relativizzare",
    "relativizzerei": "relativizzare",
    "relativizzeremmo": "relativizzare",
    "relativizzeremo": "relativizzare",
    "relativizzereste": "relativizzare",
    "relativizzeresti": "relativizzare",
    "relativizzerete": "relativizzare",
    "relativizzerà": "relativizzare",
    "relativizzerò": "relativizzare",
    "relativizzi": "relativizzare",
    "relativizziamo": "relativizzare",
    "relativizziate": "relativizzare",
    "relativizzin": "relativizzare",
    "relativizzino": "relativizzare",
    "relativizzo": "relativizzare",
    "relativizzò": "relativizzare",
    "relatori": "relatore",
    "relatrici": "relatrice",
    "relaziona": "relazionare",
    "relazionai": "relazionare",
    "relazionammo": "relazionare",
    "relazionan": "relazionare",
    "relazionando": "relazionare",
    "relazionano": "relazionare",
    "relazionante": "relazionare",
    "relazionanti": "relazionare",
    "relazionar": "relazionare",
    "relazionaron": "relazionare",
    "relazionarono": "relazionare",
    "relazionasse": "relazionare",
    "relazionasser": "relazionare",
    "relazionassero": "relazionare",
    "relazionassi": "relazionare",
    "relazionassimo": "relazionare",
    "relazionaste": "relazionare",
    "relazionasti": "relazionare",
    "relazionata": "relazionare",
    "relazionate": "relazionare",
    "relazionati": "relazionare",
    "relazionato": "relazionare",
    "relazionava": "relazionare",
    "relazionavamo": "relazionare",
    "relazionavan": "relazionare",
    "relazionavano": "relazionare",
    "relazionavate": "relazionare",
    "relazionavi": "relazionare",
    "relazionavo": "relazionare",
    "relazionerai": "relazionare",
    "relazioneran": "relazionare",
    "relazioneranno": "relazionare",
    "relazionerebbe": "relazionare",
    "relazionerebber": "relazionare",
    "relazionerebbero": "relazionare",
    "relazionerei": "relazionare",
    "relazioneremmo": "relazionare",
    "relazioneremo": "relazionare",
    "relazionereste": "relazionare",
    "relazioneresti": "relazionare",
    "relazionerete": "relazionare",
    "relazionerà": "relazionare",
    "relazionerò": "relazionare",
    "relazioni": "relazione",
    "relazioniamo": "relazionare",
    "relazioniate": "relazionare",
    "relazionin": "relazionare",
    "relazionino": "relazionare",
    "relaziono": "relazionare",
    "relazionò": "relazionare",
    "relega": "relegare",
    "relegai": "relegare",
    "relegammo": "relegare",
    "relegan": "relegare",
    "relegando": "relegare",
    "relegano": "relegare",
    "relegante": "relegare",
    "releganti": "relegare",
    "relegar": "relegare",
    "relegaron": "relegare",
    "relegarono": "relegare",
    "relegasse": "relegare",
    "relegasser": "relegare",
    "relegassero": "relegare",
    "relegassi": "relegare",
    "relegassimo": "relegare",
    "relegaste": "relegare",
    "relegasti": "relegare",
    "relegata": "relegato",
    "relegate": "relegato",
    "relegati": "relegato",
    "relegato": "relegare",
    "relegava": "relegare",
    "relegavamo": "relegare",
    "relegavan": "relegare",
    "relegavano": "relegare",
    "relegavate": "relegare",
    "relegavi": "relegare",
    "relegavo": "relegare",
    "relegherai": "relegare",
    "relegheran": "relegare",
    "relegheranno": "relegare",
    "relegherebbe": "relegare",
    "relegherebber": "relegare",
    "relegherebbero": "relegare",
    "relegherei": "relegare",
    "relegheremmo": "relegare",
    "relegheremo": "relegare",
    "releghereste": "relegare",
    "relegheresti": "relegare",
    "relegherete": "relegare",
    "relegherà": "relegare",
    "relegherò": "relegare",
    "releghi": "relegare",
    "releghiamo": "relegare",
    "releghiate": "relegare",
    "releghin": "relegare",
    "releghino": "relegare",
    "relego": "relegare",
    "relegò": "relegare",
    "religioni": "religione",
    "religiosa": "religioso",
    "religiose": "religioso",
    "religiosi": "religioso",
    "reliquiari": "reliquiario",
    "reliquie": "reliquia",
    "relitti": "relitto",
    "rema": "remare",
    "remai": "remare",
    "remammo": "remare",
    "reman": "remare",
    "remando": "remare",
    "remano": "remare",
    "remante": "remare",
    "remanti": "remare",
    "remar": "remare",
    "remaron": "remare",
    "remarono": "remare",
    "remasse": "remare",
    "remasser": "remare",
    "remassero": "remare",
    "remassi": "remare",
    "remassimo": "remare",
    "remaste": "remare",
    "remasti": "remare",
    "remata": "remare",
    "remate": "remare",
    "remati": "remare",
    "remato": "remare",
    "rematori": "rematore",
    "remava": "remare",
    "remavamo": "remare",
    "remavan": "remare",
    "remavano": "remare",
    "remavate": "remare",
    "remavi": "remare",
    "remavo": "remare",
    "remerai": "remare",
    "remeran": "remare",
    "remeranno": "remare",
    "remerebbe": "remare",
    "remerebber": "remare",
    "remerebbero": "remare",
    "remerei": "remare",
    "remeremmo": "remare",
    "remeremo": "remare",
    "remereste": "remare",
    "remeresti": "remare",
    "remerete": "remare",
    "remerà": "remare",
    "remerò": "remare",
    "remi": "remare",
    "remiamo": "remare",
    "remiate": "remare",
    "remiga": "remigare",
    "remigai": "remigare",
    "remigammo": "remigare",
    "remigan": "remigare",
    "remigando": "remigare",
    "remigano": "remigare",
    "remigante": "remigare",
    "remiganti": "remigare",
    "remigar": "remigare",
    "remigaron": "remigare",
    "remigarono": "remigare",
    "remigasse": "remigare",
    "remigasser": "remigare",
    "remigassero": "remigare",
    "remigassi": "remigare",
    "remigassimo": "remigare",
    "remigaste": "remigare",
    "remigasti": "remigare",
    "remigata": "remigare",
    "remigate": "remigare",
    "remigati": "remigare",
    "remigato": "remigare",
    "remigava": "remigare",
    "remigavamo": "remigare",
    "remigavan": "remigare",
    "remigavano": "remigare",
    "remigavate": "remigare",
    "remigavi": "remigare",
    "remigavo": "remigare",
    "remigherai": "remigare",
    "remigheran": "remigare",
    "remigheranno": "remigare",
    "remigherebbe": "remigare",
    "remigherebber": "remigare",
    "remigherebbero": "remigare",
    "remigherei": "remigare",
    "remigheremmo": "remigare",
    "remigheremo": "remigare",
    "remighereste": "remigare",
    "remigheresti": "remigare",
    "remigherete": "remigare",
    "remigherà": "remigare",
    "remigherò": "remigare",
    "remighi": "remigare",
    "remighiamo": "remigare",
    "remighiate": "remigare",
    "remighin": "remigare",
    "remighino": "remigare",
    "remigo": "remigare",
    "remigò": "remigare",
    "remin": "remare",
    "reminiscenze": "reminiscenza",
    "remino": "remare",
    "remissioni": "remissione",
    "remissiva": "remissivo",
    "remissive": "remissivo",
    "remissivi": "remissivo",
    "remo": "remare",
    "remore": "remora",
    "remota": "remoto",
    "remote": "remoto",
    "remoti": "remoto",
    "remunera": "remunerare",
    "remunerai": "remunerare",
    "remunerammo": "remunerare",
    "remuneran": "remunerare",
    "remunerando": "remunerare",
    "remunerano": "remunerare",
    "remunerante": "remunerare",
    "remuneranti": "remunerare",
    "remunerar": "remunerare",
    "remuneraron": "remunerare",
    "remunerarono": "remunerare",
    "remunerasse": "remunerare",
    "remunerasser": "remunerare",
    "remunerassero": "remunerare",
    "remunerassi": "remunerare",
    "remunerassimo": "remunerare",
    "remuneraste": "remunerare",
    "remunerasti": "remunerare",
    "remunerata": "remunerare",
    "remunerate": "remunerare",
    "remunerati": "remunerare",
    "remunerativa": "remunerativo",
    "remunerative": "remunerativo",
    "remunerativi": "remunerativo",
    "remunerato": "remunerare",
    "remunerava": "remunerare",
    "remuneravamo": "remunerare",
    "remuneravan": "remunerare",
    "remuneravano": "remunerare",
    "remuneravate": "remunerare",
    "remuneravi": "remunerare",
    "remuneravo": "remunerare",
    "remunerazioni": "remunerazione",
    "remunererai": "remunerare",
    "remunereran": "remunerare",
    "remunereranno": "remunerare",
    "remunererebbe": "remunerare",
    "remunererebber": "remunerare",
    "remunererebbero": "remunerare",
    "remunererei": "remunerare",
    "remunereremmo": "remunerare",
    "remunereremo": "remunerare",
    "remunerereste": "remunerare",
    "remunereresti": "remunerare",
    "remunererete": "remunerare",
    "remunererà": "remunerare",
    "remunererò": "remunerare",
    "remuneri": "remunerare",
    "remuneriamo": "remunerare",
    "remuneriate": "remunerare",
    "remunerin": "remunerare",
    "remunerino": "remunerare",
    "remunero": "remunerare",
    "remunerò": "remunerare",
    "remò": "remare",
    "renali": "renale",
    "renana": "renano",
    "renane": "renano",
    "renani": "renano",
    "renda": "rendere",
    "rendan": "rendere",
    "rendano": "rendere",
    "rende": "rendere",
    "rendemmo": "rendere",
    "rendendo": "rendere",
    "rendente": "rendere",
    "rendenti": "rendere",
    "render": "rendere",
    "renderai": "rendere",
    "renderan": "rendere",
    "renderanno": "rendere",
    "renderebbe": "rendere",
    "renderebber": "rendere",
    "renderebbero": "rendere",
    "renderei": "rendere",
    "renderemmo": "rendere",
    "renderemo": "rendere",
    "rendereste": "rendere",
    "renderesti": "rendere",
    "renderete": "rendere",
    "renderà": "rendere",
    "renderò": "rendere",
    "rendesse": "rendere",
    "rendesser": "rendere",
    "rendessero": "rendere",
    "rendessi": "rendere",
    "rendessimo": "rendere",
    "rendeste": "rendere",
    "rendesti": "rendere",
    "rendete": "rendere",
    "rendeva": "rendere",
    "rendevamo": "rendere",
    "rendevan": "rendere",
    "rendevano": "rendere",
    "rendevate": "rendere",
    "rendevi": "rendere",
    "rendevo": "rendere",
    "rendi": "rendere",
    "rendiamo": "rendere",
    "rendiate": "rendere",
    "rendiconti": "rendiconto",
    "rendimenti": "rendimento",
    "rendite": "rendita",
    "rendo": "rendere",
    "rendon": "rendere",
    "rendono": "rendere",
    "reni": "rene",
    "renitenti": "renitente",
    "renitenze": "renitenza",
    "renne": "renna",
    "reparti": "reparto",
    "repella": "repellere",
    "repellan": "repellere",
    "repellano": "repellere",
    "repelle": "repellere",
    "repellei": "repellere",
    "repellemmo": "repellere",
    "repellendo": "repellere",
    "repellente": "repellere",
    "repellenti": "repellere",
    "repeller": "repellere",
    "repellerai": "repellere",
    "repelleran": "repellere",
    "repelleranno": "repellere",
    "repellerebbe": "repellere",
    "repellerebber": "repellere",
    "repellerebbero": "repellere",
    "repellerei": "repellere",
    "repelleremmo": "repellere",
    "repelleremo": "repellere",
    "repellereste": "repellere",
    "repelleresti": "repellere",
    "repellerete": "repellere",
    "repelleron": "repellere",
    "repellerono": "repellere",
    "repellerà": "repellere",
    "repellerò": "repellere",
    "repellesse": "repellere",
    "repellesser": "repellere",
    "repellessero": "repellere",
    "repellessi": "repellere",
    "repellessimo": "repellere",
    "repelleste": "repellere",
    "repellesti": "repellere",
    "repellete": "repellere",
    "repelleva": "repellere",
    "repellevamo": "repellere",
    "repellevan": "repellere",
    "repellevano": "repellere",
    "repellevate": "repellere",
    "repellevi": "repellere",
    "repellevo": "repellere",
    "repelli": "repellere",
    "repelliamo": "repellere",
    "repelliate": "repellere",
    "repello": "repellere",
    "repellon": "repellere",
    "repellono": "repellere",
    "repelluta": "repellere",
    "repellute": "repellere",
    "repelluti": "repellere",
    "repelluto": "repellere",
    "repellè": "repellere",
    "repentina": "repentino",
    "repentine": "repentino",
    "repentini": "repentino",
    "reperendo": "reperire",
    "reperente": "reperire",
    "reperenti": "reperire",
    "reperiamo": "reperire",
    "reperiate": "reperire",
    "reperibili": "reperibile",
    "reperii": "reperire",
    "reperimenti": "reperimento",
    "reperimmo": "reperire",
    "reperir": "reperire",
    "reperirai": "reperire",
    "reperiran": "reperire",
    "reperiranno": "reperire",
    "reperirebbe": "reperire",
    "reperirebber": "reperire",
    "reperirebbero": "reperire",
    "reperirei": "reperire",
    "reperiremmo": "reperire",
    "reperiremo": "reperire",
    "reperireste": "reperire",
    "reperiresti": "reperire",
    "reperirete": "reperire",
    "reperiron": "reperire",
    "reperirono": "reperire",
    "reperirà": "reperire",
    "reperirò": "reperire",
    "reperisca": "reperire",
    "reperiscan": "reperire",
    "reperiscano": "reperire",
    "reperisce": "reperire",
    "reperisci": "reperire",
    "reperisco": "reperire",
    "reperiscon": "reperire",
    "reperiscono": "reperire",
    "reperisse": "reperire",
    "reperisser": "reperire",
    "reperissero": "reperire",
    "reperissi": "reperire",
    "reperissimo": "reperire",
    "reperiste": "reperire",
    "reperisti": "reperire",
    "reperita": "reperire",
    "reperite": "reperire",
    "reperiti": "reperire",
    "reperito": "reperire",
    "reperiva": "reperire",
    "reperivamo": "reperire",
    "reperivan": "reperire",
    "reperivano": "reperire",
    "reperivate": "reperire",
    "reperivi": "reperire",
    "reperivo": "reperire",
    "reperta": "repertare",
    "repertai": "repertare",
    "repertammo": "repertare",
    "repertan": "repertare",
    "repertando": "repertare",
    "repertano": "repertare",
    "repertante": "repertare",
    "repertanti": "repertare",
    "repertar": "repertare",
    "repertaron": "repertare",
    "repertarono": "repertare",
    "repertasse": "repertare",
    "repertasser": "repertare",
    "repertassero": "repertare",
    "repertassi": "repertare",
    "repertassimo": "repertare",
    "repertaste": "repertare",
    "repertasti": "repertare",
    "repertata": "repertare",
    "repertate": "repertare",
    "repertati": "repertare",
    "repertato": "repertare",
    "repertava": "repertare",
    "repertavamo": "repertare",
    "repertavan": "repertare",
    "repertavano": "repertare",
    "repertavate": "repertare",
    "repertavi": "repertare",
    "repertavo": "repertare",
    "reperterai": "repertare",
    "reperteran": "repertare",
    "reperteranno": "repertare",
    "reperterebbe": "repertare",
    "reperterebber": "repertare",
    "reperterebbero": "repertare",
    "reperterei": "repertare",
    "reperteremmo": "repertare",
    "reperteremo": "repertare",
    "repertereste": "repertare",
    "reperteresti": "repertare",
    "reperterete": "repertare",
    "reperterà": "repertare",
    "reperterò": "repertare",
    "reperti": "reperto",
    "repertiamo": "repertare",
    "repertiate": "repertare",
    "repertin": "repertare",
    "repertino": "repertare",
    "reperto": "repertare",
    "repertori": "repertorio",
    "repertò": "repertare",
    "reperì": "reperire",
    "replica": "replicare",
    "replicai": "replicare",
    "replicammo": "replicare",
    "replican": "replicare",
    "replicando": "replicare",
    "replicano": "replicare",
    "replicante": "replicare",
    "replicanti": "replicare",
    "replicar": "replicare",
    "replicaron": "replicare",
    "replicarono": "replicare",
    "replicasse": "replicare",
    "replicasser": "replicare",
    "replicassero": "replicare",
    "replicassi": "replicare",
    "replicassimo": "replicare",
    "replicaste": "replicare",
    "replicasti": "replicare",
    "replicata": "replicato",
    "replicate": "replicato",
    "replicati": "replicato",
    "replicato": "replicare",
    "replicava": "replicare",
    "replicavamo": "replicare",
    "replicavan": "replicare",
    "replicavano": "replicare",
    "replicavate": "replicare",
    "replicavi": "replicare",
    "replicavo": "replicare",
    "replicazioni": "replicazione",
    "repliche": "replica",
    "replicherai": "replicare",
    "replicheran": "replicare",
    "replicheranno": "replicare",
    "replicherebbe": "replicare",
    "replicherebber": "replicare",
    "replicherebbero": "replicare",
    "replicherei": "replicare",
    "replicheremmo": "replicare",
    "replicheremo": "replicare",
    "replichereste": "replicare",
    "replicheresti": "replicare",
    "replicherete": "replicare",
    "replicherà": "replicare",
    "replicherò": "replicare",
    "replichi": "replicare",
    "replichiamo": "replicare",
    "replichiate": "replicare",
    "replichin": "replicare",
    "replichino": "replicare",
    "replico": "replicare",
    "replicò": "replicare",
    "reportages": "reportage",
    "reporters": "reporter",
    "repressa": "reprimere",
    "represse": "reprimere",
    "represser": "reprimere",
    "repressero": "reprimere",
    "repressi": "reprimere",
    "repressioni": "repressione",
    "repressiva": "repressivo",
    "repressive": "repressivo",
    "repressivi": "repressivo",
    "represso": "reprimere",
    "repressori": "repressore",
    "reprima": "reprimere",
    "repriman": "reprimere",
    "reprimano": "reprimere",
    "reprime": "reprimere",
    "reprimemmo": "reprimere",
    "reprimende": "reprimenda",
    "reprimendo": "reprimere",
    "reprimente": "reprimere",
    "reprimenti": "reprimere",
    "reprimer": "reprimere",
    "reprimerai": "reprimere",
    "reprimeran": "reprimere",
    "reprimeranno": "reprimere",
    "reprimerebbe": "reprimere",
    "reprimerebber": "reprimere",
    "reprimerebbero": "reprimere",
    "reprimerei": "reprimere",
    "reprimeremmo": "reprimere",
    "reprimeremo": "reprimere",
    "reprimereste": "reprimere",
    "reprimeresti": "reprimere",
    "reprimerete": "reprimere",
    "reprimerà": "reprimere",
    "reprimerò": "reprimere",
    "reprimesse": "reprimere",
    "reprimesser": "reprimere",
    "reprimessero": "reprimere",
    "reprimessi": "reprimere",
    "reprimessimo": "reprimere",
    "reprimeste": "reprimere",
    "reprimesti": "reprimere",
    "reprimete": "reprimere",
    "reprimeva": "reprimere",
    "reprimevamo": "reprimere",
    "reprimevan": "reprimere",
    "reprimevano": "reprimere",
    "reprimevate": "reprimere",
    "reprimevi": "reprimere",
    "reprimevo": "reprimere",
    "reprimi": "reprimere",
    "reprimiamo": "reprimere",
    "reprimiate": "reprimere",
    "reprimo": "reprimere",
    "reprimon": "reprimere",
    "reprimono": "reprimere",
    "reproba": "reprobo",
    "reprobe": "reprobo",
    "reprobi": "reprobo",
    "repubblicana": "repubblicano",
    "repubblicane": "repubblicano",
    "repubblicani": "repubblicano",
    "repubbliche": "repubblica",
    "repubblichina": "repubblichino",
    "repubblichine": "repubblichino",
    "repubblichini": "repubblichino",
    "repulsa": "repulso",
    "repulse": "repulso",
    "repulsi": "repulso",
    "repulsioni": "repulsione",
    "reputa": "reputare",
    "reputai": "reputare",
    "reputammo": "reputare",
    "reputan": "reputare",
    "reputando": "reputare",
    "reputano": "reputare",
    "reputante": "reputare",
    "reputanti": "reputare",
    "reputar": "reputare",
    "reputaron": "reputare",
    "reputarono": "reputare",
    "reputasse": "reputare",
    "reputasser": "reputare",
    "reputassero": "reputare",
    "reputassi": "reputare",
    "reputassimo": "reputare",
    "reputaste": "reputare",
    "reputasti": "reputare",
    "reputata": "reputare",
    "reputate": "reputare",
    "reputati": "reputare",
    "reputato": "reputare",
    "reputava": "reputare",
    "reputavamo": "reputare",
    "reputavan": "reputare",
    "reputavano": "reputare",
    "reputavate": "reputare",
    "reputavi": "reputare",
    "reputavo": "reputare",
    "reputazioni": "reputazione",
    "reputerai": "reputare",
    "reputeran": "reputare",
    "reputeranno": "reputare",
    "reputerebbe": "reputare",
    "reputerebber": "reputare",
    "reputerebbero": "reputare",
    "reputerei": "reputare",
    "reputeremmo": "reputare",
    "reputeremo": "reputare",
    "reputereste": "reputare",
    "reputeresti": "reputare",
    "reputerete": "reputare",
    "reputerà": "reputare",
    "reputerò": "reputare",
    "reputi": "reputare",
    "reputiamo": "reputare",
    "reputiate": "reputare",
    "reputin": "reputare",
    "reputino": "reputare",
    "reputo": "reputare",
    "reputò": "reputare",
    "requirenti": "requirente",
    "requisendo": "requisire",
    "requisente": "requisire",
    "requisenti": "requisire",
    "requisiamo": "requisire",
    "requisiate": "requisire",
    "requisii": "requisire",
    "requisimmo": "requisire",
    "requisir": "requisire",
    "requisirai": "requisire",
    "requisiran": "requisire",
    "requisiranno": "requisire",
    "requisirebbe": "requisire",
    "requisirebber": "requisire",
    "requisirebbero": "requisire",
    "requisirei": "requisire",
    "requisiremmo": "requisire",
    "requisiremo": "requisire",
    "requisireste": "requisire",
    "requisiresti": "requisire",
    "requisirete": "requisire",
    "requisiron": "requisire",
    "requisirono": "requisire",
    "requisirà": "requisire",
    "requisirò": "requisire",
    "requisisca": "requisire",
    "requisiscan": "requisire",
    "requisiscano": "requisire",
    "requisisce": "requisire",
    "requisisci": "requisire",
    "requisisco": "requisire",
    "requisiscon": "requisire",
    "requisiscono": "requisire",
    "requisisse": "requisire",
    "requisisser": "requisire",
    "requisissero": "requisire",
    "requisissi": "requisire",
    "requisissimo": "requisire",
    "requisiste": "requisire",
    "requisisti": "requisire",
    "requisita": "requisire",
    "requisite": "requisire",
    "requisiti": "requisito",
    "requisito": "requisire",
    "requisitorie": "requisitoria",
    "requisiva": "requisire",
    "requisivamo": "requisire",
    "requisivan": "requisire",
    "requisivano": "requisire",
    "requisivate": "requisire",
    "requisivi": "requisire",
    "requisivo": "requisire",
    "requisizioni": "requisizione",
    "requisì": "requisire",
    "resa": "rendere",
    "rescinda": "rescindere",
    "rescindan": "rescindere",
    "rescindano": "rescindere",
    "rescinde": "rescindere",
    "rescindemmo": "rescindere",
    "rescindendo": "rescindere",
    "rescindente": "rescindere",
    "rescindenti": "rescindere",
    "rescinder": "rescindere",
    "rescinderai": "rescindere",
    "rescinderan": "rescindere",
    "rescinderanno": "rescindere",
    "rescinderebbe": "rescindere",
    "rescinderebber": "rescindere",
    "rescinderebbero": "rescindere",
    "rescinderei": "rescindere",
    "rescinderemmo": "rescindere",
    "rescinderemo": "rescindere",
    "rescindereste": "rescindere",
    "rescinderesti": "rescindere",
    "rescinderete": "rescindere",
    "rescinderà": "rescindere",
    "rescinderò": "rescindere",
    "rescindesse": "rescindere",
    "rescindesser": "rescindere",
    "rescindessero": "rescindere",
    "rescindessi": "rescindere",
    "rescindessimo": "rescindere",
    "rescindeste": "rescindere",
    "rescindesti": "rescindere",
    "rescindete": "rescindere",
    "rescindeva": "rescindere",
    "rescindevamo": "rescindere",
    "rescindevan": "rescindere",
    "rescindevano": "rescindere",
    "rescindevate": "rescindere",
    "rescindevi": "rescindere",
    "rescindevo": "rescindere",
    "rescindi": "rescindere",
    "rescindiamo": "rescindere",
    "rescindiate": "rescindere",
    "rescindo": "rescindere",
    "rescindon": "rescindere",
    "rescindono": "rescindere",
    "rescissa": "rescindere",
    "rescisse": "rescindere",
    "rescisser": "rescindere",
    "rescissero": "rescindere",
    "rescissi": "rescindere",
    "rescissioni": "rescissione",
    "rescisso": "rescindere",
    "rese": "resa",
    "reseca": "resecare",
    "resecai": "resecare",
    "resecammo": "resecare",
    "resecan": "resecare",
    "resecando": "resecare",
    "resecano": "resecare",
    "resecante": "resecare",
    "resecanti": "resecare",
    "resecar": "resecare",
    "resecaron": "resecare",
    "resecarono": "resecare",
    "resecasse": "resecare",
    "resecasser": "resecare",
    "resecassero": "resecare",
    "resecassi": "resecare",
    "resecassimo": "resecare",
    "resecaste": "resecare",
    "resecasti": "resecare",
    "resecata": "resecare",
    "resecate": "resecare",
    "resecati": "resecare",
    "resecato": "resecare",
    "resecava": "resecare",
    "resecavamo": "resecare",
    "resecavan": "resecare",
    "resecavano": "resecare",
    "resecavate": "resecare",
    "resecavi": "resecare",
    "resecavo": "resecare",
    "resecherai": "resecare",
    "resecheran": "resecare",
    "resecheranno": "resecare",
    "resecherebbe": "resecare",
    "resecherebber": "resecare",
    "resecherebbero": "resecare",
    "resecherei": "resecare",
    "resecheremmo": "resecare",
    "resecheremo": "resecare",
    "resechereste": "resecare",
    "resecheresti": "resecare",
    "resecherete": "resecare",
    "resecherà": "resecare",
    "resecherò": "resecare",
    "resechi": "resecare",
    "resechiamo": "resecare",
    "resechiate": "resecare",
    "resechin": "resecare",
    "resechino": "resecare",
    "reseco": "resecare",
    "resecò": "resecare",
    "reser": "rendere",
    "resero": "rendere",
    "resi": "rendere",
    "residenti": "residente",
    "residenze": "residenza",
    "residenziali": "residenziale",
    "residua": "residuo",
    "residuai": "residuare",
    "residuali": "residuale",
    "residuammo": "residuare",
    "residuan": "residuare",
    "residuando": "residuare",
    "residuano": "residuare",
    "residuante": "residuare",
    "residuanti": "residuare",
    "residuar": "residuare",
    "residuaron": "residuare",
    "residuarono": "residuare",
    "residuasse": "residuare",
    "residuasser": "residuare",
    "residuassero": "residuare",
    "residuassi": "residuare",
    "residuassimo": "residuare",
    "residuaste": "residuare",
    "residuasti": "residuare",
    "residuata": "residuato",
    "residuate": "residuato",
    "residuati": "residuato",
    "residuato": "residuare",
    "residuava": "residuare",
    "residuavamo": "residuare",
    "residuavan": "residuare",
    "residuavano": "residuare",
    "residuavate": "residuare",
    "residuavi": "residuare",
    "residuavo": "residuare",
    "residue": "residuo",
    "residuerai": "residuare",
    "residueran": "residuare",
    "residueranno": "residuare",
    "residuerebbe": "residuare",
    "residuerebber": "residuare",
    "residuerebbero": "residuare",
    "residuerei": "residuare",
    "residueremmo": "residuare",
    "residueremo": "residuare",
    "residuereste": "residuare",
    "residueresti": "residuare",
    "residuerete": "residuare",
    "residuerà": "residuare",
    "residuerò": "residuare",
    "residui": "residuo",
    "residuiamo": "residuare",
    "residuiate": "residuare",
    "residuin": "residuare",
    "residuino": "residuare",
    "residuo": "residuare",
    "residuò": "residuare",
    "resina": "resinare",
    "resinai": "resinare",
    "resinammo": "resinare",
    "resinan": "resinare",
    "resinando": "resinare",
    "resinano": "resinare",
    "resinante": "resinare",
    "resinanti": "resinare",
    "resinar": "resinare",
    "resinaron": "resinare",
    "resinarono": "resinare",
    "resinasse": "resinare",
    "resinasser": "resinare",
    "resinassero": "resinare",
    "resinassi": "resinare",
    "resinassimo": "resinare",
    "resinaste": "resinare",
    "resinasti": "resinare",
    "resinata": "resinare",
    "resinate": "resinare",
    "resinati": "resinare",
    "resinato": "resinare",
    "resinava": "resinare",
    "resinavamo": "resinare",
    "resinavan": "resinare",
    "resinavano": "resinare",
    "resinavate": "resinare",
    "resinavi": "resinare",
    "resinavo": "resinare",
    "resine": "resina",
    "resinerai": "resinare",
    "resineran": "resinare",
    "resineranno": "resinare",
    "resinerebbe": "resinare",
    "resinerebber": "resinare",
    "resinerebbero": "resinare",
    "resinerei": "resinare",
    "resineremmo": "resinare",
    "resineremo": "resinare",
    "resinereste": "resinare",
    "resineresti": "resinare",
    "resinerete": "resinare",
    "resinerà": "resinare",
    "resinerò": "resinare",
    "resini": "resinare",
    "resiniamo": "resinare",
    "resiniate": "resinare",
    "resinin": "resinare",
    "resinino": "resinare",
    "resino": "resinare",
    "resinosa": "resinoso",
    "resinose": "resinoso",
    "resinosi": "resinoso",
    "resinò": "resinare",
    "resipiscenze": "resipiscenza",
    "resista": "resistere",
    "resistan": "resistere",
    "resistano": "resistere",
    "resiste": "resistere",
    "resistei": "resistere",
    "resistemmo": "resistere",
    "resistendo": "resistere",
    "resistente": "resistere",
    "resistenti": "resistere",
    "resistenze": "resistenza",
    "resistenziali": "resistenziale",
    "resister": "resistere",
    "resisterai": "resistere",
    "resisteran": "resistere",
    "resisteranno": "resistere",
    "resisterebbe": "resistere",
    "resisterebber": "resistere",
    "resisterebbero": "resistere",
    "resisterei": "resistere",
    "resisteremmo": "resistere",
    "resisteremo": "resistere",
    "resistereste": "resistere",
    "resisteresti": "resistere",
    "resisterete": "resistere",
    "resisteron": "resistere",
    "resisterono": "resistere",
    "resisterà": "resistere",
    "resisterò": "resistere",
    "resistesse": "resistere",
    "resistesser": "resistere",
    "resistessero": "resistere",
    "resistessi": "resistere",
    "resistessimo": "resistere",
    "resisteste": "resistere",
    "resistesti": "resistere",
    "resistete": "resistere",
    "resisteva": "resistere",
    "resistevamo": "resistere",
    "resistevan": "resistere",
    "resistevano": "resistere",
    "resistevate": "resistere",
    "resistevi": "resistere",
    "resistevo": "resistere",
    "resisti": "resistere",
    "resistiamo": "resistere",
    "resistiate": "resistere",
    "resisto": "resistere",
    "resiston": "resistere",
    "resistono": "resistere",
    "resistuta": "resistere",
    "resistute": "resistere",
    "resistuti": "resistere",
    "resistuto": "resistere",
    "resistè": "resistere",
    "reso": "rendere",
    "resoconti": "resoconto",
    "respinga": "respingere",
    "respingan": "respingere",
    "respingano": "respingere",
    "respinge": "respingere",
    "respingemmo": "respingere",
    "respingendo": "respingere",
    "respingente": "respingere",
    "respingenti": "respingere",
    "respinger": "respingere",
    "respingerai": "respingere",
    "respingeran": "respingere",
    "respingeranno": "respingere",
    "respingerebbe": "respingere",
    "respingerebber": "respingere",
    "respingerebbero": "respingere",
    "respingerei": "respingere",
    "respingeremmo": "respingere",
    "respingeremo": "respingere",
    "respingereste": "respingere",
    "respingeresti": "respingere",
    "respingerete": "respingere",
    "respingerà": "respingere",
    "respingerò": "respingere",
    "respingesse": "respingere",
    "respingesser": "respingere",
    "respingessero": "respingere",
    "respingessi": "respingere",
    "respingessimo": "respingere",
    "respingeste": "respingere",
    "respingesti": "respingere",
    "respingete": "respingere",
    "respingeva": "respingere",
    "respingevamo": "respingere",
    "respingevan": "respingere",
    "respingevano": "respingere",
    "respingevate": "respingere",
    "respingevi": "respingere",
    "respingevo": "respingere",
    "respingi": "respingere",
    "respingiamo": "respingere",
    "respingiate": "respingere",
    "respingimenti": "respingimento",
    "respingo": "respingere",
    "respingon": "respingere",
    "respingono": "respingere",
    "respinse": "respingere",
    "respinser": "respingere",
    "respinsero": "respingere",
    "respinsi": "respingere",
    "respinta": "respinto",
    "respinte": "respinto",
    "respinti": "respinto",
    "respinto": "respingere",
    "respira": "respirare",
    "respirabili": "respirabile",
    "respirai": "respirare",
    "respirammo": "respirare",
    "respiran": "respirare",
    "respirando": "respirare",
    "respirano": "respirare",
    "respirante": "respirare",
    "respiranti": "respirare",
    "respirar": "respirare",
    "respiraron": "respirare",
    "respirarono": "respirare",
    "respirasse": "respirare",
    "respirasser": "respirare",
    "respirassero": "respirare",
    "respirassi": "respirare",
    "respirassimo": "respirare",
    "respiraste": "respirare",
    "respirasti": "respirare",
    "respirata": "respirare",
    "respirate": "respirare",
    "respirati": "respirare",
    "respirato": "respirare",
    "respiratori": "respiratorio",
    "respiratoria": "respiratorio",
    "respiratorie": "respiratorio",
    "respirava": "respirare",
    "respiravamo": "respirare",
    "respiravan": "respirare",
    "respiravano": "respirare",
    "respiravate": "respirare",
    "respiravi": "respirare",
    "respiravo": "respirare",
    "respirazioni": "respirazione",
    "respirerai": "respirare",
    "respireran": "respirare",
    "respireranno": "respirare",
    "respirerebbe": "respirare",
    "respirerebber": "respirare",
    "respirerebbero": "respirare",
    "respirerei": "respirare",
    "respireremmo": "respirare",
    "respireremo": "respirare",
    "respirereste": "respirare",
    "respireresti": "respirare",
    "respirerete": "respirare",
    "respirerà": "respirare",
    "respirerò": "respirare",
    "respiri": "respiro",
    "respiriamo": "respirare",
    "respiriate": "respirare",
    "respirin": "respirare",
    "respirino": "respirare",
    "respiro": "respirare",
    "respirò": "respirare",
    "responsabili": "responsabile",
    "responsabilizza": "responsabilizzare",
    "responsabilizzai": "responsabilizzare",
    "responsabilizzammo": "responsabilizzare",
    "responsabilizzan": "responsabilizzare",
    "responsabilizzando": "responsabilizzare",
    "responsabilizzano": "responsabilizzare",
    "responsabilizzante": "responsabilizzare",
    "responsabilizzanti": "responsabilizzare",
    "responsabilizzar": "responsabilizzare",
    "responsabilizzaron": "responsabilizzare",
    "responsabilizzarono": "responsabilizzare",
    "responsabilizzasse": "responsabilizzare",
    "responsabilizzasser": "responsabilizzare",
    "responsabilizzassero": "responsabilizzare",
    "responsabilizzassi": "responsabilizzare",
    "responsabilizzassimo": "responsabilizzare",
    "responsabilizzaste": "responsabilizzare",
    "responsabilizzasti": "responsabilizzare",
    "responsabilizzata": "responsabilizzare",
    "responsabilizzate": "responsabilizzare",
    "responsabilizzati": "responsabilizzare",
    "responsabilizzato": "responsabilizzare",
    "responsabilizzava": "responsabilizzare",
    "responsabilizzavamo": "responsabilizzare",
    "responsabilizzavan": "responsabilizzare",
    "responsabilizzavano": "responsabilizzare",
    "responsabilizzavate": "responsabilizzare",
    "responsabilizzavi": "responsabilizzare",
    "responsabilizzavo": "responsabilizzare",
    "responsabilizzazioni": "responsabilizzazione",
    "responsabilizzerai": "responsabilizzare",
    "responsabilizzeran": "responsabilizzare",
    "responsabilizzeranno": "responsabilizzare",
    "responsabilizzerebbe": "responsabilizzare",
    "responsabilizzerebber": "responsabilizzare",
    "responsabilizzerebbero": "responsabilizzare",
    "responsabilizzerei": "responsabilizzare",
    "responsabilizzeremmo": "responsabilizzare",
    "responsabilizzeremo": "responsabilizzare",
    "responsabilizzereste": "responsabilizzare",
    "responsabilizzeresti": "responsabilizzare",
    "responsabilizzerete": "responsabilizzare",
    "responsabilizzerà": "responsabilizzare",
    "responsabilizzerò": "responsabilizzare",
    "responsabilizzi": "responsabilizzare",
    "responsabilizziamo": "responsabilizzare",
    "responsabilizziate": "responsabilizzare",
    "responsabilizzin": "responsabilizzare",
    "responsabilizzino": "responsabilizzare",
    "responsabilizzo": "responsabilizzare",
    "responsabilizzò": "responsabilizzare",
    "responsi": "responso",
    "resse": "ressa",
    "resser": "reggere",
    "ressero": "reggere",
    "ressi": "reggere",
    "resta": "restare",
    "restai": "restare",
    "restammo": "restare",
    "restan": "restare",
    "restando": "restare",
    "restano": "restare",
    "restante": "restare",
    "restanti": "restare",
    "restar": "restare",
    "restaron": "restare",
    "restarono": "restare",
    "restasse": "restare",
    "restasser": "restare",
    "restassero": "restare",
    "restassi": "restare",
    "restassimo": "restare",
    "restaste": "restare",
    "restasti": "restare",
    "restata": "restare",
    "restate": "restare",
    "restati": "restare",
    "restato": "restare",
    "restaura": "restaurare",
    "restaurai": "restaurare",
    "restaurammo": "restaurare",
    "restauran": "restaurare",
    "restaurando": "restaurare",
    "restaurano": "restaurare",
    "restaurante": "restaurare",
    "restauranti": "restaurare",
    "restaurar": "restaurare",
    "restauraron": "restaurare",
    "restaurarono": "restaurare",
    "restaurasse": "restaurare",
    "restaurasser": "restaurare",
    "restaurassero": "restaurare",
    "restaurassi": "restaurare",
    "restaurassimo": "restaurare",
    "restauraste": "restaurare",
    "restaurasti": "restaurare",
    "restaurata": "restaurare",
    "restaurate": "restaurare",
    "restaurati": "restaurare",
    "restaurato": "restaurare",
    "restauratori": "restauratore",
    "restauratrici": "restauratrice",
    "restaurava": "restaurare",
    "restauravamo": "restaurare",
    "restauravan": "restaurare",
    "restauravano": "restaurare",
    "restauravate": "restaurare",
    "restauravi": "restaurare",
    "restauravo": "restaurare",
    "restaurazioni": "restaurazione",
    "restaurerai": "restaurare",
    "restaureran": "restaurare",
    "restaureranno": "restaurare",
    "restaurerebbe": "restaurare",
    "restaurerebber": "restaurare",
    "restaurerebbero": "restaurare",
    "restaurerei": "restaurare",
    "restaureremmo": "restaurare",
    "restaureremo": "restaurare",
    "restaurereste": "restaurare",
    "restaureresti": "restaurare",
    "restaurerete": "restaurare",
    "restaurerà": "restaurare",
    "restaurerò": "restaurare",
    "restauri": "restauro",
    "restauriamo": "restaurare",
    "restauriate": "restaurare",
    "restaurin": "restaurare",
    "restaurino": "restaurare",
    "restauro": "restaurare",
    "restaurò": "restaurare",
    "restava": "restare",
    "restavamo": "restare",
    "restavan": "restare",
    "restavano": "restare",
    "restavate": "restare",
    "restavi": "restare",
    "restavo": "restare",
    "resterai": "restare",
    "resteran": "restare",
    "resteranno": "restare",
    "resterebbe": "restare",
    "resterebber": "restare",
    "resterebbero": "restare",
    "resterei": "restare",
    "resteremmo": "restare",
    "resteremo": "restare",
    "restereste": "restare",
    "resteresti": "restare",
    "resterete": "restare",
    "resterà": "restare",
    "resterò": "restare",
    "resti": "resto",
    "restiamo": "restare",
    "restiate": "restare",
    "restie": "restio",
    "restii": "restio",
    "restin": "restare",
    "restino": "restare",
    "restituendo": "restituire",
    "restituente": "restituire",
    "restituenti": "restituire",
    "restituiamo": "restituire",
    "restituiate": "restituire",
    "restituibili": "restituibile",
    "restituii": "restituire",
    "restituimmo": "restituire",
    "restituir": "restituire",
    "restituirai": "restituire",
    "restituiran": "restituire",
    "restituiranno": "restituire",
    "restituirebbe": "restituire",
    "restituirebber": "restituire",
    "restituirebbero": "restituire",
    "restituirei": "restituire",
    "restituiremmo": "restituire",
    "restituiremo": "restituire",
    "restituireste": "restituire",
    "restituiresti": "restituire",
    "restituirete": "restituire",
    "restituiron": "restituire",
    "restituirono": "restituire",
    "restituirà": "restituire",
    "restituirò": "restituire",
    "restituisca": "restituire",
    "restituiscan": "restituire",
    "restituiscano": "restituire",
    "restituisce": "restituire",
    "restituisci": "restituire",
    "restituisco": "restituire",
    "restituiscon": "restituire",
    "restituiscono": "restituire",
    "restituisse": "restituire",
    "restituisser": "restituire",
    "restituissero": "restituire",
    "restituissi": "restituire",
    "restituissimo": "restituire",
    "restituiste": "restituire",
    "restituisti": "restituire",
    "restituita": "restituire",
    "restituite": "restituire",
    "restituiti": "restituire",
    "restituito": "restituire",
    "restituiva": "restituire",
    "restituivamo": "restituire",
    "restituivan": "restituire",
    "restituivano": "restituire",
    "restituivate": "restituire",
    "restituivi": "restituire",
    "restituivo": "restituire",
    "restituzioni": "restituzione",
    "restituì": "restituire",
    "resto": "restare",
    "restringa": "restringere",
    "restringan": "restringere",
    "restringano": "restringere",
    "restringe": "restringere",
    "restringemmo": "restringere",
    "restringendo": "restringere",
    "restringente": "restringere",
    "restringenti": "restringere",
    "restringer": "restringere",
    "restringerai": "restringere",
    "restringeran": "restringere",
    "restringeranno": "restringere",
    "restringerebbe": "restringere",
    "restringerebber": "restringere",
    "restringerebbero": "restringere",
    "restringerei": "restringere",
    "restringeremmo": "restringere",
    "restringeremo": "restringere",
    "restringereste": "restringere",
    "restringeresti": "restringere",
    "restringerete": "restringere",
    "restringerà": "restringere",
    "restringerò": "restringere",
    "restringesse": "restringere",
    "restringesser": "restringere",
    "restringessero": "restringere",
    "restringessi": "restringere",
    "restringessimo": "restringere",
    "restringeste": "restringere",
    "restringesti": "restringere",
    "restringete": "restringere",
    "restringeva": "restringere",
    "restringevamo": "restringere",
    "restringevan": "restringere",
    "restringevano": "restringere",
    "restringevate": "restringere",
    "restringevi": "restringere",
    "restringevo": "restringere",
    "restringi": "restringere",
    "restringiamo": "restringere",
    "restringiate": "restringere",
    "restringimenti": "restringimento",
    "restringo": "restringere",
    "restringon": "restringere",
    "restringono": "restringere",
    "restrinse": "restringere",
    "restrinser": "restringere",
    "restrinsero": "restringere",
    "restrinsi": "restringere",
    "restrittiva": "restrittivo",
    "restrittive": "restrittivo",
    "restrittivi": "restrittivo",
    "restrizioni": "restrizione",
    "restò": "restare",
    "resurrezioni": "resurrezione",
    "resuscita": "resuscitare",
    "resuscitai": "resuscitare",
    "resuscitammo": "resuscitare",
    "resuscitan": "resuscitare",
    "resuscitando": "resuscitare",
    "resuscitano": "resuscitare",
    "resuscitante": "resuscitare",
    "resuscitanti": "resuscitare",
    "resuscitar": "resuscitare",
    "resuscitaron": "resuscitare",
    "resuscitarono": "resuscitare",
    "resuscitasse": "resuscitare",
    "resuscitasser": "resuscitare",
    "resuscitassero": "resuscitare",
    "resuscitassi": "resuscitare",
    "resuscitassimo": "resuscitare",
    "resuscitaste": "resuscitare",
    "resuscitasti": "resuscitare",
    "resuscitata": "resuscitare",
    "resuscitate": "resuscitare",
    "resuscitati": "resuscitare",
    "resuscitato": "resuscitare",
    "resuscitava": "resuscitare",
    "resuscitavamo": "resuscitare",
    "resuscitavan": "resuscitare",
    "resuscitavano": "resuscitare",
    "resuscitavate": "resuscitare",
    "resuscitavi": "resuscitare",
    "resuscitavo": "resuscitare",
    "resusciterai": "resuscitare",
    "resusciteran": "resuscitare",
    "resusciteranno": "resuscitare",
    "resusciterebbe": "resuscitare",
    "resusciterebber": "resuscitare",
    "resusciterebbero": "resuscitare",
    "resusciterei": "resuscitare",
    "resusciteremmo": "resuscitare",
    "resusciteremo": "resuscitare",
    "resuscitereste": "resuscitare",
    "resusciteresti": "resuscitare",
    "resusciterete": "resuscitare",
    "resusciterà": "resuscitare",
    "resusciterò": "resuscitare",
    "resusciti": "resuscitare",
    "resuscitiamo": "resuscitare",
    "resuscitiate": "resuscitare",
    "resuscitin": "resuscitare",
    "resuscitino": "resuscitare",
    "resuscito": "resuscitare",
    "resuscitò": "resuscitare",
    "resè": "rendere",
    "retaggi": "retaggio",
    "retate": "retata",
    "reti": "rete",
    "reticelle": "reticella",
    "reticenti": "reticente",
    "reticenze": "reticenza",
    "reticola": "reticolare",
    "reticolai": "reticolare",
    "reticolammo": "reticolare",
    "reticolan": "reticolare",
    "reticolando": "reticolare",
    "reticolano": "reticolare",
    "reticolante": "reticolare",
    "reticolanti": "reticolare",
    "reticolar": "reticolare",
    "reticolari": "reticolare",
    "reticolaron": "reticolare",
    "reticolarono": "reticolare",
    "reticolasse": "reticolare",
    "reticolasser": "reticolare",
    "reticolassero": "reticolare",
    "reticolassi": "reticolare",
    "reticolassimo": "reticolare",
    "reticolaste": "reticolare",
    "reticolasti": "reticolare",
    "reticolata": "reticolare",
    "reticolate": "reticolare",
    "reticolati": "reticolato",
    "reticolato": "reticolare",
    "reticolava": "reticolare",
    "reticolavamo": "reticolare",
    "reticolavan": "reticolare",
    "reticolavano": "reticolare",
    "reticolavate": "reticolare",
    "reticolavi": "reticolare",
    "reticolavo": "reticolare",
    "reticolerai": "reticolare",
    "reticoleran": "reticolare",
    "reticoleranno": "reticolare",
    "reticolerebbe": "reticolare",
    "reticolerebber": "reticolare",
    "reticolerebbero": "reticolare",
    "reticolerei": "reticolare",
    "reticoleremmo": "reticolare",
    "reticoleremo": "reticolare",
    "reticolereste": "reticolare",
    "reticoleresti": "reticolare",
    "reticolerete": "reticolare",
    "reticolerà": "reticolare",
    "reticolerò": "reticolare",
    "reticoli": "reticolo",
    "reticoliamo": "reticolare",
    "reticoliate": "reticolare",
    "reticolin": "reticolare",
    "reticolino": "reticolare",
    "reticolo": "reticolare",
    "reticolò": "reticolare",
    "retina": "retinare",
    "retinai": "retinare",
    "retinammo": "retinare",
    "retinan": "retinare",
    "retinando": "retinare",
    "retinano": "retinare",
    "retinante": "retinare",
    "retinanti": "retinare",
    "retinar": "retinare",
    "retinaron": "retinare",
    "retinarono": "retinare",
    "retinasse": "retinare",
    "retinasser": "retinare",
    "retinassero": "retinare",
    "retinassi": "retinare",
    "retinassimo": "retinare",
    "retinaste": "retinare",
    "retinasti": "retinare",
    "retinata": "retinare",
    "retinate": "retinare",
    "retinati": "retinare",
    "retinato": "retinare",
    "retinava": "retinare",
    "retinavamo": "retinare",
    "retinavan": "retinare",
    "retinavano": "retinare",
    "retinavate": "retinare",
    "retinavi": "retinare",
    "retinavo": "retinare",
    "retine": "retina",
    "retinerai": "retinare",
    "retineran": "retinare",
    "retineranno": "retinare",
    "retinerebbe": "retinare",
    "retinerebber": "retinare",
    "retinerebbero": "retinare",
    "retinerei": "retinare",
    "retineremmo": "retinare",
    "retineremo": "retinare",
    "retinereste": "retinare",
    "retineresti": "retinare",
    "retinerete": "retinare",
    "retinerà": "retinare",
    "retinerò": "retinare",
    "retini": "retino",
    "retiniamo": "retinare",
    "retiniate": "retinare",
    "retinin": "retinare",
    "retinino": "retinare",
    "retino": "retinare",
    "retinò": "retinare",
    "retori": "retore",
    "retorica": "retorico",
    "retoriche": "retorico",
    "retorici": "retorico",
    "retri": "retro",
    "retribuendo": "retribuire",
    "retribuente": "retribuire",
    "retribuenti": "retribuire",
    "retribuiamo": "retribuire",
    "retribuiate": "retribuire",
    "retribuii": "retribuire",
    "retribuimmo": "retribuire",
    "retribuir": "retribuire",
    "retribuirai": "retribuire",
    "retribuiran": "retribuire",
    "retribuiranno": "retribuire",
    "retribuirebbe": "retribuire",
    "retribuirebber": "retribuire",
    "retribuirebbero": "retribuire",
    "retribuirei": "retribuire",
    "retribuiremmo": "retribuire",
    "retribuiremo": "retribuire",
    "retribuireste": "retribuire",
    "retribuiresti": "retribuire",
    "retribuirete": "retribuire",
    "retribuiron": "retribuire",
    "retribuirono": "retribuire",
    "retribuirà": "retribuire",
    "retribuirò": "retribuire",
    "retribuisca": "retribuire",
    "retribuiscan": "retribuire",
    "retribuiscano": "retribuire",
    "retribuisce": "retribuire",
    "retribuisci": "retribuire",
    "retribuisco": "retribuire",
    "retribuiscon": "retribuire",
    "retribuiscono": "retribuire",
    "retribuisse": "retribuire",
    "retribuisser": "retribuire",
    "retribuissero": "retribuire",
    "retribuissi": "retribuire",
    "retribuissimo": "retribuire",
    "retribuiste": "retribuire",
    "retribuisti": "retribuire",
    "retribuita": "retribuire",
    "retribuite": "retribuire",
    "retribuiti": "retribuire",
    "retribuito": "retribuire",
    "retribuiva": "retribuire",
    "retribuivamo": "retribuire",
    "retribuivan": "retribuire",
    "retribuivano": "retribuire",
    "retribuivate": "retribuire",
    "retribuivi": "retribuire",
    "retribuivo": "retribuire",
    "retributiva": "retributivo",
    "retributive": "retributivo",
    "retributivi": "retributivo",
    "retribuzioni": "retribuzione",
    "retribuì": "retribuire",
    "retriva": "retrivo",
    "retrive": "retrivo",
    "retrivi": "retrivo",
    "retroattiva": "retroattivo",
    "retroattive": "retroattivo",
    "retroattivi": "retroattivo",
    "retroceda": "retrocedere",
    "retrocedan": "retrocedere",
    "retrocedano": "retrocedere",
    "retrocede": "retrocedere",
    "retrocedei": "retrocedere",
    "retrocedemmo": "retrocedere",
    "retrocedendo": "retrocedere",
    "retrocedente": "retrocedere",
    "retrocedenti": "retrocedere",
    "retroceder": "retrocedere",
    "retrocederai": "retrocedere",
    "retrocederan": "retrocedere",
    "retrocederanno": "retrocedere",
    "retrocederebbe": "retrocedere",
    "retrocederebber": "retrocedere",
    "retrocederebbero": "retrocedere",
    "retrocederei": "retrocedere",
    "retrocederemmo": "retrocedere",
    "retrocederemo": "retrocedere",
    "retrocedereste": "retrocedere",
    "retrocederesti": "retrocedere",
    "retrocederete": "retrocedere",
    "retrocederon": "retrocedere",
    "retrocederono": "retrocedere",
    "retrocederà": "retrocedere",
    "retrocederò": "retrocedere",
    "retrocedesse": "retrocedere",
    "retrocedesser": "retrocedere",
    "retrocedessero": "retrocedere",
    "retrocedessi": "retrocedere",
    "retrocedessimo": "retrocedere",
    "retrocedeste": "retrocedere",
    "retrocedesti": "retrocedere",
    "retrocedete": "retrocedere",
    "retrocedeva": "retrocedere",
    "retrocedevamo": "retrocedere",
    "retrocedevan": "retrocedere",
    "retrocedevano": "retrocedere",
    "retrocedevate": "retrocedere",
    "retrocedevi": "retrocedere",
    "retrocedevo": "retrocedere",
    "retrocedi": "retrocedere",
    "retrocediamo": "retrocedere",
    "retrocediate": "retrocedere",
    "retrocedo": "retrocedere",
    "retrocedon": "retrocedere",
    "retrocedono": "retrocedere",
    "retroceduta": "retrocedere",
    "retrocedute": "retrocedere",
    "retroceduti": "retrocedere",
    "retroceduto": "retrocedere",
    "retrocedè": "retrocedere",
    "retrocessioni": "retrocessione",
    "retrodata": "retrodatare",
    "retrodatai": "retrodatare",
    "retrodatammo": "retrodatare",
    "retrodatan": "retrodatare",
    "retrodatando": "retrodatare",
    "retrodatano": "retrodatare",
    "retrodatante": "retrodatare",
    "retrodatanti": "retrodatare",
    "retrodatar": "retrodatare",
    "retrodataron": "retrodatare",
    "retrodatarono": "retrodatare",
    "retrodatasse": "retrodatare",
    "retrodatasser": "retrodatare",
    "retrodatassero": "retrodatare",
    "retrodatassi": "retrodatare",
    "retrodatassimo": "retrodatare",
    "retrodataste": "retrodatare",
    "retrodatasti": "retrodatare",
    "retrodatata": "retrodatare",
    "retrodatate": "retrodatare",
    "retrodatati": "retrodatare",
    "retrodatato": "retrodatare",
    "retrodatava": "retrodatare",
    "retrodatavamo": "retrodatare",
    "retrodatavan": "retrodatare",
    "retrodatavano": "retrodatare",
    "retrodatavate": "retrodatare",
    "retrodatavi": "retrodatare",
    "retrodatavo": "retrodatare",
    "retrodaterai": "retrodatare",
    "retrodateran": "retrodatare",
    "retrodateranno": "retrodatare",
    "retrodaterebbe": "retrodatare",
    "retrodaterebber": "retrodatare",
    "retrodaterebbero": "retrodatare",
    "retrodaterei": "retrodatare",
    "retrodateremmo": "retrodatare",
    "retrodateremo": "retrodatare",
    "retrodatereste": "retrodatare",
    "retrodateresti": "retrodatare",
    "retrodaterete": "retrodatare",
    "retrodaterà": "retrodatare",
    "retrodaterò": "retrodatare",
    "retrodati": "retrodatare",
    "retrodatiamo": "retrodatare",
    "retrodatiate": "retrodatare",
    "retrodatin": "retrodatare",
    "retrodatino": "retrodatare",
    "retrodato": "retrodatare",
    "retrodatò": "retrodatare",
    "retrograda": "retrogrado",
    "retrograde": "retrogrado",
    "retrogradi": "retrogrado",
    "retroguardie": "retroguardia",
    "retrogusti": "retrogusto",
    "retromarcie": "retromarcia",
    "retropalchi": "retropalco",
    "retropassaggi": "retropassaggio",
    "retropensieri": "retropensiero",
    "retrospettiva": "retrospettivo",
    "retrospettive": "retrospettivo",
    "retrospettivi": "retrospettivo",
    "retrostanti": "retrostante",
    "retrovie": "retrovia",
    "retrovisori": "retrovisore",
    "retta": "retto",
    "rettali": "rettale",
    "rettangola": "rettangolo",
    "rettangolari": "rettangolare",
    "rettangole": "rettangolo",
    "rettangoli": "rettangolo",
    "rettangolini": "rettangolino",
    "rette": "retto",
    "retti": "retto",
    "rettifica": "rettificare",
    "rettificai": "rettificare",
    "rettificammo": "rettificare",
    "rettifican": "rettificare",
    "rettificando": "rettificare",
    "rettificano": "rettificare",
    "rettificante": "rettificare",
    "rettificanti": "rettificare",
    "rettificar": "rettificare",
    "rettificaron": "rettificare",
    "rettificarono": "rettificare",
    "rettificasse": "rettificare",
    "rettificasser": "rettificare",
    "rettificassero": "rettificare",
    "rettificassi": "rettificare",
    "rettificassimo": "rettificare",
    "rettificaste": "rettificare",
    "rettificasti": "rettificare",
    "rettificata": "rettificare",
    "rettificate": "rettificare",
    "rettificati": "rettificare",
    "rettificato": "rettificare",
    "rettificava": "rettificare",
    "rettificavamo": "rettificare",
    "rettificavan": "rettificare",
    "rettificavano": "rettificare",
    "rettificavate": "rettificare",
    "rettificavi": "rettificare",
    "rettificavo": "rettificare",
    "rettifiche": "rettifica",
    "rettificherai": "rettificare",
    "rettificheran": "rettificare",
    "rettificheranno": "rettificare",
    "rettificherebbe": "rettificare",
    "rettificherebber": "rettificare",
    "rettificherebbero": "rettificare",
    "rettificherei": "rettificare",
    "rettificheremmo": "rettificare",
    "rettificheremo": "rettificare",
    "rettifichereste": "rettificare",
    "rettificheresti": "rettificare",
    "rettificherete": "rettificare",
    "rettificherà": "rettificare",
    "rettificherò": "rettificare",
    "rettifichi": "rettificare",
    "rettifichiamo": "rettificare",
    "rettifichiate": "rettificare",
    "rettifichin": "rettificare",
    "rettifichino": "rettificare",
    "rettifico": "rettificare",
    "rettificò": "rettificare",
    "rettifili": "rettifilo",
    "rettili": "rettile",
    "rettilinea": "rettilineo",
    "rettilinee": "rettilineo",
    "rettilinei": "rettilineo",
    "rettitudini": "rettitudine",
    "retto": "reggere",
    "rettorati": "rettorato",
    "rettori": "rettore",
    "rettrice": "rettore",
    "rettrici": "rettore",
    "reucci": "reuccio",
    "reumatica": "reumatico",
    "reumatiche": "reumatico",
    "reumatici": "reumatico",
    "reumatismi": "reumatismo",
    "revanscismi": "revanscismo",
    "reverenda": "reverendo",
    "reverende": "reverendo",
    "reverendi": "reverendo",
    "reverenze": "reverenza",
    "reverenziali": "reverenziale",
    "reversibili": "reversibile",
    "revisiona": "revisionare",
    "revisionai": "revisionare",
    "revisionammo": "revisionare",
    "revisionan": "revisionare",
    "revisionando": "revisionare",
    "revisionano": "revisionare",
    "revisionante": "revisionare",
    "revisionanti": "revisionare",
    "revisionar": "revisionare",
    "revisionaron": "revisionare",
    "revisionarono": "revisionare",
    "revisionasse": "revisionare",
    "revisionasser": "revisionare",
    "revisionassero": "revisionare",
    "revisionassi": "revisionare",
    "revisionassimo": "revisionare",
    "revisionaste": "revisionare",
    "revisionasti": "revisionare",
    "revisionata": "revisionare",
    "revisionate": "revisionare",
    "revisionati": "revisionare",
    "revisionato": "revisionare",
    "revisionava": "revisionare",
    "revisionavamo": "revisionare",
    "revisionavan": "revisionare",
    "revisionavano": "revisionare",
    "revisionavate": "revisionare",
    "revisionavi": "revisionare",
    "revisionavo": "revisionare",
    "revisionerai": "revisionare",
    "revisioneran": "revisionare",
    "revisioneranno": "revisionare",
    "revisionerebbe": "revisionare",
    "revisionerebber": "revisionare",
    "revisionerebbero": "revisionare",
    "revisionerei": "revisionare",
    "revisioneremmo": "revisionare",
    "revisioneremo": "revisionare",
    "revisionereste": "revisionare",
    "revisioneresti": "revisionare",
    "revisionerete": "revisionare",
    "revisionerà": "revisionare",
    "revisionerò": "revisionare",
    "revisioni": "revisione",
    "revisioniamo": "revisionare",
    "revisioniate": "revisionare",
    "revisionin": "revisionare",
    "revisionino": "revisionare",
    "revisionismi": "revisionismo",
    "revisioniste": "revisionista",
    "revisionisti": "revisionista",
    "revisionistica": "revisionistico",
    "revisionistiche": "revisionistico",
    "revisionistici": "revisionistico",
    "revisiono": "revisionare",
    "revisionò": "revisionare",
    "revisori": "revisore",
    "revoca": "revocare",
    "revocabili": "revocabile",
    "revocai": "revocare",
    "revocammo": "revocare",
    "revocan": "revocare",
    "revocando": "revocare",
    "revocano": "revocare",
    "revocante": "revocare",
    "revocanti": "revocare",
    "revocar": "revocare",
    "revocaron": "revocare",
    "revocarono": "revocare",
    "revocasse": "revocare",
    "revocasser": "revocare",
    "revocassero": "revocare",
    "revocassi": "revocare",
    "revocassimo": "revocare",
    "revocaste": "revocare",
    "revocasti": "revocare",
    "revocata": "revocare",
    "revocate": "revocare",
    "revocati": "revocare",
    "revocato": "revocare",
    "revocatori": "revocatorio",
    "revocatoria": "revocatorio",
    "revocatorie": "revocatorio",
    "revocava": "revocare",
    "revocavamo": "revocare",
    "revocavan": "revocare",
    "revocavano": "revocare",
    "revocavate": "revocare",
    "revocavi": "revocare",
    "revocavo": "revocare",
    "revocherai": "revocare",
    "revocheran": "revocare",
    "revocheranno": "revocare",
    "revocherebbe": "revocare",
    "revocherebber": "revocare",
    "revocherebbero": "revocare",
    "revocherei": "revocare",
    "revocheremmo": "revocare",
    "revocheremo": "revocare",
    "revochereste": "revocare",
    "revocheresti": "revocare",
    "revocherete": "revocare",
    "revocherà": "revocare",
    "revocherò": "revocare",
    "revochi": "revocare",
    "revochiamo": "revocare",
    "revochiate": "revocare",
    "revochin": "revocare",
    "revochino": "revocare",
    "revoco": "revocare",
    "revocò": "revocare",
    "ria": "rio",
    "riabbassa": "riabbassare",
    "riabbassai": "riabbassare",
    "riabbassammo": "riabbassare",
    "riabbassan": "riabbassare",
    "riabbassando": "riabbassare",
    "riabbassano": "riabbassare",
    "riabbassante": "riabbassare",
    "riabbassanti": "riabbassare",
    "riabbassar": "riabbassare",
    "riabbassaron": "riabbassare",
    "riabbassarono": "riabbassare",
    "riabbassasse": "riabbassare",
    "riabbassasser": "riabbassare",
    "riabbassassero": "riabbassare",
    "riabbassassi": "riabbassare",
    "riabbassassimo": "riabbassare",
    "riabbassaste": "riabbassare",
    "riabbassasti": "riabbassare",
    "riabbassata": "riabbassare",
    "riabbassate": "riabbassare",
    "riabbassati": "riabbassare",
    "riabbassato": "riabbassare",
    "riabbassava": "riabbassare",
    "riabbassavamo": "riabbassare",
    "riabbassavan": "riabbassare",
    "riabbassavano": "riabbassare",
    "riabbassavate": "riabbassare",
    "riabbassavi": "riabbassare",
    "riabbassavo": "riabbassare",
    "riabbasserai": "riabbassare",
    "riabbasseran": "riabbassare",
    "riabbasseranno": "riabbassare",
    "riabbasserebbe": "riabbassare",
    "riabbasserebber": "riabbassare",
    "riabbasserebbero": "riabbassare",
    "riabbasserei": "riabbassare",
    "riabbasseremmo": "riabbassare",
    "riabbasseremo": "riabbassare",
    "riabbassereste": "riabbassare",
    "riabbasseresti": "riabbassare",
    "riabbasserete": "riabbassare",
    "riabbasserà": "riabbassare",
    "riabbasserò": "riabbassare",
    "riabbassi": "riabbassare",
    "riabbassiamo": "riabbassare",
    "riabbassiate": "riabbassare",
    "riabbassin": "riabbassare",
    "riabbassino": "riabbassare",
    "riabbasso": "riabbassare",
    "riabbassò": "riabbassare",
    "riabbatta": "riabbattere",
    "riabbattan": "riabbattere",
    "riabbattano": "riabbattere",
    "riabbatte": "riabbattere",
    "riabbattei": "riabbattere",
    "riabbattemmo": "riabbattere",
    "riabbattendo": "riabbattere",
    "riabbattente": "riabbattere",
    "riabbattenti": "riabbattere",
    "riabbatter": "riabbattere",
    "riabbatterai": "riabbattere",
    "riabbatteran": "riabbattere",
    "riabbatteranno": "riabbattere",
    "riabbatterebbe": "riabbattere",
    "riabbatterebber": "riabbattere",
    "riabbatterebbero": "riabbattere",
    "riabbatterei": "riabbattere",
    "riabbatteremmo": "riabbattere",
    "riabbatteremo": "riabbattere",
    "riabbattereste": "riabbattere",
    "riabbatteresti": "riabbattere",
    "riabbatterete": "riabbattere",
    "riabbatteron": "riabbattere",
    "riabbatterono": "riabbattere",
    "riabbatterà": "riabbattere",
    "riabbatterò": "riabbattere",
    "riabbattesse": "riabbattere",
    "riabbattesser": "riabbattere",
    "riabbattessero": "riabbattere",
    "riabbattessi": "riabbattere",
    "riabbattessimo": "riabbattere",
    "riabbatteste": "riabbattere",
    "riabbattesti": "riabbattere",
    "riabbattete": "riabbattere",
    "riabbatteva": "riabbattere",
    "riabbattevamo": "riabbattere",
    "riabbattevan": "riabbattere",
    "riabbattevano": "riabbattere",
    "riabbattevate": "riabbattere",
    "riabbattevi": "riabbattere",
    "riabbattevo": "riabbattere",
    "riabbatti": "riabbattere",
    "riabbattiamo": "riabbattere",
    "riabbattiate": "riabbattere",
    "riabbatto": "riabbattere",
    "riabbatton": "riabbattere",
    "riabbattono": "riabbattere",
    "riabbattuta": "riabbattere",
    "riabbattute": "riabbattere",
    "riabbattuti": "riabbattere",
    "riabbattuto": "riabbattere",
    "riabbattè": "riabbattere",
    "riabbi": "riavere",
    "riabbia": "riavere",
    "riabbiamo": "riavere",
    "riabbian": "riavere",
    "riabbiano": "riavere",
    "riabbiate": "riavere",
    "riabbottona": "riabbottonare",
    "riabbottonai": "riabbottonare",
    "riabbottonammo": "riabbottonare",
    "riabbottonan": "riabbottonare",
    "riabbottonando": "riabbottonare",
    "riabbottonano": "riabbottonare",
    "riabbottonante": "riabbottonare",
    "riabbottonanti": "riabbottonare",
    "riabbottonar": "riabbottonare",
    "riabbottonaron": "riabbottonare",
    "riabbottonarono": "riabbottonare",
    "riabbottonasse": "riabbottonare",
    "riabbottonasser": "riabbottonare",
    "riabbottonassero": "riabbottonare",
    "riabbottonassi": "riabbottonare",
    "riabbottonassimo": "riabbottonare",
    "riabbottonaste": "riabbottonare",
    "riabbottonasti": "riabbottonare",
    "riabbottonata": "riabbottonare",
    "riabbottonate": "riabbottonare",
    "riabbottonati": "riabbottonare",
    "riabbottonato": "riabbottonare",
    "riabbottonava": "riabbottonare",
    "riabbottonavamo": "riabbottonare",
    "riabbottonavan": "riabbottonare",
    "riabbottonavano": "riabbottonare",
    "riabbottonavate": "riabbottonare",
    "riabbottonavi": "riabbottonare",
    "riabbottonavo": "riabbottonare",
    "riabbottonerai": "riabbottonare",
    "riabbottoneran": "riabbottonare",
    "riabbottoneranno": "riabbottonare",
    "riabbottonerebbe": "riabbottonare",
    "riabbottonerebber": "riabbottonare",
    "riabbottonerebbero": "riabbottonare",
    "riabbottonerei": "riabbottonare",
    "riabbottoneremmo": "riabbottonare",
    "riabbottoneremo": "riabbottonare",
    "riabbottonereste": "riabbottonare",
    "riabbottoneresti": "riabbottonare",
    "riabbottonerete": "riabbottonare",
    "riabbottonerà": "riabbottonare",
    "riabbottonerò": "riabbottonare",
    "riabbottoni": "riabbottonare",
    "riabbottoniamo": "riabbottonare",
    "riabbottoniate": "riabbottonare",
    "riabbottonin": "riabbottonare",
    "riabbottonino": "riabbottonare",
    "riabbottono": "riabbottonare",
    "riabbottonò": "riabbottonare",
    "riabbraccerai": "riabbracciare",
    "riabbracceran": "riabbracciare",
    "riabbracceranno": "riabbracciare",
    "riabbraccerebbe": "riabbracciare",
    "riabbraccerebber": "riabbracciare",
    "riabbraccerebbero": "riabbracciare",
    "riabbraccerei": "riabbracciare",
    "riabbracceremmo": "riabbracciare",
    "riabbracceremo": "riabbracciare",
    "riabbraccereste": "riabbracciare",
    "riabbracceresti": "riabbracciare",
    "riabbraccerete": "riabbracciare",
    "riabbraccerà": "riabbracciare",
    "riabbraccerò": "riabbracciare",
    "riabbracci": "riabbracciare",
    "riabbraccia": "riabbracciare",
    "riabbracciai": "riabbracciare",
    "riabbracciammo": "riabbracciare",
    "riabbracciamo": "riabbracciare",
    "riabbraccian": "riabbracciare",
    "riabbracciando": "riabbracciare",
    "riabbracciano": "riabbracciare",
    "riabbracciante": "riabbracciare",
    "riabbraccianti": "riabbracciare",
    "riabbracciar": "riabbracciare",
    "riabbracciaron": "riabbracciare",
    "riabbracciarono": "riabbracciare",
    "riabbracciasse": "riabbracciare",
    "riabbracciasser": "riabbracciare",
    "riabbracciassero": "riabbracciare",
    "riabbracciassi": "riabbracciare",
    "riabbracciassimo": "riabbracciare",
    "riabbracciaste": "riabbracciare",
    "riabbracciasti": "riabbracciare",
    "riabbracciata": "riabbracciare",
    "riabbracciate": "riabbracciare",
    "riabbracciati": "riabbracciare",
    "riabbracciato": "riabbracciare",
    "riabbracciava": "riabbracciare",
    "riabbracciavamo": "riabbracciare",
    "riabbracciavan": "riabbracciare",
    "riabbracciavano": "riabbracciare",
    "riabbracciavate": "riabbracciare",
    "riabbracciavi": "riabbracciare",
    "riabbracciavo": "riabbracciare",
    "riabbraccin": "riabbracciare",
    "riabbraccino": "riabbracciare",
    "riabbraccio": "riabbracciare",
    "riabbracciò": "riabbracciare",
    "riabilita": "riabilitare",
    "riabilitai": "riabilitare",
    "riabilitammo": "riabilitare",
    "riabilitan": "riabilitare",
    "riabilitando": "riabilitare",
    "riabilitano": "riabilitare",
    "riabilitante": "riabilitare",
    "riabilitanti": "riabilitare",
    "riabilitar": "riabilitare",
    "riabilitaron": "riabilitare",
    "riabilitarono": "riabilitare",
    "riabilitasse": "riabilitare",
    "riabilitasser": "riabilitare",
    "riabilitassero": "riabilitare",
    "riabilitassi": "riabilitare",
    "riabilitassimo": "riabilitare",
    "riabilitaste": "riabilitare",
    "riabilitasti": "riabilitare",
    "riabilitata": "riabilitare",
    "riabilitate": "riabilitare",
    "riabilitati": "riabilitare",
    "riabilitativa": "riabilitativo",
    "riabilitative": "riabilitativo",
    "riabilitativi": "riabilitativo",
    "riabilitato": "riabilitare",
    "riabilitava": "riabilitare",
    "riabilitavamo": "riabilitare",
    "riabilitavan": "riabilitare",
    "riabilitavano": "riabilitare",
    "riabilitavate": "riabilitare",
    "riabilitavi": "riabilitare",
    "riabilitavo": "riabilitare",
    "riabilitazioni": "riabilitazione",
    "riabiliterai": "riabilitare",
    "riabiliteran": "riabilitare",
    "riabiliteranno": "riabilitare",
    "riabiliterebbe": "riabilitare",
    "riabiliterebber": "riabilitare",
    "riabiliterebbero": "riabilitare",
    "riabiliterei": "riabilitare",
    "riabiliteremmo": "riabilitare",
    "riabiliteremo": "riabilitare",
    "riabilitereste": "riabilitare",
    "riabiliteresti": "riabilitare",
    "riabiliterete": "riabilitare",
    "riabiliterà": "riabilitare",
    "riabiliterò": "riabilitare",
    "riabiliti": "riabilitare",
    "riabilitiamo": "riabilitare",
    "riabilitiate": "riabilitare",
    "riabilitin": "riabilitare",
    "riabilitino": "riabilitare",
    "riabilito": "riabilitare",
    "riabilitò": "riabilitare",
    "riabitua": "riabituare",
    "riabituai": "riabituare",
    "riabituammo": "riabituare",
    "riabituan": "riabituare",
    "riabituando": "riabituare",
    "riabituano": "riabituare",
    "riabituante": "riabituare",
    "riabituanti": "riabituare",
    "riabituar": "riabituare",
    "riabituaron": "riabituare",
    "riabituarono": "riabituare",
    "riabituasse": "riabituare",
    "riabituasser": "riabituare",
    "riabituassero": "riabituare",
    "riabituassi": "riabituare",
    "riabituassimo": "riabituare",
    "riabituaste": "riabituare",
    "riabituasti": "riabituare",
    "riabituata": "riabituare",
    "riabituate": "riabituare",
    "riabituati": "riabituare",
    "riabituato": "riabituare",
    "riabituava": "riabituare",
    "riabituavamo": "riabituare",
    "riabituavan": "riabituare",
    "riabituavano": "riabituare",
    "riabituavate": "riabituare",
    "riabituavi": "riabituare",
    "riabituavo": "riabituare",
    "riabituerai": "riabituare",
    "riabitueran": "riabituare",
    "riabitueranno": "riabituare",
    "riabituerebbe": "riabituare",
    "riabituerebber": "riabituare",
    "riabituerebbero": "riabituare",
    "riabituerei": "riabituare",
    "riabitueremmo": "riabituare",
    "riabitueremo": "riabituare",
    "riabituereste": "riabituare",
    "riabitueresti": "riabituare",
    "riabituerete": "riabituare",
    "riabituerà": "riabituare",
    "riabituerò": "riabituare",
    "riabitui": "riabituare",
    "riabituiamo": "riabituare",
    "riabituiate": "riabituare",
    "riabituin": "riabituare",
    "riabituino": "riabituare",
    "riabituo": "riabituare",
    "riabituò": "riabituare",
    "riaccenda": "riaccendere",
    "riaccendan": "riaccendere",
    "riaccendano": "riaccendere",
    "riaccende": "riaccendere",
    "riaccendemmo": "riaccendere",
    "riaccendendo": "riaccendere",
    "riaccendente": "riaccendere",
    "riaccendenti": "riaccendere",
    "riaccender": "riaccendere",
    "riaccenderai": "riaccendere",
    "riaccenderan": "riaccendere",
    "riaccenderanno": "riaccendere",
    "riaccenderebbe": "riaccendere",
    "riaccenderebber": "riaccendere",
    "riaccenderebbero": "riaccendere",
    "riaccenderei": "riaccendere",
    "riaccenderemmo": "riaccendere",
    "riaccenderemo": "riaccendere",
    "riaccendereste": "riaccendere",
    "riaccenderesti": "riaccendere",
    "riaccenderete": "riaccendere",
    "riaccenderà": "riaccendere",
    "riaccenderò": "riaccendere",
    "riaccendesse": "riaccendere",
    "riaccendesser": "riaccendere",
    "riaccendessero": "riaccendere",
    "riaccendessi": "riaccendere",
    "riaccendessimo": "riaccendere",
    "riaccendeste": "riaccendere",
    "riaccendesti": "riaccendere",
    "riaccendete": "riaccendere",
    "riaccendeva": "riaccendere",
    "riaccendevamo": "riaccendere",
    "riaccendevan": "riaccendere",
    "riaccendevano": "riaccendere",
    "riaccendevate": "riaccendere",
    "riaccendevi": "riaccendere",
    "riaccendevo": "riaccendere",
    "riaccendi": "riaccendere",
    "riaccendiamo": "riaccendere",
    "riaccendiate": "riaccendere",
    "riaccendo": "riaccendere",
    "riaccendon": "riaccendere",
    "riaccendono": "riaccendere",
    "riaccenna": "riaccennare",
    "riaccennai": "riaccennare",
    "riaccennammo": "riaccennare",
    "riaccennan": "riaccennare",
    "riaccennando": "riaccennare",
    "riaccennano": "riaccennare",
    "riaccennante": "riaccennare",
    "riaccennanti": "riaccennare",
    "riaccennar": "riaccennare",
    "riaccennaron": "riaccennare",
    "riaccennarono": "riaccennare",
    "riaccennasse": "riaccennare",
    "riaccennasser": "riaccennare",
    "riaccennassero": "riaccennare",
    "riaccennassi": "riaccennare",
    "riaccennassimo": "riaccennare",
    "riaccennaste": "riaccennare",
    "riaccennasti": "riaccennare",
    "riaccennata": "riaccennare",
    "riaccennate": "riaccennare",
    "riaccennati": "riaccennare",
    "riaccennato": "riaccennare",
    "riaccennava": "riaccennare",
    "riaccennavamo": "riaccennare",
    "riaccennavan": "riaccennare",
    "riaccennavano": "riaccennare",
    "riaccennavate": "riaccennare",
    "riaccennavi": "riaccennare",
    "riaccennavo": "riaccennare",
    "riaccennerai": "riaccennare",
    "riaccenneran": "riaccennare",
    "riaccenneranno": "riaccennare",
    "riaccennerebbe": "riaccennare",
    "riaccennerebber": "riaccennare",
    "riaccennerebbero": "riaccennare",
    "riaccennerei": "riaccennare",
    "riaccenneremmo": "riaccennare",
    "riaccenneremo": "riaccennare",
    "riaccennereste": "riaccennare",
    "riaccenneresti": "riaccennare",
    "riaccennerete": "riaccennare",
    "riaccennerà": "riaccennare",
    "riaccennerò": "riaccennare",
    "riaccenni": "riaccennare",
    "riaccenniamo": "riaccennare",
    "riaccenniate": "riaccennare",
    "riaccennin": "riaccennare",
    "riaccennino": "riaccennare",
    "riaccenno": "riaccennare",
    "riaccennò": "riaccennare",
    "riaccesa": "riaccendere",
    "riaccese": "riaccendere",
    "riacceser": "riaccendere",
    "riaccesero": "riaccendere",
    "riaccesi": "riaccendere",
    "riacceso": "riaccendere",
    "riaccesè": "riaccendere",
    "riacchiappa": "riacchiappare",
    "riacchiappai": "riacchiappare",
    "riacchiappammo": "riacchiappare",
    "riacchiappan": "riacchiappare",
    "riacchiappando": "riacchiappare",
    "riacchiappano": "riacchiappare",
    "riacchiappante": "riacchiappare",
    "riacchiappanti": "riacchiappare",
    "riacchiappar": "riacchiappare",
    "riacchiapparon": "riacchiappare",
    "riacchiapparono": "riacchiappare",
    "riacchiappasse": "riacchiappare",
    "riacchiappasser": "riacchiappare",
    "riacchiappassero": "riacchiappare",
    "riacchiappassi": "riacchiappare",
    "riacchiappassimo": "riacchiappare",
    "riacchiappaste": "riacchiappare",
    "riacchiappasti": "riacchiappare",
    "riacchiappata": "riacchiappare",
    "riacchiappate": "riacchiappare",
    "riacchiappati": "riacchiappare",
    "riacchiappato": "riacchiappare",
    "riacchiappava": "riacchiappare",
    "riacchiappavamo": "riacchiappare",
    "riacchiappavan": "riacchiappare",
    "riacchiappavano": "riacchiappare",
    "riacchiappavate": "riacchiappare",
    "riacchiappavi": "riacchiappare",
    "riacchiappavo": "riacchiappare",
    "riacchiapperai": "riacchiappare",
    "riacchiapperan": "riacchiappare",
    "riacchiapperanno": "riacchiappare",
    "riacchiapperebbe": "riacchiappare",
    "riacchiapperebber": "riacchiappare",
    "riacchiapperebbero": "riacchiappare",
    "riacchiapperei": "riacchiappare",
    "riacchiapperemmo": "riacchiappare",
    "riacchiapperemo": "riacchiappare",
    "riacchiappereste": "riacchiappare",
    "riacchiapperesti": "riacchiappare",
    "riacchiapperete": "riacchiappare",
    "riacchiapperà": "riacchiappare",
    "riacchiapperò": "riacchiappare",
    "riacchiappi": "riacchiappare",
    "riacchiappiamo": "riacchiappare",
    "riacchiappiate": "riacchiappare",
    "riacchiappin": "riacchiappare",
    "riacchiappino": "riacchiappare",
    "riacchiappo": "riacchiappare",
    "riacchiappò": "riacchiappare",
    "riaccomoda": "riaccomodare",
    "riaccomodai": "riaccomodare",
    "riaccomodammo": "riaccomodare",
    "riaccomodan": "riaccomodare",
    "riaccomodando": "riaccomodare",
    "riaccomodano": "riaccomodare",
    "riaccomodante": "riaccomodare",
    "riaccomodanti": "riaccomodare",
    "riaccomodar": "riaccomodare",
    "riaccomodaron": "riaccomodare",
    "riaccomodarono": "riaccomodare",
    "riaccomodasse": "riaccomodare",
    "riaccomodasser": "riaccomodare",
    "riaccomodassero": "riaccomodare",
    "riaccomodassi": "riaccomodare",
    "riaccomodassimo": "riaccomodare",
    "riaccomodaste": "riaccomodare",
    "riaccomodasti": "riaccomodare",
    "riaccomodata": "riaccomodare",
    "riaccomodate": "riaccomodare",
    "riaccomodati": "riaccomodare",
    "riaccomodato": "riaccomodare",
    "riaccomodava": "riaccomodare",
    "riaccomodavamo": "riaccomodare",
    "riaccomodavan": "riaccomodare",
    "riaccomodavano": "riaccomodare",
    "riaccomodavate": "riaccomodare",
    "riaccomodavi": "riaccomodare",
    "riaccomodavo": "riaccomodare",
    "riaccomoderai": "riaccomodare",
    "riaccomoderan": "riaccomodare",
    "riaccomoderanno": "riaccomodare",
    "riaccomoderebbe": "riaccomodare",
    "riaccomoderebber": "riaccomodare",
    "riaccomoderebbero": "riaccomodare",
    "riaccomoderei": "riaccomodare",
    "riaccomoderemmo": "riaccomodare",
    "riaccomoderemo": "riaccomodare",
    "riaccomodereste": "riaccomodare",
    "riaccomoderesti": "riaccomodare",
    "riaccomoderete": "riaccomodare",
    "riaccomoderà": "riaccomodare",
    "riaccomoderò": "riaccomodare",
    "riaccomodi": "riaccomodare",
    "riaccomodiamo": "riaccomodare",
    "riaccomodiate": "riaccomodare",
    "riaccomodin": "riaccomodare",
    "riaccomodino": "riaccomodare",
    "riaccomodo": "riaccomodare",
    "riaccomodò": "riaccomodare",
    "riaccompagna": "riaccompagnare",
    "riaccompagnai": "riaccompagnare",
    "riaccompagnammo": "riaccompagnare",
    "riaccompagnan": "riaccompagnare",
    "riaccompagnando": "riaccompagnare",
    "riaccompagnano": "riaccompagnare",
    "riaccompagnante": "riaccompagnare",
    "riaccompagnanti": "riaccompagnare",
    "riaccompagnar": "riaccompagnare",
    "riaccompagnaron": "riaccompagnare",
    "riaccompagnarono": "riaccompagnare",
    "riaccompagnasse": "riaccompagnare",
    "riaccompagnasser": "riaccompagnare",
    "riaccompagnassero": "riaccompagnare",
    "riaccompagnassi": "riaccompagnare",
    "riaccompagnassimo": "riaccompagnare",
    "riaccompagnaste": "riaccompagnare",
    "riaccompagnasti": "riaccompagnare",
    "riaccompagnata": "riaccompagnare",
    "riaccompagnate": "riaccompagnare",
    "riaccompagnati": "riaccompagnare",
    "riaccompagnato": "riaccompagnare",
    "riaccompagnava": "riaccompagnare",
    "riaccompagnavamo": "riaccompagnare",
    "riaccompagnavan": "riaccompagnare",
    "riaccompagnavano": "riaccompagnare",
    "riaccompagnavate": "riaccompagnare",
    "riaccompagnavi": "riaccompagnare",
    "riaccompagnavo": "riaccompagnare",
    "riaccompagnerai": "riaccompagnare",
    "riaccompagneran": "riaccompagnare",
    "riaccompagneranno": "riaccompagnare",
    "riaccompagnerebbe": "riaccompagnare",
    "riaccompagnerebber": "riaccompagnare",
    "riaccompagnerebbero": "riaccompagnare",
    "riaccompagnerei": "riaccompagnare",
    "riaccompagneremmo": "riaccompagnare",
    "riaccompagneremo": "riaccompagnare",
    "riaccompagnereste": "riaccompagnare",
    "riaccompagneresti": "riaccompagnare",
    "riaccompagnerete": "riaccompagnare",
    "riaccompagnerà": "riaccompagnare",
    "riaccompagnerò": "riaccompagnare",
    "riaccompagni": "riaccompagnare",
    "riaccompagniamo": "riaccompagnare",
    "riaccompagniate": "riaccompagnare",
    "riaccompagnin": "riaccompagnare",
    "riaccompagnino": "riaccompagnare",
    "riaccompagno": "riaccompagnare",
    "riaccompagnò": "riaccompagnare",
    "riaccorpamenti": "riaccorpamento",
    "riaccosta": "riaccostare",
    "riaccostai": "riaccostare",
    "riaccostammo": "riaccostare",
    "riaccostan": "riaccostare",
    "riaccostando": "riaccostare",
    "riaccostano": "riaccostare",
    "riaccostante": "riaccostare",
    "riaccostanti": "riaccostare",
    "riaccostar": "riaccostare",
    "riaccostaron": "riaccostare",
    "riaccostarono": "riaccostare",
    "riaccostasse": "riaccostare",
    "riaccostasser": "riaccostare",
    "riaccostassero": "riaccostare",
    "riaccostassi": "riaccostare",
    "riaccostassimo": "riaccostare",
    "riaccostaste": "riaccostare",
    "riaccostasti": "riaccostare",
    "riaccostata": "riaccostare",
    "riaccostate": "riaccostare",
    "riaccostati": "riaccostare",
    "riaccostato": "riaccostare",
    "riaccostava": "riaccostare",
    "riaccostavamo": "riaccostare",
    "riaccostavan": "riaccostare",
    "riaccostavano": "riaccostare",
    "riaccostavate": "riaccostare",
    "riaccostavi": "riaccostare",
    "riaccostavo": "riaccostare",
    "riaccosterai": "riaccostare",
    "riaccosteran": "riaccostare",
    "riaccosteranno": "riaccostare",
    "riaccosterebbe": "riaccostare",
    "riaccosterebber": "riaccostare",
    "riaccosterebbero": "riaccostare",
    "riaccosterei": "riaccostare",
    "riaccosteremmo": "riaccostare",
    "riaccosteremo": "riaccostare",
    "riaccostereste": "riaccostare",
    "riaccosteresti": "riaccostare",
    "riaccosterete": "riaccostare",
    "riaccosterà": "riaccostare",
    "riaccosterò": "riaccostare",
    "riaccosti": "riaccostare",
    "riaccostiamo": "riaccostare",
    "riaccostiate": "riaccostare",
    "riaccostin": "riaccostare",
    "riaccostino": "riaccostare",
    "riaccosto": "riaccostare",
    "riaccostò": "riaccostare",
    "riacquisa": "riacquisire",
    "riacquisan": "riacquisire",
    "riacquisano": "riacquisire",
    "riacquise": "riacquisire",
    "riacquisendo": "riacquisire",
    "riacquisente": "riacquisire",
    "riacquisenti": "riacquisire",
    "riacquisi": "riacquisire",
    "riacquisiamo": "riacquisire",
    "riacquisiate": "riacquisire",
    "riacquisii": "riacquisire",
    "riacquisimmo": "riacquisire",
    "riacquisir": "riacquisire",
    "riacquisirai": "riacquisire",
    "riacquisiran": "riacquisire",
    "riacquisiranno": "riacquisire",
    "riacquisirebbe": "riacquisire",
    "riacquisirebber": "riacquisire",
    "riacquisirebbero": "riacquisire",
    "riacquisirei": "riacquisire",
    "riacquisiremmo": "riacquisire",
    "riacquisiremo": "riacquisire",
    "riacquisireste": "riacquisire",
    "riacquisiresti": "riacquisire",
    "riacquisirete": "riacquisire",
    "riacquisiron": "riacquisire",
    "riacquisirono": "riacquisire",
    "riacquisirà": "riacquisire",
    "riacquisirò": "riacquisire",
    "riacquisisse": "riacquisire",
    "riacquisisser": "riacquisire",
    "riacquisissero": "riacquisire",
    "riacquisissi": "riacquisire",
    "riacquisissimo": "riacquisire",
    "riacquisiste": "riacquisire",
    "riacquisisti": "riacquisire",
    "riacquisita": "riacquisire",
    "riacquisite": "riacquisire",
    "riacquisiti": "riacquisire",
    "riacquisito": "riacquisire",
    "riacquisiva": "riacquisire",
    "riacquisivamo": "riacquisire",
    "riacquisivan": "riacquisire",
    "riacquisivano": "riacquisire",
    "riacquisivate": "riacquisire",
    "riacquisivi": "riacquisire",
    "riacquisivo": "riacquisire",
    "riacquiso": "riacquisire",
    "riacquison": "riacquisire",
    "riacquisono": "riacquisire",
    "riacquista": "riacquistare",
    "riacquistai": "riacquistare",
    "riacquistammo": "riacquistare",
    "riacquistan": "riacquistare",
    "riacquistando": "riacquistare",
    "riacquistano": "riacquistare",
    "riacquistante": "riacquistare",
    "riacquistanti": "riacquistare",
    "riacquistar": "riacquistare",
    "riacquistaron": "riacquistare",
    "riacquistarono": "riacquistare",
    "riacquistasse": "riacquistare",
    "riacquistasser": "riacquistare",
    "riacquistassero": "riacquistare",
    "riacquistassi": "riacquistare",
    "riacquistassimo": "riacquistare",
    "riacquistaste": "riacquistare",
    "riacquistasti": "riacquistare",
    "riacquistata": "riacquistare",
    "riacquistate": "riacquistare",
    "riacquistati": "riacquistare",
    "riacquistato": "riacquistare",
    "riacquistava": "riacquistare",
    "riacquistavamo": "riacquistare",
    "riacquistavan": "riacquistare",
    "riacquistavano": "riacquistare",
    "riacquistavate": "riacquistare",
    "riacquistavi": "riacquistare",
    "riacquistavo": "riacquistare",
    "riacquisterai": "riacquistare",
    "riacquisteran": "riacquistare",
    "riacquisteranno": "riacquistare",
    "riacquisterebbe": "riacquistare",
    "riacquisterebber": "riacquistare",
    "riacquisterebbero": "riacquistare",
    "riacquisterei": "riacquistare",
    "riacquisteremmo": "riacquistare",
    "riacquisteremo": "riacquistare",
    "riacquistereste": "riacquistare",
    "riacquisteresti": "riacquistare",
    "riacquisterete": "riacquistare",
    "riacquisterà": "riacquistare",
    "riacquisterò": "riacquistare",
    "riacquisti": "riacquisto",
    "riacquistiamo": "riacquistare",
    "riacquistiate": "riacquistare",
    "riacquistin": "riacquistare",
    "riacquistino": "riacquistare",
    "riacquisto": "riacquistare",
    "riacquistò": "riacquistare",
    "riacquisì": "riacquisire",
    "riacua": "riacuire",
    "riacuan": "riacuire",
    "riacuano": "riacuire",
    "riacue": "riacuire",
    "riacuendo": "riacuire",
    "riacuente": "riacuire",
    "riacuenti": "riacuire",
    "riacui": "riacuire",
    "riacuiamo": "riacuire",
    "riacuiate": "riacuire",
    "riacuii": "riacuire",
    "riacuimmo": "riacuire",
    "riacuir": "riacuire",
    "riacuirai": "riacuire",
    "riacuiran": "riacuire",
    "riacuiranno": "riacuire",
    "riacuirebbe": "riacuire",
    "riacuirebber": "riacuire",
    "riacuirebbero": "riacuire",
    "riacuirei": "riacuire",
    "riacuiremmo": "riacuire",
    "riacuiremo": "riacuire",
    "riacuireste": "riacuire",
    "riacuiresti": "riacuire",
    "riacuirete": "riacuire",
    "riacuiron": "riacuire",
    "riacuirono": "riacuire",
    "riacuirà": "riacuire",
    "riacuirò": "riacuire",
    "riacuisse": "riacuire",
    "riacuisser": "riacuire",
    "riacuissero": "riacuire",
    "riacuissi": "riacuire",
    "riacuissimo": "riacuire",
    "riacuiste": "riacuire",
    "riacuisti": "riacuire",
    "riacuita": "riacuire",
    "riacuite": "riacuire",
    "riacuiti": "riacuire",
    "riacuito": "riacuire",
    "riacuiva": "riacuire",
    "riacuivamo": "riacuire",
    "riacuivan": "riacuire",
    "riacuivano": "riacuire",
    "riacuivate": "riacuire",
    "riacuivi": "riacuire",
    "riacuivo": "riacuire",
    "riacuo": "riacuire",
    "riacuon": "riacuire",
    "riacuono": "riacuire",
    "riacutizza": "riacutizzare",
    "riacutizzai": "riacutizzare",
    "riacutizzammo": "riacutizzare",
    "riacutizzan": "riacutizzare",
    "riacutizzando": "riacutizzare",
    "riacutizzano": "riacutizzare",
    "riacutizzante": "riacutizzare",
    "riacutizzanti": "riacutizzare",
    "riacutizzar": "riacutizzare",
    "riacutizzaron": "riacutizzare",
    "riacutizzarono": "riacutizzare",
    "riacutizzasse": "riacutizzare",
    "riacutizzasser": "riacutizzare",
    "riacutizzassero": "riacutizzare",
    "riacutizzassi": "riacutizzare",
    "riacutizzassimo": "riacutizzare",
    "riacutizzaste": "riacutizzare",
    "riacutizzasti": "riacutizzare",
    "riacutizzata": "riacutizzare",
    "riacutizzate": "riacutizzare",
    "riacutizzati": "riacutizzare",
    "riacutizzato": "riacutizzare",
    "riacutizzava": "riacutizzare",
    "riacutizzavamo": "riacutizzare",
    "riacutizzavan": "riacutizzare",
    "riacutizzavano": "riacutizzare",
    "riacutizzavate": "riacutizzare",
    "riacutizzavi": "riacutizzare",
    "riacutizzavo": "riacutizzare",
    "riacutizzerai": "riacutizzare",
    "riacutizzeran": "riacutizzare",
    "riacutizzeranno": "riacutizzare",
    "riacutizzerebbe": "riacutizzare",
    "riacutizzerebber": "riacutizzare",
    "riacutizzerebbero": "riacutizzare",
    "riacutizzerei": "riacutizzare",
    "riacutizzeremmo": "riacutizzare",
    "riacutizzeremo": "riacutizzare",
    "riacutizzereste": "riacutizzare",
    "riacutizzeresti": "riacutizzare",
    "riacutizzerete": "riacutizzare",
    "riacutizzerà": "riacutizzare",
    "riacutizzerò": "riacutizzare",
    "riacutizzi": "riacutizzare",
    "riacutizziamo": "riacutizzare",
    "riacutizziate": "riacutizzare",
    "riacutizzin": "riacutizzare",
    "riacutizzino": "riacutizzare",
    "riacutizzo": "riacutizzare",
    "riacutizzò": "riacutizzare",
    "riacuì": "riacuire",
    "riadatta": "riadattare",
    "riadattai": "riadattare",
    "riadattammo": "riadattare",
    "riadattan": "riadattare",
    "riadattando": "riadattare",
    "riadattano": "riadattare",
    "riadattante": "riadattare",
    "riadattanti": "riadattare",
    "riadattar": "riadattare",
    "riadattaron": "riadattare",
    "riadattarono": "riadattare",
    "riadattasse": "riadattare",
    "riadattasser": "riadattare",
    "riadattassero": "riadattare",
    "riadattassi": "riadattare",
    "riadattassimo": "riadattare",
    "riadattaste": "riadattare",
    "riadattasti": "riadattare",
    "riadattata": "riadattare",
    "riadattate": "riadattare",
    "riadattati": "riadattare",
    "riadattato": "riadattare",
    "riadattava": "riadattare",
    "riadattavamo": "riadattare",
    "riadattavan": "riadattare",
    "riadattavano": "riadattare",
    "riadattavate": "riadattare",
    "riadattavi": "riadattare",
    "riadattavo": "riadattare",
    "riadatterai": "riadattare",
    "riadatteran": "riadattare",
    "riadatteranno": "riadattare",
    "riadatterebbe": "riadattare",
    "riadatterebber": "riadattare",
    "riadatterebbero": "riadattare",
    "riadatterei": "riadattare",
    "riadatteremmo": "riadattare",
    "riadatteremo": "riadattare",
    "riadattereste": "riadattare",
    "riadatteresti": "riadattare",
    "riadatterete": "riadattare",
    "riadatterà": "riadattare",
    "riadatterò": "riadattare",
    "riadatti": "riadattare",
    "riadattiamo": "riadattare",
    "riadattiate": "riadattare",
    "riadattin": "riadattare",
    "riadattino": "riadattare",
    "riadatto": "riadattare",
    "riadattò": "riadattare",
    "riaddormenta": "riaddormentare",
    "riaddormentai": "riaddormentare",
    "riaddormentammo": "riaddormentare",
    "riaddormentan": "riaddormentare",
    "riaddormentando": "riaddormentare",
    "riaddormentano": "riaddormentare",
    "riaddormentante": "riaddormentare",
    "riaddormentanti": "riaddormentare",
    "riaddormentar": "riaddormentare",
    "riaddormentaron": "riaddormentare",
    "riaddormentarono": "riaddormentare",
    "riaddormentasse": "riaddormentare",
    "riaddormentasser": "riaddormentare",
    "riaddormentassero": "riaddormentare",
    "riaddormentassi": "riaddormentare",
    "riaddormentassimo": "riaddormentare",
    "riaddormentaste": "riaddormentare",
    "riaddormentasti": "riaddormentare",
    "riaddormentata": "riaddormentare",
    "riaddormentate": "riaddormentare",
    "riaddormentati": "riaddormentare",
    "riaddormentato": "riaddormentare",
    "riaddormentava": "riaddormentare",
    "riaddormentavamo": "riaddormentare",
    "riaddormentavan": "riaddormentare",
    "riaddormentavano": "riaddormentare",
    "riaddormentavate": "riaddormentare",
    "riaddormentavi": "riaddormentare",
    "riaddormentavo": "riaddormentare",
    "riaddormenterai": "riaddormentare",
    "riaddormenteran": "riaddormentare",
    "riaddormenteranno": "riaddormentare",
    "riaddormenterebbe": "riaddormentare",
    "riaddormenterebber": "riaddormentare",
    "riaddormenterebbero": "riaddormentare",
    "riaddormenterei": "riaddormentare",
    "riaddormenteremmo": "riaddormentare",
    "riaddormenteremo": "riaddormentare",
    "riaddormentereste": "riaddormentare",
    "riaddormenteresti": "riaddormentare",
    "riaddormenterete": "riaddormentare",
    "riaddormenterà": "riaddormentare",
    "riaddormenterò": "riaddormentare",
    "riaddormenti": "riaddormentare",
    "riaddormentiamo": "riaddormentare",
    "riaddormentiate": "riaddormentare",
    "riaddormentin": "riaddormentare",
    "riaddormentino": "riaddormentare",
    "riaddormento": "riaddormentare",
    "riaddormentò": "riaddormentare",
    "riadegua": "riadeguare",
    "riadeguai": "riadeguare",
    "riadeguammo": "riadeguare",
    "riadeguan": "riadeguare",
    "riadeguando": "riadeguare",
    "riadeguano": "riadeguare",
    "riadeguante": "riadeguare",
    "riadeguanti": "riadeguare",
    "riadeguar": "riadeguare",
    "riadeguaron": "riadeguare",
    "riadeguarono": "riadeguare",
    "riadeguasse": "riadeguare",
    "riadeguasser": "riadeguare",
    "riadeguassero": "riadeguare",
    "riadeguassi": "riadeguare",
    "riadeguassimo": "riadeguare",
    "riadeguaste": "riadeguare",
    "riadeguasti": "riadeguare",
    "riadeguata": "riadeguare",
    "riadeguate": "riadeguare",
    "riadeguati": "riadeguare",
    "riadeguato": "riadeguare",
    "riadeguava": "riadeguare",
    "riadeguavamo": "riadeguare",
    "riadeguavan": "riadeguare",
    "riadeguavano": "riadeguare",
    "riadeguavate": "riadeguare",
    "riadeguavi": "riadeguare",
    "riadeguavo": "riadeguare",
    "riadeguerai": "riadeguare",
    "riadegueran": "riadeguare",
    "riadegueranno": "riadeguare",
    "riadeguerebbe": "riadeguare",
    "riadeguerebber": "riadeguare",
    "riadeguerebbero": "riadeguare",
    "riadeguerei": "riadeguare",
    "riadegueremmo": "riadeguare",
    "riadegueremo": "riadeguare",
    "riadeguereste": "riadeguare",
    "riadegueresti": "riadeguare",
    "riadeguerete": "riadeguare",
    "riadeguerà": "riadeguare",
    "riadeguerò": "riadeguare",
    "riadegui": "riadeguare",
    "riadeguiamo": "riadeguare",
    "riadeguiate": "riadeguare",
    "riadeguin": "riadeguare",
    "riadeguino": "riadeguare",
    "riadeguo": "riadeguare",
    "riadeguò": "riadeguare",
    "riaffaccerai": "riaffacciare",
    "riaffacceran": "riaffacciare",
    "riaffacceranno": "riaffacciare",
    "riaffaccerebbe": "riaffacciare",
    "riaffaccerebber": "riaffacciare",
    "riaffaccerebbero": "riaffacciare",
    "riaffaccerei": "riaffacciare",
    "riaffacceremmo": "riaffacciare",
    "riaffacceremo": "riaffacciare",
    "riaffaccereste": "riaffacciare",
    "riaffacceresti": "riaffacciare",
    "riaffaccerete": "riaffacciare",
    "riaffaccerà": "riaffacciare",
    "riaffaccerò": "riaffacciare",
    "riaffacci": "riaffacciare",
    "riaffaccia": "riaffacciare",
    "riaffacciai": "riaffacciare",
    "riaffacciammo": "riaffacciare",
    "riaffacciamo": "riaffacciare",
    "riaffaccian": "riaffacciare",
    "riaffacciando": "riaffacciare",
    "riaffacciano": "riaffacciare",
    "riaffacciante": "riaffacciare",
    "riaffaccianti": "riaffacciare",
    "riaffacciar": "riaffacciare",
    "riaffacciaron": "riaffacciare",
    "riaffacciarono": "riaffacciare",
    "riaffacciasse": "riaffacciare",
    "riaffacciasser": "riaffacciare",
    "riaffacciassero": "riaffacciare",
    "riaffacciassi": "riaffacciare",
    "riaffacciassimo": "riaffacciare",
    "riaffacciaste": "riaffacciare",
    "riaffacciasti": "riaffacciare",
    "riaffacciata": "riaffacciare",
    "riaffacciate": "riaffacciare",
    "riaffacciati": "riaffacciare",
    "riaffacciato": "riaffacciare",
    "riaffacciava": "riaffacciare",
    "riaffacciavamo": "riaffacciare",
    "riaffacciavan": "riaffacciare",
    "riaffacciavano": "riaffacciare",
    "riaffacciavate": "riaffacciare",
    "riaffacciavi": "riaffacciare",
    "riaffacciavo": "riaffacciare",
    "riaffaccin": "riaffacciare",
    "riaffaccino": "riaffacciare",
    "riaffaccio": "riaffacciare",
    "riaffacciò": "riaffacciare",
    "riafferma": "riaffermare",
    "riaffermai": "riaffermare",
    "riaffermammo": "riaffermare",
    "riafferman": "riaffermare",
    "riaffermando": "riaffermare",
    "riaffermano": "riaffermare",
    "riaffermante": "riaffermare",
    "riaffermanti": "riaffermare",
    "riaffermar": "riaffermare",
    "riaffermaron": "riaffermare",
    "riaffermarono": "riaffermare",
    "riaffermasse": "riaffermare",
    "riaffermasser": "riaffermare",
    "riaffermassero": "riaffermare",
    "riaffermassi": "riaffermare",
    "riaffermassimo": "riaffermare",
    "riaffermaste": "riaffermare",
    "riaffermasti": "riaffermare",
    "riaffermata": "riaffermare",
    "riaffermate": "riaffermare",
    "riaffermati": "riaffermare",
    "riaffermato": "riaffermare",
    "riaffermava": "riaffermare",
    "riaffermavamo": "riaffermare",
    "riaffermavan": "riaffermare",
    "riaffermavano": "riaffermare",
    "riaffermavate": "riaffermare",
    "riaffermavi": "riaffermare",
    "riaffermavo": "riaffermare",
    "riaffermazioni": "riaffermazione",
    "riaffermerai": "riaffermare",
    "riaffermeran": "riaffermare",
    "riaffermeranno": "riaffermare",
    "riaffermerebbe": "riaffermare",
    "riaffermerebber": "riaffermare",
    "riaffermerebbero": "riaffermare",
    "riaffermerei": "riaffermare",
    "riaffermeremmo": "riaffermare",
    "riaffermeremo": "riaffermare",
    "riaffermereste": "riaffermare",
    "riaffermeresti": "riaffermare",
    "riaffermerete": "riaffermare",
    "riaffermerà": "riaffermare",
    "riaffermerò": "riaffermare",
    "riaffermi": "riaffermare",
    "riaffermiamo": "riaffermare",
    "riaffermiate": "riaffermare",
    "riaffermin": "riaffermare",
    "riaffermino": "riaffermare",
    "riaffermo": "riaffermare",
    "riaffermò": "riaffermare",
    "riafferra": "riafferrare",
    "riafferrai": "riafferrare",
    "riafferrammo": "riafferrare",
    "riafferran": "riafferrare",
    "riafferrando": "riafferrare",
    "riafferrano": "riafferrare",
    "riafferrante": "riafferrare",
    "riafferranti": "riafferrare",
    "riafferrar": "riafferrare",
    "riafferraron": "riafferrare",
    "riafferrarono": "riafferrare",
    "riafferrasse": "riafferrare",
    "riafferrasser": "riafferrare",
    "riafferrassero": "riafferrare",
    "riafferrassi": "riafferrare",
    "riafferrassimo": "riafferrare",
    "riafferraste": "riafferrare",
    "riafferrasti": "riafferrare",
    "riafferrata": "riafferrare",
    "riafferrate": "riafferrare",
    "riafferrati": "riafferrare",
    "riafferrato": "riafferrare",
    "riafferrava": "riafferrare",
    "riafferravamo": "riafferrare",
    "riafferravan": "riafferrare",
    "riafferravano": "riafferrare",
    "riafferravate": "riafferrare",
    "riafferravi": "riafferrare",
    "riafferravo": "riafferrare",
    "riafferrerai": "riafferrare",
    "riafferreran": "riafferrare",
    "riafferreranno": "riafferrare",
    "riafferrerebbe": "riafferrare",
    "riafferrerebber": "riafferrare",
    "riafferrerebbero": "riafferrare",
    "riafferrerei": "riafferrare",
    "riafferreremmo": "riafferrare",
    "riafferreremo": "riafferrare",
    "riafferrereste": "riafferrare",
    "riafferreresti": "riafferrare",
    "riafferrerete": "riafferrare",
    "riafferrerà": "riafferrare",
    "riafferrerò": "riafferrare",
    "riafferri": "riafferrare",
    "riafferriamo": "riafferrare",
    "riafferriate": "riafferrare",
    "riafferrin": "riafferrare",
    "riafferrino": "riafferrare",
    "riafferro": "riafferrare",
    "riafferrò": "riafferrare",
    "riaffeziona": "riaffezionare",
    "riaffezionai": "riaffezionare",
    "riaffezionammo": "riaffezionare",
    "riaffezionan": "riaffezionare",
    "riaffezionando": "riaffezionare",
    "riaffezionano": "riaffezionare",
    "riaffezionante": "riaffezionare",
    "riaffezionanti": "riaffezionare",
    "riaffezionar": "riaffezionare",
    "riaffezionaron": "riaffezionare",
    "riaffezionarono": "riaffezionare",
    "riaffezionasse": "riaffezionare",
    "riaffezionasser": "riaffezionare",
    "riaffezionassero": "riaffezionare",
    "riaffezionassi": "riaffezionare",
    "riaffezionassimo": "riaffezionare",
    "riaffezionaste": "riaffezionare",
    "riaffezionasti": "riaffezionare",
    "riaffezionata": "riaffezionare",
    "riaffezionate": "riaffezionare",
    "riaffezionati": "riaffezionare",
    "riaffezionato": "riaffezionare",
    "riaffezionava": "riaffezionare",
    "riaffezionavamo": "riaffezionare",
    "riaffezionavan": "riaffezionare",
    "riaffezionavano": "riaffezionare",
    "riaffezionavate": "riaffezionare",
    "riaffezionavi": "riaffezionare",
    "riaffezionavo": "riaffezionare",
    "riaffezionerai": "riaffezionare",
    "riaffezioneran": "riaffezionare",
    "riaffezioneranno": "riaffezionare",
    "riaffezionerebbe": "riaffezionare",
    "riaffezionerebber": "riaffezionare",
    "riaffezionerebbero": "riaffezionare",
    "riaffezionerei": "riaffezionare",
    "riaffezioneremmo": "riaffezionare",
    "riaffezioneremo": "riaffezionare",
    "riaffezionereste": "riaffezionare",
    "riaffezioneresti": "riaffezionare",
    "riaffezionerete": "riaffezionare",
    "riaffezionerà": "riaffezionare",
    "riaffezionerò": "riaffezionare",
    "riaffezioni": "riaffezionare",
    "riaffezioniamo": "riaffezionare",
    "riaffezioniate": "riaffezionare",
    "riaffezionin": "riaffezionare",
    "riaffezionino": "riaffezionare",
    "riaffeziono": "riaffezionare",
    "riaffezionò": "riaffezionare",
    "riaggiusta": "riaggiustare",
    "riaggiustai": "riaggiustare",
    "riaggiustamenti": "riaggiustamento",
    "riaggiustammo": "riaggiustare",
    "riaggiustan": "riaggiustare",
    "riaggiustando": "riaggiustare",
    "riaggiustano": "riaggiustare",
    "riaggiustante": "riaggiustare",
    "riaggiustanti": "riaggiustare",
    "riaggiustar": "riaggiustare",
    "riaggiustaron": "riaggiustare",
    "riaggiustarono": "riaggiustare",
    "riaggiustasse": "riaggiustare",
    "riaggiustasser": "riaggiustare",
    "riaggiustassero": "riaggiustare",
    "riaggiustassi": "riaggiustare",
    "riaggiustassimo": "riaggiustare",
    "riaggiustaste": "riaggiustare",
    "riaggiustasti": "riaggiustare",
    "riaggiustata": "riaggiustare",
    "riaggiustate": "riaggiustare",
    "riaggiustati": "riaggiustare",
    "riaggiustato": "riaggiustare",
    "riaggiustava": "riaggiustare",
    "riaggiustavamo": "riaggiustare",
    "riaggiustavan": "riaggiustare",
    "riaggiustavano": "riaggiustare",
    "riaggiustavate": "riaggiustare",
    "riaggiustavi": "riaggiustare",
    "riaggiustavo": "riaggiustare",
    "riaggiusterai": "riaggiustare",
    "riaggiusteran": "riaggiustare",
    "riaggiusteranno": "riaggiustare",
    "riaggiusterebbe": "riaggiustare",
    "riaggiusterebber": "riaggiustare",
    "riaggiusterebbero": "riaggiustare",
    "riaggiusterei": "riaggiustare",
    "riaggiusteremmo": "riaggiustare",
    "riaggiusteremo": "riaggiustare",
    "riaggiustereste": "riaggiustare",
    "riaggiusteresti": "riaggiustare",
    "riaggiusterete": "riaggiustare",
    "riaggiusterà": "riaggiustare",
    "riaggiusterò": "riaggiustare",
    "riaggiusti": "riaggiustare",
    "riaggiustiamo": "riaggiustare",
    "riaggiustiate": "riaggiustare",
    "riaggiustin": "riaggiustare",
    "riaggiustino": "riaggiustare",
    "riaggiusto": "riaggiustare",
    "riaggiustò": "riaggiustare",
    "riaggrava": "riaggravare",
    "riaggravai": "riaggravare",
    "riaggravammo": "riaggravare",
    "riaggravan": "riaggravare",
    "riaggravando": "riaggravare",
    "riaggravano": "riaggravare",
    "riaggravante": "riaggravare",
    "riaggravanti": "riaggravare",
    "riaggravar": "riaggravare",
    "riaggravaron": "riaggravare",
    "riaggravarono": "riaggravare",
    "riaggravasse": "riaggravare",
    "riaggravasser": "riaggravare",
    "riaggravassero": "riaggravare",
    "riaggravassi": "riaggravare",
    "riaggravassimo": "riaggravare",
    "riaggravaste": "riaggravare",
    "riaggravasti": "riaggravare",
    "riaggravata": "riaggravare",
    "riaggravate": "riaggravare",
    "riaggravati": "riaggravare",
    "riaggravato": "riaggravare",
    "riaggravava": "riaggravare",
    "riaggravavamo": "riaggravare",
    "riaggravavan": "riaggravare",
    "riaggravavano": "riaggravare",
    "riaggravavate": "riaggravare",
    "riaggravavi": "riaggravare",
    "riaggravavo": "riaggravare",
    "riaggraverai": "riaggravare",
    "riaggraveran": "riaggravare",
    "riaggraveranno": "riaggravare",
    "riaggraverebbe": "riaggravare",
    "riaggraverebber": "riaggravare",
    "riaggraverebbero": "riaggravare",
    "riaggraverei": "riaggravare",
    "riaggraveremmo": "riaggravare",
    "riaggraveremo": "riaggravare",
    "riaggravereste": "riaggravare",
    "riaggraveresti": "riaggravare",
    "riaggraverete": "riaggravare",
    "riaggraverà": "riaggravare",
    "riaggraverò": "riaggravare",
    "riaggravi": "riaggravare",
    "riaggraviamo": "riaggravare",
    "riaggraviate": "riaggravare",
    "riaggravin": "riaggravare",
    "riaggravino": "riaggravare",
    "riaggravo": "riaggravare",
    "riaggravò": "riaggravare",
    "riaggregazioni": "riaggregazione",
    "riallaccerai": "riallacciare",
    "riallacceran": "riallacciare",
    "riallacceranno": "riallacciare",
    "riallaccerebbe": "riallacciare",
    "riallaccerebber": "riallacciare",
    "riallaccerebbero": "riallacciare",
    "riallaccerei": "riallacciare",
    "riallacceremmo": "riallacciare",
    "riallacceremo": "riallacciare",
    "riallaccereste": "riallacciare",
    "riallacceresti": "riallacciare",
    "riallaccerete": "riallacciare",
    "riallaccerà": "riallacciare",
    "riallaccerò": "riallacciare",
    "riallacci": "riallacciare",
    "riallaccia": "riallacciare",
    "riallacciai": "riallacciare",
    "riallacciammo": "riallacciare",
    "riallacciamo": "riallacciare",
    "riallaccian": "riallacciare",
    "riallacciando": "riallacciare",
    "riallacciano": "riallacciare",
    "riallacciante": "riallacciare",
    "riallaccianti": "riallacciare",
    "riallacciar": "riallacciare",
    "riallacciaron": "riallacciare",
    "riallacciarono": "riallacciare",
    "riallacciasse": "riallacciare",
    "riallacciasser": "riallacciare",
    "riallacciassero": "riallacciare",
    "riallacciassi": "riallacciare",
    "riallacciassimo": "riallacciare",
    "riallacciaste": "riallacciare",
    "riallacciasti": "riallacciare",
    "riallacciata": "riallacciare",
    "riallacciate": "riallacciare",
    "riallacciati": "riallacciare",
    "riallacciato": "riallacciare",
    "riallacciava": "riallacciare",
    "riallacciavamo": "riallacciare",
    "riallacciavan": "riallacciare",
    "riallacciavano": "riallacciare",
    "riallacciavate": "riallacciare",
    "riallacciavi": "riallacciare",
    "riallacciavo": "riallacciare",
    "riallaccin": "riallacciare",
    "riallaccino": "riallacciare",
    "riallaccio": "riallacciare",
    "riallacciò": "riallacciare",
    "riallarga": "riallargare",
    "riallargai": "riallargare",
    "riallargammo": "riallargare",
    "riallargan": "riallargare",
    "riallargando": "riallargare",
    "riallargano": "riallargare",
    "riallargante": "riallargare",
    "riallarganti": "riallargare",
    "riallargar": "riallargare",
    "riallargaron": "riallargare",
    "riallargarono": "riallargare",
    "riallargasse": "riallargare",
    "riallargasser": "riallargare",
    "riallargassero": "riallargare",
    "riallargassi": "riallargare",
    "riallargassimo": "riallargare",
    "riallargaste": "riallargare",
    "riallargasti": "riallargare",
    "riallargata": "riallargare",
    "riallargate": "riallargare",
    "riallargati": "riallargare",
    "riallargato": "riallargare",
    "riallargava": "riallargare",
    "riallargavamo": "riallargare",
    "riallargavan": "riallargare",
    "riallargavano": "riallargare",
    "riallargavate": "riallargare",
    "riallargavi": "riallargare",
    "riallargavo": "riallargare",
    "riallargherai": "riallargare",
    "riallargheran": "riallargare",
    "riallargheranno": "riallargare",
    "riallargherebbe": "riallargare",
    "riallargherebber": "riallargare",
    "riallargherebbero": "riallargare",
    "riallargherei": "riallargare",
    "riallargheremmo": "riallargare",
    "riallargheremo": "riallargare",
    "riallarghereste": "riallargare",
    "riallargheresti": "riallargare",
    "riallargherete": "riallargare",
    "riallargherà": "riallargare",
    "riallargherò": "riallargare",
    "riallarghi": "riallargare",
    "riallarghiamo": "riallargare",
    "riallarghiate": "riallargare",
    "riallarghin": "riallargare",
    "riallarghino": "riallargare",
    "riallargo": "riallargare",
    "riallargò": "riallargare",
    "riallineamenti": "riallineamento",
    "riallunga": "riallungare",
    "riallungai": "riallungare",
    "riallungammo": "riallungare",
    "riallungan": "riallungare",
    "riallungando": "riallungare",
    "riallungano": "riallungare",
    "riallungante": "riallungare",
    "riallunganti": "riallungare",
    "riallungar": "riallungare",
    "riallungaron": "riallungare",
    "riallungarono": "riallungare",
    "riallungasse": "riallungare",
    "riallungasser": "riallungare",
    "riallungassero": "riallungare",
    "riallungassi": "riallungare",
    "riallungassimo": "riallungare",
    "riallungaste": "riallungare",
    "riallungasti": "riallungare",
    "riallungata": "riallungare",
    "riallungate": "riallungare",
    "riallungati": "riallungare",
    "riallungato": "riallungare",
    "riallungava": "riallungare",
    "riallungavamo": "riallungare",
    "riallungavan": "riallungare",
    "riallungavano": "riallungare",
    "riallungavate": "riallungare",
    "riallungavi": "riallungare",
    "riallungavo": "riallungare",
    "riallungherai": "riallungare",
    "riallungheran": "riallungare",
    "riallungheranno": "riallungare",
    "riallungherebbe": "riallungare",
    "riallungherebber": "riallungare",
    "riallungherebbero": "riallungare",
    "riallungherei": "riallungare",
    "riallungheremmo": "riallungare",
    "riallungheremo": "riallungare",
    "riallunghereste": "riallungare",
    "riallungheresti": "riallungare",
    "riallungherete": "riallungare",
    "riallungherà": "riallungare",
    "riallungherò": "riallungare",
    "riallunghi": "riallungare",
    "riallunghiamo": "riallungare",
    "riallunghiate": "riallungare",
    "riallunghin": "riallungare",
    "riallunghino": "riallungare",
    "riallungo": "riallungare",
    "riallungò": "riallungare",
    "rialza": "rialzare",
    "rialzai": "rialzare",
    "rialzammo": "rialzare",
    "rialzan": "rialzare",
    "rialzando": "rialzare",
    "rialzano": "rialzare",
    "rialzante": "rialzare",
    "rialzanti": "rialzare",
    "rialzar": "rialzare",
    "rialzaron": "rialzare",
    "rialzarono": "rialzare",
    "rialzasse": "rialzare",
    "rialzasser": "rialzare",
    "rialzassero": "rialzare",
    "rialzassi": "rialzare",
    "rialzassimo": "rialzare",
    "rialzaste": "rialzare",
    "rialzasti": "rialzare",
    "rialzata": "rialzato",
    "rialzate": "rialzato",
    "rialzati": "rialzato",
    "rialzato": "rialzare",
    "rialzava": "rialzare",
    "rialzavamo": "rialzare",
    "rialzavan": "rialzare",
    "rialzavano": "rialzare",
    "rialzavate": "rialzare",
    "rialzavi": "rialzare",
    "rialzavo": "rialzare",
    "rialzerai": "rialzare",
    "rialzeran": "rialzare",
    "rialzeranno": "rialzare",
    "rialzerebbe": "rialzare",
    "rialzerebber": "rialzare",
    "rialzerebbero": "rialzare",
    "rialzerei": "rialzare",
    "rialzeremmo": "rialzare",
    "rialzeremo": "rialzare",
    "rialzereste": "rialzare",
    "rialzeresti": "rialzare",
    "rialzerete": "rialzare",
    "rialzerà": "rialzare",
    "rialzerò": "rialzare",
    "rialzi": "rialzo",
    "rialziamo": "rialzare",
    "rialziate": "rialzare",
    "rialzin": "rialzare",
    "rialzino": "rialzare",
    "rialziste": "rialzista",
    "rialzisti": "rialzista",
    "rialzo": "rialzare",
    "rialzò": "rialzare",
    "riama": "riamare",
    "riamai": "riamare",
    "riamammo": "riamare",
    "riaman": "riamare",
    "riamando": "riamare",
    "riamano": "riamare",
    "riamante": "riamare",
    "riamanti": "riamare",
    "riamar": "riamare",
    "riamaron": "riamare",
    "riamarono": "riamare",
    "riamasse": "riamare",
    "riamasser": "riamare",
    "riamassero": "riamare",
    "riamassi": "riamare",
    "riamassimo": "riamare",
    "riamaste": "riamare",
    "riamasti": "riamare",
    "riamata": "riamare",
    "riamate": "riamare",
    "riamati": "riamare",
    "riamato": "riamare",
    "riamava": "riamare",
    "riamavamo": "riamare",
    "riamavan": "riamare",
    "riamavano": "riamare",
    "riamavate": "riamare",
    "riamavi": "riamare",
    "riamavo": "riamare",
    "riamerai": "riamare",
    "riameran": "riamare",
    "riameranno": "riamare",
    "riamerebbe": "riamare",
    "riamerebber": "riamare",
    "riamerebbero": "riamare",
    "riamerei": "riamare",
    "riameremmo": "riamare",
    "riameremo": "riamare",
    "riamereste": "riamare",
    "riameresti": "riamare",
    "riamerete": "riamare",
    "riamerà": "riamare",
    "riamerò": "riamare",
    "riami": "riamare",
    "riamiamo": "riamare",
    "riamiate": "riamare",
    "riamin": "riamare",
    "riamino": "riamare",
    "riammala": "riammalare",
    "riammalai": "riammalare",
    "riammalammo": "riammalare",
    "riammalan": "riammalare",
    "riammalando": "riammalare",
    "riammalano": "riammalare",
    "riammalante": "riammalare",
    "riammalanti": "riammalare",
    "riammalar": "riammalare",
    "riammalaron": "riammalare",
    "riammalarono": "riammalare",
    "riammalasse": "riammalare",
    "riammalasser": "riammalare",
    "riammalassero": "riammalare",
    "riammalassi": "riammalare",
    "riammalassimo": "riammalare",
    "riammalaste": "riammalare",
    "riammalasti": "riammalare",
    "riammalata": "riammalare",
    "riammalate": "riammalare",
    "riammalati": "riammalare",
    "riammalato": "riammalare",
    "riammalava": "riammalare",
    "riammalavamo": "riammalare",
    "riammalavan": "riammalare",
    "riammalavano": "riammalare",
    "riammalavate": "riammalare",
    "riammalavi": "riammalare",
    "riammalavo": "riammalare",
    "riammalerai": "riammalare",
    "riammaleran": "riammalare",
    "riammaleranno": "riammalare",
    "riammalerebbe": "riammalare",
    "riammalerebber": "riammalare",
    "riammalerebbero": "riammalare",
    "riammalerei": "riammalare",
    "riammaleremmo": "riammalare",
    "riammaleremo": "riammalare",
    "riammalereste": "riammalare",
    "riammaleresti": "riammalare",
    "riammalerete": "riammalare",
    "riammalerà": "riammalare",
    "riammalerò": "riammalare",
    "riammali": "riammalare",
    "riammaliamo": "riammalare",
    "riammaliate": "riammalare",
    "riammalin": "riammalare",
    "riammalino": "riammalare",
    "riammalo": "riammalare",
    "riammalò": "riammalare",
    "riammessa": "riammettere",
    "riammesse": "riammettere",
    "riammessi": "riammettere",
    "riammesso": "riammettere",
    "riammetta": "riammettere",
    "riammettan": "riammettere",
    "riammettano": "riammettere",
    "riammette": "riammettere",
    "riammettemmo": "riammettere",
    "riammettendo": "riammettere",
    "riammettente": "riammettere",
    "riammettenti": "riammettere",
    "riammetter": "riammettere",
    "riammetterai": "riammettere",
    "riammetteran": "riammettere",
    "riammetteranno": "riammettere",
    "riammetterebbe": "riammettere",
    "riammetterebber": "riammettere",
    "riammetterebbero": "riammettere",
    "riammetterei": "riammettere",
    "riammetteremmo": "riammettere",
    "riammetteremo": "riammettere",
    "riammettereste": "riammettere",
    "riammetteresti": "riammettere",
    "riammetterete": "riammettere",
    "riammetterà": "riammettere",
    "riammetterò": "riammettere",
    "riammettesse": "riammettere",
    "riammettesser": "riammettere",
    "riammettessero": "riammettere",
    "riammettessi": "riammettere",
    "riammettessimo": "riammettere",
    "riammetteste": "riammettere",
    "riammettesti": "riammettere",
    "riammettete": "riammettere",
    "riammetteva": "riammettere",
    "riammettevamo": "riammettere",
    "riammettevan": "riammettere",
    "riammettevano": "riammettere",
    "riammettevate": "riammettere",
    "riammettevi": "riammettere",
    "riammettevo": "riammettere",
    "riammetti": "riammettere",
    "riammettiamo": "riammettere",
    "riammettiate": "riammettere",
    "riammetto": "riammettere",
    "riammetton": "riammettere",
    "riammettono": "riammettere",
    "riammise": "riammettere",
    "riammiser": "riammettere",
    "riammisero": "riammettere",
    "riammisi": "riammettere",
    "riammissioni": "riammissione",
    "riammogli": "riammogliare",
    "riammoglia": "riammogliare",
    "riammogliai": "riammogliare",
    "riammogliammo": "riammogliare",
    "riammogliamo": "riammogliare",
    "riammoglian": "riammogliare",
    "riammogliando": "riammogliare",
    "riammogliano": "riammogliare",
    "riammogliante": "riammogliare",
    "riammoglianti": "riammogliare",
    "riammogliar": "riammogliare",
    "riammogliaron": "riammogliare",
    "riammogliarono": "riammogliare",
    "riammogliasse": "riammogliare",
    "riammogliasser": "riammogliare",
    "riammogliassero": "riammogliare",
    "riammogliassi": "riammogliare",
    "riammogliassimo": "riammogliare",
    "riammogliaste": "riammogliare",
    "riammogliasti": "riammogliare",
    "riammogliata": "riammogliare",
    "riammogliate": "riammogliare",
    "riammogliati": "riammogliare",
    "riammogliato": "riammogliare",
    "riammogliava": "riammogliare",
    "riammogliavamo": "riammogliare",
    "riammogliavan": "riammogliare",
    "riammogliavano": "riammogliare",
    "riammogliavate": "riammogliare",
    "riammogliavi": "riammogliare",
    "riammogliavo": "riammogliare",
    "riammoglierai": "riammogliare",
    "riammoglieran": "riammogliare",
    "riammoglieranno": "riammogliare",
    "riammoglierebbe": "riammogliare",
    "riammoglierebber": "riammogliare",
    "riammoglierebbero": "riammogliare",
    "riammoglierei": "riammogliare",
    "riammoglieremmo": "riammogliare",
    "riammoglieremo": "riammogliare",
    "riammogliereste": "riammogliare",
    "riammoglieresti": "riammogliare",
    "riammoglierete": "riammogliare",
    "riammoglierà": "riammogliare",
    "riammoglierò": "riammogliare",
    "riammoglin": "riammogliare",
    "riammoglino": "riammogliare",
    "riammoglio": "riammogliare",
    "riammogliò": "riammogliare",
    "riamo": "riamare",
    "riamò": "riamare",
    "riandai": "riandare",
    "riandammo": "riandare",
    "riandando": "riandare",
    "riandante": "riandare",
    "riandanti": "riandare",
    "riandar": "riandare",
    "riandaron": "riandare",
    "riandarono": "riandare",
    "riandasse": "riandare",
    "riandasser": "riandare",
    "riandassero": "riandare",
    "riandassi": "riandare",
    "riandassimo": "riandare",
    "riandaste": "riandare",
    "riandasti": "riandare",
    "riandata": "riandare",
    "riandate": "riandare",
    "riandati": "riandare",
    "riandato": "riandare",
    "riandava": "riandare",
    "riandavamo": "riandare",
    "riandavan": "riandare",
    "riandavano": "riandare",
    "riandavate": "riandare",
    "riandavi": "riandare",
    "riandavo": "riandare",
    "riandiamo": "riandare",
    "riandiate": "riandare",
    "riandrai": "riandare",
    "riandran": "riandare",
    "riandranno": "riandare",
    "riandrebbe": "riandare",
    "riandrebber": "riandare",
    "riandrebbero": "riandare",
    "riandrei": "riandare",
    "riandremmo": "riandare",
    "riandremo": "riandare",
    "riandreste": "riandare",
    "riandresti": "riandare",
    "riandrete": "riandare",
    "riandrà": "riandare",
    "riandrò": "riandare",
    "riandò": "riandare",
    "rianima": "rianimare",
    "rianimai": "rianimare",
    "rianimammo": "rianimare",
    "rianiman": "rianimare",
    "rianimando": "rianimare",
    "rianimano": "rianimare",
    "rianimante": "rianimare",
    "rianimanti": "rianimare",
    "rianimar": "rianimare",
    "rianimaron": "rianimare",
    "rianimarono": "rianimare",
    "rianimasse": "rianimare",
    "rianimasser": "rianimare",
    "rianimassero": "rianimare",
    "rianimassi": "rianimare",
    "rianimassimo": "rianimare",
    "rianimaste": "rianimare",
    "rianimasti": "rianimare",
    "rianimata": "rianimare",
    "rianimate": "rianimare",
    "rianimati": "rianimare",
    "rianimato": "rianimare",
    "rianimatori": "rianimatore",
    "rianimava": "rianimare",
    "rianimavamo": "rianimare",
    "rianimavan": "rianimare",
    "rianimavano": "rianimare",
    "rianimavate": "rianimare",
    "rianimavi": "rianimare",
    "rianimavo": "rianimare",
    "rianimazioni": "rianimazione",
    "rianimerai": "rianimare",
    "rianimeran": "rianimare",
    "rianimeranno": "rianimare",
    "rianimerebbe": "rianimare",
    "rianimerebber": "rianimare",
    "rianimerebbero": "rianimare",
    "rianimerei": "rianimare",
    "rianimeremmo": "rianimare",
    "rianimeremo": "rianimare",
    "rianimereste": "rianimare",
    "rianimeresti": "rianimare",
    "rianimerete": "rianimare",
    "rianimerà": "rianimare",
    "rianimerò": "rianimare",
    "rianimi": "rianimare",
    "rianimiamo": "rianimare",
    "rianimiate": "rianimare",
    "rianimin": "rianimare",
    "rianimino": "rianimare",
    "rianimo": "rianimare",
    "rianimò": "rianimare",
    "riannetta": "riannettere",
    "riannettan": "riannettere",
    "riannettano": "riannettere",
    "riannette": "riannettere",
    "riannettei": "riannettere",
    "riannettemmo": "riannettere",
    "riannettendo": "riannettere",
    "riannettente": "riannettere",
    "riannettenti": "riannettere",
    "riannetter": "riannettere",
    "riannetterai": "riannettere",
    "riannetteran": "riannettere",
    "riannetteranno": "riannettere",
    "riannetterebbe": "riannettere",
    "riannetterebber": "riannettere",
    "riannetterebbero": "riannettere",
    "riannetterei": "riannettere",
    "riannetteremmo": "riannettere",
    "riannetteremo": "riannettere",
    "riannettereste": "riannettere",
    "riannetteresti": "riannettere",
    "riannetterete": "riannettere",
    "riannetteron": "riannettere",
    "riannetterono": "riannettere",
    "riannetterà": "riannettere",
    "riannetterò": "riannettere",
    "riannettesse": "riannettere",
    "riannettesser": "riannettere",
    "riannettessero": "riannettere",
    "riannettessi": "riannettere",
    "riannettessimo": "riannettere",
    "riannetteste": "riannettere",
    "riannettesti": "riannettere",
    "riannettete": "riannettere",
    "riannetteva": "riannettere",
    "riannettevamo": "riannettere",
    "riannettevan": "riannettere",
    "riannettevano": "riannettere",
    "riannettevate": "riannettere",
    "riannettevi": "riannettere",
    "riannettevo": "riannettere",
    "riannetti": "riannettere",
    "riannettiamo": "riannettere",
    "riannettiate": "riannettere",
    "riannetto": "riannettere",
    "riannetton": "riannettere",
    "riannettono": "riannettere",
    "riannettuta": "riannettere",
    "riannettute": "riannettere",
    "riannettuti": "riannettere",
    "riannettuto": "riannettere",
    "riannettè": "riannettere",
    "riannoda": "riannodare",
    "riannodai": "riannodare",
    "riannodammo": "riannodare",
    "riannodan": "riannodare",
    "riannodando": "riannodare",
    "riannodano": "riannodare",
    "riannodante": "riannodare",
    "riannodanti": "riannodare",
    "riannodar": "riannodare",
    "riannodaron": "riannodare",
    "riannodarono": "riannodare",
    "riannodasse": "riannodare",
    "riannodasser": "riannodare",
    "riannodassero": "riannodare",
    "riannodassi": "riannodare",
    "riannodassimo": "riannodare",
    "riannodaste": "riannodare",
    "riannodasti": "riannodare",
    "riannodata": "riannodare",
    "riannodate": "riannodare",
    "riannodati": "riannodare",
    "riannodato": "riannodare",
    "riannodava": "riannodare",
    "riannodavamo": "riannodare",
    "riannodavan": "riannodare",
    "riannodavano": "riannodare",
    "riannodavate": "riannodare",
    "riannodavi": "riannodare",
    "riannodavo": "riannodare",
    "riannoderai": "riannodare",
    "riannoderan": "riannodare",
    "riannoderanno": "riannodare",
    "riannoderebbe": "riannodare",
    "riannoderebber": "riannodare",
    "riannoderebbero": "riannodare",
    "riannoderei": "riannodare",
    "riannoderemmo": "riannodare",
    "riannoderemo": "riannodare",
    "riannodereste": "riannodare",
    "riannoderesti": "riannodare",
    "riannoderete": "riannodare",
    "riannoderà": "riannodare",
    "riannoderò": "riannodare",
    "riannodi": "riannodare",
    "riannodiamo": "riannodare",
    "riannodiate": "riannodare",
    "riannodin": "riannodare",
    "riannodino": "riannodare",
    "riannodo": "riannodare",
    "riannodò": "riannodare",
    "riaperta": "riaprire",
    "riaperte": "riaprire",
    "riaperti": "riaprire",
    "riaperto": "riaprire",
    "riaperture": "riapertura",
    "riappacificazioni": "riappacificazione",
    "riappaia": "riapparire",
    "riappaian": "riapparire",
    "riappaiano": "riapparire",
    "riappaio": "riapparire",
    "riappaion": "riapparire",
    "riappaiono": "riapparire",
    "riappare": "riapparire",
    "riapparendo": "riapparire",
    "riapparente": "riapparire",
    "riapparenti": "riapparire",
    "riappari": "riapparire",
    "riappariamo": "riapparire",
    "riappariate": "riapparire",
    "riapparimmo": "riapparire",
    "riapparir": "riapparire",
    "riapparirai": "riapparire",
    "riappariran": "riapparire",
    "riappariranno": "riapparire",
    "riapparirebbe": "riapparire",
    "riapparirebber": "riapparire",
    "riapparirebbero": "riapparire",
    "riapparirei": "riapparire",
    "riappariremmo": "riapparire",
    "riappariremo": "riapparire",
    "riapparireste": "riapparire",
    "riappariresti": "riapparire",
    "riapparirete": "riapparire",
    "riapparirà": "riapparire",
    "riapparirò": "riapparire",
    "riapparisse": "riapparire",
    "riapparisser": "riapparire",
    "riapparissero": "riapparire",
    "riapparissi": "riapparire",
    "riapparissimo": "riapparire",
    "riappariste": "riapparire",
    "riapparisti": "riapparire",
    "riapparite": "riapparire",
    "riappariva": "riapparire",
    "riapparivamo": "riapparire",
    "riapparivan": "riapparire",
    "riapparivano": "riapparire",
    "riapparivate": "riapparire",
    "riapparivi": "riapparire",
    "riapparivo": "riapparire",
    "riapparizioni": "riapparizione",
    "riapparsa": "riapparire",
    "riapparse": "riapparire",
    "riapparsi": "riapparire",
    "riapparso": "riapparire",
    "riapparve": "riapparire",
    "riapparver": "riapparire",
    "riapparvero": "riapparire",
    "riapparvi": "riapparire",
    "riappropri": "riappropriare",
    "riappropria": "riappropriare",
    "riappropriai": "riappropriare",
    "riappropriammo": "riappropriare",
    "riappropriamo": "riappropriare",
    "riapproprian": "riappropriare",
    "riappropriando": "riappropriare",
    "riappropriano": "riappropriare",
    "riappropriar": "riappropriare",
    "riappropriaron": "riappropriare",
    "riappropriarono": "riappropriare",
    "riappropriasse": "riappropriare",
    "riappropriasser": "riappropriare",
    "riappropriassero": "riappropriare",
    "riappropriassi": "riappropriare",
    "riappropriassimo": "riappropriare",
    "riappropriaste": "riappropriare",
    "riappropriasti": "riappropriare",
    "riappropriata": "riappropriare",
    "riappropriate": "riappropriare",
    "riappropriati": "riappropriare",
    "riappropriato": "riappropriare",
    "riappropriava": "riappropriare",
    "riappropriavamo": "riappropriare",
    "riappropriavan": "riappropriare",
    "riappropriavano": "riappropriare",
    "riappropriavate": "riappropriare",
    "riappropriavi": "riappropriare",
    "riappropriavo": "riappropriare",
    "riappropriazioni": "riappropriazione",
    "riapproprierai": "riappropriare",
    "riapproprieran": "riappropriare",
    "riapproprieranno": "riappropriare",
    "riapproprierebbe": "riappropriare",
    "riapproprierebber": "riappropriare",
    "riapproprierebbero": "riappropriare",
    "riapproprierei": "riappropriare",
    "riapproprieremmo": "riappropriare",
    "riapproprieremo": "riappropriare",
    "riappropriereste": "riappropriare",
    "riapproprieresti": "riappropriare",
    "riapproprierete": "riappropriare",
    "riapproprierà": "riappropriare",
    "riapproprierò": "riappropriare",
    "riapproprin": "riappropriare",
    "riapproprino": "riappropriare",
    "riapproprio": "riappropriare",
    "riappropriò": "riappropriare",
    "riapprova": "riapprovare",
    "riapprovai": "riapprovare",
    "riapprovammo": "riapprovare",
    "riapprovan": "riapprovare",
    "riapprovando": "riapprovare",
    "riapprovano": "riapprovare",
    "riapprovante": "riapprovare",
    "riapprovanti": "riapprovare",
    "riapprovar": "riapprovare",
    "riapprovaron": "riapprovare",
    "riapprovarono": "riapprovare",
    "riapprovasse": "riapprovare",
    "riapprovasser": "riapprovare",
    "riapprovassero": "riapprovare",
    "riapprovassi": "riapprovare",
    "riapprovassimo": "riapprovare",
    "riapprovaste": "riapprovare",
    "riapprovasti": "riapprovare",
    "riapprovata": "riapprovare",
    "riapprovate": "riapprovare",
    "riapprovati": "riapprovare",
    "riapprovato": "riapprovare",
    "riapprovava": "riapprovare",
    "riapprovavamo": "riapprovare",
    "riapprovavan": "riapprovare",
    "riapprovavano": "riapprovare",
    "riapprovavate": "riapprovare",
    "riapprovavi": "riapprovare",
    "riapprovavo": "riapprovare",
    "riapproverai": "riapprovare",
    "riapproveran": "riapprovare",
    "riapproveranno": "riapprovare",
    "riapproverebbe": "riapprovare",
    "riapproverebber": "riapprovare",
    "riapproverebbero": "riapprovare",
    "riapproverei": "riapprovare",
    "riapproveremmo": "riapprovare",
    "riapproveremo": "riapprovare",
    "riapprovereste": "riapprovare",
    "riapproveresti": "riapprovare",
    "riapproverete": "riapprovare",
    "riapproverà": "riapprovare",
    "riapproverò": "riapprovare",
    "riapprovi": "riapprovare",
    "riapproviamo": "riapprovare",
    "riapproviate": "riapprovare",
    "riapprovin": "riapprovare",
    "riapprovino": "riapprovare",
    "riapprovo": "riapprovare",
    "riapprovò": "riapprovare",
    "riapra": "riaprire",
    "riapran": "riaprire",
    "riaprano": "riaprire",
    "riapre": "riaprire",
    "riaprendo": "riaprire",
    "riaprente": "riaprire",
    "riaprenti": "riaprire",
    "riapri": "riaprire",
    "riapriamo": "riaprire",
    "riapriate": "riaprire",
    "riaprii": "riaprire",
    "riaprimmo": "riaprire",
    "riaprir": "riaprire",
    "riaprirai": "riaprire",
    "riapriran": "riaprire",
    "riapriranno": "riaprire",
    "riaprirebbe": "riaprire",
    "riaprirebber": "riaprire",
    "riaprirebbero": "riaprire",
    "riaprirei": "riaprire",
    "riapriremmo": "riaprire",
    "riapriremo": "riaprire",
    "riaprireste": "riaprire",
    "riapriresti": "riaprire",
    "riaprirete": "riaprire",
    "riapriron": "riaprire",
    "riaprirono": "riaprire",
    "riaprirà": "riaprire",
    "riaprirò": "riaprire",
    "riaprisse": "riaprire",
    "riaprisser": "riaprire",
    "riaprissero": "riaprire",
    "riaprissi": "riaprire",
    "riaprissimo": "riaprire",
    "riapriste": "riaprire",
    "riapristi": "riaprire",
    "riaprite": "riaprire",
    "riapriva": "riaprire",
    "riaprivamo": "riaprire",
    "riaprivan": "riaprire",
    "riaprivano": "riaprire",
    "riaprivate": "riaprire",
    "riaprivi": "riaprire",
    "riaprivo": "riaprire",
    "riapro": "riaprire",
    "riapron": "riaprire",
    "riaprono": "riaprire",
    "riaprì": "riaprire",
    "riarma": "riarmare",
    "riarmai": "riarmare",
    "riarmammo": "riarmare",
    "riarman": "riarmare",
    "riarmando": "riarmare",
    "riarmano": "riarmare",
    "riarmante": "riarmare",
    "riarmanti": "riarmare",
    "riarmar": "riarmare",
    "riarmaron": "riarmare",
    "riarmarono": "riarmare",
    "riarmasse": "riarmare",
    "riarmasser": "riarmare",
    "riarmassero": "riarmare",
    "riarmassi": "riarmare",
    "riarmassimo": "riarmare",
    "riarmaste": "riarmare",
    "riarmasti": "riarmare",
    "riarmata": "riarmare",
    "riarmate": "riarmare",
    "riarmati": "riarmare",
    "riarmato": "riarmare",
    "riarmava": "riarmare",
    "riarmavamo": "riarmare",
    "riarmavan": "riarmare",
    "riarmavano": "riarmare",
    "riarmavate": "riarmare",
    "riarmavi": "riarmare",
    "riarmavo": "riarmare",
    "riarmerai": "riarmare",
    "riarmeran": "riarmare",
    "riarmeranno": "riarmare",
    "riarmerebbe": "riarmare",
    "riarmerebber": "riarmare",
    "riarmerebbero": "riarmare",
    "riarmerei": "riarmare",
    "riarmeremmo": "riarmare",
    "riarmeremo": "riarmare",
    "riarmereste": "riarmare",
    "riarmeresti": "riarmare",
    "riarmerete": "riarmare",
    "riarmerà": "riarmare",
    "riarmerò": "riarmare",
    "riarmi": "riarmo",
    "riarmiamo": "riarmare",
    "riarmiate": "riarmare",
    "riarmin": "riarmare",
    "riarmino": "riarmare",
    "riarmo": "riarmare",
    "riarmò": "riarmare",
    "riarsa": "riarso",
    "riarse": "riarso",
    "riarsi": "riarso",
    "riasciuga": "riasciugare",
    "riasciugai": "riasciugare",
    "riasciugammo": "riasciugare",
    "riasciugan": "riasciugare",
    "riasciugando": "riasciugare",
    "riasciugano": "riasciugare",
    "riasciugante": "riasciugare",
    "riasciuganti": "riasciugare",
    "riasciugar": "riasciugare",
    "riasciugaron": "riasciugare",
    "riasciugarono": "riasciugare",
    "riasciugasse": "riasciugare",
    "riasciugasser": "riasciugare",
    "riasciugassero": "riasciugare",
    "riasciugassi": "riasciugare",
    "riasciugassimo": "riasciugare",
    "riasciugaste": "riasciugare",
    "riasciugasti": "riasciugare",
    "riasciugata": "riasciugare",
    "riasciugate": "riasciugare",
    "riasciugati": "riasciugare",
    "riasciugato": "riasciugare",
    "riasciugava": "riasciugare",
    "riasciugavamo": "riasciugare",
    "riasciugavan": "riasciugare",
    "riasciugavano": "riasciugare",
    "riasciugavate": "riasciugare",
    "riasciugavi": "riasciugare",
    "riasciugavo": "riasciugare",
    "riasciugherai": "riasciugare",
    "riasciugheran": "riasciugare",
    "riasciugheranno": "riasciugare",
    "riasciugherebbe": "riasciugare",
    "riasciugherebber": "riasciugare",
    "riasciugherebbero": "riasciugare",
    "riasciugherei": "riasciugare",
    "riasciugheremmo": "riasciugare",
    "riasciugheremo": "riasciugare",
    "riasciughereste": "riasciugare",
    "riasciugheresti": "riasciugare",
    "riasciugherete": "riasciugare",
    "riasciugherà": "riasciugare",
    "riasciugherò": "riasciugare",
    "riasciughi": "riasciugare",
    "riasciughiamo": "riasciugare",
    "riasciughiate": "riasciugare",
    "riasciughin": "riasciugare",
    "riasciughino": "riasciugare",
    "riasciugo": "riasciugare",
    "riasciugò": "riasciugare",
    "riascolta": "riascoltare",
    "riascoltai": "riascoltare",
    "riascoltammo": "riascoltare",
    "riascoltan": "riascoltare",
    "riascoltando": "riascoltare",
    "riascoltano": "riascoltare",
    "riascoltante": "riascoltare",
    "riascoltanti": "riascoltare",
    "riascoltar": "riascoltare",
    "riascoltaron": "riascoltare",
    "riascoltarono": "riascoltare",
    "riascoltasse": "riascoltare",
    "riascoltasser": "riascoltare",
    "riascoltassero": "riascoltare",
    "riascoltassi": "riascoltare",
    "riascoltassimo": "riascoltare",
    "riascoltaste": "riascoltare",
    "riascoltasti": "riascoltare",
    "riascoltata": "riascoltare",
    "riascoltate": "riascoltare",
    "riascoltati": "riascoltare",
    "riascoltato": "riascoltare",
    "riascoltava": "riascoltare",
    "riascoltavamo": "riascoltare",
    "riascoltavan": "riascoltare",
    "riascoltavano": "riascoltare",
    "riascoltavate": "riascoltare",
    "riascoltavi": "riascoltare",
    "riascoltavo": "riascoltare",
    "riascolterai": "riascoltare",
    "riascolteran": "riascoltare",
    "riascolteranno": "riascoltare",
    "riascolterebbe": "riascoltare",
    "riascolterebber": "riascoltare",
    "riascolterebbero": "riascoltare",
    "riascolterei": "riascoltare",
    "riascolteremmo": "riascoltare",
    "riascolteremo": "riascoltare",
    "riascoltereste": "riascoltare",
    "riascolteresti": "riascoltare",
    "riascolterete": "riascoltare",
    "riascolterà": "riascoltare",
    "riascolterò": "riascoltare",
    "riascolti": "riascoltare",
    "riascoltiamo": "riascoltare",
    "riascoltiate": "riascoltare",
    "riascoltin": "riascoltare",
    "riascoltino": "riascoltare",
    "riascolto": "riascoltare",
    "riascoltò": "riascoltare",
    "riassala": "riassalire",
    "riassalan": "riassalire",
    "riassalano": "riassalire",
    "riassale": "riassalire",
    "riassalendo": "riassalire",
    "riassalente": "riassalire",
    "riassalenti": "riassalire",
    "riassali": "riassalire",
    "riassaliamo": "riassalire",
    "riassaliate": "riassalire",
    "riassalii": "riassalire",
    "riassalimmo": "riassalire",
    "riassalir": "riassalire",
    "riassalirai": "riassalire",
    "riassaliran": "riassalire",
    "riassaliranno": "riassalire",
    "riassalirebbe": "riassalire",
    "riassalirebber": "riassalire",
    "riassalirebbero": "riassalire",
    "riassalirei": "riassalire",
    "riassaliremmo": "riassalire",
    "riassaliremo": "riassalire",
    "riassalireste": "riassalire",
    "riassaliresti": "riassalire",
    "riassalirete": "riassalire",
    "riassaliron": "riassalire",
    "riassalirono": "riassalire",
    "riassalirà": "riassalire",
    "riassalirò": "riassalire",
    "riassalisse": "riassalire",
    "riassalisser": "riassalire",
    "riassalissero": "riassalire",
    "riassalissi": "riassalire",
    "riassalissimo": "riassalire",
    "riassaliste": "riassalire",
    "riassalisti": "riassalire",
    "riassalita": "riassalire",
    "riassalite": "riassalire",
    "riassaliti": "riassalire",
    "riassalito": "riassalire",
    "riassaliva": "riassalire",
    "riassalivamo": "riassalire",
    "riassalivan": "riassalire",
    "riassalivano": "riassalire",
    "riassalivate": "riassalire",
    "riassalivi": "riassalire",
    "riassalivo": "riassalire",
    "riassalo": "riassalire",
    "riassalon": "riassalire",
    "riassalono": "riassalire",
    "riassalì": "riassalire",
    "riassapora": "riassaporare",
    "riassaporai": "riassaporare",
    "riassaporammo": "riassaporare",
    "riassaporan": "riassaporare",
    "riassaporando": "riassaporare",
    "riassaporano": "riassaporare",
    "riassaporante": "riassaporare",
    "riassaporanti": "riassaporare",
    "riassaporar": "riassaporare",
    "riassaporaron": "riassaporare",
    "riassaporarono": "riassaporare",
    "riassaporasse": "riassaporare",
    "riassaporasser": "riassaporare",
    "riassaporassero": "riassaporare",
    "riassaporassi": "riassaporare",
    "riassaporassimo": "riassaporare",
    "riassaporaste": "riassaporare",
    "riassaporasti": "riassaporare",
    "riassaporata": "riassaporare",
    "riassaporate": "riassaporare",
    "riassaporati": "riassaporare",
    "riassaporato": "riassaporare",
    "riassaporava": "riassaporare",
    "riassaporavamo": "riassaporare",
    "riassaporavan": "riassaporare",
    "riassaporavano": "riassaporare",
    "riassaporavate": "riassaporare",
    "riassaporavi": "riassaporare",
    "riassaporavo": "riassaporare",
    "riassaporerai": "riassaporare",
    "riassaporeran": "riassaporare",
    "riassaporeranno": "riassaporare",
    "riassaporerebbe": "riassaporare",
    "riassaporerebber": "riassaporare",
    "riassaporerebbero": "riassaporare",
    "riassaporerei": "riassaporare",
    "riassaporeremmo": "riassaporare",
    "riassaporeremo": "riassaporare",
    "riassaporereste": "riassaporare",
    "riassaporeresti": "riassaporare",
    "riassaporerete": "riassaporare",
    "riassaporerà": "riassaporare",
    "riassaporerò": "riassaporare",
    "riassapori": "riassaporare",
    "riassaporiamo": "riassaporare",
    "riassaporiate": "riassaporare",
    "riassaporin": "riassaporare",
    "riassaporino": "riassaporare",
    "riassaporo": "riassaporare",
    "riassaporò": "riassaporare",
    "riassegna": "riassegnare",
    "riassegnai": "riassegnare",
    "riassegnammo": "riassegnare",
    "riassegnan": "riassegnare",
    "riassegnando": "riassegnare",
    "riassegnano": "riassegnare",
    "riassegnante": "riassegnare",
    "riassegnanti": "riassegnare",
    "riassegnar": "riassegnare",
    "riassegnaron": "riassegnare",
    "riassegnarono": "riassegnare",
    "riassegnasse": "riassegnare",
    "riassegnasser": "riassegnare",
    "riassegnassero": "riassegnare",
    "riassegnassi": "riassegnare",
    "riassegnassimo": "riassegnare",
    "riassegnaste": "riassegnare",
    "riassegnasti": "riassegnare",
    "riassegnata": "riassegnare",
    "riassegnate": "riassegnare",
    "riassegnati": "riassegnare",
    "riassegnato": "riassegnare",
    "riassegnava": "riassegnare",
    "riassegnavamo": "riassegnare",
    "riassegnavan": "riassegnare",
    "riassegnavano": "riassegnare",
    "riassegnavate": "riassegnare",
    "riassegnavi": "riassegnare",
    "riassegnavo": "riassegnare",
    "riassegnerai": "riassegnare",
    "riassegneran": "riassegnare",
    "riassegneranno": "riassegnare",
    "riassegnerebbe": "riassegnare",
    "riassegnerebber": "riassegnare",
    "riassegnerebbero": "riassegnare",
    "riassegnerei": "riassegnare",
    "riassegneremmo": "riassegnare",
    "riassegneremo": "riassegnare",
    "riassegnereste": "riassegnare",
    "riassegneresti": "riassegnare",
    "riassegnerete": "riassegnare",
    "riassegnerà": "riassegnare",
    "riassegnerò": "riassegnare",
    "riassegni": "riassegnare",
    "riassegniamo": "riassegnare",
    "riassegniate": "riassegnare",
    "riassegnin": "riassegnare",
    "riassegnino": "riassegnare",
    "riassegno": "riassegnare",
    "riassegnò": "riassegnare",
    "riassesta": "riassestare",
    "riassestai": "riassestare",
    "riassestamenti": "riassestamento",
    "riassestammo": "riassestare",
    "riassestan": "riassestare",
    "riassestando": "riassestare",
    "riassestano": "riassestare",
    "riassestante": "riassestare",
    "riassestanti": "riassestare",
    "riassestar": "riassestare",
    "riassestaron": "riassestare",
    "riassestarono": "riassestare",
    "riassestasse": "riassestare",
    "riassestasser": "riassestare",
    "riassestassero": "riassestare",
    "riassestassi": "riassestare",
    "riassestassimo": "riassestare",
    "riassestaste": "riassestare",
    "riassestasti": "riassestare",
    "riassestata": "riassestare",
    "riassestate": "riassestare",
    "riassestati": "riassestare",
    "riassestato": "riassestare",
    "riassestava": "riassestare",
    "riassestavamo": "riassestare",
    "riassestavan": "riassestare",
    "riassestavano": "riassestare",
    "riassestavate": "riassestare",
    "riassestavi": "riassestare",
    "riassestavo": "riassestare",
    "riassesterai": "riassestare",
    "riassesteran": "riassestare",
    "riassesteranno": "riassestare",
    "riassesterebbe": "riassestare",
    "riassesterebber": "riassestare",
    "riassesterebbero": "riassestare",
    "riassesterei": "riassestare",
    "riassesteremmo": "riassestare",
    "riassesteremo": "riassestare",
    "riassestereste": "riassestare",
    "riassesteresti": "riassestare",
    "riassesterete": "riassestare",
    "riassesterà": "riassestare",
    "riassesterò": "riassestare",
    "riassesti": "riassestare",
    "riassestiamo": "riassestare",
    "riassestiate": "riassestare",
    "riassestin": "riassestare",
    "riassestino": "riassestare",
    "riassesto": "riassestare",
    "riassestò": "riassestare",
    "riassetta": "riassettare",
    "riassettai": "riassettare",
    "riassettammo": "riassettare",
    "riassettan": "riassettare",
    "riassettando": "riassettare",
    "riassettano": "riassettare",
    "riassettante": "riassettare",
    "riassettanti": "riassettare",
    "riassettar": "riassettare",
    "riassettaron": "riassettare",
    "riassettarono": "riassettare",
    "riassettasse": "riassettare",
    "riassettasser": "riassettare",
    "riassettassero": "riassettare",
    "riassettassi": "riassettare",
    "riassettassimo": "riassettare",
    "riassettaste": "riassettare",
    "riassettasti": "riassettare",
    "riassettata": "riassettare",
    "riassettate": "riassettare",
    "riassettati": "riassettare",
    "riassettato": "riassettare",
    "riassettava": "riassettare",
    "riassettavamo": "riassettare",
    "riassettavan": "riassettare",
    "riassettavano": "riassettare",
    "riassettavate": "riassettare",
    "riassettavi": "riassettare",
    "riassettavo": "riassettare",
    "riassetterai": "riassettare",
    "riassetteran": "riassettare",
    "riassetteranno": "riassettare",
    "riassetterebbe": "riassettare",
    "riassetterebber": "riassettare",
    "riassetterebbero": "riassettare",
    "riassetterei": "riassettare",
    "riassetteremmo": "riassettare",
    "riassetteremo": "riassettare",
    "riassettereste": "riassettare",
    "riassetteresti": "riassettare",
    "riassetterete": "riassettare",
    "riassetterà": "riassettare",
    "riassetterò": "riassettare",
    "riassetti": "riassetto",
    "riassettiamo": "riassettare",
    "riassettiate": "riassettare",
    "riassettin": "riassettare",
    "riassettino": "riassettare",
    "riassetto": "riassettare",
    "riassettò": "riassettare",
    "riassicura": "riassicurare",
    "riassicurai": "riassicurare",
    "riassicurammo": "riassicurare",
    "riassicuran": "riassicurare",
    "riassicurando": "riassicurare",
    "riassicurano": "riassicurare",
    "riassicurante": "riassicurare",
    "riassicuranti": "riassicurare",
    "riassicurar": "riassicurare",
    "riassicuraron": "riassicurare",
    "riassicurarono": "riassicurare",
    "riassicurasse": "riassicurare",
    "riassicurasser": "riassicurare",
    "riassicurassero": "riassicurare",
    "riassicurassi": "riassicurare",
    "riassicurassimo": "riassicurare",
    "riassicuraste": "riassicurare",
    "riassicurasti": "riassicurare",
    "riassicurata": "riassicurare",
    "riassicurate": "riassicurare",
    "riassicurati": "riassicurare",
    "riassicurato": "riassicurare",
    "riassicurava": "riassicurare",
    "riassicuravamo": "riassicurare",
    "riassicuravan": "riassicurare",
    "riassicuravano": "riassicurare",
    "riassicuravate": "riassicurare",
    "riassicuravi": "riassicurare",
    "riassicuravo": "riassicurare",
    "riassicurazioni": "riassicurazione",
    "riassicurerai": "riassicurare",
    "riassicureran": "riassicurare",
    "riassicureranno": "riassicurare",
    "riassicurerebbe": "riassicurare",
    "riassicurerebber": "riassicurare",
    "riassicurerebbero": "riassicurare",
    "riassicurerei": "riassicurare",
    "riassicureremmo": "riassicurare",
    "riassicureremo": "riassicurare",
    "riassicurereste": "riassicurare",
    "riassicureresti": "riassicurare",
    "riassicurerete": "riassicurare",
    "riassicurerà": "riassicurare",
    "riassicurerò": "riassicurare",
    "riassicuri": "riassicurare",
    "riassicuriamo": "riassicurare",
    "riassicuriate": "riassicurare",
    "riassicurin": "riassicurare",
    "riassicurino": "riassicurare",
    "riassicuro": "riassicurare",
    "riassicurò": "riassicurare",
    "riassorba": "riassorbire",
    "riassorban": "riassorbire",
    "riassorbano": "riassorbire",
    "riassorbe": "riassorbire",
    "riassorbendo": "riassorbire",
    "riassorbente": "riassorbire",
    "riassorbenti": "riassorbire",
    "riassorbi": "riassorbire",
    "riassorbiamo": "riassorbire",
    "riassorbiate": "riassorbire",
    "riassorbii": "riassorbire",
    "riassorbimenti": "riassorbimento",
    "riassorbimmo": "riassorbire",
    "riassorbir": "riassorbire",
    "riassorbirai": "riassorbire",
    "riassorbiran": "riassorbire",
    "riassorbiranno": "riassorbire",
    "riassorbirebbe": "riassorbire",
    "riassorbirebber": "riassorbire",
    "riassorbirebbero": "riassorbire",
    "riassorbirei": "riassorbire",
    "riassorbiremmo": "riassorbire",
    "riassorbiremo": "riassorbire",
    "riassorbireste": "riassorbire",
    "riassorbiresti": "riassorbire",
    "riassorbirete": "riassorbire",
    "riassorbiron": "riassorbire",
    "riassorbirono": "riassorbire",
    "riassorbirà": "riassorbire",
    "riassorbirò": "riassorbire",
    "riassorbisse": "riassorbire",
    "riassorbisser": "riassorbire",
    "riassorbissero": "riassorbire",
    "riassorbissi": "riassorbire",
    "riassorbissimo": "riassorbire",
    "riassorbiste": "riassorbire",
    "riassorbisti": "riassorbire",
    "riassorbita": "riassorbire",
    "riassorbite": "riassorbire",
    "riassorbiti": "riassorbire",
    "riassorbito": "riassorbire",
    "riassorbiva": "riassorbire",
    "riassorbivamo": "riassorbire",
    "riassorbivan": "riassorbire",
    "riassorbivano": "riassorbire",
    "riassorbivate": "riassorbire",
    "riassorbivi": "riassorbire",
    "riassorbivo": "riassorbire",
    "riassorbo": "riassorbire",
    "riassorbon": "riassorbire",
    "riassorbono": "riassorbire",
    "riassorbì": "riassorbire",
    "riassuma": "riassumere",
    "riassuman": "riassumere",
    "riassumano": "riassumere",
    "riassume": "riassumere",
    "riassumemmo": "riassumere",
    "riassumendo": "riassumere",
    "riassumente": "riassumere",
    "riassumenti": "riassumere",
    "riassumer": "riassumere",
    "riassumerai": "riassumere",
    "riassumeran": "riassumere",
    "riassumeranno": "riassumere",
    "riassumerebbe": "riassumere",
    "riassumerebber": "riassumere",
    "riassumerebbero": "riassumere",
    "riassumerei": "riassumere",
    "riassumeremmo": "riassumere",
    "riassumeremo": "riassumere",
    "riassumereste": "riassumere",
    "riassumeresti": "riassumere",
    "riassumerete": "riassumere",
    "riassumerà": "riassumere",
    "riassumerò": "riassumere",
    "riassumesse": "riassumere",
    "riassumesser": "riassumere",
    "riassumessero": "riassumere",
    "riassumessi": "riassumere",
    "riassumessimo": "riassumere",
    "riassumeste": "riassumere",
    "riassumesti": "riassumere",
    "riassumete": "riassumere",
    "riassumeva": "riassumere",
    "riassumevamo": "riassumere",
    "riassumevan": "riassumere",
    "riassumevano": "riassumere",
    "riassumevate": "riassumere",
    "riassumevi": "riassumere",
    "riassumevo": "riassumere",
    "riassumi": "riassumere",
    "riassumiamo": "riassumere",
    "riassumiate": "riassumere",
    "riassumibili": "riassumibile",
    "riassumo": "riassumere",
    "riassumon": "riassumere",
    "riassumono": "riassumere",
    "riassunse": "riassumere",
    "riassunser": "riassumere",
    "riassunsero": "riassumere",
    "riassunsi": "riassumere",
    "riassunta": "riassunto",
    "riassunte": "riassunto",
    "riassunti": "riassunto",
    "riassuntiva": "riassuntivo",
    "riassuntive": "riassuntivo",
    "riassuntivi": "riassuntivo",
    "riassunto": "riassumere",
    "riassunzioni": "riassunzione",
    "riatta": "riattare",
    "riattacca": "riattaccare",
    "riattaccai": "riattaccare",
    "riattaccammo": "riattaccare",
    "riattaccan": "riattaccare",
    "riattaccando": "riattaccare",
    "riattaccano": "riattaccare",
    "riattaccante": "riattaccare",
    "riattaccanti": "riattaccare",
    "riattaccar": "riattaccare",
    "riattaccaron": "riattaccare",
    "riattaccarono": "riattaccare",
    "riattaccasse": "riattaccare",
    "riattaccasser": "riattaccare",
    "riattaccassero": "riattaccare",
    "riattaccassi": "riattaccare",
    "riattaccassimo": "riattaccare",
    "riattaccaste": "riattaccare",
    "riattaccasti": "riattaccare",
    "riattaccata": "riattaccare",
    "riattaccate": "riattaccare",
    "riattaccati": "riattaccare",
    "riattaccato": "riattaccare",
    "riattaccava": "riattaccare",
    "riattaccavamo": "riattaccare",
    "riattaccavan": "riattaccare",
    "riattaccavano": "riattaccare",
    "riattaccavate": "riattaccare",
    "riattaccavi": "riattaccare",
    "riattaccavo": "riattaccare",
    "riattaccherai": "riattaccare",
    "riattaccheran": "riattaccare",
    "riattaccheranno": "riattaccare",
    "riattaccherebbe": "riattaccare",
    "riattaccherebber": "riattaccare",
    "riattaccherebbero": "riattaccare",
    "riattaccherei": "riattaccare",
    "riattaccheremmo": "riattaccare",
    "riattaccheremo": "riattaccare",
    "riattacchereste": "riattaccare",
    "riattaccheresti": "riattaccare",
    "riattaccherete": "riattaccare",
    "riattaccherà": "riattaccare",
    "riattaccherò": "riattaccare",
    "riattacchi": "riattaccare",
    "riattacchiamo": "riattaccare",
    "riattacchiate": "riattaccare",
    "riattacchin": "riattaccare",
    "riattacchino": "riattaccare",
    "riattacco": "riattaccare",
    "riattaccò": "riattaccare",
    "riattai": "riattare",
    "riattammo": "riattare",
    "riattan": "riattare",
    "riattando": "riattare",
    "riattano": "riattare",
    "riattante": "riattare",
    "riattanti": "riattare",
    "riattar": "riattare",
    "riattaron": "riattare",
    "riattarono": "riattare",
    "riattasse": "riattare",
    "riattasser": "riattare",
    "riattassero": "riattare",
    "riattassi": "riattare",
    "riattassimo": "riattare",
    "riattaste": "riattare",
    "riattasti": "riattare",
    "riattata": "riattare",
    "riattate": "riattare",
    "riattati": "riattare",
    "riattato": "riattare",
    "riattava": "riattare",
    "riattavamo": "riattare",
    "riattavan": "riattare",
    "riattavano": "riattare",
    "riattavate": "riattare",
    "riattavi": "riattare",
    "riattavo": "riattare",
    "riatterai": "riattare",
    "riatteran": "riattare",
    "riatteranno": "riattare",
    "riatterebbe": "riattare",
    "riatterebber": "riattare",
    "riatterebbero": "riattare",
    "riatterei": "riattare",
    "riatteremmo": "riattare",
    "riatteremo": "riattare",
    "riattereste": "riattare",
    "riatteresti": "riattare",
    "riatterete": "riattare",
    "riatterà": "riattare",
    "riatterò": "riattare",
    "riatti": "riattare",
    "riattiamo": "riattare",
    "riattiate": "riattare",
    "riattin": "riattare",
    "riattino": "riattare",
    "riattiva": "riattivare",
    "riattivai": "riattivare",
    "riattivammo": "riattivare",
    "riattivan": "riattivare",
    "riattivando": "riattivare",
    "riattivano": "riattivare",
    "riattivante": "riattivare",
    "riattivanti": "riattivare",
    "riattivar": "riattivare",
    "riattivaron": "riattivare",
    "riattivarono": "riattivare",
    "riattivasse": "riattivare",
    "riattivasser": "riattivare",
    "riattivassero": "riattivare",
    "riattivassi": "riattivare",
    "riattivassimo": "riattivare",
    "riattivaste": "riattivare",
    "riattivasti": "riattivare",
    "riattivata": "riattivare",
    "riattivate": "riattivare",
    "riattivati": "riattivare",
    "riattivato": "riattivare",
    "riattivava": "riattivare",
    "riattivavamo": "riattivare",
    "riattivavan": "riattivare",
    "riattivavano": "riattivare",
    "riattivavate": "riattivare",
    "riattivavi": "riattivare",
    "riattivavo": "riattivare",
    "riattivazioni": "riattivazione",
    "riattiverai": "riattivare",
    "riattiveran": "riattivare",
    "riattiveranno": "riattivare",
    "riattiverebbe": "riattivare",
    "riattiverebber": "riattivare",
    "riattiverebbero": "riattivare",
    "riattiverei": "riattivare",
    "riattiveremmo": "riattivare",
    "riattiveremo": "riattivare",
    "riattivereste": "riattivare",
    "riattiveresti": "riattivare",
    "riattiverete": "riattivare",
    "riattiverà": "riattivare",
    "riattiverò": "riattivare",
    "riattivi": "riattivare",
    "riattiviamo": "riattivare",
    "riattiviate": "riattivare",
    "riattivin": "riattivare",
    "riattivino": "riattivare",
    "riattivo": "riattivare",
    "riattivò": "riattivare",
    "riattizza": "riattizzare",
    "riattizzai": "riattizzare",
    "riattizzammo": "riattizzare",
    "riattizzan": "riattizzare",
    "riattizzando": "riattizzare",
    "riattizzano": "riattizzare",
    "riattizzante": "riattizzare",
    "riattizzanti": "riattizzare",
    "riattizzar": "riattizzare",
    "riattizzaron": "riattizzare",
    "riattizzarono": "riattizzare",
    "riattizzasse": "riattizzare",
    "riattizzasser": "riattizzare",
    "riattizzassero": "riattizzare",
    "riattizzassi": "riattizzare",
    "riattizzassimo": "riattizzare",
    "riattizzaste": "riattizzare",
    "riattizzasti": "riattizzare",
    "riattizzata": "riattizzare",
    "riattizzate": "riattizzare",
    "riattizzati": "riattizzare",
    "riattizzato": "riattizzare",
    "riattizzava": "riattizzare",
    "riattizzavamo": "riattizzare",
    "riattizzavan": "riattizzare",
    "riattizzavano": "riattizzare",
    "riattizzavate": "riattizzare",
    "riattizzavi": "riattizzare",
    "riattizzavo": "riattizzare",
    "riattizzerai": "riattizzare",
    "riattizzeran": "riattizzare",
    "riattizzeranno": "riattizzare",
    "riattizzerebbe": "riattizzare",
    "riattizzerebber": "riattizzare",
    "riattizzerebbero": "riattizzare",
    "riattizzerei": "riattizzare",
    "riattizzeremmo": "riattizzare",
    "riattizzeremo": "riattizzare",
    "riattizzereste": "riattizzare",
    "riattizzeresti": "riattizzare",
    "riattizzerete": "riattizzare",
    "riattizzerà": "riattizzare",
    "riattizzerò": "riattizzare",
    "riattizzi": "riattizzare",
    "riattizziamo": "riattizzare",
    "riattizziate": "riattizzare",
    "riattizzin": "riattizzare",
    "riattizzino": "riattizzare",
    "riattizzo": "riattizzare",
    "riattizzò": "riattizzare",
    "riatto": "riattare",
    "riattò": "riattare",
    "riavemmo": "riavere",
    "riavendo": "riavere",
    "riavente": "riavere",
    "riaventi": "riavere",
    "riaver": "riavere",
    "riavesse": "riavere",
    "riavesser": "riavere",
    "riavessero": "riavere",
    "riavessi": "riavere",
    "riavessimo": "riavere",
    "riaveste": "riavere",
    "riavesti": "riavere",
    "riavete": "riavere",
    "riaveva": "riavere",
    "riavevamo": "riavere",
    "riavevan": "riavere",
    "riavevano": "riavere",
    "riavevate": "riavere",
    "riavevi": "riavere",
    "riavevo": "riavere",
    "riavrai": "riavere",
    "riavran": "riavere",
    "riavranno": "riavere",
    "riavrebbe": "riavere",
    "riavrebber": "riavere",
    "riavrebbero": "riavere",
    "riavrei": "riavere",
    "riavremmo": "riavere",
    "riavremo": "riavere",
    "riavreste": "riavere",
    "riavresti": "riavere",
    "riavrete": "riavere",
    "riavrà": "riavere",
    "riavrò": "riavere",
    "riavuta": "riavere",
    "riavute": "riavere",
    "riavuti": "riavere",
    "riavuto": "riavere",
    "riavvi": "riavviare",
    "riavvia": "riavviare",
    "riavviai": "riavviare",
    "riavviammo": "riavviare",
    "riavviamo": "riavviare",
    "riavvian": "riavviare",
    "riavviando": "riavviare",
    "riavviano": "riavviare",
    "riavviante": "riavviare",
    "riavvianti": "riavviare",
    "riavviar": "riavviare",
    "riavviaron": "riavviare",
    "riavviarono": "riavviare",
    "riavviasse": "riavviare",
    "riavviasser": "riavviare",
    "riavviassero": "riavviare",
    "riavviassi": "riavviare",
    "riavviassimo": "riavviare",
    "riavviaste": "riavviare",
    "riavviasti": "riavviare",
    "riavviata": "riavviare",
    "riavviate": "riavviare",
    "riavviati": "riavviare",
    "riavviato": "riavviare",
    "riavviava": "riavviare",
    "riavviavamo": "riavviare",
    "riavviavan": "riavviare",
    "riavviavano": "riavviare",
    "riavviavate": "riavviare",
    "riavviavi": "riavviare",
    "riavviavo": "riavviare",
    "riavvicina": "riavvicinare",
    "riavvicinai": "riavvicinare",
    "riavvicinamenti": "riavvicinamento",
    "riavvicinammo": "riavvicinare",
    "riavvicinan": "riavvicinare",
    "riavvicinando": "riavvicinare",
    "riavvicinano": "riavvicinare",
    "riavvicinante": "riavvicinare",
    "riavvicinanti": "riavvicinare",
    "riavvicinar": "riavvicinare",
    "riavvicinaron": "riavvicinare",
    "riavvicinarono": "riavvicinare",
    "riavvicinasse": "riavvicinare",
    "riavvicinasser": "riavvicinare",
    "riavvicinassero": "riavvicinare",
    "riavvicinassi": "riavvicinare",
    "riavvicinassimo": "riavvicinare",
    "riavvicinaste": "riavvicinare",
    "riavvicinasti": "riavvicinare",
    "riavvicinata": "riavvicinare",
    "riavvicinate": "riavvicinare",
    "riavvicinati": "riavvicinare",
    "riavvicinato": "riavvicinare",
    "riavvicinava": "riavvicinare",
    "riavvicinavamo": "riavvicinare",
    "riavvicinavan": "riavvicinare",
    "riavvicinavano": "riavvicinare",
    "riavvicinavate": "riavvicinare",
    "riavvicinavi": "riavvicinare",
    "riavvicinavo": "riavvicinare",
    "riavvicinerai": "riavvicinare",
    "riavvicineran": "riavvicinare",
    "riavvicineranno": "riavvicinare",
    "riavvicinerebbe": "riavvicinare",
    "riavvicinerebber": "riavvicinare",
    "riavvicinerebbero": "riavvicinare",
    "riavvicinerei": "riavvicinare",
    "riavvicineremmo": "riavvicinare",
    "riavvicineremo": "riavvicinare",
    "riavvicinereste": "riavvicinare",
    "riavvicineresti": "riavvicinare",
    "riavvicinerete": "riavvicinare",
    "riavvicinerà": "riavvicinare",
    "riavvicinerò": "riavvicinare",
    "riavvicini": "riavvicinare",
    "riavviciniamo": "riavvicinare",
    "riavviciniate": "riavvicinare",
    "riavvicinin": "riavvicinare",
    "riavvicinino": "riavvicinare",
    "riavvicino": "riavvicinare",
    "riavvicinò": "riavvicinare",
    "riavvierai": "riavviare",
    "riavvieran": "riavviare",
    "riavvieranno": "riavviare",
    "riavvierebbe": "riavviare",
    "riavvierebber": "riavviare",
    "riavvierebbero": "riavviare",
    "riavvierei": "riavviare",
    "riavvieremmo": "riavviare",
    "riavvieremo": "riavviare",
    "riavviereste": "riavviare",
    "riavvieresti": "riavviare",
    "riavvierete": "riavviare",
    "riavvierà": "riavviare",
    "riavvierò": "riavviare",
    "riavvii": "riavvio",
    "riavvin": "riavviare",
    "riavvino": "riavviare",
    "riavvio": "riavviare",
    "riavviò": "riavviare",
    "riavvolga": "riavvolgere",
    "riavvolgan": "riavvolgere",
    "riavvolgano": "riavvolgere",
    "riavvolge": "riavvolgere",
    "riavvolgei": "riavvolgere",
    "riavvolgemmo": "riavvolgere",
    "riavvolgendo": "riavvolgere",
    "riavvolgente": "riavvolgere",
    "riavvolgenti": "riavvolgere",
    "riavvolger": "riavvolgere",
    "riavvolgerai": "riavvolgere",
    "riavvolgeran": "riavvolgere",
    "riavvolgeranno": "riavvolgere",
    "riavvolgerebbe": "riavvolgere",
    "riavvolgerebber": "riavvolgere",
    "riavvolgerebbero": "riavvolgere",
    "riavvolgerei": "riavvolgere",
    "riavvolgeremmo": "riavvolgere",
    "riavvolgeremo": "riavvolgere",
    "riavvolgereste": "riavvolgere",
    "riavvolgeresti": "riavvolgere",
    "riavvolgerete": "riavvolgere",
    "riavvolgeron": "riavvolgere",
    "riavvolgerono": "riavvolgere",
    "riavvolgerà": "riavvolgere",
    "riavvolgerò": "riavvolgere",
    "riavvolgesse": "riavvolgere",
    "riavvolgesser": "riavvolgere",
    "riavvolgessero": "riavvolgere",
    "riavvolgessi": "riavvolgere",
    "riavvolgessimo": "riavvolgere",
    "riavvolgeste": "riavvolgere",
    "riavvolgesti": "riavvolgere",
    "riavvolgete": "riavvolgere",
    "riavvolgeva": "riavvolgere",
    "riavvolgevamo": "riavvolgere",
    "riavvolgevan": "riavvolgere",
    "riavvolgevano": "riavvolgere",
    "riavvolgevate": "riavvolgere",
    "riavvolgevi": "riavvolgere",
    "riavvolgevo": "riavvolgere",
    "riavvolgi": "riavvolgere",
    "riavvolgiamo": "riavvolgere",
    "riavvolgiate": "riavvolgere",
    "riavvolgo": "riavvolgere",
    "riavvolgon": "riavvolgere",
    "riavvolgono": "riavvolgere",
    "riavvolgè": "riavvolgere",
    "riavvolta": "riavvolgere",
    "riavvolte": "riavvolgere",
    "riavvolti": "riavvolgere",
    "riavvolto": "riavvolgere",
    "ribadendo": "ribadire",
    "ribadente": "ribadire",
    "ribadenti": "ribadire",
    "ribadiamo": "ribadire",
    "ribadiate": "ribadire",
    "ribadii": "ribadire",
    "ribadimmo": "ribadire",
    "ribadir": "ribadire",
    "ribadirai": "ribadire",
    "ribadiran": "ribadire",
    "ribadiranno": "ribadire",
    "ribadirebbe": "ribadire",
    "ribadirebber": "ribadire",
    "ribadirebbero": "ribadire",
    "ribadirei": "ribadire",
    "ribadiremmo": "ribadire",
    "ribadiremo": "ribadire",
    "ribadireste": "ribadire",
    "ribadiresti": "ribadire",
    "ribadirete": "ribadire",
    "ribadiron": "ribadire",
    "ribadirono": "ribadire",
    "ribadirà": "ribadire",
    "ribadirò": "ribadire",
    "ribadisca": "ribadire",
    "ribadiscan": "ribadire",
    "ribadiscano": "ribadire",
    "ribadisce": "ribadire",
    "ribadisci": "ribadire",
    "ribadisco": "ribadire",
    "ribadiscon": "ribadire",
    "ribadiscono": "ribadire",
    "ribadisse": "ribadire",
    "ribadisser": "ribadire",
    "ribadissero": "ribadire",
    "ribadissi": "ribadire",
    "ribadissimo": "ribadire",
    "ribadiste": "ribadire",
    "ribadisti": "ribadire",
    "ribadita": "ribadire",
    "ribadite": "ribadire",
    "ribaditi": "ribadire",
    "ribadito": "ribadire",
    "ribadiva": "ribadire",
    "ribadivamo": "ribadire",
    "ribadivan": "ribadire",
    "ribadivano": "ribadire",
    "ribadivate": "ribadire",
    "ribadivi": "ribadire",
    "ribadivo": "ribadire",
    "ribadì": "ribadire",
    "ribalderie": "ribalderia",
    "ribalta": "ribaltare",
    "ribaltabili": "ribaltabile",
    "ribaltai": "ribaltare",
    "ribaltamenti": "ribaltamento",
    "ribaltammo": "ribaltare",
    "ribaltan": "ribaltare",
    "ribaltando": "ribaltare",
    "ribaltano": "ribaltare",
    "ribaltante": "ribaltare",
    "ribaltanti": "ribaltare",
    "ribaltar": "ribaltare",
    "ribaltaron": "ribaltare",
    "ribaltarono": "ribaltare",
    "ribaltasse": "ribaltare",
    "ribaltasser": "ribaltare",
    "ribaltassero": "ribaltare",
    "ribaltassi": "ribaltare",
    "ribaltassimo": "ribaltare",
    "ribaltaste": "ribaltare",
    "ribaltasti": "ribaltare",
    "ribaltata": "ribaltare",
    "ribaltate": "ribaltare",
    "ribaltati": "ribaltare",
    "ribaltato": "ribaltare",
    "ribaltava": "ribaltare",
    "ribaltavamo": "ribaltare",
    "ribaltavan": "ribaltare",
    "ribaltavano": "ribaltare",
    "ribaltavate": "ribaltare",
    "ribaltavi": "ribaltare",
    "ribaltavo": "ribaltare",
    "ribalte": "ribalta",
    "ribalterai": "ribaltare",
    "ribalteran": "ribaltare",
    "ribalteranno": "ribaltare",
    "ribalterebbe": "ribaltare",
    "ribalterebber": "ribaltare",
    "ribalterebbero": "ribaltare",
    "ribalterei": "ribaltare",
    "ribalteremmo": "ribaltare",
    "ribalteremo": "ribaltare",
    "ribaltereste": "ribaltare",
    "ribalteresti": "ribaltare",
    "ribalterete": "ribaltare",
    "ribalterà": "ribaltare",
    "ribalterò": "ribaltare",
    "ribalti": "ribaltare",
    "ribaltiamo": "ribaltare",
    "ribaltiate": "ribaltare",
    "ribaltin": "ribaltare",
    "ribaltino": "ribaltare",
    "ribalto": "ribaltare",
    "ribaltoni": "ribaltone",
    "ribaltò": "ribaltare",
    "ribassa": "ribassare",
    "ribassai": "ribassare",
    "ribassammo": "ribassare",
    "ribassan": "ribassare",
    "ribassando": "ribassare",
    "ribassano": "ribassare",
    "ribassante": "ribassare",
    "ribassanti": "ribassare",
    "ribassar": "ribassare",
    "ribassaron": "ribassare",
    "ribassarono": "ribassare",
    "ribassasse": "ribassare",
    "ribassasser": "ribassare",
    "ribassassero": "ribassare",
    "ribassassi": "ribassare",
    "ribassassimo": "ribassare",
    "ribassaste": "ribassare",
    "ribassasti": "ribassare",
    "ribassata": "ribassare",
    "ribassate": "ribassare",
    "ribassati": "ribassare",
    "ribassato": "ribassare",
    "ribassava": "ribassare",
    "ribassavamo": "ribassare",
    "ribassavan": "ribassare",
    "ribassavano": "ribassare",
    "ribassavate": "ribassare",
    "ribassavi": "ribassare",
    "ribassavo": "ribassare",
    "ribasserai": "ribassare",
    "ribasseran": "ribassare",
    "ribasseranno": "ribassare",
    "ribasserebbe": "ribassare",
    "ribasserebber": "ribassare",
    "ribasserebbero": "ribassare",
    "ribasserei": "ribassare",
    "ribasseremmo": "ribassare",
    "ribasseremo": "ribassare",
    "ribassereste": "ribassare",
    "ribasseresti": "ribassare",
    "ribasserete": "ribassare",
    "ribasserà": "ribassare",
    "ribasserò": "ribassare",
    "ribassi": "ribasso",
    "ribassiamo": "ribassare",
    "ribassiate": "ribassare",
    "ribassin": "ribassare",
    "ribassino": "ribassare",
    "ribassiste": "ribassista",
    "ribassisti": "ribassista",
    "ribasso": "ribassare",
    "ribassò": "ribassare",
    "ribatta": "ribattere",
    "ribattan": "ribattere",
    "ribattano": "ribattere",
    "ribatte": "ribattere",
    "ribattei": "ribattere",
    "ribattemmo": "ribattere",
    "ribattendo": "ribattere",
    "ribattente": "ribattere",
    "ribattenti": "ribattere",
    "ribatter": "ribattere",
    "ribatterai": "ribattere",
    "ribatteran": "ribattere",
    "ribatteranno": "ribattere",
    "ribatterebbe": "ribattere",
    "ribatterebber": "ribattere",
    "ribatterebbero": "ribattere",
    "ribatterei": "ribattere",
    "ribatteremmo": "ribattere",
    "ribatteremo": "ribattere",
    "ribattereste": "ribattere",
    "ribatteresti": "ribattere",
    "ribatterete": "ribattere",
    "ribatteron": "ribattere",
    "ribatterono": "ribattere",
    "ribatterà": "ribattere",
    "ribatterò": "ribattere",
    "ribattesse": "ribattere",
    "ribattesser": "ribattere",
    "ribattessero": "ribattere",
    "ribattessi": "ribattere",
    "ribattessimo": "ribattere",
    "ribatteste": "ribattere",
    "ribattesti": "ribattere",
    "ribattete": "ribattere",
    "ribatteva": "ribattere",
    "ribattevamo": "ribattere",
    "ribattevan": "ribattere",
    "ribattevano": "ribattere",
    "ribattevate": "ribattere",
    "ribattevi": "ribattere",
    "ribattevo": "ribattere",
    "ribattezza": "ribattezzare",
    "ribattezzai": "ribattezzare",
    "ribattezzammo": "ribattezzare",
    "ribattezzan": "ribattezzare",
    "ribattezzando": "ribattezzare",
    "ribattezzano": "ribattezzare",
    "ribattezzante": "ribattezzare",
    "ribattezzanti": "ribattezzare",
    "ribattezzar": "ribattezzare",
    "ribattezzaron": "ribattezzare",
    "ribattezzarono": "ribattezzare",
    "ribattezzasse": "ribattezzare",
    "ribattezzasser": "ribattezzare",
    "ribattezzassero": "ribattezzare",
    "ribattezzassi": "ribattezzare",
    "ribattezzassimo": "ribattezzare",
    "ribattezzaste": "ribattezzare",
    "ribattezzasti": "ribattezzare",
    "ribattezzata": "ribattezzare",
    "ribattezzate": "ribattezzare",
    "ribattezzati": "ribattezzare",
    "ribattezzato": "ribattezzare",
    "ribattezzava": "ribattezzare",
    "ribattezzavamo": "ribattezzare",
    "ribattezzavan": "ribattezzare",
    "ribattezzavano": "ribattezzare",
    "ribattezzavate": "ribattezzare",
    "ribattezzavi": "ribattezzare",
    "ribattezzavo": "ribattezzare",
    "ribattezzerai": "ribattezzare",
    "ribattezzeran": "ribattezzare",
    "ribattezzeranno": "ribattezzare",
    "ribattezzerebbe": "ribattezzare",
    "ribattezzerebber": "ribattezzare",
    "ribattezzerebbero": "ribattezzare",
    "ribattezzerei": "ribattezzare",
    "ribattezzeremmo": "ribattezzare",
    "ribattezzeremo": "ribattezzare",
    "ribattezzereste": "ribattezzare",
    "ribattezzeresti": "ribattezzare",
    "ribattezzerete": "ribattezzare",
    "ribattezzerà": "ribattezzare",
    "ribattezzerò": "ribattezzare",
    "ribattezzi": "ribattezzare",
    "ribattezziamo": "ribattezzare",
    "ribattezziate": "ribattezzare",
    "ribattezzin": "ribattezzare",
    "ribattezzino": "ribattezzare",
    "ribattezzo": "ribattezzare",
    "ribattezzò": "ribattezzare",
    "ribatti": "ribattere",
    "ribattiamo": "ribattere",
    "ribattiate": "ribattere",
    "ribatto": "ribattere",
    "ribatton": "ribattere",
    "ribattono": "ribattere",
    "ribattuta": "ribattere",
    "ribattute": "ribattuta",
    "ribattuti": "ribattere",
    "ribattuto": "ribattere",
    "ribattè": "ribattere",
    "ribella": "ribellare",
    "ribellai": "ribellare",
    "ribellammo": "ribellare",
    "ribellan": "ribellare",
    "ribellando": "ribellare",
    "ribellano": "ribellare",
    "ribellante": "ribellare",
    "ribellanti": "ribellare",
    "ribellar": "ribellare",
    "ribellaron": "ribellare",
    "ribellarono": "ribellare",
    "ribellasse": "ribellare",
    "ribellasser": "ribellare",
    "ribellassero": "ribellare",
    "ribellassi": "ribellare",
    "ribellassimo": "ribellare",
    "ribellaste": "ribellare",
    "ribellasti": "ribellare",
    "ribellata": "ribellare",
    "ribellate": "ribellare",
    "ribellati": "ribellare",
    "ribellato": "ribellare",
    "ribellava": "ribellare",
    "ribellavamo": "ribellare",
    "ribellavan": "ribellare",
    "ribellavano": "ribellare",
    "ribellavate": "ribellare",
    "ribellavi": "ribellare",
    "ribellavo": "ribellare",
    "ribellerai": "ribellare",
    "ribelleran": "ribellare",
    "ribelleranno": "ribellare",
    "ribellerebbe": "ribellare",
    "ribellerebber": "ribellare",
    "ribellerebbero": "ribellare",
    "ribellerei": "ribellare",
    "ribelleremmo": "ribellare",
    "ribelleremo": "ribellare",
    "ribellereste": "ribellare",
    "ribelleresti": "ribellare",
    "ribellerete": "ribellare",
    "ribellerà": "ribellare",
    "ribellerò": "ribellare",
    "ribelli": "ribelle",
    "ribelliamo": "ribellare",
    "ribelliate": "ribellare",
    "ribellin": "ribellare",
    "ribellino": "ribellare",
    "ribellioni": "ribellione",
    "ribellismi": "ribellismo",
    "ribellistica": "ribellistico",
    "ribellistiche": "ribellistico",
    "ribellistici": "ribellistico",
    "ribello": "ribellare",
    "ribellò": "ribellare",
    "ribilanciamenti": "ribilanciamento",
    "ribocca": "riboccare",
    "riboccai": "riboccare",
    "riboccammo": "riboccare",
    "riboccan": "riboccare",
    "riboccando": "riboccare",
    "riboccano": "riboccare",
    "riboccante": "riboccare",
    "riboccanti": "riboccare",
    "riboccar": "riboccare",
    "riboccaron": "riboccare",
    "riboccarono": "riboccare",
    "riboccasse": "riboccare",
    "riboccasser": "riboccare",
    "riboccassero": "riboccare",
    "riboccassi": "riboccare",
    "riboccassimo": "riboccare",
    "riboccaste": "riboccare",
    "riboccasti": "riboccare",
    "riboccata": "riboccare",
    "riboccate": "riboccare",
    "riboccati": "riboccare",
    "riboccato": "riboccare",
    "riboccava": "riboccare",
    "riboccavamo": "riboccare",
    "riboccavan": "riboccare",
    "riboccavano": "riboccare",
    "riboccavate": "riboccare",
    "riboccavi": "riboccare",
    "riboccavo": "riboccare",
    "riboccherai": "riboccare",
    "riboccheran": "riboccare",
    "riboccheranno": "riboccare",
    "riboccherebbe": "riboccare",
    "riboccherebber": "riboccare",
    "riboccherebbero": "riboccare",
    "riboccherei": "riboccare",
    "riboccheremmo": "riboccare",
    "riboccheremo": "riboccare",
    "ribocchereste": "riboccare",
    "riboccheresti": "riboccare",
    "riboccherete": "riboccare",
    "riboccherà": "riboccare",
    "riboccherò": "riboccare",
    "ribocchi": "riboccare",
    "ribocchiamo": "riboccare",
    "ribocchiate": "riboccare",
    "ribocchin": "riboccare",
    "ribocchino": "riboccare",
    "ribocco": "riboccare",
    "riboccò": "riboccare",
    "ribolla": "ribollire",
    "ribollan": "ribollire",
    "ribollano": "ribollire",
    "ribolle": "ribollire",
    "ribollendo": "ribollire",
    "ribollente": "ribollire",
    "ribollenti": "ribollire",
    "ribolli": "ribollire",
    "ribolliamo": "ribollire",
    "ribolliate": "ribollire",
    "ribollii": "ribollire",
    "ribollimmo": "ribollire",
    "ribollir": "ribollire",
    "ribollirai": "ribollire",
    "ribolliran": "ribollire",
    "ribolliranno": "ribollire",
    "ribollirebbe": "ribollire",
    "ribollirebber": "ribollire",
    "ribollirebbero": "ribollire",
    "ribollirei": "ribollire",
    "ribolliremmo": "ribollire",
    "ribolliremo": "ribollire",
    "ribollireste": "ribollire",
    "ribolliresti": "ribollire",
    "ribollirete": "ribollire",
    "ribolliron": "ribollire",
    "ribollirono": "ribollire",
    "ribollirà": "ribollire",
    "ribollirò": "ribollire",
    "ribollisse": "ribollire",
    "ribollisser": "ribollire",
    "ribollissero": "ribollire",
    "ribollissi": "ribollire",
    "ribollissimo": "ribollire",
    "ribolliste": "ribollire",
    "ribollisti": "ribollire",
    "ribollita": "ribollire",
    "ribollite": "ribollire",
    "ribolliti": "ribollire",
    "ribollito": "ribollire",
    "ribolliva": "ribollire",
    "ribollivamo": "ribollire",
    "ribollivan": "ribollire",
    "ribollivano": "ribollire",
    "ribollivate": "ribollire",
    "ribollivi": "ribollire",
    "ribollivo": "ribollire",
    "ribollo": "ribollire",
    "ribollon": "ribollire",
    "ribollono": "ribollire",
    "ribollì": "ribollire",
    "ribonucleica": "ribonucleico",
    "ribonucleiche": "ribonucleico",
    "ribonucleici": "ribonucleico",
    "ributta": "ributtare",
    "ributtai": "ributtare",
    "ributtammo": "ributtare",
    "ributtan": "ributtare",
    "ributtando": "ributtare",
    "ributtano": "ributtare",
    "ributtante": "ributtare",
    "ributtanti": "ributtare",
    "ributtar": "ributtare",
    "ributtaron": "ributtare",
    "ributtarono": "ributtare",
    "ributtasse": "ributtare",
    "ributtasser": "ributtare",
    "ributtassero": "ributtare",
    "ributtassi": "ributtare",
    "ributtassimo": "ributtare",
    "ributtaste": "ributtare",
    "ributtasti": "ributtare",
    "ributtata": "ributtare",
    "ributtate": "ributtare",
    "ributtati": "ributtare",
    "ributtato": "ributtare",
    "ributtava": "ributtare",
    "ributtavamo": "ributtare",
    "ributtavan": "ributtare",
    "ributtavano": "ributtare",
    "ributtavate": "ributtare",
    "ributtavi": "ributtare",
    "ributtavo": "ributtare",
    "ributterai": "ributtare",
    "ributteran": "ributtare",
    "ributteranno": "ributtare",
    "ributterebbe": "ributtare",
    "ributterebber": "ributtare",
    "ributterebbero": "ributtare",
    "ributterei": "ributtare",
    "ributteremmo": "ributtare",
    "ributteremo": "ributtare",
    "ributtereste": "ributtare",
    "ributteresti": "ributtare",
    "ributterete": "ributtare",
    "ributterà": "ributtare",
    "ributterò": "ributtare",
    "ributti": "ributtare",
    "ributtiamo": "ributtare",
    "ributtiate": "ributtare",
    "ributtin": "ributtare",
    "ributtino": "ributtare",
    "ributto": "ributtare",
    "ributtò": "ributtare",
    "ricaccerai": "ricacciare",
    "ricacceran": "ricacciare",
    "ricacceranno": "ricacciare",
    "ricaccerebbe": "ricacciare",
    "ricaccerebber": "ricacciare",
    "ricaccerebbero": "ricacciare",
    "ricaccerei": "ricacciare",
    "ricacceremmo": "ricacciare",
    "ricacceremo": "ricacciare",
    "ricaccereste": "ricacciare",
    "ricacceresti": "ricacciare",
    "ricaccerete": "ricacciare",
    "ricaccerà": "ricacciare",
    "ricaccerò": "ricacciare",
    "ricacci": "ricacciare",
    "ricaccia": "ricacciare",
    "ricacciai": "ricacciare",
    "ricacciammo": "ricacciare",
    "ricacciamo": "ricacciare",
    "ricaccian": "ricacciare",
    "ricacciando": "ricacciare",
    "ricacciano": "ricacciare",
    "ricacciante": "ricacciare",
    "ricaccianti": "ricacciare",
    "ricacciar": "ricacciare",
    "ricacciaron": "ricacciare",
    "ricacciarono": "ricacciare",
    "ricacciasse": "ricacciare",
    "ricacciasser": "ricacciare",
    "ricacciassero": "ricacciare",
    "ricacciassi": "ricacciare",
    "ricacciassimo": "ricacciare",
    "ricacciaste": "ricacciare",
    "ricacciasti": "ricacciare",
    "ricacciata": "ricacciare",
    "ricacciate": "ricacciare",
    "ricacciati": "ricacciare",
    "ricacciato": "ricacciare",
    "ricacciava": "ricacciare",
    "ricacciavamo": "ricacciare",
    "ricacciavan": "ricacciare",
    "ricacciavano": "ricacciare",
    "ricacciavate": "ricacciare",
    "ricacciavi": "ricacciare",
    "ricacciavo": "ricacciare",
    "ricaccin": "ricacciare",
    "ricaccino": "ricacciare",
    "ricaccio": "ricacciare",
    "ricacciò": "ricacciare",
    "ricada": "ricadere",
    "ricadan": "ricadere",
    "ricadano": "ricadere",
    "ricadde": "ricadere",
    "ricadder": "ricadere",
    "ricaddero": "ricadere",
    "ricaddi": "ricadere",
    "ricade": "ricadere",
    "ricademmo": "ricadere",
    "ricadendo": "ricadere",
    "ricadente": "ricadere",
    "ricadenti": "ricadere",
    "ricader": "ricadere",
    "ricadesse": "ricadere",
    "ricadesser": "ricadere",
    "ricadessero": "ricadere",
    "ricadessi": "ricadere",
    "ricadessimo": "ricadere",
    "ricadeste": "ricadere",
    "ricadesti": "ricadere",
    "ricadete": "ricadere",
    "ricadeva": "ricadere",
    "ricadevamo": "ricadere",
    "ricadevan": "ricadere",
    "ricadevano": "ricadere",
    "ricadevate": "ricadere",
    "ricadevi": "ricadere",
    "ricadevo": "ricadere",
    "ricadi": "ricadere",
    "ricadiamo": "ricadere",
    "ricadiate": "ricadere",
    "ricado": "ricadere",
    "ricadon": "ricadere",
    "ricadono": "ricadere",
    "ricadrai": "ricadere",
    "ricadran": "ricadere",
    "ricadranno": "ricadere",
    "ricadrebbe": "ricadere",
    "ricadrebber": "ricadere",
    "ricadrebbero": "ricadere",
    "ricadrei": "ricadere",
    "ricadremmo": "ricadere",
    "ricadremo": "ricadere",
    "ricadreste": "ricadere",
    "ricadresti": "ricadere",
    "ricadrete": "ricadere",
    "ricadrà": "ricadere",
    "ricadrò": "ricadere",
    "ricaduta": "ricadere",
    "ricadute": "ricaduta",
    "ricaduti": "ricadere",
    "ricaduto": "ricadere",
    "ricalca": "ricalcare",
    "ricalcai": "ricalcare",
    "ricalcammo": "ricalcare",
    "ricalcan": "ricalcare",
    "ricalcando": "ricalcare",
    "ricalcano": "ricalcare",
    "ricalcante": "ricalcare",
    "ricalcanti": "ricalcare",
    "ricalcar": "ricalcare",
    "ricalcaron": "ricalcare",
    "ricalcarono": "ricalcare",
    "ricalcasse": "ricalcare",
    "ricalcasser": "ricalcare",
    "ricalcassero": "ricalcare",
    "ricalcassi": "ricalcare",
    "ricalcassimo": "ricalcare",
    "ricalcaste": "ricalcare",
    "ricalcasti": "ricalcare",
    "ricalcata": "ricalcare",
    "ricalcate": "ricalcare",
    "ricalcati": "ricalcare",
    "ricalcato": "ricalcare",
    "ricalcava": "ricalcare",
    "ricalcavamo": "ricalcare",
    "ricalcavan": "ricalcare",
    "ricalcavano": "ricalcare",
    "ricalcavate": "ricalcare",
    "ricalcavi": "ricalcare",
    "ricalcavo": "ricalcare",
    "ricalcherai": "ricalcare",
    "ricalcheran": "ricalcare",
    "ricalcheranno": "ricalcare",
    "ricalcherebbe": "ricalcare",
    "ricalcherebber": "ricalcare",
    "ricalcherebbero": "ricalcare",
    "ricalcherei": "ricalcare",
    "ricalcheremmo": "ricalcare",
    "ricalcheremo": "ricalcare",
    "ricalchereste": "ricalcare",
    "ricalcheresti": "ricalcare",
    "ricalcherete": "ricalcare",
    "ricalcherà": "ricalcare",
    "ricalcherò": "ricalcare",
    "ricalchi": "ricalco",
    "ricalchiamo": "ricalcare",
    "ricalchiate": "ricalcare",
    "ricalchin": "ricalcare",
    "ricalchino": "ricalcare",
    "ricalcitra": "ricalcitrare",
    "ricalcitrai": "ricalcitrare",
    "ricalcitrammo": "ricalcitrare",
    "ricalcitran": "ricalcitrare",
    "ricalcitrando": "ricalcitrare",
    "ricalcitrano": "ricalcitrare",
    "ricalcitrante": "ricalcitrare",
    "ricalcitranti": "ricalcitrare",
    "ricalcitrar": "ricalcitrare",
    "ricalcitraron": "ricalcitrare",
    "ricalcitrarono": "ricalcitrare",
    "ricalcitrasse": "ricalcitrare",
    "ricalcitrasser": "ricalcitrare",
    "ricalcitrassero": "ricalcitrare",
    "ricalcitrassi": "ricalcitrare",
    "ricalcitrassimo": "ricalcitrare",
    "ricalcitraste": "ricalcitrare",
    "ricalcitrasti": "ricalcitrare",
    "ricalcitrata": "ricalcitrare",
    "ricalcitrate": "ricalcitrare",
    "ricalcitrati": "ricalcitrare",
    "ricalcitrato": "ricalcitrare",
    "ricalcitrava": "ricalcitrare",
    "ricalcitravamo": "ricalcitrare",
    "ricalcitravan": "ricalcitrare",
    "ricalcitravano": "ricalcitrare",
    "ricalcitravate": "ricalcitrare",
    "ricalcitravi": "ricalcitrare",
    "ricalcitravo": "ricalcitrare",
    "ricalcitrerai": "ricalcitrare",
    "ricalcitreran": "ricalcitrare",
    "ricalcitreranno": "ricalcitrare",
    "ricalcitrerebbe": "ricalcitrare",
    "ricalcitrerebber": "ricalcitrare",
    "ricalcitrerebbero": "ricalcitrare",
    "ricalcitrerei": "ricalcitrare",
    "ricalcitreremmo": "ricalcitrare",
    "ricalcitreremo": "ricalcitrare",
    "ricalcitrereste": "ricalcitrare",
    "ricalcitreresti": "ricalcitrare",
    "ricalcitrerete": "ricalcitrare",
    "ricalcitrerà": "ricalcitrare",
    "ricalcitrerò": "ricalcitrare",
    "ricalcitri": "ricalcitrare",
    "ricalcitriamo": "ricalcitrare",
    "ricalcitriate": "ricalcitrare",
    "ricalcitrin": "ricalcitrare",
    "ricalcitrino": "ricalcitrare",
    "ricalcitro": "ricalcitrare",
    "ricalcitrò": "ricalcitrare",
    "ricalco": "ricalcare",
    "ricalcoli": "ricalcolo",
    "ricalcò": "ricalcare",
    "ricama": "ricamare",
    "ricamai": "ricamare",
    "ricamammo": "ricamare",
    "ricaman": "ricamare",
    "ricamando": "ricamare",
    "ricamano": "ricamare",
    "ricamante": "ricamare",
    "ricamanti": "ricamare",
    "ricamar": "ricamare",
    "ricamaron": "ricamare",
    "ricamarono": "ricamare",
    "ricamasse": "ricamare",
    "ricamasser": "ricamare",
    "ricamassero": "ricamare",
    "ricamassi": "ricamare",
    "ricamassimo": "ricamare",
    "ricamaste": "ricamare",
    "ricamasti": "ricamare",
    "ricamata": "ricamare",
    "ricamate": "ricamare",
    "ricamati": "ricamare",
    "ricamato": "ricamare",
    "ricamatori": "ricamatore",
    "ricamatrici": "ricamatrice",
    "ricamava": "ricamare",
    "ricamavamo": "ricamare",
    "ricamavan": "ricamare",
    "ricamavano": "ricamare",
    "ricamavate": "ricamare",
    "ricamavi": "ricamare",
    "ricamavo": "ricamare",
    "ricambi": "ricambio",
    "ricambia": "ricambiare",
    "ricambiai": "ricambiare",
    "ricambiammo": "ricambiare",
    "ricambiamo": "ricambiare",
    "ricambian": "ricambiare",
    "ricambiando": "ricambiare",
    "ricambiano": "ricambiare",
    "ricambiante": "ricambiare",
    "ricambianti": "ricambiare",
    "ricambiar": "ricambiare",
    "ricambiaron": "ricambiare",
    "ricambiarono": "ricambiare",
    "ricambiasse": "ricambiare",
    "ricambiasser": "ricambiare",
    "ricambiassero": "ricambiare",
    "ricambiassi": "ricambiare",
    "ricambiassimo": "ricambiare",
    "ricambiaste": "ricambiare",
    "ricambiasti": "ricambiare",
    "ricambiata": "ricambiare",
    "ricambiate": "ricambiare",
    "ricambiati": "ricambiare",
    "ricambiato": "ricambiare",
    "ricambiava": "ricambiare",
    "ricambiavamo": "ricambiare",
    "ricambiavan": "ricambiare",
    "ricambiavano": "ricambiare",
    "ricambiavate": "ricambiare",
    "ricambiavi": "ricambiare",
    "ricambiavo": "ricambiare",
    "ricambierai": "ricambiare",
    "ricambieran": "ricambiare",
    "ricambieranno": "ricambiare",
    "ricambierebbe": "ricambiare",
    "ricambierebber": "ricambiare",
    "ricambierebbero": "ricambiare",
    "ricambierei": "ricambiare",
    "ricambieremmo": "ricambiare",
    "ricambieremo": "ricambiare",
    "ricambiereste": "ricambiare",
    "ricambieresti": "ricambiare",
    "ricambierete": "ricambiare",
    "ricambierà": "ricambiare",
    "ricambierò": "ricambiare",
    "ricambin": "ricambiare",
    "ricambino": "ricambiare",
    "ricambio": "ricambiare",
    "ricambiò": "ricambiare",
    "ricamerai": "ricamare",
    "ricameran": "ricamare",
    "ricameranno": "ricamare",
    "ricamerebbe": "ricamare",
    "ricamerebber": "ricamare",
    "ricamerebbero": "ricamare",
    "ricamerei": "ricamare",
    "ricameremmo": "ricamare",
    "ricameremo": "ricamare",
    "ricamereste": "ricamare",
    "ricameresti": "ricamare",
    "ricamerete": "ricamare",
    "ricamerà": "ricamare",
    "ricamerò": "ricamare",
    "ricami": "ricamo",
    "ricamiamo": "ricamare",
    "ricamiate": "ricamare",
    "ricamin": "ricamare",
    "ricamino": "ricamare",
    "ricamo": "ricamare",
    "ricamò": "ricamare",
    "ricandidature": "ricandidatura",
    "ricanta": "ricantare",
    "ricantai": "ricantare",
    "ricantammo": "ricantare",
    "ricantan": "ricantare",
    "ricantando": "ricantare",
    "ricantano": "ricantare",
    "ricantante": "ricantare",
    "ricantanti": "ricantare",
    "ricantar": "ricantare",
    "ricantaron": "ricantare",
    "ricantarono": "ricantare",
    "ricantasse": "ricantare",
    "ricantasser": "ricantare",
    "ricantassero": "ricantare",
    "ricantassi": "ricantare",
    "ricantassimo": "ricantare",
    "ricantaste": "ricantare",
    "ricantasti": "ricantare",
    "ricantata": "ricantare",
    "ricantate": "ricantare",
    "ricantati": "ricantare",
    "ricantato": "ricantare",
    "ricantava": "ricantare",
    "ricantavamo": "ricantare",
    "ricantavan": "ricantare",
    "ricantavano": "ricantare",
    "ricantavate": "ricantare",
    "ricantavi": "ricantare",
    "ricantavo": "ricantare",
    "ricanterai": "ricantare",
    "ricanteran": "ricantare",
    "ricanteranno": "ricantare",
    "ricanterebbe": "ricantare",
    "ricanterebber": "ricantare",
    "ricanterebbero": "ricantare",
    "ricanterei": "ricantare",
    "ricanteremmo": "ricantare",
    "ricanteremo": "ricantare",
    "ricantereste": "ricantare",
    "ricanteresti": "ricantare",
    "ricanterete": "ricantare",
    "ricanterà": "ricantare",
    "ricanterò": "ricantare",
    "ricanti": "ricantare",
    "ricantiamo": "ricantare",
    "ricantiate": "ricantare",
    "ricantin": "ricantare",
    "ricantino": "ricantare",
    "ricanto": "ricantare",
    "ricantò": "ricantare",
    "ricapitalizzazioni": "ricapitalizzazione",
    "ricapitola": "ricapitolare",
    "ricapitolai": "ricapitolare",
    "ricapitolammo": "ricapitolare",
    "ricapitolan": "ricapitolare",
    "ricapitolando": "ricapitolare",
    "ricapitolano": "ricapitolare",
    "ricapitolante": "ricapitolare",
    "ricapitolanti": "ricapitolare",
    "ricapitolar": "ricapitolare",
    "ricapitolaron": "ricapitolare",
    "ricapitolarono": "ricapitolare",
    "ricapitolasse": "ricapitolare",
    "ricapitolasser": "ricapitolare",
    "ricapitolassero": "ricapitolare",
    "ricapitolassi": "ricapitolare",
    "ricapitolassimo": "ricapitolare",
    "ricapitolaste": "ricapitolare",
    "ricapitolasti": "ricapitolare",
    "ricapitolata": "ricapitolare",
    "ricapitolate": "ricapitolare",
    "ricapitolati": "ricapitolare",
    "ricapitolato": "ricapitolare",
    "ricapitolava": "ricapitolare",
    "ricapitolavamo": "ricapitolare",
    "ricapitolavan": "ricapitolare",
    "ricapitolavano": "ricapitolare",
    "ricapitolavate": "ricapitolare",
    "ricapitolavi": "ricapitolare",
    "ricapitolavo": "ricapitolare",
    "ricapitolazioni": "ricapitolazione",
    "ricapitolerai": "ricapitolare",
    "ricapitoleran": "ricapitolare",
    "ricapitoleranno": "ricapitolare",
    "ricapitolerebbe": "ricapitolare",
    "ricapitolerebber": "ricapitolare",
    "ricapitolerebbero": "ricapitolare",
    "ricapitolerei": "ricapitolare",
    "ricapitoleremmo": "ricapitolare",
    "ricapitoleremo": "ricapitolare",
    "ricapitolereste": "ricapitolare",
    "ricapitoleresti": "ricapitolare",
    "ricapitolerete": "ricapitolare",
    "ricapitolerà": "ricapitolare",
    "ricapitolerò": "ricapitolare",
    "ricapitoli": "ricapitolare",
    "ricapitoliamo": "ricapitolare",
    "ricapitoliate": "ricapitolare",
    "ricapitolin": "ricapitolare",
    "ricapitolino": "ricapitolare",
    "ricapitolo": "ricapitolare",
    "ricapitolò": "ricapitolare",
    "ricarica": "ricaricare",
    "ricaricai": "ricaricare",
    "ricaricammo": "ricaricare",
    "ricarican": "ricaricare",
    "ricaricando": "ricaricare",
    "ricaricano": "ricaricare",
    "ricaricante": "ricaricare",
    "ricaricanti": "ricaricare",
    "ricaricar": "ricaricare",
    "ricaricaron": "ricaricare",
    "ricaricarono": "ricaricare",
    "ricaricasse": "ricaricare",
    "ricaricasser": "ricaricare",
    "ricaricassero": "ricaricare",
    "ricaricassi": "ricaricare",
    "ricaricassimo": "ricaricare",
    "ricaricaste": "ricaricare",
    "ricaricasti": "ricaricare",
    "ricaricata": "ricaricare",
    "ricaricate": "ricaricare",
    "ricaricati": "ricaricare",
    "ricaricato": "ricaricare",
    "ricaricava": "ricaricare",
    "ricaricavamo": "ricaricare",
    "ricaricavan": "ricaricare",
    "ricaricavano": "ricaricare",
    "ricaricavate": "ricaricare",
    "ricaricavi": "ricaricare",
    "ricaricavo": "ricaricare",
    "ricariche": "ricarica",
    "ricaricherai": "ricaricare",
    "ricaricheran": "ricaricare",
    "ricaricheranno": "ricaricare",
    "ricaricherebbe": "ricaricare",
    "ricaricherebber": "ricaricare",
    "ricaricherebbero": "ricaricare",
    "ricaricherei": "ricaricare",
    "ricaricheremmo": "ricaricare",
    "ricaricheremo": "ricaricare",
    "ricarichereste": "ricaricare",
    "ricaricheresti": "ricaricare",
    "ricaricherete": "ricaricare",
    "ricaricherà": "ricaricare",
    "ricaricherò": "ricaricare",
    "ricarichi": "ricarico",
    "ricarichiamo": "ricaricare",
    "ricarichiate": "ricaricare",
    "ricarichin": "ricaricare",
    "ricarichino": "ricaricare",
    "ricarico": "ricaricare",
    "ricaricò": "ricaricare",
    "ricasca": "ricascare",
    "ricascai": "ricascare",
    "ricascammo": "ricascare",
    "ricascan": "ricascare",
    "ricascando": "ricascare",
    "ricascano": "ricascare",
    "ricascante": "ricascare",
    "ricascanti": "ricascare",
    "ricascar": "ricascare",
    "ricascaron": "ricascare",
    "ricascarono": "ricascare",
    "ricascasse": "ricascare",
    "ricascasser": "ricascare",
    "ricascassero": "ricascare",
    "ricascassi": "ricascare",
    "ricascassimo": "ricascare",
    "ricascaste": "ricascare",
    "ricascasti": "ricascare",
    "ricascata": "ricascare",
    "ricascate": "ricascare",
    "ricascati": "ricascare",
    "ricascato": "ricascare",
    "ricascava": "ricascare",
    "ricascavamo": "ricascare",
    "ricascavan": "ricascare",
    "ricascavano": "ricascare",
    "ricascavate": "ricascare",
    "ricascavi": "ricascare",
    "ricascavo": "ricascare",
    "ricascherai": "ricascare",
    "ricascheran": "ricascare",
    "ricascheranno": "ricascare",
    "ricascherebbe": "ricascare",
    "ricascherebber": "ricascare",
    "ricascherebbero": "ricascare",
    "ricascherei": "ricascare",
    "ricascheremmo": "ricascare",
    "ricascheremo": "ricascare",
    "ricaschereste": "ricascare",
    "ricascheresti": "ricascare",
    "ricascherete": "ricascare",
    "ricascherà": "ricascare",
    "ricascherò": "ricascare",
    "ricaschi": "ricascare",
    "ricaschiamo": "ricascare",
    "ricaschiate": "ricascare",
    "ricaschin": "ricascare",
    "ricaschino": "ricascare",
    "ricasco": "ricascare",
    "ricascò": "ricascare",
    "ricatta": "ricattare",
    "ricattai": "ricattare",
    "ricattammo": "ricattare",
    "ricattan": "ricattare",
    "ricattando": "ricattare",
    "ricattano": "ricattare",
    "ricattante": "ricattare",
    "ricattanti": "ricattare",
    "ricattar": "ricattare",
    "ricattaron": "ricattare",
    "ricattarono": "ricattare",
    "ricattasse": "ricattare",
    "ricattasser": "ricattare",
    "ricattassero": "ricattare",
    "ricattassi": "ricattare",
    "ricattassimo": "ricattare",
    "ricattaste": "ricattare",
    "ricattasti": "ricattare",
    "ricattata": "ricattare",
    "ricattate": "ricattare",
    "ricattati": "ricattare",
    "ricattato": "ricattare",
    "ricattatori": "ricattatore",
    "ricattatrice": "ricattatore",
    "ricattatrici": "ricattatore",
    "ricattava": "ricattare",
    "ricattavamo": "ricattare",
    "ricattavan": "ricattare",
    "ricattavano": "ricattare",
    "ricattavate": "ricattare",
    "ricattavi": "ricattare",
    "ricattavo": "ricattare",
    "ricatterai": "ricattare",
    "ricatteran": "ricattare",
    "ricatteranno": "ricattare",
    "ricatterebbe": "ricattare",
    "ricatterebber": "ricattare",
    "ricatterebbero": "ricattare",
    "ricatterei": "ricattare",
    "ricatteremmo": "ricattare",
    "ricatteremo": "ricattare",
    "ricattereste": "ricattare",
    "ricatteresti": "ricattare",
    "ricatterete": "ricattare",
    "ricatterà": "ricattare",
    "ricatterò": "ricattare",
    "ricatti": "ricatto",
    "ricattiamo": "ricattare",
    "ricattiate": "ricattare",
    "ricattin": "ricattare",
    "ricattino": "ricattare",
    "ricatto": "ricattare",
    "ricattò": "ricattare",
    "ricava": "ricavare",
    "ricavabili": "ricavabile",
    "ricavai": "ricavare",
    "ricavammo": "ricavare",
    "ricavan": "ricavare",
    "ricavando": "ricavare",
    "ricavano": "ricavare",
    "ricavante": "ricavare",
    "ricavanti": "ricavare",
    "ricavar": "ricavare",
    "ricavaron": "ricavare",
    "ricavarono": "ricavare",
    "ricavasse": "ricavare",
    "ricavasser": "ricavare",
    "ricavassero": "ricavare",
    "ricavassi": "ricavare",
    "ricavassimo": "ricavare",
    "ricavaste": "ricavare",
    "ricavasti": "ricavare",
    "ricavata": "ricavato",
    "ricavate": "ricavato",
    "ricavati": "ricavato",
    "ricavato": "ricavare",
    "ricavava": "ricavare",
    "ricavavamo": "ricavare",
    "ricavavan": "ricavare",
    "ricavavano": "ricavare",
    "ricavavate": "ricavare",
    "ricavavi": "ricavare",
    "ricavavo": "ricavare",
    "ricaverai": "ricavare",
    "ricaveran": "ricavare",
    "ricaveranno": "ricavare",
    "ricaverebbe": "ricavare",
    "ricaverebber": "ricavare",
    "ricaverebbero": "ricavare",
    "ricaverei": "ricavare",
    "ricaveremmo": "ricavare",
    "ricaveremo": "ricavare",
    "ricavereste": "ricavare",
    "ricaveresti": "ricavare",
    "ricaverete": "ricavare",
    "ricaverà": "ricavare",
    "ricaverò": "ricavare",
    "ricavi": "ricavo",
    "ricaviamo": "ricavare",
    "ricaviate": "ricavare",
    "ricavin": "ricavare",
    "ricavino": "ricavare",
    "ricavo": "ricavare",
    "ricavometri": "ricavometro",
    "ricavò": "ricavare",
    "ricca": "ricco",
    "riccastri": "riccastro",
    "ricce": "riccio",
    "ricche": "ricco",
    "ricchezze": "ricchezza",
    "ricchi": "ricco",
    "ricci": "riccio",
    "riccia": "riccio",
    "riccioletti": "riccioletto",
    "riccioli": "ricciolo",
    "ricciolini": "ricciolino",
    "riccioloni": "ricciolone",
    "riccioluta": "riccioluto",
    "ricciolute": "riccioluto",
    "riccioluti": "riccioluto",
    "ricciuta": "ricciuto",
    "ricciute": "ricciuto",
    "ricciuti": "ricciuto",
    "riccometri": "riccometro",
    "ricconi": "riccone",
    "riceda": "ricedere",
    "ricedan": "ricedere",
    "ricedano": "ricedere",
    "ricede": "ricedere",
    "ricedei": "ricedere",
    "ricedemmo": "ricedere",
    "ricedendo": "ricedere",
    "ricedente": "ricedere",
    "ricedenti": "ricedere",
    "riceder": "ricedere",
    "ricederai": "ricedere",
    "ricederan": "ricedere",
    "ricederanno": "ricedere",
    "ricederebbe": "ricedere",
    "ricederebber": "ricedere",
    "ricederebbero": "ricedere",
    "ricederei": "ricedere",
    "ricederemmo": "ricedere",
    "ricederemo": "ricedere",
    "ricedereste": "ricedere",
    "ricederesti": "ricedere",
    "ricederete": "ricedere",
    "ricederon": "ricedere",
    "ricederono": "ricedere",
    "ricederà": "ricedere",
    "ricederò": "ricedere",
    "ricedesse": "ricedere",
    "ricedesser": "ricedere",
    "ricedessero": "ricedere",
    "ricedessi": "ricedere",
    "ricedessimo": "ricedere",
    "ricedeste": "ricedere",
    "ricedesti": "ricedere",
    "ricedete": "ricedere",
    "ricedeva": "ricedere",
    "ricedevamo": "ricedere",
    "ricedevan": "ricedere",
    "ricedevano": "ricedere",
    "ricedevate": "ricedere",
    "ricedevi": "ricedere",
    "ricedevo": "ricedere",
    "ricedi": "ricedere",
    "ricediamo": "ricedere",
    "ricediate": "ricedere",
    "ricedo": "ricedere",
    "ricedon": "ricedere",
    "ricedono": "ricedere",
    "riceduta": "ricedere",
    "ricedute": "ricedere",
    "riceduti": "ricedere",
    "riceduto": "ricedere",
    "ricedè": "ricedere",
    "ricerca": "ricercare",
    "ricercai": "ricercare",
    "ricercammo": "ricercare",
    "ricercan": "ricercare",
    "ricercando": "ricercare",
    "ricercano": "ricercare",
    "ricercante": "ricercare",
    "ricercanti": "ricercare",
    "ricercar": "ricercare",
    "ricercaron": "ricercare",
    "ricercarono": "ricercare",
    "ricercasse": "ricercare",
    "ricercasser": "ricercare",
    "ricercassero": "ricercare",
    "ricercassi": "ricercare",
    "ricercassimo": "ricercare",
    "ricercaste": "ricercare",
    "ricercasti": "ricercare",
    "ricercata": "ricercato",
    "ricercate": "ricercato",
    "ricercatezze": "ricercatezza",
    "ricercati": "ricercato",
    "ricercato": "ricercare",
    "ricercatori": "ricercatore",
    "ricercatrici": "ricercatrice",
    "ricercava": "ricercare",
    "ricercavamo": "ricercare",
    "ricercavan": "ricercare",
    "ricercavano": "ricercare",
    "ricercavate": "ricercare",
    "ricercavi": "ricercare",
    "ricercavo": "ricercare",
    "ricerche": "ricerca",
    "ricercherai": "ricercare",
    "ricercheran": "ricercare",
    "ricercheranno": "ricercare",
    "ricercherebbe": "ricercare",
    "ricercherebber": "ricercare",
    "ricercherebbero": "ricercare",
    "ricercherei": "ricercare",
    "ricercheremmo": "ricercare",
    "ricercheremo": "ricercare",
    "ricerchereste": "ricercare",
    "ricercheresti": "ricercare",
    "ricercherete": "ricercare",
    "ricercherà": "ricercare",
    "ricercherò": "ricercare",
    "ricerchi": "ricercare",
    "ricerchiamo": "ricercare",
    "ricerchiate": "ricercare",
    "ricerchin": "ricercare",
    "ricerchino": "ricercare",
    "ricerco": "ricercare",
    "ricercò": "ricercare",
    "ricetrasmittenti": "ricetrasmittente",
    "ricetta": "ricettare",
    "ricettacoli": "ricettacolo",
    "ricettai": "ricettare",
    "ricettammo": "ricettare",
    "ricettan": "ricettare",
    "ricettando": "ricettare",
    "ricettano": "ricettare",
    "ricettante": "ricettare",
    "ricettanti": "ricettare",
    "ricettar": "ricettare",
    "ricettari": "ricettario",
    "ricettaron": "ricettare",
    "ricettarono": "ricettare",
    "ricettasse": "ricettare",
    "ricettasser": "ricettare",
    "ricettassero": "ricettare",
    "ricettassi": "ricettare",
    "ricettassimo": "ricettare",
    "ricettaste": "ricettare",
    "ricettasti": "ricettare",
    "ricettata": "ricettare",
    "ricettate": "ricettare",
    "ricettati": "ricettare",
    "ricettato": "ricettare",
    "ricettatori": "ricettatore",
    "ricettava": "ricettare",
    "ricettavamo": "ricettare",
    "ricettavan": "ricettare",
    "ricettavano": "ricettare",
    "ricettavate": "ricettare",
    "ricettavi": "ricettare",
    "ricettavo": "ricettare",
    "ricettazioni": "ricettazione",
    "ricette": "ricetta",
    "ricetterai": "ricettare",
    "ricetteran": "ricettare",
    "ricetteranno": "ricettare",
    "ricetterebbe": "ricettare",
    "ricetterebber": "ricettare",
    "ricetterebbero": "ricettare",
    "ricetterei": "ricettare",
    "ricetteremmo": "ricettare",
    "ricetteremo": "ricettare",
    "ricettereste": "ricettare",
    "ricetteresti": "ricettare",
    "ricetterete": "ricettare",
    "ricetterà": "ricettare",
    "ricetterò": "ricettare",
    "ricetti": "ricettare",
    "ricettiamo": "ricettare",
    "ricettiate": "ricettare",
    "ricettin": "ricettare",
    "ricettino": "ricettare",
    "ricettiva": "ricettivo",
    "ricettive": "ricettivo",
    "ricettivi": "ricettivo",
    "ricetto": "ricettare",
    "ricettori": "ricettore",
    "ricettò": "ricettare",
    "riceva": "ricevere",
    "ricevan": "ricevere",
    "ricevano": "ricevere",
    "riceve": "ricevere",
    "ricevei": "ricevere",
    "ricevemmo": "ricevere",
    "ricevendo": "ricevere",
    "ricevente": "ricevere",
    "riceventi": "ricevere",
    "ricever": "ricevere",
    "riceverai": "ricevere",
    "riceveran": "ricevere",
    "riceveranno": "ricevere",
    "riceverebbe": "ricevere",
    "riceverebber": "ricevere",
    "riceverebbero": "ricevere",
    "riceverei": "ricevere",
    "riceveremmo": "ricevere",
    "riceveremo": "ricevere",
    "ricevereste": "ricevere",
    "riceveresti": "ricevere",
    "riceverete": "ricevere",
    "riceveron": "ricevere",
    "riceverono": "ricevere",
    "riceverà": "ricevere",
    "riceverò": "ricevere",
    "ricevesse": "ricevere",
    "ricevesser": "ricevere",
    "ricevessero": "ricevere",
    "ricevessi": "ricevere",
    "ricevessimo": "ricevere",
    "riceveste": "ricevere",
    "ricevesti": "ricevere",
    "ricevete": "ricevere",
    "riceveva": "ricevere",
    "ricevevamo": "ricevere",
    "ricevevan": "ricevere",
    "ricevevano": "ricevere",
    "ricevevate": "ricevere",
    "ricevevi": "ricevere",
    "ricevevo": "ricevere",
    "ricevi": "ricevere",
    "riceviamo": "ricevere",
    "riceviate": "ricevere",
    "ricevimenti": "ricevimento",
    "ricevitori": "ricevitore",
    "ricevitorie": "ricevitoria",
    "ricevitrice": "ricevitore",
    "ricevitrici": "ricevitore",
    "ricevo": "ricevere",
    "ricevon": "ricevere",
    "ricevono": "ricevere",
    "ricevuta": "ricevere",
    "ricevute": "ricevuta",
    "ricevuti": "ricevere",
    "ricevuto": "ricevere",
    "ricevè": "ricevere",
    "ricezioni": "ricezione",
    "richeste": "richesta",
    "richiama": "richiamare",
    "richiamai": "richiamare",
    "richiamammo": "richiamare",
    "richiaman": "richiamare",
    "richiamando": "richiamare",
    "richiamano": "richiamare",
    "richiamante": "richiamare",
    "richiamanti": "richiamare",
    "richiamar": "richiamare",
    "richiamaron": "richiamare",
    "richiamarono": "richiamare",
    "richiamasse": "richiamare",
    "richiamasser": "richiamare",
    "richiamassero": "richiamare",
    "richiamassi": "richiamare",
    "richiamassimo": "richiamare",
    "richiamaste": "richiamare",
    "richiamasti": "richiamare",
    "richiamata": "richiamato",
    "richiamate": "richiamato",
    "richiamati": "richiamato",
    "richiamato": "richiamare",
    "richiamava": "richiamare",
    "richiamavamo": "richiamare",
    "richiamavan": "richiamare",
    "richiamavano": "richiamare",
    "richiamavate": "richiamare",
    "richiamavi": "richiamare",
    "richiamavo": "richiamare",
    "richiamerai": "richiamare",
    "richiameran": "richiamare",
    "richiameranno": "richiamare",
    "richiamerebbe": "richiamare",
    "richiamerebber": "richiamare",
    "richiamerebbero": "richiamare",
    "richiamerei": "richiamare",
    "richiameremmo": "richiamare",
    "richiameremo": "richiamare",
    "richiamereste": "richiamare",
    "richiameresti": "richiamare",
    "richiamerete": "richiamare",
    "richiamerà": "richiamare",
    "richiamerò": "richiamare",
    "richiami": "richiamo",
    "richiamiamo": "richiamare",
    "richiamiate": "richiamare",
    "richiamin": "richiamare",
    "richiamino": "richiamare",
    "richiamo": "richiamare",
    "richiamò": "richiamare",
    "richieda": "richiedere",
    "richiedan": "richiedere",
    "richiedano": "richiedere",
    "richiede": "richiedere",
    "richiedemmo": "richiedere",
    "richiedendo": "richiedere",
    "richiedente": "richiedere",
    "richiedenti": "richiedere",
    "richieder": "richiedere",
    "richiederai": "richiedere",
    "richiederan": "richiedere",
    "richiederanno": "richiedere",
    "richiederebbe": "richiedere",
    "richiederebber": "richiedere",
    "richiederebbero": "richiedere",
    "richiederei": "richiedere",
    "richiederemmo": "richiedere",
    "richiederemo": "richiedere",
    "richiedereste": "richiedere",
    "richiederesti": "richiedere",
    "richiederete": "richiedere",
    "richiederà": "richiedere",
    "richiederò": "richiedere",
    "richiedesse": "richiedere",
    "richiedesser": "richiedere",
    "richiedessero": "richiedere",
    "richiedessi": "richiedere",
    "richiedessimo": "richiedere",
    "richiedeste": "richiedere",
    "richiedesti": "richiedere",
    "richiedete": "richiedere",
    "richiedeva": "richiedere",
    "richiedevamo": "richiedere",
    "richiedevan": "richiedere",
    "richiedevano": "richiedere",
    "richiedevate": "richiedere",
    "richiedevi": "richiedere",
    "richiedevo": "richiedere",
    "richiedi": "richiedere",
    "richiediamo": "richiedere",
    "richiediate": "richiedere",
    "richiedo": "richiedere",
    "richiedon": "richiedere",
    "richiedono": "richiedere",
    "richiese": "richiedere",
    "richieser": "richiedere",
    "richiesero": "richiedere",
    "richiesi": "richiedere",
    "richiesta": "richiedere",
    "richieste": "richiesta",
    "richiesti": "richiedere",
    "richiesto": "richiedere",
    "richiuda": "richiudere",
    "richiudan": "richiudere",
    "richiudano": "richiudere",
    "richiude": "richiudere",
    "richiudemmo": "richiudere",
    "richiudendo": "richiudere",
    "richiudente": "richiudere",
    "richiudenti": "richiudere",
    "richiuder": "richiudere",
    "richiuderai": "richiudere",
    "richiuderan": "richiudere",
    "richiuderanno": "richiudere",
    "richiuderebbe": "richiudere",
    "richiuderebber": "richiudere",
    "richiuderebbero": "richiudere",
    "richiuderei": "richiudere",
    "richiuderemmo": "richiudere",
    "richiuderemo": "richiudere",
    "richiudereste": "richiudere",
    "richiuderesti": "richiudere",
    "richiuderete": "richiudere",
    "richiuderà": "richiudere",
    "richiuderò": "richiudere",
    "richiudesse": "richiudere",
    "richiudesser": "richiudere",
    "richiudessero": "richiudere",
    "richiudessi": "richiudere",
    "richiudessimo": "richiudere",
    "richiudeste": "richiudere",
    "richiudesti": "richiudere",
    "richiudete": "richiudere",
    "richiudeva": "richiudere",
    "richiudevamo": "richiudere",
    "richiudevan": "richiudere",
    "richiudevano": "richiudere",
    "richiudevate": "richiudere",
    "richiudevi": "richiudere",
    "richiudevo": "richiudere",
    "richiudi": "richiudere",
    "richiudiamo": "richiudere",
    "richiudiate": "richiudere",
    "richiudo": "richiudere",
    "richiudon": "richiudere",
    "richiudono": "richiudere",
    "richiusa": "richiudere",
    "richiuse": "richiudere",
    "richiuser": "richiudere",
    "richiusero": "richiudere",
    "richiusi": "richiudere",
    "richiuso": "richiudere",
    "ricicla": "riciclare",
    "riciclaggi": "riciclaggio",
    "riciclai": "riciclare",
    "riciclammo": "riciclare",
    "riciclan": "riciclare",
    "riciclando": "riciclare",
    "riciclano": "riciclare",
    "riciclante": "riciclare",
    "riciclanti": "riciclare",
    "riciclar": "riciclare",
    "riciclaron": "riciclare",
    "riciclarono": "riciclare",
    "riciclasse": "riciclare",
    "riciclasser": "riciclare",
    "riciclassero": "riciclare",
    "riciclassi": "riciclare",
    "riciclassimo": "riciclare",
    "riciclaste": "riciclare",
    "riciclasti": "riciclare",
    "riciclata": "riciclare",
    "riciclate": "riciclare",
    "riciclati": "riciclato",
    "riciclato": "riciclare",
    "riciclatori": "riciclatore",
    "riciclava": "riciclare",
    "riciclavamo": "riciclare",
    "riciclavan": "riciclare",
    "riciclavano": "riciclare",
    "riciclavate": "riciclare",
    "riciclavi": "riciclare",
    "riciclavo": "riciclare",
    "riciclerai": "riciclare",
    "ricicleran": "riciclare",
    "ricicleranno": "riciclare",
    "riciclerebbe": "riciclare",
    "riciclerebber": "riciclare",
    "riciclerebbero": "riciclare",
    "riciclerei": "riciclare",
    "ricicleremmo": "riciclare",
    "ricicleremo": "riciclare",
    "riciclereste": "riciclare",
    "ricicleresti": "riciclare",
    "riciclerete": "riciclare",
    "riciclerà": "riciclare",
    "riciclerò": "riciclare",
    "ricicli": "riciclare",
    "ricicliamo": "riciclare",
    "ricicliate": "riciclare",
    "riciclin": "riciclare",
    "riciclino": "riciclare",
    "riciclo": "riciclare",
    "riciclò": "riciclare",
    "riclassifica": "riclassificare",
    "riclassificai": "riclassificare",
    "riclassificammo": "riclassificare",
    "riclassifican": "riclassificare",
    "riclassificando": "riclassificare",
    "riclassificano": "riclassificare",
    "riclassificante": "riclassificare",
    "riclassificanti": "riclassificare",
    "riclassificar": "riclassificare",
    "riclassificaron": "riclassificare",
    "riclassificarono": "riclassificare",
    "riclassificasse": "riclassificare",
    "riclassificasser": "riclassificare",
    "riclassificassero": "riclassificare",
    "riclassificassi": "riclassificare",
    "riclassificassimo": "riclassificare",
    "riclassificaste": "riclassificare",
    "riclassificasti": "riclassificare",
    "riclassificata": "riclassificare",
    "riclassificate": "riclassificare",
    "riclassificati": "riclassificare",
    "riclassificato": "riclassificare",
    "riclassificava": "riclassificare",
    "riclassificavamo": "riclassificare",
    "riclassificavan": "riclassificare",
    "riclassificavano": "riclassificare",
    "riclassificavate": "riclassificare",
    "riclassificavi": "riclassificare",
    "riclassificavo": "riclassificare",
    "riclassificazioni": "riclassificazione",
    "riclassificherai": "riclassificare",
    "riclassificheran": "riclassificare",
    "riclassificheranno": "riclassificare",
    "riclassificherebbe": "riclassificare",
    "riclassificherebber": "riclassificare",
    "riclassificherebbero": "riclassificare",
    "riclassificherei": "riclassificare",
    "riclassificheremmo": "riclassificare",
    "riclassificheremo": "riclassificare",
    "riclassifichereste": "riclassificare",
    "riclassificheresti": "riclassificare",
    "riclassificherete": "riclassificare",
    "riclassificherà": "riclassificare",
    "riclassificherò": "riclassificare",
    "riclassifichi": "riclassificare",
    "riclassifichiamo": "riclassificare",
    "riclassifichiate": "riclassificare",
    "riclassifichin": "riclassificare",
    "riclassifichino": "riclassificare",
    "riclassifico": "riclassificare",
    "riclassificò": "riclassificare",
    "ricocemmo": "ricuocere",
    "ricocendo": "ricuocere",
    "ricocente": "ricuocere",
    "ricocenti": "ricuocere",
    "ricocerai": "ricuocere",
    "ricoceran": "ricuocere",
    "ricoceranno": "ricuocere",
    "ricocerebbe": "ricuocere",
    "ricocerebber": "ricuocere",
    "ricocerebbero": "ricuocere",
    "ricocerei": "ricuocere",
    "ricoceremmo": "ricuocere",
    "ricoceremo": "ricuocere",
    "ricocereste": "ricuocere",
    "ricoceresti": "ricuocere",
    "ricocerete": "ricuocere",
    "ricocerà": "ricuocere",
    "ricocerò": "ricuocere",
    "ricocesse": "ricuocere",
    "ricocesser": "ricuocere",
    "ricocessero": "ricuocere",
    "ricocessi": "ricuocere",
    "ricocessimo": "ricuocere",
    "ricoceste": "ricuocere",
    "ricocesti": "ricuocere",
    "ricocete": "ricuocere",
    "ricoceva": "ricuocere",
    "ricocevamo": "ricuocere",
    "ricocevan": "ricuocere",
    "ricocevano": "ricuocere",
    "ricocevate": "ricuocere",
    "ricocevi": "ricuocere",
    "ricocevo": "ricuocere",
    "ricociamo": "ricuocere",
    "ricociate": "ricuocere",
    "ricogli": "ricogliere",
    "ricogliamo": "ricogliere",
    "ricogliate": "ricogliere",
    "ricoglie": "ricogliere",
    "ricogliemmo": "ricogliere",
    "ricogliendo": "ricogliere",
    "ricogliente": "ricogliere",
    "ricoglienti": "ricogliere",
    "ricoglier": "ricogliere",
    "ricoglierai": "ricogliere",
    "ricoglieran": "ricogliere",
    "ricoglieranno": "ricogliere",
    "ricoglierebbe": "ricogliere",
    "ricoglierebber": "ricogliere",
    "ricoglierebbero": "ricogliere",
    "ricoglierei": "ricogliere",
    "ricoglieremmo": "ricogliere",
    "ricoglieremo": "ricogliere",
    "ricogliereste": "ricogliere",
    "ricoglieresti": "ricogliere",
    "ricoglierete": "ricogliere",
    "ricoglierà": "ricogliere",
    "ricoglierò": "ricogliere",
    "ricogliesse": "ricogliere",
    "ricogliesser": "ricogliere",
    "ricogliessero": "ricogliere",
    "ricogliessi": "ricogliere",
    "ricogliessimo": "ricogliere",
    "ricoglieste": "ricogliere",
    "ricogliesti": "ricogliere",
    "ricogliete": "ricogliere",
    "ricoglieva": "ricogliere",
    "ricoglievamo": "ricogliere",
    "ricoglievan": "ricogliere",
    "ricoglievano": "ricogliere",
    "ricoglievate": "ricogliere",
    "ricoglievi": "ricogliere",
    "ricoglievo": "ricogliere",
    "ricognitori": "ricognitore",
    "ricognizioni": "ricognizione",
    "ricolga": "ricogliere",
    "ricolgan": "ricogliere",
    "ricolgano": "ricogliere",
    "ricolgo": "ricogliere",
    "ricolgon": "ricogliere",
    "ricolgono": "ricogliere",
    "ricollega": "ricollegare",
    "ricollegai": "ricollegare",
    "ricollegammo": "ricollegare",
    "ricollegan": "ricollegare",
    "ricollegando": "ricollegare",
    "ricollegano": "ricollegare",
    "ricollegante": "ricollegare",
    "ricolleganti": "ricollegare",
    "ricollegar": "ricollegare",
    "ricollegaron": "ricollegare",
    "ricollegarono": "ricollegare",
    "ricollegasse": "ricollegare",
    "ricollegasser": "ricollegare",
    "ricollegassero": "ricollegare",
    "ricollegassi": "ricollegare",
    "ricollegassimo": "ricollegare",
    "ricollegaste": "ricollegare",
    "ricollegasti": "ricollegare",
    "ricollegata": "ricollegare",
    "ricollegate": "ricollegare",
    "ricollegati": "ricollegare",
    "ricollegato": "ricollegare",
    "ricollegava": "ricollegare",
    "ricollegavamo": "ricollegare",
    "ricollegavan": "ricollegare",
    "ricollegavano": "ricollegare",
    "ricollegavate": "ricollegare",
    "ricollegavi": "ricollegare",
    "ricollegavo": "ricollegare",
    "ricollegherai": "ricollegare",
    "ricollegheran": "ricollegare",
    "ricollegheranno": "ricollegare",
    "ricollegherebbe": "ricollegare",
    "ricollegherebber": "ricollegare",
    "ricollegherebbero": "ricollegare",
    "ricollegherei": "ricollegare",
    "ricollegheremmo": "ricollegare",
    "ricollegheremo": "ricollegare",
    "ricolleghereste": "ricollegare",
    "ricollegheresti": "ricollegare",
    "ricollegherete": "ricollegare",
    "ricollegherà": "ricollegare",
    "ricollegherò": "ricollegare",
    "ricolleghi": "ricollegare",
    "ricolleghiamo": "ricollegare",
    "ricolleghiate": "ricollegare",
    "ricolleghin": "ricollegare",
    "ricolleghino": "ricollegare",
    "ricollego": "ricollegare",
    "ricollegò": "ricollegare",
    "ricolloca": "ricollocare",
    "ricollocai": "ricollocare",
    "ricollocamenti": "ricollocamento",
    "ricollocammo": "ricollocare",
    "ricollocan": "ricollocare",
    "ricollocando": "ricollocare",
    "ricollocano": "ricollocare",
    "ricollocante": "ricollocare",
    "ricollocanti": "ricollocare",
    "ricollocar": "ricollocare",
    "ricollocaron": "ricollocare",
    "ricollocarono": "ricollocare",
    "ricollocasse": "ricollocare",
    "ricollocasser": "ricollocare",
    "ricollocassero": "ricollocare",
    "ricollocassi": "ricollocare",
    "ricollocassimo": "ricollocare",
    "ricollocaste": "ricollocare",
    "ricollocasti": "ricollocare",
    "ricollocata": "ricollocare",
    "ricollocate": "ricollocare",
    "ricollocati": "ricollocare",
    "ricollocato": "ricollocare",
    "ricollocava": "ricollocare",
    "ricollocavamo": "ricollocare",
    "ricollocavan": "ricollocare",
    "ricollocavano": "ricollocare",
    "ricollocavate": "ricollocare",
    "ricollocavi": "ricollocare",
    "ricollocavo": "ricollocare",
    "ricollocazioni": "ricollocazione",
    "ricollocherai": "ricollocare",
    "ricollocheran": "ricollocare",
    "ricollocheranno": "ricollocare",
    "ricollocherebbe": "ricollocare",
    "ricollocherebber": "ricollocare",
    "ricollocherebbero": "ricollocare",
    "ricollocherei": "ricollocare",
    "ricollocheremmo": "ricollocare",
    "ricollocheremo": "ricollocare",
    "ricollochereste": "ricollocare",
    "ricollocheresti": "ricollocare",
    "ricollocherete": "ricollocare",
    "ricollocherà": "ricollocare",
    "ricollocherò": "ricollocare",
    "ricollochi": "ricollocare",
    "ricollochiamo": "ricollocare",
    "ricollochiate": "ricollocare",
    "ricollochin": "ricollocare",
    "ricollochino": "ricollocare",
    "ricolloco": "ricollocare",
    "ricollocò": "ricollocare",
    "ricolma": "ricolmo",
    "ricolmai": "ricolmare",
    "ricolmammo": "ricolmare",
    "ricolman": "ricolmare",
    "ricolmando": "ricolmare",
    "ricolmano": "ricolmare",
    "ricolmante": "ricolmare",
    "ricolmanti": "ricolmare",
    "ricolmar": "ricolmare",
    "ricolmaron": "ricolmare",
    "ricolmarono": "ricolmare",
    "ricolmasse": "ricolmare",
    "ricolmasser": "ricolmare",
    "ricolmassero": "ricolmare",
    "ricolmassi": "ricolmare",
    "ricolmassimo": "ricolmare",
    "ricolmaste": "ricolmare",
    "ricolmasti": "ricolmare",
    "ricolmata": "ricolmare",
    "ricolmate": "ricolmare",
    "ricolmati": "ricolmare",
    "ricolmato": "ricolmare",
    "ricolmava": "ricolmare",
    "ricolmavamo": "ricolmare",
    "ricolmavan": "ricolmare",
    "ricolmavano": "ricolmare",
    "ricolmavate": "ricolmare",
    "ricolmavi": "ricolmare",
    "ricolmavo": "ricolmare",
    "ricolme": "ricolmo",
    "ricolmerai": "ricolmare",
    "ricolmeran": "ricolmare",
    "ricolmeranno": "ricolmare",
    "ricolmerebbe": "ricolmare",
    "ricolmerebber": "ricolmare",
    "ricolmerebbero": "ricolmare",
    "ricolmerei": "ricolmare",
    "ricolmeremmo": "ricolmare",
    "ricolmeremo": "ricolmare",
    "ricolmereste": "ricolmare",
    "ricolmeresti": "ricolmare",
    "ricolmerete": "ricolmare",
    "ricolmerà": "ricolmare",
    "ricolmerò": "ricolmare",
    "ricolmi": "ricolmo",
    "ricolmiamo": "ricolmare",
    "ricolmiate": "ricolmare",
    "ricolmin": "ricolmare",
    "ricolmino": "ricolmare",
    "ricolmo": "ricolmare",
    "ricolmò": "ricolmare",
    "ricolora": "ricolorare",
    "ricolorai": "ricolorare",
    "ricolorammo": "ricolorare",
    "ricoloran": "ricolorare",
    "ricolorando": "ricolorare",
    "ricolorano": "ricolorare",
    "ricolorante": "ricolorare",
    "ricoloranti": "ricolorare",
    "ricolorar": "ricolorare",
    "ricoloraron": "ricolorare",
    "ricolorarono": "ricolorare",
    "ricolorasse": "ricolorare",
    "ricolorasser": "ricolorare",
    "ricolorassero": "ricolorare",
    "ricolorassi": "ricolorare",
    "ricolorassimo": "ricolorare",
    "ricoloraste": "ricolorare",
    "ricolorasti": "ricolorare",
    "ricolorata": "ricolorare",
    "ricolorate": "ricolorare",
    "ricolorati": "ricolorare",
    "ricolorato": "ricolorare",
    "ricolorava": "ricolorare",
    "ricoloravamo": "ricolorare",
    "ricoloravan": "ricolorare",
    "ricoloravano": "ricolorare",
    "ricoloravate": "ricolorare",
    "ricoloravi": "ricolorare",
    "ricoloravo": "ricolorare",
    "ricolorerai": "ricolorare",
    "ricoloreran": "ricolorare",
    "ricoloreranno": "ricolorare",
    "ricolorerebbe": "ricolorare",
    "ricolorerebber": "ricolorare",
    "ricolorerebbero": "ricolorare",
    "ricolorerei": "ricolorare",
    "ricoloreremmo": "ricolorare",
    "ricoloreremo": "ricolorare",
    "ricolorereste": "ricolorare",
    "ricoloreresti": "ricolorare",
    "ricolorerete": "ricolorare",
    "ricolorerà": "ricolorare",
    "ricolorerò": "ricolorare",
    "ricolori": "ricolorare",
    "ricoloriamo": "ricolorare",
    "ricoloriate": "ricolorare",
    "ricolorin": "ricolorare",
    "ricolorino": "ricolorare",
    "ricoloro": "ricolorare",
    "ricolorò": "ricolorare",
    "ricolser": "ricogliere",
    "ricolsero": "ricogliere",
    "ricolsi": "ricogliere",
    "ricolsè": "ricogliere",
    "ricolta": "ricogliere",
    "ricolte": "ricogliere",
    "ricolti": "ricogliere",
    "ricolto": "ricogliere",
    "ricomincerai": "ricominciare",
    "ricominceran": "ricominciare",
    "ricominceranno": "ricominciare",
    "ricomincerebbe": "ricominciare",
    "ricomincerebber": "ricominciare",
    "ricomincerebbero": "ricominciare",
    "ricomincerei": "ricominciare",
    "ricominceremmo": "ricominciare",
    "ricominceremo": "ricominciare",
    "ricomincereste": "ricominciare",
    "ricominceresti": "ricominciare",
    "ricomincerete": "ricominciare",
    "ricomincerà": "ricominciare",
    "ricomincerò": "ricominciare",
    "ricominci": "ricominciare",
    "ricomincia": "ricominciare",
    "ricominciai": "ricominciare",
    "ricominciammo": "ricominciare",
    "ricominciamo": "ricominciare",
    "ricomincian": "ricominciare",
    "ricominciando": "ricominciare",
    "ricominciano": "ricominciare",
    "ricominciante": "ricominciare",
    "ricomincianti": "ricominciare",
    "ricominciar": "ricominciare",
    "ricominciaron": "ricominciare",
    "ricominciarono": "ricominciare",
    "ricominciasse": "ricominciare",
    "ricominciasser": "ricominciare",
    "ricominciassero": "ricominciare",
    "ricominciassi": "ricominciare",
    "ricominciassimo": "ricominciare",
    "ricominciaste": "ricominciare",
    "ricominciasti": "ricominciare",
    "ricominciata": "ricominciare",
    "ricominciate": "ricominciare",
    "ricominciati": "ricominciare",
    "ricominciato": "ricominciare",
    "ricominciava": "ricominciare",
    "ricominciavamo": "ricominciare",
    "ricominciavan": "ricominciare",
    "ricominciavano": "ricominciare",
    "ricominciavate": "ricominciare",
    "ricominciavi": "ricominciare",
    "ricominciavo": "ricominciare",
    "ricomincin": "ricominciare",
    "ricomincino": "ricominciare",
    "ricomincio": "ricominciare",
    "ricominciò": "ricominciare",
    "ricompaia": "ricomparire",
    "ricompaian": "ricomparire",
    "ricompaiano": "ricomparire",
    "ricompaio": "ricomparire",
    "ricompaion": "ricomparire",
    "ricompaiono": "ricomparire",
    "ricompare": "ricomparire",
    "ricomparendo": "ricomparire",
    "ricomparente": "ricomparire",
    "ricomparenti": "ricomparire",
    "ricompari": "ricomparire",
    "ricompariamo": "ricomparire",
    "ricompariate": "ricomparire",
    "ricomparimmo": "ricomparire",
    "ricomparir": "ricomparire",
    "ricomparirai": "ricomparire",
    "ricompariran": "ricomparire",
    "ricompariranno": "ricomparire",
    "ricomparirebbe": "ricomparire",
    "ricomparirebber": "ricomparire",
    "ricomparirebbero": "ricomparire",
    "ricomparirei": "ricomparire",
    "ricompariremmo": "ricomparire",
    "ricompariremo": "ricomparire",
    "ricomparireste": "ricomparire",
    "ricompariresti": "ricomparire",
    "ricomparirete": "ricomparire",
    "ricomparirà": "ricomparire",
    "ricomparirò": "ricomparire",
    "ricomparisse": "ricomparire",
    "ricomparisser": "ricomparire",
    "ricomparissero": "ricomparire",
    "ricomparissi": "ricomparire",
    "ricomparissimo": "ricomparire",
    "ricompariste": "ricomparire",
    "ricomparisti": "ricomparire",
    "ricomparite": "ricomparire",
    "ricompariva": "ricomparire",
    "ricomparivamo": "ricomparire",
    "ricomparivan": "ricomparire",
    "ricomparivano": "ricomparire",
    "ricomparivate": "ricomparire",
    "ricomparivi": "ricomparire",
    "ricomparivo": "ricomparire",
    "ricomparsa": "ricomparire",
    "ricomparse": "ricomparsa",
    "ricomparsi": "ricomparire",
    "ricomparso": "ricomparire",
    "ricomparve": "ricomparire",
    "ricomparver": "ricomparire",
    "ricomparvero": "ricomparire",
    "ricomparvi": "ricomparire",
    "ricompatta": "ricompattare",
    "ricompattai": "ricompattare",
    "ricompattamenti": "ricompattamento",
    "ricompattammo": "ricompattare",
    "ricompattan": "ricompattare",
    "ricompattando": "ricompattare",
    "ricompattano": "ricompattare",
    "ricompattante": "ricompattare",
    "ricompattanti": "ricompattare",
    "ricompattar": "ricompattare",
    "ricompattaron": "ricompattare",
    "ricompattarono": "ricompattare",
    "ricompattasse": "ricompattare",
    "ricompattasser": "ricompattare",
    "ricompattassero": "ricompattare",
    "ricompattassi": "ricompattare",
    "ricompattassimo": "ricompattare",
    "ricompattaste": "ricompattare",
    "ricompattasti": "ricompattare",
    "ricompattata": "ricompattare",
    "ricompattate": "ricompattare",
    "ricompattati": "ricompattare",
    "ricompattato": "ricompattare",
    "ricompattava": "ricompattare",
    "ricompattavamo": "ricompattare",
    "ricompattavan": "ricompattare",
    "ricompattavano": "ricompattare",
    "ricompattavate": "ricompattare",
    "ricompattavi": "ricompattare",
    "ricompattavo": "ricompattare",
    "ricompatterai": "ricompattare",
    "ricompatteran": "ricompattare",
    "ricompatteranno": "ricompattare",
    "ricompatterebbe": "ricompattare",
    "ricompatterebber": "ricompattare",
    "ricompatterebbero": "ricompattare",
    "ricompatterei": "ricompattare",
    "ricompatteremmo": "ricompattare",
    "ricompatteremo": "ricompattare",
    "ricompattereste": "ricompattare",
    "ricompatteresti": "ricompattare",
    "ricompatterete": "ricompattare",
    "ricompatterà": "ricompattare",
    "ricompatterò": "ricompattare",
    "ricompatti": "ricompattare",
    "ricompattiamo": "ricompattare",
    "ricompattiate": "ricompattare",
    "ricompattin": "ricompattare",
    "ricompattino": "ricompattare",
    "ricompatto": "ricompattare",
    "ricompattò": "ricompattare",
    "ricompensa": "ricompensare",
    "ricompensai": "ricompensare",
    "ricompensammo": "ricompensare",
    "ricompensan": "ricompensare",
    "ricompensando": "ricompensare",
    "ricompensano": "ricompensare",
    "ricompensante": "ricompensare",
    "ricompensanti": "ricompensare",
    "ricompensar": "ricompensare",
    "ricompensaron": "ricompensare",
    "ricompensarono": "ricompensare",
    "ricompensasse": "ricompensare",
    "ricompensasser": "ricompensare",
    "ricompensassero": "ricompensare",
    "ricompensassi": "ricompensare",
    "ricompensassimo": "ricompensare",
    "ricompensaste": "ricompensare",
    "ricompensasti": "ricompensare",
    "ricompensata": "ricompensare",
    "ricompensate": "ricompensare",
    "ricompensati": "ricompensare",
    "ricompensato": "ricompensare",
    "ricompensava": "ricompensare",
    "ricompensavamo": "ricompensare",
    "ricompensavan": "ricompensare",
    "ricompensavano": "ricompensare",
    "ricompensavate": "ricompensare",
    "ricompensavi": "ricompensare",
    "ricompensavo": "ricompensare",
    "ricompense": "ricompensa",
    "ricompenserai": "ricompensare",
    "ricompenseran": "ricompensare",
    "ricompenseranno": "ricompensare",
    "ricompenserebbe": "ricompensare",
    "ricompenserebber": "ricompensare",
    "ricompenserebbero": "ricompensare",
    "ricompenserei": "ricompensare",
    "ricompenseremmo": "ricompensare",
    "ricompenseremo": "ricompensare",
    "ricompensereste": "ricompensare",
    "ricompenseresti": "ricompensare",
    "ricompenserete": "ricompensare",
    "ricompenserà": "ricompensare",
    "ricompenserò": "ricompensare",
    "ricompensi": "ricompensare",
    "ricompensiamo": "ricompensare",
    "ricompensiate": "ricompensare",
    "ricompensin": "ricompensare",
    "ricompensino": "ricompensare",
    "ricompenso": "ricompensare",
    "ricompensò": "ricompensare",
    "ricompera": "ricomperare",
    "ricomperai": "ricomperare",
    "ricomperammo": "ricomperare",
    "ricomperan": "ricomperare",
    "ricomperando": "ricomperare",
    "ricomperano": "ricomperare",
    "ricomperante": "ricomperare",
    "ricomperanti": "ricomperare",
    "ricomperar": "ricomperare",
    "ricomperaron": "ricomperare",
    "ricomperarono": "ricomperare",
    "ricomperasse": "ricomperare",
    "ricomperasser": "ricomperare",
    "ricomperassero": "ricomperare",
    "ricomperassi": "ricomperare",
    "ricomperassimo": "ricomperare",
    "ricomperaste": "ricomperare",
    "ricomperasti": "ricomperare",
    "ricomperata": "ricomperare",
    "ricomperate": "ricomperare",
    "ricomperati": "ricomperare",
    "ricomperato": "ricomperare",
    "ricomperava": "ricomperare",
    "ricomperavamo": "ricomperare",
    "ricomperavan": "ricomperare",
    "ricomperavano": "ricomperare",
    "ricomperavate": "ricomperare",
    "ricomperavi": "ricomperare",
    "ricomperavo": "ricomperare",
    "ricompererai": "ricomperare",
    "ricompereran": "ricomperare",
    "ricompereranno": "ricomperare",
    "ricompererebbe": "ricomperare",
    "ricompererebber": "ricomperare",
    "ricompererebbero": "ricomperare",
    "ricompererei": "ricomperare",
    "ricompereremmo": "ricomperare",
    "ricompereremo": "ricomperare",
    "ricomperereste": "ricomperare",
    "ricompereresti": "ricomperare",
    "ricompererete": "ricomperare",
    "ricompererà": "ricomperare",
    "ricompererò": "ricomperare",
    "ricomperi": "ricomperare",
    "ricomperiamo": "ricomperare",
    "ricomperiate": "ricomperare",
    "ricomperin": "ricomperare",
    "ricomperino": "ricomperare",
    "ricompero": "ricomperare",
    "ricomperò": "ricomperare",
    "ricompone": "ricomporre",
    "ricomponemmo": "ricomporre",
    "ricomponendo": "ricomporre",
    "ricomponente": "ricomporre",
    "ricomponenti": "ricomporre",
    "ricomponesse": "ricomporre",
    "ricomponesser": "ricomporre",
    "ricomponessero": "ricomporre",
    "ricomponessi": "ricomporre",
    "ricomponessimo": "ricomporre",
    "ricomponeste": "ricomporre",
    "ricomponesti": "ricomporre",
    "ricomponete": "ricomporre",
    "ricomponeva": "ricomporre",
    "ricomponevamo": "ricomporre",
    "ricomponevan": "ricomporre",
    "ricomponevano": "ricomporre",
    "ricomponevate": "ricomporre",
    "ricomponevi": "ricomporre",
    "ricomponevo": "ricomporre",
    "ricomponga": "ricomporre",
    "ricompongan": "ricomporre",
    "ricompongano": "ricomporre",
    "ricompongo": "ricomporre",
    "ricompongon": "ricomporre",
    "ricompongono": "ricomporre",
    "ricomponi": "ricomporre",
    "ricomponiamo": "ricomporre",
    "ricomponiate": "ricomporre",
    "ricomporr": "ricomporre",
    "ricomporrai": "ricomporre",
    "ricomporran": "ricomporre",
    "ricomporranno": "ricomporre",
    "ricomporrebbe": "ricomporre",
    "ricomporrebber": "ricomporre",
    "ricomporrebbero": "ricomporre",
    "ricomporrei": "ricomporre",
    "ricomporremmo": "ricomporre",
    "ricomporremo": "ricomporre",
    "ricomporreste": "ricomporre",
    "ricomporresti": "ricomporre",
    "ricomporrete": "ricomporre",
    "ricomporrà": "ricomporre",
    "ricomporrò": "ricomporre",
    "ricompose": "ricomporre",
    "ricomposer": "ricomporre",
    "ricomposero": "ricomporre",
    "ricomposi": "ricomporre",
    "ricomposizioni": "ricomposizione",
    "ricomposta": "ricomporre",
    "ricomposte": "ricomporre",
    "ricomposti": "ricomporre",
    "ricomposto": "ricomporre",
    "ricompra": "ricomprare",
    "ricomprai": "ricomprare",
    "ricomprammo": "ricomprare",
    "ricompran": "ricomprare",
    "ricomprando": "ricomprare",
    "ricomprano": "ricomprare",
    "ricomprante": "ricomprare",
    "ricompranti": "ricomprare",
    "ricomprar": "ricomprare",
    "ricompraron": "ricomprare",
    "ricomprarono": "ricomprare",
    "ricomprasse": "ricomprare",
    "ricomprasser": "ricomprare",
    "ricomprassero": "ricomprare",
    "ricomprassi": "ricomprare",
    "ricomprassimo": "ricomprare",
    "ricompraste": "ricomprare",
    "ricomprasti": "ricomprare",
    "ricomprata": "ricomprare",
    "ricomprate": "ricomprare",
    "ricomprati": "ricomprare",
    "ricomprato": "ricomprare",
    "ricomprava": "ricomprare",
    "ricompravamo": "ricomprare",
    "ricompravan": "ricomprare",
    "ricompravano": "ricomprare",
    "ricompravate": "ricomprare",
    "ricompravi": "ricomprare",
    "ricompravo": "ricomprare",
    "ricomprenda": "ricomprendere",
    "ricomprendan": "ricomprendere",
    "ricomprendano": "ricomprendere",
    "ricomprende": "ricomprendere",
    "ricomprendemmo": "ricomprendere",
    "ricomprendendo": "ricomprendere",
    "ricomprendente": "ricomprendere",
    "ricomprendenti": "ricomprendere",
    "ricomprender": "ricomprendere",
    "ricomprenderai": "ricomprendere",
    "ricomprenderan": "ricomprendere",
    "ricomprenderanno": "ricomprendere",
    "ricomprenderebbe": "ricomprendere",
    "ricomprenderebber": "ricomprendere",
    "ricomprenderebbero": "ricomprendere",
    "ricomprenderei": "ricomprendere",
    "ricomprenderemmo": "ricomprendere",
    "ricomprenderemo": "ricomprendere",
    "ricomprendereste": "ricomprendere",
    "ricomprenderesti": "ricomprendere",
    "ricomprenderete": "ricomprendere",
    "ricomprenderà": "ricomprendere",
    "ricomprenderò": "ricomprendere",
    "ricomprendesse": "ricomprendere",
    "ricomprendesser": "ricomprendere",
    "ricomprendessero": "ricomprendere",
    "ricomprendessi": "ricomprendere",
    "ricomprendessimo": "ricomprendere",
    "ricomprendeste": "ricomprendere",
    "ricomprendesti": "ricomprendere",
    "ricomprendete": "ricomprendere",
    "ricomprendeva": "ricomprendere",
    "ricomprendevamo": "ricomprendere",
    "ricomprendevan": "ricomprendere",
    "ricomprendevano": "ricomprendere",
    "ricomprendevate": "ricomprendere",
    "ricomprendevi": "ricomprendere",
    "ricomprendevo": "ricomprendere",
    "ricomprendi": "ricomprendere",
    "ricomprendiamo": "ricomprendere",
    "ricomprendiate": "ricomprendere",
    "ricomprendo": "ricomprendere",
    "ricomprendon": "ricomprendere",
    "ricomprendono": "ricomprendere",
    "ricomprerai": "ricomprare",
    "ricompreran": "ricomprare",
    "ricompreranno": "ricomprare",
    "ricomprerebbe": "ricomprare",
    "ricomprerebber": "ricomprare",
    "ricomprerebbero": "ricomprare",
    "ricomprerei": "ricomprare",
    "ricompreremmo": "ricomprare",
    "ricompreremo": "ricomprare",
    "ricomprereste": "ricomprare",
    "ricompreresti": "ricomprare",
    "ricomprerete": "ricomprare",
    "ricomprerà": "ricomprare",
    "ricomprerò": "ricomprare",
    "ricompresa": "ricomprendere",
    "ricomprese": "ricomprendere",
    "ricompreser": "ricomprendere",
    "ricompresero": "ricomprendere",
    "ricompresi": "ricomprendere",
    "ricompreso": "ricomprendere",
    "ricompresè": "ricomprendere",
    "ricompri": "ricomprare",
    "ricompriamo": "ricomprare",
    "ricompriate": "ricomprare",
    "ricomprin": "ricomprare",
    "ricomprino": "ricomprare",
    "ricompro": "ricomprare",
    "ricomprò": "ricomprare",
    "ricomunica": "ricomunicare",
    "ricomunicai": "ricomunicare",
    "ricomunicammo": "ricomunicare",
    "ricomunican": "ricomunicare",
    "ricomunicando": "ricomunicare",
    "ricomunicano": "ricomunicare",
    "ricomunicante": "ricomunicare",
    "ricomunicanti": "ricomunicare",
    "ricomunicar": "ricomunicare",
    "ricomunicaron": "ricomunicare",
    "ricomunicarono": "ricomunicare",
    "ricomunicasse": "ricomunicare",
    "ricomunicasser": "ricomunicare",
    "ricomunicassero": "ricomunicare",
    "ricomunicassi": "ricomunicare",
    "ricomunicassimo": "ricomunicare",
    "ricomunicaste": "ricomunicare",
    "ricomunicasti": "ricomunicare",
    "ricomunicata": "ricomunicare",
    "ricomunicate": "ricomunicare",
    "ricomunicati": "ricomunicare",
    "ricomunicato": "ricomunicare",
    "ricomunicava": "ricomunicare",
    "ricomunicavamo": "ricomunicare",
    "ricomunicavan": "ricomunicare",
    "ricomunicavano": "ricomunicare",
    "ricomunicavate": "ricomunicare",
    "ricomunicavi": "ricomunicare",
    "ricomunicavo": "ricomunicare",
    "ricomunicherai": "ricomunicare",
    "ricomunicheran": "ricomunicare",
    "ricomunicheranno": "ricomunicare",
    "ricomunicherebbe": "ricomunicare",
    "ricomunicherebber": "ricomunicare",
    "ricomunicherebbero": "ricomunicare",
    "ricomunicherei": "ricomunicare",
    "ricomunicheremmo": "ricomunicare",
    "ricomunicheremo": "ricomunicare",
    "ricomunichereste": "ricomunicare",
    "ricomunicheresti": "ricomunicare",
    "ricomunicherete": "ricomunicare",
    "ricomunicherà": "ricomunicare",
    "ricomunicherò": "ricomunicare",
    "ricomunichi": "ricomunicare",
    "ricomunichiamo": "ricomunicare",
    "ricomunichiate": "ricomunicare",
    "ricomunichin": "ricomunicare",
    "ricomunichino": "ricomunicare",
    "ricomunico": "ricomunicare",
    "ricomunicò": "ricomunicare",
    "riconcentra": "riconcentrare",
    "riconcentrai": "riconcentrare",
    "riconcentrammo": "riconcentrare",
    "riconcentran": "riconcentrare",
    "riconcentrando": "riconcentrare",
    "riconcentrano": "riconcentrare",
    "riconcentrante": "riconcentrare",
    "riconcentranti": "riconcentrare",
    "riconcentrar": "riconcentrare",
    "riconcentraron": "riconcentrare",
    "riconcentrarono": "riconcentrare",
    "riconcentrasse": "riconcentrare",
    "riconcentrasser": "riconcentrare",
    "riconcentrassero": "riconcentrare",
    "riconcentrassi": "riconcentrare",
    "riconcentrassimo": "riconcentrare",
    "riconcentraste": "riconcentrare",
    "riconcentrasti": "riconcentrare",
    "riconcentrata": "riconcentrare",
    "riconcentrate": "riconcentrare",
    "riconcentrati": "riconcentrare",
    "riconcentrato": "riconcentrare",
    "riconcentrava": "riconcentrare",
    "riconcentravamo": "riconcentrare",
    "riconcentravan": "riconcentrare",
    "riconcentravano": "riconcentrare",
    "riconcentravate": "riconcentrare",
    "riconcentravi": "riconcentrare",
    "riconcentravo": "riconcentrare",
    "riconcentrerai": "riconcentrare",
    "riconcentreran": "riconcentrare",
    "riconcentreranno": "riconcentrare",
    "riconcentrerebbe": "riconcentrare",
    "riconcentrerebber": "riconcentrare",
    "riconcentrerebbero": "riconcentrare",
    "riconcentrerei": "riconcentrare",
    "riconcentreremmo": "riconcentrare",
    "riconcentreremo": "riconcentrare",
    "riconcentrereste": "riconcentrare",
    "riconcentreresti": "riconcentrare",
    "riconcentrerete": "riconcentrare",
    "riconcentrerà": "riconcentrare",
    "riconcentrerò": "riconcentrare",
    "riconcentri": "riconcentrare",
    "riconcentriamo": "riconcentrare",
    "riconcentriate": "riconcentrare",
    "riconcentrin": "riconcentrare",
    "riconcentrino": "riconcentrare",
    "riconcentro": "riconcentrare",
    "riconcentrò": "riconcentrare",
    "riconcili": "riconciliare",
    "riconcilia": "riconciliare",
    "riconciliai": "riconciliare",
    "riconciliammo": "riconciliare",
    "riconciliamo": "riconciliare",
    "riconcilian": "riconciliare",
    "riconciliando": "riconciliare",
    "riconciliano": "riconciliare",
    "riconciliante": "riconciliare",
    "riconcilianti": "riconciliare",
    "riconciliar": "riconciliare",
    "riconciliaron": "riconciliare",
    "riconciliarono": "riconciliare",
    "riconciliasse": "riconciliare",
    "riconciliasser": "riconciliare",
    "riconciliassero": "riconciliare",
    "riconciliassi": "riconciliare",
    "riconciliassimo": "riconciliare",
    "riconciliaste": "riconciliare",
    "riconciliasti": "riconciliare",
    "riconciliata": "riconciliare",
    "riconciliate": "riconciliare",
    "riconciliati": "riconciliare",
    "riconciliato": "riconciliare",
    "riconciliatori": "riconciliatore",
    "riconciliatrice": "riconciliatore",
    "riconciliatrici": "riconciliatore",
    "riconciliava": "riconciliare",
    "riconciliavamo": "riconciliare",
    "riconciliavan": "riconciliare",
    "riconciliavano": "riconciliare",
    "riconciliavate": "riconciliare",
    "riconciliavi": "riconciliare",
    "riconciliavo": "riconciliare",
    "riconciliazioni": "riconciliazione",
    "riconcilierai": "riconciliare",
    "riconcilieran": "riconciliare",
    "riconcilieranno": "riconciliare",
    "riconcilierebbe": "riconciliare",
    "riconcilierebber": "riconciliare",
    "riconcilierebbero": "riconciliare",
    "riconcilierei": "riconciliare",
    "riconcilieremmo": "riconciliare",
    "riconcilieremo": "riconciliare",
    "riconciliereste": "riconciliare",
    "riconcilieresti": "riconciliare",
    "riconcilierete": "riconciliare",
    "riconcilierà": "riconciliare",
    "riconcilierò": "riconciliare",
    "riconcilin": "riconciliare",
    "riconcilino": "riconciliare",
    "riconcilio": "riconciliare",
    "riconciliò": "riconciliare",
    "ricondotta": "ricondurre",
    "ricondotte": "ricondurre",
    "ricondotti": "ricondurre",
    "ricondotto": "ricondurre",
    "riconduca": "ricondurre",
    "riconducan": "ricondurre",
    "riconducano": "ricondurre",
    "riconduce": "ricondurre",
    "riconducemmo": "ricondurre",
    "riconducendo": "ricondurre",
    "riconducente": "ricondurre",
    "riconducenti": "ricondurre",
    "riconducesse": "ricondurre",
    "riconducesser": "ricondurre",
    "riconducessero": "ricondurre",
    "riconducessi": "ricondurre",
    "riconducessimo": "ricondurre",
    "riconduceste": "ricondurre",
    "riconducesti": "ricondurre",
    "riconducete": "ricondurre",
    "riconduceva": "ricondurre",
    "riconducevamo": "ricondurre",
    "riconducevan": "ricondurre",
    "riconducevano": "ricondurre",
    "riconducevate": "ricondurre",
    "riconducevi": "ricondurre",
    "riconducevo": "ricondurre",
    "riconduci": "ricondurre",
    "riconduciamo": "ricondurre",
    "riconduciate": "ricondurre",
    "riconducibili": "riconducibile",
    "riconduco": "ricondurre",
    "riconducon": "ricondurre",
    "riconducono": "ricondurre",
    "ricondurr": "ricondurre",
    "ricondurrai": "ricondurre",
    "ricondurran": "ricondurre",
    "ricondurranno": "ricondurre",
    "ricondurrebbe": "ricondurre",
    "ricondurrebber": "ricondurre",
    "ricondurrebbero": "ricondurre",
    "ricondurrei": "ricondurre",
    "ricondurremmo": "ricondurre",
    "ricondurremo": "ricondurre",
    "ricondurreste": "ricondurre",
    "ricondurresti": "ricondurre",
    "ricondurrete": "ricondurre",
    "ricondurrà": "ricondurre",
    "ricondurrò": "ricondurre",
    "ricondusse": "ricondurre",
    "ricondusser": "ricondurre",
    "ricondussero": "ricondurre",
    "ricondussi": "ricondurre",
    "riconferma": "riconfermare",
    "riconfermai": "riconfermare",
    "riconfermammo": "riconfermare",
    "riconferman": "riconfermare",
    "riconfermando": "riconfermare",
    "riconfermano": "riconfermare",
    "riconfermante": "riconfermare",
    "riconfermanti": "riconfermare",
    "riconfermar": "riconfermare",
    "riconfermaron": "riconfermare",
    "riconfermarono": "riconfermare",
    "riconfermasse": "riconfermare",
    "riconfermasser": "riconfermare",
    "riconfermassero": "riconfermare",
    "riconfermassi": "riconfermare",
    "riconfermassimo": "riconfermare",
    "riconfermaste": "riconfermare",
    "riconfermasti": "riconfermare",
    "riconfermata": "riconfermare",
    "riconfermate": "riconfermare",
    "riconfermati": "riconfermato",
    "riconfermato": "riconfermare",
    "riconfermava": "riconfermare",
    "riconfermavamo": "riconfermare",
    "riconfermavan": "riconfermare",
    "riconfermavano": "riconfermare",
    "riconfermavate": "riconfermare",
    "riconfermavi": "riconfermare",
    "riconfermavo": "riconfermare",
    "riconferme": "riconferma",
    "riconfermerai": "riconfermare",
    "riconfermeran": "riconfermare",
    "riconfermeranno": "riconfermare",
    "riconfermerebbe": "riconfermare",
    "riconfermerebber": "riconfermare",
    "riconfermerebbero": "riconfermare",
    "riconfermerei": "riconfermare",
    "riconfermeremmo": "riconfermare",
    "riconfermeremo": "riconfermare",
    "riconfermereste": "riconfermare",
    "riconfermeresti": "riconfermare",
    "riconfermerete": "riconfermare",
    "riconfermerà": "riconfermare",
    "riconfermerò": "riconfermare",
    "riconfermi": "riconfermare",
    "riconfermiamo": "riconfermare",
    "riconfermiate": "riconfermare",
    "riconfermin": "riconfermare",
    "riconfermino": "riconfermare",
    "riconfermo": "riconfermare",
    "riconfermò": "riconfermare",
    "riconforta": "riconfortare",
    "riconfortai": "riconfortare",
    "riconfortammo": "riconfortare",
    "riconfortan": "riconfortare",
    "riconfortando": "riconfortare",
    "riconfortano": "riconfortare",
    "riconfortante": "riconfortare",
    "riconfortanti": "riconfortare",
    "riconfortar": "riconfortare",
    "riconfortaron": "riconfortare",
    "riconfortarono": "riconfortare",
    "riconfortasse": "riconfortare",
    "riconfortasser": "riconfortare",
    "riconfortassero": "riconfortare",
    "riconfortassi": "riconfortare",
    "riconfortassimo": "riconfortare",
    "riconfortaste": "riconfortare",
    "riconfortasti": "riconfortare",
    "riconfortata": "riconfortare",
    "riconfortate": "riconfortare",
    "riconfortati": "riconfortare",
    "riconfortato": "riconfortare",
    "riconfortava": "riconfortare",
    "riconfortavamo": "riconfortare",
    "riconfortavan": "riconfortare",
    "riconfortavano": "riconfortare",
    "riconfortavate": "riconfortare",
    "riconfortavi": "riconfortare",
    "riconfortavo": "riconfortare",
    "riconforterai": "riconfortare",
    "riconforteran": "riconfortare",
    "riconforteranno": "riconfortare",
    "riconforterebbe": "riconfortare",
    "riconforterebber": "riconfortare",
    "riconforterebbero": "riconfortare",
    "riconforterei": "riconfortare",
    "riconforteremmo": "riconfortare",
    "riconforteremo": "riconfortare",
    "riconfortereste": "riconfortare",
    "riconforteresti": "riconfortare",
    "riconforterete": "riconfortare",
    "riconforterà": "riconfortare",
    "riconforterò": "riconfortare",
    "riconforti": "riconfortare",
    "riconfortiamo": "riconfortare",
    "riconfortiate": "riconfortare",
    "riconfortin": "riconfortare",
    "riconfortino": "riconfortare",
    "riconforto": "riconfortare",
    "riconfortò": "riconfortare",
    "riconfronta": "riconfrontare",
    "riconfrontai": "riconfrontare",
    "riconfrontammo": "riconfrontare",
    "riconfrontan": "riconfrontare",
    "riconfrontando": "riconfrontare",
    "riconfrontano": "riconfrontare",
    "riconfrontante": "riconfrontare",
    "riconfrontanti": "riconfrontare",
    "riconfrontar": "riconfrontare",
    "riconfrontaron": "riconfrontare",
    "riconfrontarono": "riconfrontare",
    "riconfrontasse": "riconfrontare",
    "riconfrontasser": "riconfrontare",
    "riconfrontassero": "riconfrontare",
    "riconfrontassi": "riconfrontare",
    "riconfrontassimo": "riconfrontare",
    "riconfrontaste": "riconfrontare",
    "riconfrontasti": "riconfrontare",
    "riconfrontata": "riconfrontare",
    "riconfrontate": "riconfrontare",
    "riconfrontati": "riconfrontare",
    "riconfrontato": "riconfrontare",
    "riconfrontava": "riconfrontare",
    "riconfrontavamo": "riconfrontare",
    "riconfrontavan": "riconfrontare",
    "riconfrontavano": "riconfrontare",
    "riconfrontavate": "riconfrontare",
    "riconfrontavi": "riconfrontare",
    "riconfrontavo": "riconfrontare",
    "riconfronterai": "riconfrontare",
    "riconfronteran": "riconfrontare",
    "riconfronteranno": "riconfrontare",
    "riconfronterebbe": "riconfrontare",
    "riconfronterebber": "riconfrontare",
    "riconfronterebbero": "riconfrontare",
    "riconfronterei": "riconfrontare",
    "riconfronteremmo": "riconfrontare",
    "riconfronteremo": "riconfrontare",
    "riconfrontereste": "riconfrontare",
    "riconfronteresti": "riconfrontare",
    "riconfronterete": "riconfrontare",
    "riconfronterà": "riconfrontare",
    "riconfronterò": "riconfrontare",
    "riconfronti": "riconfrontare",
    "riconfrontiamo": "riconfrontare",
    "riconfrontiate": "riconfrontare",
    "riconfrontin": "riconfrontare",
    "riconfrontino": "riconfrontare",
    "riconfronto": "riconfrontare",
    "riconfrontò": "riconfrontare",
    "ricongiunga": "ricongiungere",
    "ricongiungan": "ricongiungere",
    "ricongiungano": "ricongiungere",
    "ricongiunge": "ricongiungere",
    "ricongiungemmo": "ricongiungere",
    "ricongiungendo": "ricongiungere",
    "ricongiungente": "ricongiungere",
    "ricongiungenti": "ricongiungere",
    "ricongiunger": "ricongiungere",
    "ricongiungerai": "ricongiungere",
    "ricongiungeran": "ricongiungere",
    "ricongiungeranno": "ricongiungere",
    "ricongiungerebbe": "ricongiungere",
    "ricongiungerebber": "ricongiungere",
    "ricongiungerebbero": "ricongiungere",
    "ricongiungerei": "ricongiungere",
    "ricongiungeremmo": "ricongiungere",
    "ricongiungeremo": "ricongiungere",
    "ricongiungereste": "ricongiungere",
    "ricongiungeresti": "ricongiungere",
    "ricongiungerete": "ricongiungere",
    "ricongiungerà": "ricongiungere",
    "ricongiungerò": "ricongiungere",
    "ricongiungesse": "ricongiungere",
    "ricongiungesser": "ricongiungere",
    "ricongiungessero": "ricongiungere",
    "ricongiungessi": "ricongiungere",
    "ricongiungessimo": "ricongiungere",
    "ricongiungeste": "ricongiungere",
    "ricongiungesti": "ricongiungere",
    "ricongiungete": "ricongiungere",
    "ricongiungeva": "ricongiungere",
    "ricongiungevamo": "ricongiungere",
    "ricongiungevan": "ricongiungere",
    "ricongiungevano": "ricongiungere",
    "ricongiungevate": "ricongiungere",
    "ricongiungevi": "ricongiungere",
    "ricongiungevo": "ricongiungere",
    "ricongiungi": "ricongiungere",
    "ricongiungiamo": "ricongiungere",
    "ricongiungiate": "ricongiungere",
    "ricongiungimenti": "ricongiungimento",
    "ricongiungo": "ricongiungere",
    "ricongiungon": "ricongiungere",
    "ricongiungono": "ricongiungere",
    "ricongiunser": "ricongiungere",
    "ricongiunsero": "ricongiungere",
    "ricongiunsi": "ricongiungere",
    "ricongiunsè": "ricongiungere",
    "ricongiunta": "ricongiungere",
    "ricongiunte": "ricongiungere",
    "ricongiunti": "ricongiungere",
    "ricongiunto": "ricongiungere",
    "ricongiunzioni": "ricongiunzione",
    "riconnessa": "riconnettere",
    "riconnesse": "riconnettere",
    "riconnessi": "riconnettere",
    "riconnesso": "riconnettere",
    "riconnetta": "riconnettere",
    "riconnettan": "riconnettere",
    "riconnettano": "riconnettere",
    "riconnette": "riconnettere",
    "riconnettei": "riconnettere",
    "riconnettemmo": "riconnettere",
    "riconnettendo": "riconnettere",
    "riconnettente": "riconnettere",
    "riconnettenti": "riconnettere",
    "riconnetter": "riconnettere",
    "riconnetterai": "riconnettere",
    "riconnetteran": "riconnettere",
    "riconnetteranno": "riconnettere",
    "riconnetterebbe": "riconnettere",
    "riconnetterebber": "riconnettere",
    "riconnetterebbero": "riconnettere",
    "riconnetterei": "riconnettere",
    "riconnetteremmo": "riconnettere",
    "riconnetteremo": "riconnettere",
    "riconnettereste": "riconnettere",
    "riconnetteresti": "riconnettere",
    "riconnetterete": "riconnettere",
    "riconnetteron": "riconnettere",
    "riconnetterono": "riconnettere",
    "riconnetterà": "riconnettere",
    "riconnetterò": "riconnettere",
    "riconnettesse": "riconnettere",
    "riconnettesser": "riconnettere",
    "riconnettessero": "riconnettere",
    "riconnettessi": "riconnettere",
    "riconnettessimo": "riconnettere",
    "riconnetteste": "riconnettere",
    "riconnettesti": "riconnettere",
    "riconnettete": "riconnettere",
    "riconnetteva": "riconnettere",
    "riconnettevamo": "riconnettere",
    "riconnettevan": "riconnettere",
    "riconnettevano": "riconnettere",
    "riconnettevate": "riconnettere",
    "riconnettevi": "riconnettere",
    "riconnettevo": "riconnettere",
    "riconnetti": "riconnettere",
    "riconnettiamo": "riconnettere",
    "riconnettiate": "riconnettere",
    "riconnetto": "riconnettere",
    "riconnetton": "riconnettere",
    "riconnettono": "riconnettere",
    "riconnettè": "riconnettere",
    "riconobbe": "riconoscere",
    "riconobber": "riconoscere",
    "riconobbero": "riconoscere",
    "riconobbi": "riconoscere",
    "riconosca": "riconoscere",
    "riconoscan": "riconoscere",
    "riconoscano": "riconoscere",
    "riconosce": "riconoscere",
    "riconoscemmo": "riconoscere",
    "riconoscendo": "riconoscere",
    "riconoscente": "riconoscere",
    "riconoscenti": "riconoscere",
    "riconoscenze": "riconoscenza",
    "riconoscer": "riconoscere",
    "riconoscerai": "riconoscere",
    "riconosceran": "riconoscere",
    "riconosceranno": "riconoscere",
    "riconoscerebbe": "riconoscere",
    "riconoscerebber": "riconoscere",
    "riconoscerebbero": "riconoscere",
    "riconoscerei": "riconoscere",
    "riconosceremmo": "riconoscere",
    "riconosceremo": "riconoscere",
    "riconoscereste": "riconoscere",
    "riconosceresti": "riconoscere",
    "riconoscerete": "riconoscere",
    "riconoscerà": "riconoscere",
    "riconoscerò": "riconoscere",
    "riconoscesse": "riconoscere",
    "riconoscesser": "riconoscere",
    "riconoscessero": "riconoscere",
    "riconoscessi": "riconoscere",
    "riconoscessimo": "riconoscere",
    "riconosceste": "riconoscere",
    "riconoscesti": "riconoscere",
    "riconoscete": "riconoscere",
    "riconosceva": "riconoscere",
    "riconoscevamo": "riconoscere",
    "riconoscevan": "riconoscere",
    "riconoscevano": "riconoscere",
    "riconoscevate": "riconoscere",
    "riconoscevi": "riconoscere",
    "riconoscevo": "riconoscere",
    "riconosci": "riconoscere",
    "riconosciamo": "riconoscere",
    "riconosciate": "riconoscere",
    "riconoscibili": "riconoscibile",
    "riconoscimenti": "riconoscimento",
    "riconosciuta": "riconoscere",
    "riconosciute": "riconoscere",
    "riconosciuti": "riconoscere",
    "riconosciuto": "riconoscere",
    "riconosco": "riconoscere",
    "riconoscon": "riconoscere",
    "riconoscono": "riconoscere",
    "riconquista": "riconquistare",
    "riconquistai": "riconquistare",
    "riconquistammo": "riconquistare",
    "riconquistan": "riconquistare",
    "riconquistando": "riconquistare",
    "riconquistano": "riconquistare",
    "riconquistante": "riconquistare",
    "riconquistanti": "riconquistare",
    "riconquistar": "riconquistare",
    "riconquistaron": "riconquistare",
    "riconquistarono": "riconquistare",
    "riconquistasse": "riconquistare",
    "riconquistasser": "riconquistare",
    "riconquistassero": "riconquistare",
    "riconquistassi": "riconquistare",
    "riconquistassimo": "riconquistare",
    "riconquistaste": "riconquistare",
    "riconquistasti": "riconquistare",
    "riconquistata": "riconquistare",
    "riconquistate": "riconquistare",
    "riconquistati": "riconquistare",
    "riconquistato": "riconquistare",
    "riconquistava": "riconquistare",
    "riconquistavamo": "riconquistare",
    "riconquistavan": "riconquistare",
    "riconquistavano": "riconquistare",
    "riconquistavate": "riconquistare",
    "riconquistavi": "riconquistare",
    "riconquistavo": "riconquistare",
    "riconquiste": "riconquista",
    "riconquisterai": "riconquistare",
    "riconquisteran": "riconquistare",
    "riconquisteranno": "riconquistare",
    "riconquisterebbe": "riconquistare",
    "riconquisterebber": "riconquistare",
    "riconquisterebbero": "riconquistare",
    "riconquisterei": "riconquistare",
    "riconquisteremmo": "riconquistare",
    "riconquisteremo": "riconquistare",
    "riconquistereste": "riconquistare",
    "riconquisteresti": "riconquistare",
    "riconquisterete": "riconquistare",
    "riconquisterà": "riconquistare",
    "riconquisterò": "riconquistare",
    "riconquisti": "riconquistare",
    "riconquistiamo": "riconquistare",
    "riconquistiate": "riconquistare",
    "riconquistin": "riconquistare",
    "riconquistino": "riconquistare",
    "riconquisto": "riconquistare",
    "riconquistò": "riconquistare",
    "riconsacra": "riconsacrare",
    "riconsacrai": "riconsacrare",
    "riconsacrammo": "riconsacrare",
    "riconsacran": "riconsacrare",
    "riconsacrando": "riconsacrare",
    "riconsacrano": "riconsacrare",
    "riconsacrante": "riconsacrare",
    "riconsacranti": "riconsacrare",
    "riconsacrar": "riconsacrare",
    "riconsacraron": "riconsacrare",
    "riconsacrarono": "riconsacrare",
    "riconsacrasse": "riconsacrare",
    "riconsacrasser": "riconsacrare",
    "riconsacrassero": "riconsacrare",
    "riconsacrassi": "riconsacrare",
    "riconsacrassimo": "riconsacrare",
    "riconsacraste": "riconsacrare",
    "riconsacrasti": "riconsacrare",
    "riconsacrata": "riconsacrare",
    "riconsacrate": "riconsacrare",
    "riconsacrati": "riconsacrare",
    "riconsacrato": "riconsacrare",
    "riconsacrava": "riconsacrare",
    "riconsacravamo": "riconsacrare",
    "riconsacravan": "riconsacrare",
    "riconsacravano": "riconsacrare",
    "riconsacravate": "riconsacrare",
    "riconsacravi": "riconsacrare",
    "riconsacravo": "riconsacrare",
    "riconsacrerai": "riconsacrare",
    "riconsacreran": "riconsacrare",
    "riconsacreranno": "riconsacrare",
    "riconsacrerebbe": "riconsacrare",
    "riconsacrerebber": "riconsacrare",
    "riconsacrerebbero": "riconsacrare",
    "riconsacrerei": "riconsacrare",
    "riconsacreremmo": "riconsacrare",
    "riconsacreremo": "riconsacrare",
    "riconsacrereste": "riconsacrare",
    "riconsacreresti": "riconsacrare",
    "riconsacrerete": "riconsacrare",
    "riconsacrerà": "riconsacrare",
    "riconsacrerò": "riconsacrare",
    "riconsacri": "riconsacrare",
    "riconsacriamo": "riconsacrare",
    "riconsacriate": "riconsacrare",
    "riconsacrin": "riconsacrare",
    "riconsacrino": "riconsacrare",
    "riconsacro": "riconsacrare",
    "riconsacrò": "riconsacrare",
    "riconsegna": "riconsegnare",
    "riconsegnai": "riconsegnare",
    "riconsegnammo": "riconsegnare",
    "riconsegnan": "riconsegnare",
    "riconsegnando": "riconsegnare",
    "riconsegnano": "riconsegnare",
    "riconsegnante": "riconsegnare",
    "riconsegnanti": "riconsegnare",
    "riconsegnar": "riconsegnare",
    "riconsegnaron": "riconsegnare",
    "riconsegnarono": "riconsegnare",
    "riconsegnasse": "riconsegnare",
    "riconsegnasser": "riconsegnare",
    "riconsegnassero": "riconsegnare",
    "riconsegnassi": "riconsegnare",
    "riconsegnassimo": "riconsegnare",
    "riconsegnaste": "riconsegnare",
    "riconsegnasti": "riconsegnare",
    "riconsegnata": "riconsegnare",
    "riconsegnate": "riconsegnare",
    "riconsegnati": "riconsegnare",
    "riconsegnato": "riconsegnare",
    "riconsegnava": "riconsegnare",
    "riconsegnavamo": "riconsegnare",
    "riconsegnavan": "riconsegnare",
    "riconsegnavano": "riconsegnare",
    "riconsegnavate": "riconsegnare",
    "riconsegnavi": "riconsegnare",
    "riconsegnavo": "riconsegnare",
    "riconsegne": "riconsegna",
    "riconsegnerai": "riconsegnare",
    "riconsegneran": "riconsegnare",
    "riconsegneranno": "riconsegnare",
    "riconsegnerebbe": "riconsegnare",
    "riconsegnerebber": "riconsegnare",
    "riconsegnerebbero": "riconsegnare",
    "riconsegnerei": "riconsegnare",
    "riconsegneremmo": "riconsegnare",
    "riconsegneremo": "riconsegnare",
    "riconsegnereste": "riconsegnare",
    "riconsegneresti": "riconsegnare",
    "riconsegnerete": "riconsegnare",
    "riconsegnerà": "riconsegnare",
    "riconsegnerò": "riconsegnare",
    "riconsegni": "riconsegnare",
    "riconsegniamo": "riconsegnare",
    "riconsegniate": "riconsegnare",
    "riconsegnin": "riconsegnare",
    "riconsegnino": "riconsegnare",
    "riconsegno": "riconsegnare",
    "riconsegnò": "riconsegnare",
    "riconsidera": "riconsiderare",
    "riconsiderai": "riconsiderare",
    "riconsiderammo": "riconsiderare",
    "riconsideran": "riconsiderare",
    "riconsiderando": "riconsiderare",
    "riconsiderano": "riconsiderare",
    "riconsiderante": "riconsiderare",
    "riconsideranti": "riconsiderare",
    "riconsiderar": "riconsiderare",
    "riconsideraron": "riconsiderare",
    "riconsiderarono": "riconsiderare",
    "riconsiderasse": "riconsiderare",
    "riconsiderasser": "riconsiderare",
    "riconsiderassero": "riconsiderare",
    "riconsiderassi": "riconsiderare",
    "riconsiderassimo": "riconsiderare",
    "riconsideraste": "riconsiderare",
    "riconsiderasti": "riconsiderare",
    "riconsiderata": "riconsiderare",
    "riconsiderate": "riconsiderare",
    "riconsiderati": "riconsiderare",
    "riconsiderato": "riconsiderare",
    "riconsiderava": "riconsiderare",
    "riconsideravamo": "riconsiderare",
    "riconsideravan": "riconsiderare",
    "riconsideravano": "riconsiderare",
    "riconsideravate": "riconsiderare",
    "riconsideravi": "riconsiderare",
    "riconsideravo": "riconsiderare",
    "riconsiderazioni": "riconsiderazione",
    "riconsidererai": "riconsiderare",
    "riconsidereran": "riconsiderare",
    "riconsidereranno": "riconsiderare",
    "riconsidererebbe": "riconsiderare",
    "riconsidererebber": "riconsiderare",
    "riconsidererebbero": "riconsiderare",
    "riconsidererei": "riconsiderare",
    "riconsidereremmo": "riconsiderare",
    "riconsidereremo": "riconsiderare",
    "riconsiderereste": "riconsiderare",
    "riconsidereresti": "riconsiderare",
    "riconsidererete": "riconsiderare",
    "riconsidererà": "riconsiderare",
    "riconsidererò": "riconsiderare",
    "riconsideri": "riconsiderare",
    "riconsideriamo": "riconsiderare",
    "riconsideriate": "riconsiderare",
    "riconsiderin": "riconsiderare",
    "riconsiderino": "riconsiderare",
    "riconsidero": "riconsiderare",
    "riconsiderò": "riconsiderare",
    "riconvenendo": "riconvenire",
    "riconvenente": "riconvenire",
    "riconvenenti": "riconvenire",
    "riconvenga": "riconvenire",
    "riconvengan": "riconvenire",
    "riconvengano": "riconvenire",
    "riconvengo": "riconvenire",
    "riconvengon": "riconvenire",
    "riconvengono": "riconvenire",
    "riconveniamo": "riconvenire",
    "riconveniate": "riconvenire",
    "riconvenimmo": "riconvenire",
    "riconvenir": "riconvenire",
    "riconvenisse": "riconvenire",
    "riconvenisser": "riconvenire",
    "riconvenissero": "riconvenire",
    "riconvenissi": "riconvenire",
    "riconvenissimo": "riconvenire",
    "riconveniste": "riconvenire",
    "riconvenisti": "riconvenire",
    "riconvenite": "riconvenire",
    "riconveniva": "riconvenire",
    "riconvenivamo": "riconvenire",
    "riconvenivan": "riconvenire",
    "riconvenivano": "riconvenire",
    "riconvenivate": "riconvenire",
    "riconvenivi": "riconvenire",
    "riconvenivo": "riconvenire",
    "riconvenne": "riconvenire",
    "riconvenner": "riconvenire",
    "riconvennero": "riconvenire",
    "riconvenni": "riconvenire",
    "riconvenuta": "riconvenire",
    "riconvenute": "riconvenire",
    "riconvenuti": "riconvenire",
    "riconvenuto": "riconvenire",
    "riconverrai": "riconvenire",
    "riconverran": "riconvenire",
    "riconverranno": "riconvenire",
    "riconverrebbe": "riconvenire",
    "riconverrebber": "riconvenire",
    "riconverrebbero": "riconvenire",
    "riconverrei": "riconvenire",
    "riconverremmo": "riconvenire",
    "riconverremo": "riconvenire",
    "riconverreste": "riconvenire",
    "riconverresti": "riconvenire",
    "riconverrete": "riconvenire",
    "riconverrà": "riconvenire",
    "riconverrò": "riconvenire",
    "riconversioni": "riconversione",
    "riconverta": "riconvertire",
    "riconvertan": "riconvertire",
    "riconvertano": "riconvertire",
    "riconverte": "riconvertire",
    "riconvertendo": "riconvertire",
    "riconvertente": "riconvertire",
    "riconvertenti": "riconvertire",
    "riconverti": "riconvertire",
    "riconvertiamo": "riconvertire",
    "riconvertiate": "riconvertire",
    "riconvertii": "riconvertire",
    "riconvertimmo": "riconvertire",
    "riconvertir": "riconvertire",
    "riconvertirai": "riconvertire",
    "riconvertiran": "riconvertire",
    "riconvertiranno": "riconvertire",
    "riconvertirebbe": "riconvertire",
    "riconvertirebber": "riconvertire",
    "riconvertirebbero": "riconvertire",
    "riconvertirei": "riconvertire",
    "riconvertiremmo": "riconvertire",
    "riconvertiremo": "riconvertire",
    "riconvertireste": "riconvertire",
    "riconvertiresti": "riconvertire",
    "riconvertirete": "riconvertire",
    "riconvertiron": "riconvertire",
    "riconvertirono": "riconvertire",
    "riconvertirà": "riconvertire",
    "riconvertirò": "riconvertire",
    "riconvertisse": "riconvertire",
    "riconvertisser": "riconvertire",
    "riconvertissero": "riconvertire",
    "riconvertissi": "riconvertire",
    "riconvertissimo": "riconvertire",
    "riconvertiste": "riconvertire",
    "riconvertisti": "riconvertire",
    "riconvertita": "riconvertire",
    "riconvertite": "riconvertire",
    "riconvertiti": "riconvertire",
    "riconvertito": "riconvertire",
    "riconvertiva": "riconvertire",
    "riconvertivamo": "riconvertire",
    "riconvertivan": "riconvertire",
    "riconvertivano": "riconvertire",
    "riconvertivate": "riconvertire",
    "riconvertivi": "riconvertire",
    "riconvertivo": "riconvertire",
    "riconverto": "riconvertire",
    "riconverton": "riconvertire",
    "riconvertono": "riconvertire",
    "riconvertì": "riconvertire",
    "riconviene": "riconvenire",
    "riconvieni": "riconvenire",
    "riconvoca": "riconvocare",
    "riconvocai": "riconvocare",
    "riconvocammo": "riconvocare",
    "riconvocan": "riconvocare",
    "riconvocando": "riconvocare",
    "riconvocano": "riconvocare",
    "riconvocante": "riconvocare",
    "riconvocanti": "riconvocare",
    "riconvocar": "riconvocare",
    "riconvocaron": "riconvocare",
    "riconvocarono": "riconvocare",
    "riconvocasse": "riconvocare",
    "riconvocasser": "riconvocare",
    "riconvocassero": "riconvocare",
    "riconvocassi": "riconvocare",
    "riconvocassimo": "riconvocare",
    "riconvocaste": "riconvocare",
    "riconvocasti": "riconvocare",
    "riconvocata": "riconvocare",
    "riconvocate": "riconvocare",
    "riconvocati": "riconvocare",
    "riconvocato": "riconvocare",
    "riconvocava": "riconvocare",
    "riconvocavamo": "riconvocare",
    "riconvocavan": "riconvocare",
    "riconvocavano": "riconvocare",
    "riconvocavate": "riconvocare",
    "riconvocavi": "riconvocare",
    "riconvocavo": "riconvocare",
    "riconvocazioni": "riconvocazione",
    "riconvocherai": "riconvocare",
    "riconvocheran": "riconvocare",
    "riconvocheranno": "riconvocare",
    "riconvocherebbe": "riconvocare",
    "riconvocherebber": "riconvocare",
    "riconvocherebbero": "riconvocare",
    "riconvocherei": "riconvocare",
    "riconvocheremmo": "riconvocare",
    "riconvocheremo": "riconvocare",
    "riconvochereste": "riconvocare",
    "riconvocheresti": "riconvocare",
    "riconvocherete": "riconvocare",
    "riconvocherà": "riconvocare",
    "riconvocherò": "riconvocare",
    "riconvochi": "riconvocare",
    "riconvochiamo": "riconvocare",
    "riconvochiate": "riconvocare",
    "riconvochin": "riconvocare",
    "riconvochino": "riconvocare",
    "riconvoco": "riconvocare",
    "riconvocò": "riconvocare",
    "ricoperta": "ricoprire",
    "ricoperte": "ricoprire",
    "ricoperti": "ricoprire",
    "ricoperto": "ricoprire",
    "ricoperture": "ricopertura",
    "ricopi": "ricopiare",
    "ricopia": "ricopiare",
    "ricopiai": "ricopiare",
    "ricopiammo": "ricopiare",
    "ricopiamo": "ricopiare",
    "ricopian": "ricopiare",
    "ricopiando": "ricopiare",
    "ricopiano": "ricopiare",
    "ricopiante": "ricopiare",
    "ricopianti": "ricopiare",
    "ricopiar": "ricopiare",
    "ricopiaron": "ricopiare",
    "ricopiarono": "ricopiare",
    "ricopiasse": "ricopiare",
    "ricopiasser": "ricopiare",
    "ricopiassero": "ricopiare",
    "ricopiassi": "ricopiare",
    "ricopiassimo": "ricopiare",
    "ricopiaste": "ricopiare",
    "ricopiasti": "ricopiare",
    "ricopiata": "ricopiare",
    "ricopiate": "ricopiare",
    "ricopiati": "ricopiare",
    "ricopiato": "ricopiare",
    "ricopiava": "ricopiare",
    "ricopiavamo": "ricopiare",
    "ricopiavan": "ricopiare",
    "ricopiavano": "ricopiare",
    "ricopiavate": "ricopiare",
    "ricopiavi": "ricopiare",
    "ricopiavo": "ricopiare",
    "ricopierai": "ricopiare",
    "ricopieran": "ricopiare",
    "ricopieranno": "ricopiare",
    "ricopierebbe": "ricopiare",
    "ricopierebber": "ricopiare",
    "ricopierebbero": "ricopiare",
    "ricopierei": "ricopiare",
    "ricopieremmo": "ricopiare",
    "ricopieremo": "ricopiare",
    "ricopiereste": "ricopiare",
    "ricopieresti": "ricopiare",
    "ricopierete": "ricopiare",
    "ricopierà": "ricopiare",
    "ricopierò": "ricopiare",
    "ricopin": "ricopiare",
    "ricopino": "ricopiare",
    "ricopio": "ricopiare",
    "ricopiò": "ricopiare",
    "ricopra": "ricoprire",
    "ricopran": "ricoprire",
    "ricoprano": "ricoprire",
    "ricopre": "ricoprire",
    "ricoprendo": "ricoprire",
    "ricoprente": "ricoprire",
    "ricoprenti": "ricoprire",
    "ricopri": "ricoprire",
    "ricopriamo": "ricoprire",
    "ricopriate": "ricoprire",
    "ricoprii": "ricoprire",
    "ricoprimmo": "ricoprire",
    "ricoprir": "ricoprire",
    "ricoprirai": "ricoprire",
    "ricopriran": "ricoprire",
    "ricopriranno": "ricoprire",
    "ricoprirebbe": "ricoprire",
    "ricoprirebber": "ricoprire",
    "ricoprirebbero": "ricoprire",
    "ricoprirei": "ricoprire",
    "ricopriremmo": "ricoprire",
    "ricopriremo": "ricoprire",
    "ricoprireste": "ricoprire",
    "ricopriresti": "ricoprire",
    "ricoprirete": "ricoprire",
    "ricopriron": "ricoprire",
    "ricoprirono": "ricoprire",
    "ricoprirà": "ricoprire",
    "ricoprirò": "ricoprire",
    "ricoprisse": "ricoprire",
    "ricoprisser": "ricoprire",
    "ricoprissero": "ricoprire",
    "ricoprissi": "ricoprire",
    "ricoprissimo": "ricoprire",
    "ricopriste": "ricoprire",
    "ricopristi": "ricoprire",
    "ricoprite": "ricoprire",
    "ricopriva": "ricoprire",
    "ricoprivamo": "ricoprire",
    "ricoprivan": "ricoprire",
    "ricoprivano": "ricoprire",
    "ricoprivate": "ricoprire",
    "ricoprivi": "ricoprire",
    "ricoprivo": "ricoprire",
    "ricopro": "ricoprire",
    "ricopron": "ricoprire",
    "ricoprono": "ricoprire",
    "ricoprì": "ricoprire",
    "ricorda": "ricordare",
    "ricordai": "ricordare",
    "ricordammo": "ricordare",
    "ricordan": "ricordare",
    "ricordando": "ricordare",
    "ricordano": "ricordare",
    "ricordante": "ricordare",
    "ricordanti": "ricordare",
    "ricordar": "ricordare",
    "ricordaron": "ricordare",
    "ricordarono": "ricordare",
    "ricordasse": "ricordare",
    "ricordasser": "ricordare",
    "ricordassero": "ricordare",
    "ricordassi": "ricordare",
    "ricordassimo": "ricordare",
    "ricordaste": "ricordare",
    "ricordasti": "ricordare",
    "ricordata": "ricordare",
    "ricordate": "ricordare",
    "ricordati": "ricordare",
    "ricordato": "ricordare",
    "ricordava": "ricordare",
    "ricordavamo": "ricordare",
    "ricordavan": "ricordare",
    "ricordavano": "ricordare",
    "ricordavate": "ricordare",
    "ricordavi": "ricordare",
    "ricordavo": "ricordare",
    "ricorderai": "ricordare",
    "ricorderan": "ricordare",
    "ricorderanno": "ricordare",
    "ricorderebbe": "ricordare",
    "ricorderebber": "ricordare",
    "ricorderebbero": "ricordare",
    "ricorderei": "ricordare",
    "ricorderemmo": "ricordare",
    "ricorderemo": "ricordare",
    "ricordereste": "ricordare",
    "ricorderesti": "ricordare",
    "ricorderete": "ricordare",
    "ricorderà": "ricordare",
    "ricorderò": "ricordare",
    "ricordi": "ricordo",
    "ricordiamo": "ricordare",
    "ricordiate": "ricordare",
    "ricordin": "ricordare",
    "ricordino": "ricordare",
    "ricordo": "ricordare",
    "ricordò": "ricordare",
    "ricorra": "ricorrere",
    "ricorran": "ricorrere",
    "ricorrano": "ricorrere",
    "ricorre": "ricorrere",
    "ricorregga": "ricorreggere",
    "ricorreggan": "ricorreggere",
    "ricorreggano": "ricorreggere",
    "ricorregge": "ricorreggere",
    "ricorreggemmo": "ricorreggere",
    "ricorreggendo": "ricorreggere",
    "ricorreggente": "ricorreggere",
    "ricorreggenti": "ricorreggere",
    "ricorregger": "ricorreggere",
    "ricorreggerai": "ricorreggere",
    "ricorreggeran": "ricorreggere",
    "ricorreggeranno": "ricorreggere",
    "ricorreggerebbe": "ricorreggere",
    "ricorreggerebber": "ricorreggere",
    "ricorreggerebbero": "ricorreggere",
    "ricorreggerei": "ricorreggere",
    "ricorreggeremmo": "ricorreggere",
    "ricorreggeremo": "ricorreggere",
    "ricorreggereste": "ricorreggere",
    "ricorreggeresti": "ricorreggere",
    "ricorreggerete": "ricorreggere",
    "ricorreggerà": "ricorreggere",
    "ricorreggerò": "ricorreggere",
    "ricorreggesse": "ricorreggere",
    "ricorreggesser": "ricorreggere",
    "ricorreggessero": "ricorreggere",
    "ricorreggessi": "ricorreggere",
    "ricorreggessimo": "ricorreggere",
    "ricorreggeste": "ricorreggere",
    "ricorreggesti": "ricorreggere",
    "ricorreggete": "ricorreggere",
    "ricorreggeva": "ricorreggere",
    "ricorreggevamo": "ricorreggere",
    "ricorreggevan": "ricorreggere",
    "ricorreggevano": "ricorreggere",
    "ricorreggevate": "ricorreggere",
    "ricorreggevi": "ricorreggere",
    "ricorreggevo": "ricorreggere",
    "ricorreggi": "ricorreggere",
    "ricorreggiamo": "ricorreggere",
    "ricorreggiate": "ricorreggere",
    "ricorreggo": "ricorreggere",
    "ricorreggon": "ricorreggere",
    "ricorreggono": "ricorreggere",
    "ricorremmo": "ricorrere",
    "ricorrendo": "ricorrere",
    "ricorrente": "ricorrere",
    "ricorrenti": "ricorrere",
    "ricorrenze": "ricorrenza",
    "ricorrer": "ricorrere",
    "ricorrerai": "ricorrere",
    "ricorreran": "ricorrere",
    "ricorreranno": "ricorrere",
    "ricorrerebbe": "ricorrere",
    "ricorrerebber": "ricorrere",
    "ricorrerebbero": "ricorrere",
    "ricorrerei": "ricorrere",
    "ricorreremmo": "ricorrere",
    "ricorreremo": "ricorrere",
    "ricorrereste": "ricorrere",
    "ricorreresti": "ricorrere",
    "ricorrerete": "ricorrere",
    "ricorrerà": "ricorrere",
    "ricorrerò": "ricorrere",
    "ricorresse": "ricorrere",
    "ricorresser": "ricorrere",
    "ricorressero": "ricorrere",
    "ricorressi": "ricorrere",
    "ricorressimo": "ricorrere",
    "ricorressè": "ricorreggere",
    "ricorreste": "ricorrere",
    "ricorresti": "ricorrere",
    "ricorrete": "ricorrere",
    "ricorretta": "ricorreggere",
    "ricorrette": "ricorreggere",
    "ricorretti": "ricorreggere",
    "ricorretto": "ricorreggere",
    "ricorreva": "ricorrere",
    "ricorrevamo": "ricorrere",
    "ricorrevan": "ricorrere",
    "ricorrevano": "ricorrere",
    "ricorrevate": "ricorrere",
    "ricorrevi": "ricorrere",
    "ricorrevo": "ricorrere",
    "ricorri": "ricorrere",
    "ricorriamo": "ricorrere",
    "ricorriate": "ricorrere",
    "ricorro": "ricorrere",
    "ricorron": "ricorrere",
    "ricorrono": "ricorrere",
    "ricorsa": "ricorso",
    "ricorse": "ricorso",
    "ricorser": "ricorrere",
    "ricorsero": "ricorrere",
    "ricorsi": "ricorso",
    "ricorso": "ricorrere",
    "ricosse": "ricuocere",
    "ricosser": "ricuocere",
    "ricossero": "ricuocere",
    "ricossi": "ricuocere",
    "ricostituendo": "ricostituire",
    "ricostituente": "ricostituire",
    "ricostituenti": "ricostituire",
    "ricostituiamo": "ricostituire",
    "ricostituiate": "ricostituire",
    "ricostituii": "ricostituire",
    "ricostituimmo": "ricostituire",
    "ricostituir": "ricostituire",
    "ricostituirai": "ricostituire",
    "ricostituiran": "ricostituire",
    "ricostituiranno": "ricostituire",
    "ricostituirebbe": "ricostituire",
    "ricostituirebber": "ricostituire",
    "ricostituirebbero": "ricostituire",
    "ricostituirei": "ricostituire",
    "ricostituiremmo": "ricostituire",
    "ricostituiremo": "ricostituire",
    "ricostituireste": "ricostituire",
    "ricostituiresti": "ricostituire",
    "ricostituirete": "ricostituire",
    "ricostituiron": "ricostituire",
    "ricostituirono": "ricostituire",
    "ricostituirà": "ricostituire",
    "ricostituirò": "ricostituire",
    "ricostituisca": "ricostituire",
    "ricostituiscan": "ricostituire",
    "ricostituiscano": "ricostituire",
    "ricostituisce": "ricostituire",
    "ricostituisci": "ricostituire",
    "ricostituisco": "ricostituire",
    "ricostituiscon": "ricostituire",
    "ricostituiscono": "ricostituire",
    "ricostituisse": "ricostituire",
    "ricostituisser": "ricostituire",
    "ricostituissero": "ricostituire",
    "ricostituissi": "ricostituire",
    "ricostituissimo": "ricostituire",
    "ricostituiste": "ricostituire",
    "ricostituisti": "ricostituire",
    "ricostituita": "ricostituire",
    "ricostituite": "ricostituire",
    "ricostituiti": "ricostituire",
    "ricostituito": "ricostituire",
    "ricostituiva": "ricostituire",
    "ricostituivamo": "ricostituire",
    "ricostituivan": "ricostituire",
    "ricostituivano": "ricostituire",
    "ricostituivate": "ricostituire",
    "ricostituivi": "ricostituire",
    "ricostituivo": "ricostituire",
    "ricostituzioni": "ricostituzione",
    "ricostituì": "ricostituire",
    "ricostruendo": "ricostruire",
    "ricostruente": "ricostruire",
    "ricostruenti": "ricostruire",
    "ricostruiamo": "ricostruire",
    "ricostruiate": "ricostruire",
    "ricostruii": "ricostruire",
    "ricostruimmo": "ricostruire",
    "ricostruir": "ricostruire",
    "ricostruirai": "ricostruire",
    "ricostruiran": "ricostruire",
    "ricostruiranno": "ricostruire",
    "ricostruirebbe": "ricostruire",
    "ricostruirebber": "ricostruire",
    "ricostruirebbero": "ricostruire",
    "ricostruirei": "ricostruire",
    "ricostruiremmo": "ricostruire",
    "ricostruiremo": "ricostruire",
    "ricostruireste": "ricostruire",
    "ricostruiresti": "ricostruire",
    "ricostruirete": "ricostruire",
    "ricostruiron": "ricostruire",
    "ricostruirono": "ricostruire",
    "ricostruirà": "ricostruire",
    "ricostruirò": "ricostruire",
    "ricostruisca": "ricostruire",
    "ricostruiscan": "ricostruire",
    "ricostruiscano": "ricostruire",
    "ricostruisce": "ricostruire",
    "ricostruisci": "ricostruire",
    "ricostruisco": "ricostruire",
    "ricostruiscon": "ricostruire",
    "ricostruiscono": "ricostruire",
    "ricostruisse": "ricostruire",
    "ricostruisser": "ricostruire",
    "ricostruissero": "ricostruire",
    "ricostruissi": "ricostruire",
    "ricostruissimo": "ricostruire",
    "ricostruiste": "ricostruire",
    "ricostruisti": "ricostruire",
    "ricostruita": "ricostruire",
    "ricostruite": "ricostruire",
    "ricostruiti": "ricostruire",
    "ricostruito": "ricostruire",
    "ricostruiva": "ricostruire",
    "ricostruivamo": "ricostruire",
    "ricostruivan": "ricostruire",
    "ricostruivano": "ricostruire",
    "ricostruivate": "ricostruire",
    "ricostruivi": "ricostruire",
    "ricostruivo": "ricostruire",
    "ricostruzioni": "ricostruzione",
    "ricostruì": "ricostruire",
    "ricotta": "ricuocere",
    "ricotte": "ricuocere",
    "ricotti": "ricuocere",
    "ricotto": "ricuocere",
    "ricovera": "ricoverare",
    "ricoverai": "ricoverare",
    "ricoverammo": "ricoverare",
    "ricoveran": "ricoverare",
    "ricoverando": "ricoverare",
    "ricoverano": "ricoverare",
    "ricoverante": "ricoverare",
    "ricoveranti": "ricoverare",
    "ricoverar": "ricoverare",
    "ricoveraron": "ricoverare",
    "ricoverarono": "ricoverare",
    "ricoverasse": "ricoverare",
    "ricoverasser": "ricoverare",
    "ricoverassero": "ricoverare",
    "ricoverassi": "ricoverare",
    "ricoverassimo": "ricoverare",
    "ricoveraste": "ricoverare",
    "ricoverasti": "ricoverare",
    "ricoverata": "ricoverato",
    "ricoverate": "ricoverato",
    "ricoverati": "ricoverato",
    "ricoverato": "ricoverare",
    "ricoverava": "ricoverare",
    "ricoveravamo": "ricoverare",
    "ricoveravan": "ricoverare",
    "ricoveravano": "ricoverare",
    "ricoveravate": "ricoverare",
    "ricoveravi": "ricoverare",
    "ricoveravo": "ricoverare",
    "ricovererai": "ricoverare",
    "ricovereran": "ricoverare",
    "ricovereranno": "ricoverare",
    "ricovererebbe": "ricoverare",
    "ricovererebber": "ricoverare",
    "ricovererebbero": "ricoverare",
    "ricovererei": "ricoverare",
    "ricovereremmo": "ricoverare",
    "ricovereremo": "ricoverare",
    "ricoverereste": "ricoverare",
    "ricovereresti": "ricoverare",
    "ricovererete": "ricoverare",
    "ricovererà": "ricoverare",
    "ricovererò": "ricoverare",
    "ricoveri": "ricovero",
    "ricoveriamo": "ricoverare",
    "ricoveriate": "ricoverare",
    "ricoverin": "ricoverare",
    "ricoverino": "ricoverare",
    "ricovero": "ricoverare",
    "ricoverò": "ricoverare",
    "ricrea": "ricreare",
    "ricreai": "ricreare",
    "ricreammo": "ricreare",
    "ricrean": "ricreare",
    "ricreando": "ricreare",
    "ricreano": "ricreare",
    "ricreante": "ricreare",
    "ricreanti": "ricreare",
    "ricrear": "ricreare",
    "ricrearon": "ricreare",
    "ricrearono": "ricreare",
    "ricreasse": "ricreare",
    "ricreasser": "ricreare",
    "ricreassero": "ricreare",
    "ricreassi": "ricreare",
    "ricreassimo": "ricreare",
    "ricreaste": "ricreare",
    "ricreasti": "ricreare",
    "ricreata": "ricreare",
    "ricreate": "ricreare",
    "ricreati": "ricreare",
    "ricreativa": "ricreativo",
    "ricreative": "ricreativo",
    "ricreativi": "ricreativo",
    "ricreato": "ricreare",
    "ricreava": "ricreare",
    "ricreavamo": "ricreare",
    "ricreavan": "ricreare",
    "ricreavano": "ricreare",
    "ricreavate": "ricreare",
    "ricreavi": "ricreare",
    "ricreavo": "ricreare",
    "ricreazioni": "ricreazione",
    "ricreda": "ricredere",
    "ricredan": "ricredere",
    "ricredano": "ricredere",
    "ricrede": "ricredere",
    "ricredei": "ricredere",
    "ricredemmo": "ricredere",
    "ricredendo": "ricredere",
    "ricredente": "ricredere",
    "ricredenti": "ricredere",
    "ricreder": "ricredere",
    "ricrederai": "ricredere",
    "ricrederan": "ricredere",
    "ricrederanno": "ricredere",
    "ricrederebbe": "ricredere",
    "ricrederebber": "ricredere",
    "ricrederebbero": "ricredere",
    "ricrederei": "ricredere",
    "ricrederemmo": "ricredere",
    "ricrederemo": "ricredere",
    "ricredereste": "ricredere",
    "ricrederesti": "ricredere",
    "ricrederete": "ricredere",
    "ricrederono": "ricredere",
    "ricrederà": "ricredere",
    "ricrederò": "ricredere",
    "ricredesse": "ricredere",
    "ricredesser": "ricredere",
    "ricredessero": "ricredere",
    "ricredessi": "ricredere",
    "ricredessimo": "ricredere",
    "ricredeste": "ricredere",
    "ricredesti": "ricredere",
    "ricredete": "ricredere",
    "ricredeva": "ricredere",
    "ricredevamo": "ricredere",
    "ricredevan": "ricredere",
    "ricredevano": "ricredere",
    "ricredevate": "ricredere",
    "ricredevi": "ricredere",
    "ricredevo": "ricredere",
    "ricredi": "ricredere",
    "ricrediamo": "ricredere",
    "ricrediate": "ricredere",
    "ricredo": "ricredere",
    "ricredon": "ricredere",
    "ricredono": "ricredere",
    "ricreduta": "ricredere",
    "ricredute": "ricredere",
    "ricreduti": "ricredere",
    "ricreduto": "ricredere",
    "ricredè": "ricredere",
    "ricreerai": "ricreare",
    "ricreeran": "ricreare",
    "ricreeranno": "ricreare",
    "ricreerebbe": "ricreare",
    "ricreerebber": "ricreare",
    "ricreerebbero": "ricreare",
    "ricreerei": "ricreare",
    "ricreeremmo": "ricreare",
    "ricreeremo": "ricreare",
    "ricreereste": "ricreare",
    "ricreeresti": "ricreare",
    "ricreerete": "ricreare",
    "ricreerà": "ricreare",
    "ricreerò": "ricreare",
    "ricrei": "ricreare",
    "ricreiamo": "ricreare",
    "ricreiate": "ricreare",
    "ricrein": "ricreare",
    "ricreino": "ricreare",
    "ricreo": "ricreare",
    "ricresca": "ricrescere",
    "ricrescan": "ricrescere",
    "ricrescano": "ricrescere",
    "ricresce": "ricrescere",
    "ricrescei": "ricrescere",
    "ricrescemmo": "ricrescere",
    "ricrescendo": "ricrescere",
    "ricrescente": "ricrescere",
    "ricrescenti": "ricrescere",
    "ricrescer": "ricrescere",
    "ricrescerai": "ricrescere",
    "ricresceran": "ricrescere",
    "ricresceranno": "ricrescere",
    "ricrescerebbe": "ricrescere",
    "ricrescerebber": "ricrescere",
    "ricrescerebbero": "ricrescere",
    "ricrescerei": "ricrescere",
    "ricresceremmo": "ricrescere",
    "ricresceremo": "ricrescere",
    "ricrescereste": "ricrescere",
    "ricresceresti": "ricrescere",
    "ricrescerete": "ricrescere",
    "ricresceron": "ricrescere",
    "ricrescerono": "ricrescere",
    "ricrescerà": "ricrescere",
    "ricrescerò": "ricrescere",
    "ricrescesse": "ricrescere",
    "ricrescesser": "ricrescere",
    "ricrescessero": "ricrescere",
    "ricrescessi": "ricrescere",
    "ricrescessimo": "ricrescere",
    "ricresceste": "ricrescere",
    "ricrescesti": "ricrescere",
    "ricrescete": "ricrescere",
    "ricresceva": "ricrescere",
    "ricrescevamo": "ricrescere",
    "ricrescevan": "ricrescere",
    "ricrescevano": "ricrescere",
    "ricrescevate": "ricrescere",
    "ricrescevi": "ricrescere",
    "ricrescevo": "ricrescere",
    "ricresci": "ricrescere",
    "ricresciamo": "ricrescere",
    "ricresciate": "ricrescere",
    "ricresciuta": "ricrescere",
    "ricresciute": "ricrescere",
    "ricresciuti": "ricrescere",
    "ricresciuto": "ricrescere",
    "ricresco": "ricrescere",
    "ricrescon": "ricrescere",
    "ricrescono": "ricrescere",
    "ricrescè": "ricrescere",
    "ricreò": "ricreare",
    "ricuce": "ricucire",
    "ricucendo": "ricucire",
    "ricucente": "ricucire",
    "ricucenti": "ricucire",
    "ricuci": "ricucire",
    "ricucia": "ricucire",
    "ricuciamo": "ricucire",
    "ricucian": "ricucire",
    "ricuciano": "ricucire",
    "ricuciate": "ricucire",
    "ricucii": "ricucire",
    "ricucimmo": "ricucire",
    "ricucio": "ricucire",
    "ricucion": "ricucire",
    "ricuciono": "ricucire",
    "ricucir": "ricucire",
    "ricucirai": "ricucire",
    "ricuciran": "ricucire",
    "ricuciranno": "ricucire",
    "ricucirebbe": "ricucire",
    "ricucirebber": "ricucire",
    "ricucirebbero": "ricucire",
    "ricucirei": "ricucire",
    "ricuciremmo": "ricucire",
    "ricuciremo": "ricucire",
    "ricucireste": "ricucire",
    "ricuciresti": "ricucire",
    "ricucirete": "ricucire",
    "ricuciron": "ricucire",
    "ricucirono": "ricucire",
    "ricucirà": "ricucire",
    "ricucirò": "ricucire",
    "ricucisse": "ricucire",
    "ricucisser": "ricucire",
    "ricucissero": "ricucire",
    "ricucissi": "ricucire",
    "ricucissimo": "ricucire",
    "ricuciste": "ricucire",
    "ricucisti": "ricucire",
    "ricucita": "ricucire",
    "ricucite": "ricucire",
    "ricuciti": "ricucire",
    "ricucito": "ricucire",
    "ricuciture": "ricucitura",
    "ricuciva": "ricucire",
    "ricucivamo": "ricucire",
    "ricucivan": "ricucire",
    "ricucivano": "ricucire",
    "ricucivate": "ricucire",
    "ricucivi": "ricucire",
    "ricucivo": "ricucire",
    "ricucì": "ricucire",
    "ricuoce": "ricuocere",
    "ricuocei": "ricuocere",
    "ricuocemmo": "ricuocere",
    "ricuocendo": "ricuocere",
    "ricuocer": "ricuocere",
    "ricuocerai": "ricuocere",
    "ricuoceran": "ricuocere",
    "ricuoceranno": "ricuocere",
    "ricuocerebbe": "ricuocere",
    "ricuocerebber": "ricuocere",
    "ricuocerebbero": "ricuocere",
    "ricuocerei": "ricuocere",
    "ricuoceremmo": "ricuocere",
    "ricuoceremo": "ricuocere",
    "ricuocereste": "ricuocere",
    "ricuoceresti": "ricuocere",
    "ricuocerete": "ricuocere",
    "ricuoceron": "ricuocere",
    "ricuocerono": "ricuocere",
    "ricuocerà": "ricuocere",
    "ricuocerò": "ricuocere",
    "ricuocesse": "ricuocere",
    "ricuocesser": "ricuocere",
    "ricuocessero": "ricuocere",
    "ricuocessi": "ricuocere",
    "ricuocessimo": "ricuocere",
    "ricuoceste": "ricuocere",
    "ricuocesti": "ricuocere",
    "ricuocete": "ricuocere",
    "ricuoceva": "ricuocere",
    "ricuocevamo": "ricuocere",
    "ricuocevan": "ricuocere",
    "ricuocevano": "ricuocere",
    "ricuocevate": "ricuocere",
    "ricuocevi": "ricuocere",
    "ricuocevo": "ricuocere",
    "ricuoci": "ricuocere",
    "ricuocia": "ricuocere",
    "ricuociamo": "ricuocere",
    "ricuocian": "ricuocere",
    "ricuociano": "ricuocere",
    "ricuociate": "ricuocere",
    "ricuocio": "ricuocere",
    "ricuocion": "ricuocere",
    "ricuociono": "ricuocere",
    "ricuocè": "ricuocere",
    "ricupera": "ricuperare",
    "ricuperai": "ricuperare",
    "ricuperammo": "ricuperare",
    "ricuperan": "ricuperare",
    "ricuperando": "ricuperare",
    "ricuperano": "ricuperare",
    "ricuperante": "ricuperare",
    "ricuperanti": "ricuperare",
    "ricuperar": "ricuperare",
    "ricuperaron": "ricuperare",
    "ricuperarono": "ricuperare",
    "ricuperasse": "ricuperare",
    "ricuperasser": "ricuperare",
    "ricuperassero": "ricuperare",
    "ricuperassi": "ricuperare",
    "ricuperassimo": "ricuperare",
    "ricuperaste": "ricuperare",
    "ricuperasti": "ricuperare",
    "ricuperata": "ricuperare",
    "ricuperate": "ricuperare",
    "ricuperati": "ricuperare",
    "ricuperato": "ricuperare",
    "ricuperava": "ricuperare",
    "ricuperavamo": "ricuperare",
    "ricuperavan": "ricuperare",
    "ricuperavano": "ricuperare",
    "ricuperavate": "ricuperare",
    "ricuperavi": "ricuperare",
    "ricuperavo": "ricuperare",
    "ricupererai": "ricuperare",
    "ricupereran": "ricuperare",
    "ricupereranno": "ricuperare",
    "ricupererebbe": "ricuperare",
    "ricupererebber": "ricuperare",
    "ricupererebbero": "ricuperare",
    "ricupererei": "ricuperare",
    "ricupereremmo": "ricuperare",
    "ricupereremo": "ricuperare",
    "ricuperereste": "ricuperare",
    "ricupereresti": "ricuperare",
    "ricupererete": "ricuperare",
    "ricupererà": "ricuperare",
    "ricupererò": "ricuperare",
    "ricuperi": "ricupero",
    "ricuperiamo": "ricuperare",
    "ricuperiate": "ricuperare",
    "ricuperin": "ricuperare",
    "ricuperino": "ricuperare",
    "ricupero": "ricuperare",
    "ricuperò": "ricuperare",
    "ricurva": "ricurvo",
    "ricurve": "ricurvo",
    "ricurvi": "ricurvo",
    "ricusa": "ricusare",
    "ricusabili": "ricusabile",
    "ricusai": "ricusare",
    "ricusammo": "ricusare",
    "ricusan": "ricusare",
    "ricusando": "ricusare",
    "ricusano": "ricusare",
    "ricusante": "ricusare",
    "ricusanti": "ricusare",
    "ricusar": "ricusare",
    "ricusaron": "ricusare",
    "ricusarono": "ricusare",
    "ricusasse": "ricusare",
    "ricusasser": "ricusare",
    "ricusassero": "ricusare",
    "ricusassi": "ricusare",
    "ricusassimo": "ricusare",
    "ricusaste": "ricusare",
    "ricusasti": "ricusare",
    "ricusata": "ricusare",
    "ricusate": "ricusare",
    "ricusati": "ricusare",
    "ricusato": "ricusare",
    "ricusava": "ricusare",
    "ricusavamo": "ricusare",
    "ricusavan": "ricusare",
    "ricusavano": "ricusare",
    "ricusavate": "ricusare",
    "ricusavi": "ricusare",
    "ricusavo": "ricusare",
    "ricusazioni": "ricusazione",
    "ricuserai": "ricusare",
    "ricuseran": "ricusare",
    "ricuseranno": "ricusare",
    "ricuserebbe": "ricusare",
    "ricuserebber": "ricusare",
    "ricuserebbero": "ricusare",
    "ricuserei": "ricusare",
    "ricuseremmo": "ricusare",
    "ricuseremo": "ricusare",
    "ricusereste": "ricusare",
    "ricuseresti": "ricusare",
    "ricuserete": "ricusare",
    "ricuserà": "ricusare",
    "ricuserò": "ricusare",
    "ricusi": "ricusare",
    "ricusiamo": "ricusare",
    "ricusiate": "ricusare",
    "ricusin": "ricusare",
    "ricusino": "ricusare",
    "ricuso": "ricusare",
    "ricusò": "ricusare",
    "rida": "ridere",
    "rida'": "ridare",
    "ridacchi": "ridacchiare",
    "ridacchia": "ridacchiare",
    "ridacchiai": "ridacchiare",
    "ridacchiammo": "ridacchiare",
    "ridacchiamo": "ridacchiare",
    "ridacchian": "ridacchiare",
    "ridacchiando": "ridacchiare",
    "ridacchiano": "ridacchiare",
    "ridacchiante": "ridacchiare",
    "ridacchianti": "ridacchiare",
    "ridacchiar": "ridacchiare",
    "ridacchiaron": "ridacchiare",
    "ridacchiarono": "ridacchiare",
    "ridacchiasse": "ridacchiare",
    "ridacchiasser": "ridacchiare",
    "ridacchiassero": "ridacchiare",
    "ridacchiassi": "ridacchiare",
    "ridacchiassimo": "ridacchiare",
    "ridacchiaste": "ridacchiare",
    "ridacchiasti": "ridacchiare",
    "ridacchiata": "ridacchiare",
    "ridacchiate": "ridacchiare",
    "ridacchiati": "ridacchiare",
    "ridacchiato": "ridacchiare",
    "ridacchiava": "ridacchiare",
    "ridacchiavamo": "ridacchiare",
    "ridacchiavan": "ridacchiare",
    "ridacchiavano": "ridacchiare",
    "ridacchiavate": "ridacchiare",
    "ridacchiavi": "ridacchiare",
    "ridacchiavo": "ridacchiare",
    "ridacchierai": "ridacchiare",
    "ridacchieran": "ridacchiare",
    "ridacchieranno": "ridacchiare",
    "ridacchierebbe": "ridacchiare",
    "ridacchierebber": "ridacchiare",
    "ridacchierebbero": "ridacchiare",
    "ridacchierei": "ridacchiare",
    "ridacchieremmo": "ridacchiare",
    "ridacchieremo": "ridacchiare",
    "ridacchiereste": "ridacchiare",
    "ridacchieresti": "ridacchiare",
    "ridacchierete": "ridacchiare",
    "ridacchierà": "ridacchiare",
    "ridacchierò": "ridacchiare",
    "ridacchin": "ridacchiare",
    "ridacchino": "ridacchiare",
    "ridacchio": "ridacchiare",
    "ridacchiò": "ridacchiare",
    "ridai": "ridare",
    "ridan": "ridere",
    "ridanciana": "ridanciano",
    "ridanciane": "ridanciano",
    "ridanciani": "ridanciano",
    "ridando": "ridare",
    "ridanno": "ridare",
    "ridano": "ridere",
    "ridante": "ridare",
    "ridanti": "ridare",
    "ridar": "ridare",
    "ridarai": "ridare",
    "ridaran": "ridare",
    "ridaranno": "ridare",
    "ridarebbe": "ridare",
    "ridarebber": "ridare",
    "ridarebbero": "ridare",
    "ridarei": "ridare",
    "ridaremmo": "ridare",
    "ridaremo": "ridare",
    "ridareste": "ridare",
    "ridaresti": "ridare",
    "ridarete": "ridare",
    "ridarà": "ridare",
    "ridarò": "ridare",
    "ridata": "ridare",
    "ridate": "ridare",
    "ridati": "ridare",
    "ridato": "ridare",
    "ridava": "ridare",
    "ridavamo": "ridare",
    "ridavan": "ridare",
    "ridavano": "ridare",
    "ridavate": "ridare",
    "ridavi": "ridare",
    "ridavo": "ridare",
    "ridde": "ridda",
    "ride": "ridere",
    "ridefina": "ridefinire",
    "ridefinan": "ridefinire",
    "ridefinano": "ridefinire",
    "ridefine": "ridefinire",
    "ridefinendo": "ridefinire",
    "ridefinente": "ridefinire",
    "ridefinenti": "ridefinire",
    "ridefini": "ridefinire",
    "ridefiniamo": "ridefinire",
    "ridefiniate": "ridefinire",
    "ridefinii": "ridefinire",
    "ridefinimmo": "ridefinire",
    "ridefinir": "ridefinire",
    "ridefinirai": "ridefinire",
    "ridefiniran": "ridefinire",
    "ridefiniranno": "ridefinire",
    "ridefinirebbe": "ridefinire",
    "ridefinirebber": "ridefinire",
    "ridefinirebbero": "ridefinire",
    "ridefinirei": "ridefinire",
    "ridefiniremmo": "ridefinire",
    "ridefiniremo": "ridefinire",
    "ridefinireste": "ridefinire",
    "ridefiniresti": "ridefinire",
    "ridefinirete": "ridefinire",
    "ridefiniron": "ridefinire",
    "ridefinirono": "ridefinire",
    "ridefinirà": "ridefinire",
    "ridefinirò": "ridefinire",
    "ridefinisse": "ridefinire",
    "ridefinisser": "ridefinire",
    "ridefinissero": "ridefinire",
    "ridefinissi": "ridefinire",
    "ridefinissimo": "ridefinire",
    "ridefiniste": "ridefinire",
    "ridefinisti": "ridefinire",
    "ridefinita": "ridefinire",
    "ridefinite": "ridefinire",
    "ridefiniti": "ridefinire",
    "ridefinito": "ridefinire",
    "ridefiniva": "ridefinire",
    "ridefinivamo": "ridefinire",
    "ridefinivan": "ridefinire",
    "ridefinivano": "ridefinire",
    "ridefinivate": "ridefinire",
    "ridefinivi": "ridefinire",
    "ridefinivo": "ridefinire",
    "ridefinizioni": "ridefinizione",
    "ridefino": "ridefinire",
    "ridefinon": "ridefinire",
    "ridefinono": "ridefinire",
    "ridefinì": "ridefinire",
    "ridemmo": "ridere",
    "ridendo": "ridere",
    "ridente": "ridere",
    "ridenti": "ridere",
    "rider": "ridere",
    "riderai": "ridere",
    "rideran": "ridere",
    "rideranno": "ridere",
    "riderebbe": "ridere",
    "riderebber": "ridere",
    "riderebbero": "ridere",
    "riderei": "ridere",
    "rideremmo": "ridere",
    "rideremo": "ridere",
    "ridereste": "ridere",
    "rideresti": "ridere",
    "riderete": "ridere",
    "riderà": "ridere",
    "riderò": "ridere",
    "ridesse": "ridere",
    "ridesser": "ridere",
    "ridessero": "ridere",
    "ridessi": "ridere",
    "ridessimo": "ridere",
    "ridesta": "ridestare",
    "ridestai": "ridestare",
    "ridestammo": "ridestare",
    "ridestan": "ridestare",
    "ridestando": "ridestare",
    "ridestano": "ridestare",
    "ridestante": "ridestare",
    "ridestanti": "ridestare",
    "ridestar": "ridestare",
    "ridestaron": "ridestare",
    "ridestarono": "ridestare",
    "ridestasse": "ridestare",
    "ridestasser": "ridestare",
    "ridestassero": "ridestare",
    "ridestassi": "ridestare",
    "ridestassimo": "ridestare",
    "ridestaste": "ridestare",
    "ridestasti": "ridestare",
    "ridestata": "ridestare",
    "ridestate": "ridestare",
    "ridestati": "ridestare",
    "ridestato": "ridestare",
    "ridestava": "ridestare",
    "ridestavamo": "ridestare",
    "ridestavan": "ridestare",
    "ridestavano": "ridestare",
    "ridestavate": "ridestare",
    "ridestavi": "ridestare",
    "ridestavo": "ridestare",
    "rideste": "ridere",
    "ridesterai": "ridestare",
    "ridesteran": "ridestare",
    "ridesteranno": "ridestare",
    "ridesterebbe": "ridestare",
    "ridesterebber": "ridestare",
    "ridesterebbero": "ridestare",
    "ridesterei": "ridestare",
    "ridesteremmo": "ridestare",
    "ridesteremo": "ridestare",
    "ridestereste": "ridestare",
    "ridesteresti": "ridestare",
    "ridesterete": "ridestare",
    "ridesterà": "ridestare",
    "ridesterò": "ridestare",
    "ridesti": "ridestare",
    "ridestiamo": "ridestare",
    "ridestiate": "ridestare",
    "ridestin": "ridestare",
    "ridestino": "ridestare",
    "ridesto": "ridestare",
    "ridestò": "ridestare",
    "ridete": "ridere",
    "ridetta": "ridire",
    "ridette": "ridire",
    "ridetter": "ridare",
    "ridettero": "ridare",
    "ridetti": "ridire",
    "ridetto": "ridire",
    "rideva": "ridere",
    "ridevamo": "ridere",
    "ridevan": "ridere",
    "ridevano": "ridere",
    "ridevate": "ridere",
    "ridevi": "ridere",
    "ridevo": "ridere",
    "ridi": "ridere",
    "ridi'": "ridire",
    "ridia": "ridare",
    "ridiamo": "ridere",
    "ridian": "ridare",
    "ridiano": "ridare",
    "ridiate": "ridere",
    "ridica": "ridire",
    "ridican": "ridire",
    "ridicano": "ridire",
    "ridice": "ridire",
    "ridicemmo": "ridire",
    "ridicendo": "ridire",
    "ridicente": "ridire",
    "ridicenti": "ridire",
    "ridicesse": "ridire",
    "ridicesser": "ridire",
    "ridicessero": "ridire",
    "ridicessi": "ridire",
    "ridicessimo": "ridire",
    "ridiceste": "ridire",
    "ridicesti": "ridire",
    "ridiceva": "ridire",
    "ridicevamo": "ridire",
    "ridicevan": "ridire",
    "ridicevano": "ridire",
    "ridicevate": "ridire",
    "ridicevi": "ridire",
    "ridicevo": "ridire",
    "ridici": "ridire",
    "ridiciamo": "ridire",
    "ridiciate": "ridire",
    "ridico": "ridire",
    "ridicola": "ridicolo",
    "ridicolaggini": "ridicolaggine",
    "ridicole": "ridicolo",
    "ridicoli": "ridicolo",
    "ridicolizza": "ridicolizzare",
    "ridicolizzai": "ridicolizzare",
    "ridicolizzammo": "ridicolizzare",
    "ridicolizzan": "ridicolizzare",
    "ridicolizzando": "ridicolizzare",
    "ridicolizzano": "ridicolizzare",
    "ridicolizzante": "ridicolizzare",
    "ridicolizzanti": "ridicolizzare",
    "ridicolizzar": "ridicolizzare",
    "ridicolizzaron": "ridicolizzare",
    "ridicolizzarono": "ridicolizzare",
    "ridicolizzasse": "ridicolizzare",
    "ridicolizzasser": "ridicolizzare",
    "ridicolizzassero": "ridicolizzare",
    "ridicolizzassi": "ridicolizzare",
    "ridicolizzassimo": "ridicolizzare",
    "ridicolizzaste": "ridicolizzare",
    "ridicolizzasti": "ridicolizzare",
    "ridicolizzata": "ridicolizzare",
    "ridicolizzate": "ridicolizzare",
    "ridicolizzati": "ridicolizzare",
    "ridicolizzato": "ridicolizzare",
    "ridicolizzava": "ridicolizzare",
    "ridicolizzavamo": "ridicolizzare",
    "ridicolizzavan": "ridicolizzare",
    "ridicolizzavano": "ridicolizzare",
    "ridicolizzavate": "ridicolizzare",
    "ridicolizzavi": "ridicolizzare",
    "ridicolizzavo": "ridicolizzare",
    "ridicolizzerai": "ridicolizzare",
    "ridicolizzeran": "ridicolizzare",
    "ridicolizzeranno": "ridicolizzare",
    "ridicolizzerebbe": "ridicolizzare",
    "ridicolizzerebber": "ridicolizzare",
    "ridicolizzerebbero": "ridicolizzare",
    "ridicolizzerei": "ridicolizzare",
    "ridicolizzeremmo": "ridicolizzare",
    "ridicolizzeremo": "ridicolizzare",
    "ridicolizzereste": "ridicolizzare",
    "ridicolizzeresti": "ridicolizzare",
    "ridicolizzerete": "ridicolizzare",
    "ridicolizzerà": "ridicolizzare",
    "ridicolizzerò": "ridicolizzare",
    "ridicolizzi": "ridicolizzare",
    "ridicolizziamo": "ridicolizzare",
    "ridicolizziate": "ridicolizzare",
    "ridicolizzin": "ridicolizzare",
    "ridicolizzino": "ridicolizzare",
    "ridicolizzo": "ridicolizzare",
    "ridicolizzò": "ridicolizzare",
    "ridicon": "ridire",
    "ridicono": "ridire",
    "ridiede": "ridare",
    "ridiedi": "ridare",
    "ridimensiona": "ridimensionare",
    "ridimensionai": "ridimensionare",
    "ridimensionamenti": "ridimensionamento",
    "ridimensionammo": "ridimensionare",
    "ridimensionan": "ridimensionare",
    "ridimensionando": "ridimensionare",
    "ridimensionano": "ridimensionare",
    "ridimensionante": "ridimensionare",
    "ridimensionanti": "ridimensionare",
    "ridimensionar": "ridimensionare",
    "ridimensionaron": "ridimensionare",
    "ridimensionarono": "ridimensionare",
    "ridimensionasse": "ridimensionare",
    "ridimensionasser": "ridimensionare",
    "ridimensionassero": "ridimensionare",
    "ridimensionassi": "ridimensionare",
    "ridimensionassimo": "ridimensionare",
    "ridimensionaste": "ridimensionare",
    "ridimensionasti": "ridimensionare",
    "ridimensionata": "ridimensionare",
    "ridimensionate": "ridimensionare",
    "ridimensionati": "ridimensionare",
    "ridimensionato": "ridimensionare",
    "ridimensionava": "ridimensionare",
    "ridimensionavamo": "ridimensionare",
    "ridimensionavan": "ridimensionare",
    "ridimensionavano": "ridimensionare",
    "ridimensionavate": "ridimensionare",
    "ridimensionavi": "ridimensionare",
    "ridimensionavo": "ridimensionare",
    "ridimensionerai": "ridimensionare",
    "ridimensioneran": "ridimensionare",
    "ridimensioneranno": "ridimensionare",
    "ridimensionerebbe": "ridimensionare",
    "ridimensionerebber": "ridimensionare",
    "ridimensionerebbero": "ridimensionare",
    "ridimensionerei": "ridimensionare",
    "ridimensioneremmo": "ridimensionare",
    "ridimensioneremo": "ridimensionare",
    "ridimensionereste": "ridimensionare",
    "ridimensioneresti": "ridimensionare",
    "ridimensionerete": "ridimensionare",
    "ridimensionerà": "ridimensionare",
    "ridimensionerò": "ridimensionare",
    "ridimensioni": "ridimensionare",
    "ridimensioniamo": "ridimensionare",
    "ridimensioniate": "ridimensionare",
    "ridimensionin": "ridimensionare",
    "ridimensionino": "ridimensionare",
    "ridimensiono": "ridimensionare",
    "ridimensionò": "ridimensionare",
    "ridimostra": "ridimostrare",
    "ridimostrai": "ridimostrare",
    "ridimostrammo": "ridimostrare",
    "ridimostran": "ridimostrare",
    "ridimostrando": "ridimostrare",
    "ridimostrano": "ridimostrare",
    "ridimostrante": "ridimostrare",
    "ridimostranti": "ridimostrare",
    "ridimostrar": "ridimostrare",
    "ridimostraron": "ridimostrare",
    "ridimostrarono": "ridimostrare",
    "ridimostrasse": "ridimostrare",
    "ridimostrasser": "ridimostrare",
    "ridimostrassero": "ridimostrare",
    "ridimostrassi": "ridimostrare",
    "ridimostrassimo": "ridimostrare",
    "ridimostraste": "ridimostrare",
    "ridimostrasti": "ridimostrare",
    "ridimostrata": "ridimostrare",
    "ridimostrate": "ridimostrare",
    "ridimostrati": "ridimostrare",
    "ridimostrato": "ridimostrare",
    "ridimostrava": "ridimostrare",
    "ridimostravamo": "ridimostrare",
    "ridimostravan": "ridimostrare",
    "ridimostravano": "ridimostrare",
    "ridimostravate": "ridimostrare",
    "ridimostravi": "ridimostrare",
    "ridimostravo": "ridimostrare",
    "ridimostrerai": "ridimostrare",
    "ridimostreran": "ridimostrare",
    "ridimostreranno": "ridimostrare",
    "ridimostrerebbe": "ridimostrare",
    "ridimostrerebber": "ridimostrare",
    "ridimostrerebbero": "ridimostrare",
    "ridimostrerei": "ridimostrare",
    "ridimostreremmo": "ridimostrare",
    "ridimostreremo": "ridimostrare",
    "ridimostrereste": "ridimostrare",
    "ridimostreresti": "ridimostrare",
    "ridimostrerete": "ridimostrare",
    "ridimostrerà": "ridimostrare",
    "ridimostrerò": "ridimostrare",
    "ridimostri": "ridimostrare",
    "ridimostriamo": "ridimostrare",
    "ridimostriate": "ridimostrare",
    "ridimostrin": "ridimostrare",
    "ridimostrino": "ridimostrare",
    "ridimostro": "ridimostrare",
    "ridimostrò": "ridimostrare",
    "ridipinga": "ridipingere",
    "ridipingan": "ridipingere",
    "ridipingano": "ridipingere",
    "ridipinge": "ridipingere",
    "ridipingemmo": "ridipingere",
    "ridipingendo": "ridipingere",
    "ridipingente": "ridipingere",
    "ridipingenti": "ridipingere",
    "ridipinger": "ridipingere",
    "ridipingerai": "ridipingere",
    "ridipingeran": "ridipingere",
    "ridipingeranno": "ridipingere",
    "ridipingerebbe": "ridipingere",
    "ridipingerebber": "ridipingere",
    "ridipingerebbero": "ridipingere",
    "ridipingerei": "ridipingere",
    "ridipingeremmo": "ridipingere",
    "ridipingeremo": "ridipingere",
    "ridipingereste": "ridipingere",
    "ridipingeresti": "ridipingere",
    "ridipingerete": "ridipingere",
    "ridipingerà": "ridipingere",
    "ridipingerò": "ridipingere",
    "ridipingesse": "ridipingere",
    "ridipingesser": "ridipingere",
    "ridipingessero": "ridipingere",
    "ridipingessi": "ridipingere",
    "ridipingessimo": "ridipingere",
    "ridipingeste": "ridipingere",
    "ridipingesti": "ridipingere",
    "ridipingete": "ridipingere",
    "ridipingeva": "ridipingere",
    "ridipingevamo": "ridipingere",
    "ridipingevan": "ridipingere",
    "ridipingevano": "ridipingere",
    "ridipingevate": "ridipingere",
    "ridipingevi": "ridipingere",
    "ridipingevo": "ridipingere",
    "ridipingi": "ridipingere",
    "ridipingiamo": "ridipingere",
    "ridipingiate": "ridipingere",
    "ridipingo": "ridipingere",
    "ridipingon": "ridipingere",
    "ridipingono": "ridipingere",
    "ridipinser": "ridipingere",
    "ridipinsero": "ridipingere",
    "ridipinsi": "ridipingere",
    "ridipinsè": "ridipingere",
    "ridipinta": "ridipingere",
    "ridipinte": "ridipingere",
    "ridipinti": "ridipingere",
    "ridipinto": "ridipingere",
    "ridipinture": "ridipintura",
    "ridir": "ridire",
    "ridirai": "ridire",
    "ridiran": "ridire",
    "ridiranno": "ridire",
    "ridirebbe": "ridire",
    "ridirebber": "ridire",
    "ridirebbero": "ridire",
    "ridirei": "ridire",
    "ridiremmo": "ridire",
    "ridiremo": "ridire",
    "ridireste": "ridire",
    "ridiresti": "ridire",
    "ridirete": "ridire",
    "ridirà": "ridire",
    "ridirò": "ridire",
    "ridiscenda": "ridiscendere",
    "ridiscendan": "ridiscendere",
    "ridiscendano": "ridiscendere",
    "ridiscende": "ridiscendere",
    "ridiscendemmo": "ridiscendere",
    "ridiscendendo": "ridiscendere",
    "ridiscendente": "ridiscendere",
    "ridiscendenti": "ridiscendere",
    "ridiscender": "ridiscendere",
    "ridiscenderai": "ridiscendere",
    "ridiscenderan": "ridiscendere",
    "ridiscenderanno": "ridiscendere",
    "ridiscenderebbe": "ridiscendere",
    "ridiscenderebber": "ridiscendere",
    "ridiscenderebbero": "ridiscendere",
    "ridiscenderei": "ridiscendere",
    "ridiscenderemmo": "ridiscendere",
    "ridiscenderemo": "ridiscendere",
    "ridiscendereste": "ridiscendere",
    "ridiscenderesti": "ridiscendere",
    "ridiscenderete": "ridiscendere",
    "ridiscenderà": "ridiscendere",
    "ridiscenderò": "ridiscendere",
    "ridiscendesse": "ridiscendere",
    "ridiscendesser": "ridiscendere",
    "ridiscendessero": "ridiscendere",
    "ridiscendessi": "ridiscendere",
    "ridiscendessimo": "ridiscendere",
    "ridiscendeste": "ridiscendere",
    "ridiscendesti": "ridiscendere",
    "ridiscendete": "ridiscendere",
    "ridiscendeva": "ridiscendere",
    "ridiscendevamo": "ridiscendere",
    "ridiscendevan": "ridiscendere",
    "ridiscendevano": "ridiscendere",
    "ridiscendevate": "ridiscendere",
    "ridiscendevi": "ridiscendere",
    "ridiscendevo": "ridiscendere",
    "ridiscendi": "ridiscendere",
    "ridiscendiamo": "ridiscendere",
    "ridiscendiate": "ridiscendere",
    "ridiscendo": "ridiscendere",
    "ridiscendon": "ridiscendere",
    "ridiscendono": "ridiscendere",
    "ridiscesa": "ridiscendere",
    "ridiscese": "ridiscendere",
    "ridisceser": "ridiscendere",
    "ridiscesero": "ridiscendere",
    "ridiscesi": "ridiscendere",
    "ridisceso": "ridiscendere",
    "ridiscesè": "ridiscendere",
    "ridiscorra": "ridiscorrere",
    "ridiscorran": "ridiscorrere",
    "ridiscorrano": "ridiscorrere",
    "ridiscorre": "ridiscorrere",
    "ridiscorrei": "ridiscorrere",
    "ridiscorremmo": "ridiscorrere",
    "ridiscorrendo": "ridiscorrere",
    "ridiscorrente": "ridiscorrere",
    "ridiscorrenti": "ridiscorrere",
    "ridiscorrer": "ridiscorrere",
    "ridiscorrerai": "ridiscorrere",
    "ridiscorreran": "ridiscorrere",
    "ridiscorreranno": "ridiscorrere",
    "ridiscorrerebbe": "ridiscorrere",
    "ridiscorrerebber": "ridiscorrere",
    "ridiscorrerebbero": "ridiscorrere",
    "ridiscorrerei": "ridiscorrere",
    "ridiscorreremmo": "ridiscorrere",
    "ridiscorreremo": "ridiscorrere",
    "ridiscorrereste": "ridiscorrere",
    "ridiscorreresti": "ridiscorrere",
    "ridiscorrerete": "ridiscorrere",
    "ridiscorreron": "ridiscorrere",
    "ridiscorrerono": "ridiscorrere",
    "ridiscorrerà": "ridiscorrere",
    "ridiscorrerò": "ridiscorrere",
    "ridiscorresse": "ridiscorrere",
    "ridiscorresser": "ridiscorrere",
    "ridiscorressero": "ridiscorrere",
    "ridiscorressi": "ridiscorrere",
    "ridiscorressimo": "ridiscorrere",
    "ridiscorreste": "ridiscorrere",
    "ridiscorresti": "ridiscorrere",
    "ridiscorrete": "ridiscorrere",
    "ridiscorreva": "ridiscorrere",
    "ridiscorrevamo": "ridiscorrere",
    "ridiscorrevan": "ridiscorrere",
    "ridiscorrevano": "ridiscorrere",
    "ridiscorrevate": "ridiscorrere",
    "ridiscorrevi": "ridiscorrere",
    "ridiscorrevo": "ridiscorrere",
    "ridiscorri": "ridiscorrere",
    "ridiscorriamo": "ridiscorrere",
    "ridiscorriate": "ridiscorrere",
    "ridiscorro": "ridiscorrere",
    "ridiscorron": "ridiscorrere",
    "ridiscorrono": "ridiscorrere",
    "ridiscorruta": "ridiscorrere",
    "ridiscorrute": "ridiscorrere",
    "ridiscorruti": "ridiscorrere",
    "ridiscorruto": "ridiscorrere",
    "ridiscorrè": "ridiscorrere",
    "ridiscussioni": "ridiscussione",
    "ridiscuta": "ridiscutere",
    "ridiscutan": "ridiscutere",
    "ridiscutano": "ridiscutere",
    "ridiscute": "ridiscutere",
    "ridiscutei": "ridiscutere",
    "ridiscutemmo": "ridiscutere",
    "ridiscutendo": "ridiscutere",
    "ridiscutente": "ridiscutere",
    "ridiscutenti": "ridiscutere",
    "ridiscuter": "ridiscutere",
    "ridiscuterai": "ridiscutere",
    "ridiscuteran": "ridiscutere",
    "ridiscuteranno": "ridiscutere",
    "ridiscuterebbe": "ridiscutere",
    "ridiscuterebber": "ridiscutere",
    "ridiscuterebbero": "ridiscutere",
    "ridiscuterei": "ridiscutere",
    "ridiscuteremmo": "ridiscutere",
    "ridiscuteremo": "ridiscutere",
    "ridiscutereste": "ridiscutere",
    "ridiscuteresti": "ridiscutere",
    "ridiscuterete": "ridiscutere",
    "ridiscuteron": "ridiscutere",
    "ridiscuterono": "ridiscutere",
    "ridiscuterà": "ridiscutere",
    "ridiscuterò": "ridiscutere",
    "ridiscutesse": "ridiscutere",
    "ridiscutesser": "ridiscutere",
    "ridiscutessero": "ridiscutere",
    "ridiscutessi": "ridiscutere",
    "ridiscutessimo": "ridiscutere",
    "ridiscuteste": "ridiscutere",
    "ridiscutesti": "ridiscutere",
    "ridiscutete": "ridiscutere",
    "ridiscuteva": "ridiscutere",
    "ridiscutevamo": "ridiscutere",
    "ridiscutevan": "ridiscutere",
    "ridiscutevano": "ridiscutere",
    "ridiscutevate": "ridiscutere",
    "ridiscutevi": "ridiscutere",
    "ridiscutevo": "ridiscutere",
    "ridiscuti": "ridiscutere",
    "ridiscutiamo": "ridiscutere",
    "ridiscutiate": "ridiscutere",
    "ridiscuto": "ridiscutere",
    "ridiscuton": "ridiscutere",
    "ridiscutono": "ridiscutere",
    "ridiscututa": "ridiscutere",
    "ridiscutute": "ridiscutere",
    "ridiscututi": "ridiscutere",
    "ridiscututo": "ridiscutere",
    "ridiscutè": "ridiscutere",
    "ridisegna": "ridisegnare",
    "ridisegnai": "ridisegnare",
    "ridisegnammo": "ridisegnare",
    "ridisegnan": "ridisegnare",
    "ridisegnando": "ridisegnare",
    "ridisegnano": "ridisegnare",
    "ridisegnante": "ridisegnare",
    "ridisegnanti": "ridisegnare",
    "ridisegnar": "ridisegnare",
    "ridisegnaron": "ridisegnare",
    "ridisegnarono": "ridisegnare",
    "ridisegnasse": "ridisegnare",
    "ridisegnasser": "ridisegnare",
    "ridisegnassero": "ridisegnare",
    "ridisegnassi": "ridisegnare",
    "ridisegnassimo": "ridisegnare",
    "ridisegnaste": "ridisegnare",
    "ridisegnasti": "ridisegnare",
    "ridisegnata": "ridisegnare",
    "ridisegnate": "ridisegnare",
    "ridisegnati": "ridisegnare",
    "ridisegnato": "ridisegnare",
    "ridisegnava": "ridisegnare",
    "ridisegnavamo": "ridisegnare",
    "ridisegnavan": "ridisegnare",
    "ridisegnavano": "ridisegnare",
    "ridisegnavate": "ridisegnare",
    "ridisegnavi": "ridisegnare",
    "ridisegnavo": "ridisegnare",
    "ridisegnerai": "ridisegnare",
    "ridisegneran": "ridisegnare",
    "ridisegneranno": "ridisegnare",
    "ridisegnerebbe": "ridisegnare",
    "ridisegnerebber": "ridisegnare",
    "ridisegnerebbero": "ridisegnare",
    "ridisegnerei": "ridisegnare",
    "ridisegneremmo": "ridisegnare",
    "ridisegneremo": "ridisegnare",
    "ridisegnereste": "ridisegnare",
    "ridisegneresti": "ridisegnare",
    "ridisegnerete": "ridisegnare",
    "ridisegnerà": "ridisegnare",
    "ridisegnerò": "ridisegnare",
    "ridisegni": "ridisegno",
    "ridisegniamo": "ridisegnare",
    "ridisegniate": "ridisegnare",
    "ridisegnin": "ridisegnare",
    "ridisegnino": "ridisegnare",
    "ridisegno": "ridisegnare",
    "ridisegnò": "ridisegnare",
    "ridisse": "ridire",
    "ridisser": "ridire",
    "ridissero": "ridire",
    "ridissi": "ridire",
    "ridistribuendo": "ridistribuire",
    "ridistribuente": "ridistribuire",
    "ridistribuenti": "ridistribuire",
    "ridistribuiamo": "ridistribuire",
    "ridistribuiate": "ridistribuire",
    "ridistribuii": "ridistribuire",
    "ridistribuimmo": "ridistribuire",
    "ridistribuir": "ridistribuire",
    "ridistribuirai": "ridistribuire",
    "ridistribuiran": "ridistribuire",
    "ridistribuiranno": "ridistribuire",
    "ridistribuirebbe": "ridistribuire",
    "ridistribuirebber": "ridistribuire",
    "ridistribuirebbero": "ridistribuire",
    "ridistribuirei": "ridistribuire",
    "ridistribuiremmo": "ridistribuire",
    "ridistribuiremo": "ridistribuire",
    "ridistribuireste": "ridistribuire",
    "ridistribuiresti": "ridistribuire",
    "ridistribuirete": "ridistribuire",
    "ridistribuiron": "ridistribuire",
    "ridistribuirono": "ridistribuire",
    "ridistribuirà": "ridistribuire",
    "ridistribuirò": "ridistribuire",
    "ridistribuisca": "ridistribuire",
    "ridistribuiscan": "ridistribuire",
    "ridistribuiscano": "ridistribuire",
    "ridistribuisce": "ridistribuire",
    "ridistribuisci": "ridistribuire",
    "ridistribuisco": "ridistribuire",
    "ridistribuiscon": "ridistribuire",
    "ridistribuiscono": "ridistribuire",
    "ridistribuisse": "ridistribuire",
    "ridistribuisser": "ridistribuire",
    "ridistribuissero": "ridistribuire",
    "ridistribuissi": "ridistribuire",
    "ridistribuissimo": "ridistribuire",
    "ridistribuiste": "ridistribuire",
    "ridistribuisti": "ridistribuire",
    "ridistribuita": "ridistribuire",
    "ridistribuite": "ridistribuire",
    "ridistribuiti": "ridistribuire",
    "ridistribuito": "ridistribuire",
    "ridistribuiva": "ridistribuire",
    "ridistribuivamo": "ridistribuire",
    "ridistribuivan": "ridistribuire",
    "ridistribuivano": "ridistribuire",
    "ridistribuivate": "ridistribuire",
    "ridistribuivi": "ridistribuire",
    "ridistribuivo": "ridistribuire",
    "ridistribuzioni": "ridistribuzione",
    "ridistribuì": "ridistribuire",
    "ridite": "ridire",
    "ridiventa": "ridiventare",
    "ridiventai": "ridiventare",
    "ridiventammo": "ridiventare",
    "ridiventan": "ridiventare",
    "ridiventando": "ridiventare",
    "ridiventano": "ridiventare",
    "ridiventante": "ridiventare",
    "ridiventanti": "ridiventare",
    "ridiventar": "ridiventare",
    "ridiventaron": "ridiventare",
    "ridiventarono": "ridiventare",
    "ridiventasse": "ridiventare",
    "ridiventasser": "ridiventare",
    "ridiventassero": "ridiventare",
    "ridiventassi": "ridiventare",
    "ridiventassimo": "ridiventare",
    "ridiventaste": "ridiventare",
    "ridiventasti": "ridiventare",
    "ridiventata": "ridiventare",
    "ridiventate": "ridiventare",
    "ridiventati": "ridiventare",
    "ridiventato": "ridiventare",
    "ridiventava": "ridiventare",
    "ridiventavamo": "ridiventare",
    "ridiventavan": "ridiventare",
    "ridiventavano": "ridiventare",
    "ridiventavate": "ridiventare",
    "ridiventavi": "ridiventare",
    "ridiventavo": "ridiventare",
    "ridiventerai": "ridiventare",
    "ridiventeran": "ridiventare",
    "ridiventeranno": "ridiventare",
    "ridiventerebbe": "ridiventare",
    "ridiventerebber": "ridiventare",
    "ridiventerebbero": "ridiventare",
    "ridiventerei": "ridiventare",
    "ridiventeremmo": "ridiventare",
    "ridiventeremo": "ridiventare",
    "ridiventereste": "ridiventare",
    "ridiventeresti": "ridiventare",
    "ridiventerete": "ridiventare",
    "ridiventerà": "ridiventare",
    "ridiventerò": "ridiventare",
    "ridiventi": "ridiventare",
    "ridiventiamo": "ridiventare",
    "ridiventiate": "ridiventare",
    "ridiventin": "ridiventare",
    "ridiventino": "ridiventare",
    "ridivento": "ridiventare",
    "ridiventò": "ridiventare",
    "rido": "ridere",
    "ridomanda": "ridomandare",
    "ridomandai": "ridomandare",
    "ridomandammo": "ridomandare",
    "ridomandan": "ridomandare",
    "ridomandando": "ridomandare",
    "ridomandano": "ridomandare",
    "ridomandante": "ridomandare",
    "ridomandanti": "ridomandare",
    "ridomandar": "ridomandare",
    "ridomandaron": "ridomandare",
    "ridomandarono": "ridomandare",
    "ridomandasse": "ridomandare",
    "ridomandasser": "ridomandare",
    "ridomandassero": "ridomandare",
    "ridomandassi": "ridomandare",
    "ridomandassimo": "ridomandare",
    "ridomandaste": "ridomandare",
    "ridomandasti": "ridomandare",
    "ridomandata": "ridomandare",
    "ridomandate": "ridomandare",
    "ridomandati": "ridomandare",
    "ridomandato": "ridomandare",
    "ridomandava": "ridomandare",
    "ridomandavamo": "ridomandare",
    "ridomandavan": "ridomandare",
    "ridomandavano": "ridomandare",
    "ridomandavate": "ridomandare",
    "ridomandavi": "ridomandare",
    "ridomandavo": "ridomandare",
    "ridomanderai": "ridomandare",
    "ridomanderan": "ridomandare",
    "ridomanderanno": "ridomandare",
    "ridomanderebbe": "ridomandare",
    "ridomanderebber": "ridomandare",
    "ridomanderebbero": "ridomandare",
    "ridomanderei": "ridomandare",
    "ridomanderemmo": "ridomandare",
    "ridomanderemo": "ridomandare",
    "ridomandereste": "ridomandare",
    "ridomanderesti": "ridomandare",
    "ridomanderete": "ridomandare",
    "ridomanderà": "ridomandare",
    "ridomanderò": "ridomandare",
    "ridomandi": "ridomandare",
    "ridomandiamo": "ridomandare",
    "ridomandiate": "ridomandare",
    "ridomandin": "ridomandare",
    "ridomandino": "ridomandare",
    "ridomando": "ridomandare",
    "ridomandò": "ridomandare",
    "ridon": "ridere",
    "ridona": "ridonare",
    "ridonai": "ridonare",
    "ridonammo": "ridonare",
    "ridonan": "ridonare",
    "ridonando": "ridonare",
    "ridonano": "ridonare",
    "ridonante": "ridonare",
    "ridonanti": "ridonare",
    "ridonar": "ridonare",
    "ridonaron": "ridonare",
    "ridonarono": "ridonare",
    "ridonasse": "ridonare",
    "ridonasser": "ridonare",
    "ridonassero": "ridonare",
    "ridonassi": "ridonare",
    "ridonassimo": "ridonare",
    "ridonaste": "ridonare",
    "ridonasti": "ridonare",
    "ridonata": "ridonare",
    "ridonate": "ridonare",
    "ridonati": "ridonare",
    "ridonato": "ridonare",
    "ridonava": "ridonare",
    "ridonavamo": "ridonare",
    "ridonavan": "ridonare",
    "ridonavano": "ridonare",
    "ridonavate": "ridonare",
    "ridonavi": "ridonare",
    "ridonavo": "ridonare",
    "ridonda": "ridondare",
    "ridondai": "ridondare",
    "ridondammo": "ridondare",
    "ridondan": "ridondare",
    "ridondando": "ridondare",
    "ridondano": "ridondare",
    "ridondante": "ridondare",
    "ridondanti": "ridondare",
    "ridondanze": "ridondanza",
    "ridondar": "ridondare",
    "ridondaron": "ridondare",
    "ridondarono": "ridondare",
    "ridondasse": "ridondare",
    "ridondasser": "ridondare",
    "ridondassero": "ridondare",
    "ridondassi": "ridondare",
    "ridondassimo": "ridondare",
    "ridondaste": "ridondare",
    "ridondasti": "ridondare",
    "ridondata": "ridondare",
    "ridondate": "ridondare",
    "ridondati": "ridondare",
    "ridondato": "ridondare",
    "ridondava": "ridondare",
    "ridondavamo": "ridondare",
    "ridondavan": "ridondare",
    "ridondavano": "ridondare",
    "ridondavate": "ridondare",
    "ridondavi": "ridondare",
    "ridondavo": "ridondare",
    "ridonderai": "ridondare",
    "ridonderan": "ridondare",
    "ridonderanno": "ridondare",
    "ridonderebbe": "ridondare",
    "ridonderebber": "ridondare",
    "ridonderebbero": "ridondare",
    "ridonderei": "ridondare",
    "ridonderemmo": "ridondare",
    "ridonderemo": "ridondare",
    "ridondereste": "ridondare",
    "ridonderesti": "ridondare",
    "ridonderete": "ridondare",
    "ridonderà": "ridondare",
    "ridonderò": "ridondare",
    "ridondi": "ridondare",
    "ridondiamo": "ridondare",
    "ridondiate": "ridondare",
    "ridondin": "ridondare",
    "ridondino": "ridondare",
    "ridondo": "ridondare",
    "ridondò": "ridondare",
    "ridonerai": "ridonare",
    "ridoneran": "ridonare",
    "ridoneranno": "ridonare",
    "ridonerebbe": "ridonare",
    "ridonerebber": "ridonare",
    "ridonerebbero": "ridonare",
    "ridonerei": "ridonare",
    "ridoneremmo": "ridonare",
    "ridoneremo": "ridonare",
    "ridonereste": "ridonare",
    "ridoneresti": "ridonare",
    "ridonerete": "ridonare",
    "ridonerà": "ridonare",
    "ridonerò": "ridonare",
    "ridoni": "ridonare",
    "ridoniamo": "ridonare",
    "ridoniate": "ridonare",
    "ridonin": "ridonare",
    "ridonino": "ridonare",
    "ridono": "ridonare",
    "ridonò": "ridonare",
    "ridotta": "ridurre",
    "ridotte": "ridurre",
    "ridotti": "ridurre",
    "ridotto": "ridurre",
    "riduca": "ridurre",
    "riducan": "ridurre",
    "riducano": "ridurre",
    "riduce": "ridurre",
    "riducemmo": "ridurre",
    "riducendo": "ridurre",
    "riducente": "ridurre",
    "riducenti": "ridurre",
    "riducesse": "ridurre",
    "riducesser": "ridurre",
    "riducessero": "ridurre",
    "riducessi": "ridurre",
    "riducessimo": "ridurre",
    "riduceste": "ridurre",
    "riducesti": "ridurre",
    "riducete": "ridurre",
    "riduceva": "ridurre",
    "riducevamo": "ridurre",
    "riducevan": "ridurre",
    "riducevano": "ridurre",
    "riducevate": "ridurre",
    "riducevi": "ridurre",
    "riducevo": "ridurre",
    "riduci": "ridurre",
    "riduciamo": "ridurre",
    "riduciate": "ridurre",
    "riducibili": "riducibile",
    "riduco": "ridurre",
    "riducon": "ridurre",
    "riducono": "ridurre",
    "ridurr": "ridurre",
    "ridurrai": "ridurre",
    "ridurran": "ridurre",
    "ridurranno": "ridurre",
    "ridurrebbe": "ridurre",
    "ridurrebber": "ridurre",
    "ridurrebbero": "ridurre",
    "ridurrei": "ridurre",
    "ridurremmo": "ridurre",
    "ridurremo": "ridurre",
    "ridurreste": "ridurre",
    "ridurresti": "ridurre",
    "ridurrete": "ridurre",
    "ridurrà": "ridurre",
    "ridurrò": "ridurre",
    "ridusse": "ridurre",
    "ridusser": "ridurre",
    "ridussero": "ridurre",
    "ridussi": "ridurre",
    "riduttiva": "riduttivo",
    "riduttive": "riduttivo",
    "riduttivi": "riduttivo",
    "riduttori": "riduttore",
    "riduzioni": "riduzione",
    "riduzionismi": "riduzionismo",
    "ridà": "ridare",
    "ridì": "ridire",
    "ridò": "ridare",
    "rie": "rio",
    "riebbe": "riavere",
    "riebber": "riavere",
    "riebbero": "riavere",
    "riebbi": "riavere",
    "riecheggerai": "riecheggiare",
    "riecheggeran": "riecheggiare",
    "riecheggeranno": "riecheggiare",
    "riecheggerebbe": "riecheggiare",
    "riecheggerebber": "riecheggiare",
    "riecheggerebbero": "riecheggiare",
    "riecheggerei": "riecheggiare",
    "riecheggeremmo": "riecheggiare",
    "riecheggeremo": "riecheggiare",
    "riecheggereste": "riecheggiare",
    "riecheggeresti": "riecheggiare",
    "riecheggerete": "riecheggiare",
    "riecheggerà": "riecheggiare",
    "riecheggerò": "riecheggiare",
    "riecheggi": "riecheggiare",
    "riecheggia": "riecheggiare",
    "riecheggiai": "riecheggiare",
    "riecheggiammo": "riecheggiare",
    "riecheggiamo": "riecheggiare",
    "riecheggian": "riecheggiare",
    "riecheggiando": "riecheggiare",
    "riecheggiano": "riecheggiare",
    "riecheggiante": "riecheggiare",
    "riecheggianti": "riecheggiare",
    "riecheggiar": "riecheggiare",
    "riecheggiaron": "riecheggiare",
    "riecheggiarono": "riecheggiare",
    "riecheggiasse": "riecheggiare",
    "riecheggiasser": "riecheggiare",
    "riecheggiassero": "riecheggiare",
    "riecheggiassi": "riecheggiare",
    "riecheggiassimo": "riecheggiare",
    "riecheggiaste": "riecheggiare",
    "riecheggiasti": "riecheggiare",
    "riecheggiata": "riecheggiare",
    "riecheggiate": "riecheggiare",
    "riecheggiati": "riecheggiare",
    "riecheggiato": "riecheggiare",
    "riecheggiava": "riecheggiare",
    "riecheggiavamo": "riecheggiare",
    "riecheggiavan": "riecheggiare",
    "riecheggiavano": "riecheggiare",
    "riecheggiavate": "riecheggiare",
    "riecheggiavi": "riecheggiare",
    "riecheggiavo": "riecheggiare",
    "riecheggin": "riecheggiare",
    "riecheggino": "riecheggiare",
    "riecheggio": "riecheggiare",
    "riecheggiò": "riecheggiare",
    "rieda": "riedere",
    "riedan": "riedere",
    "riedano": "riedere",
    "riede": "riedere",
    "riedei": "riedere",
    "riedemmo": "riedere",
    "riedendo": "riedere",
    "riedente": "riedere",
    "riedenti": "riedere",
    "rieder": "riedere",
    "riederai": "riedere",
    "riederan": "riedere",
    "riederanno": "riedere",
    "riederebbe": "riedere",
    "riederebber": "riedere",
    "riederebbero": "riedere",
    "riederei": "riedere",
    "riederemmo": "riedere",
    "riederemo": "riedere",
    "riedereste": "riedere",
    "riederesti": "riedere",
    "riederete": "riedere",
    "riederon": "riedere",
    "riederono": "riedere",
    "riederà": "riedere",
    "riederò": "riedere",
    "riedesse": "riedere",
    "riedesser": "riedere",
    "riedessero": "riedere",
    "riedessi": "riedere",
    "riedessimo": "riedere",
    "riedeste": "riedere",
    "riedesti": "riedere",
    "riedete": "riedere",
    "riedeva": "riedere",
    "riedevamo": "riedere",
    "riedevan": "riedere",
    "riedevano": "riedere",
    "riedevate": "riedere",
    "riedevi": "riedere",
    "riedevo": "riedere",
    "riedi": "riedere",
    "riediamo": "riedere",
    "riediate": "riedere",
    "riedifica": "riedificare",
    "riedificai": "riedificare",
    "riedificammo": "riedificare",
    "riedifican": "riedificare",
    "riedificando": "riedificare",
    "riedificano": "riedificare",
    "riedificante": "riedificare",
    "riedificanti": "riedificare",
    "riedificar": "riedificare",
    "riedificaron": "riedificare",
    "riedificarono": "riedificare",
    "riedificasse": "riedificare",
    "riedificasser": "riedificare",
    "riedificassero": "riedificare",
    "riedificassi": "riedificare",
    "riedificassimo": "riedificare",
    "riedificaste": "riedificare",
    "riedificasti": "riedificare",
    "riedificata": "riedificare",
    "riedificate": "riedificare",
    "riedificati": "riedificare",
    "riedificato": "riedificare",
    "riedificava": "riedificare",
    "riedificavamo": "riedificare",
    "riedificavan": "riedificare",
    "riedificavano": "riedificare",
    "riedificavate": "riedificare",
    "riedificavi": "riedificare",
    "riedificavo": "riedificare",
    "riedificherai": "riedificare",
    "riedificheran": "riedificare",
    "riedificheranno": "riedificare",
    "riedificherebbe": "riedificare",
    "riedificherebber": "riedificare",
    "riedificherebbero": "riedificare",
    "riedificherei": "riedificare",
    "riedificheremmo": "riedificare",
    "riedificheremo": "riedificare",
    "riedifichereste": "riedificare",
    "riedificheresti": "riedificare",
    "riedificherete": "riedificare",
    "riedificherà": "riedificare",
    "riedificherò": "riedificare",
    "riedifichi": "riedificare",
    "riedifichiamo": "riedificare",
    "riedifichiate": "riedificare",
    "riedifichin": "riedificare",
    "riedifichino": "riedificare",
    "riedifico": "riedificare",
    "riedificò": "riedificare",
    "riedizioni": "riedizione",
    "riedo": "riedere",
    "riedon": "riedere",
    "riedono": "riedere",
    "rieduca": "rieducare",
    "rieducai": "rieducare",
    "rieducammo": "rieducare",
    "rieducan": "rieducare",
    "rieducando": "rieducare",
    "rieducano": "rieducare",
    "rieducante": "rieducare",
    "rieducanti": "rieducare",
    "rieducar": "rieducare",
    "rieducaron": "rieducare",
    "rieducarono": "rieducare",
    "rieducasse": "rieducare",
    "rieducasser": "rieducare",
    "rieducassero": "rieducare",
    "rieducassi": "rieducare",
    "rieducassimo": "rieducare",
    "rieducaste": "rieducare",
    "rieducasti": "rieducare",
    "rieducata": "rieducare",
    "rieducate": "rieducare",
    "rieducati": "rieducare",
    "rieducato": "rieducare",
    "rieducava": "rieducare",
    "rieducavamo": "rieducare",
    "rieducavan": "rieducare",
    "rieducavano": "rieducare",
    "rieducavate": "rieducare",
    "rieducavi": "rieducare",
    "rieducavo": "rieducare",
    "rieducazioni": "rieducazione",
    "rieducherai": "rieducare",
    "rieducheran": "rieducare",
    "rieducheranno": "rieducare",
    "rieducherebbe": "rieducare",
    "rieducherebber": "rieducare",
    "rieducherebbero": "rieducare",
    "rieducherei": "rieducare",
    "rieducheremmo": "rieducare",
    "rieducheremo": "rieducare",
    "rieduchereste": "rieducare",
    "rieducheresti": "rieducare",
    "rieducherete": "rieducare",
    "rieducherà": "rieducare",
    "rieducherò": "rieducare",
    "rieduchi": "rieducare",
    "rieduchiamo": "rieducare",
    "rieduchiate": "rieducare",
    "rieduchin": "rieducare",
    "rieduchino": "rieducare",
    "rieduco": "rieducare",
    "rieducò": "rieducare",
    "rieduta": "riedere",
    "riedute": "riedere",
    "rieduti": "riedere",
    "rieduto": "riedere",
    "riedè": "riedere",
    "rielabora": "rielaborare",
    "rielaborai": "rielaborare",
    "rielaborammo": "rielaborare",
    "rielaboran": "rielaborare",
    "rielaborando": "rielaborare",
    "rielaborano": "rielaborare",
    "rielaborante": "rielaborare",
    "rielaboranti": "rielaborare",
    "rielaborar": "rielaborare",
    "rielaboraron": "rielaborare",
    "rielaborarono": "rielaborare",
    "rielaborasse": "rielaborare",
    "rielaborasser": "rielaborare",
    "rielaborassero": "rielaborare",
    "rielaborassi": "rielaborare",
    "rielaborassimo": "rielaborare",
    "rielaboraste": "rielaborare",
    "rielaborasti": "rielaborare",
    "rielaborata": "rielaborare",
    "rielaborate": "rielaborare",
    "rielaborati": "rielaborare",
    "rielaborato": "rielaborare",
    "rielaborava": "rielaborare",
    "rielaboravamo": "rielaborare",
    "rielaboravan": "rielaborare",
    "rielaboravano": "rielaborare",
    "rielaboravate": "rielaborare",
    "rielaboravi": "rielaborare",
    "rielaboravo": "rielaborare",
    "rielaborazioni": "rielaborazione",
    "rielaborerai": "rielaborare",
    "rielaboreran": "rielaborare",
    "rielaboreranno": "rielaborare",
    "rielaborerebbe": "rielaborare",
    "rielaborerebber": "rielaborare",
    "rielaborerebbero": "rielaborare",
    "rielaborerei": "rielaborare",
    "rielaboreremmo": "rielaborare",
    "rielaboreremo": "rielaborare",
    "rielaborereste": "rielaborare",
    "rielaboreresti": "rielaborare",
    "rielaborerete": "rielaborare",
    "rielaborerà": "rielaborare",
    "rielaborerò": "rielaborare",
    "rielabori": "rielaborare",
    "rielaboriamo": "rielaborare",
    "rielaboriate": "rielaborare",
    "rielaborin": "rielaborare",
    "rielaborino": "rielaborare",
    "rielaboro": "rielaborare",
    "rielaborò": "rielaborare",
    "rielegga": "rieleggere",
    "rieleggan": "rieleggere",
    "rieleggano": "rieleggere",
    "rielegge": "rieleggere",
    "rieleggemmo": "rieleggere",
    "rieleggendo": "rieleggere",
    "rieleggente": "rieleggere",
    "rieleggenti": "rieleggere",
    "rielegger": "rieleggere",
    "rieleggerai": "rieleggere",
    "rieleggeran": "rieleggere",
    "rieleggeranno": "rieleggere",
    "rieleggerebbe": "rieleggere",
    "rieleggerebber": "rieleggere",
    "rieleggerebbero": "rieleggere",
    "rieleggerei": "rieleggere",
    "rieleggeremmo": "rieleggere",
    "rieleggeremo": "rieleggere",
    "rieleggereste": "rieleggere",
    "rieleggeresti": "rieleggere",
    "rieleggerete": "rieleggere",
    "rieleggerà": "rieleggere",
    "rieleggerò": "rieleggere",
    "rieleggesse": "rieleggere",
    "rieleggesser": "rieleggere",
    "rieleggessero": "rieleggere",
    "rieleggessi": "rieleggere",
    "rieleggessimo": "rieleggere",
    "rieleggeste": "rieleggere",
    "rieleggesti": "rieleggere",
    "rieleggete": "rieleggere",
    "rieleggeva": "rieleggere",
    "rieleggevamo": "rieleggere",
    "rieleggevan": "rieleggere",
    "rieleggevano": "rieleggere",
    "rieleggevate": "rieleggere",
    "rieleggevi": "rieleggere",
    "rieleggevo": "rieleggere",
    "rieleggi": "rieleggere",
    "rieleggiamo": "rieleggere",
    "rieleggiate": "rieleggere",
    "rieleggibili": "rieleggibile",
    "rieleggo": "rieleggere",
    "rieleggon": "rieleggere",
    "rieleggono": "rieleggere",
    "rielesser": "rieleggere",
    "rielessero": "rieleggere",
    "rielessi": "rieleggere",
    "rielessè": "rieleggere",
    "rieletta": "rieleggere",
    "rielette": "rieleggere",
    "rieletti": "rieleggere",
    "rieletto": "rieleggere",
    "rielezioni": "rielezione",
    "riemerga": "riemergere",
    "riemergan": "riemergere",
    "riemergano": "riemergere",
    "riemerge": "riemergere",
    "riemergemmo": "riemergere",
    "riemergendo": "riemergere",
    "riemergente": "riemergere",
    "riemergenti": "riemergere",
    "riemerger": "riemergere",
    "riemergerai": "riemergere",
    "riemergeran": "riemergere",
    "riemergeranno": "riemergere",
    "riemergerebbe": "riemergere",
    "riemergerebber": "riemergere",
    "riemergerebbero": "riemergere",
    "riemergerei": "riemergere",
    "riemergeremmo": "riemergere",
    "riemergeremo": "riemergere",
    "riemergereste": "riemergere",
    "riemergeresti": "riemergere",
    "riemergerete": "riemergere",
    "riemergerà": "riemergere",
    "riemergerò": "riemergere",
    "riemergesse": "riemergere",
    "riemergesser": "riemergere",
    "riemergessero": "riemergere",
    "riemergessi": "riemergere",
    "riemergessimo": "riemergere",
    "riemergeste": "riemergere",
    "riemergesti": "riemergere",
    "riemergete": "riemergere",
    "riemergeva": "riemergere",
    "riemergevamo": "riemergere",
    "riemergevan": "riemergere",
    "riemergevano": "riemergere",
    "riemergevate": "riemergere",
    "riemergevi": "riemergere",
    "riemergevo": "riemergere",
    "riemergi": "riemergere",
    "riemergiamo": "riemergere",
    "riemergiate": "riemergere",
    "riemergo": "riemergere",
    "riemergon": "riemergere",
    "riemergono": "riemergere",
    "riemersa": "riemergere",
    "riemerse": "riemergere",
    "riemerser": "riemergere",
    "riemersero": "riemergere",
    "riemersi": "riemergere",
    "riemerso": "riemergere",
    "riempa": "riempire",
    "riempan": "riempire",
    "riempano": "riempire",
    "riempe": "riempire",
    "riempendo": "riempire",
    "riempente": "riempire",
    "riempenti": "riempire",
    "riempi": "riempire",
    "riempiamo": "riempire",
    "riempiate": "riempire",
    "riempii": "riempire",
    "riempimmo": "riempire",
    "riempir": "riempire",
    "riempirai": "riempire",
    "riempiran": "riempire",
    "riempiranno": "riempire",
    "riempirebbe": "riempire",
    "riempirebber": "riempire",
    "riempirebbero": "riempire",
    "riempirei": "riempire",
    "riempiremmo": "riempire",
    "riempiremo": "riempire",
    "riempireste": "riempire",
    "riempiresti": "riempire",
    "riempirete": "riempire",
    "riempiron": "riempire",
    "riempirono": "riempire",
    "riempirà": "riempire",
    "riempirò": "riempire",
    "riempisse": "riempire",
    "riempisser": "riempire",
    "riempissero": "riempire",
    "riempissi": "riempire",
    "riempissimo": "riempire",
    "riempiste": "riempire",
    "riempisti": "riempire",
    "riempita": "riempire",
    "riempite": "riempire",
    "riempiti": "riempire",
    "riempitiva": "riempitivo",
    "riempitive": "riempitivo",
    "riempitivi": "riempitivo",
    "riempito": "riempire",
    "riempiva": "riempire",
    "riempivamo": "riempire",
    "riempivan": "riempire",
    "riempivano": "riempire",
    "riempivate": "riempire",
    "riempivi": "riempire",
    "riempivo": "riempire",
    "riempo": "riempire",
    "riempon": "riempire",
    "riempono": "riempire",
    "riempì": "riempire",
    "rientra": "rientrare",
    "rientrai": "rientrare",
    "rientrammo": "rientrare",
    "rientran": "rientrare",
    "rientrando": "rientrare",
    "rientrano": "rientrare",
    "rientrante": "rientrare",
    "rientranti": "rientrare",
    "rientrar": "rientrare",
    "rientraron": "rientrare",
    "rientrarono": "rientrare",
    "rientrasse": "rientrare",
    "rientrasser": "rientrare",
    "rientrassero": "rientrare",
    "rientrassi": "rientrare",
    "rientrassimo": "rientrare",
    "rientraste": "rientrare",
    "rientrasti": "rientrare",
    "rientrata": "rientrato",
    "rientrate": "rientrato",
    "rientrati": "rientrato",
    "rientrato": "rientrare",
    "rientrava": "rientrare",
    "rientravamo": "rientrare",
    "rientravan": "rientrare",
    "rientravano": "rientrare",
    "rientravate": "rientrare",
    "rientravi": "rientrare",
    "rientravo": "rientrare",
    "rientrerai": "rientrare",
    "rientreran": "rientrare",
    "rientreranno": "rientrare",
    "rientrerebbe": "rientrare",
    "rientrerebber": "rientrare",
    "rientrerebbero": "rientrare",
    "rientrerei": "rientrare",
    "rientreremmo": "rientrare",
    "rientreremo": "rientrare",
    "rientrereste": "rientrare",
    "rientreresti": "rientrare",
    "rientrerete": "rientrare",
    "rientrerà": "rientrare",
    "rientrerò": "rientrare",
    "rientri": "rientro",
    "rientriamo": "rientrare",
    "rientriate": "rientrare",
    "rientrin": "rientrare",
    "rientrino": "rientrare",
    "rientro": "rientrare",
    "rientrò": "rientrare",
    "riepiloga": "riepilogare",
    "riepilogai": "riepilogare",
    "riepilogammo": "riepilogare",
    "riepilogan": "riepilogare",
    "riepilogando": "riepilogare",
    "riepilogano": "riepilogare",
    "riepilogante": "riepilogare",
    "riepiloganti": "riepilogare",
    "riepilogar": "riepilogare",
    "riepilogaron": "riepilogare",
    "riepilogarono": "riepilogare",
    "riepilogasse": "riepilogare",
    "riepilogasser": "riepilogare",
    "riepilogassero": "riepilogare",
    "riepilogassi": "riepilogare",
    "riepilogassimo": "riepilogare",
    "riepilogaste": "riepilogare",
    "riepilogasti": "riepilogare",
    "riepilogata": "riepilogare",
    "riepilogate": "riepilogare",
    "riepilogati": "riepilogare",
    "riepilogato": "riepilogare",
    "riepilogava": "riepilogare",
    "riepilogavamo": "riepilogare",
    "riepilogavan": "riepilogare",
    "riepilogavano": "riepilogare",
    "riepilogavate": "riepilogare",
    "riepilogavi": "riepilogare",
    "riepilogavo": "riepilogare",
    "riepilogherai": "riepilogare",
    "riepilogheran": "riepilogare",
    "riepilogheranno": "riepilogare",
    "riepilogherebbe": "riepilogare",
    "riepilogherebber": "riepilogare",
    "riepilogherebbero": "riepilogare",
    "riepilogherei": "riepilogare",
    "riepilogheremmo": "riepilogare",
    "riepilogheremo": "riepilogare",
    "riepiloghereste": "riepilogare",
    "riepilogheresti": "riepilogare",
    "riepilogherete": "riepilogare",
    "riepilogherà": "riepilogare",
    "riepilogherò": "riepilogare",
    "riepiloghi": "riepilogo",
    "riepiloghiamo": "riepilogare",
    "riepiloghiate": "riepilogare",
    "riepiloghin": "riepilogare",
    "riepiloghino": "riepilogare",
    "riepilogo": "riepilogare",
    "riepilogò": "riepilogare",
    "riequilibra": "riequilibrare",
    "riequilibrai": "riequilibrare",
    "riequilibrammo": "riequilibrare",
    "riequilibran": "riequilibrare",
    "riequilibrando": "riequilibrare",
    "riequilibrano": "riequilibrare",
    "riequilibrante": "riequilibrare",
    "riequilibranti": "riequilibrare",
    "riequilibrar": "riequilibrare",
    "riequilibraron": "riequilibrare",
    "riequilibrarono": "riequilibrare",
    "riequilibrasse": "riequilibrare",
    "riequilibrasser": "riequilibrare",
    "riequilibrassero": "riequilibrare",
    "riequilibrassi": "riequilibrare",
    "riequilibrassimo": "riequilibrare",
    "riequilibraste": "riequilibrare",
    "riequilibrasti": "riequilibrare",
    "riequilibrata": "riequilibrare",
    "riequilibrate": "riequilibrare",
    "riequilibrati": "riequilibrare",
    "riequilibrato": "riequilibrare",
    "riequilibrava": "riequilibrare",
    "riequilibravamo": "riequilibrare",
    "riequilibravan": "riequilibrare",
    "riequilibravano": "riequilibrare",
    "riequilibravate": "riequilibrare",
    "riequilibravi": "riequilibrare",
    "riequilibravo": "riequilibrare",
    "riequilibrerai": "riequilibrare",
    "riequilibreran": "riequilibrare",
    "riequilibreranno": "riequilibrare",
    "riequilibrerebbe": "riequilibrare",
    "riequilibrerebber": "riequilibrare",
    "riequilibrerebbero": "riequilibrare",
    "riequilibrerei": "riequilibrare",
    "riequilibreremmo": "riequilibrare",
    "riequilibreremo": "riequilibrare",
    "riequilibrereste": "riequilibrare",
    "riequilibreresti": "riequilibrare",
    "riequilibrerete": "riequilibrare",
    "riequilibrerà": "riequilibrare",
    "riequilibrerò": "riequilibrare",
    "riequilibri": "riequilibrio",
    "riequilibriamo": "riequilibrare",
    "riequilibriate": "riequilibrare",
    "riequilibrin": "riequilibrare",
    "riequilibrino": "riequilibrare",
    "riequilibro": "riequilibrare",
    "riequilibrò": "riequilibrare",
    "riera": "riessere",
    "rieran": "riessere",
    "rierano": "riessere",
    "rieravamo": "riessere",
    "rieravate": "riessere",
    "rieri": "riessere",
    "riero": "riessere",
    "riesami": "riesame",
    "riesamina": "riesaminare",
    "riesaminai": "riesaminare",
    "riesaminammo": "riesaminare",
    "riesaminan": "riesaminare",
    "riesaminando": "riesaminare",
    "riesaminano": "riesaminare",
    "riesaminante": "riesaminare",
    "riesaminanti": "riesaminare",
    "riesaminar": "riesaminare",
    "riesaminaron": "riesaminare",
    "riesaminarono": "riesaminare",
    "riesaminasse": "riesaminare",
    "riesaminasser": "riesaminare",
    "riesaminassero": "riesaminare",
    "riesaminassi": "riesaminare",
    "riesaminassimo": "riesaminare",
    "riesaminaste": "riesaminare",
    "riesaminasti": "riesaminare",
    "riesaminata": "riesaminare",
    "riesaminate": "riesaminare",
    "riesaminati": "riesaminare",
    "riesaminato": "riesaminare",
    "riesaminava": "riesaminare",
    "riesaminavamo": "riesaminare",
    "riesaminavan": "riesaminare",
    "riesaminavano": "riesaminare",
    "riesaminavate": "riesaminare",
    "riesaminavi": "riesaminare",
    "riesaminavo": "riesaminare",
    "riesaminerai": "riesaminare",
    "riesamineran": "riesaminare",
    "riesamineranno": "riesaminare",
    "riesaminerebbe": "riesaminare",
    "riesaminerebber": "riesaminare",
    "riesaminerebbero": "riesaminare",
    "riesaminerei": "riesaminare",
    "riesamineremmo": "riesaminare",
    "riesamineremo": "riesaminare",
    "riesaminereste": "riesaminare",
    "riesamineresti": "riesaminare",
    "riesaminerete": "riesaminare",
    "riesaminerà": "riesaminare",
    "riesaminerò": "riesaminare",
    "riesamini": "riesaminare",
    "riesaminiamo": "riesaminare",
    "riesaminiate": "riesaminare",
    "riesaminin": "riesaminare",
    "riesaminino": "riesaminare",
    "riesamino": "riesaminare",
    "riesaminò": "riesaminare",
    "riesca": "riuscire",
    "riescan": "riuscire",
    "riescano": "riuscire",
    "riesce": "riuscire",
    "riesci": "riuscire",
    "riesco": "riuscire",
    "riescon": "riuscire",
    "riescono": "riuscire",
    "riesploda": "riesplodere",
    "riesplodan": "riesplodere",
    "riesplodano": "riesplodere",
    "riesplode": "riesplodere",
    "riesplodei": "riesplodere",
    "riesplodemmo": "riesplodere",
    "riesplodendo": "riesplodere",
    "riesplodente": "riesplodere",
    "riesplodenti": "riesplodere",
    "riesploder": "riesplodere",
    "riesploderai": "riesplodere",
    "riesploderan": "riesplodere",
    "riesploderanno": "riesplodere",
    "riesploderebbe": "riesplodere",
    "riesploderebber": "riesplodere",
    "riesploderebbero": "riesplodere",
    "riesploderei": "riesplodere",
    "riesploderemmo": "riesplodere",
    "riesploderemo": "riesplodere",
    "riesplodereste": "riesplodere",
    "riesploderesti": "riesplodere",
    "riesploderete": "riesplodere",
    "riesploderon": "riesplodere",
    "riesploderono": "riesplodere",
    "riesploderà": "riesplodere",
    "riesploderò": "riesplodere",
    "riesplodesse": "riesplodere",
    "riesplodesser": "riesplodere",
    "riesplodessero": "riesplodere",
    "riesplodessi": "riesplodere",
    "riesplodessimo": "riesplodere",
    "riesplodeste": "riesplodere",
    "riesplodesti": "riesplodere",
    "riesplodete": "riesplodere",
    "riesplodeva": "riesplodere",
    "riesplodevamo": "riesplodere",
    "riesplodevan": "riesplodere",
    "riesplodevano": "riesplodere",
    "riesplodevate": "riesplodere",
    "riesplodevi": "riesplodere",
    "riesplodevo": "riesplodere",
    "riesplodi": "riesplodere",
    "riesplodiamo": "riesplodere",
    "riesplodiate": "riesplodere",
    "riesplodo": "riesplodere",
    "riesplodon": "riesplodere",
    "riesplodono": "riesplodere",
    "riesploduta": "riesplodere",
    "riesplodute": "riesplodere",
    "riesploduti": "riesplodere",
    "riesploduto": "riesplodere",
    "riesplodè": "riesplodere",
    "riesporta": "riesportare",
    "riesportai": "riesportare",
    "riesportammo": "riesportare",
    "riesportan": "riesportare",
    "riesportando": "riesportare",
    "riesportano": "riesportare",
    "riesportante": "riesportare",
    "riesportanti": "riesportare",
    "riesportar": "riesportare",
    "riesportaron": "riesportare",
    "riesportarono": "riesportare",
    "riesportasse": "riesportare",
    "riesportasser": "riesportare",
    "riesportassero": "riesportare",
    "riesportassi": "riesportare",
    "riesportassimo": "riesportare",
    "riesportaste": "riesportare",
    "riesportasti": "riesportare",
    "riesportata": "riesportare",
    "riesportate": "riesportare",
    "riesportati": "riesportare",
    "riesportato": "riesportare",
    "riesportava": "riesportare",
    "riesportavamo": "riesportare",
    "riesportavan": "riesportare",
    "riesportavano": "riesportare",
    "riesportavate": "riesportare",
    "riesportavi": "riesportare",
    "riesportavo": "riesportare",
    "riesporterai": "riesportare",
    "riesporteran": "riesportare",
    "riesporteranno": "riesportare",
    "riesporterebbe": "riesportare",
    "riesporterebber": "riesportare",
    "riesporterebbero": "riesportare",
    "riesporterei": "riesportare",
    "riesporteremmo": "riesportare",
    "riesporteremo": "riesportare",
    "riesportereste": "riesportare",
    "riesporteresti": "riesportare",
    "riesporterete": "riesportare",
    "riesporterà": "riesportare",
    "riesporterò": "riesportare",
    "riesporti": "riesportare",
    "riesportiamo": "riesportare",
    "riesportiate": "riesportare",
    "riesportin": "riesportare",
    "riesportino": "riesportare",
    "riesporto": "riesportare",
    "riesportò": "riesportare",
    "riessendo": "riessere",
    "riessente": "riessere",
    "riessenti": "riessere",
    "riesser": "riessere",
    "riesuma": "riesumare",
    "riesumai": "riesumare",
    "riesumammo": "riesumare",
    "riesuman": "riesumare",
    "riesumando": "riesumare",
    "riesumano": "riesumare",
    "riesumante": "riesumare",
    "riesumanti": "riesumare",
    "riesumar": "riesumare",
    "riesumaron": "riesumare",
    "riesumarono": "riesumare",
    "riesumasse": "riesumare",
    "riesumasser": "riesumare",
    "riesumassero": "riesumare",
    "riesumassi": "riesumare",
    "riesumassimo": "riesumare",
    "riesumaste": "riesumare",
    "riesumasti": "riesumare",
    "riesumata": "riesumare",
    "riesumate": "riesumare",
    "riesumati": "riesumare",
    "riesumato": "riesumare",
    "riesumava": "riesumare",
    "riesumavamo": "riesumare",
    "riesumavan": "riesumare",
    "riesumavano": "riesumare",
    "riesumavate": "riesumare",
    "riesumavi": "riesumare",
    "riesumavo": "riesumare",
    "riesumazioni": "riesumazione",
    "riesumerai": "riesumare",
    "riesumeran": "riesumare",
    "riesumeranno": "riesumare",
    "riesumerebbe": "riesumare",
    "riesumerebber": "riesumare",
    "riesumerebbero": "riesumare",
    "riesumerei": "riesumare",
    "riesumeremmo": "riesumare",
    "riesumeremo": "riesumare",
    "riesumereste": "riesumare",
    "riesumeresti": "riesumare",
    "riesumerete": "riesumare",
    "riesumerà": "riesumare",
    "riesumerò": "riesumare",
    "riesumi": "riesumare",
    "riesumiamo": "riesumare",
    "riesumiate": "riesumare",
    "riesumin": "riesumare",
    "riesumino": "riesumare",
    "riesumo": "riesumare",
    "riesumò": "riesumare",
    "rievoca": "rievocare",
    "rievocai": "rievocare",
    "rievocammo": "rievocare",
    "rievocan": "rievocare",
    "rievocando": "rievocare",
    "rievocano": "rievocare",
    "rievocante": "rievocare",
    "rievocanti": "rievocare",
    "rievocar": "rievocare",
    "rievocaron": "rievocare",
    "rievocarono": "rievocare",
    "rievocasse": "rievocare",
    "rievocasser": "rievocare",
    "rievocassero": "rievocare",
    "rievocassi": "rievocare",
    "rievocassimo": "rievocare",
    "rievocaste": "rievocare",
    "rievocasti": "rievocare",
    "rievocata": "rievocare",
    "rievocate": "rievocare",
    "rievocati": "rievocare",
    "rievocato": "rievocare",
    "rievocava": "rievocare",
    "rievocavamo": "rievocare",
    "rievocavan": "rievocare",
    "rievocavano": "rievocare",
    "rievocavate": "rievocare",
    "rievocavi": "rievocare",
    "rievocavo": "rievocare",
    "rievocazioni": "rievocazione",
    "rievocherai": "rievocare",
    "rievocheran": "rievocare",
    "rievocheranno": "rievocare",
    "rievocherebbe": "rievocare",
    "rievocherebber": "rievocare",
    "rievocherebbero": "rievocare",
    "rievocherei": "rievocare",
    "rievocheremmo": "rievocare",
    "rievocheremo": "rievocare",
    "rievochereste": "rievocare",
    "rievocheresti": "rievocare",
    "rievocherete": "rievocare",
    "rievocherà": "rievocare",
    "rievocherò": "rievocare",
    "rievochi": "rievocare",
    "rievochiamo": "rievocare",
    "rievochiate": "rievocare",
    "rievochin": "rievocare",
    "rievochino": "rievocare",
    "rievoco": "rievocare",
    "rievocò": "rievocare",
    "rifa": "rifare",
    "rifa'": "rifare",
    "rifaccia": "rifare",
    "rifacciamo": "rifare",
    "rifaccian": "rifare",
    "rifacciano": "rifare",
    "rifacciate": "rifare",
    "rifaccio": "rifare",
    "rifacemmo": "rifare",
    "rifacendo": "rifare",
    "rifacente": "rifare",
    "rifacenti": "rifare",
    "rifacesse": "rifare",
    "rifacesser": "rifare",
    "rifacessero": "rifare",
    "rifacessi": "rifare",
    "rifacessimo": "rifare",
    "rifaceste": "rifare",
    "rifacesti": "rifare",
    "rifaceva": "rifare",
    "rifacevamo": "rifare",
    "rifacevan": "rifare",
    "rifacevano": "rifare",
    "rifacevate": "rifare",
    "rifacevi": "rifare",
    "rifacevo": "rifare",
    "rifacimenti": "rifacimento",
    "rifai": "rifare",
    "rifan": "rifare",
    "rifanno": "rifare",
    "rifar": "rifare",
    "rifarai": "rifare",
    "rifaran": "rifare",
    "rifaranno": "rifare",
    "rifarebbe": "rifare",
    "rifarebber": "rifare",
    "rifarebbero": "rifare",
    "rifarei": "rifare",
    "rifaremmo": "rifare",
    "rifaremo": "rifare",
    "rifareste": "rifare",
    "rifaresti": "rifare",
    "rifarete": "rifare",
    "rifarà": "rifare",
    "rifarò": "rifare",
    "rifate": "rifare",
    "rifatta": "rifare",
    "rifatte": "rifare",
    "rifatti": "rifare",
    "rifatto": "rifare",
    "rifece": "rifare",
    "rifecer": "rifare",
    "rifecero": "rifare",
    "rifeci": "rifare",
    "riferendo": "riferire",
    "riferente": "riferire",
    "riferenti": "riferire",
    "riferiamo": "riferire",
    "riferiate": "riferire",
    "riferibili": "riferibile",
    "riferii": "riferire",
    "riferimenti": "riferimento",
    "riferimmo": "riferire",
    "riferir": "riferire",
    "riferirai": "riferire",
    "riferiran": "riferire",
    "riferiranno": "riferire",
    "riferirebbe": "riferire",
    "riferirebber": "riferire",
    "riferirebbero": "riferire",
    "riferirei": "riferire",
    "riferiremmo": "riferire",
    "riferiremo": "riferire",
    "riferireste": "riferire",
    "riferiresti": "riferire",
    "riferirete": "riferire",
    "riferiron": "riferire",
    "riferirono": "riferire",
    "riferirà": "riferire",
    "riferirò": "riferire",
    "riferisca": "riferire",
    "riferiscan": "riferire",
    "riferiscano": "riferire",
    "riferisce": "riferire",
    "riferisci": "riferire",
    "riferisco": "riferire",
    "riferiscon": "riferire",
    "riferiscono": "riferire",
    "riferisse": "riferire",
    "riferisser": "riferire",
    "riferissero": "riferire",
    "riferissi": "riferire",
    "riferissimo": "riferire",
    "riferiste": "riferire",
    "riferisti": "riferire",
    "riferita": "riferire",
    "riferite": "riferire",
    "riferiti": "riferire",
    "riferito": "riferire",
    "riferiva": "riferire",
    "riferivamo": "riferire",
    "riferivan": "riferire",
    "riferivano": "riferire",
    "riferivate": "riferire",
    "riferivi": "riferire",
    "riferivo": "riferire",
    "riferì": "riferire",
    "rifiata": "rifiatare",
    "rifiatai": "rifiatare",
    "rifiatammo": "rifiatare",
    "rifiatan": "rifiatare",
    "rifiatando": "rifiatare",
    "rifiatano": "rifiatare",
    "rifiatante": "rifiatare",
    "rifiatanti": "rifiatare",
    "rifiatar": "rifiatare",
    "rifiataron": "rifiatare",
    "rifiatarono": "rifiatare",
    "rifiatasse": "rifiatare",
    "rifiatasser": "rifiatare",
    "rifiatassero": "rifiatare",
    "rifiatassi": "rifiatare",
    "rifiatassimo": "rifiatare",
    "rifiataste": "rifiatare",
    "rifiatasti": "rifiatare",
    "rifiatata": "rifiatare",
    "rifiatate": "rifiatare",
    "rifiatati": "rifiatare",
    "rifiatato": "rifiatare",
    "rifiatava": "rifiatare",
    "rifiatavamo": "rifiatare",
    "rifiatavan": "rifiatare",
    "rifiatavano": "rifiatare",
    "rifiatavate": "rifiatare",
    "rifiatavi": "rifiatare",
    "rifiatavo": "rifiatare",
    "rifiaterai": "rifiatare",
    "rifiateran": "rifiatare",
    "rifiateranno": "rifiatare",
    "rifiaterebbe": "rifiatare",
    "rifiaterebber": "rifiatare",
    "rifiaterebbero": "rifiatare",
    "rifiaterei": "rifiatare",
    "rifiateremmo": "rifiatare",
    "rifiateremo": "rifiatare",
    "rifiatereste": "rifiatare",
    "rifiateresti": "rifiatare",
    "rifiaterete": "rifiatare",
    "rifiaterà": "rifiatare",
    "rifiaterò": "rifiatare",
    "rifiati": "rifiatare",
    "rifiatiamo": "rifiatare",
    "rifiatiate": "rifiatare",
    "rifiatin": "rifiatare",
    "rifiatino": "rifiatare",
    "rifiato": "rifiatare",
    "rifiatò": "rifiatare",
    "rificca": "rificcare",
    "rificcai": "rificcare",
    "rificcammo": "rificcare",
    "rificcan": "rificcare",
    "rificcando": "rificcare",
    "rificcano": "rificcare",
    "rificcante": "rificcare",
    "rificcanti": "rificcare",
    "rificcar": "rificcare",
    "rificcaron": "rificcare",
    "rificcarono": "rificcare",
    "rificcasse": "rificcare",
    "rificcasser": "rificcare",
    "rificcassero": "rificcare",
    "rificcassi": "rificcare",
    "rificcassimo": "rificcare",
    "rificcaste": "rificcare",
    "rificcasti": "rificcare",
    "rificcata": "rificcare",
    "rificcate": "rificcare",
    "rificcati": "rificcare",
    "rificcato": "rificcare",
    "rificcava": "rificcare",
    "rificcavamo": "rificcare",
    "rificcavan": "rificcare",
    "rificcavano": "rificcare",
    "rificcavate": "rificcare",
    "rificcavi": "rificcare",
    "rificcavo": "rificcare",
    "rificcherai": "rificcare",
    "rificcheran": "rificcare",
    "rificcheranno": "rificcare",
    "rificcherebbe": "rificcare",
    "rificcherebber": "rificcare",
    "rificcherebbero": "rificcare",
    "rificcherei": "rificcare",
    "rificcheremmo": "rificcare",
    "rificcheremo": "rificcare",
    "rificchereste": "rificcare",
    "rificcheresti": "rificcare",
    "rificcherete": "rificcare",
    "rificcherà": "rificcare",
    "rificcherò": "rificcare",
    "rificchi": "rificcare",
    "rificchiamo": "rificcare",
    "rificchiate": "rificcare",
    "rificchin": "rificcare",
    "rificchino": "rificcare",
    "rificco": "rificcare",
    "rificcò": "rificcare",
    "rifila": "rifilare",
    "rifilai": "rifilare",
    "rifilammo": "rifilare",
    "rifilan": "rifilare",
    "rifilando": "rifilare",
    "rifilano": "rifilare",
    "rifilante": "rifilare",
    "rifilanti": "rifilare",
    "rifilar": "rifilare",
    "rifilaron": "rifilare",
    "rifilarono": "rifilare",
    "rifilasse": "rifilare",
    "rifilasser": "rifilare",
    "rifilassero": "rifilare",
    "rifilassi": "rifilare",
    "rifilassimo": "rifilare",
    "rifilaste": "rifilare",
    "rifilasti": "rifilare",
    "rifilata": "rifilare",
    "rifilate": "rifilare",
    "rifilati": "rifilare",
    "rifilato": "rifilare",
    "rifilava": "rifilare",
    "rifilavamo": "rifilare",
    "rifilavan": "rifilare",
    "rifilavano": "rifilare",
    "rifilavate": "rifilare",
    "rifilavi": "rifilare",
    "rifilavo": "rifilare",
    "rifilerai": "rifilare",
    "rifileran": "rifilare",
    "rifileranno": "rifilare",
    "rifilerebbe": "rifilare",
    "rifilerebber": "rifilare",
    "rifilerebbero": "rifilare",
    "rifilerei": "rifilare",
    "rifileremmo": "rifilare",
    "rifileremo": "rifilare",
    "rifilereste": "rifilare",
    "rifileresti": "rifilare",
    "rifilerete": "rifilare",
    "rifilerà": "rifilare",
    "rifilerò": "rifilare",
    "rifili": "rifilare",
    "rifiliamo": "rifilare",
    "rifiliate": "rifilare",
    "rifilin": "rifilare",
    "rifilino": "rifilare",
    "rifilo": "rifilare",
    "rifilò": "rifilare",
    "rifinanziamenti": "rifinanziamento",
    "rifinendo": "rifinire",
    "rifinente": "rifinire",
    "rifinenti": "rifinire",
    "rifiniamo": "rifinire",
    "rifiniate": "rifinire",
    "rifinii": "rifinire",
    "rifinimmo": "rifinire",
    "rifinir": "rifinire",
    "rifinirai": "rifinire",
    "rifiniran": "rifinire",
    "rifiniranno": "rifinire",
    "rifinirebbe": "rifinire",
    "rifinirebber": "rifinire",
    "rifinirebbero": "rifinire",
    "rifinirei": "rifinire",
    "rifiniremmo": "rifinire",
    "rifiniremo": "rifinire",
    "rifinireste": "rifinire",
    "rifiniresti": "rifinire",
    "rifinirete": "rifinire",
    "rifiniron": "rifinire",
    "rifinirono": "rifinire",
    "rifinirà": "rifinire",
    "rifinirò": "rifinire",
    "rifinisca": "rifinire",
    "rifiniscan": "rifinire",
    "rifiniscano": "rifinire",
    "rifinisce": "rifinire",
    "rifinisci": "rifinire",
    "rifinisco": "rifinire",
    "rifiniscon": "rifinire",
    "rifiniscono": "rifinire",
    "rifinisse": "rifinire",
    "rifinisser": "rifinire",
    "rifinissero": "rifinire",
    "rifinissi": "rifinire",
    "rifinissimo": "rifinire",
    "rifiniste": "rifinire",
    "rifinisti": "rifinire",
    "rifinita": "rifinito",
    "rifinite": "rifinito",
    "rifiniti": "rifinito",
    "rifinito": "rifinire",
    "rifinitori": "rifinitore",
    "rifiniture": "rifinitura",
    "rifiniva": "rifinire",
    "rifinivamo": "rifinire",
    "rifinivan": "rifinire",
    "rifinivano": "rifinire",
    "rifinivate": "rifinire",
    "rifinivi": "rifinire",
    "rifinivo": "rifinire",
    "rifinì": "rifinire",
    "rifiorendo": "rifiorire",
    "rifiorente": "rifiorire",
    "rifiorenti": "rifiorire",
    "rifioriamo": "rifiorire",
    "rifioriate": "rifiorire",
    "rifiorii": "rifiorire",
    "rifiorimmo": "rifiorire",
    "rifiorir": "rifiorire",
    "rifiorirai": "rifiorire",
    "rifioriran": "rifiorire",
    "rifioriranno": "rifiorire",
    "rifiorirebbe": "rifiorire",
    "rifiorirebber": "rifiorire",
    "rifiorirebbero": "rifiorire",
    "rifiorirei": "rifiorire",
    "rifioriremmo": "rifiorire",
    "rifioriremo": "rifiorire",
    "rifiorireste": "rifiorire",
    "rifioriresti": "rifiorire",
    "rifiorirete": "rifiorire",
    "rifioriron": "rifiorire",
    "rifiorirono": "rifiorire",
    "rifiorirà": "rifiorire",
    "rifiorirò": "rifiorire",
    "rifiorisca": "rifiorire",
    "rifioriscan": "rifiorire",
    "rifioriscano": "rifiorire",
    "rifiorisce": "rifiorire",
    "rifiorisci": "rifiorire",
    "rifiorisco": "rifiorire",
    "rifioriscon": "rifiorire",
    "rifioriscono": "rifiorire",
    "rifiorisse": "rifiorire",
    "rifiorisser": "rifiorire",
    "rifiorissero": "rifiorire",
    "rifiorissi": "rifiorire",
    "rifiorissimo": "rifiorire",
    "rifioriste": "rifiorire",
    "rifioristi": "rifiorire",
    "rifiorita": "rifiorire",
    "rifiorite": "rifiorire",
    "rifioriti": "rifiorire",
    "rifiorito": "rifiorire",
    "rifioriva": "rifiorire",
    "rifiorivamo": "rifiorire",
    "rifiorivan": "rifiorire",
    "rifiorivano": "rifiorire",
    "rifiorivate": "rifiorire",
    "rifiorivi": "rifiorire",
    "rifiorivo": "rifiorire",
    "rifiorì": "rifiorire",
    "rifiuta": "rifiutare",
    "rifiutai": "rifiutare",
    "rifiutammo": "rifiutare",
    "rifiutan": "rifiutare",
    "rifiutando": "rifiutare",
    "rifiutano": "rifiutare",
    "rifiutante": "rifiutare",
    "rifiutanti": "rifiutare",
    "rifiutar": "rifiutare",
    "rifiutaron": "rifiutare",
    "rifiutarono": "rifiutare",
    "rifiutasse": "rifiutare",
    "rifiutasser": "rifiutare",
    "rifiutassero": "rifiutare",
    "rifiutassi": "rifiutare",
    "rifiutassimo": "rifiutare",
    "rifiutaste": "rifiutare",
    "rifiutasti": "rifiutare",
    "rifiutata": "rifiutato",
    "rifiutate": "rifiutato",
    "rifiutati": "rifiutato",
    "rifiutato": "rifiutare",
    "rifiutava": "rifiutare",
    "rifiutavamo": "rifiutare",
    "rifiutavan": "rifiutare",
    "rifiutavano": "rifiutare",
    "rifiutavate": "rifiutare",
    "rifiutavi": "rifiutare",
    "rifiutavo": "rifiutare",
    "rifiuterai": "rifiutare",
    "rifiuteran": "rifiutare",
    "rifiuteranno": "rifiutare",
    "rifiuterebbe": "rifiutare",
    "rifiuterebber": "rifiutare",
    "rifiuterebbero": "rifiutare",
    "rifiuterei": "rifiutare",
    "rifiuteremmo": "rifiutare",
    "rifiuteremo": "rifiutare",
    "rifiutereste": "rifiutare",
    "rifiuteresti": "rifiutare",
    "rifiuterete": "rifiutare",
    "rifiuterà": "rifiutare",
    "rifiuterò": "rifiutare",
    "rifiuti": "rifiuto",
    "rifiutiamo": "rifiutare",
    "rifiutiate": "rifiutare",
    "rifiutin": "rifiutare",
    "rifiutino": "rifiutare",
    "rifiuto": "rifiutare",
    "rifiutò": "rifiutare",
    "riflessa": "riflesso",
    "riflesse": "riflesso",
    "riflessi": "riflesso",
    "riflessioni": "riflessione",
    "riflessiva": "riflessivo",
    "riflessive": "riflessivo",
    "riflessivi": "riflessivo",
    "rifletta": "riflettere",
    "riflettan": "riflettere",
    "riflettano": "riflettere",
    "riflette": "riflettere",
    "riflettei": "riflettere",
    "riflettemmo": "riflettere",
    "riflettendo": "riflettere",
    "riflettente": "riflettere",
    "riflettenti": "riflettere",
    "rifletter": "riflettere",
    "rifletterai": "riflettere",
    "rifletteran": "riflettere",
    "rifletteranno": "riflettere",
    "rifletterebbe": "riflettere",
    "rifletterebber": "riflettere",
    "rifletterebbero": "riflettere",
    "rifletterei": "riflettere",
    "rifletteremmo": "riflettere",
    "rifletteremo": "riflettere",
    "riflettereste": "riflettere",
    "rifletteresti": "riflettere",
    "rifletterete": "riflettere",
    "rifletteron": "riflettere",
    "rifletterono": "riflettere",
    "rifletterà": "riflettere",
    "rifletterò": "riflettere",
    "riflettesse": "riflettere",
    "riflettesser": "riflettere",
    "riflettessero": "riflettere",
    "riflettessi": "riflettere",
    "riflettessimo": "riflettere",
    "rifletteste": "riflettere",
    "riflettesti": "riflettere",
    "riflettete": "riflettere",
    "rifletteva": "riflettere",
    "riflettevamo": "riflettere",
    "riflettevan": "riflettere",
    "riflettevano": "riflettere",
    "riflettevate": "riflettere",
    "riflettevi": "riflettere",
    "riflettevo": "riflettere",
    "rifletti": "riflettere",
    "riflettiamo": "riflettere",
    "riflettiate": "riflettere",
    "rifletto": "riflettere",
    "rifletton": "riflettere",
    "riflettono": "riflettere",
    "riflettori": "riflettore",
    "riflettuta": "riflettuto",
    "riflettute": "riflettuto",
    "riflettuti": "riflettuto",
    "riflettuto": "riflettere",
    "riflettè": "riflettere",
    "rifluendo": "rifluire",
    "rifluente": "rifluire",
    "rifluenti": "rifluire",
    "rifluiamo": "rifluire",
    "rifluiate": "rifluire",
    "rifluii": "rifluire",
    "rifluimmo": "rifluire",
    "rifluir": "rifluire",
    "rifluirai": "rifluire",
    "rifluiran": "rifluire",
    "rifluiranno": "rifluire",
    "rifluirebbe": "rifluire",
    "rifluirebber": "rifluire",
    "rifluirebbero": "rifluire",
    "rifluirei": "rifluire",
    "rifluiremmo": "rifluire",
    "rifluiremo": "rifluire",
    "rifluireste": "rifluire",
    "rifluiresti": "rifluire",
    "rifluirete": "rifluire",
    "rifluiron": "rifluire",
    "rifluirono": "rifluire",
    "rifluirà": "rifluire",
    "rifluirò": "rifluire",
    "rifluisca": "rifluire",
    "rifluiscan": "rifluire",
    "rifluiscano": "rifluire",
    "rifluisce": "rifluire",
    "rifluisci": "rifluire",
    "rifluisco": "rifluire",
    "rifluiscon": "rifluire",
    "rifluiscono": "rifluire",
    "rifluisse": "rifluire",
    "rifluisser": "rifluire",
    "rifluissero": "rifluire",
    "rifluissi": "rifluire",
    "rifluissimo": "rifluire",
    "rifluiste": "rifluire",
    "rifluisti": "rifluire",
    "rifluita": "rifluire",
    "rifluite": "rifluire",
    "rifluiti": "rifluire",
    "rifluito": "rifluire",
    "rifluiva": "rifluire",
    "rifluivamo": "rifluire",
    "rifluivan": "rifluire",
    "rifluivano": "rifluire",
    "rifluivate": "rifluire",
    "rifluivi": "rifluire",
    "rifluivo": "rifluire",
    "riflussi": "riflusso",
    "rifluì": "rifluire",
    "rifocilla": "rifocillare",
    "rifocillai": "rifocillare",
    "rifocillammo": "rifocillare",
    "rifocillan": "rifocillare",
    "rifocillando": "rifocillare",
    "rifocillano": "rifocillare",
    "rifocillante": "rifocillare",
    "rifocillanti": "rifocillare",
    "rifocillar": "rifocillare",
    "rifocillaron": "rifocillare",
    "rifocillarono": "rifocillare",
    "rifocillasse": "rifocillare",
    "rifocillasser": "rifocillare",
    "rifocillassero": "rifocillare",
    "rifocillassi": "rifocillare",
    "rifocillassimo": "rifocillare",
    "rifocillaste": "rifocillare",
    "rifocillasti": "rifocillare",
    "rifocillata": "rifocillare",
    "rifocillate": "rifocillare",
    "rifocillati": "rifocillare",
    "rifocillato": "rifocillare",
    "rifocillava": "rifocillare",
    "rifocillavamo": "rifocillare",
    "rifocillavan": "rifocillare",
    "rifocillavano": "rifocillare",
    "rifocillavate": "rifocillare",
    "rifocillavi": "rifocillare",
    "rifocillavo": "rifocillare",
    "rifocillerai": "rifocillare",
    "rifocilleran": "rifocillare",
    "rifocilleranno": "rifocillare",
    "rifocillerebbe": "rifocillare",
    "rifocillerebber": "rifocillare",
    "rifocillerebbero": "rifocillare",
    "rifocillerei": "rifocillare",
    "rifocilleremmo": "rifocillare",
    "rifocilleremo": "rifocillare",
    "rifocillereste": "rifocillare",
    "rifocilleresti": "rifocillare",
    "rifocillerete": "rifocillare",
    "rifocillerà": "rifocillare",
    "rifocillerò": "rifocillare",
    "rifocilli": "rifocillare",
    "rifocilliamo": "rifocillare",
    "rifocilliate": "rifocillare",
    "rifocillin": "rifocillare",
    "rifocillino": "rifocillare",
    "rifocillo": "rifocillare",
    "rifocillò": "rifocillare",
    "rifonda": "rifondere",
    "rifondan": "rifondere",
    "rifondano": "rifondere",
    "rifondaroli": "rifondarolo",
    "rifondatori": "rifondatore",
    "rifondazioni": "rifondazione",
    "rifonde": "rifondere",
    "rifondemmo": "rifondere",
    "rifondendo": "rifondere",
    "rifondente": "rifondere",
    "rifondenti": "rifondere",
    "rifonder": "rifondere",
    "rifonderai": "rifondere",
    "rifonderan": "rifondere",
    "rifonderanno": "rifondere",
    "rifonderebbe": "rifondere",
    "rifonderebber": "rifondere",
    "rifonderebbero": "rifondere",
    "rifonderei": "rifondere",
    "rifonderemmo": "rifondere",
    "rifonderemo": "rifondere",
    "rifondereste": "rifondere",
    "rifonderesti": "rifondere",
    "rifonderete": "rifondere",
    "rifonderà": "rifondere",
    "rifonderò": "rifondere",
    "rifondesse": "rifondere",
    "rifondesser": "rifondere",
    "rifondessero": "rifondere",
    "rifondessi": "rifondere",
    "rifondessimo": "rifondere",
    "rifondeste": "rifondere",
    "rifondesti": "rifondere",
    "rifondete": "rifondere",
    "rifondeva": "rifondere",
    "rifondevamo": "rifondere",
    "rifondevan": "rifondere",
    "rifondevano": "rifondere",
    "rifondevate": "rifondere",
    "rifondevi": "rifondere",
    "rifondevo": "rifondere",
    "rifondi": "rifondere",
    "rifondiamo": "rifondere",
    "rifondiate": "rifondere",
    "rifondo": "rifondere",
    "rifondon": "rifondere",
    "rifondono": "rifondere",
    "riforma": "riformare",
    "riformabili": "riformabile",
    "riformai": "riformare",
    "riformammo": "riformare",
    "riforman": "riformare",
    "riformando": "riformare",
    "riformano": "riformare",
    "riformante": "riformare",
    "riformanti": "riformare",
    "riformar": "riformare",
    "riformaron": "riformare",
    "riformarono": "riformare",
    "riformasse": "riformare",
    "riformasser": "riformare",
    "riformassero": "riformare",
    "riformassi": "riformare",
    "riformassimo": "riformare",
    "riformaste": "riformare",
    "riformasti": "riformare",
    "riformata": "riformato",
    "riformate": "riformato",
    "riformati": "riformato",
    "riformato": "riformare",
    "riformatori": "riformatorio",
    "riformatoria": "riformatorio",
    "riformatorie": "riformatorio",
    "riformatrice": "riformatore",
    "riformatrici": "riformatore",
    "riformava": "riformare",
    "riformavamo": "riformare",
    "riformavan": "riformare",
    "riformavano": "riformare",
    "riformavate": "riformare",
    "riformavi": "riformare",
    "riformavo": "riformare",
    "riforme": "riforma",
    "riformerai": "riformare",
    "riformeran": "riformare",
    "riformeranno": "riformare",
    "riformerebbe": "riformare",
    "riformerebber": "riformare",
    "riformerebbero": "riformare",
    "riformerei": "riformare",
    "riformeremmo": "riformare",
    "riformeremo": "riformare",
    "riformereste": "riformare",
    "riformeresti": "riformare",
    "riformerete": "riformare",
    "riformerà": "riformare",
    "riformerò": "riformare",
    "riformi": "riformare",
    "riformiamo": "riformare",
    "riformiate": "riformare",
    "riformin": "riformare",
    "riformino": "riformare",
    "riformismi": "riformismo",
    "riformiste": "riformista",
    "riformisti": "riformista",
    "riformistica": "riformistico",
    "riformistiche": "riformistico",
    "riformistici": "riformistico",
    "riformo": "riformare",
    "riformula": "riformulare",
    "riformulai": "riformulare",
    "riformulammo": "riformulare",
    "riformulan": "riformulare",
    "riformulando": "riformulare",
    "riformulano": "riformulare",
    "riformulante": "riformulare",
    "riformulanti": "riformulare",
    "riformular": "riformulare",
    "riformularon": "riformulare",
    "riformularono": "riformulare",
    "riformulasse": "riformulare",
    "riformulasser": "riformulare",
    "riformulassero": "riformulare",
    "riformulassi": "riformulare",
    "riformulassimo": "riformulare",
    "riformulaste": "riformulare",
    "riformulasti": "riformulare",
    "riformulata": "riformulare",
    "riformulate": "riformulare",
    "riformulati": "riformulare",
    "riformulato": "riformulare",
    "riformulava": "riformulare",
    "riformulavamo": "riformulare",
    "riformulavan": "riformulare",
    "riformulavano": "riformulare",
    "riformulavate": "riformulare",
    "riformulavi": "riformulare",
    "riformulavo": "riformulare",
    "riformulazioni": "riformulazione",
    "riformulerai": "riformulare",
    "riformuleran": "riformulare",
    "riformuleranno": "riformulare",
    "riformulerebbe": "riformulare",
    "riformulerebber": "riformulare",
    "riformulerebbero": "riformulare",
    "riformulerei": "riformulare",
    "riformuleremmo": "riformulare",
    "riformuleremo": "riformulare",
    "riformulereste": "riformulare",
    "riformuleresti": "riformulare",
    "riformulerete": "riformulare",
    "riformulerà": "riformulare",
    "riformulerò": "riformulare",
    "riformuli": "riformulare",
    "riformuliamo": "riformulare",
    "riformuliate": "riformulare",
    "riformulin": "riformulare",
    "riformulino": "riformulare",
    "riformulo": "riformulare",
    "riformulò": "riformulare",
    "riformò": "riformare",
    "rifornendo": "rifornire",
    "rifornente": "rifornire",
    "rifornenti": "rifornire",
    "riforniamo": "rifornire",
    "riforniate": "rifornire",
    "rifornii": "rifornire",
    "rifornimenti": "rifornimento",
    "rifornimmo": "rifornire",
    "rifornir": "rifornire",
    "rifornirai": "rifornire",
    "riforniran": "rifornire",
    "riforniranno": "rifornire",
    "rifornirebbe": "rifornire",
    "rifornirebber": "rifornire",
    "rifornirebbero": "rifornire",
    "rifornirei": "rifornire",
    "riforniremmo": "rifornire",
    "riforniremo": "rifornire",
    "rifornireste": "rifornire",
    "riforniresti": "rifornire",
    "rifornirete": "rifornire",
    "riforniron": "rifornire",
    "rifornirono": "rifornire",
    "rifornirà": "rifornire",
    "rifornirò": "rifornire",
    "rifornisca": "rifornire",
    "riforniscan": "rifornire",
    "riforniscano": "rifornire",
    "rifornisce": "rifornire",
    "rifornisci": "rifornire",
    "rifornisco": "rifornire",
    "riforniscon": "rifornire",
    "riforniscono": "rifornire",
    "rifornisse": "rifornire",
    "rifornisser": "rifornire",
    "rifornissero": "rifornire",
    "rifornissi": "rifornire",
    "rifornissimo": "rifornire",
    "riforniste": "rifornire",
    "rifornisti": "rifornire",
    "rifornita": "rifornire",
    "rifornite": "rifornire",
    "riforniti": "rifornire",
    "rifornito": "rifornire",
    "rifornitori": "rifornitore",
    "rifornitrice": "rifornitore",
    "rifornitrici": "rifornitore",
    "riforniva": "rifornire",
    "rifornivamo": "rifornire",
    "rifornivan": "rifornire",
    "rifornivano": "rifornire",
    "rifornivate": "rifornire",
    "rifornivi": "rifornire",
    "rifornivo": "rifornire",
    "rifornì": "rifornire",
    "rifosse": "riessere",
    "rifosser": "riessere",
    "rifossero": "riessere",
    "rifossi": "riessere",
    "rifossimo": "riessere",
    "rifoste": "riessere",
    "rifosti": "riessere",
    "rifranga": "rifrangere",
    "rifrangan": "rifrangere",
    "rifrangano": "rifrangere",
    "rifrange": "rifrangere",
    "rifrangemmo": "rifrangere",
    "rifrangendo": "rifrangere",
    "rifrangente": "rifrangere",
    "rifrangenti": "rifrangere",
    "rifranger": "rifrangere",
    "rifrangerai": "rifrangere",
    "rifrangeran": "rifrangere",
    "rifrangeranno": "rifrangere",
    "rifrangerebbe": "rifrangere",
    "rifrangerebber": "rifrangere",
    "rifrangerebbero": "rifrangere",
    "rifrangerei": "rifrangere",
    "rifrangeremmo": "rifrangere",
    "rifrangeremo": "rifrangere",
    "rifrangereste": "rifrangere",
    "rifrangeresti": "rifrangere",
    "rifrangerete": "rifrangere",
    "rifrangerà": "rifrangere",
    "rifrangerò": "rifrangere",
    "rifrangesse": "rifrangere",
    "rifrangesser": "rifrangere",
    "rifrangessero": "rifrangere",
    "rifrangessi": "rifrangere",
    "rifrangessimo": "rifrangere",
    "rifrangeste": "rifrangere",
    "rifrangesti": "rifrangere",
    "rifrangete": "rifrangere",
    "rifrangeva": "rifrangere",
    "rifrangevamo": "rifrangere",
    "rifrangevan": "rifrangere",
    "rifrangevano": "rifrangere",
    "rifrangevate": "rifrangere",
    "rifrangevi": "rifrangere",
    "rifrangevo": "rifrangere",
    "rifrangi": "rifrangere",
    "rifrangiamo": "rifrangere",
    "rifrangiate": "rifrangere",
    "rifrango": "rifrangere",
    "rifrangon": "rifrangere",
    "rifrangono": "rifrangere",
    "rifranser": "rifrangere",
    "rifransero": "rifrangere",
    "rifransi": "rifrangere",
    "rifransè": "rifrangere",
    "rifranta": "rifrangere",
    "rifrante": "rifrangere",
    "rifranti": "rifrangere",
    "rifranto": "rifrangere",
    "rifrazioni": "rifrazione",
    "rifrigga": "rifriggere",
    "rifriggan": "rifriggere",
    "rifriggano": "rifriggere",
    "rifrigge": "rifriggere",
    "rifriggemmo": "rifriggere",
    "rifriggendo": "rifriggere",
    "rifriggente": "rifriggere",
    "rifriggenti": "rifriggere",
    "rifrigger": "rifriggere",
    "rifriggerai": "rifriggere",
    "rifriggeran": "rifriggere",
    "rifriggeranno": "rifriggere",
    "rifriggerebbe": "rifriggere",
    "rifriggerebber": "rifriggere",
    "rifriggerebbero": "rifriggere",
    "rifriggerei": "rifriggere",
    "rifriggeremmo": "rifriggere",
    "rifriggeremo": "rifriggere",
    "rifriggereste": "rifriggere",
    "rifriggeresti": "rifriggere",
    "rifriggerete": "rifriggere",
    "rifriggerà": "rifriggere",
    "rifriggerò": "rifriggere",
    "rifriggesse": "rifriggere",
    "rifriggesser": "rifriggere",
    "rifriggessero": "rifriggere",
    "rifriggessi": "rifriggere",
    "rifriggessimo": "rifriggere",
    "rifriggeste": "rifriggere",
    "rifriggesti": "rifriggere",
    "rifriggete": "rifriggere",
    "rifriggeva": "rifriggere",
    "rifriggevamo": "rifriggere",
    "rifriggevan": "rifriggere",
    "rifriggevano": "rifriggere",
    "rifriggevate": "rifriggere",
    "rifriggevi": "rifriggere",
    "rifriggevo": "rifriggere",
    "rifriggi": "rifriggere",
    "rifriggiamo": "rifriggere",
    "rifriggiate": "rifriggere",
    "rifriggo": "rifriggere",
    "rifriggon": "rifriggere",
    "rifriggono": "rifriggere",
    "rifrisser": "rifriggere",
    "rifrissero": "rifriggere",
    "rifrissi": "rifriggere",
    "rifrissè": "rifriggere",
    "rifritta": "rifriggere",
    "rifritte": "rifriggere",
    "rifritti": "rifriggere",
    "rifritto": "rifriggere",
    "rifu": "riessere",
    "rifugerai": "rifugiare",
    "rifugeran": "rifugiare",
    "rifugeranno": "rifugiare",
    "rifugerebbe": "rifugiare",
    "rifugerebber": "rifugiare",
    "rifugerebbero": "rifugiare",
    "rifugerei": "rifugiare",
    "rifugeremmo": "rifugiare",
    "rifugeremo": "rifugiare",
    "rifugereste": "rifugiare",
    "rifugeresti": "rifugiare",
    "rifugerete": "rifugiare",
    "rifugerà": "rifugiare",
    "rifugerò": "rifugiare",
    "rifugga": "rifuggire",
    "rifuggan": "rifuggire",
    "rifuggano": "rifuggire",
    "rifugge": "rifuggire",
    "rifuggendo": "rifuggire",
    "rifuggente": "rifuggire",
    "rifuggenti": "rifuggire",
    "rifuggi": "rifuggire",
    "rifuggiamo": "rifuggire",
    "rifuggiate": "rifuggire",
    "rifuggii": "rifuggire",
    "rifuggimmo": "rifuggire",
    "rifuggir": "rifuggire",
    "rifuggirai": "rifuggire",
    "rifuggiran": "rifuggire",
    "rifuggiranno": "rifuggire",
    "rifuggirebbe": "rifuggire",
    "rifuggirebber": "rifuggire",
    "rifuggirebbero": "rifuggire",
    "rifuggirei": "rifuggire",
    "rifuggiremmo": "rifuggire",
    "rifuggiremo": "rifuggire",
    "rifuggireste": "rifuggire",
    "rifuggiresti": "rifuggire",
    "rifuggirete": "rifuggire",
    "rifuggiron": "rifuggire",
    "rifuggirono": "rifuggire",
    "rifuggirà": "rifuggire",
    "rifuggirò": "rifuggire",
    "rifuggisse": "rifuggire",
    "rifuggisser": "rifuggire",
    "rifuggissero": "rifuggire",
    "rifuggissi": "rifuggire",
    "rifuggissimo": "rifuggire",
    "rifuggiste": "rifuggire",
    "rifuggisti": "rifuggire",
    "rifuggita": "rifuggire",
    "rifuggite": "rifuggire",
    "rifuggiti": "rifuggire",
    "rifuggito": "rifuggire",
    "rifuggiva": "rifuggire",
    "rifuggivamo": "rifuggire",
    "rifuggivan": "rifuggire",
    "rifuggivano": "rifuggire",
    "rifuggivate": "rifuggire",
    "rifuggivi": "rifuggire",
    "rifuggivo": "rifuggire",
    "rifuggo": "rifuggire",
    "rifuggon": "rifuggire",
    "rifuggono": "rifuggire",
    "rifuggì": "rifuggire",
    "rifugi": "rifugio",
    "rifugia": "rifugiare",
    "rifugiai": "rifugiare",
    "rifugiammo": "rifugiare",
    "rifugiamo": "rifugiare",
    "rifugian": "rifugiare",
    "rifugiando": "rifugiare",
    "rifugiano": "rifugiare",
    "rifugiante": "rifugiare",
    "rifugianti": "rifugiare",
    "rifugiar": "rifugiare",
    "rifugiaron": "rifugiare",
    "rifugiarono": "rifugiare",
    "rifugiasse": "rifugiare",
    "rifugiasser": "rifugiare",
    "rifugiassero": "rifugiare",
    "rifugiassi": "rifugiare",
    "rifugiassimo": "rifugiare",
    "rifugiaste": "rifugiare",
    "rifugiasti": "rifugiare",
    "rifugiata": "rifugiato",
    "rifugiate": "rifugiato",
    "rifugiati": "rifugiato",
    "rifugiato": "rifugiare",
    "rifugiava": "rifugiare",
    "rifugiavamo": "rifugiare",
    "rifugiavan": "rifugiare",
    "rifugiavano": "rifugiare",
    "rifugiavate": "rifugiare",
    "rifugiavi": "rifugiare",
    "rifugiavo": "rifugiare",
    "rifugin": "rifugiare",
    "rifugino": "rifugiare",
    "rifugio": "rifugiare",
    "rifugiò": "rifugiare",
    "rifui": "riessere",
    "rifulga": "rifulgere",
    "rifulgan": "rifulgere",
    "rifulgano": "rifulgere",
    "rifulge": "rifulgere",
    "rifulgei": "rifulgere",
    "rifulgemmo": "rifulgere",
    "rifulgendo": "rifulgere",
    "rifulgente": "rifulgere",
    "rifulgenti": "rifulgere",
    "rifulger": "rifulgere",
    "rifulgerai": "rifulgere",
    "rifulgeran": "rifulgere",
    "rifulgeranno": "rifulgere",
    "rifulgerebbe": "rifulgere",
    "rifulgerebber": "rifulgere",
    "rifulgerebbero": "rifulgere",
    "rifulgerei": "rifulgere",
    "rifulgeremmo": "rifulgere",
    "rifulgeremo": "rifulgere",
    "rifulgereste": "rifulgere",
    "rifulgeresti": "rifulgere",
    "rifulgerete": "rifulgere",
    "rifulgeron": "rifulgere",
    "rifulgerono": "rifulgere",
    "rifulgerà": "rifulgere",
    "rifulgerò": "rifulgere",
    "rifulgesse": "rifulgere",
    "rifulgesser": "rifulgere",
    "rifulgessero": "rifulgere",
    "rifulgessi": "rifulgere",
    "rifulgessimo": "rifulgere",
    "rifulgeste": "rifulgere",
    "rifulgesti": "rifulgere",
    "rifulgete": "rifulgere",
    "rifulgeva": "rifulgere",
    "rifulgevamo": "rifulgere",
    "rifulgevan": "rifulgere",
    "rifulgevano": "rifulgere",
    "rifulgevate": "rifulgere",
    "rifulgevi": "rifulgere",
    "rifulgevo": "rifulgere",
    "rifulgi": "rifulgere",
    "rifulgiamo": "rifulgere",
    "rifulgiate": "rifulgere",
    "rifulgo": "rifulgere",
    "rifulgon": "rifulgere",
    "rifulgono": "rifulgere",
    "rifulgè": "rifulgere",
    "rifulta": "rifulgere",
    "rifulte": "rifulgere",
    "rifulti": "rifulgere",
    "rifulto": "rifulgere",
    "rifummo": "riessere",
    "rifuron": "riessere",
    "rifurono": "riessere",
    "rifusa": "rifondere",
    "rifuse": "rifondere",
    "rifuser": "rifondere",
    "rifusero": "rifondere",
    "rifusi": "rifondere",
    "rifuso": "rifondere",
    "rifuti": "rifuto",
    "riga": "rigare",
    "rigagnoli": "rigagnolo",
    "rigai": "rigare",
    "rigammo": "rigare",
    "rigan": "rigare",
    "rigando": "rigare",
    "rigano": "rigare",
    "rigante": "rigare",
    "riganti": "rigare",
    "rigar": "rigare",
    "rigaron": "rigare",
    "rigarono": "rigare",
    "rigasse": "rigare",
    "rigasser": "rigare",
    "rigassero": "rigare",
    "rigassi": "rigare",
    "rigassimo": "rigare",
    "rigaste": "rigare",
    "rigasti": "rigare",
    "rigata": "rigato",
    "rigate": "rigato",
    "rigati": "rigato",
    "rigato": "rigare",
    "rigatoni": "rigatone",
    "rigattieri": "rigattiere",
    "rigava": "rigare",
    "rigavamo": "rigare",
    "rigavan": "rigare",
    "rigavano": "rigare",
    "rigavate": "rigare",
    "rigavi": "rigare",
    "rigavo": "rigare",
    "rigenera": "rigenerare",
    "rigenerai": "rigenerare",
    "rigenerammo": "rigenerare",
    "rigeneran": "rigenerare",
    "rigenerando": "rigenerare",
    "rigenerano": "rigenerare",
    "rigenerante": "rigenerare",
    "rigeneranti": "rigenerare",
    "rigenerar": "rigenerare",
    "rigeneraron": "rigenerare",
    "rigenerarono": "rigenerare",
    "rigenerasse": "rigenerare",
    "rigenerasser": "rigenerare",
    "rigenerassero": "rigenerare",
    "rigenerassi": "rigenerare",
    "rigenerassimo": "rigenerare",
    "rigeneraste": "rigenerare",
    "rigenerasti": "rigenerare",
    "rigenerata": "rigenerato",
    "rigenerate": "rigenerato",
    "rigenerati": "rigenerato",
    "rigenerato": "rigenerare",
    "rigenerava": "rigenerare",
    "rigeneravamo": "rigenerare",
    "rigeneravan": "rigenerare",
    "rigeneravano": "rigenerare",
    "rigeneravate": "rigenerare",
    "rigeneravi": "rigenerare",
    "rigeneravo": "rigenerare",
    "rigenerazioni": "rigenerazione",
    "rigenererai": "rigenerare",
    "rigenereran": "rigenerare",
    "rigenereranno": "rigenerare",
    "rigenererebbe": "rigenerare",
    "rigenererebber": "rigenerare",
    "rigenererebbero": "rigenerare",
    "rigenererei": "rigenerare",
    "rigenereremmo": "rigenerare",
    "rigenereremo": "rigenerare",
    "rigenerereste": "rigenerare",
    "rigenereresti": "rigenerare",
    "rigenererete": "rigenerare",
    "rigenererà": "rigenerare",
    "rigenererò": "rigenerare",
    "rigeneri": "rigenerare",
    "rigeneriamo": "rigenerare",
    "rigeneriate": "rigenerare",
    "rigenerin": "rigenerare",
    "rigenerino": "rigenerare",
    "rigenero": "rigenerare",
    "rigenerò": "rigenerare",
    "rigetta": "rigettare",
    "rigettai": "rigettare",
    "rigettammo": "rigettare",
    "rigettan": "rigettare",
    "rigettando": "rigettare",
    "rigettano": "rigettare",
    "rigettante": "rigettare",
    "rigettanti": "rigettare",
    "rigettar": "rigettare",
    "rigettaron": "rigettare",
    "rigettarono": "rigettare",
    "rigettasse": "rigettare",
    "rigettasser": "rigettare",
    "rigettassero": "rigettare",
    "rigettassi": "rigettare",
    "rigettassimo": "rigettare",
    "rigettaste": "rigettare",
    "rigettasti": "rigettare",
    "rigettata": "rigettare",
    "rigettate": "rigettare",
    "rigettati": "rigettare",
    "rigettato": "rigettare",
    "rigettava": "rigettare",
    "rigettavamo": "rigettare",
    "rigettavan": "rigettare",
    "rigettavano": "rigettare",
    "rigettavate": "rigettare",
    "rigettavi": "rigettare",
    "rigettavo": "rigettare",
    "rigetterai": "rigettare",
    "rigetteran": "rigettare",
    "rigetteranno": "rigettare",
    "rigetterebbe": "rigettare",
    "rigetterebber": "rigettare",
    "rigetterebbero": "rigettare",
    "rigetterei": "rigettare",
    "rigetteremmo": "rigettare",
    "rigetteremo": "rigettare",
    "rigettereste": "rigettare",
    "rigetteresti": "rigettare",
    "rigetterete": "rigettare",
    "rigetterà": "rigettare",
    "rigetterò": "rigettare",
    "rigetti": "rigetto",
    "rigettiamo": "rigettare",
    "rigettiate": "rigettare",
    "rigettin": "rigettare",
    "rigettino": "rigettare",
    "rigetto": "rigettare",
    "rigettò": "rigettare",
    "righe": "riga",
    "righelli": "righello",
    "righerai": "rigare",
    "righeran": "rigare",
    "righeranno": "rigare",
    "righerebbe": "rigare",
    "righerebber": "rigare",
    "righerebbero": "rigare",
    "righerei": "rigare",
    "righeremmo": "rigare",
    "righeremo": "rigare",
    "righereste": "rigare",
    "righeresti": "rigare",
    "righerete": "rigare",
    "righerà": "rigare",
    "righerò": "rigare",
    "righi": "rigo",
    "righiamo": "rigare",
    "righiate": "rigare",
    "righin": "rigare",
    "righino": "rigare",
    "rigida": "rigido",
    "rigide": "rigido",
    "rigidezze": "rigidezza",
    "rigidi": "rigido",
    "rigioca": "rigiocare",
    "rigiocai": "rigiocare",
    "rigiocammo": "rigiocare",
    "rigiocan": "rigiocare",
    "rigiocando": "rigiocare",
    "rigiocano": "rigiocare",
    "rigiocante": "rigiocare",
    "rigiocanti": "rigiocare",
    "rigiocar": "rigiocare",
    "rigiocaron": "rigiocare",
    "rigiocarono": "rigiocare",
    "rigiocasse": "rigiocare",
    "rigiocasser": "rigiocare",
    "rigiocassero": "rigiocare",
    "rigiocassi": "rigiocare",
    "rigiocassimo": "rigiocare",
    "rigiocaste": "rigiocare",
    "rigiocasti": "rigiocare",
    "rigiocata": "rigiocare",
    "rigiocate": "rigiocare",
    "rigiocati": "rigiocare",
    "rigiocato": "rigiocare",
    "rigiocava": "rigiocare",
    "rigiocavamo": "rigiocare",
    "rigiocavan": "rigiocare",
    "rigiocavano": "rigiocare",
    "rigiocavate": "rigiocare",
    "rigiocavi": "rigiocare",
    "rigiocavo": "rigiocare",
    "rigiocherai": "rigiocare",
    "rigiocheran": "rigiocare",
    "rigiocheranno": "rigiocare",
    "rigiocherebbe": "rigiocare",
    "rigiocherebber": "rigiocare",
    "rigiocherebbero": "rigiocare",
    "rigiocherei": "rigiocare",
    "rigiocheremmo": "rigiocare",
    "rigiocheremo": "rigiocare",
    "rigiochereste": "rigiocare",
    "rigiocheresti": "rigiocare",
    "rigiocherete": "rigiocare",
    "rigiocherà": "rigiocare",
    "rigiocherò": "rigiocare",
    "rigiochi": "rigiocare",
    "rigiochiamo": "rigiocare",
    "rigiochiate": "rigiocare",
    "rigiochin": "rigiocare",
    "rigiochino": "rigiocare",
    "rigioco": "rigiocare",
    "rigiocò": "rigiocare",
    "rigira": "rigirare",
    "rigirai": "rigirare",
    "rigirammo": "rigirare",
    "rigiran": "rigirare",
    "rigirando": "rigirare",
    "rigirano": "rigirare",
    "rigirante": "rigirare",
    "rigiranti": "rigirare",
    "rigirar": "rigirare",
    "rigiraron": "rigirare",
    "rigirarono": "rigirare",
    "rigirasse": "rigirare",
    "rigirasser": "rigirare",
    "rigirassero": "rigirare",
    "rigirassi": "rigirare",
    "rigirassimo": "rigirare",
    "rigiraste": "rigirare",
    "rigirasti": "rigirare",
    "rigirata": "rigirare",
    "rigirate": "rigirare",
    "rigirati": "rigirare",
    "rigirato": "rigirare",
    "rigirava": "rigirare",
    "rigiravamo": "rigirare",
    "rigiravan": "rigirare",
    "rigiravano": "rigirare",
    "rigiravate": "rigirare",
    "rigiravi": "rigirare",
    "rigiravo": "rigirare",
    "rigirerai": "rigirare",
    "rigireran": "rigirare",
    "rigireranno": "rigirare",
    "rigirerebbe": "rigirare",
    "rigirerebber": "rigirare",
    "rigirerebbero": "rigirare",
    "rigirerei": "rigirare",
    "rigireremmo": "rigirare",
    "rigireremo": "rigirare",
    "rigirereste": "rigirare",
    "rigireresti": "rigirare",
    "rigirerete": "rigirare",
    "rigirerà": "rigirare",
    "rigirerò": "rigirare",
    "rigiri": "rigirare",
    "rigiriamo": "rigirare",
    "rigiriate": "rigirare",
    "rigirin": "rigirare",
    "rigirino": "rigirare",
    "rigiro": "rigirare",
    "rigirò": "rigirare",
    "rigo": "rigare",
    "rigogli": "rigoglio",
    "rigogliosa": "rigoglioso",
    "rigogliose": "rigoglioso",
    "rigogliosi": "rigoglioso",
    "rigonfi": "rigonfio",
    "rigonfia": "rigonfio",
    "rigonfiai": "rigonfiare",
    "rigonfiamenti": "rigonfiamento",
    "rigonfiammo": "rigonfiare",
    "rigonfiamo": "rigonfiare",
    "rigonfian": "rigonfiare",
    "rigonfiando": "rigonfiare",
    "rigonfiano": "rigonfiare",
    "rigonfiante": "rigonfiare",
    "rigonfianti": "rigonfiare",
    "rigonfiar": "rigonfiare",
    "rigonfiaron": "rigonfiare",
    "rigonfiarono": "rigonfiare",
    "rigonfiasse": "rigonfiare",
    "rigonfiasser": "rigonfiare",
    "rigonfiassero": "rigonfiare",
    "rigonfiassi": "rigonfiare",
    "rigonfiassimo": "rigonfiare",
    "rigonfiaste": "rigonfiare",
    "rigonfiasti": "rigonfiare",
    "rigonfiata": "rigonfiare",
    "rigonfiate": "rigonfiare",
    "rigonfiati": "rigonfiare",
    "rigonfiato": "rigonfiare",
    "rigonfiava": "rigonfiare",
    "rigonfiavamo": "rigonfiare",
    "rigonfiavan": "rigonfiare",
    "rigonfiavano": "rigonfiare",
    "rigonfiavate": "rigonfiare",
    "rigonfiavi": "rigonfiare",
    "rigonfiavo": "rigonfiare",
    "rigonfie": "rigonfio",
    "rigonfierai": "rigonfiare",
    "rigonfieran": "rigonfiare",
    "rigonfieranno": "rigonfiare",
    "rigonfierebbe": "rigonfiare",
    "rigonfierebber": "rigonfiare",
    "rigonfierebbero": "rigonfiare",
    "rigonfierei": "rigonfiare",
    "rigonfieremmo": "rigonfiare",
    "rigonfieremo": "rigonfiare",
    "rigonfiereste": "rigonfiare",
    "rigonfieresti": "rigonfiare",
    "rigonfierete": "rigonfiare",
    "rigonfierà": "rigonfiare",
    "rigonfierò": "rigonfiare",
    "rigonfin": "rigonfiare",
    "rigonfino": "rigonfiare",
    "rigonfio": "rigonfiare",
    "rigonfiò": "rigonfiare",
    "rigori": "rigore",
    "rigorismi": "rigorismo",
    "rigoristi": "rigorista",
    "rigorosa": "rigoroso",
    "rigorose": "rigoroso",
    "rigorosi": "rigoroso",
    "rigoverna": "rigovernare",
    "rigovernai": "rigovernare",
    "rigovernammo": "rigovernare",
    "rigovernan": "rigovernare",
    "rigovernando": "rigovernare",
    "rigovernano": "rigovernare",
    "rigovernante": "rigovernare",
    "rigovernanti": "rigovernare",
    "rigovernar": "rigovernare",
    "rigovernaron": "rigovernare",
    "rigovernarono": "rigovernare",
    "rigovernasse": "rigovernare",
    "rigovernasser": "rigovernare",
    "rigovernassero": "rigovernare",
    "rigovernassi": "rigovernare",
    "rigovernassimo": "rigovernare",
    "rigovernaste": "rigovernare",
    "rigovernasti": "rigovernare",
    "rigovernata": "rigovernare",
    "rigovernate": "rigovernare",
    "rigovernati": "rigovernare",
    "rigovernato": "rigovernare",
    "rigovernava": "rigovernare",
    "rigovernavamo": "rigovernare",
    "rigovernavan": "rigovernare",
    "rigovernavano": "rigovernare",
    "rigovernavate": "rigovernare",
    "rigovernavi": "rigovernare",
    "rigovernavo": "rigovernare",
    "rigovernerai": "rigovernare",
    "rigoverneran": "rigovernare",
    "rigoverneranno": "rigovernare",
    "rigovernerebbe": "rigovernare",
    "rigovernerebber": "rigovernare",
    "rigovernerebbero": "rigovernare",
    "rigovernerei": "rigovernare",
    "rigoverneremmo": "rigovernare",
    "rigoverneremo": "rigovernare",
    "rigovernereste": "rigovernare",
    "rigoverneresti": "rigovernare",
    "rigovernerete": "rigovernare",
    "rigovernerà": "rigovernare",
    "rigovernerò": "rigovernare",
    "rigoverni": "rigovernare",
    "rigoverniamo": "rigovernare",
    "rigoverniate": "rigovernare",
    "rigovernin": "rigovernare",
    "rigovernino": "rigovernare",
    "rigoverno": "rigovernare",
    "rigovernò": "rigovernare",
    "riguadagna": "riguadagnare",
    "riguadagnai": "riguadagnare",
    "riguadagnammo": "riguadagnare",
    "riguadagnan": "riguadagnare",
    "riguadagnando": "riguadagnare",
    "riguadagnano": "riguadagnare",
    "riguadagnante": "riguadagnare",
    "riguadagnanti": "riguadagnare",
    "riguadagnar": "riguadagnare",
    "riguadagnaron": "riguadagnare",
    "riguadagnarono": "riguadagnare",
    "riguadagnasse": "riguadagnare",
    "riguadagnasser": "riguadagnare",
    "riguadagnassero": "riguadagnare",
    "riguadagnassi": "riguadagnare",
    "riguadagnassimo": "riguadagnare",
    "riguadagnaste": "riguadagnare",
    "riguadagnasti": "riguadagnare",
    "riguadagnata": "riguadagnare",
    "riguadagnate": "riguadagnare",
    "riguadagnati": "riguadagnare",
    "riguadagnato": "riguadagnare",
    "riguadagnava": "riguadagnare",
    "riguadagnavamo": "riguadagnare",
    "riguadagnavan": "riguadagnare",
    "riguadagnavano": "riguadagnare",
    "riguadagnavate": "riguadagnare",
    "riguadagnavi": "riguadagnare",
    "riguadagnavo": "riguadagnare",
    "riguadagnerai": "riguadagnare",
    "riguadagneran": "riguadagnare",
    "riguadagneranno": "riguadagnare",
    "riguadagnerebbe": "riguadagnare",
    "riguadagnerebber": "riguadagnare",
    "riguadagnerebbero": "riguadagnare",
    "riguadagnerei": "riguadagnare",
    "riguadagneremmo": "riguadagnare",
    "riguadagneremo": "riguadagnare",
    "riguadagnereste": "riguadagnare",
    "riguadagneresti": "riguadagnare",
    "riguadagnerete": "riguadagnare",
    "riguadagnerà": "riguadagnare",
    "riguadagnerò": "riguadagnare",
    "riguadagni": "riguadagnare",
    "riguadagniamo": "riguadagnare",
    "riguadagniate": "riguadagnare",
    "riguadagnin": "riguadagnare",
    "riguadagnino": "riguadagnare",
    "riguadagno": "riguadagnare",
    "riguadagnò": "riguadagnare",
    "riguarda": "riguardare",
    "riguardai": "riguardare",
    "riguardammo": "riguardare",
    "riguardan": "riguardare",
    "riguardando": "riguardare",
    "riguardano": "riguardare",
    "riguardante": "riguardare",
    "riguardanti": "riguardare",
    "riguardar": "riguardare",
    "riguardaron": "riguardare",
    "riguardarono": "riguardare",
    "riguardasse": "riguardare",
    "riguardasser": "riguardare",
    "riguardassero": "riguardare",
    "riguardassi": "riguardare",
    "riguardassimo": "riguardare",
    "riguardaste": "riguardare",
    "riguardasti": "riguardare",
    "riguardata": "riguardare",
    "riguardate": "riguardare",
    "riguardati": "riguardare",
    "riguardato": "riguardare",
    "riguardava": "riguardare",
    "riguardavamo": "riguardare",
    "riguardavan": "riguardare",
    "riguardavano": "riguardare",
    "riguardavate": "riguardare",
    "riguardavi": "riguardare",
    "riguardavo": "riguardare",
    "riguarderai": "riguardare",
    "riguarderan": "riguardare",
    "riguarderanno": "riguardare",
    "riguarderebbe": "riguardare",
    "riguarderebber": "riguardare",
    "riguarderebbero": "riguardare",
    "riguarderei": "riguardare",
    "riguarderemmo": "riguardare",
    "riguarderemo": "riguardare",
    "riguardereste": "riguardare",
    "riguarderesti": "riguardare",
    "riguarderete": "riguardare",
    "riguarderà": "riguardare",
    "riguarderò": "riguardare",
    "riguardi": "riguardo",
    "riguardiamo": "riguardare",
    "riguardiate": "riguardare",
    "riguardin": "riguardare",
    "riguardino": "riguardare",
    "riguardo": "riguardare",
    "riguardò": "riguardare",
    "rigurgita": "rigurgitare",
    "rigurgitai": "rigurgitare",
    "rigurgitammo": "rigurgitare",
    "rigurgitan": "rigurgitare",
    "rigurgitando": "rigurgitare",
    "rigurgitano": "rigurgitare",
    "rigurgitante": "rigurgitare",
    "rigurgitanti": "rigurgitare",
    "rigurgitar": "rigurgitare",
    "rigurgitaron": "rigurgitare",
    "rigurgitarono": "rigurgitare",
    "rigurgitasse": "rigurgitare",
    "rigurgitasser": "rigurgitare",
    "rigurgitassero": "rigurgitare",
    "rigurgitassi": "rigurgitare",
    "rigurgitassimo": "rigurgitare",
    "rigurgitaste": "rigurgitare",
    "rigurgitasti": "rigurgitare",
    "rigurgitata": "rigurgitare",
    "rigurgitate": "rigurgitare",
    "rigurgitati": "rigurgitare",
    "rigurgitato": "rigurgitare",
    "rigurgitava": "rigurgitare",
    "rigurgitavamo": "rigurgitare",
    "rigurgitavan": "rigurgitare",
    "rigurgitavano": "rigurgitare",
    "rigurgitavate": "rigurgitare",
    "rigurgitavi": "rigurgitare",
    "rigurgitavo": "rigurgitare",
    "rigurgiterai": "rigurgitare",
    "rigurgiteran": "rigurgitare",
    "rigurgiteranno": "rigurgitare",
    "rigurgiterebbe": "rigurgitare",
    "rigurgiterebber": "rigurgitare",
    "rigurgiterebbero": "rigurgitare",
    "rigurgiterei": "rigurgitare",
    "rigurgiteremmo": "rigurgitare",
    "rigurgiteremo": "rigurgitare",
    "rigurgitereste": "rigurgitare",
    "rigurgiteresti": "rigurgitare",
    "rigurgiterete": "rigurgitare",
    "rigurgiterà": "rigurgitare",
    "rigurgiterò": "rigurgitare",
    "rigurgiti": "rigurgito",
    "rigurgitiamo": "rigurgitare",
    "rigurgitiate": "rigurgitare",
    "rigurgitin": "rigurgitare",
    "rigurgitino": "rigurgitare",
    "rigurgito": "rigurgitare",
    "rigurgitò": "rigurgitare",
    "rigò": "rigare",
    "riha": "riavere",
    "rihai": "riavere",
    "rihan": "riavere",
    "rihanno": "riavere",
    "riho": "riavere",
    "rii": "rio",
    "rilancerai": "rilanciare",
    "rilanceran": "rilanciare",
    "rilanceranno": "rilanciare",
    "rilancerebbe": "rilanciare",
    "rilancerebber": "rilanciare",
    "rilancerebbero": "rilanciare",
    "rilancerei": "rilanciare",
    "rilanceremmo": "rilanciare",
    "rilanceremo": "rilanciare",
    "rilancereste": "rilanciare",
    "rilanceresti": "rilanciare",
    "rilancerete": "rilanciare",
    "rilancerà": "rilanciare",
    "rilancerò": "rilanciare",
    "rilanci": "rilancio",
    "rilancia": "rilanciare",
    "rilanciai": "rilanciare",
    "rilanciammo": "rilanciare",
    "rilanciamo": "rilanciare",
    "rilancian": "rilanciare",
    "rilanciando": "rilanciare",
    "rilanciano": "rilanciare",
    "rilanciante": "rilanciare",
    "rilancianti": "rilanciare",
    "rilanciar": "rilanciare",
    "rilanciaron": "rilanciare",
    "rilanciarono": "rilanciare",
    "rilanciasse": "rilanciare",
    "rilanciasser": "rilanciare",
    "rilanciassero": "rilanciare",
    "rilanciassi": "rilanciare",
    "rilanciassimo": "rilanciare",
    "rilanciaste": "rilanciare",
    "rilanciasti": "rilanciare",
    "rilanciata": "rilanciare",
    "rilanciate": "rilanciare",
    "rilanciati": "rilanciare",
    "rilanciato": "rilanciare",
    "rilanciava": "rilanciare",
    "rilanciavamo": "rilanciare",
    "rilanciavan": "rilanciare",
    "rilanciavano": "rilanciare",
    "rilanciavate": "rilanciare",
    "rilanciavi": "rilanciare",
    "rilanciavo": "rilanciare",
    "rilancin": "rilanciare",
    "rilancino": "rilanciare",
    "rilancio": "rilanciare",
    "rilanciò": "rilanciare",
    "rilascerai": "rilasciare",
    "rilasceran": "rilasciare",
    "rilasceranno": "rilasciare",
    "rilascerebbe": "rilasciare",
    "rilascerebber": "rilasciare",
    "rilascerebbero": "rilasciare",
    "rilascerei": "rilasciare",
    "rilasceremmo": "rilasciare",
    "rilasceremo": "rilasciare",
    "rilascereste": "rilasciare",
    "rilasceresti": "rilasciare",
    "rilascerete": "rilasciare",
    "rilascerà": "rilasciare",
    "rilascerò": "rilasciare",
    "rilasci": "rilascio",
    "rilascia": "rilasciare",
    "rilasciai": "rilasciare",
    "rilasciammo": "rilasciare",
    "rilasciamo": "rilasciare",
    "rilascian": "rilasciare",
    "rilasciando": "rilasciare",
    "rilasciano": "rilasciare",
    "rilasciante": "rilasciare",
    "rilascianti": "rilasciare",
    "rilasciar": "rilasciare",
    "rilasciaron": "rilasciare",
    "rilasciarono": "rilasciare",
    "rilasciasse": "rilasciare",
    "rilasciasser": "rilasciare",
    "rilasciassero": "rilasciare",
    "rilasciassi": "rilasciare",
    "rilasciassimo": "rilasciare",
    "rilasciaste": "rilasciare",
    "rilasciasti": "rilasciare",
    "rilasciata": "rilasciare",
    "rilasciate": "rilasciata",
    "rilasciati": "rilasciare",
    "rilasciato": "rilasciare",
    "rilasciava": "rilasciare",
    "rilasciavamo": "rilasciare",
    "rilasciavan": "rilasciare",
    "rilasciavano": "rilasciare",
    "rilasciavate": "rilasciare",
    "rilasciavi": "rilasciare",
    "rilasciavo": "rilasciare",
    "rilascin": "rilasciare",
    "rilascino": "rilasciare",
    "rilascio": "rilasciare",
    "rilasciò": "rilasciare",
    "rilassa": "rilassare",
    "rilassai": "rilassare",
    "rilassamenti": "rilassamento",
    "rilassammo": "rilassare",
    "rilassan": "rilassare",
    "rilassando": "rilassare",
    "rilassano": "rilassare",
    "rilassante": "rilassare",
    "rilassanti": "rilassare",
    "rilassar": "rilassare",
    "rilassaron": "rilassare",
    "rilassarono": "rilassare",
    "rilassasse": "rilassare",
    "rilassasser": "rilassare",
    "rilassassero": "rilassare",
    "rilassassi": "rilassare",
    "rilassassimo": "rilassare",
    "rilassaste": "rilassare",
    "rilassasti": "rilassare",
    "rilassata": "rilassare",
    "rilassate": "rilassare",
    "rilassatezze": "rilassatezza",
    "rilassati": "rilassare",
    "rilassato": "rilassare",
    "rilassava": "rilassare",
    "rilassavamo": "rilassare",
    "rilassavan": "rilassare",
    "rilassavano": "rilassare",
    "rilassavate": "rilassare",
    "rilassavi": "rilassare",
    "rilassavo": "rilassare",
    "rilasserai": "rilassare",
    "rilasseran": "rilassare",
    "rilasseranno": "rilassare",
    "rilasserebbe": "rilassare",
    "rilasserebber": "rilassare",
    "rilasserebbero": "rilassare",
    "rilasserei": "rilassare",
    "rilasseremmo": "rilassare",
    "rilasseremo": "rilassare",
    "rilassereste": "rilassare",
    "rilasseresti": "rilassare",
    "rilasserete": "rilassare",
    "rilasserà": "rilassare",
    "rilasserò": "rilassare",
    "rilassi": "rilassare",
    "rilassiamo": "rilassare",
    "rilassiate": "rilassare",
    "rilassin": "rilassare",
    "rilassino": "rilassare",
    "rilasso": "rilassare",
    "rilassò": "rilassare",
    "rilava": "rilavare",
    "rilavai": "rilavare",
    "rilavammo": "rilavare",
    "rilavan": "rilavare",
    "rilavando": "rilavare",
    "rilavano": "rilavare",
    "rilavante": "rilavare",
    "rilavanti": "rilavare",
    "rilavar": "rilavare",
    "rilavaron": "rilavare",
    "rilavarono": "rilavare",
    "rilavasse": "rilavare",
    "rilavasser": "rilavare",
    "rilavassero": "rilavare",
    "rilavassi": "rilavare",
    "rilavassimo": "rilavare",
    "rilavaste": "rilavare",
    "rilavasti": "rilavare",
    "rilavata": "rilavare",
    "rilavate": "rilavare",
    "rilavati": "rilavare",
    "rilavato": "rilavare",
    "rilavava": "rilavare",
    "rilavavamo": "rilavare",
    "rilavavan": "rilavare",
    "rilavavano": "rilavare",
    "rilavavate": "rilavare",
    "rilavavi": "rilavare",
    "rilavavo": "rilavare",
    "rilaverai": "rilavare",
    "rilaveran": "rilavare",
    "rilaveranno": "rilavare",
    "rilaverebbe": "rilavare",
    "rilaverebber": "rilavare",
    "rilaverebbero": "rilavare",
    "rilaverei": "rilavare",
    "rilaveremmo": "rilavare",
    "rilaveremo": "rilavare",
    "rilavereste": "rilavare",
    "rilaveresti": "rilavare",
    "rilaverete": "rilavare",
    "rilaverà": "rilavare",
    "rilaverò": "rilavare",
    "rilavi": "rilavare",
    "rilaviamo": "rilavare",
    "rilaviate": "rilavare",
    "rilavin": "rilavare",
    "rilavino": "rilavare",
    "rilavo": "rilavare",
    "rilavò": "rilavare",
    "rilega": "rilegare",
    "rilegai": "rilegare",
    "rilegammo": "rilegare",
    "rilegan": "rilegare",
    "rilegando": "rilegare",
    "rilegano": "rilegare",
    "rilegante": "rilegare",
    "rileganti": "rilegare",
    "rilegar": "rilegare",
    "rilegaron": "rilegare",
    "rilegarono": "rilegare",
    "rilegasse": "rilegare",
    "rilegasser": "rilegare",
    "rilegassero": "rilegare",
    "rilegassi": "rilegare",
    "rilegassimo": "rilegare",
    "rilegaste": "rilegare",
    "rilegasti": "rilegare",
    "rilegata": "rilegare",
    "rilegate": "rilegare",
    "rilegati": "rilegare",
    "rilegato": "rilegare",
    "rilegature": "rilegatura",
    "rilegava": "rilegare",
    "rilegavamo": "rilegare",
    "rilegavan": "rilegare",
    "rilegavano": "rilegare",
    "rilegavate": "rilegare",
    "rilegavi": "rilegare",
    "rilegavo": "rilegare",
    "rilegga": "rileggere",
    "rileggan": "rileggere",
    "rileggano": "rileggere",
    "rilegge": "rileggere",
    "rileggemmo": "rileggere",
    "rileggendo": "rileggere",
    "rileggente": "rileggere",
    "rileggenti": "rileggere",
    "rilegger": "rileggere",
    "rileggerai": "rileggere",
    "rileggeran": "rileggere",
    "rileggeranno": "rileggere",
    "rileggerebbe": "rileggere",
    "rileggerebber": "rileggere",
    "rileggerebbero": "rileggere",
    "rileggerei": "rileggere",
    "rileggeremmo": "rileggere",
    "rileggeremo": "rileggere",
    "rileggereste": "rileggere",
    "rileggeresti": "rileggere",
    "rileggerete": "rileggere",
    "rileggerà": "rileggere",
    "rileggerò": "rileggere",
    "rileggesse": "rileggere",
    "rileggesser": "rileggere",
    "rileggessero": "rileggere",
    "rileggessi": "rileggere",
    "rileggessimo": "rileggere",
    "rileggeste": "rileggere",
    "rileggesti": "rileggere",
    "rileggete": "rileggere",
    "rileggeva": "rileggere",
    "rileggevamo": "rileggere",
    "rileggevan": "rileggere",
    "rileggevano": "rileggere",
    "rileggevate": "rileggere",
    "rileggevi": "rileggere",
    "rileggevo": "rileggere",
    "rileggi": "rileggere",
    "rileggiamo": "rileggere",
    "rileggiate": "rileggere",
    "rileggo": "rileggere",
    "rileggon": "rileggere",
    "rileggono": "rileggere",
    "rilegherai": "rilegare",
    "rilegheran": "rilegare",
    "rilegheranno": "rilegare",
    "rilegherebbe": "rilegare",
    "rilegherebber": "rilegare",
    "rilegherebbero": "rilegare",
    "rilegherei": "rilegare",
    "rilegheremmo": "rilegare",
    "rilegheremo": "rilegare",
    "rileghereste": "rilegare",
    "rilegheresti": "rilegare",
    "rilegherete": "rilegare",
    "rilegherà": "rilegare",
    "rilegherò": "rilegare",
    "rileghi": "rilegare",
    "rileghiamo": "rilegare",
    "rileghiate": "rilegare",
    "rileghin": "rilegare",
    "rileghino": "rilegare",
    "rilego": "rilegare",
    "rilegò": "rilegare",
    "rilesse": "rileggere",
    "rilesser": "rileggere",
    "rilessero": "rileggere",
    "rilessi": "rileggere",
    "riletta": "rileggere",
    "rilette": "rileggere",
    "riletti": "rileggere",
    "riletto": "rileggere",
    "riletture": "rilettura",
    "rileva": "rilevare",
    "rilevai": "rilevare",
    "rilevamenti": "rilevamento",
    "rilevammo": "rilevare",
    "rilevan": "rilevare",
    "rilevando": "rilevare",
    "rilevano": "rilevare",
    "rilevante": "rilevare",
    "rilevanti": "rilevare",
    "rilevanze": "rilevanza",
    "rilevar": "rilevare",
    "rilevaron": "rilevare",
    "rilevarono": "rilevare",
    "rilevasse": "rilevare",
    "rilevasser": "rilevare",
    "rilevassero": "rilevare",
    "rilevassi": "rilevare",
    "rilevassimo": "rilevare",
    "rilevaste": "rilevare",
    "rilevasti": "rilevare",
    "rilevata": "rilevato",
    "rilevate": "rilevato",
    "rilevati": "rilevato",
    "rilevato": "rilevare",
    "rilevatori": "rilevatore",
    "rilevava": "rilevare",
    "rilevavamo": "rilevare",
    "rilevavan": "rilevare",
    "rilevavano": "rilevare",
    "rilevavate": "rilevare",
    "rilevavi": "rilevare",
    "rilevavo": "rilevare",
    "rilevazioni": "rilevazione",
    "rileverai": "rilevare",
    "rileveran": "rilevare",
    "rileveranno": "rilevare",
    "rileverebbe": "rilevare",
    "rileverebber": "rilevare",
    "rileverebbero": "rilevare",
    "rileverei": "rilevare",
    "rileveremmo": "rilevare",
    "rileveremo": "rilevare",
    "rilevereste": "rilevare",
    "rileveresti": "rilevare",
    "rileverete": "rilevare",
    "rileverà": "rilevare",
    "rileverò": "rilevare",
    "rilevi": "rilevare",
    "rileviamo": "rilevare",
    "rileviate": "rilevare",
    "rilevin": "rilevare",
    "rilevino": "rilevare",
    "rilevo": "rilevare",
    "rilevò": "rilevare",
    "rilievi": "rilievo",
    "riluca": "rilucere",
    "rilucan": "rilucere",
    "rilucano": "rilucere",
    "riluce": "rilucere",
    "rilucei": "rilucere",
    "rilucemmo": "rilucere",
    "rilucendo": "rilucere",
    "rilucente": "rilucere",
    "rilucenti": "rilucere",
    "rilucer": "rilucere",
    "rilucerai": "rilucere",
    "riluceran": "rilucere",
    "riluceranno": "rilucere",
    "rilucerebbe": "rilucere",
    "rilucerebber": "rilucere",
    "rilucerebbero": "rilucere",
    "rilucerei": "rilucere",
    "riluceremmo": "rilucere",
    "riluceremo": "rilucere",
    "rilucereste": "rilucere",
    "riluceresti": "rilucere",
    "rilucerete": "rilucere",
    "riluceron": "rilucere",
    "rilucerono": "rilucere",
    "rilucerà": "rilucere",
    "rilucerò": "rilucere",
    "rilucesse": "rilucere",
    "rilucesser": "rilucere",
    "rilucessero": "rilucere",
    "rilucessi": "rilucere",
    "rilucessimo": "rilucere",
    "riluceste": "rilucere",
    "rilucesti": "rilucere",
    "rilucete": "rilucere",
    "riluceva": "rilucere",
    "rilucevamo": "rilucere",
    "rilucevan": "rilucere",
    "rilucevano": "rilucere",
    "rilucevate": "rilucere",
    "rilucevi": "rilucere",
    "rilucevo": "rilucere",
    "riluci": "rilucere",
    "riluciamo": "rilucere",
    "riluciate": "rilucere",
    "riluciuta": "rilucere",
    "riluciute": "rilucere",
    "riluciuti": "rilucere",
    "riluciuto": "rilucere",
    "riluco": "rilucere",
    "rilucon": "rilucere",
    "rilucono": "rilucere",
    "rilucè": "rilucere",
    "rilutta": "riluttare",
    "riluttai": "riluttare",
    "riluttammo": "riluttare",
    "riluttan": "riluttare",
    "riluttando": "riluttare",
    "riluttano": "riluttare",
    "riluttante": "riluttare",
    "riluttanti": "riluttare",
    "riluttanze": "riluttanza",
    "riluttar": "riluttare",
    "riluttaron": "riluttare",
    "riluttarono": "riluttare",
    "riluttasse": "riluttare",
    "riluttasser": "riluttare",
    "riluttassero": "riluttare",
    "riluttassi": "riluttare",
    "riluttassimo": "riluttare",
    "riluttaste": "riluttare",
    "riluttasti": "riluttare",
    "riluttata": "riluttare",
    "riluttate": "riluttare",
    "riluttati": "riluttare",
    "riluttato": "riluttare",
    "riluttava": "riluttare",
    "riluttavamo": "riluttare",
    "riluttavan": "riluttare",
    "riluttavano": "riluttare",
    "riluttavate": "riluttare",
    "riluttavi": "riluttare",
    "riluttavo": "riluttare",
    "rilutterai": "riluttare",
    "rilutteran": "riluttare",
    "rilutteranno": "riluttare",
    "rilutterebbe": "riluttare",
    "rilutterebber": "riluttare",
    "rilutterebbero": "riluttare",
    "rilutterei": "riluttare",
    "rilutteremmo": "riluttare",
    "rilutteremo": "riluttare",
    "riluttereste": "riluttare",
    "rilutteresti": "riluttare",
    "rilutterete": "riluttare",
    "rilutterà": "riluttare",
    "rilutterò": "riluttare",
    "rilutti": "riluttare",
    "riluttiamo": "riluttare",
    "riluttiate": "riluttare",
    "riluttin": "riluttare",
    "riluttino": "riluttare",
    "rilutto": "riluttare",
    "riluttò": "riluttare",
    "rima": "rimare",
    "rimai": "rimare",
    "rimammo": "rimare",
    "riman": "rimare",
    "rimanda": "rimandare",
    "rimandai": "rimandare",
    "rimandammo": "rimandare",
    "rimandan": "rimandare",
    "rimandando": "rimandare",
    "rimandano": "rimandare",
    "rimandante": "rimandare",
    "rimandanti": "rimandare",
    "rimandar": "rimandare",
    "rimandaron": "rimandare",
    "rimandarono": "rimandare",
    "rimandasse": "rimandare",
    "rimandasser": "rimandare",
    "rimandassero": "rimandare",
    "rimandassi": "rimandare",
    "rimandassimo": "rimandare",
    "rimandaste": "rimandare",
    "rimandasti": "rimandare",
    "rimandata": "rimandato",
    "rimandate": "rimandato",
    "rimandati": "rimandato",
    "rimandato": "rimandare",
    "rimandava": "rimandare",
    "rimandavamo": "rimandare",
    "rimandavan": "rimandare",
    "rimandavano": "rimandare",
    "rimandavate": "rimandare",
    "rimandavi": "rimandare",
    "rimandavo": "rimandare",
    "rimanderai": "rimandare",
    "rimanderan": "rimandare",
    "rimanderanno": "rimandare",
    "rimanderebbe": "rimandare",
    "rimanderebber": "rimandare",
    "rimanderebbero": "rimandare",
    "rimanderei": "rimandare",
    "rimanderemmo": "rimandare",
    "rimanderemo": "rimandare",
    "rimandereste": "rimandare",
    "rimanderesti": "rimandare",
    "rimanderete": "rimandare",
    "rimanderà": "rimandare",
    "rimanderò": "rimandare",
    "rimandi": "rimando",
    "rimandiamo": "rimandare",
    "rimandiate": "rimandare",
    "rimandin": "rimandare",
    "rimandino": "rimandare",
    "rimando": "rimare",
    "rimandò": "rimandare",
    "rimane": "rimanere",
    "rimaneggerai": "rimaneggiare",
    "rimaneggeran": "rimaneggiare",
    "rimaneggeranno": "rimaneggiare",
    "rimaneggerebbe": "rimaneggiare",
    "rimaneggerebber": "rimaneggiare",
    "rimaneggerebbero": "rimaneggiare",
    "rimaneggerei": "rimaneggiare",
    "rimaneggeremmo": "rimaneggiare",
    "rimaneggeremo": "rimaneggiare",
    "rimaneggereste": "rimaneggiare",
    "rimaneggeresti": "rimaneggiare",
    "rimaneggerete": "rimaneggiare",
    "rimaneggerà": "rimaneggiare",
    "rimaneggerò": "rimaneggiare",
    "rimaneggi": "rimaneggiare",
    "rimaneggia": "rimaneggiare",
    "rimaneggiai": "rimaneggiare",
    "rimaneggiamenti": "rimaneggiamento",
    "rimaneggiammo": "rimaneggiare",
    "rimaneggiamo": "rimaneggiare",
    "rimaneggian": "rimaneggiare",
    "rimaneggiando": "rimaneggiare",
    "rimaneggiano": "rimaneggiare",
    "rimaneggiante": "rimaneggiare",
    "rimaneggianti": "rimaneggiare",
    "rimaneggiar": "rimaneggiare",
    "rimaneggiaron": "rimaneggiare",
    "rimaneggiarono": "rimaneggiare",
    "rimaneggiasse": "rimaneggiare",
    "rimaneggiasser": "rimaneggiare",
    "rimaneggiassero": "rimaneggiare",
    "rimaneggiassi": "rimaneggiare",
    "rimaneggiassimo": "rimaneggiare",
    "rimaneggiaste": "rimaneggiare",
    "rimaneggiasti": "rimaneggiare",
    "rimaneggiata": "rimaneggiare",
    "rimaneggiate": "rimaneggiare",
    "rimaneggiati": "rimaneggiare",
    "rimaneggiato": "rimaneggiare",
    "rimaneggiava": "rimaneggiare",
    "rimaneggiavamo": "rimaneggiare",
    "rimaneggiavan": "rimaneggiare",
    "rimaneggiavano": "rimaneggiare",
    "rimaneggiavate": "rimaneggiare",
    "rimaneggiavi": "rimaneggiare",
    "rimaneggiavo": "rimaneggiare",
    "rimaneggin": "rimaneggiare",
    "rimaneggino": "rimaneggiare",
    "rimaneggio": "rimaneggiare",
    "rimaneggiò": "rimaneggiare",
    "rimanemmo": "rimanere",
    "rimanendo": "rimanere",
    "rimanente": "rimanere",
    "rimanenti": "rimanere",
    "rimanenze": "rimanenza",
    "rimaner": "rimanere",
    "rimanesse": "rimanere",
    "rimanesser": "rimanere",
    "rimanessero": "rimanere",
    "rimanessi": "rimanere",
    "rimanessimo": "rimanere",
    "rimaneste": "rimanere",
    "rimanesti": "rimanere",
    "rimanete": "rimanere",
    "rimaneva": "rimanere",
    "rimanevamo": "rimanere",
    "rimanevan": "rimanere",
    "rimanevano": "rimanere",
    "rimanevate": "rimanere",
    "rimanevi": "rimanere",
    "rimanevo": "rimanere",
    "rimanga": "rimanere",
    "rimangan": "rimanere",
    "rimangano": "rimanere",
    "rimangerai": "rimangiare",
    "rimangeran": "rimangiare",
    "rimangeranno": "rimangiare",
    "rimangerebbe": "rimangiare",
    "rimangerebber": "rimangiare",
    "rimangerebbero": "rimangiare",
    "rimangerei": "rimangiare",
    "rimangeremmo": "rimangiare",
    "rimangeremo": "rimangiare",
    "rimangereste": "rimangiare",
    "rimangeresti": "rimangiare",
    "rimangerete": "rimangiare",
    "rimangerà": "rimangiare",
    "rimangerò": "rimangiare",
    "rimangi": "rimangiare",
    "rimangia": "rimangiare",
    "rimangiai": "rimangiare",
    "rimangiammo": "rimangiare",
    "rimangiamo": "rimangiare",
    "rimangian": "rimangiare",
    "rimangiando": "rimangiare",
    "rimangiano": "rimangiare",
    "rimangiante": "rimangiare",
    "rimangianti": "rimangiare",
    "rimangiar": "rimangiare",
    "rimangiaron": "rimangiare",
    "rimangiarono": "rimangiare",
    "rimangiasse": "rimangiare",
    "rimangiasser": "rimangiare",
    "rimangiassero": "rimangiare",
    "rimangiassi": "rimangiare",
    "rimangiassimo": "rimangiare",
    "rimangiaste": "rimangiare",
    "rimangiasti": "rimangiare",
    "rimangiata": "rimangiare",
    "rimangiate": "rimangiare",
    "rimangiati": "rimangiare",
    "rimangiato": "rimangiare",
    "rimangiava": "rimangiare",
    "rimangiavamo": "rimangiare",
    "rimangiavan": "rimangiare",
    "rimangiavano": "rimangiare",
    "rimangiavate": "rimangiare",
    "rimangiavi": "rimangiare",
    "rimangiavo": "rimangiare",
    "rimangin": "rimangiare",
    "rimangino": "rimangiare",
    "rimangio": "rimangiare",
    "rimangiò": "rimangiare",
    "rimango": "rimanere",
    "rimangon": "rimanere",
    "rimangono": "rimanere",
    "rimani": "rimanere",
    "rimaniamo": "rimanere",
    "rimaniate": "rimanere",
    "rimano": "rimare",
    "rimante": "rimare",
    "rimanti": "rimare",
    "rimar": "rimare",
    "rimarca": "rimarcare",
    "rimarcai": "rimarcare",
    "rimarcammo": "rimarcare",
    "rimarcan": "rimarcare",
    "rimarcando": "rimarcare",
    "rimarcano": "rimarcare",
    "rimarcante": "rimarcare",
    "rimarcanti": "rimarcare",
    "rimarcar": "rimarcare",
    "rimarcaron": "rimarcare",
    "rimarcarono": "rimarcare",
    "rimarcasse": "rimarcare",
    "rimarcasser": "rimarcare",
    "rimarcassero": "rimarcare",
    "rimarcassi": "rimarcare",
    "rimarcassimo": "rimarcare",
    "rimarcaste": "rimarcare",
    "rimarcasti": "rimarcare",
    "rimarcata": "rimarcare",
    "rimarcate": "rimarcare",
    "rimarcati": "rimarcare",
    "rimarcato": "rimarcare",
    "rimarcava": "rimarcare",
    "rimarcavamo": "rimarcare",
    "rimarcavan": "rimarcare",
    "rimarcavano": "rimarcare",
    "rimarcavate": "rimarcare",
    "rimarcavi": "rimarcare",
    "rimarcavo": "rimarcare",
    "rimarcherai": "rimarcare",
    "rimarcheran": "rimarcare",
    "rimarcheranno": "rimarcare",
    "rimarcherebbe": "rimarcare",
    "rimarcherebber": "rimarcare",
    "rimarcherebbero": "rimarcare",
    "rimarcherei": "rimarcare",
    "rimarcheremmo": "rimarcare",
    "rimarcheremo": "rimarcare",
    "rimarchereste": "rimarcare",
    "rimarcheresti": "rimarcare",
    "rimarcherete": "rimarcare",
    "rimarcherà": "rimarcare",
    "rimarcherò": "rimarcare",
    "rimarchevoli": "rimarchevole",
    "rimarchi": "rimarcare",
    "rimarchiamo": "rimarcare",
    "rimarchiate": "rimarcare",
    "rimarchin": "rimarcare",
    "rimarchino": "rimarcare",
    "rimarco": "rimarcare",
    "rimarcò": "rimarcare",
    "rimargina": "rimarginare",
    "rimarginai": "rimarginare",
    "rimarginammo": "rimarginare",
    "rimarginan": "rimarginare",
    "rimarginando": "rimarginare",
    "rimarginano": "rimarginare",
    "rimarginante": "rimarginare",
    "rimarginanti": "rimarginare",
    "rimarginar": "rimarginare",
    "rimarginaron": "rimarginare",
    "rimarginarono": "rimarginare",
    "rimarginasse": "rimarginare",
    "rimarginasser": "rimarginare",
    "rimarginassero": "rimarginare",
    "rimarginassi": "rimarginare",
    "rimarginassimo": "rimarginare",
    "rimarginaste": "rimarginare",
    "rimarginasti": "rimarginare",
    "rimarginata": "rimarginare",
    "rimarginate": "rimarginare",
    "rimarginati": "rimarginare",
    "rimarginato": "rimarginare",
    "rimarginava": "rimarginare",
    "rimarginavamo": "rimarginare",
    "rimarginavan": "rimarginare",
    "rimarginavano": "rimarginare",
    "rimarginavate": "rimarginare",
    "rimarginavi": "rimarginare",
    "rimarginavo": "rimarginare",
    "rimarginerai": "rimarginare",
    "rimargineran": "rimarginare",
    "rimargineranno": "rimarginare",
    "rimarginerebbe": "rimarginare",
    "rimarginerebber": "rimarginare",
    "rimarginerebbero": "rimarginare",
    "rimarginerei": "rimarginare",
    "rimargineremmo": "rimarginare",
    "rimargineremo": "rimarginare",
    "rimarginereste": "rimarginare",
    "rimargineresti": "rimarginare",
    "rimarginerete": "rimarginare",
    "rimarginerà": "rimarginare",
    "rimarginerò": "rimarginare",
    "rimargini": "rimarginare",
    "rimarginiamo": "rimarginare",
    "rimarginiate": "rimarginare",
    "rimarginin": "rimarginare",
    "rimarginino": "rimarginare",
    "rimargino": "rimarginare",
    "rimarginò": "rimarginare",
    "rimarita": "rimaritare",
    "rimaritai": "rimaritare",
    "rimaritammo": "rimaritare",
    "rimaritan": "rimaritare",
    "rimaritando": "rimaritare",
    "rimaritano": "rimaritare",
    "rimaritante": "rimaritare",
    "rimaritanti": "rimaritare",
    "rimaritar": "rimaritare",
    "rimaritaron": "rimaritare",
    "rimaritarono": "rimaritare",
    "rimaritasse": "rimaritare",
    "rimaritasser": "rimaritare",
    "rimaritassero": "rimaritare",
    "rimaritassi": "rimaritare",
    "rimaritassimo": "rimaritare",
    "rimaritaste": "rimaritare",
    "rimaritasti": "rimaritare",
    "rimaritata": "rimaritare",
    "rimaritate": "rimaritare",
    "rimaritati": "rimaritare",
    "rimaritato": "rimaritare",
    "rimaritava": "rimaritare",
    "rimaritavamo": "rimaritare",
    "rimaritavan": "rimaritare",
    "rimaritavano": "rimaritare",
    "rimaritavate": "rimaritare",
    "rimaritavi": "rimaritare",
    "rimaritavo": "rimaritare",
    "rimariterai": "rimaritare",
    "rimariteran": "rimaritare",
    "rimariteranno": "rimaritare",
    "rimariterebbe": "rimaritare",
    "rimariterebber": "rimaritare",
    "rimariterebbero": "rimaritare",
    "rimariterei": "rimaritare",
    "rimariteremmo": "rimaritare",
    "rimariteremo": "rimaritare",
    "rimaritereste": "rimaritare",
    "rimariteresti": "rimaritare",
    "rimariterete": "rimaritare",
    "rimariterà": "rimaritare",
    "rimariterò": "rimaritare",
    "rimariti": "rimaritare",
    "rimaritiamo": "rimaritare",
    "rimaritiate": "rimaritare",
    "rimaritin": "rimaritare",
    "rimaritino": "rimaritare",
    "rimarito": "rimaritare",
    "rimaritò": "rimaritare",
    "rimaron": "rimare",
    "rimarono": "rimare",
    "rimarrai": "rimanere",
    "rimarran": "rimanere",
    "rimarranno": "rimanere",
    "rimarrebbe": "rimanere",
    "rimarrebber": "rimanere",
    "rimarrebbero": "rimanere",
    "rimarrei": "rimanere",
    "rimarremmo": "rimanere",
    "rimarremo": "rimanere",
    "rimarreste": "rimanere",
    "rimarresti": "rimanere",
    "rimarrete": "rimanere",
    "rimarrà": "rimanere",
    "rimarrò": "rimanere",
    "rimase": "rimanere",
    "rimaser": "rimanere",
    "rimasero": "rimanere",
    "rimasi": "rimanere",
    "rimasse": "rimare",
    "rimasser": "rimare",
    "rimassero": "rimare",
    "rimassi": "rimare",
    "rimassimo": "rimare",
    "rimasta": "rimanere",
    "rimaste": "rimare",
    "rimasti": "rimare",
    "rimastica": "rimasticare",
    "rimasticai": "rimasticare",
    "rimasticammo": "rimasticare",
    "rimastican": "rimasticare",
    "rimasticando": "rimasticare",
    "rimasticano": "rimasticare",
    "rimasticante": "rimasticare",
    "rimasticanti": "rimasticare",
    "rimasticar": "rimasticare",
    "rimasticaron": "rimasticare",
    "rimasticarono": "rimasticare",
    "rimasticasse": "rimasticare",
    "rimasticasser": "rimasticare",
    "rimasticassero": "rimasticare",
    "rimasticassi": "rimasticare",
    "rimasticassimo": "rimasticare",
    "rimasticaste": "rimasticare",
    "rimasticasti": "rimasticare",
    "rimasticata": "rimasticare",
    "rimasticate": "rimasticare",
    "rimasticati": "rimasticare",
    "rimasticato": "rimasticare",
    "rimasticature": "rimasticatura",
    "rimasticava": "rimasticare",
    "rimasticavamo": "rimasticare",
    "rimasticavan": "rimasticare",
    "rimasticavano": "rimasticare",
    "rimasticavate": "rimasticare",
    "rimasticavi": "rimasticare",
    "rimasticavo": "rimasticare",
    "rimasticherai": "rimasticare",
    "rimasticheran": "rimasticare",
    "rimasticheranno": "rimasticare",
    "rimasticherebbe": "rimasticare",
    "rimasticherebber": "rimasticare",
    "rimasticherebbero": "rimasticare",
    "rimasticherei": "rimasticare",
    "rimasticheremmo": "rimasticare",
    "rimasticheremo": "rimasticare",
    "rimastichereste": "rimasticare",
    "rimasticheresti": "rimasticare",
    "rimasticherete": "rimasticare",
    "rimasticherà": "rimasticare",
    "rimasticherò": "rimasticare",
    "rimastichi": "rimasticare",
    "rimastichiamo": "rimasticare",
    "rimastichiate": "rimasticare",
    "rimastichin": "rimasticare",
    "rimastichino": "rimasticare",
    "rimastico": "rimasticare",
    "rimasticò": "rimasticare",
    "rimasto": "rimanere",
    "rimasugli": "rimasuglio",
    "rimata": "rimare",
    "rimate": "rimare",
    "rimati": "rimare",
    "rimato": "rimare",
    "rimava": "rimare",
    "rimavamo": "rimare",
    "rimavan": "rimare",
    "rimavano": "rimare",
    "rimavate": "rimare",
    "rimavi": "rimare",
    "rimavo": "rimare",
    "rimbalza": "rimbalzare",
    "rimbalzai": "rimbalzare",
    "rimbalzammo": "rimbalzare",
    "rimbalzan": "rimbalzare",
    "rimbalzando": "rimbalzare",
    "rimbalzano": "rimbalzare",
    "rimbalzante": "rimbalzare",
    "rimbalzanti": "rimbalzare",
    "rimbalzar": "rimbalzare",
    "rimbalzaron": "rimbalzare",
    "rimbalzarono": "rimbalzare",
    "rimbalzasse": "rimbalzare",
    "rimbalzasser": "rimbalzare",
    "rimbalzassero": "rimbalzare",
    "rimbalzassi": "rimbalzare",
    "rimbalzassimo": "rimbalzare",
    "rimbalzaste": "rimbalzare",
    "rimbalzasti": "rimbalzare",
    "rimbalzata": "rimbalzare",
    "rimbalzate": "rimbalzare",
    "rimbalzati": "rimbalzare",
    "rimbalzato": "rimbalzare",
    "rimbalzava": "rimbalzare",
    "rimbalzavamo": "rimbalzare",
    "rimbalzavan": "rimbalzare",
    "rimbalzavano": "rimbalzare",
    "rimbalzavate": "rimbalzare",
    "rimbalzavi": "rimbalzare",
    "rimbalzavo": "rimbalzare",
    "rimbalzerai": "rimbalzare",
    "rimbalzeran": "rimbalzare",
    "rimbalzeranno": "rimbalzare",
    "rimbalzerebbe": "rimbalzare",
    "rimbalzerebber": "rimbalzare",
    "rimbalzerebbero": "rimbalzare",
    "rimbalzerei": "rimbalzare",
    "rimbalzeremmo": "rimbalzare",
    "rimbalzeremo": "rimbalzare",
    "rimbalzereste": "rimbalzare",
    "rimbalzeresti": "rimbalzare",
    "rimbalzerete": "rimbalzare",
    "rimbalzerà": "rimbalzare",
    "rimbalzerò": "rimbalzare",
    "rimbalzi": "rimbalzo",
    "rimbalziamo": "rimbalzare",
    "rimbalziate": "rimbalzare",
    "rimbalzin": "rimbalzare",
    "rimbalzino": "rimbalzare",
    "rimbalzo": "rimbalzare",
    "rimbalzò": "rimbalzare",
    "rimbamba": "rimbambire",
    "rimbamban": "rimbambire",
    "rimbambano": "rimbambire",
    "rimbambe": "rimbambire",
    "rimbambendo": "rimbambire",
    "rimbambente": "rimbambire",
    "rimbambenti": "rimbambire",
    "rimbambi": "rimbambire",
    "rimbambiamo": "rimbambire",
    "rimbambiate": "rimbambire",
    "rimbambii": "rimbambire",
    "rimbambimmo": "rimbambire",
    "rimbambir": "rimbambire",
    "rimbambirai": "rimbambire",
    "rimbambiran": "rimbambire",
    "rimbambiranno": "rimbambire",
    "rimbambirebbe": "rimbambire",
    "rimbambirebber": "rimbambire",
    "rimbambirebbero": "rimbambire",
    "rimbambirei": "rimbambire",
    "rimbambiremmo": "rimbambire",
    "rimbambiremo": "rimbambire",
    "rimbambireste": "rimbambire",
    "rimbambiresti": "rimbambire",
    "rimbambirete": "rimbambire",
    "rimbambiron": "rimbambire",
    "rimbambirono": "rimbambire",
    "rimbambirà": "rimbambire",
    "rimbambirò": "rimbambire",
    "rimbambisse": "rimbambire",
    "rimbambisser": "rimbambire",
    "rimbambissero": "rimbambire",
    "rimbambissi": "rimbambire",
    "rimbambissimo": "rimbambire",
    "rimbambiste": "rimbambire",
    "rimbambisti": "rimbambire",
    "rimbambita": "rimbambire",
    "rimbambite": "rimbambire",
    "rimbambiti": "rimbambire",
    "rimbambito": "rimbambire",
    "rimbambiva": "rimbambire",
    "rimbambivamo": "rimbambire",
    "rimbambivan": "rimbambire",
    "rimbambivano": "rimbambire",
    "rimbambivate": "rimbambire",
    "rimbambivi": "rimbambire",
    "rimbambivo": "rimbambire",
    "rimbambo": "rimbambire",
    "rimbambon": "rimbambire",
    "rimbambono": "rimbambire",
    "rimbambì": "rimbambire",
    "rimbecca": "rimbeccare",
    "rimbeccai": "rimbeccare",
    "rimbeccammo": "rimbeccare",
    "rimbeccan": "rimbeccare",
    "rimbeccando": "rimbeccare",
    "rimbeccano": "rimbeccare",
    "rimbeccante": "rimbeccare",
    "rimbeccanti": "rimbeccare",
    "rimbeccar": "rimbeccare",
    "rimbeccaron": "rimbeccare",
    "rimbeccarono": "rimbeccare",
    "rimbeccasse": "rimbeccare",
    "rimbeccasser": "rimbeccare",
    "rimbeccassero": "rimbeccare",
    "rimbeccassi": "rimbeccare",
    "rimbeccassimo": "rimbeccare",
    "rimbeccaste": "rimbeccare",
    "rimbeccasti": "rimbeccare",
    "rimbeccata": "rimbeccare",
    "rimbeccate": "rimbeccare",
    "rimbeccati": "rimbeccare",
    "rimbeccato": "rimbeccare",
    "rimbeccava": "rimbeccare",
    "rimbeccavamo": "rimbeccare",
    "rimbeccavan": "rimbeccare",
    "rimbeccavano": "rimbeccare",
    "rimbeccavate": "rimbeccare",
    "rimbeccavi": "rimbeccare",
    "rimbeccavo": "rimbeccare",
    "rimbeccherai": "rimbeccare",
    "rimbeccheran": "rimbeccare",
    "rimbeccheranno": "rimbeccare",
    "rimbeccherebbe": "rimbeccare",
    "rimbeccherebber": "rimbeccare",
    "rimbeccherebbero": "rimbeccare",
    "rimbeccherei": "rimbeccare",
    "rimbeccheremmo": "rimbeccare",
    "rimbeccheremo": "rimbeccare",
    "rimbecchereste": "rimbeccare",
    "rimbeccheresti": "rimbeccare",
    "rimbeccherete": "rimbeccare",
    "rimbeccherà": "rimbeccare",
    "rimbeccherò": "rimbeccare",
    "rimbecchi": "rimbeccare",
    "rimbecchiamo": "rimbeccare",
    "rimbecchiate": "rimbeccare",
    "rimbecchin": "rimbeccare",
    "rimbecchino": "rimbeccare",
    "rimbecco": "rimbeccare",
    "rimbeccò": "rimbeccare",
    "rimbecilla": "rimbecillire",
    "rimbecillan": "rimbecillire",
    "rimbecillano": "rimbecillire",
    "rimbecille": "rimbecillire",
    "rimbecillendo": "rimbecillire",
    "rimbecillente": "rimbecillire",
    "rimbecillenti": "rimbecillire",
    "rimbecilli": "rimbecillire",
    "rimbecilliamo": "rimbecillire",
    "rimbecilliate": "rimbecillire",
    "rimbecillii": "rimbecillire",
    "rimbecillimmo": "rimbecillire",
    "rimbecillir": "rimbecillire",
    "rimbecillirai": "rimbecillire",
    "rimbecilliran": "rimbecillire",
    "rimbecilliranno": "rimbecillire",
    "rimbecillirebbe": "rimbecillire",
    "rimbecillirebber": "rimbecillire",
    "rimbecillirebbero": "rimbecillire",
    "rimbecillirei": "rimbecillire",
    "rimbecilliremmo": "rimbecillire",
    "rimbecilliremo": "rimbecillire",
    "rimbecillireste": "rimbecillire",
    "rimbecilliresti": "rimbecillire",
    "rimbecillirete": "rimbecillire",
    "rimbecilliron": "rimbecillire",
    "rimbecillirono": "rimbecillire",
    "rimbecillirà": "rimbecillire",
    "rimbecillirò": "rimbecillire",
    "rimbecillisse": "rimbecillire",
    "rimbecillisser": "rimbecillire",
    "rimbecillissero": "rimbecillire",
    "rimbecillissi": "rimbecillire",
    "rimbecillissimo": "rimbecillire",
    "rimbecilliste": "rimbecillire",
    "rimbecillisti": "rimbecillire",
    "rimbecillita": "rimbecillire",
    "rimbecillite": "rimbecillire",
    "rimbecilliti": "rimbecillire",
    "rimbecillito": "rimbecillire",
    "rimbecilliva": "rimbecillire",
    "rimbecillivamo": "rimbecillire",
    "rimbecillivan": "rimbecillire",
    "rimbecillivano": "rimbecillire",
    "rimbecillivate": "rimbecillire",
    "rimbecillivi": "rimbecillire",
    "rimbecillivo": "rimbecillire",
    "rimbecillo": "rimbecillire",
    "rimbecillon": "rimbecillire",
    "rimbecillono": "rimbecillire",
    "rimbecillì": "rimbecillire",
    "rimbocca": "rimboccare",
    "rimboccai": "rimboccare",
    "rimboccammo": "rimboccare",
    "rimboccan": "rimboccare",
    "rimboccando": "rimboccare",
    "rimboccano": "rimboccare",
    "rimboccante": "rimboccare",
    "rimboccanti": "rimboccare",
    "rimboccar": "rimboccare",
    "rimboccaron": "rimboccare",
    "rimboccarono": "rimboccare",
    "rimboccasse": "rimboccare",
    "rimboccasser": "rimboccare",
    "rimboccassero": "rimboccare",
    "rimboccassi": "rimboccare",
    "rimboccassimo": "rimboccare",
    "rimboccaste": "rimboccare",
    "rimboccasti": "rimboccare",
    "rimboccata": "rimboccare",
    "rimboccate": "rimboccare",
    "rimboccati": "rimboccare",
    "rimboccato": "rimboccare",
    "rimboccava": "rimboccare",
    "rimboccavamo": "rimboccare",
    "rimboccavan": "rimboccare",
    "rimboccavano": "rimboccare",
    "rimboccavate": "rimboccare",
    "rimboccavi": "rimboccare",
    "rimboccavo": "rimboccare",
    "rimboccherai": "rimboccare",
    "rimboccheran": "rimboccare",
    "rimboccheranno": "rimboccare",
    "rimboccherebbe": "rimboccare",
    "rimboccherebber": "rimboccare",
    "rimboccherebbero": "rimboccare",
    "rimboccherei": "rimboccare",
    "rimboccheremmo": "rimboccare",
    "rimboccheremo": "rimboccare",
    "rimbocchereste": "rimboccare",
    "rimboccheresti": "rimboccare",
    "rimboccherete": "rimboccare",
    "rimboccherà": "rimboccare",
    "rimboccherò": "rimboccare",
    "rimbocchi": "rimboccare",
    "rimbocchiamo": "rimboccare",
    "rimbocchiate": "rimboccare",
    "rimbocchin": "rimboccare",
    "rimbocchino": "rimboccare",
    "rimbocco": "rimboccare",
    "rimboccò": "rimboccare",
    "rimbomba": "rimbombare",
    "rimbombai": "rimbombare",
    "rimbombammo": "rimbombare",
    "rimbomban": "rimbombare",
    "rimbombando": "rimbombare",
    "rimbombano": "rimbombare",
    "rimbombante": "rimbombare",
    "rimbombanti": "rimbombare",
    "rimbombar": "rimbombare",
    "rimbombaron": "rimbombare",
    "rimbombarono": "rimbombare",
    "rimbombasse": "rimbombare",
    "rimbombasser": "rimbombare",
    "rimbombassero": "rimbombare",
    "rimbombassi": "rimbombare",
    "rimbombassimo": "rimbombare",
    "rimbombaste": "rimbombare",
    "rimbombasti": "rimbombare",
    "rimbombata": "rimbombare",
    "rimbombate": "rimbombare",
    "rimbombati": "rimbombare",
    "rimbombato": "rimbombare",
    "rimbombava": "rimbombare",
    "rimbombavamo": "rimbombare",
    "rimbombavan": "rimbombare",
    "rimbombavano": "rimbombare",
    "rimbombavate": "rimbombare",
    "rimbombavi": "rimbombare",
    "rimbombavo": "rimbombare",
    "rimbomberai": "rimbombare",
    "rimbomberan": "rimbombare",
    "rimbomberanno": "rimbombare",
    "rimbomberebbe": "rimbombare",
    "rimbomberebber": "rimbombare",
    "rimbomberebbero": "rimbombare",
    "rimbomberei": "rimbombare",
    "rimbomberemmo": "rimbombare",
    "rimbomberemo": "rimbombare",
    "rimbombereste": "rimbombare",
    "rimbomberesti": "rimbombare",
    "rimbomberete": "rimbombare",
    "rimbomberà": "rimbombare",
    "rimbomberò": "rimbombare",
    "rimbombi": "rimbombo",
    "rimbombiamo": "rimbombare",
    "rimbombiate": "rimbombare",
    "rimbombin": "rimbombare",
    "rimbombino": "rimbombare",
    "rimbombo": "rimbombare",
    "rimbombò": "rimbombare",
    "rimborsa": "rimborsare",
    "rimborsabili": "rimborsabile",
    "rimborsai": "rimborsare",
    "rimborsammo": "rimborsare",
    "rimborsan": "rimborsare",
    "rimborsando": "rimborsare",
    "rimborsano": "rimborsare",
    "rimborsante": "rimborsare",
    "rimborsanti": "rimborsare",
    "rimborsar": "rimborsare",
    "rimborsaron": "rimborsare",
    "rimborsarono": "rimborsare",
    "rimborsasse": "rimborsare",
    "rimborsasser": "rimborsare",
    "rimborsassero": "rimborsare",
    "rimborsassi": "rimborsare",
    "rimborsassimo": "rimborsare",
    "rimborsaste": "rimborsare",
    "rimborsasti": "rimborsare",
    "rimborsata": "rimborsare",
    "rimborsate": "rimborsare",
    "rimborsati": "rimborsare",
    "rimborsato": "rimborsare",
    "rimborsava": "rimborsare",
    "rimborsavamo": "rimborsare",
    "rimborsavan": "rimborsare",
    "rimborsavano": "rimborsare",
    "rimborsavate": "rimborsare",
    "rimborsavi": "rimborsare",
    "rimborsavo": "rimborsare",
    "rimborserai": "rimborsare",
    "rimborseran": "rimborsare",
    "rimborseranno": "rimborsare",
    "rimborserebbe": "rimborsare",
    "rimborserebber": "rimborsare",
    "rimborserebbero": "rimborsare",
    "rimborserei": "rimborsare",
    "rimborseremmo": "rimborsare",
    "rimborseremo": "rimborsare",
    "rimborsereste": "rimborsare",
    "rimborseresti": "rimborsare",
    "rimborserete": "rimborsare",
    "rimborserà": "rimborsare",
    "rimborserò": "rimborsare",
    "rimborsi": "rimborso",
    "rimborsiamo": "rimborsare",
    "rimborsiate": "rimborsare",
    "rimborsin": "rimborsare",
    "rimborsino": "rimborsare",
    "rimborso": "rimborsare",
    "rimborsò": "rimborsare",
    "rimbosca": "rimboscare",
    "rimboscai": "rimboscare",
    "rimboscammo": "rimboscare",
    "rimboscan": "rimboscare",
    "rimboscando": "rimboscare",
    "rimboscano": "rimboscare",
    "rimboscante": "rimboscare",
    "rimboscanti": "rimboscare",
    "rimboscar": "rimboscare",
    "rimboscaron": "rimboscare",
    "rimboscarono": "rimboscare",
    "rimboscasse": "rimboscare",
    "rimboscasser": "rimboscare",
    "rimboscassero": "rimboscare",
    "rimboscassi": "rimboscare",
    "rimboscassimo": "rimboscare",
    "rimboscaste": "rimboscare",
    "rimboscasti": "rimboscare",
    "rimboscata": "rimboscare",
    "rimboscate": "rimboscare",
    "rimboscati": "rimboscare",
    "rimboscato": "rimboscare",
    "rimboscava": "rimboscare",
    "rimboscavamo": "rimboscare",
    "rimboscavan": "rimboscare",
    "rimboscavano": "rimboscare",
    "rimboscavate": "rimboscare",
    "rimboscavi": "rimboscare",
    "rimboscavo": "rimboscare",
    "rimboscha": "rimboschire",
    "rimboschan": "rimboschire",
    "rimboschano": "rimboschire",
    "rimbosche": "rimboschire",
    "rimboschendo": "rimboschire",
    "rimboschente": "rimboschire",
    "rimboschenti": "rimboschire",
    "rimboscherai": "rimboscare",
    "rimboscheran": "rimboscare",
    "rimboscheranno": "rimboscare",
    "rimboscherebbe": "rimboscare",
    "rimboscherebber": "rimboscare",
    "rimboscherebbero": "rimboscare",
    "rimboscherei": "rimboscare",
    "rimboscheremmo": "rimboscare",
    "rimboscheremo": "rimboscare",
    "rimboschereste": "rimboscare",
    "rimboscheresti": "rimboscare",
    "rimboscherete": "rimboscare",
    "rimboscherà": "rimboscare",
    "rimboscherò": "rimboscare",
    "rimboschi": "rimboschire",
    "rimboschiamo": "rimboschire",
    "rimboschiate": "rimboschire",
    "rimboschii": "rimboschire",
    "rimboschimenti": "rimboschimento",
    "rimboschimmo": "rimboschire",
    "rimboschin": "rimboscare",
    "rimboschino": "rimboscare",
    "rimboschir": "rimboschire",
    "rimboschirai": "rimboschire",
    "rimboschiran": "rimboschire",
    "rimboschiranno": "rimboschire",
    "rimboschirebbe": "rimboschire",
    "rimboschirebber": "rimboschire",
    "rimboschirebbero": "rimboschire",
    "rimboschirei": "rimboschire",
    "rimboschiremmo": "rimboschire",
    "rimboschiremo": "rimboschire",
    "rimboschireste": "rimboschire",
    "rimboschiresti": "rimboschire",
    "rimboschirete": "rimboschire",
    "rimboschiron": "rimboschire",
    "rimboschirono": "rimboschire",
    "rimboschirà": "rimboschire",
    "rimboschirò": "rimboschire",
    "rimboschisse": "rimboschire",
    "rimboschisser": "rimboschire",
    "rimboschissero": "rimboschire",
    "rimboschissi": "rimboschire",
    "rimboschissimo": "rimboschire",
    "rimboschiste": "rimboschire",
    "rimboschisti": "rimboschire",
    "rimboschita": "rimboschire",
    "rimboschite": "rimboschire",
    "rimboschiti": "rimboschire",
    "rimboschito": "rimboschire",
    "rimboschiva": "rimboschire",
    "rimboschivamo": "rimboschire",
    "rimboschivan": "rimboschire",
    "rimboschivano": "rimboschire",
    "rimboschivate": "rimboschire",
    "rimboschivi": "rimboschire",
    "rimboschivo": "rimboschire",
    "rimboscho": "rimboschire",
    "rimboschon": "rimboschire",
    "rimboschono": "rimboschire",
    "rimboschì": "rimboschire",
    "rimbosco": "rimboscare",
    "rimboscò": "rimboscare",
    "rimbrotta": "rimbrottare",
    "rimbrottai": "rimbrottare",
    "rimbrottammo": "rimbrottare",
    "rimbrottan": "rimbrottare",
    "rimbrottando": "rimbrottare",
    "rimbrottano": "rimbrottare",
    "rimbrottante": "rimbrottare",
    "rimbrottanti": "rimbrottare",
    "rimbrottar": "rimbrottare",
    "rimbrottaron": "rimbrottare",
    "rimbrottarono": "rimbrottare",
    "rimbrottasse": "rimbrottare",
    "rimbrottasser": "rimbrottare",
    "rimbrottassero": "rimbrottare",
    "rimbrottassi": "rimbrottare",
    "rimbrottassimo": "rimbrottare",
    "rimbrottaste": "rimbrottare",
    "rimbrottasti": "rimbrottare",
    "rimbrottata": "rimbrottare",
    "rimbrottate": "rimbrottare",
    "rimbrottati": "rimbrottare",
    "rimbrottato": "rimbrottare",
    "rimbrottava": "rimbrottare",
    "rimbrottavamo": "rimbrottare",
    "rimbrottavan": "rimbrottare",
    "rimbrottavano": "rimbrottare",
    "rimbrottavate": "rimbrottare",
    "rimbrottavi": "rimbrottare",
    "rimbrottavo": "rimbrottare",
    "rimbrotterai": "rimbrottare",
    "rimbrotteran": "rimbrottare",
    "rimbrotteranno": "rimbrottare",
    "rimbrotterebbe": "rimbrottare",
    "rimbrotterebber": "rimbrottare",
    "rimbrotterebbero": "rimbrottare",
    "rimbrotterei": "rimbrottare",
    "rimbrotteremmo": "rimbrottare",
    "rimbrotteremo": "rimbrottare",
    "rimbrottereste": "rimbrottare",
    "rimbrotteresti": "rimbrottare",
    "rimbrotterete": "rimbrottare",
    "rimbrotterà": "rimbrottare",
    "rimbrotterò": "rimbrottare",
    "rimbrotti": "rimbrotto",
    "rimbrottiamo": "rimbrottare",
    "rimbrottiate": "rimbrottare",
    "rimbrottin": "rimbrottare",
    "rimbrottino": "rimbrottare",
    "rimbrotto": "rimbrottare",
    "rimbrottò": "rimbrottare",
    "rime": "rima",
    "rimedi": "rimedio",
    "rimedia": "rimediare",
    "rimediabili": "rimediabile",
    "rimediai": "rimediare",
    "rimediammo": "rimediare",
    "rimediamo": "rimediare",
    "rimedian": "rimediare",
    "rimediando": "rimediare",
    "rimediano": "rimediare",
    "rimediante": "rimediare",
    "rimedianti": "rimediare",
    "rimediar": "rimediare",
    "rimediaron": "rimediare",
    "rimediarono": "rimediare",
    "rimediasse": "rimediare",
    "rimediasser": "rimediare",
    "rimediassero": "rimediare",
    "rimediassi": "rimediare",
    "rimediassimo": "rimediare",
    "rimediaste": "rimediare",
    "rimediasti": "rimediare",
    "rimediata": "rimediare",
    "rimediate": "rimediare",
    "rimediati": "rimediare",
    "rimediato": "rimediare",
    "rimediava": "rimediare",
    "rimediavamo": "rimediare",
    "rimediavan": "rimediare",
    "rimediavano": "rimediare",
    "rimediavate": "rimediare",
    "rimediavi": "rimediare",
    "rimediavo": "rimediare",
    "rimedierai": "rimediare",
    "rimedieran": "rimediare",
    "rimedieranno": "rimediare",
    "rimedierebbe": "rimediare",
    "rimedierebber": "rimediare",
    "rimedierebbero": "rimediare",
    "rimedierei": "rimediare",
    "rimedieremmo": "rimediare",
    "rimedieremo": "rimediare",
    "rimediereste": "rimediare",
    "rimedieresti": "rimediare",
    "rimedierete": "rimediare",
    "rimedierà": "rimediare",
    "rimedierò": "rimediare",
    "rimedin": "rimediare",
    "rimedino": "rimediare",
    "rimedio": "rimediare",
    "rimediò": "rimediare",
    "rimembra": "rimembrare",
    "rimembrai": "rimembrare",
    "rimembrammo": "rimembrare",
    "rimembran": "rimembrare",
    "rimembrando": "rimembrare",
    "rimembrano": "rimembrare",
    "rimembrante": "rimembrare",
    "rimembranti": "rimembrare",
    "rimembranze": "rimembranza",
    "rimembrar": "rimembrare",
    "rimembraron": "rimembrare",
    "rimembrarono": "rimembrare",
    "rimembrasse": "rimembrare",
    "rimembrasser": "rimembrare",
    "rimembrassero": "rimembrare",
    "rimembrassi": "rimembrare",
    "rimembrassimo": "rimembrare",
    "rimembraste": "rimembrare",
    "rimembrasti": "rimembrare",
    "rimembrata": "rimembrare",
    "rimembrate": "rimembrare",
    "rimembrati": "rimembrare",
    "rimembrato": "rimembrare",
    "rimembrava": "rimembrare",
    "rimembravamo": "rimembrare",
    "rimembravan": "rimembrare",
    "rimembravano": "rimembrare",
    "rimembravate": "rimembrare",
    "rimembravi": "rimembrare",
    "rimembravo": "rimembrare",
    "rimembrerai": "rimembrare",
    "rimembreran": "rimembrare",
    "rimembreranno": "rimembrare",
    "rimembrerebbe": "rimembrare",
    "rimembrerebber": "rimembrare",
    "rimembrerebbero": "rimembrare",
    "rimembrerei": "rimembrare",
    "rimembreremmo": "rimembrare",
    "rimembreremo": "rimembrare",
    "rimembrereste": "rimembrare",
    "rimembreresti": "rimembrare",
    "rimembrerete": "rimembrare",
    "rimembrerà": "rimembrare",
    "rimembrerò": "rimembrare",
    "rimembri": "rimembrare",
    "rimembriamo": "rimembrare",
    "rimembriate": "rimembrare",
    "rimembrin": "rimembrare",
    "rimembrino": "rimembrare",
    "rimembro": "rimembrare",
    "rimembrò": "rimembrare",
    "rimena": "rimenare",
    "rimenai": "rimenare",
    "rimenammo": "rimenare",
    "rimenan": "rimenare",
    "rimenando": "rimenare",
    "rimenano": "rimenare",
    "rimenante": "rimenare",
    "rimenanti": "rimenare",
    "rimenar": "rimenare",
    "rimenaron": "rimenare",
    "rimenarono": "rimenare",
    "rimenasse": "rimenare",
    "rimenasser": "rimenare",
    "rimenassero": "rimenare",
    "rimenassi": "rimenare",
    "rimenassimo": "rimenare",
    "rimenaste": "rimenare",
    "rimenasti": "rimenare",
    "rimenata": "rimenare",
    "rimenate": "rimenare",
    "rimenati": "rimenare",
    "rimenato": "rimenare",
    "rimenava": "rimenare",
    "rimenavamo": "rimenare",
    "rimenavan": "rimenare",
    "rimenavano": "rimenare",
    "rimenavate": "rimenare",
    "rimenavi": "rimenare",
    "rimenavo": "rimenare",
    "rimenerai": "rimenare",
    "rimeneran": "rimenare",
    "rimeneranno": "rimenare",
    "rimenerebbe": "rimenare",
    "rimenerebber": "rimenare",
    "rimenerebbero": "rimenare",
    "rimenerei": "rimenare",
    "rimeneremmo": "rimenare",
    "rimeneremo": "rimenare",
    "rimenereste": "rimenare",
    "rimeneresti": "rimenare",
    "rimenerete": "rimenare",
    "rimenerà": "rimenare",
    "rimenerò": "rimenare",
    "rimeni": "rimenare",
    "rimeniamo": "rimenare",
    "rimeniate": "rimenare",
    "rimenin": "rimenare",
    "rimenino": "rimenare",
    "rimeno": "rimenare",
    "rimenò": "rimenare",
    "rimerai": "rimare",
    "rimeran": "rimare",
    "rimeranno": "rimare",
    "rimerebbe": "rimare",
    "rimerebber": "rimare",
    "rimerebbero": "rimare",
    "rimerei": "rimare",
    "rimeremmo": "rimare",
    "rimeremo": "rimare",
    "rimereste": "rimare",
    "rimeresti": "rimare",
    "rimerete": "rimare",
    "rimerita": "rimeritare",
    "rimeritai": "rimeritare",
    "rimeritammo": "rimeritare",
    "rimeritan": "rimeritare",
    "rimeritando": "rimeritare",
    "rimeritano": "rimeritare",
    "rimeritante": "rimeritare",
    "rimeritanti": "rimeritare",
    "rimeritar": "rimeritare",
    "rimeritaron": "rimeritare",
    "rimeritarono": "rimeritare",
    "rimeritasse": "rimeritare",
    "rimeritasser": "rimeritare",
    "rimeritassero": "rimeritare",
    "rimeritassi": "rimeritare",
    "rimeritassimo": "rimeritare",
    "rimeritaste": "rimeritare",
    "rimeritasti": "rimeritare",
    "rimeritata": "rimeritare",
    "rimeritate": "rimeritare",
    "rimeritati": "rimeritare",
    "rimeritato": "rimeritare",
    "rimeritava": "rimeritare",
    "rimeritavamo": "rimeritare",
    "rimeritavan": "rimeritare",
    "rimeritavano": "rimeritare",
    "rimeritavate": "rimeritare",
    "rimeritavi": "rimeritare",
    "rimeritavo": "rimeritare",
    "rimeriterai": "rimeritare",
    "rimeriteran": "rimeritare",
    "rimeriteranno": "rimeritare",
    "rimeriterebbe": "rimeritare",
    "rimeriterebber": "rimeritare",
    "rimeriterebbero": "rimeritare",
    "rimeriterei": "rimeritare",
    "rimeriteremmo": "rimeritare",
    "rimeriteremo": "rimeritare",
    "rimeritereste": "rimeritare",
    "rimeriteresti": "rimeritare",
    "rimeriterete": "rimeritare",
    "rimeriterà": "rimeritare",
    "rimeriterò": "rimeritare",
    "rimeriti": "rimeritare",
    "rimeritiamo": "rimeritare",
    "rimeritiate": "rimeritare",
    "rimeritin": "rimeritare",
    "rimeritino": "rimeritare",
    "rimerito": "rimeritare",
    "rimeritò": "rimeritare",
    "rimerà": "rimare",
    "rimerò": "rimare",
    "rimescola": "rimescolare",
    "rimescolai": "rimescolare",
    "rimescolamenti": "rimescolamento",
    "rimescolammo": "rimescolare",
    "rimescolan": "rimescolare",
    "rimescolando": "rimescolare",
    "rimescolano": "rimescolare",
    "rimescolante": "rimescolare",
    "rimescolanti": "rimescolare",
    "rimescolar": "rimescolare",
    "rimescolaron": "rimescolare",
    "rimescolarono": "rimescolare",
    "rimescolasse": "rimescolare",
    "rimescolasser": "rimescolare",
    "rimescolassero": "rimescolare",
    "rimescolassi": "rimescolare",
    "rimescolassimo": "rimescolare",
    "rimescolaste": "rimescolare",
    "rimescolasti": "rimescolare",
    "rimescolata": "rimescolare",
    "rimescolate": "rimescolare",
    "rimescolati": "rimescolare",
    "rimescolato": "rimescolare",
    "rimescolava": "rimescolare",
    "rimescolavamo": "rimescolare",
    "rimescolavan": "rimescolare",
    "rimescolavano": "rimescolare",
    "rimescolavate": "rimescolare",
    "rimescolavi": "rimescolare",
    "rimescolavo": "rimescolare",
    "rimescolerai": "rimescolare",
    "rimescoleran": "rimescolare",
    "rimescoleranno": "rimescolare",
    "rimescolerebbe": "rimescolare",
    "rimescolerebber": "rimescolare",
    "rimescolerebbero": "rimescolare",
    "rimescolerei": "rimescolare",
    "rimescoleremmo": "rimescolare",
    "rimescoleremo": "rimescolare",
    "rimescolereste": "rimescolare",
    "rimescoleresti": "rimescolare",
    "rimescolerete": "rimescolare",
    "rimescolerà": "rimescolare",
    "rimescolerò": "rimescolare",
    "rimescoli": "rimescolare",
    "rimescoliamo": "rimescolare",
    "rimescoliate": "rimescolare",
    "rimescolin": "rimescolare",
    "rimescolino": "rimescolare",
    "rimescolo": "rimescolare",
    "rimescolò": "rimescolare",
    "rimessa": "rimettere",
    "rimesse": "rimettere",
    "rimessi": "rimettere",
    "rimesso": "rimettere",
    "rimesta": "rimestare",
    "rimestai": "rimestare",
    "rimestammo": "rimestare",
    "rimestan": "rimestare",
    "rimestando": "rimestare",
    "rimestano": "rimestare",
    "rimestante": "rimestare",
    "rimestanti": "rimestare",
    "rimestar": "rimestare",
    "rimestaron": "rimestare",
    "rimestarono": "rimestare",
    "rimestasse": "rimestare",
    "rimestasser": "rimestare",
    "rimestassero": "rimestare",
    "rimestassi": "rimestare",
    "rimestassimo": "rimestare",
    "rimestaste": "rimestare",
    "rimestasti": "rimestare",
    "rimestata": "rimestare",
    "rimestate": "rimestare",
    "rimestati": "rimestare",
    "rimestato": "rimestare",
    "rimestava": "rimestare",
    "rimestavamo": "rimestare",
    "rimestavan": "rimestare",
    "rimestavano": "rimestare",
    "rimestavate": "rimestare",
    "rimestavi": "rimestare",
    "rimestavo": "rimestare",
    "rimesterai": "rimestare",
    "rimesteran": "rimestare",
    "rimesteranno": "rimestare",
    "rimesterebbe": "rimestare",
    "rimesterebber": "rimestare",
    "rimesterebbero": "rimestare",
    "rimesterei": "rimestare",
    "rimesteremmo": "rimestare",
    "rimesteremo": "rimestare",
    "rimestereste": "rimestare",
    "rimesteresti": "rimestare",
    "rimesterete": "rimestare",
    "rimesterà": "rimestare",
    "rimesterò": "rimestare",
    "rimesti": "rimestare",
    "rimestiamo": "rimestare",
    "rimestiate": "rimestare",
    "rimestin": "rimestare",
    "rimestino": "rimestare",
    "rimesto": "rimestare",
    "rimestò": "rimestare",
    "rimetta": "rimettere",
    "rimettan": "rimettere",
    "rimettano": "rimettere",
    "rimette": "rimettere",
    "rimettemmo": "rimettere",
    "rimettendo": "rimettere",
    "rimettente": "rimettere",
    "rimettenti": "rimettere",
    "rimetter": "rimettere",
    "rimetterai": "rimettere",
    "rimetteran": "rimettere",
    "rimetteranno": "rimettere",
    "rimetterebbe": "rimettere",
    "rimetterebber": "rimettere",
    "rimetterebbero": "rimettere",
    "rimetterei": "rimettere",
    "rimetteremmo": "rimettere",
    "rimetteremo": "rimettere",
    "rimettereste": "rimettere",
    "rimetteresti": "rimettere",
    "rimetterete": "rimettere",
    "rimetterà": "rimettere",
    "rimetterò": "rimettere",
    "rimettesse": "rimettere",
    "rimettesser": "rimettere",
    "rimettessero": "rimettere",
    "rimettessi": "rimettere",
    "rimettessimo": "rimettere",
    "rimetteste": "rimettere",
    "rimettesti": "rimettere",
    "rimettete": "rimettere",
    "rimetteva": "rimettere",
    "rimettevamo": "rimettere",
    "rimettevan": "rimettere",
    "rimettevano": "rimettere",
    "rimettevate": "rimettere",
    "rimettevi": "rimettere",
    "rimettevo": "rimettere",
    "rimetti": "rimettere",
    "rimettiamo": "rimettere",
    "rimettiate": "rimettere",
    "rimetto": "rimettere",
    "rimetton": "rimettere",
    "rimettono": "rimettere",
    "rimi": "rimare",
    "rimiamo": "rimare",
    "rimiate": "rimare",
    "rimin": "rimare",
    "riminesi": "riminese",
    "rimino": "rimare",
    "rimira": "rimirare",
    "rimirai": "rimirare",
    "rimirammo": "rimirare",
    "rimiran": "rimirare",
    "rimirando": "rimirare",
    "rimirano": "rimirare",
    "rimirante": "rimirare",
    "rimiranti": "rimirare",
    "rimirar": "rimirare",
    "rimiraron": "rimirare",
    "rimirarono": "rimirare",
    "rimirasse": "rimirare",
    "rimirasser": "rimirare",
    "rimirassero": "rimirare",
    "rimirassi": "rimirare",
    "rimirassimo": "rimirare",
    "rimiraste": "rimirare",
    "rimirasti": "rimirare",
    "rimirata": "rimirare",
    "rimirate": "rimirare",
    "rimirati": "rimirare",
    "rimirato": "rimirare",
    "rimirava": "rimirare",
    "rimiravamo": "rimirare",
    "rimiravan": "rimirare",
    "rimiravano": "rimirare",
    "rimiravate": "rimirare",
    "rimiravi": "rimirare",
    "rimiravo": "rimirare",
    "rimirerai": "rimirare",
    "rimireran": "rimirare",
    "rimireranno": "rimirare",
    "rimirerebbe": "rimirare",
    "rimirerebber": "rimirare",
    "rimirerebbero": "rimirare",
    "rimirerei": "rimirare",
    "rimireremmo": "rimirare",
    "rimireremo": "rimirare",
    "rimirereste": "rimirare",
    "rimireresti": "rimirare",
    "rimirerete": "rimirare",
    "rimirerà": "rimirare",
    "rimirerò": "rimirare",
    "rimiri": "rimirare",
    "rimiriamo": "rimirare",
    "rimiriate": "rimirare",
    "rimirin": "rimirare",
    "rimirino": "rimirare",
    "rimiro": "rimirare",
    "rimirò": "rimirare",
    "rimise": "rimettere",
    "rimiser": "rimettere",
    "rimisero": "rimettere",
    "rimisi": "rimettere",
    "rimisura": "rimisurare",
    "rimisurai": "rimisurare",
    "rimisurammo": "rimisurare",
    "rimisuran": "rimisurare",
    "rimisurando": "rimisurare",
    "rimisurano": "rimisurare",
    "rimisurante": "rimisurare",
    "rimisuranti": "rimisurare",
    "rimisurar": "rimisurare",
    "rimisuraron": "rimisurare",
    "rimisurarono": "rimisurare",
    "rimisurasse": "rimisurare",
    "rimisurasser": "rimisurare",
    "rimisurassero": "rimisurare",
    "rimisurassi": "rimisurare",
    "rimisurassimo": "rimisurare",
    "rimisuraste": "rimisurare",
    "rimisurasti": "rimisurare",
    "rimisurata": "rimisurare",
    "rimisurate": "rimisurare",
    "rimisurati": "rimisurare",
    "rimisurato": "rimisurare",
    "rimisurava": "rimisurare",
    "rimisuravamo": "rimisurare",
    "rimisuravan": "rimisurare",
    "rimisuravano": "rimisurare",
    "rimisuravate": "rimisurare",
    "rimisuravi": "rimisurare",
    "rimisuravo": "rimisurare",
    "rimisurerai": "rimisurare",
    "rimisureran": "rimisurare",
    "rimisureranno": "rimisurare",
    "rimisurerebbe": "rimisurare",
    "rimisurerebber": "rimisurare",
    "rimisurerebbero": "rimisurare",
    "rimisurerei": "rimisurare",
    "rimisureremmo": "rimisurare",
    "rimisureremo": "rimisurare",
    "rimisurereste": "rimisurare",
    "rimisureresti": "rimisurare",
    "rimisurerete": "rimisurare",
    "rimisurerà": "rimisurare",
    "rimisurerò": "rimisurare",
    "rimisuri": "rimisurare",
    "rimisuriamo": "rimisurare",
    "rimisuriate": "rimisurare",
    "rimisurin": "rimisurare",
    "rimisurino": "rimisurare",
    "rimisuro": "rimisurare",
    "rimisurò": "rimisurare",
    "rimo": "rimare",
    "rimodella": "rimodellare",
    "rimodellai": "rimodellare",
    "rimodellammo": "rimodellare",
    "rimodellan": "rimodellare",
    "rimodellando": "rimodellare",
    "rimodellano": "rimodellare",
    "rimodellante": "rimodellare",
    "rimodellanti": "rimodellare",
    "rimodellar": "rimodellare",
    "rimodellaron": "rimodellare",
    "rimodellarono": "rimodellare",
    "rimodellasse": "rimodellare",
    "rimodellasser": "rimodellare",
    "rimodellassero": "rimodellare",
    "rimodellassi": "rimodellare",
    "rimodellassimo": "rimodellare",
    "rimodellaste": "rimodellare",
    "rimodellasti": "rimodellare",
    "rimodellata": "rimodellare",
    "rimodellate": "rimodellare",
    "rimodellati": "rimodellare",
    "rimodellato": "rimodellare",
    "rimodellava": "rimodellare",
    "rimodellavamo": "rimodellare",
    "rimodellavan": "rimodellare",
    "rimodellavano": "rimodellare",
    "rimodellavate": "rimodellare",
    "rimodellavi": "rimodellare",
    "rimodellavo": "rimodellare",
    "rimodellerai": "rimodellare",
    "rimodelleran": "rimodellare",
    "rimodelleranno": "rimodellare",
    "rimodellerebbe": "rimodellare",
    "rimodellerebber": "rimodellare",
    "rimodellerebbero": "rimodellare",
    "rimodellerei": "rimodellare",
    "rimodelleremmo": "rimodellare",
    "rimodelleremo": "rimodellare",
    "rimodellereste": "rimodellare",
    "rimodelleresti": "rimodellare",
    "rimodellerete": "rimodellare",
    "rimodellerà": "rimodellare",
    "rimodellerò": "rimodellare",
    "rimodelli": "rimodellare",
    "rimodelliamo": "rimodellare",
    "rimodelliate": "rimodellare",
    "rimodellin": "rimodellare",
    "rimodellino": "rimodellare",
    "rimodello": "rimodellare",
    "rimodellò": "rimodellare",
    "rimoderna": "rimodernare",
    "rimodernai": "rimodernare",
    "rimodernammo": "rimodernare",
    "rimodernan": "rimodernare",
    "rimodernando": "rimodernare",
    "rimodernano": "rimodernare",
    "rimodernante": "rimodernare",
    "rimodernanti": "rimodernare",
    "rimodernar": "rimodernare",
    "rimodernaron": "rimodernare",
    "rimodernarono": "rimodernare",
    "rimodernasse": "rimodernare",
    "rimodernasser": "rimodernare",
    "rimodernassero": "rimodernare",
    "rimodernassi": "rimodernare",
    "rimodernassimo": "rimodernare",
    "rimodernaste": "rimodernare",
    "rimodernasti": "rimodernare",
    "rimodernata": "rimodernare",
    "rimodernate": "rimodernare",
    "rimodernati": "rimodernare",
    "rimodernato": "rimodernare",
    "rimodernava": "rimodernare",
    "rimodernavamo": "rimodernare",
    "rimodernavan": "rimodernare",
    "rimodernavano": "rimodernare",
    "rimodernavate": "rimodernare",
    "rimodernavi": "rimodernare",
    "rimodernavo": "rimodernare",
    "rimodernerai": "rimodernare",
    "rimoderneran": "rimodernare",
    "rimoderneranno": "rimodernare",
    "rimodernerebbe": "rimodernare",
    "rimodernerebber": "rimodernare",
    "rimodernerebbero": "rimodernare",
    "rimodernerei": "rimodernare",
    "rimoderneremmo": "rimodernare",
    "rimoderneremo": "rimodernare",
    "rimodernereste": "rimodernare",
    "rimoderneresti": "rimodernare",
    "rimodernerete": "rimodernare",
    "rimodernerà": "rimodernare",
    "rimodernerò": "rimodernare",
    "rimoderni": "rimodernare",
    "rimoderniamo": "rimodernare",
    "rimoderniate": "rimodernare",
    "rimodernin": "rimodernare",
    "rimodernino": "rimodernare",
    "rimoderno": "rimodernare",
    "rimodernò": "rimodernare",
    "rimodulazioni": "rimodulazione",
    "rimonta": "rimontare",
    "rimontai": "rimontare",
    "rimontammo": "rimontare",
    "rimontan": "rimontare",
    "rimontando": "rimontare",
    "rimontano": "rimontare",
    "rimontante": "rimontare",
    "rimontanti": "rimontare",
    "rimontar": "rimontare",
    "rimontaron": "rimontare",
    "rimontarono": "rimontare",
    "rimontasse": "rimontare",
    "rimontasser": "rimontare",
    "rimontassero": "rimontare",
    "rimontassi": "rimontare",
    "rimontassimo": "rimontare",
    "rimontaste": "rimontare",
    "rimontasti": "rimontare",
    "rimontata": "rimontare",
    "rimontate": "rimontare",
    "rimontati": "rimontare",
    "rimontato": "rimontare",
    "rimontava": "rimontare",
    "rimontavamo": "rimontare",
    "rimontavan": "rimontare",
    "rimontavano": "rimontare",
    "rimontavate": "rimontare",
    "rimontavi": "rimontare",
    "rimontavo": "rimontare",
    "rimonte": "rimonta",
    "rimonterai": "rimontare",
    "rimonteran": "rimontare",
    "rimonteranno": "rimontare",
    "rimonterebbe": "rimontare",
    "rimonterebber": "rimontare",
    "rimonterebbero": "rimontare",
    "rimonterei": "rimontare",
    "rimonteremmo": "rimontare",
    "rimonteremo": "rimontare",
    "rimontereste": "rimontare",
    "rimonteresti": "rimontare",
    "rimonterete": "rimontare",
    "rimonterà": "rimontare",
    "rimonterò": "rimontare",
    "rimonti": "rimontare",
    "rimontiamo": "rimontare",
    "rimontiate": "rimontare",
    "rimontin": "rimontare",
    "rimontino": "rimontare",
    "rimonto": "rimontare",
    "rimontò": "rimontare",
    "rimorchi": "rimorchio",
    "rimorchia": "rimorchiare",
    "rimorchiai": "rimorchiare",
    "rimorchiammo": "rimorchiare",
    "rimorchiamo": "rimorchiare",
    "rimorchian": "rimorchiare",
    "rimorchiando": "rimorchiare",
    "rimorchiano": "rimorchiare",
    "rimorchiante": "rimorchiare",
    "rimorchianti": "rimorchiare",
    "rimorchiar": "rimorchiare",
    "rimorchiaron": "rimorchiare",
    "rimorchiarono": "rimorchiare",
    "rimorchiasse": "rimorchiare",
    "rimorchiasser": "rimorchiare",
    "rimorchiassero": "rimorchiare",
    "rimorchiassi": "rimorchiare",
    "rimorchiassimo": "rimorchiare",
    "rimorchiaste": "rimorchiare",
    "rimorchiasti": "rimorchiare",
    "rimorchiata": "rimorchiare",
    "rimorchiate": "rimorchiare",
    "rimorchiati": "rimorchiare",
    "rimorchiato": "rimorchiare",
    "rimorchiatori": "rimorchiatore",
    "rimorchiatrice": "rimorchiatore",
    "rimorchiatrici": "rimorchiatore",
    "rimorchiava": "rimorchiare",
    "rimorchiavamo": "rimorchiare",
    "rimorchiavan": "rimorchiare",
    "rimorchiavano": "rimorchiare",
    "rimorchiavate": "rimorchiare",
    "rimorchiavi": "rimorchiare",
    "rimorchiavo": "rimorchiare",
    "rimorchierai": "rimorchiare",
    "rimorchieran": "rimorchiare",
    "rimorchieranno": "rimorchiare",
    "rimorchierebbe": "rimorchiare",
    "rimorchierebber": "rimorchiare",
    "rimorchierebbero": "rimorchiare",
    "rimorchierei": "rimorchiare",
    "rimorchieremmo": "rimorchiare",
    "rimorchieremo": "rimorchiare",
    "rimorchiereste": "rimorchiare",
    "rimorchieresti": "rimorchiare",
    "rimorchierete": "rimorchiare",
    "rimorchierà": "rimorchiare",
    "rimorchierò": "rimorchiare",
    "rimorchin": "rimorchiare",
    "rimorchino": "rimorchiare",
    "rimorchio": "rimorchiare",
    "rimorchiò": "rimorchiare",
    "rimorda": "rimordere",
    "rimordan": "rimordere",
    "rimordano": "rimordere",
    "rimorde": "rimordere",
    "rimordemmo": "rimordere",
    "rimordendo": "rimordere",
    "rimordente": "rimordere",
    "rimordenti": "rimordere",
    "rimorder": "rimordere",
    "rimorderai": "rimordere",
    "rimorderan": "rimordere",
    "rimorderanno": "rimordere",
    "rimorderebbe": "rimordere",
    "rimorderebber": "rimordere",
    "rimorderebbero": "rimordere",
    "rimorderei": "rimordere",
    "rimorderemmo": "rimordere",
    "rimorderemo": "rimordere",
    "rimordereste": "rimordere",
    "rimorderesti": "rimordere",
    "rimorderete": "rimordere",
    "rimorderà": "rimordere",
    "rimorderò": "rimordere",
    "rimordesse": "rimordere",
    "rimordesser": "rimordere",
    "rimordessero": "rimordere",
    "rimordessi": "rimordere",
    "rimordessimo": "rimordere",
    "rimordeste": "rimordere",
    "rimordesti": "rimordere",
    "rimordete": "rimordere",
    "rimordeva": "rimordere",
    "rimordevamo": "rimordere",
    "rimordevan": "rimordere",
    "rimordevano": "rimordere",
    "rimordevate": "rimordere",
    "rimordevi": "rimordere",
    "rimordevo": "rimordere",
    "rimordi": "rimordere",
    "rimordiamo": "rimordere",
    "rimordiate": "rimordere",
    "rimordo": "rimordere",
    "rimordon": "rimordere",
    "rimordono": "rimordere",
    "rimorsa": "rimordere",
    "rimorse": "rimordere",
    "rimorser": "rimordere",
    "rimorsero": "rimordere",
    "rimorsi": "rimorso",
    "rimorso": "rimordere",
    "rimorsè": "rimordere",
    "rimossa": "rimuovere",
    "rimosse": "rimuovere",
    "rimosser": "rimuovere",
    "rimossero": "rimuovere",
    "rimossi": "rimuovere",
    "rimosso": "rimuovere",
    "rimostra": "rimostrare",
    "rimostrai": "rimostrare",
    "rimostrammo": "rimostrare",
    "rimostran": "rimostrare",
    "rimostrando": "rimostrare",
    "rimostrano": "rimostrare",
    "rimostrante": "rimostrare",
    "rimostranti": "rimostrare",
    "rimostranze": "rimostranza",
    "rimostrar": "rimostrare",
    "rimostraron": "rimostrare",
    "rimostrarono": "rimostrare",
    "rimostrasse": "rimostrare",
    "rimostrasser": "rimostrare",
    "rimostrassero": "rimostrare",
    "rimostrassi": "rimostrare",
    "rimostrassimo": "rimostrare",
    "rimostraste": "rimostrare",
    "rimostrasti": "rimostrare",
    "rimostrata": "rimostrare",
    "rimostrate": "rimostrare",
    "rimostrati": "rimostrare",
    "rimostrato": "rimostrare",
    "rimostrava": "rimostrare",
    "rimostravamo": "rimostrare",
    "rimostravan": "rimostrare",
    "rimostravano": "rimostrare",
    "rimostravate": "rimostrare",
    "rimostravi": "rimostrare",
    "rimostravo": "rimostrare",
    "rimostrerai": "rimostrare",
    "rimostreran": "rimostrare",
    "rimostreranno": "rimostrare",
    "rimostrerebbe": "rimostrare",
    "rimostrerebber": "rimostrare",
    "rimostrerebbero": "rimostrare",
    "rimostrerei": "rimostrare",
    "rimostreremmo": "rimostrare",
    "rimostreremo": "rimostrare",
    "rimostrereste": "rimostrare",
    "rimostreresti": "rimostrare",
    "rimostrerete": "rimostrare",
    "rimostrerà": "rimostrare",
    "rimostrerò": "rimostrare",
    "rimostri": "rimostrare",
    "rimostriamo": "rimostrare",
    "rimostriate": "rimostrare",
    "rimostrin": "rimostrare",
    "rimostrino": "rimostrare",
    "rimostro": "rimostrare",
    "rimostrò": "rimostrare",
    "rimozioni": "rimozione",
    "rimpacchetta": "rimpacchettare",
    "rimpacchettai": "rimpacchettare",
    "rimpacchettammo": "rimpacchettare",
    "rimpacchettan": "rimpacchettare",
    "rimpacchettando": "rimpacchettare",
    "rimpacchettano": "rimpacchettare",
    "rimpacchettante": "rimpacchettare",
    "rimpacchettanti": "rimpacchettare",
    "rimpacchettar": "rimpacchettare",
    "rimpacchettaron": "rimpacchettare",
    "rimpacchettarono": "rimpacchettare",
    "rimpacchettasse": "rimpacchettare",
    "rimpacchettasser": "rimpacchettare",
    "rimpacchettassero": "rimpacchettare",
    "rimpacchettassi": "rimpacchettare",
    "rimpacchettassimo": "rimpacchettare",
    "rimpacchettaste": "rimpacchettare",
    "rimpacchettasti": "rimpacchettare",
    "rimpacchettata": "rimpacchettare",
    "rimpacchettate": "rimpacchettare",
    "rimpacchettati": "rimpacchettare",
    "rimpacchettato": "rimpacchettare",
    "rimpacchettava": "rimpacchettare",
    "rimpacchettavamo": "rimpacchettare",
    "rimpacchettavan": "rimpacchettare",
    "rimpacchettavano": "rimpacchettare",
    "rimpacchettavate": "rimpacchettare",
    "rimpacchettavi": "rimpacchettare",
    "rimpacchettavo": "rimpacchettare",
    "rimpacchetterai": "rimpacchettare",
    "rimpacchetteran": "rimpacchettare",
    "rimpacchetteranno": "rimpacchettare",
    "rimpacchetterebbe": "rimpacchettare",
    "rimpacchetterebber": "rimpacchettare",
    "rimpacchetterebbero": "rimpacchettare",
    "rimpacchetterei": "rimpacchettare",
    "rimpacchetteremmo": "rimpacchettare",
    "rimpacchetteremo": "rimpacchettare",
    "rimpacchettereste": "rimpacchettare",
    "rimpacchetteresti": "rimpacchettare",
    "rimpacchetterete": "rimpacchettare",
    "rimpacchetterà": "rimpacchettare",
    "rimpacchetterò": "rimpacchettare",
    "rimpacchetti": "rimpacchettare",
    "rimpacchettiamo": "rimpacchettare",
    "rimpacchettiate": "rimpacchettare",
    "rimpacchettin": "rimpacchettare",
    "rimpacchettino": "rimpacchettare",
    "rimpacchetto": "rimpacchettare",
    "rimpacchettò": "rimpacchettare",
    "rimpalla": "rimpallare",
    "rimpallai": "rimpallare",
    "rimpallammo": "rimpallare",
    "rimpallan": "rimpallare",
    "rimpallando": "rimpallare",
    "rimpallano": "rimpallare",
    "rimpallante": "rimpallare",
    "rimpallanti": "rimpallare",
    "rimpallar": "rimpallare",
    "rimpallaron": "rimpallare",
    "rimpallarono": "rimpallare",
    "rimpallasse": "rimpallare",
    "rimpallasser": "rimpallare",
    "rimpallassero": "rimpallare",
    "rimpallassi": "rimpallare",
    "rimpallassimo": "rimpallare",
    "rimpallaste": "rimpallare",
    "rimpallasti": "rimpallare",
    "rimpallata": "rimpallare",
    "rimpallate": "rimpallare",
    "rimpallati": "rimpallare",
    "rimpallato": "rimpallare",
    "rimpallava": "rimpallare",
    "rimpallavamo": "rimpallare",
    "rimpallavan": "rimpallare",
    "rimpallavano": "rimpallare",
    "rimpallavate": "rimpallare",
    "rimpallavi": "rimpallare",
    "rimpallavo": "rimpallare",
    "rimpallerai": "rimpallare",
    "rimpalleran": "rimpallare",
    "rimpalleranno": "rimpallare",
    "rimpallerebbe": "rimpallare",
    "rimpallerebber": "rimpallare",
    "rimpallerebbero": "rimpallare",
    "rimpallerei": "rimpallare",
    "rimpalleremmo": "rimpallare",
    "rimpalleremo": "rimpallare",
    "rimpallereste": "rimpallare",
    "rimpalleresti": "rimpallare",
    "rimpallerete": "rimpallare",
    "rimpallerà": "rimpallare",
    "rimpallerò": "rimpallare",
    "rimpalli": "rimpallo",
    "rimpalliamo": "rimpallare",
    "rimpalliate": "rimpallare",
    "rimpallin": "rimpallare",
    "rimpallino": "rimpallare",
    "rimpallo": "rimpallare",
    "rimpallò": "rimpallare",
    "rimpannuccerai": "rimpannucciare",
    "rimpannucceran": "rimpannucciare",
    "rimpannucceranno": "rimpannucciare",
    "rimpannuccerebbe": "rimpannucciare",
    "rimpannuccerebber": "rimpannucciare",
    "rimpannuccerebbero": "rimpannucciare",
    "rimpannuccerei": "rimpannucciare",
    "rimpannucceremmo": "rimpannucciare",
    "rimpannucceremo": "rimpannucciare",
    "rimpannuccereste": "rimpannucciare",
    "rimpannucceresti": "rimpannucciare",
    "rimpannuccerete": "rimpannucciare",
    "rimpannuccerà": "rimpannucciare",
    "rimpannuccerò": "rimpannucciare",
    "rimpannucci": "rimpannucciare",
    "rimpannuccia": "rimpannucciare",
    "rimpannucciai": "rimpannucciare",
    "rimpannucciammo": "rimpannucciare",
    "rimpannucciamo": "rimpannucciare",
    "rimpannuccian": "rimpannucciare",
    "rimpannucciando": "rimpannucciare",
    "rimpannucciano": "rimpannucciare",
    "rimpannucciante": "rimpannucciare",
    "rimpannuccianti": "rimpannucciare",
    "rimpannucciar": "rimpannucciare",
    "rimpannucciaron": "rimpannucciare",
    "rimpannucciarono": "rimpannucciare",
    "rimpannucciasse": "rimpannucciare",
    "rimpannucciasser": "rimpannucciare",
    "rimpannucciassero": "rimpannucciare",
    "rimpannucciassi": "rimpannucciare",
    "rimpannucciassimo": "rimpannucciare",
    "rimpannucciaste": "rimpannucciare",
    "rimpannucciasti": "rimpannucciare",
    "rimpannucciata": "rimpannucciare",
    "rimpannucciate": "rimpannucciare",
    "rimpannucciati": "rimpannucciare",
    "rimpannucciato": "rimpannucciare",
    "rimpannucciava": "rimpannucciare",
    "rimpannucciavamo": "rimpannucciare",
    "rimpannucciavan": "rimpannucciare",
    "rimpannucciavano": "rimpannucciare",
    "rimpannucciavate": "rimpannucciare",
    "rimpannucciavi": "rimpannucciare",
    "rimpannucciavo": "rimpannucciare",
    "rimpannuccin": "rimpannucciare",
    "rimpannuccino": "rimpannucciare",
    "rimpannuccio": "rimpannucciare",
    "rimpannucciò": "rimpannucciare",
    "rimpasta": "rimpastare",
    "rimpastai": "rimpastare",
    "rimpastammo": "rimpastare",
    "rimpastan": "rimpastare",
    "rimpastando": "rimpastare",
    "rimpastano": "rimpastare",
    "rimpastante": "rimpastare",
    "rimpastanti": "rimpastare",
    "rimpastar": "rimpastare",
    "rimpastaron": "rimpastare",
    "rimpastarono": "rimpastare",
    "rimpastasse": "rimpastare",
    "rimpastasser": "rimpastare",
    "rimpastassero": "rimpastare",
    "rimpastassi": "rimpastare",
    "rimpastassimo": "rimpastare",
    "rimpastaste": "rimpastare",
    "rimpastasti": "rimpastare",
    "rimpastata": "rimpastare",
    "rimpastate": "rimpastare",
    "rimpastati": "rimpastare",
    "rimpastato": "rimpastare",
    "rimpastava": "rimpastare",
    "rimpastavamo": "rimpastare",
    "rimpastavan": "rimpastare",
    "rimpastavano": "rimpastare",
    "rimpastavate": "rimpastare",
    "rimpastavi": "rimpastare",
    "rimpastavo": "rimpastare",
    "rimpasterai": "rimpastare",
    "rimpasteran": "rimpastare",
    "rimpasteranno": "rimpastare",
    "rimpasterebbe": "rimpastare",
    "rimpasterebber": "rimpastare",
    "rimpasterebbero": "rimpastare",
    "rimpasterei": "rimpastare",
    "rimpasteremmo": "rimpastare",
    "rimpasteremo": "rimpastare",
    "rimpastereste": "rimpastare",
    "rimpasteresti": "rimpastare",
    "rimpasterete": "rimpastare",
    "rimpasterà": "rimpastare",
    "rimpasterò": "rimpastare",
    "rimpasti": "rimpasto",
    "rimpastiamo": "rimpastare",
    "rimpastiate": "rimpastare",
    "rimpastin": "rimpastare",
    "rimpastino": "rimpastare",
    "rimpasto": "rimpastare",
    "rimpastò": "rimpastare",
    "rimpatri": "rimpatrio",
    "rimpatria": "rimpatriare",
    "rimpatriai": "rimpatriare",
    "rimpatriammo": "rimpatriare",
    "rimpatriamo": "rimpatriare",
    "rimpatrian": "rimpatriare",
    "rimpatriando": "rimpatriare",
    "rimpatriano": "rimpatriare",
    "rimpatriante": "rimpatriare",
    "rimpatrianti": "rimpatriare",
    "rimpatriar": "rimpatriare",
    "rimpatriaron": "rimpatriare",
    "rimpatriarono": "rimpatriare",
    "rimpatriasse": "rimpatriare",
    "rimpatriasser": "rimpatriare",
    "rimpatriassero": "rimpatriare",
    "rimpatriassi": "rimpatriare",
    "rimpatriassimo": "rimpatriare",
    "rimpatriaste": "rimpatriare",
    "rimpatriasti": "rimpatriare",
    "rimpatriata": "rimpatriare",
    "rimpatriate": "rimpatriata",
    "rimpatriati": "rimpatriare",
    "rimpatriato": "rimpatriare",
    "rimpatriava": "rimpatriare",
    "rimpatriavamo": "rimpatriare",
    "rimpatriavan": "rimpatriare",
    "rimpatriavano": "rimpatriare",
    "rimpatriavate": "rimpatriare",
    "rimpatriavi": "rimpatriare",
    "rimpatriavo": "rimpatriare",
    "rimpatrierai": "rimpatriare",
    "rimpatrieran": "rimpatriare",
    "rimpatrieranno": "rimpatriare",
    "rimpatrierebbe": "rimpatriare",
    "rimpatrierebber": "rimpatriare",
    "rimpatrierebbero": "rimpatriare",
    "rimpatrierei": "rimpatriare",
    "rimpatrieremmo": "rimpatriare",
    "rimpatrieremo": "rimpatriare",
    "rimpatriereste": "rimpatriare",
    "rimpatrieresti": "rimpatriare",
    "rimpatrierete": "rimpatriare",
    "rimpatrierà": "rimpatriare",
    "rimpatrierò": "rimpatriare",
    "rimpatrin": "rimpatriare",
    "rimpatrino": "rimpatriare",
    "rimpatrio": "rimpatriare",
    "rimpatriò": "rimpatriare",
    "rimpianga": "rimpiangere",
    "rimpiangan": "rimpiangere",
    "rimpiangano": "rimpiangere",
    "rimpiange": "rimpiangere",
    "rimpiangemmo": "rimpiangere",
    "rimpiangendo": "rimpiangere",
    "rimpiangente": "rimpiangere",
    "rimpiangenti": "rimpiangere",
    "rimpianger": "rimpiangere",
    "rimpiangerai": "rimpiangere",
    "rimpiangeran": "rimpiangere",
    "rimpiangeranno": "rimpiangere",
    "rimpiangerebbe": "rimpiangere",
    "rimpiangerebber": "rimpiangere",
    "rimpiangerebbero": "rimpiangere",
    "rimpiangerei": "rimpiangere",
    "rimpiangeremmo": "rimpiangere",
    "rimpiangeremo": "rimpiangere",
    "rimpiangereste": "rimpiangere",
    "rimpiangeresti": "rimpiangere",
    "rimpiangerete": "rimpiangere",
    "rimpiangerà": "rimpiangere",
    "rimpiangerò": "rimpiangere",
    "rimpiangesse": "rimpiangere",
    "rimpiangesser": "rimpiangere",
    "rimpiangessero": "rimpiangere",
    "rimpiangessi": "rimpiangere",
    "rimpiangessimo": "rimpiangere",
    "rimpiangeste": "rimpiangere",
    "rimpiangesti": "rimpiangere",
    "rimpiangete": "rimpiangere",
    "rimpiangeva": "rimpiangere",
    "rimpiangevamo": "rimpiangere",
    "rimpiangevan": "rimpiangere",
    "rimpiangevano": "rimpiangere",
    "rimpiangevate": "rimpiangere",
    "rimpiangevi": "rimpiangere",
    "rimpiangevo": "rimpiangere",
    "rimpiangi": "rimpiangere",
    "rimpiangiamo": "rimpiangere",
    "rimpiangiate": "rimpiangere",
    "rimpiango": "rimpiangere",
    "rimpiangon": "rimpiangere",
    "rimpiangono": "rimpiangere",
    "rimpianser": "rimpiangere",
    "rimpiansero": "rimpiangere",
    "rimpiansi": "rimpiangere",
    "rimpiansè": "rimpiangere",
    "rimpianta": "rimpianto",
    "rimpiante": "rimpianto",
    "rimpianti": "rimpianto",
    "rimpianto": "rimpiangere",
    "rimpiatta": "rimpiattare",
    "rimpiattai": "rimpiattare",
    "rimpiattammo": "rimpiattare",
    "rimpiattan": "rimpiattare",
    "rimpiattando": "rimpiattare",
    "rimpiattano": "rimpiattare",
    "rimpiattante": "rimpiattare",
    "rimpiattanti": "rimpiattare",
    "rimpiattar": "rimpiattare",
    "rimpiattaron": "rimpiattare",
    "rimpiattarono": "rimpiattare",
    "rimpiattasse": "rimpiattare",
    "rimpiattasser": "rimpiattare",
    "rimpiattassero": "rimpiattare",
    "rimpiattassi": "rimpiattare",
    "rimpiattassimo": "rimpiattare",
    "rimpiattaste": "rimpiattare",
    "rimpiattasti": "rimpiattare",
    "rimpiattata": "rimpiattare",
    "rimpiattate": "rimpiattare",
    "rimpiattati": "rimpiattare",
    "rimpiattato": "rimpiattare",
    "rimpiattava": "rimpiattare",
    "rimpiattavamo": "rimpiattare",
    "rimpiattavan": "rimpiattare",
    "rimpiattavano": "rimpiattare",
    "rimpiattavate": "rimpiattare",
    "rimpiattavi": "rimpiattare",
    "rimpiattavo": "rimpiattare",
    "rimpiatterai": "rimpiattare",
    "rimpiatteran": "rimpiattare",
    "rimpiatteranno": "rimpiattare",
    "rimpiatterebbe": "rimpiattare",
    "rimpiatterebber": "rimpiattare",
    "rimpiatterebbero": "rimpiattare",
    "rimpiatterei": "rimpiattare",
    "rimpiatteremmo": "rimpiattare",
    "rimpiatteremo": "rimpiattare",
    "rimpiattereste": "rimpiattare",
    "rimpiatteresti": "rimpiattare",
    "rimpiatterete": "rimpiattare",
    "rimpiatterà": "rimpiattare",
    "rimpiatterò": "rimpiattare",
    "rimpiatti": "rimpiattare",
    "rimpiattiamo": "rimpiattare",
    "rimpiattiate": "rimpiattare",
    "rimpiattin": "rimpiattare",
    "rimpiattino": "rimpiattare",
    "rimpiatto": "rimpiattare",
    "rimpiattò": "rimpiattare",
    "rimpiazza": "rimpiazzare",
    "rimpiazzai": "rimpiazzare",
    "rimpiazzammo": "rimpiazzare",
    "rimpiazzan": "rimpiazzare",
    "rimpiazzando": "rimpiazzare",
    "rimpiazzano": "rimpiazzare",
    "rimpiazzante": "rimpiazzare",
    "rimpiazzanti": "rimpiazzare",
    "rimpiazzar": "rimpiazzare",
    "rimpiazzaron": "rimpiazzare",
    "rimpiazzarono": "rimpiazzare",
    "rimpiazzasse": "rimpiazzare",
    "rimpiazzasser": "rimpiazzare",
    "rimpiazzassero": "rimpiazzare",
    "rimpiazzassi": "rimpiazzare",
    "rimpiazzassimo": "rimpiazzare",
    "rimpiazzaste": "rimpiazzare",
    "rimpiazzasti": "rimpiazzare",
    "rimpiazzata": "rimpiazzare",
    "rimpiazzate": "rimpiazzare",
    "rimpiazzati": "rimpiazzare",
    "rimpiazzato": "rimpiazzare",
    "rimpiazzava": "rimpiazzare",
    "rimpiazzavamo": "rimpiazzare",
    "rimpiazzavan": "rimpiazzare",
    "rimpiazzavano": "rimpiazzare",
    "rimpiazzavate": "rimpiazzare",
    "rimpiazzavi": "rimpiazzare",
    "rimpiazzavo": "rimpiazzare",
    "rimpiazzerai": "rimpiazzare",
    "rimpiazzeran": "rimpiazzare",
    "rimpiazzeranno": "rimpiazzare",
    "rimpiazzerebbe": "rimpiazzare",
    "rimpiazzerebber": "rimpiazzare",
    "rimpiazzerebbero": "rimpiazzare",
    "rimpiazzerei": "rimpiazzare",
    "rimpiazzeremmo": "rimpiazzare",
    "rimpiazzeremo": "rimpiazzare",
    "rimpiazzereste": "rimpiazzare",
    "rimpiazzeresti": "rimpiazzare",
    "rimpiazzerete": "rimpiazzare",
    "rimpiazzerà": "rimpiazzare",
    "rimpiazzerò": "rimpiazzare",
    "rimpiazzi": "rimpiazzo",
    "rimpiazziamo": "rimpiazzare",
    "rimpiazziate": "rimpiazzare",
    "rimpiazzin": "rimpiazzare",
    "rimpiazzino": "rimpiazzare",
    "rimpiazzo": "rimpiazzare",
    "rimpiazzò": "rimpiazzare",
    "rimpiccola": "rimpiccolire",
    "rimpiccolan": "rimpiccolire",
    "rimpiccolano": "rimpiccolire",
    "rimpiccole": "rimpiccolire",
    "rimpiccolendo": "rimpiccolire",
    "rimpiccolente": "rimpiccolire",
    "rimpiccolenti": "rimpiccolire",
    "rimpiccoli": "rimpiccolire",
    "rimpiccoliamo": "rimpiccolire",
    "rimpiccoliate": "rimpiccolire",
    "rimpiccolii": "rimpiccolire",
    "rimpiccolimmo": "rimpiccolire",
    "rimpiccolir": "rimpiccolire",
    "rimpiccolirai": "rimpiccolire",
    "rimpiccoliran": "rimpiccolire",
    "rimpiccoliranno": "rimpiccolire",
    "rimpiccolirebbe": "rimpiccolire",
    "rimpiccolirebber": "rimpiccolire",
    "rimpiccolirebbero": "rimpiccolire",
    "rimpiccolirei": "rimpiccolire",
    "rimpiccoliremmo": "rimpiccolire",
    "rimpiccoliremo": "rimpiccolire",
    "rimpiccolireste": "rimpiccolire",
    "rimpiccoliresti": "rimpiccolire",
    "rimpiccolirete": "rimpiccolire",
    "rimpiccoliron": "rimpiccolire",
    "rimpiccolirono": "rimpiccolire",
    "rimpiccolirà": "rimpiccolire",
    "rimpiccolirò": "rimpiccolire",
    "rimpiccolisse": "rimpiccolire",
    "rimpiccolisser": "rimpiccolire",
    "rimpiccolissero": "rimpiccolire",
    "rimpiccolissi": "rimpiccolire",
    "rimpiccolissimo": "rimpiccolire",
    "rimpiccoliste": "rimpiccolire",
    "rimpiccolisti": "rimpiccolire",
    "rimpiccolita": "rimpiccolire",
    "rimpiccolite": "rimpiccolire",
    "rimpiccoliti": "rimpiccolire",
    "rimpiccolito": "rimpiccolire",
    "rimpiccoliva": "rimpiccolire",
    "rimpiccolivamo": "rimpiccolire",
    "rimpiccolivan": "rimpiccolire",
    "rimpiccolivano": "rimpiccolire",
    "rimpiccolivate": "rimpiccolire",
    "rimpiccolivi": "rimpiccolire",
    "rimpiccolivo": "rimpiccolire",
    "rimpiccolo": "rimpiccolire",
    "rimpiccolon": "rimpiccolire",
    "rimpiccolono": "rimpiccolire",
    "rimpiccolì": "rimpiccolire",
    "rimpingua": "rimpinguare",
    "rimpinguai": "rimpinguare",
    "rimpinguammo": "rimpinguare",
    "rimpinguan": "rimpinguare",
    "rimpinguando": "rimpinguare",
    "rimpinguano": "rimpinguare",
    "rimpinguante": "rimpinguare",
    "rimpinguanti": "rimpinguare",
    "rimpinguar": "rimpinguare",
    "rimpinguaron": "rimpinguare",
    "rimpinguarono": "rimpinguare",
    "rimpinguasse": "rimpinguare",
    "rimpinguasser": "rimpinguare",
    "rimpinguassero": "rimpinguare",
    "rimpinguassi": "rimpinguare",
    "rimpinguassimo": "rimpinguare",
    "rimpinguaste": "rimpinguare",
    "rimpinguasti": "rimpinguare",
    "rimpinguata": "rimpinguare",
    "rimpinguate": "rimpinguare",
    "rimpinguati": "rimpinguare",
    "rimpinguato": "rimpinguare",
    "rimpinguava": "rimpinguare",
    "rimpinguavamo": "rimpinguare",
    "rimpinguavan": "rimpinguare",
    "rimpinguavano": "rimpinguare",
    "rimpinguavate": "rimpinguare",
    "rimpinguavi": "rimpinguare",
    "rimpinguavo": "rimpinguare",
    "rimpinguerai": "rimpinguare",
    "rimpingueran": "rimpinguare",
    "rimpingueranno": "rimpinguare",
    "rimpinguerebbe": "rimpinguare",
    "rimpinguerebber": "rimpinguare",
    "rimpinguerebbero": "rimpinguare",
    "rimpinguerei": "rimpinguare",
    "rimpingueremmo": "rimpinguare",
    "rimpingueremo": "rimpinguare",
    "rimpinguereste": "rimpinguare",
    "rimpingueresti": "rimpinguare",
    "rimpinguerete": "rimpinguare",
    "rimpinguerà": "rimpinguare",
    "rimpinguerò": "rimpinguare",
    "rimpingui": "rimpinguare",
    "rimpinguiamo": "rimpinguare",
    "rimpinguiate": "rimpinguare",
    "rimpinguin": "rimpinguare",
    "rimpinguino": "rimpinguare",
    "rimpinguo": "rimpinguare",
    "rimpinguò": "rimpinguare",
    "rimpinza": "rimpinzare",
    "rimpinzai": "rimpinzare",
    "rimpinzammo": "rimpinzare",
    "rimpinzan": "rimpinzare",
    "rimpinzando": "rimpinzare",
    "rimpinzano": "rimpinzare",
    "rimpinzante": "rimpinzare",
    "rimpinzanti": "rimpinzare",
    "rimpinzar": "rimpinzare",
    "rimpinzaron": "rimpinzare",
    "rimpinzarono": "rimpinzare",
    "rimpinzasse": "rimpinzare",
    "rimpinzasser": "rimpinzare",
    "rimpinzassero": "rimpinzare",
    "rimpinzassi": "rimpinzare",
    "rimpinzassimo": "rimpinzare",
    "rimpinzaste": "rimpinzare",
    "rimpinzasti": "rimpinzare",
    "rimpinzata": "rimpinzare",
    "rimpinzate": "rimpinzare",
    "rimpinzati": "rimpinzare",
    "rimpinzato": "rimpinzare",
    "rimpinzava": "rimpinzare",
    "rimpinzavamo": "rimpinzare",
    "rimpinzavan": "rimpinzare",
    "rimpinzavano": "rimpinzare",
    "rimpinzavate": "rimpinzare",
    "rimpinzavi": "rimpinzare",
    "rimpinzavo": "rimpinzare",
    "rimpinzerai": "rimpinzare",
    "rimpinzeran": "rimpinzare",
    "rimpinzeranno": "rimpinzare",
    "rimpinzerebbe": "rimpinzare",
    "rimpinzerebber": "rimpinzare",
    "rimpinzerebbero": "rimpinzare",
    "rimpinzerei": "rimpinzare",
    "rimpinzeremmo": "rimpinzare",
    "rimpinzeremo": "rimpinzare",
    "rimpinzereste": "rimpinzare",
    "rimpinzeresti": "rimpinzare",
    "rimpinzerete": "rimpinzare",
    "rimpinzerà": "rimpinzare",
    "rimpinzerò": "rimpinzare",
    "rimpinzi": "rimpinzare",
    "rimpinziamo": "rimpinzare",
    "rimpinziate": "rimpinzare",
    "rimpinzin": "rimpinzare",
    "rimpinzino": "rimpinzare",
    "rimpinzo": "rimpinzare",
    "rimpinzò": "rimpinzare",
    "rimpolpa": "rimpolpare",
    "rimpolpai": "rimpolpare",
    "rimpolpammo": "rimpolpare",
    "rimpolpan": "rimpolpare",
    "rimpolpando": "rimpolpare",
    "rimpolpano": "rimpolpare",
    "rimpolpante": "rimpolpare",
    "rimpolpanti": "rimpolpare",
    "rimpolpar": "rimpolpare",
    "rimpolparon": "rimpolpare",
    "rimpolparono": "rimpolpare",
    "rimpolpasse": "rimpolpare",
    "rimpolpasser": "rimpolpare",
    "rimpolpassero": "rimpolpare",
    "rimpolpassi": "rimpolpare",
    "rimpolpassimo": "rimpolpare",
    "rimpolpaste": "rimpolpare",
    "rimpolpasti": "rimpolpare",
    "rimpolpata": "rimpolpare",
    "rimpolpate": "rimpolpare",
    "rimpolpati": "rimpolpare",
    "rimpolpato": "rimpolpare",
    "rimpolpava": "rimpolpare",
    "rimpolpavamo": "rimpolpare",
    "rimpolpavan": "rimpolpare",
    "rimpolpavano": "rimpolpare",
    "rimpolpavate": "rimpolpare",
    "rimpolpavi": "rimpolpare",
    "rimpolpavo": "rimpolpare",
    "rimpolperai": "rimpolpare",
    "rimpolperan": "rimpolpare",
    "rimpolperanno": "rimpolpare",
    "rimpolperebbe": "rimpolpare",
    "rimpolperebber": "rimpolpare",
    "rimpolperebbero": "rimpolpare",
    "rimpolperei": "rimpolpare",
    "rimpolperemmo": "rimpolpare",
    "rimpolperemo": "rimpolpare",
    "rimpolpereste": "rimpolpare",
    "rimpolperesti": "rimpolpare",
    "rimpolperete": "rimpolpare",
    "rimpolperà": "rimpolpare",
    "rimpolperò": "rimpolpare",
    "rimpolpi": "rimpolpare",
    "rimpolpiamo": "rimpolpare",
    "rimpolpiate": "rimpolpare",
    "rimpolpin": "rimpolpare",
    "rimpolpino": "rimpolpare",
    "rimpolpo": "rimpolpare",
    "rimpolpò": "rimpolpare",
    "rimpossessa": "rimpossessare",
    "rimpossessai": "rimpossessare",
    "rimpossessammo": "rimpossessare",
    "rimpossessan": "rimpossessare",
    "rimpossessando": "rimpossessare",
    "rimpossessano": "rimpossessare",
    "rimpossessar": "rimpossessare",
    "rimpossessaron": "rimpossessare",
    "rimpossessarono": "rimpossessare",
    "rimpossessasse": "rimpossessare",
    "rimpossessasser": "rimpossessare",
    "rimpossessassero": "rimpossessare",
    "rimpossessassi": "rimpossessare",
    "rimpossessassimo": "rimpossessare",
    "rimpossessaste": "rimpossessare",
    "rimpossessasti": "rimpossessare",
    "rimpossessata": "rimpossessare",
    "rimpossessate": "rimpossessare",
    "rimpossessati": "rimpossessare",
    "rimpossessato": "rimpossessare",
    "rimpossessava": "rimpossessare",
    "rimpossessavamo": "rimpossessare",
    "rimpossessavan": "rimpossessare",
    "rimpossessavano": "rimpossessare",
    "rimpossessavate": "rimpossessare",
    "rimpossessavi": "rimpossessare",
    "rimpossessavo": "rimpossessare",
    "rimpossesserai": "rimpossessare",
    "rimpossesseran": "rimpossessare",
    "rimpossesseranno": "rimpossessare",
    "rimpossesserebbe": "rimpossessare",
    "rimpossesserebber": "rimpossessare",
    "rimpossesserebbero": "rimpossessare",
    "rimpossesserei": "rimpossessare",
    "rimpossesseremmo": "rimpossessare",
    "rimpossesseremo": "rimpossessare",
    "rimpossessereste": "rimpossessare",
    "rimpossesseresti": "rimpossessare",
    "rimpossesserete": "rimpossessare",
    "rimpossesserà": "rimpossessare",
    "rimpossesserò": "rimpossessare",
    "rimpossessi": "rimpossessare",
    "rimpossessiamo": "rimpossessare",
    "rimpossessiate": "rimpossessare",
    "rimpossessin": "rimpossessare",
    "rimpossessino": "rimpossessare",
    "rimpossesso": "rimpossessare",
    "rimpossessò": "rimpossessare",
    "rimprovera": "rimproverare",
    "rimproverai": "rimproverare",
    "rimproverammo": "rimproverare",
    "rimproveran": "rimproverare",
    "rimproverando": "rimproverare",
    "rimproverano": "rimproverare",
    "rimproverante": "rimproverare",
    "rimproveranti": "rimproverare",
    "rimproverar": "rimproverare",
    "rimproveraron": "rimproverare",
    "rimproverarono": "rimproverare",
    "rimproverasse": "rimproverare",
    "rimproverasser": "rimproverare",
    "rimproverassero": "rimproverare",
    "rimproverassi": "rimproverare",
    "rimproverassimo": "rimproverare",
    "rimproveraste": "rimproverare",
    "rimproverasti": "rimproverare",
    "rimproverata": "rimproverare",
    "rimproverate": "rimproverare",
    "rimproverati": "rimproverare",
    "rimproverato": "rimproverare",
    "rimproverava": "rimproverare",
    "rimproveravamo": "rimproverare",
    "rimproveravan": "rimproverare",
    "rimproveravano": "rimproverare",
    "rimproveravate": "rimproverare",
    "rimproveravi": "rimproverare",
    "rimproveravo": "rimproverare",
    "rimprovererai": "rimproverare",
    "rimprovereran": "rimproverare",
    "rimprovereranno": "rimproverare",
    "rimprovererebbe": "rimproverare",
    "rimprovererebber": "rimproverare",
    "rimprovererebbero": "rimproverare",
    "rimprovererei": "rimproverare",
    "rimprovereremmo": "rimproverare",
    "rimprovereremo": "rimproverare",
    "rimproverereste": "rimproverare",
    "rimprovereresti": "rimproverare",
    "rimprovererete": "rimproverare",
    "rimprovererà": "rimproverare",
    "rimprovererò": "rimproverare",
    "rimproveri": "rimprovero",
    "rimproveriamo": "rimproverare",
    "rimproveriate": "rimproverare",
    "rimproverin": "rimproverare",
    "rimproverino": "rimproverare",
    "rimprovero": "rimproverare",
    "rimproverò": "rimproverare",
    "rimugina": "rimuginare",
    "rimuginai": "rimuginare",
    "rimuginammo": "rimuginare",
    "rimuginan": "rimuginare",
    "rimuginando": "rimuginare",
    "rimuginano": "rimuginare",
    "rimuginante": "rimuginare",
    "rimuginanti": "rimuginare",
    "rimuginar": "rimuginare",
    "rimuginaron": "rimuginare",
    "rimuginarono": "rimuginare",
    "rimuginasse": "rimuginare",
    "rimuginasser": "rimuginare",
    "rimuginassero": "rimuginare",
    "rimuginassi": "rimuginare",
    "rimuginassimo": "rimuginare",
    "rimuginaste": "rimuginare",
    "rimuginasti": "rimuginare",
    "rimuginata": "rimuginare",
    "rimuginate": "rimuginare",
    "rimuginati": "rimuginare",
    "rimuginato": "rimuginare",
    "rimuginava": "rimuginare",
    "rimuginavamo": "rimuginare",
    "rimuginavan": "rimuginare",
    "rimuginavano": "rimuginare",
    "rimuginavate": "rimuginare",
    "rimuginavi": "rimuginare",
    "rimuginavo": "rimuginare",
    "rimuginerai": "rimuginare",
    "rimugineran": "rimuginare",
    "rimugineranno": "rimuginare",
    "rimuginerebbe": "rimuginare",
    "rimuginerebber": "rimuginare",
    "rimuginerebbero": "rimuginare",
    "rimuginerei": "rimuginare",
    "rimugineremmo": "rimuginare",
    "rimugineremo": "rimuginare",
    "rimuginereste": "rimuginare",
    "rimugineresti": "rimuginare",
    "rimuginerete": "rimuginare",
    "rimuginerà": "rimuginare",
    "rimuginerò": "rimuginare",
    "rimugini": "rimuginare",
    "rimuginiamo": "rimuginare",
    "rimuginiate": "rimuginare",
    "rimuginin": "rimuginare",
    "rimuginino": "rimuginare",
    "rimugino": "rimuginare",
    "rimuginò": "rimuginare",
    "rimunera": "rimunerare",
    "rimunerai": "rimunerare",
    "rimunerammo": "rimunerare",
    "rimuneran": "rimunerare",
    "rimunerando": "rimunerare",
    "rimunerano": "rimunerare",
    "rimunerante": "rimunerare",
    "rimuneranti": "rimunerare",
    "rimunerar": "rimunerare",
    "rimuneraron": "rimunerare",
    "rimunerarono": "rimunerare",
    "rimunerasse": "rimunerare",
    "rimunerasser": "rimunerare",
    "rimunerassero": "rimunerare",
    "rimunerassi": "rimunerare",
    "rimunerassimo": "rimunerare",
    "rimuneraste": "rimunerare",
    "rimunerasti": "rimunerare",
    "rimunerata": "rimunerare",
    "rimunerate": "rimunerare",
    "rimunerati": "rimunerare",
    "rimunerato": "rimunerare",
    "rimunerava": "rimunerare",
    "rimuneravamo": "rimunerare",
    "rimuneravan": "rimunerare",
    "rimuneravano": "rimunerare",
    "rimuneravate": "rimunerare",
    "rimuneravi": "rimunerare",
    "rimuneravo": "rimunerare",
    "rimunererai": "rimunerare",
    "rimunereran": "rimunerare",
    "rimunereranno": "rimunerare",
    "rimunererebbe": "rimunerare",
    "rimunererebber": "rimunerare",
    "rimunererebbero": "rimunerare",
    "rimunererei": "rimunerare",
    "rimunereremmo": "rimunerare",
    "rimunereremo": "rimunerare",
    "rimunerereste": "rimunerare",
    "rimunereresti": "rimunerare",
    "rimunererete": "rimunerare",
    "rimunererà": "rimunerare",
    "rimunererò": "rimunerare",
    "rimuneri": "rimunerare",
    "rimuneriamo": "rimunerare",
    "rimuneriate": "rimunerare",
    "rimunerin": "rimunerare",
    "rimunerino": "rimunerare",
    "rimunero": "rimunerare",
    "rimunerò": "rimunerare",
    "rimuova": "rimuovere",
    "rimuovan": "rimuovere",
    "rimuovano": "rimuovere",
    "rimuove": "rimuovere",
    "rimuovemmo": "rimuovere",
    "rimuovendo": "rimuovere",
    "rimuovente": "rimuovere",
    "rimuoventi": "rimuovere",
    "rimuover": "rimuovere",
    "rimuoverai": "rimuovere",
    "rimuoveran": "rimuovere",
    "rimuoveranno": "rimuovere",
    "rimuoverebbe": "rimuovere",
    "rimuoverebber": "rimuovere",
    "rimuoverebbero": "rimuovere",
    "rimuoverei": "rimuovere",
    "rimuoveremmo": "rimuovere",
    "rimuoveremo": "rimuovere",
    "rimuovereste": "rimuovere",
    "rimuoveresti": "rimuovere",
    "rimuoverete": "rimuovere",
    "rimuoverà": "rimuovere",
    "rimuoverò": "rimuovere",
    "rimuovesse": "rimuovere",
    "rimuovesser": "rimuovere",
    "rimuovessero": "rimuovere",
    "rimuovessi": "rimuovere",
    "rimuovessimo": "rimuovere",
    "rimuoveste": "rimuovere",
    "rimuovesti": "rimuovere",
    "rimuovete": "rimuovere",
    "rimuoveva": "rimuovere",
    "rimuovevamo": "rimuovere",
    "rimuovevan": "rimuovere",
    "rimuovevano": "rimuovere",
    "rimuovevate": "rimuovere",
    "rimuovevi": "rimuovere",
    "rimuovevo": "rimuovere",
    "rimuovi": "rimuovere",
    "rimuoviamo": "rimuovere",
    "rimuoviate": "rimuovere",
    "rimuovo": "rimuovere",
    "rimuovon": "rimuovere",
    "rimuovono": "rimuovere",
    "rimuta": "rimutare",
    "rimutai": "rimutare",
    "rimutammo": "rimutare",
    "rimutan": "rimutare",
    "rimutando": "rimutare",
    "rimutano": "rimutare",
    "rimutante": "rimutare",
    "rimutanti": "rimutare",
    "rimutar": "rimutare",
    "rimutaron": "rimutare",
    "rimutarono": "rimutare",
    "rimutasse": "rimutare",
    "rimutasser": "rimutare",
    "rimutassero": "rimutare",
    "rimutassi": "rimutare",
    "rimutassimo": "rimutare",
    "rimutaste": "rimutare",
    "rimutasti": "rimutare",
    "rimutata": "rimutare",
    "rimutate": "rimutare",
    "rimutati": "rimutare",
    "rimutato": "rimutare",
    "rimutava": "rimutare",
    "rimutavamo": "rimutare",
    "rimutavan": "rimutare",
    "rimutavano": "rimutare",
    "rimutavate": "rimutare",
    "rimutavi": "rimutare",
    "rimutavo": "rimutare",
    "rimuterai": "rimutare",
    "rimuteran": "rimutare",
    "rimuteranno": "rimutare",
    "rimuterebbe": "rimutare",
    "rimuterebber": "rimutare",
    "rimuterebbero": "rimutare",
    "rimuterei": "rimutare",
    "rimuteremmo": "rimutare",
    "rimuteremo": "rimutare",
    "rimutereste": "rimutare",
    "rimuteresti": "rimutare",
    "rimuterete": "rimutare",
    "rimuterà": "rimutare",
    "rimuterò": "rimutare",
    "rimuti": "rimutare",
    "rimutiamo": "rimutare",
    "rimutiate": "rimutare",
    "rimutin": "rimutare",
    "rimutino": "rimutare",
    "rimuto": "rimutare",
    "rimutò": "rimutare",
    "rimò": "rimare",
    "rinacque": "rinascere",
    "rinacquer": "rinascere",
    "rinacquero": "rinascere",
    "rinacqui": "rinascere",
    "rinasca": "rinascere",
    "rinascan": "rinascere",
    "rinascano": "rinascere",
    "rinasce": "rinascere",
    "rinascemmo": "rinascere",
    "rinascendo": "rinascere",
    "rinascente": "rinascere",
    "rinascenti": "rinascere",
    "rinascer": "rinascere",
    "rinascerai": "rinascere",
    "rinasceran": "rinascere",
    "rinasceranno": "rinascere",
    "rinascerebbe": "rinascere",
    "rinascerebber": "rinascere",
    "rinascerebbero": "rinascere",
    "rinascerei": "rinascere",
    "rinasceremmo": "rinascere",
    "rinasceremo": "rinascere",
    "rinascereste": "rinascere",
    "rinasceresti": "rinascere",
    "rinascerete": "rinascere",
    "rinascerà": "rinascere",
    "rinascerò": "rinascere",
    "rinascesse": "rinascere",
    "rinascesser": "rinascere",
    "rinascessero": "rinascere",
    "rinascessi": "rinascere",
    "rinascessimo": "rinascere",
    "rinasceste": "rinascere",
    "rinascesti": "rinascere",
    "rinascete": "rinascere",
    "rinasceva": "rinascere",
    "rinascevamo": "rinascere",
    "rinascevan": "rinascere",
    "rinascevano": "rinascere",
    "rinascevate": "rinascere",
    "rinascevi": "rinascere",
    "rinascevo": "rinascere",
    "rinasci": "rinascere",
    "rinasciamo": "rinascere",
    "rinasciate": "rinascere",
    "rinascimentali": "rinascimentale",
    "rinascimenti": "rinascimento",
    "rinascite": "rinascita",
    "rinasco": "rinascere",
    "rinascon": "rinascere",
    "rinascono": "rinascere",
    "rinata": "rinascere",
    "rinate": "rinata",
    "rinati": "rinato",
    "rinato": "rinascere",
    "rinazionalizza": "rinazionalizzare",
    "rinazionalizzai": "rinazionalizzare",
    "rinazionalizzammo": "rinazionalizzare",
    "rinazionalizzan": "rinazionalizzare",
    "rinazionalizzando": "rinazionalizzare",
    "rinazionalizzano": "rinazionalizzare",
    "rinazionalizzante": "rinazionalizzare",
    "rinazionalizzanti": "rinazionalizzare",
    "rinazionalizzar": "rinazionalizzare",
    "rinazionalizzaron": "rinazionalizzare",
    "rinazionalizzarono": "rinazionalizzare",
    "rinazionalizzasse": "rinazionalizzare",
    "rinazionalizzasser": "rinazionalizzare",
    "rinazionalizzassero": "rinazionalizzare",
    "rinazionalizzassi": "rinazionalizzare",
    "rinazionalizzassimo": "rinazionalizzare",
    "rinazionalizzaste": "rinazionalizzare",
    "rinazionalizzasti": "rinazionalizzare",
    "rinazionalizzata": "rinazionalizzare",
    "rinazionalizzate": "rinazionalizzare",
    "rinazionalizzati": "rinazionalizzare",
    "rinazionalizzato": "rinazionalizzare",
    "rinazionalizzava": "rinazionalizzare",
    "rinazionalizzavamo": "rinazionalizzare",
    "rinazionalizzavan": "rinazionalizzare",
    "rinazionalizzavano": "rinazionalizzare",
    "rinazionalizzavate": "rinazionalizzare",
    "rinazionalizzavi": "rinazionalizzare",
    "rinazionalizzavo": "rinazionalizzare",
    "rinazionalizzerai": "rinazionalizzare",
    "rinazionalizzeran": "rinazionalizzare",
    "rinazionalizzeranno": "rinazionalizzare",
    "rinazionalizzerebbe": "rinazionalizzare",
    "rinazionalizzerebber": "rinazionalizzare",
    "rinazionalizzerebbero": "rinazionalizzare",
    "rinazionalizzerei": "rinazionalizzare",
    "rinazionalizzeremmo": "rinazionalizzare",
    "rinazionalizzeremo": "rinazionalizzare",
    "rinazionalizzereste": "rinazionalizzare",
    "rinazionalizzeresti": "rinazionalizzare",
    "rinazionalizzerete": "rinazionalizzare",
    "rinazionalizzerà": "rinazionalizzare",
    "rinazionalizzerò": "rinazionalizzare",
    "rinazionalizzi": "rinazionalizzare",
    "rinazionalizziamo": "rinazionalizzare",
    "rinazionalizziate": "rinazionalizzare",
    "rinazionalizzin": "rinazionalizzare",
    "rinazionalizzino": "rinazionalizzare",
    "rinazionalizzo": "rinazionalizzare",
    "rinazionalizzò": "rinazionalizzare",
    "rincagna": "rincagnare",
    "rincagnai": "rincagnare",
    "rincagnammo": "rincagnare",
    "rincagnan": "rincagnare",
    "rincagnando": "rincagnare",
    "rincagnano": "rincagnare",
    "rincagnar": "rincagnare",
    "rincagnaron": "rincagnare",
    "rincagnarono": "rincagnare",
    "rincagnasse": "rincagnare",
    "rincagnasser": "rincagnare",
    "rincagnassero": "rincagnare",
    "rincagnassi": "rincagnare",
    "rincagnassimo": "rincagnare",
    "rincagnaste": "rincagnare",
    "rincagnasti": "rincagnare",
    "rincagnata": "rincagnare",
    "rincagnate": "rincagnare",
    "rincagnati": "rincagnare",
    "rincagnato": "rincagnare",
    "rincagnava": "rincagnare",
    "rincagnavamo": "rincagnare",
    "rincagnavan": "rincagnare",
    "rincagnavano": "rincagnare",
    "rincagnavate": "rincagnare",
    "rincagnavi": "rincagnare",
    "rincagnavo": "rincagnare",
    "rincagnerai": "rincagnare",
    "rincagneran": "rincagnare",
    "rincagneranno": "rincagnare",
    "rincagnerebbe": "rincagnare",
    "rincagnerebber": "rincagnare",
    "rincagnerebbero": "rincagnare",
    "rincagnerei": "rincagnare",
    "rincagneremmo": "rincagnare",
    "rincagneremo": "rincagnare",
    "rincagnereste": "rincagnare",
    "rincagneresti": "rincagnare",
    "rincagnerete": "rincagnare",
    "rincagnerà": "rincagnare",
    "rincagnerò": "rincagnare",
    "rincagni": "rincagnare",
    "rincagniamo": "rincagnare",
    "rincagniate": "rincagnare",
    "rincagnin": "rincagnare",
    "rincagnino": "rincagnare",
    "rincagno": "rincagnare",
    "rincagnò": "rincagnare",
    "rincalzi": "rincalzo",
    "rincantuccerai": "rincantucciare",
    "rincantucceran": "rincantucciare",
    "rincantucceranno": "rincantucciare",
    "rincantuccerebbe": "rincantucciare",
    "rincantuccerebber": "rincantucciare",
    "rincantuccerebbero": "rincantucciare",
    "rincantuccerei": "rincantucciare",
    "rincantucceremmo": "rincantucciare",
    "rincantucceremo": "rincantucciare",
    "rincantuccereste": "rincantucciare",
    "rincantucceresti": "rincantucciare",
    "rincantuccerete": "rincantucciare",
    "rincantuccerà": "rincantucciare",
    "rincantuccerò": "rincantucciare",
    "rincantucci": "rincantucciare",
    "rincantuccia": "rincantucciare",
    "rincantucciai": "rincantucciare",
    "rincantucciammo": "rincantucciare",
    "rincantucciamo": "rincantucciare",
    "rincantuccian": "rincantucciare",
    "rincantucciando": "rincantucciare",
    "rincantucciano": "rincantucciare",
    "rincantucciante": "rincantucciare",
    "rincantuccianti": "rincantucciare",
    "rincantucciar": "rincantucciare",
    "rincantucciaron": "rincantucciare",
    "rincantucciarono": "rincantucciare",
    "rincantucciasse": "rincantucciare",
    "rincantucciasser": "rincantucciare",
    "rincantucciassero": "rincantucciare",
    "rincantucciassi": "rincantucciare",
    "rincantucciassimo": "rincantucciare",
    "rincantucciaste": "rincantucciare",
    "rincantucciasti": "rincantucciare",
    "rincantucciata": "rincantucciare",
    "rincantucciate": "rincantucciare",
    "rincantucciati": "rincantucciare",
    "rincantucciato": "rincantucciare",
    "rincantucciava": "rincantucciare",
    "rincantucciavamo": "rincantucciare",
    "rincantucciavan": "rincantucciare",
    "rincantucciavano": "rincantucciare",
    "rincantucciavate": "rincantucciare",
    "rincantucciavi": "rincantucciare",
    "rincantucciavo": "rincantucciare",
    "rincantuccin": "rincantucciare",
    "rincantuccino": "rincantucciare",
    "rincantuccio": "rincantucciare",
    "rincantucciò": "rincantucciare",
    "rincara": "rincarare",
    "rincarai": "rincarare",
    "rincarammo": "rincarare",
    "rincaran": "rincarare",
    "rincarando": "rincarare",
    "rincarano": "rincarare",
    "rincarante": "rincarare",
    "rincaranti": "rincarare",
    "rincarar": "rincarare",
    "rincararon": "rincarare",
    "rincararono": "rincarare",
    "rincarasse": "rincarare",
    "rincarasser": "rincarare",
    "rincarassero": "rincarare",
    "rincarassi": "rincarare",
    "rincarassimo": "rincarare",
    "rincaraste": "rincarare",
    "rincarasti": "rincarare",
    "rincarata": "rincarare",
    "rincarate": "rincarare",
    "rincarati": "rincarare",
    "rincarato": "rincarare",
    "rincarava": "rincarare",
    "rincaravamo": "rincarare",
    "rincaravan": "rincarare",
    "rincaravano": "rincarare",
    "rincaravate": "rincarare",
    "rincaravi": "rincarare",
    "rincaravo": "rincarare",
    "rincarerai": "rincarare",
    "rincareran": "rincarare",
    "rincareranno": "rincarare",
    "rincarerebbe": "rincarare",
    "rincarerebber": "rincarare",
    "rincarerebbero": "rincarare",
    "rincarerei": "rincarare",
    "rincareremmo": "rincarare",
    "rincareremo": "rincarare",
    "rincarereste": "rincarare",
    "rincareresti": "rincarare",
    "rincarerete": "rincarare",
    "rincarerà": "rincarare",
    "rincarerò": "rincarare",
    "rincari": "rincaro",
    "rincariamo": "rincarare",
    "rincariate": "rincarare",
    "rincarin": "rincarare",
    "rincarino": "rincarare",
    "rincaro": "rincarare",
    "rincarò": "rincarare",
    "rincasa": "rincasare",
    "rincasai": "rincasare",
    "rincasammo": "rincasare",
    "rincasan": "rincasare",
    "rincasando": "rincasare",
    "rincasano": "rincasare",
    "rincasante": "rincasare",
    "rincasanti": "rincasare",
    "rincasar": "rincasare",
    "rincasaron": "rincasare",
    "rincasarono": "rincasare",
    "rincasasse": "rincasare",
    "rincasasser": "rincasare",
    "rincasassero": "rincasare",
    "rincasassi": "rincasare",
    "rincasassimo": "rincasare",
    "rincasaste": "rincasare",
    "rincasasti": "rincasare",
    "rincasata": "rincasare",
    "rincasate": "rincasare",
    "rincasati": "rincasare",
    "rincasato": "rincasare",
    "rincasava": "rincasare",
    "rincasavamo": "rincasare",
    "rincasavan": "rincasare",
    "rincasavano": "rincasare",
    "rincasavate": "rincasare",
    "rincasavi": "rincasare",
    "rincasavo": "rincasare",
    "rincaserai": "rincasare",
    "rincaseran": "rincasare",
    "rincaseranno": "rincasare",
    "rincaserebbe": "rincasare",
    "rincaserebber": "rincasare",
    "rincaserebbero": "rincasare",
    "rincaserei": "rincasare",
    "rincaseremmo": "rincasare",
    "rincaseremo": "rincasare",
    "rincasereste": "rincasare",
    "rincaseresti": "rincasare",
    "rincaserete": "rincasare",
    "rincaserà": "rincasare",
    "rincaserò": "rincasare",
    "rincasi": "rincasare",
    "rincasiamo": "rincasare",
    "rincasiate": "rincasare",
    "rincasin": "rincasare",
    "rincasino": "rincasare",
    "rincaso": "rincasare",
    "rincasò": "rincasare",
    "rinchiuda": "rinchiudere",
    "rinchiudan": "rinchiudere",
    "rinchiudano": "rinchiudere",
    "rinchiude": "rinchiudere",
    "rinchiudemmo": "rinchiudere",
    "rinchiudendo": "rinchiudere",
    "rinchiudente": "rinchiudere",
    "rinchiudenti": "rinchiudere",
    "rinchiuder": "rinchiudere",
    "rinchiuderai": "rinchiudere",
    "rinchiuderan": "rinchiudere",
    "rinchiuderanno": "rinchiudere",
    "rinchiuderebbe": "rinchiudere",
    "rinchiuderebber": "rinchiudere",
    "rinchiuderebbero": "rinchiudere",
    "rinchiuderei": "rinchiudere",
    "rinchiuderemmo": "rinchiudere",
    "rinchiuderemo": "rinchiudere",
    "rinchiudereste": "rinchiudere",
    "rinchiuderesti": "rinchiudere",
    "rinchiuderete": "rinchiudere",
    "rinchiuderà": "rinchiudere",
    "rinchiuderò": "rinchiudere",
    "rinchiudesse": "rinchiudere",
    "rinchiudesser": "rinchiudere",
    "rinchiudessero": "rinchiudere",
    "rinchiudessi": "rinchiudere",
    "rinchiudessimo": "rinchiudere",
    "rinchiudeste": "rinchiudere",
    "rinchiudesti": "rinchiudere",
    "rinchiudete": "rinchiudere",
    "rinchiudeva": "rinchiudere",
    "rinchiudevamo": "rinchiudere",
    "rinchiudevan": "rinchiudere",
    "rinchiudevano": "rinchiudere",
    "rinchiudevate": "rinchiudere",
    "rinchiudevi": "rinchiudere",
    "rinchiudevo": "rinchiudere",
    "rinchiudi": "rinchiudere",
    "rinchiudiamo": "rinchiudere",
    "rinchiudiate": "rinchiudere",
    "rinchiudo": "rinchiudere",
    "rinchiudon": "rinchiudere",
    "rinchiudono": "rinchiudere",
    "rinchiusa": "rinchiuso",
    "rinchiuse": "rinchiuso",
    "rinchiuser": "rinchiudere",
    "rinchiusero": "rinchiudere",
    "rinchiusi": "rinchiuso",
    "rinchiuso": "rinchiudere",
    "rincitrulla": "rincitrullire",
    "rincitrullan": "rincitrullire",
    "rincitrullano": "rincitrullire",
    "rincitrulle": "rincitrullire",
    "rincitrullendo": "rincitrullire",
    "rincitrullente": "rincitrullire",
    "rincitrullenti": "rincitrullire",
    "rincitrulli": "rincitrullire",
    "rincitrulliamo": "rincitrullire",
    "rincitrulliate": "rincitrullire",
    "rincitrullii": "rincitrullire",
    "rincitrullimmo": "rincitrullire",
    "rincitrullir": "rincitrullire",
    "rincitrullirai": "rincitrullire",
    "rincitrulliran": "rincitrullire",
    "rincitrulliranno": "rincitrullire",
    "rincitrullirebbe": "rincitrullire",
    "rincitrullirebber": "rincitrullire",
    "rincitrullirebbero": "rincitrullire",
    "rincitrullirei": "rincitrullire",
    "rincitrulliremmo": "rincitrullire",
    "rincitrulliremo": "rincitrullire",
    "rincitrullireste": "rincitrullire",
    "rincitrulliresti": "rincitrullire",
    "rincitrullirete": "rincitrullire",
    "rincitrulliron": "rincitrullire",
    "rincitrullirono": "rincitrullire",
    "rincitrullirà": "rincitrullire",
    "rincitrullirò": "rincitrullire",
    "rincitrullisse": "rincitrullire",
    "rincitrullisser": "rincitrullire",
    "rincitrullissero": "rincitrullire",
    "rincitrullissi": "rincitrullire",
    "rincitrullissimo": "rincitrullire",
    "rincitrulliste": "rincitrullire",
    "rincitrullisti": "rincitrullire",
    "rincitrullita": "rincitrullire",
    "rincitrullite": "rincitrullire",
    "rincitrulliti": "rincitrullire",
    "rincitrullito": "rincitrullire",
    "rincitrulliva": "rincitrullire",
    "rincitrullivamo": "rincitrullire",
    "rincitrullivan": "rincitrullire",
    "rincitrullivano": "rincitrullire",
    "rincitrullivate": "rincitrullire",
    "rincitrullivi": "rincitrullire",
    "rincitrullivo": "rincitrullire",
    "rincitrullo": "rincitrullire",
    "rincitrullon": "rincitrullire",
    "rincitrullono": "rincitrullire",
    "rincitrullì": "rincitrullire",
    "rincivila": "rincivilire",
    "rincivilan": "rincivilire",
    "rincivilano": "rincivilire",
    "rincivile": "rincivilire",
    "rincivilendo": "rincivilire",
    "rincivilente": "rincivilire",
    "rincivilenti": "rincivilire",
    "rincivili": "rincivilire",
    "rinciviliamo": "rincivilire",
    "rinciviliate": "rincivilire",
    "rincivilii": "rincivilire",
    "rincivilimmo": "rincivilire",
    "rincivilir": "rincivilire",
    "rincivilirai": "rincivilire",
    "rinciviliran": "rincivilire",
    "rinciviliranno": "rincivilire",
    "rincivilirebbe": "rincivilire",
    "rincivilirebber": "rincivilire",
    "rincivilirebbero": "rincivilire",
    "rincivilirei": "rincivilire",
    "rinciviliremmo": "rincivilire",
    "rinciviliremo": "rincivilire",
    "rincivilireste": "rincivilire",
    "rinciviliresti": "rincivilire",
    "rincivilirete": "rincivilire",
    "rinciviliron": "rincivilire",
    "rincivilirono": "rincivilire",
    "rincivilirà": "rincivilire",
    "rincivilirò": "rincivilire",
    "rincivilisse": "rincivilire",
    "rincivilisser": "rincivilire",
    "rincivilissero": "rincivilire",
    "rincivilissi": "rincivilire",
    "rincivilissimo": "rincivilire",
    "rinciviliste": "rincivilire",
    "rincivilisti": "rincivilire",
    "rincivilita": "rincivilire",
    "rincivilite": "rincivilire",
    "rinciviliti": "rincivilire",
    "rincivilito": "rincivilire",
    "rinciviliva": "rincivilire",
    "rincivilivamo": "rincivilire",
    "rincivilivan": "rincivilire",
    "rincivilivano": "rincivilire",
    "rincivilivate": "rincivilire",
    "rincivilivi": "rincivilire",
    "rincivilivo": "rincivilire",
    "rincivilo": "rincivilire",
    "rincivilon": "rincivilire",
    "rincivilono": "rincivilire",
    "rincivilì": "rincivilire",
    "rincogliona": "rincoglionire",
    "rincoglionan": "rincoglionire",
    "rincoglionano": "rincoglionire",
    "rincoglione": "rincoglionire",
    "rincoglionendo": "rincoglionire",
    "rincoglionente": "rincoglionire",
    "rincoglionenti": "rincoglionire",
    "rincoglioni": "rincoglionire",
    "rincoglioniamo": "rincoglionire",
    "rincoglioniate": "rincoglionire",
    "rincoglionii": "rincoglionire",
    "rincoglionimmo": "rincoglionire",
    "rincoglionir": "rincoglionire",
    "rincoglionirai": "rincoglionire",
    "rincoglioniran": "rincoglionire",
    "rincoglioniranno": "rincoglionire",
    "rincoglionirebbe": "rincoglionire",
    "rincoglionirebber": "rincoglionire",
    "rincoglionirebbero": "rincoglionire",
    "rincoglionirei": "rincoglionire",
    "rincoglioniremmo": "rincoglionire",
    "rincoglioniremo": "rincoglionire",
    "rincoglionireste": "rincoglionire",
    "rincoglioniresti": "rincoglionire",
    "rincoglionirete": "rincoglionire",
    "rincoglioniron": "rincoglionire",
    "rincoglionirono": "rincoglionire",
    "rincoglionirà": "rincoglionire",
    "rincoglionirò": "rincoglionire",
    "rincoglionisse": "rincoglionire",
    "rincoglionisser": "rincoglionire",
    "rincoglionissero": "rincoglionire",
    "rincoglionissi": "rincoglionire",
    "rincoglionissimo": "rincoglionire",
    "rincoglioniste": "rincoglionire",
    "rincoglionisti": "rincoglionire",
    "rincoglionita": "rincoglionire",
    "rincoglionite": "rincoglionire",
    "rincoglioniti": "rincoglionire",
    "rincoglionito": "rincoglionire",
    "rincoglioniva": "rincoglionire",
    "rincoglionivamo": "rincoglionire",
    "rincoglionivan": "rincoglionire",
    "rincoglionivano": "rincoglionire",
    "rincoglionivate": "rincoglionire",
    "rincoglionivi": "rincoglionire",
    "rincoglionivo": "rincoglionire",
    "rincogliono": "rincoglionire",
    "rincoglionon": "rincoglionire",
    "rincoglionono": "rincoglionire",
    "rincoglionì": "rincoglionire",
    "rincolla": "rincollare",
    "rincollai": "rincollare",
    "rincollammo": "rincollare",
    "rincollan": "rincollare",
    "rincollando": "rincollare",
    "rincollano": "rincollare",
    "rincollante": "rincollare",
    "rincollanti": "rincollare",
    "rincollar": "rincollare",
    "rincollaron": "rincollare",
    "rincollarono": "rincollare",
    "rincollasse": "rincollare",
    "rincollasser": "rincollare",
    "rincollassero": "rincollare",
    "rincollassi": "rincollare",
    "rincollassimo": "rincollare",
    "rincollaste": "rincollare",
    "rincollasti": "rincollare",
    "rincollata": "rincollare",
    "rincollate": "rincollare",
    "rincollati": "rincollare",
    "rincollato": "rincollare",
    "rincollava": "rincollare",
    "rincollavamo": "rincollare",
    "rincollavan": "rincollare",
    "rincollavano": "rincollare",
    "rincollavate": "rincollare",
    "rincollavi": "rincollare",
    "rincollavo": "rincollare",
    "rincollerai": "rincollare",
    "rincolleran": "rincollare",
    "rincolleranno": "rincollare",
    "rincollerebbe": "rincollare",
    "rincollerebber": "rincollare",
    "rincollerebbero": "rincollare",
    "rincollerei": "rincollare",
    "rincolleremmo": "rincollare",
    "rincolleremo": "rincollare",
    "rincollereste": "rincollare",
    "rincolleresti": "rincollare",
    "rincollerete": "rincollare",
    "rincollerà": "rincollare",
    "rincollerò": "rincollare",
    "rincolli": "rincollare",
    "rincolliamo": "rincollare",
    "rincolliate": "rincollare",
    "rincollin": "rincollare",
    "rincollino": "rincollare",
    "rincollo": "rincollare",
    "rincollò": "rincollare",
    "rincomincerai": "rincominciare",
    "rincominceran": "rincominciare",
    "rincominceranno": "rincominciare",
    "rincomincerebbe": "rincominciare",
    "rincomincerebber": "rincominciare",
    "rincomincerebbero": "rincominciare",
    "rincomincerei": "rincominciare",
    "rincominceremmo": "rincominciare",
    "rincominceremo": "rincominciare",
    "rincomincereste": "rincominciare",
    "rincominceresti": "rincominciare",
    "rincomincerete": "rincominciare",
    "rincomincerà": "rincominciare",
    "rincomincerò": "rincominciare",
    "rincominci": "rincominciare",
    "rincomincia": "rincominciare",
    "rincominciai": "rincominciare",
    "rincominciammo": "rincominciare",
    "rincominciamo": "rincominciare",
    "rincomincian": "rincominciare",
    "rincominciando": "rincominciare",
    "rincominciano": "rincominciare",
    "rincominciante": "rincominciare",
    "rincomincianti": "rincominciare",
    "rincominciar": "rincominciare",
    "rincominciaron": "rincominciare",
    "rincominciarono": "rincominciare",
    "rincominciasse": "rincominciare",
    "rincominciasser": "rincominciare",
    "rincominciassero": "rincominciare",
    "rincominciassi": "rincominciare",
    "rincominciassimo": "rincominciare",
    "rincominciaste": "rincominciare",
    "rincominciasti": "rincominciare",
    "rincominciata": "rincominciare",
    "rincominciate": "rincominciare",
    "rincominciati": "rincominciare",
    "rincominciato": "rincominciare",
    "rincominciava": "rincominciare",
    "rincominciavamo": "rincominciare",
    "rincominciavan": "rincominciare",
    "rincominciavano": "rincominciare",
    "rincominciavate": "rincominciare",
    "rincominciavi": "rincominciare",
    "rincominciavo": "rincominciare",
    "rincomincin": "rincominciare",
    "rincomincino": "rincominciare",
    "rincomincio": "rincominciare",
    "rincominciò": "rincominciare",
    "rincontra": "rincontrare",
    "rincontrai": "rincontrare",
    "rincontrammo": "rincontrare",
    "rincontran": "rincontrare",
    "rincontrando": "rincontrare",
    "rincontrano": "rincontrare",
    "rincontrante": "rincontrare",
    "rincontranti": "rincontrare",
    "rincontrar": "rincontrare",
    "rincontraron": "rincontrare",
    "rincontrarono": "rincontrare",
    "rincontrasse": "rincontrare",
    "rincontrasser": "rincontrare",
    "rincontrassero": "rincontrare",
    "rincontrassi": "rincontrare",
    "rincontrassimo": "rincontrare",
    "rincontraste": "rincontrare",
    "rincontrasti": "rincontrare",
    "rincontrata": "rincontrare",
    "rincontrate": "rincontrare",
    "rincontrati": "rincontrare",
    "rincontrato": "rincontrare",
    "rincontrava": "rincontrare",
    "rincontravamo": "rincontrare",
    "rincontravan": "rincontrare",
    "rincontravano": "rincontrare",
    "rincontravate": "rincontrare",
    "rincontravi": "rincontrare",
    "rincontravo": "rincontrare",
    "rincontrerai": "rincontrare",
    "rincontreran": "rincontrare",
    "rincontreranno": "rincontrare",
    "rincontrerebbe": "rincontrare",
    "rincontrerebber": "rincontrare",
    "rincontrerebbero": "rincontrare",
    "rincontrerei": "rincontrare",
    "rincontreremmo": "rincontrare",
    "rincontreremo": "rincontrare",
    "rincontrereste": "rincontrare",
    "rincontreresti": "rincontrare",
    "rincontrerete": "rincontrare",
    "rincontrerà": "rincontrare",
    "rincontrerò": "rincontrare",
    "rincontri": "rincontrare",
    "rincontriamo": "rincontrare",
    "rincontriate": "rincontrare",
    "rincontrin": "rincontrare",
    "rincontrino": "rincontrare",
    "rincontro": "rincontrare",
    "rincontrò": "rincontrare",
    "rincorra": "rincorrere",
    "rincorran": "rincorrere",
    "rincorrano": "rincorrere",
    "rincorre": "rincorrere",
    "rincorremmo": "rincorrere",
    "rincorrendo": "rincorrere",
    "rincorrente": "rincorrere",
    "rincorrenti": "rincorrere",
    "rincorrer": "rincorrere",
    "rincorrerai": "rincorrere",
    "rincorreran": "rincorrere",
    "rincorreranno": "rincorrere",
    "rincorrerebbe": "rincorrere",
    "rincorrerebber": "rincorrere",
    "rincorrerebbero": "rincorrere",
    "rincorrerei": "rincorrere",
    "rincorreremmo": "rincorrere",
    "rincorreremo": "rincorrere",
    "rincorrereste": "rincorrere",
    "rincorreresti": "rincorrere",
    "rincorrerete": "rincorrere",
    "rincorrerà": "rincorrere",
    "rincorrerò": "rincorrere",
    "rincorresse": "rincorrere",
    "rincorresser": "rincorrere",
    "rincorressero": "rincorrere",
    "rincorressi": "rincorrere",
    "rincorressimo": "rincorrere",
    "rincorreste": "rincorrere",
    "rincorresti": "rincorrere",
    "rincorrete": "rincorrere",
    "rincorreva": "rincorrere",
    "rincorrevamo": "rincorrere",
    "rincorrevan": "rincorrere",
    "rincorrevano": "rincorrere",
    "rincorrevate": "rincorrere",
    "rincorrevi": "rincorrere",
    "rincorrevo": "rincorrere",
    "rincorri": "rincorrere",
    "rincorriamo": "rincorrere",
    "rincorriate": "rincorrere",
    "rincorro": "rincorrere",
    "rincorron": "rincorrere",
    "rincorrono": "rincorrere",
    "rincorsa": "rincorrere",
    "rincorse": "rincorsa",
    "rincorser": "rincorrere",
    "rincorsero": "rincorrere",
    "rincorsi": "rincorrere",
    "rincorso": "rincorrere",
    "rincresca": "rincrescere",
    "rincrescan": "rincrescere",
    "rincrescano": "rincrescere",
    "rincresce": "rincrescere",
    "rincrescei": "rincrescere",
    "rincrescemmo": "rincrescere",
    "rincrescendo": "rincrescere",
    "rincrescente": "rincrescere",
    "rincrescenti": "rincrescere",
    "rincrescer": "rincrescere",
    "rincrescerai": "rincrescere",
    "rincresceran": "rincrescere",
    "rincresceranno": "rincrescere",
    "rincrescerebbe": "rincrescere",
    "rincrescerebber": "rincrescere",
    "rincrescerebbero": "rincrescere",
    "rincrescerei": "rincrescere",
    "rincresceremmo": "rincrescere",
    "rincresceremo": "rincrescere",
    "rincrescereste": "rincrescere",
    "rincresceresti": "rincrescere",
    "rincrescerete": "rincrescere",
    "rincresceron": "rincrescere",
    "rincrescerono": "rincrescere",
    "rincrescerà": "rincrescere",
    "rincrescerò": "rincrescere",
    "rincrescesse": "rincrescere",
    "rincrescesser": "rincrescere",
    "rincrescessero": "rincrescere",
    "rincrescessi": "rincrescere",
    "rincrescessimo": "rincrescere",
    "rincresceste": "rincrescere",
    "rincrescesti": "rincrescere",
    "rincrescete": "rincrescere",
    "rincresceva": "rincrescere",
    "rincrescevamo": "rincrescere",
    "rincrescevan": "rincrescere",
    "rincrescevano": "rincrescere",
    "rincrescevate": "rincrescere",
    "rincrescevi": "rincrescere",
    "rincrescevo": "rincrescere",
    "rincresci": "rincrescere",
    "rincresciamo": "rincrescere",
    "rincresciate": "rincrescere",
    "rincrescimenti": "rincrescimento",
    "rincresciuta": "rincrescere",
    "rincresciute": "rincrescere",
    "rincresciuti": "rincrescere",
    "rincresciuto": "rincrescere",
    "rincresco": "rincrescere",
    "rincrescon": "rincrescere",
    "rincrescono": "rincrescere",
    "rincrescè": "rincrescere",
    "rincretina": "rincretinire",
    "rincretinan": "rincretinire",
    "rincretinano": "rincretinire",
    "rincretine": "rincretinire",
    "rincretinendo": "rincretinire",
    "rincretinente": "rincretinire",
    "rincretinenti": "rincretinire",
    "rincretini": "rincretinire",
    "rincretiniamo": "rincretinire",
    "rincretiniate": "rincretinire",
    "rincretinii": "rincretinire",
    "rincretinimmo": "rincretinire",
    "rincretinir": "rincretinire",
    "rincretinirai": "rincretinire",
    "rincretiniran": "rincretinire",
    "rincretiniranno": "rincretinire",
    "rincretinirebbe": "rincretinire",
    "rincretinirebber": "rincretinire",
    "rincretinirebbero": "rincretinire",
    "rincretinirei": "rincretinire",
    "rincretiniremmo": "rincretinire",
    "rincretiniremo": "rincretinire",
    "rincretinireste": "rincretinire",
    "rincretiniresti": "rincretinire",
    "rincretinirete": "rincretinire",
    "rincretiniron": "rincretinire",
    "rincretinirono": "rincretinire",
    "rincretinirà": "rincretinire",
    "rincretinirò": "rincretinire",
    "rincretinisse": "rincretinire",
    "rincretinisser": "rincretinire",
    "rincretinissero": "rincretinire",
    "rincretinissi": "rincretinire",
    "rincretinissimo": "rincretinire",
    "rincretiniste": "rincretinire",
    "rincretinisti": "rincretinire",
    "rincretinita": "rincretinire",
    "rincretinite": "rincretinire",
    "rincretiniti": "rincretinire",
    "rincretinito": "rincretinire",
    "rincretiniva": "rincretinire",
    "rincretinivamo": "rincretinire",
    "rincretinivan": "rincretinire",
    "rincretinivano": "rincretinire",
    "rincretinivate": "rincretinire",
    "rincretinivi": "rincretinire",
    "rincretinivo": "rincretinire",
    "rincretino": "rincretinire",
    "rincretinon": "rincretinire",
    "rincretinono": "rincretinire",
    "rincretinì": "rincretinire",
    "rincruda": "rincrudire",
    "rincrudan": "rincrudire",
    "rincrudano": "rincrudire",
    "rincrude": "rincrudire",
    "rincrudendo": "rincrudire",
    "rincrudente": "rincrudire",
    "rincrudenti": "rincrudire",
    "rincrudi": "rincrudire",
    "rincrudiamo": "rincrudire",
    "rincrudiate": "rincrudire",
    "rincrudii": "rincrudire",
    "rincrudimmo": "rincrudire",
    "rincrudir": "rincrudire",
    "rincrudirai": "rincrudire",
    "rincrudiran": "rincrudire",
    "rincrudiranno": "rincrudire",
    "rincrudirebbe": "rincrudire",
    "rincrudirebber": "rincrudire",
    "rincrudirebbero": "rincrudire",
    "rincrudirei": "rincrudire",
    "rincrudiremmo": "rincrudire",
    "rincrudiremo": "rincrudire",
    "rincrudireste": "rincrudire",
    "rincrudiresti": "rincrudire",
    "rincrudirete": "rincrudire",
    "rincrudiron": "rincrudire",
    "rincrudirono": "rincrudire",
    "rincrudirà": "rincrudire",
    "rincrudirò": "rincrudire",
    "rincrudisse": "rincrudire",
    "rincrudisser": "rincrudire",
    "rincrudissero": "rincrudire",
    "rincrudissi": "rincrudire",
    "rincrudissimo": "rincrudire",
    "rincrudiste": "rincrudire",
    "rincrudisti": "rincrudire",
    "rincrudita": "rincrudire",
    "rincrudite": "rincrudire",
    "rincruditi": "rincrudire",
    "rincrudito": "rincrudire",
    "rincrudiva": "rincrudire",
    "rincrudivamo": "rincrudire",
    "rincrudivan": "rincrudire",
    "rincrudivano": "rincrudire",
    "rincrudivate": "rincrudire",
    "rincrudivi": "rincrudire",
    "rincrudivo": "rincrudire",
    "rincrudo": "rincrudire",
    "rincrudon": "rincrudire",
    "rincrudono": "rincrudire",
    "rincrudì": "rincrudire",
    "rincula": "rinculare",
    "rinculai": "rinculare",
    "rinculammo": "rinculare",
    "rinculan": "rinculare",
    "rinculando": "rinculare",
    "rinculano": "rinculare",
    "rinculante": "rinculare",
    "rinculanti": "rinculare",
    "rincular": "rinculare",
    "rincularon": "rinculare",
    "rincularono": "rinculare",
    "rinculasse": "rinculare",
    "rinculasser": "rinculare",
    "rinculassero": "rinculare",
    "rinculassi": "rinculare",
    "rinculassimo": "rinculare",
    "rinculaste": "rinculare",
    "rinculasti": "rinculare",
    "rinculata": "rinculare",
    "rinculate": "rinculare",
    "rinculati": "rinculare",
    "rinculato": "rinculare",
    "rinculava": "rinculare",
    "rinculavamo": "rinculare",
    "rinculavan": "rinculare",
    "rinculavano": "rinculare",
    "rinculavate": "rinculare",
    "rinculavi": "rinculare",
    "rinculavo": "rinculare",
    "rinculerai": "rinculare",
    "rinculeran": "rinculare",
    "rinculeranno": "rinculare",
    "rinculerebbe": "rinculare",
    "rinculerebber": "rinculare",
    "rinculerebbero": "rinculare",
    "rinculerei": "rinculare",
    "rinculeremmo": "rinculare",
    "rinculeremo": "rinculare",
    "rinculereste": "rinculare",
    "rinculeresti": "rinculare",
    "rinculerete": "rinculare",
    "rinculerà": "rinculare",
    "rinculerò": "rinculare",
    "rinculi": "rinculare",
    "rinculiamo": "rinculare",
    "rinculiate": "rinculare",
    "rinculin": "rinculare",
    "rinculino": "rinculare",
    "rinculo": "rinculare",
    "rinculò": "rinculare",
    "rincuora": "rincuorare",
    "rincuorai": "rincuorare",
    "rincuorammo": "rincuorare",
    "rincuoran": "rincuorare",
    "rincuorando": "rincuorare",
    "rincuorano": "rincuorare",
    "rincuorante": "rincuorare",
    "rincuoranti": "rincuorare",
    "rincuorar": "rincuorare",
    "rincuoraron": "rincuorare",
    "rincuorarono": "rincuorare",
    "rincuorasse": "rincuorare",
    "rincuorasser": "rincuorare",
    "rincuorassero": "rincuorare",
    "rincuorassi": "rincuorare",
    "rincuorassimo": "rincuorare",
    "rincuoraste": "rincuorare",
    "rincuorasti": "rincuorare",
    "rincuorata": "rincuorare",
    "rincuorate": "rincuorare",
    "rincuorati": "rincuorare",
    "rincuorato": "rincuorare",
    "rincuorava": "rincuorare",
    "rincuoravamo": "rincuorare",
    "rincuoravan": "rincuorare",
    "rincuoravano": "rincuorare",
    "rincuoravate": "rincuorare",
    "rincuoravi": "rincuorare",
    "rincuoravo": "rincuorare",
    "rincuorerai": "rincuorare",
    "rincuoreran": "rincuorare",
    "rincuoreranno": "rincuorare",
    "rincuorerebbe": "rincuorare",
    "rincuorerebber": "rincuorare",
    "rincuorerebbero": "rincuorare",
    "rincuorerei": "rincuorare",
    "rincuoreremmo": "rincuorare",
    "rincuoreremo": "rincuorare",
    "rincuorereste": "rincuorare",
    "rincuoreresti": "rincuorare",
    "rincuorerete": "rincuorare",
    "rincuorerà": "rincuorare",
    "rincuorerò": "rincuorare",
    "rincuori": "rincuorare",
    "rincuoriamo": "rincuorare",
    "rincuoriate": "rincuorare",
    "rincuorin": "rincuorare",
    "rincuorino": "rincuorare",
    "rincuoro": "rincuorare",
    "rincuorò": "rincuorare",
    "rinegozi": "rinegoziare",
    "rinegozia": "rinegoziare",
    "rinegoziai": "rinegoziare",
    "rinegoziammo": "rinegoziare",
    "rinegoziamo": "rinegoziare",
    "rinegozian": "rinegoziare",
    "rinegoziando": "rinegoziare",
    "rinegoziano": "rinegoziare",
    "rinegoziante": "rinegoziare",
    "rinegozianti": "rinegoziare",
    "rinegoziar": "rinegoziare",
    "rinegoziaron": "rinegoziare",
    "rinegoziarono": "rinegoziare",
    "rinegoziasse": "rinegoziare",
    "rinegoziasser": "rinegoziare",
    "rinegoziassero": "rinegoziare",
    "rinegoziassi": "rinegoziare",
    "rinegoziassimo": "rinegoziare",
    "rinegoziaste": "rinegoziare",
    "rinegoziasti": "rinegoziare",
    "rinegoziata": "rinegoziare",
    "rinegoziate": "rinegoziare",
    "rinegoziati": "rinegoziare",
    "rinegoziato": "rinegoziare",
    "rinegoziava": "rinegoziare",
    "rinegoziavamo": "rinegoziare",
    "rinegoziavan": "rinegoziare",
    "rinegoziavano": "rinegoziare",
    "rinegoziavate": "rinegoziare",
    "rinegoziavi": "rinegoziare",
    "rinegoziavo": "rinegoziare",
    "rinegoziazioni": "rinegoziazione",
    "rinegozierai": "rinegoziare",
    "rinegozieran": "rinegoziare",
    "rinegozieranno": "rinegoziare",
    "rinegozierebbe": "rinegoziare",
    "rinegozierebber": "rinegoziare",
    "rinegozierebbero": "rinegoziare",
    "rinegozierei": "rinegoziare",
    "rinegozieremmo": "rinegoziare",
    "rinegozieremo": "rinegoziare",
    "rinegoziereste": "rinegoziare",
    "rinegozieresti": "rinegoziare",
    "rinegozierete": "rinegoziare",
    "rinegozierà": "rinegoziare",
    "rinegozierò": "rinegoziare",
    "rinegozin": "rinegoziare",
    "rinegozino": "rinegoziare",
    "rinegozio": "rinegoziare",
    "rinegoziò": "rinegoziare",
    "rinfaccerai": "rinfacciare",
    "rinfacceran": "rinfacciare",
    "rinfacceranno": "rinfacciare",
    "rinfaccerebbe": "rinfacciare",
    "rinfaccerebber": "rinfacciare",
    "rinfaccerebbero": "rinfacciare",
    "rinfaccerei": "rinfacciare",
    "rinfacceremmo": "rinfacciare",
    "rinfacceremo": "rinfacciare",
    "rinfaccereste": "rinfacciare",
    "rinfacceresti": "rinfacciare",
    "rinfaccerete": "rinfacciare",
    "rinfaccerà": "rinfacciare",
    "rinfaccerò": "rinfacciare",
    "rinfacci": "rinfacciare",
    "rinfaccia": "rinfacciare",
    "rinfacciai": "rinfacciare",
    "rinfacciammo": "rinfacciare",
    "rinfacciamo": "rinfacciare",
    "rinfaccian": "rinfacciare",
    "rinfacciando": "rinfacciare",
    "rinfacciano": "rinfacciare",
    "rinfacciante": "rinfacciare",
    "rinfaccianti": "rinfacciare",
    "rinfacciar": "rinfacciare",
    "rinfacciaron": "rinfacciare",
    "rinfacciarono": "rinfacciare",
    "rinfacciasse": "rinfacciare",
    "rinfacciasser": "rinfacciare",
    "rinfacciassero": "rinfacciare",
    "rinfacciassi": "rinfacciare",
    "rinfacciassimo": "rinfacciare",
    "rinfacciaste": "rinfacciare",
    "rinfacciasti": "rinfacciare",
    "rinfacciata": "rinfacciare",
    "rinfacciate": "rinfacciare",
    "rinfacciati": "rinfacciare",
    "rinfacciato": "rinfacciare",
    "rinfacciava": "rinfacciare",
    "rinfacciavamo": "rinfacciare",
    "rinfacciavan": "rinfacciare",
    "rinfacciavano": "rinfacciare",
    "rinfacciavate": "rinfacciare",
    "rinfacciavi": "rinfacciare",
    "rinfacciavo": "rinfacciare",
    "rinfaccin": "rinfacciare",
    "rinfaccino": "rinfacciare",
    "rinfaccio": "rinfacciare",
    "rinfacciò": "rinfacciare",
    "rinfocola": "rinfocolare",
    "rinfocolai": "rinfocolare",
    "rinfocolammo": "rinfocolare",
    "rinfocolan": "rinfocolare",
    "rinfocolando": "rinfocolare",
    "rinfocolano": "rinfocolare",
    "rinfocolante": "rinfocolare",
    "rinfocolanti": "rinfocolare",
    "rinfocolar": "rinfocolare",
    "rinfocolaron": "rinfocolare",
    "rinfocolarono": "rinfocolare",
    "rinfocolasse": "rinfocolare",
    "rinfocolasser": "rinfocolare",
    "rinfocolassero": "rinfocolare",
    "rinfocolassi": "rinfocolare",
    "rinfocolassimo": "rinfocolare",
    "rinfocolaste": "rinfocolare",
    "rinfocolasti": "rinfocolare",
    "rinfocolata": "rinfocolare",
    "rinfocolate": "rinfocolare",
    "rinfocolati": "rinfocolare",
    "rinfocolato": "rinfocolare",
    "rinfocolava": "rinfocolare",
    "rinfocolavamo": "rinfocolare",
    "rinfocolavan": "rinfocolare",
    "rinfocolavano": "rinfocolare",
    "rinfocolavate": "rinfocolare",
    "rinfocolavi": "rinfocolare",
    "rinfocolavo": "rinfocolare",
    "rinfocolerai": "rinfocolare",
    "rinfocoleran": "rinfocolare",
    "rinfocoleranno": "rinfocolare",
    "rinfocolerebbe": "rinfocolare",
    "rinfocolerebber": "rinfocolare",
    "rinfocolerebbero": "rinfocolare",
    "rinfocolerei": "rinfocolare",
    "rinfocoleremmo": "rinfocolare",
    "rinfocoleremo": "rinfocolare",
    "rinfocolereste": "rinfocolare",
    "rinfocoleresti": "rinfocolare",
    "rinfocolerete": "rinfocolare",
    "rinfocolerà": "rinfocolare",
    "rinfocolerò": "rinfocolare",
    "rinfocoli": "rinfocolare",
    "rinfocoliamo": "rinfocolare",
    "rinfocoliate": "rinfocolare",
    "rinfocolin": "rinfocolare",
    "rinfocolino": "rinfocolare",
    "rinfocolo": "rinfocolare",
    "rinfocolò": "rinfocolare",
    "rinfodera": "rinfoderare",
    "rinfoderai": "rinfoderare",
    "rinfoderammo": "rinfoderare",
    "rinfoderan": "rinfoderare",
    "rinfoderando": "rinfoderare",
    "rinfoderano": "rinfoderare",
    "rinfoderante": "rinfoderare",
    "rinfoderanti": "rinfoderare",
    "rinfoderar": "rinfoderare",
    "rinfoderaron": "rinfoderare",
    "rinfoderarono": "rinfoderare",
    "rinfoderasse": "rinfoderare",
    "rinfoderasser": "rinfoderare",
    "rinfoderassero": "rinfoderare",
    "rinfoderassi": "rinfoderare",
    "rinfoderassimo": "rinfoderare",
    "rinfoderaste": "rinfoderare",
    "rinfoderasti": "rinfoderare",
    "rinfoderata": "rinfoderare",
    "rinfoderate": "rinfoderare",
    "rinfoderati": "rinfoderare",
    "rinfoderato": "rinfoderare",
    "rinfoderava": "rinfoderare",
    "rinfoderavamo": "rinfoderare",
    "rinfoderavan": "rinfoderare",
    "rinfoderavano": "rinfoderare",
    "rinfoderavate": "rinfoderare",
    "rinfoderavi": "rinfoderare",
    "rinfoderavo": "rinfoderare",
    "rinfodererai": "rinfoderare",
    "rinfodereran": "rinfoderare",
    "rinfodereranno": "rinfoderare",
    "rinfodererebbe": "rinfoderare",
    "rinfodererebber": "rinfoderare",
    "rinfodererebbero": "rinfoderare",
    "rinfodererei": "rinfoderare",
    "rinfodereremmo": "rinfoderare",
    "rinfodereremo": "rinfoderare",
    "rinfoderereste": "rinfoderare",
    "rinfodereresti": "rinfoderare",
    "rinfodererete": "rinfoderare",
    "rinfodererà": "rinfoderare",
    "rinfodererò": "rinfoderare",
    "rinfoderi": "rinfoderare",
    "rinfoderiamo": "rinfoderare",
    "rinfoderiate": "rinfoderare",
    "rinfoderin": "rinfoderare",
    "rinfoderino": "rinfoderare",
    "rinfodero": "rinfoderare",
    "rinfoderò": "rinfoderare",
    "rinforza": "rinforzare",
    "rinforzai": "rinforzare",
    "rinforzammo": "rinforzare",
    "rinforzan": "rinforzare",
    "rinforzando": "rinforzare",
    "rinforzano": "rinforzare",
    "rinforzante": "rinforzare",
    "rinforzanti": "rinforzare",
    "rinforzar": "rinforzare",
    "rinforzaron": "rinforzare",
    "rinforzarono": "rinforzare",
    "rinforzasse": "rinforzare",
    "rinforzasser": "rinforzare",
    "rinforzassero": "rinforzare",
    "rinforzassi": "rinforzare",
    "rinforzassimo": "rinforzare",
    "rinforzaste": "rinforzare",
    "rinforzasti": "rinforzare",
    "rinforzata": "rinforzare",
    "rinforzate": "rinforzare",
    "rinforzati": "rinforzare",
    "rinforzato": "rinforzare",
    "rinforzava": "rinforzare",
    "rinforzavamo": "rinforzare",
    "rinforzavan": "rinforzare",
    "rinforzavano": "rinforzare",
    "rinforzavate": "rinforzare",
    "rinforzavi": "rinforzare",
    "rinforzavo": "rinforzare",
    "rinforzerai": "rinforzare",
    "rinforzeran": "rinforzare",
    "rinforzeranno": "rinforzare",
    "rinforzerebbe": "rinforzare",
    "rinforzerebber": "rinforzare",
    "rinforzerebbero": "rinforzare",
    "rinforzerei": "rinforzare",
    "rinforzeremmo": "rinforzare",
    "rinforzeremo": "rinforzare",
    "rinforzereste": "rinforzare",
    "rinforzeresti": "rinforzare",
    "rinforzerete": "rinforzare",
    "rinforzerà": "rinforzare",
    "rinforzerò": "rinforzare",
    "rinforzi": "rinforzo",
    "rinforziamo": "rinforzare",
    "rinforziate": "rinforzare",
    "rinforzin": "rinforzare",
    "rinforzino": "rinforzare",
    "rinforzo": "rinforzare",
    "rinforzò": "rinforzare",
    "rinfranca": "rinfrancare",
    "rinfrancai": "rinfrancare",
    "rinfrancammo": "rinfrancare",
    "rinfrancan": "rinfrancare",
    "rinfrancando": "rinfrancare",
    "rinfrancano": "rinfrancare",
    "rinfrancante": "rinfrancare",
    "rinfrancanti": "rinfrancare",
    "rinfrancar": "rinfrancare",
    "rinfrancaron": "rinfrancare",
    "rinfrancarono": "rinfrancare",
    "rinfrancasse": "rinfrancare",
    "rinfrancasser": "rinfrancare",
    "rinfrancassero": "rinfrancare",
    "rinfrancassi": "rinfrancare",
    "rinfrancassimo": "rinfrancare",
    "rinfrancaste": "rinfrancare",
    "rinfrancasti": "rinfrancare",
    "rinfrancata": "rinfrancare",
    "rinfrancate": "rinfrancare",
    "rinfrancati": "rinfrancare",
    "rinfrancato": "rinfrancare",
    "rinfrancava": "rinfrancare",
    "rinfrancavamo": "rinfrancare",
    "rinfrancavan": "rinfrancare",
    "rinfrancavano": "rinfrancare",
    "rinfrancavate": "rinfrancare",
    "rinfrancavi": "rinfrancare",
    "rinfrancavo": "rinfrancare",
    "rinfrancherai": "rinfrancare",
    "rinfrancheran": "rinfrancare",
    "rinfrancheranno": "rinfrancare",
    "rinfrancherebbe": "rinfrancare",
    "rinfrancherebber": "rinfrancare",
    "rinfrancherebbero": "rinfrancare",
    "rinfrancherei": "rinfrancare",
    "rinfrancheremmo": "rinfrancare",
    "rinfrancheremo": "rinfrancare",
    "rinfranchereste": "rinfrancare",
    "rinfrancheresti": "rinfrancare",
    "rinfrancherete": "rinfrancare",
    "rinfrancherà": "rinfrancare",
    "rinfrancherò": "rinfrancare",
    "rinfranchi": "rinfrancare",
    "rinfranchiamo": "rinfrancare",
    "rinfranchiate": "rinfrancare",
    "rinfranchin": "rinfrancare",
    "rinfranchino": "rinfrancare",
    "rinfranco": "rinfrancare",
    "rinfrancò": "rinfrancare",
    "rinfresca": "rinfrescare",
    "rinfrescai": "rinfrescare",
    "rinfrescammo": "rinfrescare",
    "rinfrescan": "rinfrescare",
    "rinfrescando": "rinfrescare",
    "rinfrescano": "rinfrescare",
    "rinfrescante": "rinfrescare",
    "rinfrescanti": "rinfrescare",
    "rinfrescar": "rinfrescare",
    "rinfrescaron": "rinfrescare",
    "rinfrescarono": "rinfrescare",
    "rinfrescasse": "rinfrescare",
    "rinfrescasser": "rinfrescare",
    "rinfrescassero": "rinfrescare",
    "rinfrescassi": "rinfrescare",
    "rinfrescassimo": "rinfrescare",
    "rinfrescaste": "rinfrescare",
    "rinfrescasti": "rinfrescare",
    "rinfrescata": "rinfrescare",
    "rinfrescate": "rinfrescare",
    "rinfrescati": "rinfrescare",
    "rinfrescato": "rinfrescare",
    "rinfrescava": "rinfrescare",
    "rinfrescavamo": "rinfrescare",
    "rinfrescavan": "rinfrescare",
    "rinfrescavano": "rinfrescare",
    "rinfrescavate": "rinfrescare",
    "rinfrescavi": "rinfrescare",
    "rinfrescavo": "rinfrescare",
    "rinfrescherai": "rinfrescare",
    "rinfrescheran": "rinfrescare",
    "rinfrescheranno": "rinfrescare",
    "rinfrescherebbe": "rinfrescare",
    "rinfrescherebber": "rinfrescare",
    "rinfrescherebbero": "rinfrescare",
    "rinfrescherei": "rinfrescare",
    "rinfrescheremmo": "rinfrescare",
    "rinfrescheremo": "rinfrescare",
    "rinfreschereste": "rinfrescare",
    "rinfrescheresti": "rinfrescare",
    "rinfrescherete": "rinfrescare",
    "rinfrescherà": "rinfrescare",
    "rinfrescherò": "rinfrescare",
    "rinfreschi": "rinfresco",
    "rinfreschiamo": "rinfrescare",
    "rinfreschiate": "rinfrescare",
    "rinfreschin": "rinfrescare",
    "rinfreschino": "rinfrescare",
    "rinfresco": "rinfrescare",
    "rinfrescò": "rinfrescare",
    "ringalluzza": "ringalluzzire",
    "ringalluzzan": "ringalluzzire",
    "ringalluzzano": "ringalluzzire",
    "ringalluzze": "ringalluzzire",
    "ringalluzzendo": "ringalluzzire",
    "ringalluzzente": "ringalluzzire",
    "ringalluzzenti": "ringalluzzire",
    "ringalluzzi": "ringalluzzire",
    "ringalluzziamo": "ringalluzzire",
    "ringalluzziate": "ringalluzzire",
    "ringalluzzii": "ringalluzzire",
    "ringalluzzimmo": "ringalluzzire",
    "ringalluzzir": "ringalluzzire",
    "ringalluzzirai": "ringalluzzire",
    "ringalluzziran": "ringalluzzire",
    "ringalluzziranno": "ringalluzzire",
    "ringalluzzirebbe": "ringalluzzire",
    "ringalluzzirebber": "ringalluzzire",
    "ringalluzzirebbero": "ringalluzzire",
    "ringalluzzirei": "ringalluzzire",
    "ringalluzziremmo": "ringalluzzire",
    "ringalluzziremo": "ringalluzzire",
    "ringalluzzireste": "ringalluzzire",
    "ringalluzziresti": "ringalluzzire",
    "ringalluzzirete": "ringalluzzire",
    "ringalluzziron": "ringalluzzire",
    "ringalluzzirono": "ringalluzzire",
    "ringalluzzirà": "ringalluzzire",
    "ringalluzzirò": "ringalluzzire",
    "ringalluzzisse": "ringalluzzire",
    "ringalluzzisser": "ringalluzzire",
    "ringalluzzissero": "ringalluzzire",
    "ringalluzzissi": "ringalluzzire",
    "ringalluzzissimo": "ringalluzzire",
    "ringalluzziste": "ringalluzzire",
    "ringalluzzisti": "ringalluzzire",
    "ringalluzzita": "ringalluzzito",
    "ringalluzzite": "ringalluzzito",
    "ringalluzziti": "ringalluzzito",
    "ringalluzzito": "ringalluzzire",
    "ringalluzziva": "ringalluzzire",
    "ringalluzzivamo": "ringalluzzire",
    "ringalluzzivan": "ringalluzzire",
    "ringalluzzivano": "ringalluzzire",
    "ringalluzzivate": "ringalluzzire",
    "ringalluzzivi": "ringalluzzire",
    "ringalluzzivo": "ringalluzzire",
    "ringalluzzo": "ringalluzzire",
    "ringalluzzon": "ringalluzzire",
    "ringalluzzono": "ringalluzzire",
    "ringalluzzì": "ringalluzzire",
    "ringhi": "ringhio",
    "ringhia": "ringhiare",
    "ringhiai": "ringhiare",
    "ringhiammo": "ringhiare",
    "ringhiamo": "ringhiare",
    "ringhian": "ringhiare",
    "ringhiando": "ringhiare",
    "ringhiano": "ringhiare",
    "ringhiante": "ringhiare",
    "ringhianti": "ringhiare",
    "ringhiar": "ringhiare",
    "ringhiaron": "ringhiare",
    "ringhiarono": "ringhiare",
    "ringhiasse": "ringhiare",
    "ringhiasser": "ringhiare",
    "ringhiassero": "ringhiare",
    "ringhiassi": "ringhiare",
    "ringhiassimo": "ringhiare",
    "ringhiaste": "ringhiare",
    "ringhiasti": "ringhiare",
    "ringhiata": "ringhiare",
    "ringhiate": "ringhiare",
    "ringhiati": "ringhiare",
    "ringhiato": "ringhiare",
    "ringhiava": "ringhiare",
    "ringhiavamo": "ringhiare",
    "ringhiavan": "ringhiare",
    "ringhiavano": "ringhiare",
    "ringhiavate": "ringhiare",
    "ringhiavi": "ringhiare",
    "ringhiavo": "ringhiare",
    "ringhierai": "ringhiare",
    "ringhieran": "ringhiare",
    "ringhieranno": "ringhiare",
    "ringhiere": "ringhiera",
    "ringhierebbe": "ringhiare",
    "ringhierebber": "ringhiare",
    "ringhierebbero": "ringhiare",
    "ringhierei": "ringhiare",
    "ringhieremmo": "ringhiare",
    "ringhieremo": "ringhiare",
    "ringhiereste": "ringhiare",
    "ringhieresti": "ringhiare",
    "ringhierete": "ringhiare",
    "ringhierà": "ringhiare",
    "ringhierò": "ringhiare",
    "ringhin": "ringhiare",
    "ringhino": "ringhiare",
    "ringhio": "ringhiare",
    "ringhiosa": "ringhioso",
    "ringhiose": "ringhioso",
    "ringhiosi": "ringhioso",
    "ringhiò": "ringhiare",
    "ringiovanendo": "ringiovanire",
    "ringiovanente": "ringiovanire",
    "ringiovanenti": "ringiovanire",
    "ringiovaniamo": "ringiovanire",
    "ringiovaniate": "ringiovanire",
    "ringiovanii": "ringiovanire",
    "ringiovanimenti": "ringiovanimento",
    "ringiovanimmo": "ringiovanire",
    "ringiovanir": "ringiovanire",
    "ringiovanirai": "ringiovanire",
    "ringiovaniran": "ringiovanire",
    "ringiovaniranno": "ringiovanire",
    "ringiovanirebbe": "ringiovanire",
    "ringiovanirebber": "ringiovanire",
    "ringiovanirebbero": "ringiovanire",
    "ringiovanirei": "ringiovanire",
    "ringiovaniremmo": "ringiovanire",
    "ringiovaniremo": "ringiovanire",
    "ringiovanireste": "ringiovanire",
    "ringiovaniresti": "ringiovanire",
    "ringiovanirete": "ringiovanire",
    "ringiovaniron": "ringiovanire",
    "ringiovanirono": "ringiovanire",
    "ringiovanirà": "ringiovanire",
    "ringiovanirò": "ringiovanire",
    "ringiovanisca": "ringiovanire",
    "ringiovaniscan": "ringiovanire",
    "ringiovaniscano": "ringiovanire",
    "ringiovanisce": "ringiovanire",
    "ringiovanisci": "ringiovanire",
    "ringiovanisco": "ringiovanire",
    "ringiovaniscon": "ringiovanire",
    "ringiovaniscono": "ringiovanire",
    "ringiovanisse": "ringiovanire",
    "ringiovanisser": "ringiovanire",
    "ringiovanissero": "ringiovanire",
    "ringiovanissi": "ringiovanire",
    "ringiovanissimo": "ringiovanire",
    "ringiovaniste": "ringiovanire",
    "ringiovanisti": "ringiovanire",
    "ringiovanita": "ringiovanire",
    "ringiovanite": "ringiovanire",
    "ringiovaniti": "ringiovanire",
    "ringiovanito": "ringiovanire",
    "ringiovaniva": "ringiovanire",
    "ringiovanivamo": "ringiovanire",
    "ringiovanivan": "ringiovanire",
    "ringiovanivano": "ringiovanire",
    "ringiovanivate": "ringiovanire",
    "ringiovanivi": "ringiovanire",
    "ringiovanivo": "ringiovanire",
    "ringiovanì": "ringiovanire",
    "ringoi": "ringoiare",
    "ringoia": "ringoiare",
    "ringoiai": "ringoiare",
    "ringoiammo": "ringoiare",
    "ringoiamo": "ringoiare",
    "ringoian": "ringoiare",
    "ringoiando": "ringoiare",
    "ringoiano": "ringoiare",
    "ringoiante": "ringoiare",
    "ringoianti": "ringoiare",
    "ringoiar": "ringoiare",
    "ringoiaron": "ringoiare",
    "ringoiarono": "ringoiare",
    "ringoiasse": "ringoiare",
    "ringoiasser": "ringoiare",
    "ringoiassero": "ringoiare",
    "ringoiassi": "ringoiare",
    "ringoiassimo": "ringoiare",
    "ringoiaste": "ringoiare",
    "ringoiasti": "ringoiare",
    "ringoiata": "ringoiare",
    "ringoiate": "ringoiare",
    "ringoiati": "ringoiare",
    "ringoiato": "ringoiare",
    "ringoiava": "ringoiare",
    "ringoiavamo": "ringoiare",
    "ringoiavan": "ringoiare",
    "ringoiavano": "ringoiare",
    "ringoiavate": "ringoiare",
    "ringoiavi": "ringoiare",
    "ringoiavo": "ringoiare",
    "ringoierai": "ringoiare",
    "ringoieran": "ringoiare",
    "ringoieranno": "ringoiare",
    "ringoierebbe": "ringoiare",
    "ringoierebber": "ringoiare",
    "ringoierebbero": "ringoiare",
    "ringoierei": "ringoiare",
    "ringoieremmo": "ringoiare",
    "ringoieremo": "ringoiare",
    "ringoiereste": "ringoiare",
    "ringoieresti": "ringoiare",
    "ringoierete": "ringoiare",
    "ringoierà": "ringoiare",
    "ringoierò": "ringoiare",
    "ringoin": "ringoiare",
    "ringoino": "ringoiare",
    "ringoio": "ringoiare",
    "ringoiò": "ringoiare",
    "ringrazi": "ringraziare",
    "ringrazia": "ringraziare",
    "ringraziai": "ringraziare",
    "ringraziamenti": "ringraziamento",
    "ringraziammo": "ringraziare",
    "ringraziamo": "ringraziare",
    "ringrazian": "ringraziare",
    "ringraziando": "ringraziare",
    "ringraziano": "ringraziare",
    "ringraziante": "ringraziare",
    "ringrazianti": "ringraziare",
    "ringraziar": "ringraziare",
    "ringraziaron": "ringraziare",
    "ringraziarono": "ringraziare",
    "ringraziasse": "ringraziare",
    "ringraziasser": "ringraziare",
    "ringraziassero": "ringraziare",
    "ringraziassi": "ringraziare",
    "ringraziassimo": "ringraziare",
    "ringraziaste": "ringraziare",
    "ringraziasti": "ringraziare",
    "ringraziata": "ringraziare",
    "ringraziate": "ringraziare",
    "ringraziati": "ringraziare",
    "ringraziato": "ringraziare",
    "ringraziava": "ringraziare",
    "ringraziavamo": "ringraziare",
    "ringraziavan": "ringraziare",
    "ringraziavano": "ringraziare",
    "ringraziavate": "ringraziare",
    "ringraziavi": "ringraziare",
    "ringraziavo": "ringraziare",
    "ringrazierai": "ringraziare",
    "ringrazieran": "ringraziare",
    "ringrazieranno": "ringraziare",
    "ringrazierebbe": "ringraziare",
    "ringrazierebber": "ringraziare",
    "ringrazierebbero": "ringraziare",
    "ringrazierei": "ringraziare",
    "ringrazieremmo": "ringraziare",
    "ringrazieremo": "ringraziare",
    "ringraziereste": "ringraziare",
    "ringrazieresti": "ringraziare",
    "ringrazierete": "ringraziare",
    "ringrazierà": "ringraziare",
    "ringrazierò": "ringraziare",
    "ringrazin": "ringraziare",
    "ringrazino": "ringraziare",
    "ringrazio": "ringraziare",
    "ringraziò": "ringraziare",
    "ringuaina": "ringuainare",
    "ringuainai": "ringuainare",
    "ringuainammo": "ringuainare",
    "ringuainan": "ringuainare",
    "ringuainando": "ringuainare",
    "ringuainano": "ringuainare",
    "ringuainante": "ringuainare",
    "ringuainanti": "ringuainare",
    "ringuainar": "ringuainare",
    "ringuainaron": "ringuainare",
    "ringuainarono": "ringuainare",
    "ringuainasse": "ringuainare",
    "ringuainasser": "ringuainare",
    "ringuainassero": "ringuainare",
    "ringuainassi": "ringuainare",
    "ringuainassimo": "ringuainare",
    "ringuainaste": "ringuainare",
    "ringuainasti": "ringuainare",
    "ringuainata": "ringuainare",
    "ringuainate": "ringuainare",
    "ringuainati": "ringuainare",
    "ringuainato": "ringuainare",
    "ringuainava": "ringuainare",
    "ringuainavamo": "ringuainare",
    "ringuainavan": "ringuainare",
    "ringuainavano": "ringuainare",
    "ringuainavate": "ringuainare",
    "ringuainavi": "ringuainare",
    "ringuainavo": "ringuainare",
    "ringuainerai": "ringuainare",
    "ringuaineran": "ringuainare",
    "ringuaineranno": "ringuainare",
    "ringuainerebbe": "ringuainare",
    "ringuainerebber": "ringuainare",
    "ringuainerebbero": "ringuainare",
    "ringuainerei": "ringuainare",
    "ringuaineremmo": "ringuainare",
    "ringuaineremo": "ringuainare",
    "ringuainereste": "ringuainare",
    "ringuaineresti": "ringuainare",
    "ringuainerete": "ringuainare",
    "ringuainerà": "ringuainare",
    "ringuainerò": "ringuainare",
    "ringuaini": "ringuainare",
    "ringuainiamo": "ringuainare",
    "ringuainiate": "ringuainare",
    "ringuainin": "ringuainare",
    "ringuainino": "ringuainare",
    "ringuaino": "ringuainare",
    "ringuainò": "ringuainare",
    "rinnega": "rinnegare",
    "rinnegai": "rinnegare",
    "rinnegammo": "rinnegare",
    "rinnegan": "rinnegare",
    "rinnegando": "rinnegare",
    "rinnegano": "rinnegare",
    "rinnegante": "rinnegare",
    "rinneganti": "rinnegare",
    "rinnegar": "rinnegare",
    "rinnegaron": "rinnegare",
    "rinnegarono": "rinnegare",
    "rinnegasse": "rinnegare",
    "rinnegasser": "rinnegare",
    "rinnegassero": "rinnegare",
    "rinnegassi": "rinnegare",
    "rinnegassimo": "rinnegare",
    "rinnegaste": "rinnegare",
    "rinnegasti": "rinnegare",
    "rinnegata": "rinnegato",
    "rinnegate": "rinnegato",
    "rinnegati": "rinnegato",
    "rinnegato": "rinnegare",
    "rinnegava": "rinnegare",
    "rinnegavamo": "rinnegare",
    "rinnegavan": "rinnegare",
    "rinnegavano": "rinnegare",
    "rinnegavate": "rinnegare",
    "rinnegavi": "rinnegare",
    "rinnegavo": "rinnegare",
    "rinnegherai": "rinnegare",
    "rinnegheran": "rinnegare",
    "rinnegheranno": "rinnegare",
    "rinnegherebbe": "rinnegare",
    "rinnegherebber": "rinnegare",
    "rinnegherebbero": "rinnegare",
    "rinnegherei": "rinnegare",
    "rinnegheremmo": "rinnegare",
    "rinnegheremo": "rinnegare",
    "rinneghereste": "rinnegare",
    "rinnegheresti": "rinnegare",
    "rinnegherete": "rinnegare",
    "rinnegherà": "rinnegare",
    "rinnegherò": "rinnegare",
    "rinneghi": "rinnegare",
    "rinneghiamo": "rinnegare",
    "rinneghiate": "rinnegare",
    "rinneghin": "rinnegare",
    "rinneghino": "rinnegare",
    "rinnego": "rinnegare",
    "rinnegò": "rinnegare",
    "rinnesta": "rinnestare",
    "rinnestai": "rinnestare",
    "rinnestammo": "rinnestare",
    "rinnestan": "rinnestare",
    "rinnestando": "rinnestare",
    "rinnestano": "rinnestare",
    "rinnestante": "rinnestare",
    "rinnestanti": "rinnestare",
    "rinnestar": "rinnestare",
    "rinnestaron": "rinnestare",
    "rinnestarono": "rinnestare",
    "rinnestasse": "rinnestare",
    "rinnestasser": "rinnestare",
    "rinnestassero": "rinnestare",
    "rinnestassi": "rinnestare",
    "rinnestassimo": "rinnestare",
    "rinnestaste": "rinnestare",
    "rinnestasti": "rinnestare",
    "rinnestata": "rinnestare",
    "rinnestate": "rinnestare",
    "rinnestati": "rinnestare",
    "rinnestato": "rinnestare",
    "rinnestava": "rinnestare",
    "rinnestavamo": "rinnestare",
    "rinnestavan": "rinnestare",
    "rinnestavano": "rinnestare",
    "rinnestavate": "rinnestare",
    "rinnestavi": "rinnestare",
    "rinnestavo": "rinnestare",
    "rinnesterai": "rinnestare",
    "rinnesteran": "rinnestare",
    "rinnesteranno": "rinnestare",
    "rinnesterebbe": "rinnestare",
    "rinnesterebber": "rinnestare",
    "rinnesterebbero": "rinnestare",
    "rinnesterei": "rinnestare",
    "rinnesteremmo": "rinnestare",
    "rinnesteremo": "rinnestare",
    "rinnestereste": "rinnestare",
    "rinnesteresti": "rinnestare",
    "rinnesterete": "rinnestare",
    "rinnesterà": "rinnestare",
    "rinnesterò": "rinnestare",
    "rinnesti": "rinnestare",
    "rinnestiamo": "rinnestare",
    "rinnestiate": "rinnestare",
    "rinnestin": "rinnestare",
    "rinnestino": "rinnestare",
    "rinnesto": "rinnestare",
    "rinnestò": "rinnestare",
    "rinnova": "rinnovare",
    "rinnovabili": "rinnovabile",
    "rinnovai": "rinnovare",
    "rinnovamenti": "rinnovamento",
    "rinnovammo": "rinnovare",
    "rinnovan": "rinnovare",
    "rinnovando": "rinnovare",
    "rinnovano": "rinnovare",
    "rinnovante": "rinnovare",
    "rinnovanti": "rinnovare",
    "rinnovar": "rinnovare",
    "rinnovaron": "rinnovare",
    "rinnovarono": "rinnovare",
    "rinnovasse": "rinnovare",
    "rinnovasser": "rinnovare",
    "rinnovassero": "rinnovare",
    "rinnovassi": "rinnovare",
    "rinnovassimo": "rinnovare",
    "rinnovaste": "rinnovare",
    "rinnovasti": "rinnovare",
    "rinnovata": "rinnovare",
    "rinnovate": "rinnovare",
    "rinnovati": "rinnovare",
    "rinnovato": "rinnovare",
    "rinnovatori": "rinnovatore",
    "rinnovatrice": "rinnovatore",
    "rinnovatrici": "rinnovatore",
    "rinnovava": "rinnovare",
    "rinnovavamo": "rinnovare",
    "rinnovavan": "rinnovare",
    "rinnovavano": "rinnovare",
    "rinnovavate": "rinnovare",
    "rinnovavi": "rinnovare",
    "rinnovavo": "rinnovare",
    "rinnovella": "rinnovellare",
    "rinnovellai": "rinnovellare",
    "rinnovellammo": "rinnovellare",
    "rinnovellan": "rinnovellare",
    "rinnovellando": "rinnovellare",
    "rinnovellano": "rinnovellare",
    "rinnovellante": "rinnovellare",
    "rinnovellanti": "rinnovellare",
    "rinnovellar": "rinnovellare",
    "rinnovellaron": "rinnovellare",
    "rinnovellarono": "rinnovellare",
    "rinnovellasse": "rinnovellare",
    "rinnovellasser": "rinnovellare",
    "rinnovellassero": "rinnovellare",
    "rinnovellassi": "rinnovellare",
    "rinnovellassimo": "rinnovellare",
    "rinnovellaste": "rinnovellare",
    "rinnovellasti": "rinnovellare",
    "rinnovellata": "rinnovellare",
    "rinnovellate": "rinnovellare",
    "rinnovellati": "rinnovellare",
    "rinnovellato": "rinnovellare",
    "rinnovellava": "rinnovellare",
    "rinnovellavamo": "rinnovellare",
    "rinnovellavan": "rinnovellare",
    "rinnovellavano": "rinnovellare",
    "rinnovellavate": "rinnovellare",
    "rinnovellavi": "rinnovellare",
    "rinnovellavo": "rinnovellare",
    "rinnovellerai": "rinnovellare",
    "rinnovelleran": "rinnovellare",
    "rinnovelleranno": "rinnovellare",
    "rinnovellerebbe": "rinnovellare",
    "rinnovellerebber": "rinnovellare",
    "rinnovellerebbero": "rinnovellare",
    "rinnovellerei": "rinnovellare",
    "rinnovelleremmo": "rinnovellare",
    "rinnovelleremo": "rinnovellare",
    "rinnovellereste": "rinnovellare",
    "rinnovelleresti": "rinnovellare",
    "rinnovellerete": "rinnovellare",
    "rinnovellerà": "rinnovellare",
    "rinnovellerò": "rinnovellare",
    "rinnovelli": "rinnovellare",
    "rinnovelliamo": "rinnovellare",
    "rinnovelliate": "rinnovellare",
    "rinnovellin": "rinnovellare",
    "rinnovellino": "rinnovellare",
    "rinnovello": "rinnovellare",
    "rinnovellò": "rinnovellare",
    "rinnoverai": "rinnovare",
    "rinnoveran": "rinnovare",
    "rinnoveranno": "rinnovare",
    "rinnoverebbe": "rinnovare",
    "rinnoverebber": "rinnovare",
    "rinnoverebbero": "rinnovare",
    "rinnoverei": "rinnovare",
    "rinnoveremmo": "rinnovare",
    "rinnoveremo": "rinnovare",
    "rinnovereste": "rinnovare",
    "rinnoveresti": "rinnovare",
    "rinnoverete": "rinnovare",
    "rinnoverà": "rinnovare",
    "rinnoverò": "rinnovare",
    "rinnovi": "rinnovo",
    "rinnoviamo": "rinnovare",
    "rinnoviate": "rinnovare",
    "rinnovin": "rinnovare",
    "rinnovino": "rinnovare",
    "rinnovo": "rinnovare",
    "rinnovò": "rinnovare",
    "rinoceronti": "rinoceronte",
    "rinomanze": "rinomanza",
    "rinomata": "rinomato",
    "rinomate": "rinomato",
    "rinomati": "rinomato",
    "rinsacca": "rinsaccare",
    "rinsaccai": "rinsaccare",
    "rinsaccammo": "rinsaccare",
    "rinsaccan": "rinsaccare",
    "rinsaccando": "rinsaccare",
    "rinsaccano": "rinsaccare",
    "rinsaccante": "rinsaccare",
    "rinsaccanti": "rinsaccare",
    "rinsaccar": "rinsaccare",
    "rinsaccaron": "rinsaccare",
    "rinsaccarono": "rinsaccare",
    "rinsaccasse": "rinsaccare",
    "rinsaccasser": "rinsaccare",
    "rinsaccassero": "rinsaccare",
    "rinsaccassi": "rinsaccare",
    "rinsaccassimo": "rinsaccare",
    "rinsaccaste": "rinsaccare",
    "rinsaccasti": "rinsaccare",
    "rinsaccata": "rinsaccare",
    "rinsaccate": "rinsaccare",
    "rinsaccati": "rinsaccare",
    "rinsaccato": "rinsaccare",
    "rinsaccava": "rinsaccare",
    "rinsaccavamo": "rinsaccare",
    "rinsaccavan": "rinsaccare",
    "rinsaccavano": "rinsaccare",
    "rinsaccavate": "rinsaccare",
    "rinsaccavi": "rinsaccare",
    "rinsaccavo": "rinsaccare",
    "rinsaccherai": "rinsaccare",
    "rinsaccheran": "rinsaccare",
    "rinsaccheranno": "rinsaccare",
    "rinsaccherebbe": "rinsaccare",
    "rinsaccherebber": "rinsaccare",
    "rinsaccherebbero": "rinsaccare",
    "rinsaccherei": "rinsaccare",
    "rinsaccheremmo": "rinsaccare",
    "rinsaccheremo": "rinsaccare",
    "rinsacchereste": "rinsaccare",
    "rinsaccheresti": "rinsaccare",
    "rinsaccherete": "rinsaccare",
    "rinsaccherà": "rinsaccare",
    "rinsaccherò": "rinsaccare",
    "rinsacchi": "rinsaccare",
    "rinsacchiamo": "rinsaccare",
    "rinsacchiate": "rinsaccare",
    "rinsacchin": "rinsaccare",
    "rinsacchino": "rinsaccare",
    "rinsacco": "rinsaccare",
    "rinsaccò": "rinsaccare",
    "rinsalda": "rinsaldare",
    "rinsaldai": "rinsaldare",
    "rinsaldammo": "rinsaldare",
    "rinsaldan": "rinsaldare",
    "rinsaldando": "rinsaldare",
    "rinsaldano": "rinsaldare",
    "rinsaldante": "rinsaldare",
    "rinsaldanti": "rinsaldare",
    "rinsaldar": "rinsaldare",
    "rinsaldaron": "rinsaldare",
    "rinsaldarono": "rinsaldare",
    "rinsaldasse": "rinsaldare",
    "rinsaldasser": "rinsaldare",
    "rinsaldassero": "rinsaldare",
    "rinsaldassi": "rinsaldare",
    "rinsaldassimo": "rinsaldare",
    "rinsaldaste": "rinsaldare",
    "rinsaldasti": "rinsaldare",
    "rinsaldata": "rinsaldare",
    "rinsaldate": "rinsaldare",
    "rinsaldati": "rinsaldare",
    "rinsaldato": "rinsaldare",
    "rinsaldava": "rinsaldare",
    "rinsaldavamo": "rinsaldare",
    "rinsaldavan": "rinsaldare",
    "rinsaldavano": "rinsaldare",
    "rinsaldavate": "rinsaldare",
    "rinsaldavi": "rinsaldare",
    "rinsaldavo": "rinsaldare",
    "rinsalderai": "rinsaldare",
    "rinsalderan": "rinsaldare",
    "rinsalderanno": "rinsaldare",
    "rinsalderebbe": "rinsaldare",
    "rinsalderebber": "rinsaldare",
    "rinsalderebbero": "rinsaldare",
    "rinsalderei": "rinsaldare",
    "rinsalderemmo": "rinsaldare",
    "rinsalderemo": "rinsaldare",
    "rinsaldereste": "rinsaldare",
    "rinsalderesti": "rinsaldare",
    "rinsalderete": "rinsaldare",
    "rinsalderà": "rinsaldare",
    "rinsalderò": "rinsaldare",
    "rinsaldi": "rinsaldare",
    "rinsaldiamo": "rinsaldare",
    "rinsaldiate": "rinsaldare",
    "rinsaldin": "rinsaldare",
    "rinsaldino": "rinsaldare",
    "rinsaldo": "rinsaldare",
    "rinsaldò": "rinsaldare",
    "rinsangua": "rinsanguare",
    "rinsanguai": "rinsanguare",
    "rinsanguammo": "rinsanguare",
    "rinsanguan": "rinsanguare",
    "rinsanguando": "rinsanguare",
    "rinsanguano": "rinsanguare",
    "rinsanguante": "rinsanguare",
    "rinsanguanti": "rinsanguare",
    "rinsanguar": "rinsanguare",
    "rinsanguaron": "rinsanguare",
    "rinsanguarono": "rinsanguare",
    "rinsanguasse": "rinsanguare",
    "rinsanguasser": "rinsanguare",
    "rinsanguassero": "rinsanguare",
    "rinsanguassi": "rinsanguare",
    "rinsanguassimo": "rinsanguare",
    "rinsanguaste": "rinsanguare",
    "rinsanguasti": "rinsanguare",
    "rinsanguata": "rinsanguare",
    "rinsanguate": "rinsanguare",
    "rinsanguati": "rinsanguare",
    "rinsanguato": "rinsanguare",
    "rinsanguava": "rinsanguare",
    "rinsanguavamo": "rinsanguare",
    "rinsanguavan": "rinsanguare",
    "rinsanguavano": "rinsanguare",
    "rinsanguavate": "rinsanguare",
    "rinsanguavi": "rinsanguare",
    "rinsanguavo": "rinsanguare",
    "rinsanguerai": "rinsanguare",
    "rinsangueran": "rinsanguare",
    "rinsangueranno": "rinsanguare",
    "rinsanguerebbe": "rinsanguare",
    "rinsanguerebber": "rinsanguare",
    "rinsanguerebbero": "rinsanguare",
    "rinsanguerei": "rinsanguare",
    "rinsangueremmo": "rinsanguare",
    "rinsangueremo": "rinsanguare",
    "rinsanguereste": "rinsanguare",
    "rinsangueresti": "rinsanguare",
    "rinsanguerete": "rinsanguare",
    "rinsanguerà": "rinsanguare",
    "rinsanguerò": "rinsanguare",
    "rinsangui": "rinsanguare",
    "rinsanguiamo": "rinsanguare",
    "rinsanguiate": "rinsanguare",
    "rinsanguin": "rinsanguare",
    "rinsanguino": "rinsanguare",
    "rinsanguo": "rinsanguare",
    "rinsanguò": "rinsanguare",
    "rinsava": "rinsavire",
    "rinsavan": "rinsavire",
    "rinsavano": "rinsavire",
    "rinsave": "rinsavire",
    "rinsavendo": "rinsavire",
    "rinsavente": "rinsavire",
    "rinsaventi": "rinsavire",
    "rinsavi": "rinsavire",
    "rinsaviamo": "rinsavire",
    "rinsaviate": "rinsavire",
    "rinsavii": "rinsavire",
    "rinsavimmo": "rinsavire",
    "rinsavir": "rinsavire",
    "rinsavirai": "rinsavire",
    "rinsaviran": "rinsavire",
    "rinsaviranno": "rinsavire",
    "rinsavirebbe": "rinsavire",
    "rinsavirebber": "rinsavire",
    "rinsavirebbero": "rinsavire",
    "rinsavirei": "rinsavire",
    "rinsaviremmo": "rinsavire",
    "rinsaviremo": "rinsavire",
    "rinsavireste": "rinsavire",
    "rinsaviresti": "rinsavire",
    "rinsavirete": "rinsavire",
    "rinsaviron": "rinsavire",
    "rinsavirono": "rinsavire",
    "rinsavirà": "rinsavire",
    "rinsavirò": "rinsavire",
    "rinsavisse": "rinsavire",
    "rinsavisser": "rinsavire",
    "rinsavissero": "rinsavire",
    "rinsavissi": "rinsavire",
    "rinsavissimo": "rinsavire",
    "rinsaviste": "rinsavire",
    "rinsavisti": "rinsavire",
    "rinsavita": "rinsavire",
    "rinsavite": "rinsavire",
    "rinsaviti": "rinsavire",
    "rinsavito": "rinsavire",
    "rinsaviva": "rinsavire",
    "rinsavivamo": "rinsavire",
    "rinsavivan": "rinsavire",
    "rinsavivano": "rinsavire",
    "rinsavivate": "rinsavire",
    "rinsavivi": "rinsavire",
    "rinsavivo": "rinsavire",
    "rinsavo": "rinsavire",
    "rinsavon": "rinsavire",
    "rinsavono": "rinsavire",
    "rinsavì": "rinsavire",
    "rinseccha": "rinsecchire",
    "rinsecchan": "rinsecchire",
    "rinsecchano": "rinsecchire",
    "rinsecche": "rinsecchire",
    "rinsecchendo": "rinsecchire",
    "rinsecchente": "rinsecchire",
    "rinsecchenti": "rinsecchire",
    "rinsecchi": "rinsecchire",
    "rinsecchiamo": "rinsecchire",
    "rinsecchiate": "rinsecchire",
    "rinsecchii": "rinsecchire",
    "rinsecchimmo": "rinsecchire",
    "rinsecchir": "rinsecchire",
    "rinsecchirai": "rinsecchire",
    "rinsecchiran": "rinsecchire",
    "rinsecchiranno": "rinsecchire",
    "rinsecchirebbe": "rinsecchire",
    "rinsecchirebber": "rinsecchire",
    "rinsecchirebbero": "rinsecchire",
    "rinsecchirei": "rinsecchire",
    "rinsecchiremmo": "rinsecchire",
    "rinsecchiremo": "rinsecchire",
    "rinsecchireste": "rinsecchire",
    "rinsecchiresti": "rinsecchire",
    "rinsecchirete": "rinsecchire",
    "rinsecchiron": "rinsecchire",
    "rinsecchirono": "rinsecchire",
    "rinsecchirà": "rinsecchire",
    "rinsecchirò": "rinsecchire",
    "rinsecchisse": "rinsecchire",
    "rinsecchisser": "rinsecchire",
    "rinsecchissero": "rinsecchire",
    "rinsecchissi": "rinsecchire",
    "rinsecchissimo": "rinsecchire",
    "rinsecchiste": "rinsecchire",
    "rinsecchisti": "rinsecchire",
    "rinsecchita": "rinsecchire",
    "rinsecchite": "rinsecchire",
    "rinsecchiti": "rinsecchire",
    "rinsecchito": "rinsecchire",
    "rinsecchiva": "rinsecchire",
    "rinsecchivamo": "rinsecchire",
    "rinsecchivan": "rinsecchire",
    "rinsecchivano": "rinsecchire",
    "rinsecchivate": "rinsecchire",
    "rinsecchivi": "rinsecchire",
    "rinsecchivo": "rinsecchire",
    "rinseccho": "rinsecchire",
    "rinsecchon": "rinsecchire",
    "rinsecchono": "rinsecchire",
    "rinsecchì": "rinsecchire",
    "rinserra": "rinserrare",
    "rinserrai": "rinserrare",
    "rinserrammo": "rinserrare",
    "rinserran": "rinserrare",
    "rinserrando": "rinserrare",
    "rinserrano": "rinserrare",
    "rinserrante": "rinserrare",
    "rinserranti": "rinserrare",
    "rinserrar": "rinserrare",
    "rinserraron": "rinserrare",
    "rinserrarono": "rinserrare",
    "rinserrasse": "rinserrare",
    "rinserrasser": "rinserrare",
    "rinserrassero": "rinserrare",
    "rinserrassi": "rinserrare",
    "rinserrassimo": "rinserrare",
    "rinserraste": "rinserrare",
    "rinserrasti": "rinserrare",
    "rinserrata": "rinserrare",
    "rinserrate": "rinserrare",
    "rinserrati": "rinserrare",
    "rinserrato": "rinserrare",
    "rinserrava": "rinserrare",
    "rinserravamo": "rinserrare",
    "rinserravan": "rinserrare",
    "rinserravano": "rinserrare",
    "rinserravate": "rinserrare",
    "rinserravi": "rinserrare",
    "rinserravo": "rinserrare",
    "rinserrerai": "rinserrare",
    "rinserreran": "rinserrare",
    "rinserreranno": "rinserrare",
    "rinserrerebbe": "rinserrare",
    "rinserrerebber": "rinserrare",
    "rinserrerebbero": "rinserrare",
    "rinserrerei": "rinserrare",
    "rinserreremmo": "rinserrare",
    "rinserreremo": "rinserrare",
    "rinserrereste": "rinserrare",
    "rinserreresti": "rinserrare",
    "rinserrerete": "rinserrare",
    "rinserrerà": "rinserrare",
    "rinserrerò": "rinserrare",
    "rinserri": "rinserrare",
    "rinserriamo": "rinserrare",
    "rinserriate": "rinserrare",
    "rinserrin": "rinserrare",
    "rinserrino": "rinserrare",
    "rinserro": "rinserrare",
    "rinserrò": "rinserrare",
    "rintana": "rintanare",
    "rintanai": "rintanare",
    "rintanammo": "rintanare",
    "rintanan": "rintanare",
    "rintanando": "rintanare",
    "rintanano": "rintanare",
    "rintanante": "rintanare",
    "rintananti": "rintanare",
    "rintanar": "rintanare",
    "rintanaron": "rintanare",
    "rintanarono": "rintanare",
    "rintanasse": "rintanare",
    "rintanasser": "rintanare",
    "rintanassero": "rintanare",
    "rintanassi": "rintanare",
    "rintanassimo": "rintanare",
    "rintanaste": "rintanare",
    "rintanasti": "rintanare",
    "rintanata": "rintanare",
    "rintanate": "rintanare",
    "rintanati": "rintanare",
    "rintanato": "rintanare",
    "rintanava": "rintanare",
    "rintanavamo": "rintanare",
    "rintanavan": "rintanare",
    "rintanavano": "rintanare",
    "rintanavate": "rintanare",
    "rintanavi": "rintanare",
    "rintanavo": "rintanare",
    "rintanerai": "rintanare",
    "rintaneran": "rintanare",
    "rintaneranno": "rintanare",
    "rintanerebbe": "rintanare",
    "rintanerebber": "rintanare",
    "rintanerebbero": "rintanare",
    "rintanerei": "rintanare",
    "rintaneremmo": "rintanare",
    "rintaneremo": "rintanare",
    "rintanereste": "rintanare",
    "rintaneresti": "rintanare",
    "rintanerete": "rintanare",
    "rintanerà": "rintanare",
    "rintanerò": "rintanare",
    "rintani": "rintanare",
    "rintaniamo": "rintanare",
    "rintaniate": "rintanare",
    "rintanin": "rintanare",
    "rintanino": "rintanare",
    "rintano": "rintanare",
    "rintanò": "rintanare",
    "rintela": "rintelare",
    "rintelai": "rintelare",
    "rintelammo": "rintelare",
    "rintelan": "rintelare",
    "rintelando": "rintelare",
    "rintelano": "rintelare",
    "rintelante": "rintelare",
    "rintelanti": "rintelare",
    "rintelar": "rintelare",
    "rintelaron": "rintelare",
    "rintelarono": "rintelare",
    "rintelasse": "rintelare",
    "rintelasser": "rintelare",
    "rintelassero": "rintelare",
    "rintelassi": "rintelare",
    "rintelassimo": "rintelare",
    "rintelaste": "rintelare",
    "rintelasti": "rintelare",
    "rintelata": "rintelare",
    "rintelate": "rintelare",
    "rintelati": "rintelare",
    "rintelato": "rintelare",
    "rintelava": "rintelare",
    "rintelavamo": "rintelare",
    "rintelavan": "rintelare",
    "rintelavano": "rintelare",
    "rintelavate": "rintelare",
    "rintelavi": "rintelare",
    "rintelavo": "rintelare",
    "rintelerai": "rintelare",
    "rinteleran": "rintelare",
    "rinteleranno": "rintelare",
    "rintelerebbe": "rintelare",
    "rintelerebber": "rintelare",
    "rintelerebbero": "rintelare",
    "rintelerei": "rintelare",
    "rinteleremmo": "rintelare",
    "rinteleremo": "rintelare",
    "rintelereste": "rintelare",
    "rinteleresti": "rintelare",
    "rintelerete": "rintelare",
    "rintelerà": "rintelare",
    "rintelerò": "rintelare",
    "rinteli": "rintelare",
    "rinteliamo": "rintelare",
    "rinteliate": "rintelare",
    "rintelin": "rintelare",
    "rintelino": "rintelare",
    "rintelo": "rintelare",
    "rintelò": "rintelare",
    "rintocca": "rintoccare",
    "rintoccai": "rintoccare",
    "rintoccammo": "rintoccare",
    "rintoccan": "rintoccare",
    "rintoccando": "rintoccare",
    "rintoccano": "rintoccare",
    "rintoccante": "rintoccare",
    "rintoccanti": "rintoccare",
    "rintoccar": "rintoccare",
    "rintoccaron": "rintoccare",
    "rintoccarono": "rintoccare",
    "rintoccasse": "rintoccare",
    "rintoccasser": "rintoccare",
    "rintoccassero": "rintoccare",
    "rintoccassi": "rintoccare",
    "rintoccassimo": "rintoccare",
    "rintoccaste": "rintoccare",
    "rintoccasti": "rintoccare",
    "rintoccata": "rintoccare",
    "rintoccate": "rintoccare",
    "rintoccati": "rintoccare",
    "rintoccato": "rintoccare",
    "rintoccava": "rintoccare",
    "rintoccavamo": "rintoccare",
    "rintoccavan": "rintoccare",
    "rintoccavano": "rintoccare",
    "rintoccavate": "rintoccare",
    "rintoccavi": "rintoccare",
    "rintoccavo": "rintoccare",
    "rintoccherai": "rintoccare",
    "rintoccheran": "rintoccare",
    "rintoccheranno": "rintoccare",
    "rintoccherebbe": "rintoccare",
    "rintoccherebber": "rintoccare",
    "rintoccherebbero": "rintoccare",
    "rintoccherei": "rintoccare",
    "rintoccheremmo": "rintoccare",
    "rintoccheremo": "rintoccare",
    "rintocchereste": "rintoccare",
    "rintoccheresti": "rintoccare",
    "rintoccherete": "rintoccare",
    "rintoccherà": "rintoccare",
    "rintoccherò": "rintoccare",
    "rintocchi": "rintocco",
    "rintocchiamo": "rintoccare",
    "rintocchiate": "rintoccare",
    "rintocchin": "rintoccare",
    "rintocchino": "rintoccare",
    "rintocco": "rintoccare",
    "rintoccò": "rintoccare",
    "rintonta": "rintontire",
    "rintontan": "rintontire",
    "rintontano": "rintontire",
    "rintonte": "rintontire",
    "rintontendo": "rintontire",
    "rintontente": "rintontire",
    "rintontenti": "rintontire",
    "rintonti": "rintontire",
    "rintontiamo": "rintontire",
    "rintontiate": "rintontire",
    "rintontii": "rintontire",
    "rintontimmo": "rintontire",
    "rintontir": "rintontire",
    "rintontirai": "rintontire",
    "rintontiran": "rintontire",
    "rintontiranno": "rintontire",
    "rintontirebbe": "rintontire",
    "rintontirebber": "rintontire",
    "rintontirebbero": "rintontire",
    "rintontirei": "rintontire",
    "rintontiremmo": "rintontire",
    "rintontiremo": "rintontire",
    "rintontireste": "rintontire",
    "rintontiresti": "rintontire",
    "rintontirete": "rintontire",
    "rintontiron": "rintontire",
    "rintontirono": "rintontire",
    "rintontirà": "rintontire",
    "rintontirò": "rintontire",
    "rintontisse": "rintontire",
    "rintontisser": "rintontire",
    "rintontissero": "rintontire",
    "rintontissi": "rintontire",
    "rintontissimo": "rintontire",
    "rintontiste": "rintontire",
    "rintontisti": "rintontire",
    "rintontita": "rintontire",
    "rintontite": "rintontire",
    "rintontiti": "rintontire",
    "rintontito": "rintontire",
    "rintontiva": "rintontire",
    "rintontivamo": "rintontire",
    "rintontivan": "rintontire",
    "rintontivano": "rintontire",
    "rintontivate": "rintontire",
    "rintontivi": "rintontire",
    "rintontivo": "rintontire",
    "rintonto": "rintontire",
    "rintonton": "rintontire",
    "rintontono": "rintontire",
    "rintontì": "rintontire",
    "rintraccerai": "rintracciare",
    "rintracceran": "rintracciare",
    "rintracceranno": "rintracciare",
    "rintraccerebbe": "rintracciare",
    "rintraccerebber": "rintracciare",
    "rintraccerebbero": "rintracciare",
    "rintraccerei": "rintracciare",
    "rintracceremmo": "rintracciare",
    "rintracceremo": "rintracciare",
    "rintraccereste": "rintracciare",
    "rintracceresti": "rintracciare",
    "rintraccerete": "rintracciare",
    "rintraccerà": "rintracciare",
    "rintraccerò": "rintracciare",
    "rintracci": "rintracciare",
    "rintraccia": "rintracciare",
    "rintracciabili": "rintracciabile",
    "rintracciai": "rintracciare",
    "rintracciammo": "rintracciare",
    "rintracciamo": "rintracciare",
    "rintraccian": "rintracciare",
    "rintracciando": "rintracciare",
    "rintracciano": "rintracciare",
    "rintracciante": "rintracciare",
    "rintraccianti": "rintracciare",
    "rintracciar": "rintracciare",
    "rintracciaron": "rintracciare",
    "rintracciarono": "rintracciare",
    "rintracciasse": "rintracciare",
    "rintracciasser": "rintracciare",
    "rintracciassero": "rintracciare",
    "rintracciassi": "rintracciare",
    "rintracciassimo": "rintracciare",
    "rintracciaste": "rintracciare",
    "rintracciasti": "rintracciare",
    "rintracciata": "rintracciare",
    "rintracciate": "rintracciare",
    "rintracciati": "rintracciare",
    "rintracciato": "rintracciare",
    "rintracciava": "rintracciare",
    "rintracciavamo": "rintracciare",
    "rintracciavan": "rintracciare",
    "rintracciavano": "rintracciare",
    "rintracciavate": "rintracciare",
    "rintracciavi": "rintracciare",
    "rintracciavo": "rintracciare",
    "rintraccin": "rintracciare",
    "rintraccino": "rintracciare",
    "rintraccio": "rintracciare",
    "rintracciò": "rintracciare",
    "rintrona": "rintronare",
    "rintronai": "rintronare",
    "rintronammo": "rintronare",
    "rintronan": "rintronare",
    "rintronando": "rintronare",
    "rintronano": "rintronare",
    "rintronante": "rintronare",
    "rintronanti": "rintronare",
    "rintronar": "rintronare",
    "rintronaron": "rintronare",
    "rintronarono": "rintronare",
    "rintronasse": "rintronare",
    "rintronasser": "rintronare",
    "rintronassero": "rintronare",
    "rintronassi": "rintronare",
    "rintronassimo": "rintronare",
    "rintronaste": "rintronare",
    "rintronasti": "rintronare",
    "rintronata": "rintronare",
    "rintronate": "rintronare",
    "rintronati": "rintronare",
    "rintronato": "rintronare",
    "rintronava": "rintronare",
    "rintronavamo": "rintronare",
    "rintronavan": "rintronare",
    "rintronavano": "rintronare",
    "rintronavate": "rintronare",
    "rintronavi": "rintronare",
    "rintronavo": "rintronare",
    "rintronerai": "rintronare",
    "rintroneran": "rintronare",
    "rintroneranno": "rintronare",
    "rintronerebbe": "rintronare",
    "rintronerebber": "rintronare",
    "rintronerebbero": "rintronare",
    "rintronerei": "rintronare",
    "rintroneremmo": "rintronare",
    "rintroneremo": "rintronare",
    "rintronereste": "rintronare",
    "rintroneresti": "rintronare",
    "rintronerete": "rintronare",
    "rintronerà": "rintronare",
    "rintronerò": "rintronare",
    "rintroni": "rintronare",
    "rintroniamo": "rintronare",
    "rintroniate": "rintronare",
    "rintronin": "rintronare",
    "rintronino": "rintronare",
    "rintrono": "rintronare",
    "rintronò": "rintronare",
    "rintuzza": "rintuzzare",
    "rintuzzai": "rintuzzare",
    "rintuzzammo": "rintuzzare",
    "rintuzzan": "rintuzzare",
    "rintuzzando": "rintuzzare",
    "rintuzzano": "rintuzzare",
    "rintuzzante": "rintuzzare",
    "rintuzzanti": "rintuzzare",
    "rintuzzar": "rintuzzare",
    "rintuzzaron": "rintuzzare",
    "rintuzzarono": "rintuzzare",
    "rintuzzasse": "rintuzzare",
    "rintuzzasser": "rintuzzare",
    "rintuzzassero": "rintuzzare",
    "rintuzzassi": "rintuzzare",
    "rintuzzassimo": "rintuzzare",
    "rintuzzaste": "rintuzzare",
    "rintuzzasti": "rintuzzare",
    "rintuzzata": "rintuzzare",
    "rintuzzate": "rintuzzare",
    "rintuzzati": "rintuzzare",
    "rintuzzato": "rintuzzare",
    "rintuzzava": "rintuzzare",
    "rintuzzavamo": "rintuzzare",
    "rintuzzavan": "rintuzzare",
    "rintuzzavano": "rintuzzare",
    "rintuzzavate": "rintuzzare",
    "rintuzzavi": "rintuzzare",
    "rintuzzavo": "rintuzzare",
    "rintuzzerai": "rintuzzare",
    "rintuzzeran": "rintuzzare",
    "rintuzzeranno": "rintuzzare",
    "rintuzzerebbe": "rintuzzare",
    "rintuzzerebber": "rintuzzare",
    "rintuzzerebbero": "rintuzzare",
    "rintuzzerei": "rintuzzare",
    "rintuzzeremmo": "rintuzzare",
    "rintuzzeremo": "rintuzzare",
    "rintuzzereste": "rintuzzare",
    "rintuzzeresti": "rintuzzare",
    "rintuzzerete": "rintuzzare",
    "rintuzzerà": "rintuzzare",
    "rintuzzerò": "rintuzzare",
    "rintuzzi": "rintuzzare",
    "rintuzziamo": "rintuzzare",
    "rintuzziate": "rintuzzare",
    "rintuzzin": "rintuzzare",
    "rintuzzino": "rintuzzare",
    "rintuzzo": "rintuzzare",
    "rintuzzò": "rintuzzare",
    "rinunce": "rinuncia",
    "rinuncerai": "rinunciare",
    "rinunceran": "rinunciare",
    "rinunceranno": "rinunciare",
    "rinuncerebbe": "rinunciare",
    "rinuncerebber": "rinunciare",
    "rinuncerebbero": "rinunciare",
    "rinuncerei": "rinunciare",
    "rinunceremmo": "rinunciare",
    "rinunceremo": "rinunciare",
    "rinuncereste": "rinunciare",
    "rinunceresti": "rinunciare",
    "rinuncerete": "rinunciare",
    "rinuncerà": "rinunciare",
    "rinuncerò": "rinunciare",
    "rinunci": "rinunciare",
    "rinuncia": "rinunciare",
    "rinunciai": "rinunciare",
    "rinunciammo": "rinunciare",
    "rinunciamo": "rinunciare",
    "rinuncian": "rinunciare",
    "rinunciando": "rinunciare",
    "rinunciano": "rinunciare",
    "rinunciante": "rinunciare",
    "rinuncianti": "rinunciare",
    "rinunciar": "rinunciare",
    "rinunciaron": "rinunciare",
    "rinunciarono": "rinunciare",
    "rinunciasse": "rinunciare",
    "rinunciasser": "rinunciare",
    "rinunciassero": "rinunciare",
    "rinunciassi": "rinunciare",
    "rinunciassimo": "rinunciare",
    "rinunciaste": "rinunciare",
    "rinunciasti": "rinunciare",
    "rinunciata": "rinunciare",
    "rinunciatari": "rinunciatario",
    "rinunciataria": "rinunciatario",
    "rinunciatarie": "rinunciatario",
    "rinunciate": "rinunciare",
    "rinunciati": "rinunciare",
    "rinunciato": "rinunciare",
    "rinunciava": "rinunciare",
    "rinunciavamo": "rinunciare",
    "rinunciavan": "rinunciare",
    "rinunciavano": "rinunciare",
    "rinunciavate": "rinunciare",
    "rinunciavi": "rinunciare",
    "rinunciavo": "rinunciare",
    "rinuncin": "rinunciare",
    "rinuncino": "rinunciare",
    "rinuncio": "rinunciare",
    "rinunciò": "rinunciare",
    "rinunzi": "rinunziare",
    "rinunzia": "rinunziare",
    "rinunziai": "rinunziare",
    "rinunziammo": "rinunziare",
    "rinunziamo": "rinunziare",
    "rinunzian": "rinunziare",
    "rinunziando": "rinunziare",
    "rinunziano": "rinunziare",
    "rinunziante": "rinunziare",
    "rinunzianti": "rinunziare",
    "rinunziar": "rinunziare",
    "rinunziaron": "rinunziare",
    "rinunziarono": "rinunziare",
    "rinunziasse": "rinunziare",
    "rinunziasser": "rinunziare",
    "rinunziassero": "rinunziare",
    "rinunziassi": "rinunziare",
    "rinunziassimo": "rinunziare",
    "rinunziaste": "rinunziare",
    "rinunziasti": "rinunziare",
    "rinunziata": "rinunziare",
    "rinunziate": "rinunziare",
    "rinunziati": "rinunziare",
    "rinunziato": "rinunziare",
    "rinunziava": "rinunziare",
    "rinunziavamo": "rinunziare",
    "rinunziavan": "rinunziare",
    "rinunziavano": "rinunziare",
    "rinunziavate": "rinunziare",
    "rinunziavi": "rinunziare",
    "rinunziavo": "rinunziare",
    "rinunzie": "rinunzia",
    "rinunzierai": "rinunziare",
    "rinunzieran": "rinunziare",
    "rinunzieranno": "rinunziare",
    "rinunzierebbe": "rinunziare",
    "rinunzierebber": "rinunziare",
    "rinunzierebbero": "rinunziare",
    "rinunzierei": "rinunziare",
    "rinunzieremmo": "rinunziare",
    "rinunzieremo": "rinunziare",
    "rinunziereste": "rinunziare",
    "rinunzieresti": "rinunziare",
    "rinunzierete": "rinunziare",
    "rinunzierà": "rinunziare",
    "rinunzierò": "rinunziare",
    "rinunzin": "rinunziare",
    "rinunzino": "rinunziare",
    "rinunzio": "rinunziare",
    "rinunziò": "rinunziare",
    "rinvanga": "rinvangare",
    "rinvangai": "rinvangare",
    "rinvangammo": "rinvangare",
    "rinvangan": "rinvangare",
    "rinvangando": "rinvangare",
    "rinvangano": "rinvangare",
    "rinvangante": "rinvangare",
    "rinvanganti": "rinvangare",
    "rinvangar": "rinvangare",
    "rinvangaron": "rinvangare",
    "rinvangarono": "rinvangare",
    "rinvangasse": "rinvangare",
    "rinvangasser": "rinvangare",
    "rinvangassero": "rinvangare",
    "rinvangassi": "rinvangare",
    "rinvangassimo": "rinvangare",
    "rinvangaste": "rinvangare",
    "rinvangasti": "rinvangare",
    "rinvangata": "rinvangare",
    "rinvangate": "rinvangare",
    "rinvangati": "rinvangare",
    "rinvangato": "rinvangare",
    "rinvangava": "rinvangare",
    "rinvangavamo": "rinvangare",
    "rinvangavan": "rinvangare",
    "rinvangavano": "rinvangare",
    "rinvangavate": "rinvangare",
    "rinvangavi": "rinvangare",
    "rinvangavo": "rinvangare",
    "rinvangherai": "rinvangare",
    "rinvangheran": "rinvangare",
    "rinvangheranno": "rinvangare",
    "rinvangherebbe": "rinvangare",
    "rinvangherebber": "rinvangare",
    "rinvangherebbero": "rinvangare",
    "rinvangherei": "rinvangare",
    "rinvangheremmo": "rinvangare",
    "rinvangheremo": "rinvangare",
    "rinvanghereste": "rinvangare",
    "rinvangheresti": "rinvangare",
    "rinvangherete": "rinvangare",
    "rinvangherà": "rinvangare",
    "rinvangherò": "rinvangare",
    "rinvanghi": "rinvangare",
    "rinvanghiamo": "rinvangare",
    "rinvanghiate": "rinvangare",
    "rinvanghin": "rinvangare",
    "rinvanghino": "rinvangare",
    "rinvango": "rinvangare",
    "rinvangò": "rinvangare",
    "rinvenendo": "rinvenire",
    "rinvenente": "rinvenire",
    "rinvenenti": "rinvenire",
    "rinvenga": "rinvenire",
    "rinvengan": "rinvenire",
    "rinvengano": "rinvenire",
    "rinvengo": "rinvenire",
    "rinvengon": "rinvenire",
    "rinvengono": "rinvenire",
    "rinveniamo": "rinvenire",
    "rinveniate": "rinvenire",
    "rinvenimenti": "rinvenimento",
    "rinvenimmo": "rinvenire",
    "rinvenir": "rinvenire",
    "rinvenisse": "rinvenire",
    "rinvenisser": "rinvenire",
    "rinvenissero": "rinvenire",
    "rinvenissi": "rinvenire",
    "rinvenissimo": "rinvenire",
    "rinveniste": "rinvenire",
    "rinvenisti": "rinvenire",
    "rinvenite": "rinvenire",
    "rinveniva": "rinvenire",
    "rinvenivamo": "rinvenire",
    "rinvenivan": "rinvenire",
    "rinvenivano": "rinvenire",
    "rinvenivate": "rinvenire",
    "rinvenivi": "rinvenire",
    "rinvenivo": "rinvenire",
    "rinvenne": "rinvenire",
    "rinvenner": "rinvenire",
    "rinvennero": "rinvenire",
    "rinvenni": "rinvenire",
    "rinvenuta": "rinvenire",
    "rinvenute": "rinvenire",
    "rinvenuti": "rinvenire",
    "rinvenuto": "rinvenire",
    "rinverdendo": "rinverdire",
    "rinverdente": "rinverdire",
    "rinverdenti": "rinverdire",
    "rinverdiamo": "rinverdire",
    "rinverdiate": "rinverdire",
    "rinverdii": "rinverdire",
    "rinverdimmo": "rinverdire",
    "rinverdir": "rinverdire",
    "rinverdirai": "rinverdire",
    "rinverdiran": "rinverdire",
    "rinverdiranno": "rinverdire",
    "rinverdirebbe": "rinverdire",
    "rinverdirebber": "rinverdire",
    "rinverdirebbero": "rinverdire",
    "rinverdirei": "rinverdire",
    "rinverdiremmo": "rinverdire",
    "rinverdiremo": "rinverdire",
    "rinverdireste": "rinverdire",
    "rinverdiresti": "rinverdire",
    "rinverdirete": "rinverdire",
    "rinverdiron": "rinverdire",
    "rinverdirono": "rinverdire",
    "rinverdirà": "rinverdire",
    "rinverdirò": "rinverdire",
    "rinverdisca": "rinverdire",
    "rinverdiscan": "rinverdire",
    "rinverdiscano": "rinverdire",
    "rinverdisce": "rinverdire",
    "rinverdisci": "rinverdire",
    "rinverdisco": "rinverdire",
    "rinverdiscon": "rinverdire",
    "rinverdiscono": "rinverdire",
    "rinverdisse": "rinverdire",
    "rinverdisser": "rinverdire",
    "rinverdissero": "rinverdire",
    "rinverdissi": "rinverdire",
    "rinverdissimo": "rinverdire",
    "rinverdiste": "rinverdire",
    "rinverdisti": "rinverdire",
    "rinverdita": "rinverdire",
    "rinverdite": "rinverdire",
    "rinverditi": "rinverdire",
    "rinverdito": "rinverdire",
    "rinverdiva": "rinverdire",
    "rinverdivamo": "rinverdire",
    "rinverdivan": "rinverdire",
    "rinverdivano": "rinverdire",
    "rinverdivate": "rinverdire",
    "rinverdivi": "rinverdire",
    "rinverdivo": "rinverdire",
    "rinverdì": "rinverdire",
    "rinverrai": "rinvenire",
    "rinverran": "rinvenire",
    "rinverranno": "rinvenire",
    "rinverrebbe": "rinvenire",
    "rinverrebber": "rinvenire",
    "rinverrebbero": "rinvenire",
    "rinverrei": "rinvenire",
    "rinverremmo": "rinvenire",
    "rinverremo": "rinvenire",
    "rinverreste": "rinvenire",
    "rinverresti": "rinvenire",
    "rinverrete": "rinvenire",
    "rinverrà": "rinvenire",
    "rinverrò": "rinvenire",
    "rinvesta": "rinvestire",
    "rinvestan": "rinvestire",
    "rinvestano": "rinvestire",
    "rinveste": "rinvestire",
    "rinvestendo": "rinvestire",
    "rinvestente": "rinvestire",
    "rinvestenti": "rinvestire",
    "rinvesti": "rinvestire",
    "rinvestiamo": "rinvestire",
    "rinvestiate": "rinvestire",
    "rinvestii": "rinvestire",
    "rinvestimmo": "rinvestire",
    "rinvestir": "rinvestire",
    "rinvestirai": "rinvestire",
    "rinvestiran": "rinvestire",
    "rinvestiranno": "rinvestire",
    "rinvestirebbe": "rinvestire",
    "rinvestirebber": "rinvestire",
    "rinvestirebbero": "rinvestire",
    "rinvestirei": "rinvestire",
    "rinvestiremmo": "rinvestire",
    "rinvestiremo": "rinvestire",
    "rinvestireste": "rinvestire",
    "rinvestiresti": "rinvestire",
    "rinvestirete": "rinvestire",
    "rinvestiron": "rinvestire",
    "rinvestirono": "rinvestire",
    "rinvestirà": "rinvestire",
    "rinvestirò": "rinvestire",
    "rinvestisse": "rinvestire",
    "rinvestisser": "rinvestire",
    "rinvestissero": "rinvestire",
    "rinvestissi": "rinvestire",
    "rinvestissimo": "rinvestire",
    "rinvestiste": "rinvestire",
    "rinvestisti": "rinvestire",
    "rinvestita": "rinvestire",
    "rinvestite": "rinvestire",
    "rinvestiti": "rinvestire",
    "rinvestito": "rinvestire",
    "rinvestiva": "rinvestire",
    "rinvestivamo": "rinvestire",
    "rinvestivan": "rinvestire",
    "rinvestivano": "rinvestire",
    "rinvestivate": "rinvestire",
    "rinvestivi": "rinvestire",
    "rinvestivo": "rinvestire",
    "rinvesto": "rinvestire",
    "rinveston": "rinvestire",
    "rinvestono": "rinvestire",
    "rinvestì": "rinvestire",
    "rinvia": "rinviare",
    "rinviai": "rinviare",
    "rinviammo": "rinviare",
    "rinviamo": "rinviare",
    "rinvian": "rinviare",
    "rinviando": "rinviare",
    "rinviano": "rinviare",
    "rinviante": "rinviare",
    "rinvianti": "rinviare",
    "rinviar": "rinviare",
    "rinviaron": "rinviare",
    "rinviarono": "rinviare",
    "rinviasse": "rinviare",
    "rinviasser": "rinviare",
    "rinviassero": "rinviare",
    "rinviassi": "rinviare",
    "rinviassimo": "rinviare",
    "rinviaste": "rinviare",
    "rinviasti": "rinviare",
    "rinviata": "rinviare",
    "rinviate": "rinviare",
    "rinviati": "rinviare",
    "rinviato": "rinviare",
    "rinviava": "rinviare",
    "rinviavamo": "rinviare",
    "rinviavan": "rinviare",
    "rinviavano": "rinviare",
    "rinviavate": "rinviare",
    "rinviavi": "rinviare",
    "rinviavo": "rinviare",
    "rinviene": "rinvenire",
    "rinvieni": "rinvenire",
    "rinvierai": "rinviare",
    "rinvieran": "rinviare",
    "rinvieranno": "rinviare",
    "rinvierebbe": "rinviare",
    "rinvierebber": "rinviare",
    "rinvierebbero": "rinviare",
    "rinvierei": "rinviare",
    "rinvieremmo": "rinviare",
    "rinvieremo": "rinviare",
    "rinviereste": "rinviare",
    "rinvieresti": "rinviare",
    "rinvierete": "rinviare",
    "rinvierà": "rinviare",
    "rinvierò": "rinviare",
    "rinvigorendo": "rinvigorire",
    "rinvigorente": "rinvigorire",
    "rinvigorenti": "rinvigorire",
    "rinvigoriamo": "rinvigorire",
    "rinvigoriate": "rinvigorire",
    "rinvigorii": "rinvigorire",
    "rinvigorimmo": "rinvigorire",
    "rinvigorir": "rinvigorire",
    "rinvigorirai": "rinvigorire",
    "rinvigoriran": "rinvigorire",
    "rinvigoriranno": "rinvigorire",
    "rinvigorirebbe": "rinvigorire",
    "rinvigorirebber": "rinvigorire",
    "rinvigorirebbero": "rinvigorire",
    "rinvigorirei": "rinvigorire",
    "rinvigoriremmo": "rinvigorire",
    "rinvigoriremo": "rinvigorire",
    "rinvigorireste": "rinvigorire",
    "rinvigoriresti": "rinvigorire",
    "rinvigorirete": "rinvigorire",
    "rinvigoriron": "rinvigorire",
    "rinvigorirono": "rinvigorire",
    "rinvigorirà": "rinvigorire",
    "rinvigorirò": "rinvigorire",
    "rinvigorisca": "rinvigorire",
    "rinvigoriscan": "rinvigorire",
    "rinvigoriscano": "rinvigorire",
    "rinvigorisce": "rinvigorire",
    "rinvigorisci": "rinvigorire",
    "rinvigorisco": "rinvigorire",
    "rinvigoriscon": "rinvigorire",
    "rinvigoriscono": "rinvigorire",
    "rinvigorisse": "rinvigorire",
    "rinvigorisser": "rinvigorire",
    "rinvigorissero": "rinvigorire",
    "rinvigorissi": "rinvigorire",
    "rinvigorissimo": "rinvigorire",
    "rinvigoriste": "rinvigorire",
    "rinvigoristi": "rinvigorire",
    "rinvigorita": "rinvigorire",
    "rinvigorite": "rinvigorire",
    "rinvigoriti": "rinvigorire",
    "rinvigorito": "rinvigorire",
    "rinvigoriva": "rinvigorire",
    "rinvigorivamo": "rinvigorire",
    "rinvigorivan": "rinvigorire",
    "rinvigorivano": "rinvigorire",
    "rinvigorivate": "rinvigorire",
    "rinvigorivi": "rinvigorire",
    "rinvigorivo": "rinvigorire",
    "rinvigorì": "rinvigorire",
    "rinvii": "rinvio",
    "rinviin": "rinviare",
    "rinviino": "rinviare",
    "rinvila": "rinvilire",
    "rinvilan": "rinvilire",
    "rinvilano": "rinvilire",
    "rinvile": "rinvilire",
    "rinvilendo": "rinvilire",
    "rinvilente": "rinvilire",
    "rinvilenti": "rinvilire",
    "rinvili": "rinvilire",
    "rinviliamo": "rinvilire",
    "rinviliate": "rinvilire",
    "rinvilii": "rinvilire",
    "rinvilimmo": "rinvilire",
    "rinvilir": "rinvilire",
    "rinvilirai": "rinvilire",
    "rinviliran": "rinvilire",
    "rinviliranno": "rinvilire",
    "rinvilirebbe": "rinvilire",
    "rinvilirebber": "rinvilire",
    "rinvilirebbero": "rinvilire",
    "rinvilirei": "rinvilire",
    "rinviliremmo": "rinvilire",
    "rinviliremo": "rinvilire",
    "rinvilireste": "rinvilire",
    "rinviliresti": "rinvilire",
    "rinvilirete": "rinvilire",
    "rinviliron": "rinvilire",
    "rinvilirono": "rinvilire",
    "rinvilirà": "rinvilire",
    "rinvilirò": "rinvilire",
    "rinvilisse": "rinvilire",
    "rinvilisser": "rinvilire",
    "rinvilissero": "rinvilire",
    "rinvilissi": "rinvilire",
    "rinvilissimo": "rinvilire",
    "rinviliste": "rinvilire",
    "rinvilisti": "rinvilire",
    "rinvilita": "rinvilire",
    "rinvilite": "rinvilire",
    "rinviliti": "rinvilire",
    "rinvilito": "rinvilire",
    "rinviliva": "rinvilire",
    "rinvilivamo": "rinvilire",
    "rinvilivan": "rinvilire",
    "rinvilivano": "rinvilire",
    "rinvilivate": "rinvilire",
    "rinvilivi": "rinvilire",
    "rinvilivo": "rinvilire",
    "rinvilo": "rinvilire",
    "rinvilon": "rinvilire",
    "rinvilono": "rinvilire",
    "rinvilì": "rinvilire",
    "rinvio": "rinviare",
    "rinviò": "rinviare",
    "rinvolga": "rinvolgere",
    "rinvolgan": "rinvolgere",
    "rinvolgano": "rinvolgere",
    "rinvolge": "rinvolgere",
    "rinvolgei": "rinvolgere",
    "rinvolgemmo": "rinvolgere",
    "rinvolgendo": "rinvolgere",
    "rinvolgente": "rinvolgere",
    "rinvolgenti": "rinvolgere",
    "rinvolger": "rinvolgere",
    "rinvolgerai": "rinvolgere",
    "rinvolgeran": "rinvolgere",
    "rinvolgeranno": "rinvolgere",
    "rinvolgerebbe": "rinvolgere",
    "rinvolgerebber": "rinvolgere",
    "rinvolgerebbero": "rinvolgere",
    "rinvolgerei": "rinvolgere",
    "rinvolgeremmo": "rinvolgere",
    "rinvolgeremo": "rinvolgere",
    "rinvolgereste": "rinvolgere",
    "rinvolgeresti": "rinvolgere",
    "rinvolgerete": "rinvolgere",
    "rinvolgeron": "rinvolgere",
    "rinvolgerono": "rinvolgere",
    "rinvolgerà": "rinvolgere",
    "rinvolgerò": "rinvolgere",
    "rinvolgesse": "rinvolgere",
    "rinvolgesser": "rinvolgere",
    "rinvolgessero": "rinvolgere",
    "rinvolgessi": "rinvolgere",
    "rinvolgessimo": "rinvolgere",
    "rinvolgeste": "rinvolgere",
    "rinvolgesti": "rinvolgere",
    "rinvolgete": "rinvolgere",
    "rinvolgeva": "rinvolgere",
    "rinvolgevamo": "rinvolgere",
    "rinvolgevan": "rinvolgere",
    "rinvolgevano": "rinvolgere",
    "rinvolgevate": "rinvolgere",
    "rinvolgevi": "rinvolgere",
    "rinvolgevo": "rinvolgere",
    "rinvolgi": "rinvolgere",
    "rinvolgiamo": "rinvolgere",
    "rinvolgiate": "rinvolgere",
    "rinvolgo": "rinvolgere",
    "rinvolgon": "rinvolgere",
    "rinvolgono": "rinvolgere",
    "rinvolgè": "rinvolgere",
    "rinvolta": "rinvoltare",
    "rinvoltai": "rinvoltare",
    "rinvoltammo": "rinvoltare",
    "rinvoltan": "rinvoltare",
    "rinvoltando": "rinvoltare",
    "rinvoltano": "rinvoltare",
    "rinvoltante": "rinvoltare",
    "rinvoltanti": "rinvoltare",
    "rinvoltar": "rinvoltare",
    "rinvoltaron": "rinvoltare",
    "rinvoltarono": "rinvoltare",
    "rinvoltasse": "rinvoltare",
    "rinvoltasser": "rinvoltare",
    "rinvoltassero": "rinvoltare",
    "rinvoltassi": "rinvoltare",
    "rinvoltassimo": "rinvoltare",
    "rinvoltaste": "rinvoltare",
    "rinvoltasti": "rinvoltare",
    "rinvoltata": "rinvoltare",
    "rinvoltate": "rinvoltare",
    "rinvoltati": "rinvoltare",
    "rinvoltato": "rinvoltare",
    "rinvoltava": "rinvoltare",
    "rinvoltavamo": "rinvoltare",
    "rinvoltavan": "rinvoltare",
    "rinvoltavano": "rinvoltare",
    "rinvoltavate": "rinvoltare",
    "rinvoltavi": "rinvoltare",
    "rinvoltavo": "rinvoltare",
    "rinvolte": "rinvolgere",
    "rinvolterai": "rinvoltare",
    "rinvolteran": "rinvoltare",
    "rinvolteranno": "rinvoltare",
    "rinvolterebbe": "rinvoltare",
    "rinvolterebber": "rinvoltare",
    "rinvolterebbero": "rinvoltare",
    "rinvolterei": "rinvoltare",
    "rinvolteremmo": "rinvoltare",
    "rinvolteremo": "rinvoltare",
    "rinvoltereste": "rinvoltare",
    "rinvolteresti": "rinvoltare",
    "rinvolterete": "rinvoltare",
    "rinvolterà": "rinvoltare",
    "rinvolterò": "rinvoltare",
    "rinvolti": "rinvoltare",
    "rinvoltiamo": "rinvoltare",
    "rinvoltiate": "rinvoltare",
    "rinvoltin": "rinvoltare",
    "rinvoltino": "rinvoltare",
    "rinvolto": "rinvoltare",
    "rinvoltò": "rinvoltare",
    "rinzaffa": "rinzaffare",
    "rinzaffai": "rinzaffare",
    "rinzaffammo": "rinzaffare",
    "rinzaffan": "rinzaffare",
    "rinzaffando": "rinzaffare",
    "rinzaffano": "rinzaffare",
    "rinzaffante": "rinzaffare",
    "rinzaffanti": "rinzaffare",
    "rinzaffar": "rinzaffare",
    "rinzaffaron": "rinzaffare",
    "rinzaffarono": "rinzaffare",
    "rinzaffasse": "rinzaffare",
    "rinzaffasser": "rinzaffare",
    "rinzaffassero": "rinzaffare",
    "rinzaffassi": "rinzaffare",
    "rinzaffassimo": "rinzaffare",
    "rinzaffaste": "rinzaffare",
    "rinzaffasti": "rinzaffare",
    "rinzaffata": "rinzaffare",
    "rinzaffate": "rinzaffare",
    "rinzaffati": "rinzaffare",
    "rinzaffato": "rinzaffare",
    "rinzaffava": "rinzaffare",
    "rinzaffavamo": "rinzaffare",
    "rinzaffavan": "rinzaffare",
    "rinzaffavano": "rinzaffare",
    "rinzaffavate": "rinzaffare",
    "rinzaffavi": "rinzaffare",
    "rinzaffavo": "rinzaffare",
    "rinzafferai": "rinzaffare",
    "rinzafferan": "rinzaffare",
    "rinzafferanno": "rinzaffare",
    "rinzafferebbe": "rinzaffare",
    "rinzafferebber": "rinzaffare",
    "rinzafferebbero": "rinzaffare",
    "rinzafferei": "rinzaffare",
    "rinzafferemmo": "rinzaffare",
    "rinzafferemo": "rinzaffare",
    "rinzaffereste": "rinzaffare",
    "rinzafferesti": "rinzaffare",
    "rinzafferete": "rinzaffare",
    "rinzafferà": "rinzaffare",
    "rinzafferò": "rinzaffare",
    "rinzaffi": "rinzaffare",
    "rinzaffiamo": "rinzaffare",
    "rinzaffiate": "rinzaffare",
    "rinzaffin": "rinzaffare",
    "rinzaffino": "rinzaffare",
    "rinzaffo": "rinzaffare",
    "rinzaffò": "rinzaffare",
    "rioccupa": "rioccupare",
    "rioccupai": "rioccupare",
    "rioccupammo": "rioccupare",
    "rioccupan": "rioccupare",
    "rioccupando": "rioccupare",
    "rioccupano": "rioccupare",
    "rioccupante": "rioccupare",
    "rioccupanti": "rioccupare",
    "rioccupar": "rioccupare",
    "rioccuparon": "rioccupare",
    "rioccuparono": "rioccupare",
    "rioccupasse": "rioccupare",
    "rioccupasser": "rioccupare",
    "rioccupassero": "rioccupare",
    "rioccupassi": "rioccupare",
    "rioccupassimo": "rioccupare",
    "rioccupaste": "rioccupare",
    "rioccupasti": "rioccupare",
    "rioccupata": "rioccupare",
    "rioccupate": "rioccupare",
    "rioccupati": "rioccupare",
    "rioccupato": "rioccupare",
    "rioccupava": "rioccupare",
    "rioccupavamo": "rioccupare",
    "rioccupavan": "rioccupare",
    "rioccupavano": "rioccupare",
    "rioccupavate": "rioccupare",
    "rioccupavi": "rioccupare",
    "rioccupavo": "rioccupare",
    "rioccuperai": "rioccupare",
    "rioccuperan": "rioccupare",
    "rioccuperanno": "rioccupare",
    "rioccuperebbe": "rioccupare",
    "rioccuperebber": "rioccupare",
    "rioccuperebbero": "rioccupare",
    "rioccuperei": "rioccupare",
    "rioccuperemmo": "rioccupare",
    "rioccuperemo": "rioccupare",
    "rioccupereste": "rioccupare",
    "rioccuperesti": "rioccupare",
    "rioccuperete": "rioccupare",
    "rioccuperà": "rioccupare",
    "rioccuperò": "rioccupare",
    "rioccupi": "rioccupare",
    "rioccupiamo": "rioccupare",
    "rioccupiate": "rioccupare",
    "rioccupin": "rioccupare",
    "rioccupino": "rioccupare",
    "rioccupo": "rioccupare",
    "rioccupò": "rioccupare",
    "rionali": "rionale",
    "rioni": "rione",
    "riordina": "riordinare",
    "riordinai": "riordinare",
    "riordinamenti": "riordinamento",
    "riordinammo": "riordinare",
    "riordinan": "riordinare",
    "riordinando": "riordinare",
    "riordinano": "riordinare",
    "riordinante": "riordinare",
    "riordinanti": "riordinare",
    "riordinar": "riordinare",
    "riordinaron": "riordinare",
    "riordinarono": "riordinare",
    "riordinasse": "riordinare",
    "riordinasser": "riordinare",
    "riordinassero": "riordinare",
    "riordinassi": "riordinare",
    "riordinassimo": "riordinare",
    "riordinaste": "riordinare",
    "riordinasti": "riordinare",
    "riordinata": "riordinare",
    "riordinate": "riordinare",
    "riordinati": "riordinare",
    "riordinato": "riordinare",
    "riordinava": "riordinare",
    "riordinavamo": "riordinare",
    "riordinavan": "riordinare",
    "riordinavano": "riordinare",
    "riordinavate": "riordinare",
    "riordinavi": "riordinare",
    "riordinavo": "riordinare",
    "riordinerai": "riordinare",
    "riordineran": "riordinare",
    "riordineranno": "riordinare",
    "riordinerebbe": "riordinare",
    "riordinerebber": "riordinare",
    "riordinerebbero": "riordinare",
    "riordinerei": "riordinare",
    "riordineremmo": "riordinare",
    "riordineremo": "riordinare",
    "riordinereste": "riordinare",
    "riordineresti": "riordinare",
    "riordinerete": "riordinare",
    "riordinerà": "riordinare",
    "riordinerò": "riordinare",
    "riordini": "riordino",
    "riordiniamo": "riordinare",
    "riordiniate": "riordinare",
    "riordinin": "riordinare",
    "riordinino": "riordinare",
    "riordino": "riordinare",
    "riordinò": "riordinare",
    "riorganizza": "riorganizzare",
    "riorganizzai": "riorganizzare",
    "riorganizzammo": "riorganizzare",
    "riorganizzan": "riorganizzare",
    "riorganizzando": "riorganizzare",
    "riorganizzano": "riorganizzare",
    "riorganizzante": "riorganizzare",
    "riorganizzanti": "riorganizzare",
    "riorganizzar": "riorganizzare",
    "riorganizzaron": "riorganizzare",
    "riorganizzarono": "riorganizzare",
    "riorganizzasse": "riorganizzare",
    "riorganizzasser": "riorganizzare",
    "riorganizzassero": "riorganizzare",
    "riorganizzassi": "riorganizzare",
    "riorganizzassimo": "riorganizzare",
    "riorganizzaste": "riorganizzare",
    "riorganizzasti": "riorganizzare",
    "riorganizzata": "riorganizzare",
    "riorganizzate": "riorganizzare",
    "riorganizzati": "riorganizzare",
    "riorganizzato": "riorganizzare",
    "riorganizzava": "riorganizzare",
    "riorganizzavamo": "riorganizzare",
    "riorganizzavan": "riorganizzare",
    "riorganizzavano": "riorganizzare",
    "riorganizzavate": "riorganizzare",
    "riorganizzavi": "riorganizzare",
    "riorganizzavo": "riorganizzare",
    "riorganizzazioni": "riorganizzazione",
    "riorganizzerai": "riorganizzare",
    "riorganizzeran": "riorganizzare",
    "riorganizzeranno": "riorganizzare",
    "riorganizzerebbe": "riorganizzare",
    "riorganizzerebber": "riorganizzare",
    "riorganizzerebbero": "riorganizzare",
    "riorganizzerei": "riorganizzare",
    "riorganizzeremmo": "riorganizzare",
    "riorganizzeremo": "riorganizzare",
    "riorganizzereste": "riorganizzare",
    "riorganizzeresti": "riorganizzare",
    "riorganizzerete": "riorganizzare",
    "riorganizzerà": "riorganizzare",
    "riorganizzerò": "riorganizzare",
    "riorganizzi": "riorganizzare",
    "riorganizziamo": "riorganizzare",
    "riorganizziate": "riorganizzare",
    "riorganizzin": "riorganizzare",
    "riorganizzino": "riorganizzare",
    "riorganizzo": "riorganizzare",
    "riorganizzò": "riorganizzare",
    "riorienta": "riorientare",
    "riorientai": "riorientare",
    "riorientammo": "riorientare",
    "riorientan": "riorientare",
    "riorientando": "riorientare",
    "riorientano": "riorientare",
    "riorientante": "riorientare",
    "riorientanti": "riorientare",
    "riorientar": "riorientare",
    "riorientaron": "riorientare",
    "riorientarono": "riorientare",
    "riorientasse": "riorientare",
    "riorientasser": "riorientare",
    "riorientassero": "riorientare",
    "riorientassi": "riorientare",
    "riorientassimo": "riorientare",
    "riorientaste": "riorientare",
    "riorientasti": "riorientare",
    "riorientata": "riorientare",
    "riorientate": "riorientare",
    "riorientati": "riorientare",
    "riorientato": "riorientare",
    "riorientava": "riorientare",
    "riorientavamo": "riorientare",
    "riorientavan": "riorientare",
    "riorientavano": "riorientare",
    "riorientavate": "riorientare",
    "riorientavi": "riorientare",
    "riorientavo": "riorientare",
    "riorienterai": "riorientare",
    "riorienteran": "riorientare",
    "riorienteranno": "riorientare",
    "riorienterebbe": "riorientare",
    "riorienterebber": "riorientare",
    "riorienterebbero": "riorientare",
    "riorienterei": "riorientare",
    "riorienteremmo": "riorientare",
    "riorienteremo": "riorientare",
    "riorientereste": "riorientare",
    "riorienteresti": "riorientare",
    "riorienterete": "riorientare",
    "riorienterà": "riorientare",
    "riorienterò": "riorientare",
    "riorienti": "riorientare",
    "riorientiamo": "riorientare",
    "riorientiate": "riorientare",
    "riorientin": "riorientare",
    "riorientino": "riorientare",
    "rioriento": "riorientare",
    "riorientò": "riorientare",
    "riottene": "riottenere",
    "riottenei": "riottenere",
    "riottenemmo": "riottenere",
    "riottenendo": "riottenere",
    "riottenente": "riottenere",
    "riottenenti": "riottenere",
    "riottener": "riottenere",
    "riottenerai": "riottenere",
    "riotteneran": "riottenere",
    "riotteneranno": "riottenere",
    "riottenerebbe": "riottenere",
    "riottenerebber": "riottenere",
    "riottenerebbero": "riottenere",
    "riottenerei": "riottenere",
    "riotteneremmo": "riottenere",
    "riotteneremo": "riottenere",
    "riottenereste": "riottenere",
    "riotteneresti": "riottenere",
    "riottenerete": "riottenere",
    "riotteneron": "riottenere",
    "riottenerono": "riottenere",
    "riottenerà": "riottenere",
    "riottenerò": "riottenere",
    "riottenesse": "riottenere",
    "riottenesser": "riottenere",
    "riottenessero": "riottenere",
    "riottenessi": "riottenere",
    "riottenessimo": "riottenere",
    "riotteneste": "riottenere",
    "riottenesti": "riottenere",
    "riottenete": "riottenere",
    "riotteneva": "riottenere",
    "riottenevamo": "riottenere",
    "riottenevan": "riottenere",
    "riottenevano": "riottenere",
    "riottenevate": "riottenere",
    "riottenevi": "riottenere",
    "riottenevo": "riottenere",
    "riottenga": "riottenere",
    "riottengan": "riottenere",
    "riottengano": "riottenere",
    "riottengo": "riottenere",
    "riottengon": "riottenere",
    "riottengono": "riottenere",
    "riotteni": "riottenere",
    "riotteniamo": "riottenere",
    "riotteniate": "riottenere",
    "riottenuta": "riottenere",
    "riottenute": "riottenere",
    "riottenuti": "riottenere",
    "riottenuto": "riottenere",
    "riottenè": "riottenere",
    "riottosa": "riottoso",
    "riottose": "riottoso",
    "riottosi": "riottoso",
    "ripaga": "ripagare",
    "ripagai": "ripagare",
    "ripagammo": "ripagare",
    "ripagan": "ripagare",
    "ripagando": "ripagare",
    "ripagano": "ripagare",
    "ripagante": "ripagare",
    "ripaganti": "ripagare",
    "ripagar": "ripagare",
    "ripagaron": "ripagare",
    "ripagarono": "ripagare",
    "ripagasse": "ripagare",
    "ripagasser": "ripagare",
    "ripagassero": "ripagare",
    "ripagassi": "ripagare",
    "ripagassimo": "ripagare",
    "ripagaste": "ripagare",
    "ripagasti": "ripagare",
    "ripagata": "ripagare",
    "ripagate": "ripagare",
    "ripagati": "ripagare",
    "ripagato": "ripagare",
    "ripagava": "ripagare",
    "ripagavamo": "ripagare",
    "ripagavan": "ripagare",
    "ripagavano": "ripagare",
    "ripagavate": "ripagare",
    "ripagavi": "ripagare",
    "ripagavo": "ripagare",
    "ripagherai": "ripagare",
    "ripagheran": "ripagare",
    "ripagheranno": "ripagare",
    "ripagherebbe": "ripagare",
    "ripagherebber": "ripagare",
    "ripagherebbero": "ripagare",
    "ripagherei": "ripagare",
    "ripagheremmo": "ripagare",
    "ripagheremo": "ripagare",
    "ripaghereste": "ripagare",
    "ripagheresti": "ripagare",
    "ripagherete": "ripagare",
    "ripagherà": "ripagare",
    "ripagherò": "ripagare",
    "ripaghi": "ripagare",
    "ripaghiamo": "ripagare",
    "ripaghiate": "ripagare",
    "ripaghin": "ripagare",
    "ripaghino": "ripagare",
    "ripago": "ripagare",
    "ripagò": "ripagare",
    "ripara": "riparare",
    "riparai": "riparare",
    "riparammo": "riparare",
    "riparan": "riparare",
    "riparando": "riparare",
    "riparano": "riparare",
    "riparante": "riparare",
    "riparanti": "riparare",
    "riparar": "riparare",
    "ripararon": "riparare",
    "ripararono": "riparare",
    "riparasse": "riparare",
    "riparasser": "riparare",
    "riparassero": "riparare",
    "riparassi": "riparare",
    "riparassimo": "riparare",
    "riparaste": "riparare",
    "riparasti": "riparare",
    "riparata": "riparato",
    "riparate": "riparato",
    "riparati": "riparato",
    "riparato": "riparare",
    "riparatori": "riparatore",
    "riparatrice": "riparatore",
    "riparatrici": "riparatore",
    "riparava": "riparare",
    "riparavamo": "riparare",
    "riparavan": "riparare",
    "riparavano": "riparare",
    "riparavate": "riparare",
    "riparavi": "riparare",
    "riparavo": "riparare",
    "riparazioni": "riparazione",
    "riparerai": "riparare",
    "ripareran": "riparare",
    "ripareranno": "riparare",
    "riparerebbe": "riparare",
    "riparerebber": "riparare",
    "riparerebbero": "riparare",
    "riparerei": "riparare",
    "ripareremmo": "riparare",
    "ripareremo": "riparare",
    "riparereste": "riparare",
    "ripareresti": "riparare",
    "riparerete": "riparare",
    "riparerà": "riparare",
    "riparerò": "riparare",
    "ripari": "riparo",
    "ripariamo": "riparare",
    "ripariate": "riparare",
    "riparin": "riparare",
    "riparino": "riparare",
    "riparla": "riparlare",
    "riparlai": "riparlare",
    "riparlammo": "riparlare",
    "riparlan": "riparlare",
    "riparlando": "riparlare",
    "riparlano": "riparlare",
    "riparlante": "riparlare",
    "riparlanti": "riparlare",
    "riparlar": "riparlare",
    "riparlaron": "riparlare",
    "riparlarono": "riparlare",
    "riparlasse": "riparlare",
    "riparlasser": "riparlare",
    "riparlassero": "riparlare",
    "riparlassi": "riparlare",
    "riparlassimo": "riparlare",
    "riparlaste": "riparlare",
    "riparlasti": "riparlare",
    "riparlata": "riparlare",
    "riparlate": "riparlare",
    "riparlati": "riparlare",
    "riparlato": "riparlare",
    "riparlava": "riparlare",
    "riparlavamo": "riparlare",
    "riparlavan": "riparlare",
    "riparlavano": "riparlare",
    "riparlavate": "riparlare",
    "riparlavi": "riparlare",
    "riparlavo": "riparlare",
    "riparlerai": "riparlare",
    "riparleran": "riparlare",
    "riparleranno": "riparlare",
    "riparlerebbe": "riparlare",
    "riparlerebber": "riparlare",
    "riparlerebbero": "riparlare",
    "riparlerei": "riparlare",
    "riparleremmo": "riparlare",
    "riparleremo": "riparlare",
    "riparlereste": "riparlare",
    "riparleresti": "riparlare",
    "riparlerete": "riparlare",
    "riparlerà": "riparlare",
    "riparlerò": "riparlare",
    "riparli": "riparlare",
    "riparliamo": "riparlare",
    "riparliate": "riparlare",
    "riparlin": "riparlare",
    "riparlino": "riparlare",
    "riparlo": "riparlare",
    "riparlò": "riparlare",
    "riparo": "riparare",
    "ripartendo": "ripartire",
    "ripartente": "ripartire",
    "ripartenti": "ripartire",
    "ripartenze": "ripartenza",
    "ripartiamo": "ripartire",
    "ripartiate": "ripartire",
    "ripartii": "ripartire",
    "ripartimmo": "ripartire",
    "ripartir": "ripartire",
    "ripartirai": "ripartire",
    "ripartiran": "ripartire",
    "ripartiranno": "ripartire",
    "ripartirebbe": "ripartire",
    "ripartirebber": "ripartire",
    "ripartirebbero": "ripartire",
    "ripartirei": "ripartire",
    "ripartiremmo": "ripartire",
    "ripartiremo": "ripartire",
    "ripartireste": "ripartire",
    "ripartiresti": "ripartire",
    "ripartirete": "ripartire",
    "ripartiron": "ripartire",
    "ripartirono": "ripartire",
    "ripartirà": "ripartire",
    "ripartirò": "ripartire",
    "ripartisca": "ripartire",
    "ripartiscan": "ripartire",
    "ripartiscano": "ripartire",
    "ripartisce": "ripartire",
    "ripartisci": "ripartire",
    "ripartisco": "ripartire",
    "ripartiscon": "ripartire",
    "ripartiscono": "ripartire",
    "ripartisse": "ripartire",
    "ripartisser": "ripartire",
    "ripartissero": "ripartire",
    "ripartissi": "ripartire",
    "ripartissimo": "ripartire",
    "ripartiste": "ripartire",
    "ripartisti": "ripartire",
    "ripartita": "ripartire",
    "ripartite": "ripartire",
    "ripartiti": "ripartire",
    "ripartito": "ripartire",
    "ripartiva": "ripartire",
    "ripartivamo": "ripartire",
    "ripartivan": "ripartire",
    "ripartivano": "ripartire",
    "ripartivate": "ripartire",
    "ripartivi": "ripartire",
    "ripartivo": "ripartire",
    "ripartizioni": "ripartizione",
    "ripartì": "ripartire",
    "riparò": "riparare",
    "ripassa": "ripassare",
    "ripassai": "ripassare",
    "ripassammo": "ripassare",
    "ripassan": "ripassare",
    "ripassando": "ripassare",
    "ripassano": "ripassare",
    "ripassante": "ripassare",
    "ripassanti": "ripassare",
    "ripassar": "ripassare",
    "ripassaron": "ripassare",
    "ripassarono": "ripassare",
    "ripassasse": "ripassare",
    "ripassasser": "ripassare",
    "ripassassero": "ripassare",
    "ripassassi": "ripassare",
    "ripassassimo": "ripassare",
    "ripassaste": "ripassare",
    "ripassasti": "ripassare",
    "ripassata": "ripassare",
    "ripassate": "ripassare",
    "ripassati": "ripassare",
    "ripassato": "ripassare",
    "ripassava": "ripassare",
    "ripassavamo": "ripassare",
    "ripassavan": "ripassare",
    "ripassavano": "ripassare",
    "ripassavate": "ripassare",
    "ripassavi": "ripassare",
    "ripassavo": "ripassare",
    "ripasserai": "ripassare",
    "ripasseran": "ripassare",
    "ripasseranno": "ripassare",
    "ripasserebbe": "ripassare",
    "ripasserebber": "ripassare",
    "ripasserebbero": "ripassare",
    "ripasserei": "ripassare",
    "ripasseremmo": "ripassare",
    "ripasseremo": "ripassare",
    "ripassereste": "ripassare",
    "ripasseresti": "ripassare",
    "ripasserete": "ripassare",
    "ripasserà": "ripassare",
    "ripasserò": "ripassare",
    "ripassi": "ripasso",
    "ripassiamo": "ripassare",
    "ripassiate": "ripassare",
    "ripassin": "ripassare",
    "ripassino": "ripassare",
    "ripasso": "ripassare",
    "ripassò": "ripassare",
    "ripensa": "ripensare",
    "ripensai": "ripensare",
    "ripensamenti": "ripensamento",
    "ripensammo": "ripensare",
    "ripensan": "ripensare",
    "ripensando": "ripensare",
    "ripensano": "ripensare",
    "ripensante": "ripensare",
    "ripensanti": "ripensare",
    "ripensar": "ripensare",
    "ripensaron": "ripensare",
    "ripensarono": "ripensare",
    "ripensasse": "ripensare",
    "ripensasser": "ripensare",
    "ripensassero": "ripensare",
    "ripensassi": "ripensare",
    "ripensassimo": "ripensare",
    "ripensaste": "ripensare",
    "ripensasti": "ripensare",
    "ripensata": "ripensare",
    "ripensate": "ripensare",
    "ripensati": "ripensare",
    "ripensato": "ripensare",
    "ripensava": "ripensare",
    "ripensavamo": "ripensare",
    "ripensavan": "ripensare",
    "ripensavano": "ripensare",
    "ripensavate": "ripensare",
    "ripensavi": "ripensare",
    "ripensavo": "ripensare",
    "ripenserai": "ripensare",
    "ripenseran": "ripensare",
    "ripenseranno": "ripensare",
    "ripenserebbe": "ripensare",
    "ripenserebber": "ripensare",
    "ripenserebbero": "ripensare",
    "ripenserei": "ripensare",
    "ripenseremmo": "ripensare",
    "ripenseremo": "ripensare",
    "ripensereste": "ripensare",
    "ripenseresti": "ripensare",
    "ripenserete": "ripensare",
    "ripenserà": "ripensare",
    "ripenserò": "ripensare",
    "ripensi": "ripensare",
    "ripensiamo": "ripensare",
    "ripensiate": "ripensare",
    "ripensin": "ripensare",
    "ripensino": "ripensare",
    "ripenso": "ripensare",
    "ripensò": "ripensare",
    "ripenta": "ripentire",
    "ripentan": "ripentire",
    "ripentano": "ripentire",
    "ripente": "ripentire",
    "ripentendo": "ripentire",
    "ripenti": "ripentire",
    "ripentiamo": "ripentire",
    "ripentiate": "ripentire",
    "ripentii": "ripentire",
    "ripentimmo": "ripentire",
    "ripentir": "ripentire",
    "ripentirai": "ripentire",
    "ripentiran": "ripentire",
    "ripentiranno": "ripentire",
    "ripentirebbe": "ripentire",
    "ripentirebber": "ripentire",
    "ripentirebbero": "ripentire",
    "ripentirei": "ripentire",
    "ripentiremmo": "ripentire",
    "ripentiremo": "ripentire",
    "ripentireste": "ripentire",
    "ripentiresti": "ripentire",
    "ripentirete": "ripentire",
    "ripentiron": "ripentire",
    "ripentirono": "ripentire",
    "ripentirà": "ripentire",
    "ripentirò": "ripentire",
    "ripentisse": "ripentire",
    "ripentisser": "ripentire",
    "ripentissero": "ripentire",
    "ripentissi": "ripentire",
    "ripentissimo": "ripentire",
    "ripentiste": "ripentire",
    "ripentisti": "ripentire",
    "ripentita": "ripentire",
    "ripentite": "ripentire",
    "ripentiti": "ripentire",
    "ripentito": "ripentire",
    "ripentiva": "ripentire",
    "ripentivamo": "ripentire",
    "ripentivan": "ripentire",
    "ripentivano": "ripentire",
    "ripentivate": "ripentire",
    "ripentivi": "ripentire",
    "ripentivo": "ripentire",
    "ripento": "ripentire",
    "ripenton": "ripentire",
    "ripentono": "ripentire",
    "ripentì": "ripentire",
    "ripercorra": "ripercorrere",
    "ripercorran": "ripercorrere",
    "ripercorrano": "ripercorrere",
    "ripercorre": "ripercorrere",
    "ripercorremmo": "ripercorrere",
    "ripercorrendo": "ripercorrere",
    "ripercorrente": "ripercorrere",
    "ripercorrenti": "ripercorrere",
    "ripercorrer": "ripercorrere",
    "ripercorrerai": "ripercorrere",
    "ripercorreran": "ripercorrere",
    "ripercorreranno": "ripercorrere",
    "ripercorrerebbe": "ripercorrere",
    "ripercorrerebber": "ripercorrere",
    "ripercorrerebbero": "ripercorrere",
    "ripercorrerei": "ripercorrere",
    "ripercorreremmo": "ripercorrere",
    "ripercorreremo": "ripercorrere",
    "ripercorrereste": "ripercorrere",
    "ripercorreresti": "ripercorrere",
    "ripercorrerete": "ripercorrere",
    "ripercorrerà": "ripercorrere",
    "ripercorrerò": "ripercorrere",
    "ripercorresse": "ripercorrere",
    "ripercorresser": "ripercorrere",
    "ripercorressero": "ripercorrere",
    "ripercorressi": "ripercorrere",
    "ripercorressimo": "ripercorrere",
    "ripercorreste": "ripercorrere",
    "ripercorresti": "ripercorrere",
    "ripercorrete": "ripercorrere",
    "ripercorreva": "ripercorrere",
    "ripercorrevamo": "ripercorrere",
    "ripercorrevan": "ripercorrere",
    "ripercorrevano": "ripercorrere",
    "ripercorrevate": "ripercorrere",
    "ripercorrevi": "ripercorrere",
    "ripercorrevo": "ripercorrere",
    "ripercorri": "ripercorrere",
    "ripercorriamo": "ripercorrere",
    "ripercorriate": "ripercorrere",
    "ripercorro": "ripercorrere",
    "ripercorron": "ripercorrere",
    "ripercorrono": "ripercorrere",
    "ripercorsa": "ripercorrere",
    "ripercorse": "ripercorrere",
    "ripercorser": "ripercorrere",
    "ripercorsero": "ripercorrere",
    "ripercorsi": "ripercorrere",
    "ripercorso": "ripercorrere",
    "ripercossa": "ripercuotere",
    "ripercosse": "ripercuotere",
    "ripercosser": "ripercuotere",
    "ripercossero": "ripercuotere",
    "ripercossi": "ripercuotere",
    "ripercosso": "ripercuotere",
    "ripercuota": "ripercuotere",
    "ripercuotan": "ripercuotere",
    "ripercuotano": "ripercuotere",
    "ripercuote": "ripercuotere",
    "ripercuotemmo": "ripercuotere",
    "ripercuoter": "ripercuotere",
    "ripercuoterai": "ripercuotere",
    "ripercuoteran": "ripercuotere",
    "ripercuoteranno": "ripercuotere",
    "ripercuoterebbe": "ripercuotere",
    "ripercuoterebber": "ripercuotere",
    "ripercuoterebbero": "ripercuotere",
    "ripercuoterei": "ripercuotere",
    "ripercuoteremmo": "ripercuotere",
    "ripercuoteremo": "ripercuotere",
    "ripercuotereste": "ripercuotere",
    "ripercuoteresti": "ripercuotere",
    "ripercuoterete": "ripercuotere",
    "ripercuoterà": "ripercuotere",
    "ripercuoterò": "ripercuotere",
    "ripercuotesse": "ripercuotere",
    "ripercuotessero": "ripercuotere",
    "ripercuotessi": "ripercuotere",
    "ripercuotessimo": "ripercuotere",
    "ripercuoteste": "ripercuotere",
    "ripercuotesti": "ripercuotere",
    "ripercuoteva": "ripercuotere",
    "ripercuotevamo": "ripercuotere",
    "ripercuotevano": "ripercuotere",
    "ripercuotevate": "ripercuotere",
    "ripercuotevi": "ripercuotere",
    "ripercuotevo": "ripercuotere",
    "ripercuoti": "ripercuotere",
    "ripercuotiamo": "ripercuotere",
    "ripercuotiate": "ripercuotere",
    "ripercuoto": "ripercuotere",
    "ripercuoton": "ripercuotere",
    "ripercuotono": "ripercuotere",
    "ripercussioni": "ripercussione",
    "ripesca": "ripescare",
    "ripescaggi": "ripescaggio",
    "ripescai": "ripescare",
    "ripescammo": "ripescare",
    "ripescan": "ripescare",
    "ripescando": "ripescare",
    "ripescano": "ripescare",
    "ripescante": "ripescare",
    "ripescanti": "ripescare",
    "ripescar": "ripescare",
    "ripescaron": "ripescare",
    "ripescarono": "ripescare",
    "ripescasse": "ripescare",
    "ripescasser": "ripescare",
    "ripescassero": "ripescare",
    "ripescassi": "ripescare",
    "ripescassimo": "ripescare",
    "ripescaste": "ripescare",
    "ripescasti": "ripescare",
    "ripescata": "ripescare",
    "ripescate": "ripescare",
    "ripescati": "ripescare",
    "ripescato": "ripescare",
    "ripescava": "ripescare",
    "ripescavamo": "ripescare",
    "ripescavan": "ripescare",
    "ripescavano": "ripescare",
    "ripescavate": "ripescare",
    "ripescavi": "ripescare",
    "ripescavo": "ripescare",
    "ripescherai": "ripescare",
    "ripescheran": "ripescare",
    "ripescheranno": "ripescare",
    "ripescherebbe": "ripescare",
    "ripescherebber": "ripescare",
    "ripescherebbero": "ripescare",
    "ripescherei": "ripescare",
    "ripescheremmo": "ripescare",
    "ripescheremo": "ripescare",
    "ripeschereste": "ripescare",
    "ripescheresti": "ripescare",
    "ripescherete": "ripescare",
    "ripescherà": "ripescare",
    "ripescherò": "ripescare",
    "ripeschi": "ripescare",
    "ripeschiamo": "ripescare",
    "ripeschiate": "ripescare",
    "ripeschin": "ripescare",
    "ripeschino": "ripescare",
    "ripesco": "ripescare",
    "ripescò": "ripescare",
    "ripeta": "ripetere",
    "ripetan": "ripetere",
    "ripetano": "ripetere",
    "ripete": "ripetere",
    "ripetei": "ripetere",
    "ripetemmo": "ripetere",
    "ripetendo": "ripetere",
    "ripetente": "ripetere",
    "ripetenti": "ripetere",
    "ripeter": "ripetere",
    "ripeterai": "ripetere",
    "ripeteran": "ripetere",
    "ripeteranno": "ripetere",
    "ripeterebbe": "ripetere",
    "ripeterebber": "ripetere",
    "ripeterebbero": "ripetere",
    "ripeterei": "ripetere",
    "ripeteremmo": "ripetere",
    "ripeteremo": "ripetere",
    "ripetereste": "ripetere",
    "ripeteresti": "ripetere",
    "ripeterete": "ripetere",
    "ripeteron": "ripetere",
    "ripeterono": "ripetere",
    "ripeterà": "ripetere",
    "ripeterò": "ripetere",
    "ripetesse": "ripetere",
    "ripetesser": "ripetere",
    "ripetessero": "ripetere",
    "ripetessi": "ripetere",
    "ripetessimo": "ripetere",
    "ripeteste": "ripetere",
    "ripetesti": "ripetere",
    "ripetete": "ripetere",
    "ripeteva": "ripetere",
    "ripetevamo": "ripetere",
    "ripetevan": "ripetere",
    "ripetevano": "ripetere",
    "ripetevate": "ripetere",
    "ripetevi": "ripetere",
    "ripetevo": "ripetere",
    "ripeti": "ripetere",
    "ripetiamo": "ripetere",
    "ripetiate": "ripetere",
    "ripetibili": "ripetibile",
    "ripetitiva": "ripetitivo",
    "ripetitive": "ripetitivo",
    "ripetitivi": "ripetitivo",
    "ripetitori": "ripetitore",
    "ripetitrice": "ripetitore",
    "ripetitrici": "ripetitore",
    "ripetizioni": "ripetizione",
    "ripeto": "ripetere",
    "ripeton": "ripetere",
    "ripetono": "ripetere",
    "ripetuta": "ripetuto",
    "ripetute": "ripetuto",
    "ripetuti": "ripetuto",
    "ripetuto": "ripetere",
    "ripetè": "ripetere",
    "ripianamenti": "ripianamento",
    "ripiani": "ripiano",
    "ripicche": "ripicca",
    "ripicchi": "ripicchiare",
    "ripicchia": "ripicchiare",
    "ripicchiai": "ripicchiare",
    "ripicchiammo": "ripicchiare",
    "ripicchiamo": "ripicchiare",
    "ripicchian": "ripicchiare",
    "ripicchiando": "ripicchiare",
    "ripicchiano": "ripicchiare",
    "ripicchiante": "ripicchiare",
    "ripicchianti": "ripicchiare",
    "ripicchiar": "ripicchiare",
    "ripicchiaron": "ripicchiare",
    "ripicchiarono": "ripicchiare",
    "ripicchiasse": "ripicchiare",
    "ripicchiasser": "ripicchiare",
    "ripicchiassero": "ripicchiare",
    "ripicchiassi": "ripicchiare",
    "ripicchiassimo": "ripicchiare",
    "ripicchiaste": "ripicchiare",
    "ripicchiasti": "ripicchiare",
    "ripicchiata": "ripicchiare",
    "ripicchiate": "ripicchiare",
    "ripicchiati": "ripicchiare",
    "ripicchiato": "ripicchiare",
    "ripicchiava": "ripicchiare",
    "ripicchiavamo": "ripicchiare",
    "ripicchiavan": "ripicchiare",
    "ripicchiavano": "ripicchiare",
    "ripicchiavate": "ripicchiare",
    "ripicchiavi": "ripicchiare",
    "ripicchiavo": "ripicchiare",
    "ripicchierai": "ripicchiare",
    "ripicchieran": "ripicchiare",
    "ripicchieranno": "ripicchiare",
    "ripicchierebbe": "ripicchiare",
    "ripicchierebber": "ripicchiare",
    "ripicchierebbero": "ripicchiare",
    "ripicchierei": "ripicchiare",
    "ripicchieremmo": "ripicchiare",
    "ripicchieremo": "ripicchiare",
    "ripicchiereste": "ripicchiare",
    "ripicchieresti": "ripicchiare",
    "ripicchierete": "ripicchiare",
    "ripicchierà": "ripicchiare",
    "ripicchierò": "ripicchiare",
    "ripicchin": "ripicchiare",
    "ripicchino": "ripicchiare",
    "ripicchio": "ripicchiare",
    "ripicchiò": "ripicchiare",
    "ripida": "ripido",
    "ripide": "ripido",
    "ripidi": "ripido",
    "ripiega": "ripiegare",
    "ripiegai": "ripiegare",
    "ripiegamenti": "ripiegamento",
    "ripiegammo": "ripiegare",
    "ripiegan": "ripiegare",
    "ripiegando": "ripiegare",
    "ripiegano": "ripiegare",
    "ripiegante": "ripiegare",
    "ripieganti": "ripiegare",
    "ripiegar": "ripiegare",
    "ripiegaron": "ripiegare",
    "ripiegarono": "ripiegare",
    "ripiegasse": "ripiegare",
    "ripiegasser": "ripiegare",
    "ripiegassero": "ripiegare",
    "ripiegassi": "ripiegare",
    "ripiegassimo": "ripiegare",
    "ripiegaste": "ripiegare",
    "ripiegasti": "ripiegare",
    "ripiegata": "ripiegare",
    "ripiegate": "ripiegare",
    "ripiegati": "ripiegare",
    "ripiegato": "ripiegare",
    "ripiegava": "ripiegare",
    "ripiegavamo": "ripiegare",
    "ripiegavan": "ripiegare",
    "ripiegavano": "ripiegare",
    "ripiegavate": "ripiegare",
    "ripiegavi": "ripiegare",
    "ripiegavo": "ripiegare",
    "ripiegherai": "ripiegare",
    "ripiegheran": "ripiegare",
    "ripiegheranno": "ripiegare",
    "ripiegherebbe": "ripiegare",
    "ripiegherebber": "ripiegare",
    "ripiegherebbero": "ripiegare",
    "ripiegherei": "ripiegare",
    "ripiegheremmo": "ripiegare",
    "ripiegheremo": "ripiegare",
    "ripieghereste": "ripiegare",
    "ripiegheresti": "ripiegare",
    "ripiegherete": "ripiegare",
    "ripiegherà": "ripiegare",
    "ripiegherò": "ripiegare",
    "ripieghi": "ripiegare",
    "ripieghiamo": "ripiegare",
    "ripieghiate": "ripiegare",
    "ripieghin": "ripiegare",
    "ripieghino": "ripiegare",
    "ripiego": "ripiegare",
    "ripiegò": "ripiegare",
    "ripiena": "ripieno",
    "ripiene": "ripieno",
    "ripieni": "ripieno",
    "ripigli": "ripigliare",
    "ripiglia": "ripigliare",
    "ripigliai": "ripigliare",
    "ripigliammo": "ripigliare",
    "ripigliamo": "ripigliare",
    "ripiglian": "ripigliare",
    "ripigliando": "ripigliare",
    "ripigliano": "ripigliare",
    "ripigliante": "ripigliare",
    "ripiglianti": "ripigliare",
    "ripigliar": "ripigliare",
    "ripigliaron": "ripigliare",
    "ripigliarono": "ripigliare",
    "ripigliasse": "ripigliare",
    "ripigliasser": "ripigliare",
    "ripigliassero": "ripigliare",
    "ripigliassi": "ripigliare",
    "ripigliassimo": "ripigliare",
    "ripigliaste": "ripigliare",
    "ripigliasti": "ripigliare",
    "ripigliata": "ripigliare",
    "ripigliate": "ripigliare",
    "ripigliati": "ripigliare",
    "ripigliato": "ripigliare",
    "ripigliava": "ripigliare",
    "ripigliavamo": "ripigliare",
    "ripigliavan": "ripigliare",
    "ripigliavano": "ripigliare",
    "ripigliavate": "ripigliare",
    "ripigliavi": "ripigliare",
    "ripigliavo": "ripigliare",
    "ripiglierai": "ripigliare",
    "ripiglieran": "ripigliare",
    "ripiglieranno": "ripigliare",
    "ripiglierebbe": "ripigliare",
    "ripiglierebber": "ripigliare",
    "ripiglierebbero": "ripigliare",
    "ripiglierei": "ripigliare",
    "ripiglieremmo": "ripigliare",
    "ripiglieremo": "ripigliare",
    "ripigliereste": "ripigliare",
    "ripiglieresti": "ripigliare",
    "ripiglierete": "ripigliare",
    "ripiglierà": "ripigliare",
    "ripiglierò": "ripigliare",
    "ripiglin": "ripigliare",
    "ripiglino": "ripigliare",
    "ripiglio": "ripigliare",
    "ripigliò": "ripigliare",
    "ripiomba": "ripiombare",
    "ripiombai": "ripiombare",
    "ripiombammo": "ripiombare",
    "ripiomban": "ripiombare",
    "ripiombando": "ripiombare",
    "ripiombano": "ripiombare",
    "ripiombante": "ripiombare",
    "ripiombanti": "ripiombare",
    "ripiombar": "ripiombare",
    "ripiombaron": "ripiombare",
    "ripiombarono": "ripiombare",
    "ripiombasse": "ripiombare",
    "ripiombasser": "ripiombare",
    "ripiombassero": "ripiombare",
    "ripiombassi": "ripiombare",
    "ripiombassimo": "ripiombare",
    "ripiombaste": "ripiombare",
    "ripiombasti": "ripiombare",
    "ripiombata": "ripiombare",
    "ripiombate": "ripiombare",
    "ripiombati": "ripiombare",
    "ripiombato": "ripiombare",
    "ripiombava": "ripiombare",
    "ripiombavamo": "ripiombare",
    "ripiombavan": "ripiombare",
    "ripiombavano": "ripiombare",
    "ripiombavate": "ripiombare",
    "ripiombavi": "ripiombare",
    "ripiombavo": "ripiombare",
    "ripiomberai": "ripiombare",
    "ripiomberan": "ripiombare",
    "ripiomberanno": "ripiombare",
    "ripiomberebbe": "ripiombare",
    "ripiomberebber": "ripiombare",
    "ripiomberebbero": "ripiombare",
    "ripiomberei": "ripiombare",
    "ripiomberemmo": "ripiombare",
    "ripiomberemo": "ripiombare",
    "ripiombereste": "ripiombare",
    "ripiomberesti": "ripiombare",
    "ripiomberete": "ripiombare",
    "ripiomberà": "ripiombare",
    "ripiomberò": "ripiombare",
    "ripiombi": "ripiombare",
    "ripiombiamo": "ripiombare",
    "ripiombiate": "ripiombare",
    "ripiombin": "ripiombare",
    "ripiombino": "ripiombare",
    "ripiombo": "ripiombare",
    "ripiombò": "ripiombare",
    "ripiova": "ripiovere",
    "ripiovan": "ripiovere",
    "ripiovano": "ripiovere",
    "ripiove": "ripiovere",
    "ripiovei": "ripiovere",
    "ripiovemmo": "ripiovere",
    "ripiovendo": "ripiovere",
    "ripiovente": "ripiovere",
    "ripioventi": "ripiovere",
    "ripiover": "ripiovere",
    "ripioverai": "ripiovere",
    "ripioveran": "ripiovere",
    "ripioveranno": "ripiovere",
    "ripioverebbe": "ripiovere",
    "ripioverebber": "ripiovere",
    "ripioverebbero": "ripiovere",
    "ripioverei": "ripiovere",
    "ripioveremmo": "ripiovere",
    "ripioveremo": "ripiovere",
    "ripiovereste": "ripiovere",
    "ripioveresti": "ripiovere",
    "ripioverete": "ripiovere",
    "ripioveron": "ripiovere",
    "ripioverono": "ripiovere",
    "ripioverà": "ripiovere",
    "ripioverò": "ripiovere",
    "ripiovesse": "ripiovere",
    "ripiovesser": "ripiovere",
    "ripiovessero": "ripiovere",
    "ripiovessi": "ripiovere",
    "ripiovessimo": "ripiovere",
    "ripioveste": "ripiovere",
    "ripiovesti": "ripiovere",
    "ripiovete": "ripiovere",
    "ripioveva": "ripiovere",
    "ripiovevamo": "ripiovere",
    "ripiovevan": "ripiovere",
    "ripiovevano": "ripiovere",
    "ripiovevate": "ripiovere",
    "ripiovevi": "ripiovere",
    "ripiovevo": "ripiovere",
    "ripiovi": "ripiovere",
    "ripioviamo": "ripiovere",
    "ripioviate": "ripiovere",
    "ripiovo": "ripiovere",
    "ripiovon": "ripiovere",
    "ripiovono": "ripiovere",
    "ripiovuta": "ripiovere",
    "ripiovute": "ripiovere",
    "ripiovuti": "ripiovere",
    "ripiovuto": "ripiovere",
    "ripiovè": "ripiovere",
    "ripone": "riporre",
    "riponemmo": "riporre",
    "riponendo": "riporre",
    "riponente": "riporre",
    "riponenti": "riporre",
    "riponesse": "riporre",
    "riponesser": "riporre",
    "riponessero": "riporre",
    "riponessi": "riporre",
    "riponessimo": "riporre",
    "riponeste": "riporre",
    "riponesti": "riporre",
    "riponete": "riporre",
    "riponeva": "riporre",
    "riponevamo": "riporre",
    "riponevan": "riporre",
    "riponevano": "riporre",
    "riponevate": "riporre",
    "riponevi": "riporre",
    "riponevo": "riporre",
    "riponga": "riporre",
    "ripongan": "riporre",
    "ripongano": "riporre",
    "ripongo": "riporre",
    "ripongon": "riporre",
    "ripongono": "riporre",
    "riponi": "riporre",
    "riponiamo": "riporre",
    "riponiate": "riporre",
    "ripopola": "ripopolare",
    "ripopolai": "ripopolare",
    "ripopolamenti": "ripopolamento",
    "ripopolammo": "ripopolare",
    "ripopolan": "ripopolare",
    "ripopolando": "ripopolare",
    "ripopolano": "ripopolare",
    "ripopolante": "ripopolare",
    "ripopolanti": "ripopolare",
    "ripopolar": "ripopolare",
    "ripopolaron": "ripopolare",
    "ripopolarono": "ripopolare",
    "ripopolasse": "ripopolare",
    "ripopolasser": "ripopolare",
    "ripopolassero": "ripopolare",
    "ripopolassi": "ripopolare",
    "ripopolassimo": "ripopolare",
    "ripopolaste": "ripopolare",
    "ripopolasti": "ripopolare",
    "ripopolata": "ripopolare",
    "ripopolate": "ripopolare",
    "ripopolati": "ripopolare",
    "ripopolato": "ripopolare",
    "ripopolava": "ripopolare",
    "ripopolavamo": "ripopolare",
    "ripopolavan": "ripopolare",
    "ripopolavano": "ripopolare",
    "ripopolavate": "ripopolare",
    "ripopolavi": "ripopolare",
    "ripopolavo": "ripopolare",
    "ripopolerai": "ripopolare",
    "ripopoleran": "ripopolare",
    "ripopoleranno": "ripopolare",
    "ripopolerebbe": "ripopolare",
    "ripopolerebber": "ripopolare",
    "ripopolerebbero": "ripopolare",
    "ripopolerei": "ripopolare",
    "ripopoleremmo": "ripopolare",
    "ripopoleremo": "ripopolare",
    "ripopolereste": "ripopolare",
    "ripopoleresti": "ripopolare",
    "ripopolerete": "ripopolare",
    "ripopolerà": "ripopolare",
    "ripopolerò": "ripopolare",
    "ripopoli": "ripopolare",
    "ripopoliamo": "ripopolare",
    "ripopoliate": "ripopolare",
    "ripopolin": "ripopolare",
    "ripopolino": "ripopolare",
    "ripopolo": "ripopolare",
    "ripopolò": "ripopolare",
    "riporr": "riporre",
    "riporrai": "riporre",
    "riporran": "riporre",
    "riporranno": "riporre",
    "riporrebbe": "riporre",
    "riporrebber": "riporre",
    "riporrebbero": "riporre",
    "riporrei": "riporre",
    "riporremmo": "riporre",
    "riporremo": "riporre",
    "riporreste": "riporre",
    "riporresti": "riporre",
    "riporrete": "riporre",
    "riporrà": "riporre",
    "riporrò": "riporre",
    "riporta": "riportare",
    "riportai": "riportare",
    "riportammo": "riportare",
    "riportan": "riportare",
    "riportando": "riportare",
    "riportano": "riportare",
    "riportante": "riportare",
    "riportanti": "riportare",
    "riportar": "riportare",
    "riportaron": "riportare",
    "riportarono": "riportare",
    "riportasse": "riportare",
    "riportasser": "riportare",
    "riportassero": "riportare",
    "riportassi": "riportare",
    "riportassimo": "riportare",
    "riportaste": "riportare",
    "riportasti": "riportare",
    "riportata": "riportare",
    "riportate": "riportare",
    "riportati": "riportare",
    "riportato": "riportare",
    "riportava": "riportare",
    "riportavamo": "riportare",
    "riportavan": "riportare",
    "riportavano": "riportare",
    "riportavate": "riportare",
    "riportavi": "riportare",
    "riportavo": "riportare",
    "riporterai": "riportare",
    "riporteran": "riportare",
    "riporteranno": "riportare",
    "riporterebbe": "riportare",
    "riporterebber": "riportare",
    "riporterebbero": "riportare",
    "riporterei": "riportare",
    "riporteremmo": "riportare",
    "riporteremo": "riportare",
    "riportereste": "riportare",
    "riporteresti": "riportare",
    "riporterete": "riportare",
    "riporterà": "riportare",
    "riporterò": "riportare",
    "riporti": "riporto",
    "riportiamo": "riportare",
    "riportiate": "riportare",
    "riportin": "riportare",
    "riportino": "riportare",
    "riporto": "riportare",
    "riportò": "riportare",
    "riposa": "riposare",
    "riposai": "riposare",
    "riposammo": "riposare",
    "riposan": "riposare",
    "riposando": "riposare",
    "riposano": "riposare",
    "riposante": "riposare",
    "riposanti": "riposare",
    "riposar": "riposare",
    "riposaron": "riposare",
    "riposarono": "riposare",
    "riposasse": "riposare",
    "riposasser": "riposare",
    "riposassero": "riposare",
    "riposassi": "riposare",
    "riposassimo": "riposare",
    "riposaste": "riposare",
    "riposasti": "riposare",
    "riposata": "riposato",
    "riposate": "riposato",
    "riposati": "riposato",
    "riposato": "riposare",
    "riposava": "riposare",
    "riposavamo": "riposare",
    "riposavan": "riposare",
    "riposavano": "riposare",
    "riposavate": "riposare",
    "riposavi": "riposare",
    "riposavo": "riposare",
    "ripose": "riporre",
    "riposer": "riporre",
    "riposerai": "riposare",
    "riposeran": "riposare",
    "riposeranno": "riposare",
    "riposerebbe": "riposare",
    "riposerebber": "riposare",
    "riposerebbero": "riposare",
    "riposerei": "riposare",
    "riposeremmo": "riposare",
    "riposeremo": "riposare",
    "riposereste": "riposare",
    "riposeresti": "riposare",
    "riposerete": "riposare",
    "riposero": "riporre",
    "riposerà": "riposare",
    "riposerò": "riposare",
    "riposi": "riposo",
    "riposiamo": "riposare",
    "riposiate": "riposare",
    "riposin": "riposare",
    "riposini": "riposino",
    "riposino": "riposare",
    "riposizionamenti": "riposizionamento",
    "riposo": "riposare",
    "riposta": "riposto",
    "riposte": "riposto",
    "riposti": "riposto",
    "ripostigli": "ripostiglio",
    "riposto": "riporre",
    "riposò": "riposare",
    "riprenda": "riprendere",
    "riprendan": "riprendere",
    "riprendano": "riprendere",
    "riprende": "riprendere",
    "riprendemmo": "riprendere",
    "riprendendo": "riprendere",
    "riprendente": "riprendere",
    "riprendenti": "riprendere",
    "riprender": "riprendere",
    "riprenderai": "riprendere",
    "riprenderan": "riprendere",
    "riprenderanno": "riprendere",
    "riprenderebbe": "riprendere",
    "riprenderebber": "riprendere",
    "riprenderebbero": "riprendere",
    "riprenderei": "riprendere",
    "riprenderemmo": "riprendere",
    "riprenderemo": "riprendere",
    "riprendereste": "riprendere",
    "riprenderesti": "riprendere",
    "riprenderete": "riprendere",
    "riprenderà": "riprendere",
    "riprenderò": "riprendere",
    "riprendesse": "riprendere",
    "riprendesser": "riprendere",
    "riprendessero": "riprendere",
    "riprendessi": "riprendere",
    "riprendessimo": "riprendere",
    "riprendeste": "riprendere",
    "riprendesti": "riprendere",
    "riprendete": "riprendere",
    "riprendeva": "riprendere",
    "riprendevamo": "riprendere",
    "riprendevan": "riprendere",
    "riprendevano": "riprendere",
    "riprendevate": "riprendere",
    "riprendevi": "riprendere",
    "riprendevo": "riprendere",
    "riprendi": "riprendere",
    "riprendiamo": "riprendere",
    "riprendiate": "riprendere",
    "riprendo": "riprendere",
    "riprendon": "riprendere",
    "riprendono": "riprendere",
    "ripresa": "riprendere",
    "riprese": "ripresa",
    "ripresenta": "ripresentare",
    "ripresentai": "ripresentare",
    "ripresentammo": "ripresentare",
    "ripresentan": "ripresentare",
    "ripresentando": "ripresentare",
    "ripresentano": "ripresentare",
    "ripresentante": "ripresentare",
    "ripresentanti": "ripresentare",
    "ripresentar": "ripresentare",
    "ripresentaron": "ripresentare",
    "ripresentarono": "ripresentare",
    "ripresentasse": "ripresentare",
    "ripresentasser": "ripresentare",
    "ripresentassero": "ripresentare",
    "ripresentassi": "ripresentare",
    "ripresentassimo": "ripresentare",
    "ripresentaste": "ripresentare",
    "ripresentasti": "ripresentare",
    "ripresentata": "ripresentare",
    "ripresentate": "ripresentare",
    "ripresentati": "ripresentare",
    "ripresentato": "ripresentare",
    "ripresentava": "ripresentare",
    "ripresentavamo": "ripresentare",
    "ripresentavan": "ripresentare",
    "ripresentavano": "ripresentare",
    "ripresentavate": "ripresentare",
    "ripresentavi": "ripresentare",
    "ripresentavo": "ripresentare",
    "ripresentazioni": "ripresentazione",
    "ripresenterai": "ripresentare",
    "ripresenteran": "ripresentare",
    "ripresenteranno": "ripresentare",
    "ripresenterebbe": "ripresentare",
    "ripresenterebber": "ripresentare",
    "ripresenterebbero": "ripresentare",
    "ripresenterei": "ripresentare",
    "ripresenteremmo": "ripresentare",
    "ripresenteremo": "ripresentare",
    "ripresentereste": "ripresentare",
    "ripresenteresti": "ripresentare",
    "ripresenterete": "ripresentare",
    "ripresenterà": "ripresentare",
    "ripresenterò": "ripresentare",
    "ripresenti": "ripresentare",
    "ripresentiamo": "ripresentare",
    "ripresentiate": "ripresentare",
    "ripresentin": "ripresentare",
    "ripresentino": "ripresentare",
    "ripresento": "ripresentare",
    "ripresentò": "ripresentare",
    "ripreser": "riprendere",
    "ripresero": "riprendere",
    "ripresi": "riprendere",
    "ripresine": "ripresina",
    "ripreso": "riprendere",
    "ripresè": "riprendere",
    "ripristina": "ripristinare",
    "ripristinai": "ripristinare",
    "ripristinammo": "ripristinare",
    "ripristinan": "ripristinare",
    "ripristinando": "ripristinare",
    "ripristinano": "ripristinare",
    "ripristinante": "ripristinare",
    "ripristinanti": "ripristinare",
    "ripristinar": "ripristinare",
    "ripristinaron": "ripristinare",
    "ripristinarono": "ripristinare",
    "ripristinasse": "ripristinare",
    "ripristinasser": "ripristinare",
    "ripristinassero": "ripristinare",
    "ripristinassi": "ripristinare",
    "ripristinassimo": "ripristinare",
    "ripristinaste": "ripristinare",
    "ripristinasti": "ripristinare",
    "ripristinata": "ripristinare",
    "ripristinate": "ripristinare",
    "ripristinati": "ripristinare",
    "ripristinato": "ripristinare",
    "ripristinava": "ripristinare",
    "ripristinavamo": "ripristinare",
    "ripristinavan": "ripristinare",
    "ripristinavano": "ripristinare",
    "ripristinavate": "ripristinare",
    "ripristinavi": "ripristinare",
    "ripristinavo": "ripristinare",
    "ripristinerai": "ripristinare",
    "ripristineran": "ripristinare",
    "ripristineranno": "ripristinare",
    "ripristinerebbe": "ripristinare",
    "ripristinerebber": "ripristinare",
    "ripristinerebbero": "ripristinare",
    "ripristinerei": "ripristinare",
    "ripristineremmo": "ripristinare",
    "ripristineremo": "ripristinare",
    "ripristinereste": "ripristinare",
    "ripristineresti": "ripristinare",
    "ripristinerete": "ripristinare",
    "ripristinerà": "ripristinare",
    "ripristinerò": "ripristinare",
    "ripristini": "ripristino",
    "ripristiniamo": "ripristinare",
    "ripristiniate": "ripristinare",
    "ripristinin": "ripristinare",
    "ripristinino": "ripristinare",
    "ripristino": "ripristinare",
    "ripristinò": "ripristinare",
    "riprodotta": "riprodurre",
    "riprodotte": "riprodurre",
    "riprodotti": "riprodurre",
    "riprodotto": "riprodurre",
    "riproduca": "riprodurre",
    "riproducan": "riprodurre",
    "riproducano": "riprodurre",
    "riproduce": "riprodurre",
    "riproducemmo": "riprodurre",
    "riproducendo": "riprodurre",
    "riproducente": "riprodurre",
    "riproducenti": "riprodurre",
    "riproducesse": "riprodurre",
    "riproducesser": "riprodurre",
    "riproducessero": "riprodurre",
    "riproducessi": "riprodurre",
    "riproducessimo": "riprodurre",
    "riproduceste": "riprodurre",
    "riproducesti": "riprodurre",
    "riproducete": "riprodurre",
    "riproduceva": "riprodurre",
    "riproducevamo": "riprodurre",
    "riproducevan": "riprodurre",
    "riproducevano": "riprodurre",
    "riproducevate": "riprodurre",
    "riproducevi": "riprodurre",
    "riproducevo": "riprodurre",
    "riproduci": "riprodurre",
    "riproduciamo": "riprodurre",
    "riproduciate": "riprodurre",
    "riproducibili": "riproducibile",
    "riproduco": "riprodurre",
    "riproducon": "riprodurre",
    "riproducono": "riprodurre",
    "riprodurr": "riprodurre",
    "riprodurrai": "riprodurre",
    "riprodurran": "riprodurre",
    "riprodurranno": "riprodurre",
    "riprodurrebbe": "riprodurre",
    "riprodurrebber": "riprodurre",
    "riprodurrebbero": "riprodurre",
    "riprodurrei": "riprodurre",
    "riprodurremmo": "riprodurre",
    "riprodurremo": "riprodurre",
    "riprodurreste": "riprodurre",
    "riprodurresti": "riprodurre",
    "riprodurrete": "riprodurre",
    "riprodurrà": "riprodurre",
    "riprodurrò": "riprodurre",
    "riprodusse": "riprodurre",
    "riprodusser": "riprodurre",
    "riprodussero": "riprodurre",
    "riprodussi": "riprodurre",
    "riproduttiva": "riproduttivo",
    "riproduttive": "riproduttivo",
    "riproduttivi": "riproduttivo",
    "riproduttori": "riproduttore",
    "riproduttrice": "riproduttore",
    "riproduttrici": "riproduttore",
    "riproduzioni": "riproduzione",
    "riprogramma": "riprogrammare",
    "riprogrammai": "riprogrammare",
    "riprogrammammo": "riprogrammare",
    "riprogramman": "riprogrammare",
    "riprogrammando": "riprogrammare",
    "riprogrammano": "riprogrammare",
    "riprogrammante": "riprogrammare",
    "riprogrammanti": "riprogrammare",
    "riprogrammar": "riprogrammare",
    "riprogrammaron": "riprogrammare",
    "riprogrammarono": "riprogrammare",
    "riprogrammasse": "riprogrammare",
    "riprogrammasser": "riprogrammare",
    "riprogrammassero": "riprogrammare",
    "riprogrammassi": "riprogrammare",
    "riprogrammassimo": "riprogrammare",
    "riprogrammaste": "riprogrammare",
    "riprogrammasti": "riprogrammare",
    "riprogrammata": "riprogrammare",
    "riprogrammate": "riprogrammare",
    "riprogrammati": "riprogrammare",
    "riprogrammato": "riprogrammare",
    "riprogrammava": "riprogrammare",
    "riprogrammavamo": "riprogrammare",
    "riprogrammavan": "riprogrammare",
    "riprogrammavano": "riprogrammare",
    "riprogrammavate": "riprogrammare",
    "riprogrammavi": "riprogrammare",
    "riprogrammavo": "riprogrammare",
    "riprogrammerai": "riprogrammare",
    "riprogrammeran": "riprogrammare",
    "riprogrammeranno": "riprogrammare",
    "riprogrammerebbe": "riprogrammare",
    "riprogrammerebber": "riprogrammare",
    "riprogrammerebbero": "riprogrammare",
    "riprogrammerei": "riprogrammare",
    "riprogrammeremmo": "riprogrammare",
    "riprogrammeremo": "riprogrammare",
    "riprogrammereste": "riprogrammare",
    "riprogrammeresti": "riprogrammare",
    "riprogrammerete": "riprogrammare",
    "riprogrammerà": "riprogrammare",
    "riprogrammerò": "riprogrammare",
    "riprogrammi": "riprogrammare",
    "riprogrammiamo": "riprogrammare",
    "riprogrammiate": "riprogrammare",
    "riprogrammin": "riprogrammare",
    "riprogrammino": "riprogrammare",
    "riprogrammo": "riprogrammare",
    "riprogrammò": "riprogrammare",
    "ripromessa": "ripromettere",
    "ripromesse": "ripromettere",
    "ripromessi": "ripromettere",
    "ripromesso": "ripromettere",
    "riprometta": "ripromettere",
    "ripromettan": "ripromettere",
    "ripromettano": "ripromettere",
    "ripromette": "ripromettere",
    "ripromettemmo": "ripromettere",
    "ripromettendo": "ripromettere",
    "ripromettente": "ripromettere",
    "ripromettenti": "ripromettere",
    "riprometter": "ripromettere",
    "riprometterai": "ripromettere",
    "riprometteran": "ripromettere",
    "riprometteranno": "ripromettere",
    "riprometterebbe": "ripromettere",
    "riprometterebber": "ripromettere",
    "riprometterebbero": "ripromettere",
    "riprometterei": "ripromettere",
    "riprometteremmo": "ripromettere",
    "riprometteremo": "ripromettere",
    "ripromettereste": "ripromettere",
    "riprometteresti": "ripromettere",
    "riprometterete": "ripromettere",
    "riprometterà": "ripromettere",
    "riprometterò": "ripromettere",
    "ripromettesse": "ripromettere",
    "ripromettesser": "ripromettere",
    "ripromettessero": "ripromettere",
    "ripromettessi": "ripromettere",
    "ripromettessimo": "ripromettere",
    "riprometteste": "ripromettere",
    "ripromettesti": "ripromettere",
    "ripromettete": "ripromettere",
    "riprometteva": "ripromettere",
    "ripromettevamo": "ripromettere",
    "ripromettevan": "ripromettere",
    "ripromettevano": "ripromettere",
    "ripromettevate": "ripromettere",
    "ripromettevi": "ripromettere",
    "ripromettevo": "ripromettere",
    "riprometti": "ripromettere",
    "ripromettiamo": "ripromettere",
    "ripromettiate": "ripromettere",
    "riprometto": "ripromettere",
    "riprometton": "ripromettere",
    "ripromettono": "ripromettere",
    "ripromise": "ripromettere",
    "ripromiser": "ripromettere",
    "ripromisero": "ripromettere",
    "ripromisi": "ripromettere",
    "ripropone": "riproporre",
    "riproponemmo": "riproporre",
    "riproponendo": "riproporre",
    "riproponente": "riproporre",
    "riproponenti": "riproporre",
    "riproponesse": "riproporre",
    "riproponesser": "riproporre",
    "riproponessero": "riproporre",
    "riproponessi": "riproporre",
    "riproponessimo": "riproporre",
    "riproponeste": "riproporre",
    "riproponesti": "riproporre",
    "riproponete": "riproporre",
    "riproponeva": "riproporre",
    "riproponevamo": "riproporre",
    "riproponevan": "riproporre",
    "riproponevano": "riproporre",
    "riproponevate": "riproporre",
    "riproponevi": "riproporre",
    "riproponevo": "riproporre",
    "riproponga": "riproporre",
    "ripropongan": "riproporre",
    "ripropongano": "riproporre",
    "ripropongo": "riproporre",
    "ripropongon": "riproporre",
    "ripropongono": "riproporre",
    "riproponi": "riproporre",
    "riproponiamo": "riproporre",
    "riproponiate": "riproporre",
    "riproponibili": "riproponibile",
    "riproporr": "riproporre",
    "riproporrai": "riproporre",
    "riproporran": "riproporre",
    "riproporranno": "riproporre",
    "riproporrebbe": "riproporre",
    "riproporrebber": "riproporre",
    "riproporrebbero": "riproporre",
    "riproporrei": "riproporre",
    "riproporremmo": "riproporre",
    "riproporremo": "riproporre",
    "riproporreste": "riproporre",
    "riproporresti": "riproporre",
    "riproporrete": "riproporre",
    "riproporrà": "riproporre",
    "riproporrò": "riproporre",
    "ripropose": "riproporre",
    "riproposer": "riproporre",
    "riproposero": "riproporre",
    "riproposi": "riproporre",
    "riproposizioni": "riproposizione",
    "riproposta": "riproporre",
    "riproposte": "riproposta",
    "riproposti": "riproporre",
    "riproposto": "riproporre",
    "riprova": "riprovare",
    "riprovai": "riprovare",
    "riprovammo": "riprovare",
    "riprovan": "riprovare",
    "riprovando": "riprovare",
    "riprovano": "riprovare",
    "riprovante": "riprovare",
    "riprovanti": "riprovare",
    "riprovar": "riprovare",
    "riprovaron": "riprovare",
    "riprovarono": "riprovare",
    "riprovasse": "riprovare",
    "riprovasser": "riprovare",
    "riprovassero": "riprovare",
    "riprovassi": "riprovare",
    "riprovassimo": "riprovare",
    "riprovaste": "riprovare",
    "riprovasti": "riprovare",
    "riprovata": "riprovare",
    "riprovate": "riprovare",
    "riprovati": "riprovare",
    "riprovato": "riprovare",
    "riprovava": "riprovare",
    "riprovavamo": "riprovare",
    "riprovavan": "riprovare",
    "riprovavano": "riprovare",
    "riprovavate": "riprovare",
    "riprovavi": "riprovare",
    "riprovavo": "riprovare",
    "riprovazioni": "riprovazione",
    "riproverai": "riprovare",
    "riproveran": "riprovare",
    "riproveranno": "riprovare",
    "riproverebbe": "riprovare",
    "riproverebber": "riprovare",
    "riproverebbero": "riprovare",
    "riproverei": "riprovare",
    "riproveremmo": "riprovare",
    "riproveremo": "riprovare",
    "riprovereste": "riprovare",
    "riproveresti": "riprovare",
    "riproverete": "riprovare",
    "riproverà": "riprovare",
    "riproverò": "riprovare",
    "riprovevoli": "riprovevole",
    "riprovi": "riprovare",
    "riproviamo": "riprovare",
    "riproviate": "riprovare",
    "riprovin": "riprovare",
    "riprovino": "riprovare",
    "riprovo": "riprovare",
    "riprovò": "riprovare",
    "ripubblica": "ripubblicare",
    "ripubblicai": "ripubblicare",
    "ripubblicammo": "ripubblicare",
    "ripubblican": "ripubblicare",
    "ripubblicando": "ripubblicare",
    "ripubblicano": "ripubblicare",
    "ripubblicante": "ripubblicare",
    "ripubblicanti": "ripubblicare",
    "ripubblicar": "ripubblicare",
    "ripubblicaron": "ripubblicare",
    "ripubblicarono": "ripubblicare",
    "ripubblicasse": "ripubblicare",
    "ripubblicasser": "ripubblicare",
    "ripubblicassero": "ripubblicare",
    "ripubblicassi": "ripubblicare",
    "ripubblicassimo": "ripubblicare",
    "ripubblicaste": "ripubblicare",
    "ripubblicasti": "ripubblicare",
    "ripubblicata": "ripubblicare",
    "ripubblicate": "ripubblicare",
    "ripubblicati": "ripubblicare",
    "ripubblicato": "ripubblicare",
    "ripubblicava": "ripubblicare",
    "ripubblicavamo": "ripubblicare",
    "ripubblicavan": "ripubblicare",
    "ripubblicavano": "ripubblicare",
    "ripubblicavate": "ripubblicare",
    "ripubblicavi": "ripubblicare",
    "ripubblicavo": "ripubblicare",
    "ripubblicherai": "ripubblicare",
    "ripubblicheran": "ripubblicare",
    "ripubblicheranno": "ripubblicare",
    "ripubblicherebbe": "ripubblicare",
    "ripubblicherebber": "ripubblicare",
    "ripubblicherebbero": "ripubblicare",
    "ripubblicherei": "ripubblicare",
    "ripubblicheremmo": "ripubblicare",
    "ripubblicheremo": "ripubblicare",
    "ripubblichereste": "ripubblicare",
    "ripubblicheresti": "ripubblicare",
    "ripubblicherete": "ripubblicare",
    "ripubblicherà": "ripubblicare",
    "ripubblicherò": "ripubblicare",
    "ripubblichi": "ripubblicare",
    "ripubblichiamo": "ripubblicare",
    "ripubblichiate": "ripubblicare",
    "ripubblichin": "ripubblicare",
    "ripubblichino": "ripubblicare",
    "ripubblico": "ripubblicare",
    "ripubblicò": "ripubblicare",
    "ripudi": "ripudio",
    "ripudia": "ripudiare",
    "ripudiai": "ripudiare",
    "ripudiammo": "ripudiare",
    "ripudiamo": "ripudiare",
    "ripudian": "ripudiare",
    "ripudiando": "ripudiare",
    "ripudiano": "ripudiare",
    "ripudiante": "ripudiare",
    "ripudianti": "ripudiare",
    "ripudiar": "ripudiare",
    "ripudiaron": "ripudiare",
    "ripudiarono": "ripudiare",
    "ripudiasse": "ripudiare",
    "ripudiasser": "ripudiare",
    "ripudiassero": "ripudiare",
    "ripudiassi": "ripudiare",
    "ripudiassimo": "ripudiare",
    "ripudiaste": "ripudiare",
    "ripudiasti": "ripudiare",
    "ripudiata": "ripudiare",
    "ripudiate": "ripudiare",
    "ripudiati": "ripudiare",
    "ripudiato": "ripudiare",
    "ripudiava": "ripudiare",
    "ripudiavamo": "ripudiare",
    "ripudiavan": "ripudiare",
    "ripudiavano": "ripudiare",
    "ripudiavate": "ripudiare",
    "ripudiavi": "ripudiare",
    "ripudiavo": "ripudiare",
    "ripudierai": "ripudiare",
    "ripudieran": "ripudiare",
    "ripudieranno": "ripudiare",
    "ripudierebbe": "ripudiare",
    "ripudierebber": "ripudiare",
    "ripudierebbero": "ripudiare",
    "ripudierei": "ripudiare",
    "ripudieremmo": "ripudiare",
    "ripudieremo": "ripudiare",
    "ripudiereste": "ripudiare",
    "ripudieresti": "ripudiare",
    "ripudierete": "ripudiare",
    "ripudierà": "ripudiare",
    "ripudierò": "ripudiare",
    "ripudin": "ripudiare",
    "ripudino": "ripudiare",
    "ripudio": "ripudiare",
    "ripudiò": "ripudiare",
    "ripugna": "ripugnare",
    "ripugnai": "ripugnare",
    "ripugnammo": "ripugnare",
    "ripugnan": "ripugnare",
    "ripugnando": "ripugnare",
    "ripugnano": "ripugnare",
    "ripugnante": "ripugnare",
    "ripugnanti": "ripugnare",
    "ripugnar": "ripugnare",
    "ripugnaron": "ripugnare",
    "ripugnarono": "ripugnare",
    "ripugnasse": "ripugnare",
    "ripugnasser": "ripugnare",
    "ripugnassero": "ripugnare",
    "ripugnassi": "ripugnare",
    "ripugnassimo": "ripugnare",
    "ripugnaste": "ripugnare",
    "ripugnasti": "ripugnare",
    "ripugnata": "ripugnare",
    "ripugnate": "ripugnare",
    "ripugnati": "ripugnare",
    "ripugnato": "ripugnare",
    "ripugnava": "ripugnare",
    "ripugnavamo": "ripugnare",
    "ripugnavan": "ripugnare",
    "ripugnavano": "ripugnare",
    "ripugnavate": "ripugnare",
    "ripugnavi": "ripugnare",
    "ripugnavo": "ripugnare",
    "ripugnerai": "ripugnare",
    "ripugneran": "ripugnare",
    "ripugneranno": "ripugnare",
    "ripugnerebbe": "ripugnare",
    "ripugnerebber": "ripugnare",
    "ripugnerebbero": "ripugnare",
    "ripugnerei": "ripugnare",
    "ripugneremmo": "ripugnare",
    "ripugneremo": "ripugnare",
    "ripugnereste": "ripugnare",
    "ripugneresti": "ripugnare",
    "ripugnerete": "ripugnare",
    "ripugnerà": "ripugnare",
    "ripugnerò": "ripugnare",
    "ripugni": "ripugnare",
    "ripugniamo": "ripugnare",
    "ripugniate": "ripugnare",
    "ripugnin": "ripugnare",
    "ripugnino": "ripugnare",
    "ripugno": "ripugnare",
    "ripugnò": "ripugnare",
    "ripulendo": "ripulire",
    "ripulente": "ripulire",
    "ripulenti": "ripulire",
    "ripuliamo": "ripulire",
    "ripuliate": "ripulire",
    "ripulii": "ripulire",
    "ripulimmo": "ripulire",
    "ripulir": "ripulire",
    "ripulirai": "ripulire",
    "ripuliran": "ripulire",
    "ripuliranno": "ripulire",
    "ripulirebbe": "ripulire",
    "ripulirebber": "ripulire",
    "ripulirebbero": "ripulire",
    "ripulirei": "ripulire",
    "ripuliremmo": "ripulire",
    "ripuliremo": "ripulire",
    "ripulireste": "ripulire",
    "ripuliresti": "ripulire",
    "ripulirete": "ripulire",
    "ripuliron": "ripulire",
    "ripulirono": "ripulire",
    "ripulirà": "ripulire",
    "ripulirò": "ripulire",
    "ripulisca": "ripulire",
    "ripuliscan": "ripulire",
    "ripuliscano": "ripulire",
    "ripulisce": "ripulire",
    "ripulisci": "ripulire",
    "ripulisco": "ripulire",
    "ripuliscon": "ripulire",
    "ripuliscono": "ripulire",
    "ripulisse": "ripulire",
    "ripulisser": "ripulire",
    "ripulissero": "ripulire",
    "ripulissi": "ripulire",
    "ripulissimo": "ripulire",
    "ripuliste": "ripulire",
    "ripulisti": "ripulire",
    "ripulita": "ripulire",
    "ripulite": "ripulire",
    "ripuliti": "ripulire",
    "ripulito": "ripulire",
    "ripuliture": "ripulitura",
    "ripuliva": "ripulire",
    "ripulivamo": "ripulire",
    "ripulivan": "ripulire",
    "ripulivano": "ripulire",
    "ripulivate": "ripulire",
    "ripulivi": "ripulire",
    "ripulivo": "ripulire",
    "ripulsa": "ripulso",
    "ripulse": "ripulso",
    "ripulsi": "ripulso",
    "ripulì": "ripulire",
    "ripunga": "ripungere",
    "ripungan": "ripungere",
    "ripungano": "ripungere",
    "ripunge": "ripungere",
    "ripungemmo": "ripungere",
    "ripungendo": "ripungere",
    "ripungente": "ripungere",
    "ripungenti": "ripungere",
    "ripunger": "ripungere",
    "ripungerai": "ripungere",
    "ripungeran": "ripungere",
    "ripungeranno": "ripungere",
    "ripungerebbe": "ripungere",
    "ripungerebber": "ripungere",
    "ripungerebbero": "ripungere",
    "ripungerei": "ripungere",
    "ripungeremmo": "ripungere",
    "ripungeremo": "ripungere",
    "ripungereste": "ripungere",
    "ripungeresti": "ripungere",
    "ripungerete": "ripungere",
    "ripungerà": "ripungere",
    "ripungerò": "ripungere",
    "ripungesse": "ripungere",
    "ripungesser": "ripungere",
    "ripungessero": "ripungere",
    "ripungessi": "ripungere",
    "ripungessimo": "ripungere",
    "ripungeste": "ripungere",
    "ripungesti": "ripungere",
    "ripungete": "ripungere",
    "ripungeva": "ripungere",
    "ripungevamo": "ripungere",
    "ripungevan": "ripungere",
    "ripungevano": "ripungere",
    "ripungevate": "ripungere",
    "ripungevi": "ripungere",
    "ripungevo": "ripungere",
    "ripungi": "ripungere",
    "ripungiamo": "ripungere",
    "ripungiate": "ripungere",
    "ripungo": "ripungere",
    "ripungon": "ripungere",
    "ripungono": "ripungere",
    "ripunser": "ripungere",
    "ripunsero": "ripungere",
    "ripunsi": "ripungere",
    "ripunsè": "ripungere",
    "ripunta": "ripungere",
    "ripunte": "ripungere",
    "ripunti": "ripungere",
    "ripunto": "ripungere",
    "riputa": "riputare",
    "riputai": "riputare",
    "riputammo": "riputare",
    "riputan": "riputare",
    "riputando": "riputare",
    "riputano": "riputare",
    "riputante": "riputare",
    "riputanti": "riputare",
    "riputar": "riputare",
    "riputaron": "riputare",
    "riputarono": "riputare",
    "riputasse": "riputare",
    "riputasser": "riputare",
    "riputassero": "riputare",
    "riputassi": "riputare",
    "riputassimo": "riputare",
    "riputaste": "riputare",
    "riputasti": "riputare",
    "riputata": "riputare",
    "riputate": "riputare",
    "riputati": "riputare",
    "riputato": "riputare",
    "riputava": "riputare",
    "riputavamo": "riputare",
    "riputavan": "riputare",
    "riputavano": "riputare",
    "riputavate": "riputare",
    "riputavi": "riputare",
    "riputavo": "riputare",
    "riputerai": "riputare",
    "riputeran": "riputare",
    "riputeranno": "riputare",
    "riputerebbe": "riputare",
    "riputerebber": "riputare",
    "riputerebbero": "riputare",
    "riputerei": "riputare",
    "riputeremmo": "riputare",
    "riputeremo": "riputare",
    "riputereste": "riputare",
    "riputeresti": "riputare",
    "riputerete": "riputare",
    "riputerà": "riputare",
    "riputerò": "riputare",
    "riputi": "riputare",
    "riputiamo": "riputare",
    "riputiate": "riputare",
    "riputin": "riputare",
    "riputino": "riputare",
    "riputo": "riputare",
    "riputò": "riputare",
    "riquadra": "riquadrare",
    "riquadrai": "riquadrare",
    "riquadrammo": "riquadrare",
    "riquadran": "riquadrare",
    "riquadrando": "riquadrare",
    "riquadrano": "riquadrare",
    "riquadrante": "riquadrare",
    "riquadranti": "riquadrare",
    "riquadrar": "riquadrare",
    "riquadraron": "riquadrare",
    "riquadrarono": "riquadrare",
    "riquadrasse": "riquadrare",
    "riquadrasser": "riquadrare",
    "riquadrassero": "riquadrare",
    "riquadrassi": "riquadrare",
    "riquadrassimo": "riquadrare",
    "riquadraste": "riquadrare",
    "riquadrasti": "riquadrare",
    "riquadrata": "riquadrare",
    "riquadrate": "riquadrare",
    "riquadrati": "riquadrare",
    "riquadrato": "riquadrare",
    "riquadrava": "riquadrare",
    "riquadravamo": "riquadrare",
    "riquadravan": "riquadrare",
    "riquadravano": "riquadrare",
    "riquadravate": "riquadrare",
    "riquadravi": "riquadrare",
    "riquadravo": "riquadrare",
    "riquadrerai": "riquadrare",
    "riquadreran": "riquadrare",
    "riquadreranno": "riquadrare",
    "riquadrerebbe": "riquadrare",
    "riquadrerebber": "riquadrare",
    "riquadrerebbero": "riquadrare",
    "riquadrerei": "riquadrare",
    "riquadreremmo": "riquadrare",
    "riquadreremo": "riquadrare",
    "riquadrereste": "riquadrare",
    "riquadreresti": "riquadrare",
    "riquadrerete": "riquadrare",
    "riquadrerà": "riquadrare",
    "riquadrerò": "riquadrare",
    "riquadri": "riquadro",
    "riquadriamo": "riquadrare",
    "riquadriate": "riquadrare",
    "riquadrin": "riquadrare",
    "riquadrino": "riquadrare",
    "riquadro": "riquadrare",
    "riquadrò": "riquadrare",
    "riqualifica": "riqualificare",
    "riqualificai": "riqualificare",
    "riqualificammo": "riqualificare",
    "riqualifican": "riqualificare",
    "riqualificando": "riqualificare",
    "riqualificano": "riqualificare",
    "riqualificante": "riqualificare",
    "riqualificanti": "riqualificare",
    "riqualificar": "riqualificare",
    "riqualificaron": "riqualificare",
    "riqualificarono": "riqualificare",
    "riqualificasse": "riqualificare",
    "riqualificasser": "riqualificare",
    "riqualificassero": "riqualificare",
    "riqualificassi": "riqualificare",
    "riqualificassimo": "riqualificare",
    "riqualificaste": "riqualificare",
    "riqualificasti": "riqualificare",
    "riqualificata": "riqualificare",
    "riqualificate": "riqualificare",
    "riqualificati": "riqualificare",
    "riqualificato": "riqualificare",
    "riqualificava": "riqualificare",
    "riqualificavamo": "riqualificare",
    "riqualificavan": "riqualificare",
    "riqualificavano": "riqualificare",
    "riqualificavate": "riqualificare",
    "riqualificavi": "riqualificare",
    "riqualificavo": "riqualificare",
    "riqualificazioni": "riqualificazione",
    "riqualificherai": "riqualificare",
    "riqualificheran": "riqualificare",
    "riqualificheranno": "riqualificare",
    "riqualificherebbe": "riqualificare",
    "riqualificherebber": "riqualificare",
    "riqualificherebbero": "riqualificare",
    "riqualificherei": "riqualificare",
    "riqualificheremmo": "riqualificare",
    "riqualificheremo": "riqualificare",
    "riqualifichereste": "riqualificare",
    "riqualificheresti": "riqualificare",
    "riqualificherete": "riqualificare",
    "riqualificherà": "riqualificare",
    "riqualificherò": "riqualificare",
    "riqualifichi": "riqualificare",
    "riqualifichiamo": "riqualificare",
    "riqualifichiate": "riqualificare",
    "riqualifichin": "riqualificare",
    "riqualifichino": "riqualificare",
    "riqualifico": "riqualificare",
    "riqualificò": "riqualificare",
    "risa": "riso",
    "risacche": "risacca",
    "risai": "risapere",
    "risaie": "risaia",
    "risalda": "risaldare",
    "risaldai": "risaldare",
    "risaldammo": "risaldare",
    "risaldan": "risaldare",
    "risaldando": "risaldare",
    "risaldano": "risaldare",
    "risaldante": "risaldare",
    "risaldanti": "risaldare",
    "risaldar": "risaldare",
    "risaldaron": "risaldare",
    "risaldarono": "risaldare",
    "risaldasse": "risaldare",
    "risaldasser": "risaldare",
    "risaldassero": "risaldare",
    "risaldassi": "risaldare",
    "risaldassimo": "risaldare",
    "risaldaste": "risaldare",
    "risaldasti": "risaldare",
    "risaldata": "risaldare",
    "risaldate": "risaldare",
    "risaldati": "risaldare",
    "risaldato": "risaldare",
    "risaldava": "risaldare",
    "risaldavamo": "risaldare",
    "risaldavan": "risaldare",
    "risaldavano": "risaldare",
    "risaldavate": "risaldare",
    "risaldavi": "risaldare",
    "risaldavo": "risaldare",
    "risalderai": "risaldare",
    "risalderan": "risaldare",
    "risalderanno": "risaldare",
    "risalderebbe": "risaldare",
    "risalderebber": "risaldare",
    "risalderebbero": "risaldare",
    "risalderei": "risaldare",
    "risalderemmo": "risaldare",
    "risalderemo": "risaldare",
    "risaldereste": "risaldare",
    "risalderesti": "risaldare",
    "risalderete": "risaldare",
    "risalderà": "risaldare",
    "risalderò": "risaldare",
    "risaldi": "risaldare",
    "risaldiamo": "risaldare",
    "risaldiate": "risaldare",
    "risaldin": "risaldare",
    "risaldino": "risaldare",
    "risaldo": "risaldare",
    "risaldò": "risaldare",
    "risale": "risalire",
    "risalendo": "risalire",
    "risalente": "risalire",
    "risalenti": "risalire",
    "risalga": "risalire",
    "risalgan": "risalire",
    "risalgano": "risalire",
    "risalgo": "risalire",
    "risalgon": "risalire",
    "risalgono": "risalire",
    "risali": "risalire",
    "risaliamo": "risalire",
    "risaliate": "risalire",
    "risalii": "risalire",
    "risalimmo": "risalire",
    "risalir": "risalire",
    "risalirai": "risalire",
    "risaliran": "risalire",
    "risaliranno": "risalire",
    "risalirebbe": "risalire",
    "risalirebber": "risalire",
    "risalirebbero": "risalire",
    "risalirei": "risalire",
    "risaliremmo": "risalire",
    "risaliremo": "risalire",
    "risalireste": "risalire",
    "risaliresti": "risalire",
    "risalirete": "risalire",
    "risaliron": "risalire",
    "risalirono": "risalire",
    "risalirà": "risalire",
    "risalirò": "risalire",
    "risalisse": "risalire",
    "risalisser": "risalire",
    "risalissero": "risalire",
    "risalissi": "risalire",
    "risalissimo": "risalire",
    "risaliste": "risalire",
    "risalisti": "risalire",
    "risalita": "risalire",
    "risalite": "risalita",
    "risaliti": "risalire",
    "risalito": "risalire",
    "risaliva": "risalire",
    "risalivamo": "risalire",
    "risalivan": "risalire",
    "risalivano": "risalire",
    "risalivate": "risalire",
    "risalivi": "risalire",
    "risalivo": "risalire",
    "risalta": "risaltare",
    "risaltai": "risaltare",
    "risaltammo": "risaltare",
    "risaltan": "risaltare",
    "risaltando": "risaltare",
    "risaltano": "risaltare",
    "risaltante": "risaltare",
    "risaltanti": "risaltare",
    "risaltar": "risaltare",
    "risaltaron": "risaltare",
    "risaltarono": "risaltare",
    "risaltasse": "risaltare",
    "risaltasser": "risaltare",
    "risaltassero": "risaltare",
    "risaltassi": "risaltare",
    "risaltassimo": "risaltare",
    "risaltaste": "risaltare",
    "risaltasti": "risaltare",
    "risaltata": "risaltare",
    "risaltate": "risaltare",
    "risaltati": "risaltare",
    "risaltato": "risaltare",
    "risaltava": "risaltare",
    "risaltavamo": "risaltare",
    "risaltavan": "risaltare",
    "risaltavano": "risaltare",
    "risaltavate": "risaltare",
    "risaltavi": "risaltare",
    "risaltavo": "risaltare",
    "risalterai": "risaltare",
    "risalteran": "risaltare",
    "risalteranno": "risaltare",
    "risalterebbe": "risaltare",
    "risalterebber": "risaltare",
    "risalterebbero": "risaltare",
    "risalterei": "risaltare",
    "risalteremmo": "risaltare",
    "risalteremo": "risaltare",
    "risaltereste": "risaltare",
    "risalteresti": "risaltare",
    "risalterete": "risaltare",
    "risalterà": "risaltare",
    "risalterò": "risaltare",
    "risalti": "risalto",
    "risaltiamo": "risaltare",
    "risaltiate": "risaltare",
    "risaltin": "risaltare",
    "risaltino": "risaltare",
    "risalto": "risaltare",
    "risaltò": "risaltare",
    "risalì": "risalire",
    "risan": "risapere",
    "risana": "risanare",
    "risanabili": "risanabile",
    "risanai": "risanare",
    "risanamenti": "risanamento",
    "risanammo": "risanare",
    "risanan": "risanare",
    "risanando": "risanare",
    "risanano": "risanare",
    "risanante": "risanare",
    "risananti": "risanare",
    "risanar": "risanare",
    "risanaron": "risanare",
    "risanarono": "risanare",
    "risanasse": "risanare",
    "risanasser": "risanare",
    "risanassero": "risanare",
    "risanassi": "risanare",
    "risanassimo": "risanare",
    "risanaste": "risanare",
    "risanasti": "risanare",
    "risanata": "risanare",
    "risanate": "risanare",
    "risanati": "risanare",
    "risanato": "risanare",
    "risanatori": "risanatore",
    "risanatrice": "risanatore",
    "risanatrici": "risanatore",
    "risanava": "risanare",
    "risanavamo": "risanare",
    "risanavan": "risanare",
    "risanavano": "risanare",
    "risanavate": "risanare",
    "risanavi": "risanare",
    "risanavo": "risanare",
    "risanerai": "risanare",
    "risaneran": "risanare",
    "risaneranno": "risanare",
    "risanerebbe": "risanare",
    "risanerebber": "risanare",
    "risanerebbero": "risanare",
    "risanerei": "risanare",
    "risaneremmo": "risanare",
    "risaneremo": "risanare",
    "risanereste": "risanare",
    "risaneresti": "risanare",
    "risanerete": "risanare",
    "risanerà": "risanare",
    "risanerò": "risanare",
    "risani": "risanare",
    "risaniamo": "risanare",
    "risaniate": "risanare",
    "risanin": "risanare",
    "risanino": "risanare",
    "risanno": "risapere",
    "risano": "risanare",
    "risanò": "risanare",
    "risapemmo": "risapere",
    "risapendo": "risapere",
    "risapente": "risapere",
    "risapenti": "risapere",
    "risaper": "risapere",
    "risapesse": "risapere",
    "risapesser": "risapere",
    "risapessero": "risapere",
    "risapessi": "risapere",
    "risapessimo": "risapere",
    "risapeste": "risapere",
    "risapesti": "risapere",
    "risapete": "risapere",
    "risapeva": "risapere",
    "risapevamo": "risapere",
    "risapevan": "risapere",
    "risapevano": "risapere",
    "risapevate": "risapere",
    "risapevi": "risapere",
    "risapevo": "risapere",
    "risappia": "risapere",
    "risappiamo": "risapere",
    "risappian": "risapere",
    "risappiano": "risapere",
    "risappiate": "risapere",
    "risaprai": "risapere",
    "risapran": "risapere",
    "risapranno": "risapere",
    "risaprebbe": "risapere",
    "risaprebber": "risapere",
    "risaprebbero": "risapere",
    "risaprei": "risapere",
    "risapremmo": "risapere",
    "risapremo": "risapere",
    "risapreste": "risapere",
    "risapresti": "risapere",
    "risaprete": "risapere",
    "risaprà": "risapere",
    "risaprò": "risapere",
    "risaputa": "risaputo",
    "risapute": "risaputo",
    "risaputi": "risaputo",
    "risaputo": "risapere",
    "risarai": "riessere",
    "risaran": "riessere",
    "risaranno": "riessere",
    "risarcendo": "risarcire",
    "risarcente": "risarcire",
    "risarcenti": "risarcire",
    "risarciamo": "risarcire",
    "risarciate": "risarcire",
    "risarcii": "risarcire",
    "risarcimenti": "risarcimento",
    "risarcimmo": "risarcire",
    "risarcir": "risarcire",
    "risarcirai": "risarcire",
    "risarciran": "risarcire",
    "risarciranno": "risarcire",
    "risarcirebbe": "risarcire",
    "risarcirebber": "risarcire",
    "risarcirebbero": "risarcire",
    "risarcirei": "risarcire",
    "risarciremmo": "risarcire",
    "risarciremo": "risarcire",
    "risarcireste": "risarcire",
    "risarciresti": "risarcire",
    "risarcirete": "risarcire",
    "risarciron": "risarcire",
    "risarcirono": "risarcire",
    "risarcirà": "risarcire",
    "risarcirò": "risarcire",
    "risarcisca": "risarcire",
    "risarciscan": "risarcire",
    "risarciscano": "risarcire",
    "risarcisce": "risarcire",
    "risarcisci": "risarcire",
    "risarcisco": "risarcire",
    "risarciscon": "risarcire",
    "risarciscono": "risarcire",
    "risarcisse": "risarcire",
    "risarcisser": "risarcire",
    "risarcissero": "risarcire",
    "risarcissi": "risarcire",
    "risarcissimo": "risarcire",
    "risarciste": "risarcire",
    "risarcisti": "risarcire",
    "risarcita": "risarcire",
    "risarcite": "risarcire",
    "risarciti": "risarcire",
    "risarcito": "risarcire",
    "risarciva": "risarcire",
    "risarcivamo": "risarcire",
    "risarcivan": "risarcire",
    "risarcivano": "risarcire",
    "risarcivate": "risarcire",
    "risarcivi": "risarcire",
    "risarcivo": "risarcire",
    "risarcì": "risarcire",
    "risarebbe": "riessere",
    "risarebber": "riessere",
    "risarebbero": "riessere",
    "risarei": "riessere",
    "risaremmo": "riessere",
    "risaremo": "riessere",
    "risareste": "riessere",
    "risaresti": "riessere",
    "risarete": "riessere",
    "risarà": "riessere",
    "risarò": "riessere",
    "risatacce": "risataccia",
    "risate": "risata",
    "risatine": "risatina",
    "riscalda": "riscaldare",
    "riscaldai": "riscaldare",
    "riscaldamenti": "riscaldamento",
    "riscaldammo": "riscaldare",
    "riscaldan": "riscaldare",
    "riscaldando": "riscaldare",
    "riscaldano": "riscaldare",
    "riscaldante": "riscaldare",
    "riscaldanti": "riscaldare",
    "riscaldar": "riscaldare",
    "riscaldaron": "riscaldare",
    "riscaldarono": "riscaldare",
    "riscaldasse": "riscaldare",
    "riscaldasser": "riscaldare",
    "riscaldassero": "riscaldare",
    "riscaldassi": "riscaldare",
    "riscaldassimo": "riscaldare",
    "riscaldaste": "riscaldare",
    "riscaldasti": "riscaldare",
    "riscaldata": "riscaldare",
    "riscaldate": "riscaldare",
    "riscaldati": "riscaldare",
    "riscaldato": "riscaldare",
    "riscaldava": "riscaldare",
    "riscaldavamo": "riscaldare",
    "riscaldavan": "riscaldare",
    "riscaldavano": "riscaldare",
    "riscaldavate": "riscaldare",
    "riscaldavi": "riscaldare",
    "riscaldavo": "riscaldare",
    "riscalderai": "riscaldare",
    "riscalderan": "riscaldare",
    "riscalderanno": "riscaldare",
    "riscalderebbe": "riscaldare",
    "riscalderebber": "riscaldare",
    "riscalderebbero": "riscaldare",
    "riscalderei": "riscaldare",
    "riscalderemmo": "riscaldare",
    "riscalderemo": "riscaldare",
    "riscaldereste": "riscaldare",
    "riscalderesti": "riscaldare",
    "riscalderete": "riscaldare",
    "riscalderà": "riscaldare",
    "riscalderò": "riscaldare",
    "riscaldi": "riscaldare",
    "riscaldiamo": "riscaldare",
    "riscaldiate": "riscaldare",
    "riscaldin": "riscaldare",
    "riscaldino": "riscaldare",
    "riscaldo": "riscaldare",
    "riscaldò": "riscaldare",
    "riscatta": "riscattare",
    "riscattai": "riscattare",
    "riscattammo": "riscattare",
    "riscattan": "riscattare",
    "riscattando": "riscattare",
    "riscattano": "riscattare",
    "riscattante": "riscattare",
    "riscattanti": "riscattare",
    "riscattar": "riscattare",
    "riscattaron": "riscattare",
    "riscattarono": "riscattare",
    "riscattasse": "riscattare",
    "riscattasser": "riscattare",
    "riscattassero": "riscattare",
    "riscattassi": "riscattare",
    "riscattassimo": "riscattare",
    "riscattaste": "riscattare",
    "riscattasti": "riscattare",
    "riscattata": "riscattare",
    "riscattate": "riscattare",
    "riscattati": "riscattare",
    "riscattato": "riscattare",
    "riscattava": "riscattare",
    "riscattavamo": "riscattare",
    "riscattavan": "riscattare",
    "riscattavano": "riscattare",
    "riscattavate": "riscattare",
    "riscattavi": "riscattare",
    "riscattavo": "riscattare",
    "riscatterai": "riscattare",
    "riscatteran": "riscattare",
    "riscatteranno": "riscattare",
    "riscatterebbe": "riscattare",
    "riscatterebber": "riscattare",
    "riscatterebbero": "riscattare",
    "riscatterei": "riscattare",
    "riscatteremmo": "riscattare",
    "riscatteremo": "riscattare",
    "riscattereste": "riscattare",
    "riscatteresti": "riscattare",
    "riscatterete": "riscattare",
    "riscatterà": "riscattare",
    "riscatterò": "riscattare",
    "riscatti": "riscatto",
    "riscattiamo": "riscattare",
    "riscattiate": "riscattare",
    "riscattin": "riscattare",
    "riscattino": "riscattare",
    "riscatto": "riscattare",
    "riscattò": "riscattare",
    "riscegli": "riscegliere",
    "riscegliamo": "riscegliere",
    "riscegliate": "riscegliere",
    "risceglie": "riscegliere",
    "riscegliemmo": "riscegliere",
    "riscegliendo": "riscegliere",
    "riscegliente": "riscegliere",
    "risceglienti": "riscegliere",
    "risceglier": "riscegliere",
    "risceglierai": "riscegliere",
    "risceglieran": "riscegliere",
    "risceglieranno": "riscegliere",
    "risceglierebbe": "riscegliere",
    "risceglierebber": "riscegliere",
    "risceglierebbero": "riscegliere",
    "risceglierei": "riscegliere",
    "risceglieremmo": "riscegliere",
    "risceglieremo": "riscegliere",
    "riscegliereste": "riscegliere",
    "risceglieresti": "riscegliere",
    "risceglierete": "riscegliere",
    "risceglierà": "riscegliere",
    "risceglierò": "riscegliere",
    "riscegliesse": "riscegliere",
    "riscegliesser": "riscegliere",
    "riscegliessero": "riscegliere",
    "riscegliessi": "riscegliere",
    "riscegliessimo": "riscegliere",
    "risceglieste": "riscegliere",
    "riscegliesti": "riscegliere",
    "riscegliete": "riscegliere",
    "risceglieva": "riscegliere",
    "risceglievamo": "riscegliere",
    "risceglievan": "riscegliere",
    "risceglievano": "riscegliere",
    "risceglievate": "riscegliere",
    "risceglievi": "riscegliere",
    "risceglievo": "riscegliere",
    "riscelga": "riscegliere",
    "riscelgan": "riscegliere",
    "riscelgano": "riscegliere",
    "riscelgo": "riscegliere",
    "riscelgon": "riscegliere",
    "riscelgono": "riscegliere",
    "riscelser": "riscegliere",
    "riscelsero": "riscegliere",
    "riscelsi": "riscegliere",
    "riscelsè": "riscegliere",
    "riscelta": "riscegliere",
    "riscelte": "riscegliere",
    "riscelti": "riscegliere",
    "riscelto": "riscegliere",
    "rischi": "rischio",
    "rischia": "rischiare",
    "rischiai": "rischiare",
    "rischiammo": "rischiare",
    "rischiamo": "rischiare",
    "rischian": "rischiare",
    "rischiando": "rischiare",
    "rischiano": "rischiare",
    "rischiante": "rischiare",
    "rischianti": "rischiare",
    "rischiar": "rischiare",
    "rischiara": "rischiarare",
    "rischiarai": "rischiarare",
    "rischiarammo": "rischiarare",
    "rischiaran": "rischiarare",
    "rischiarando": "rischiarare",
    "rischiarano": "rischiarare",
    "rischiarante": "rischiarare",
    "rischiaranti": "rischiarare",
    "rischiarar": "rischiarare",
    "rischiararon": "rischiarare",
    "rischiararono": "rischiarare",
    "rischiarasse": "rischiarare",
    "rischiarasser": "rischiarare",
    "rischiarassero": "rischiarare",
    "rischiarassi": "rischiarare",
    "rischiarassimo": "rischiarare",
    "rischiaraste": "rischiarare",
    "rischiarasti": "rischiarare",
    "rischiarata": "rischiarare",
    "rischiarate": "rischiarare",
    "rischiarati": "rischiarare",
    "rischiarato": "rischiarare",
    "rischiarava": "rischiarare",
    "rischiaravamo": "rischiarare",
    "rischiaravan": "rischiarare",
    "rischiaravano": "rischiarare",
    "rischiaravate": "rischiarare",
    "rischiaravi": "rischiarare",
    "rischiaravo": "rischiarare",
    "rischiarerai": "rischiarare",
    "rischiareran": "rischiarare",
    "rischiareranno": "rischiarare",
    "rischiarerebbe": "rischiarare",
    "rischiarerebber": "rischiarare",
    "rischiarerebbero": "rischiarare",
    "rischiarerei": "rischiarare",
    "rischiareremmo": "rischiarare",
    "rischiareremo": "rischiarare",
    "rischiarereste": "rischiarare",
    "rischiareresti": "rischiarare",
    "rischiarerete": "rischiarare",
    "rischiarerà": "rischiarare",
    "rischiarerò": "rischiarare",
    "rischiari": "rischiarare",
    "rischiariamo": "rischiarare",
    "rischiariate": "rischiarare",
    "rischiarin": "rischiarare",
    "rischiarino": "rischiarare",
    "rischiaro": "rischiarare",
    "rischiaron": "rischiare",
    "rischiarono": "rischiare",
    "rischiarò": "rischiarare",
    "rischiasse": "rischiare",
    "rischiasser": "rischiare",
    "rischiassero": "rischiare",
    "rischiassi": "rischiare",
    "rischiassimo": "rischiare",
    "rischiaste": "rischiare",
    "rischiasti": "rischiare",
    "rischiata": "rischiare",
    "rischiate": "rischiare",
    "rischiati": "rischiare",
    "rischiato": "rischiare",
    "rischiava": "rischiare",
    "rischiavamo": "rischiare",
    "rischiavan": "rischiare",
    "rischiavano": "rischiare",
    "rischiavate": "rischiare",
    "rischiavi": "rischiare",
    "rischiavo": "rischiare",
    "rischierai": "rischiare",
    "rischieran": "rischiare",
    "rischieranno": "rischiare",
    "rischierebbe": "rischiare",
    "rischierebber": "rischiare",
    "rischierebbero": "rischiare",
    "rischierei": "rischiare",
    "rischieremmo": "rischiare",
    "rischieremo": "rischiare",
    "rischiereste": "rischiare",
    "rischieresti": "rischiare",
    "rischierete": "rischiare",
    "rischierà": "rischiare",
    "rischierò": "rischiare",
    "rischin": "rischiare",
    "rischino": "rischiare",
    "rischio": "rischiare",
    "rischiosa": "rischioso",
    "rischiose": "rischioso",
    "rischiosi": "rischioso",
    "rischiò": "rischiare",
    "risciacqua": "risciacquare",
    "risciacquai": "risciacquare",
    "risciacquammo": "risciacquare",
    "risciacquan": "risciacquare",
    "risciacquando": "risciacquare",
    "risciacquano": "risciacquare",
    "risciacquante": "risciacquare",
    "risciacquanti": "risciacquare",
    "risciacquar": "risciacquare",
    "risciacquaron": "risciacquare",
    "risciacquarono": "risciacquare",
    "risciacquasse": "risciacquare",
    "risciacquasser": "risciacquare",
    "risciacquassero": "risciacquare",
    "risciacquassi": "risciacquare",
    "risciacquassimo": "risciacquare",
    "risciacquaste": "risciacquare",
    "risciacquasti": "risciacquare",
    "risciacquata": "risciacquare",
    "risciacquate": "risciacquare",
    "risciacquati": "risciacquare",
    "risciacquato": "risciacquare",
    "risciacquava": "risciacquare",
    "risciacquavamo": "risciacquare",
    "risciacquavan": "risciacquare",
    "risciacquavano": "risciacquare",
    "risciacquavate": "risciacquare",
    "risciacquavi": "risciacquare",
    "risciacquavo": "risciacquare",
    "risciacquerai": "risciacquare",
    "risciacqueran": "risciacquare",
    "risciacqueranno": "risciacquare",
    "risciacquerebbe": "risciacquare",
    "risciacquerebber": "risciacquare",
    "risciacquerebbero": "risciacquare",
    "risciacquerei": "risciacquare",
    "risciacqueremmo": "risciacquare",
    "risciacqueremo": "risciacquare",
    "risciacquereste": "risciacquare",
    "risciacqueresti": "risciacquare",
    "risciacquerete": "risciacquare",
    "risciacquerà": "risciacquare",
    "risciacquerò": "risciacquare",
    "risciacqui": "risciacquare",
    "risciacquiamo": "risciacquare",
    "risciacquiate": "risciacquare",
    "risciacquin": "risciacquare",
    "risciacquino": "risciacquare",
    "risciacquo": "risciacquare",
    "risciacquò": "risciacquare",
    "risciogli": "risciogliere",
    "risciogliamo": "risciogliere",
    "risciogliate": "risciogliere",
    "riscioglie": "risciogliere",
    "risciogliemmo": "risciogliere",
    "risciogliendo": "risciogliere",
    "risciogliente": "risciogliere",
    "riscioglienti": "risciogliere",
    "riscioglier": "risciogliere",
    "riscioglierai": "risciogliere",
    "riscioglieran": "risciogliere",
    "riscioglieranno": "risciogliere",
    "riscioglierebbe": "risciogliere",
    "riscioglierebber": "risciogliere",
    "riscioglierebbero": "risciogliere",
    "riscioglierei": "risciogliere",
    "riscioglieremmo": "risciogliere",
    "riscioglieremo": "risciogliere",
    "risciogliereste": "risciogliere",
    "riscioglieresti": "risciogliere",
    "riscioglierete": "risciogliere",
    "riscioglierà": "risciogliere",
    "riscioglierò": "risciogliere",
    "risciogliesse": "risciogliere",
    "risciogliesser": "risciogliere",
    "risciogliessero": "risciogliere",
    "risciogliessi": "risciogliere",
    "risciogliessimo": "risciogliere",
    "riscioglieste": "risciogliere",
    "risciogliesti": "risciogliere",
    "risciogliete": "risciogliere",
    "riscioglieva": "risciogliere",
    "riscioglievamo": "risciogliere",
    "riscioglievan": "risciogliere",
    "riscioglievano": "risciogliere",
    "riscioglievate": "risciogliere",
    "riscioglievi": "risciogliere",
    "riscioglievo": "risciogliere",
    "risciolga": "risciogliere",
    "risciolgan": "risciogliere",
    "risciolgano": "risciogliere",
    "risciolgo": "risciogliere",
    "risciolgon": "risciogliere",
    "risciolgono": "risciogliere",
    "risciolser": "risciogliere",
    "risciolsero": "risciogliere",
    "risciolsi": "risciogliere",
    "risciolsè": "risciogliere",
    "risciolta": "risciogliere",
    "risciolte": "risciogliere",
    "risciolti": "risciogliere",
    "risciolto": "risciogliere",
    "risconta": "riscontare",
    "riscontai": "riscontare",
    "riscontammo": "riscontare",
    "riscontan": "riscontare",
    "riscontando": "riscontare",
    "riscontano": "riscontare",
    "riscontante": "riscontare",
    "riscontanti": "riscontare",
    "riscontar": "riscontare",
    "riscontaron": "riscontare",
    "riscontarono": "riscontare",
    "riscontasse": "riscontare",
    "riscontasser": "riscontare",
    "riscontassero": "riscontare",
    "riscontassi": "riscontare",
    "riscontassimo": "riscontare",
    "riscontaste": "riscontare",
    "riscontasti": "riscontare",
    "riscontata": "riscontare",
    "riscontate": "riscontare",
    "riscontati": "riscontare",
    "riscontato": "riscontare",
    "riscontava": "riscontare",
    "riscontavamo": "riscontare",
    "riscontavan": "riscontare",
    "riscontavano": "riscontare",
    "riscontavate": "riscontare",
    "riscontavi": "riscontare",
    "riscontavo": "riscontare",
    "risconterai": "riscontare",
    "risconteran": "riscontare",
    "risconteranno": "riscontare",
    "risconterebbe": "riscontare",
    "risconterebber": "riscontare",
    "risconterebbero": "riscontare",
    "risconterei": "riscontare",
    "risconteremmo": "riscontare",
    "risconteremo": "riscontare",
    "riscontereste": "riscontare",
    "risconteresti": "riscontare",
    "risconterete": "riscontare",
    "risconterà": "riscontare",
    "risconterò": "riscontare",
    "risconti": "riscontare",
    "riscontiamo": "riscontare",
    "riscontiate": "riscontare",
    "riscontin": "riscontare",
    "riscontino": "riscontare",
    "risconto": "riscontare",
    "riscontra": "riscontrare",
    "riscontrabili": "riscontrabile",
    "riscontrai": "riscontrare",
    "riscontrammo": "riscontrare",
    "riscontran": "riscontrare",
    "riscontrando": "riscontrare",
    "riscontrano": "riscontrare",
    "riscontrante": "riscontrare",
    "riscontranti": "riscontrare",
    "riscontrar": "riscontrare",
    "riscontraron": "riscontrare",
    "riscontrarono": "riscontrare",
    "riscontrasse": "riscontrare",
    "riscontrasser": "riscontrare",
    "riscontrassero": "riscontrare",
    "riscontrassi": "riscontrare",
    "riscontrassimo": "riscontrare",
    "riscontraste": "riscontrare",
    "riscontrasti": "riscontrare",
    "riscontrata": "riscontrare",
    "riscontrate": "riscontrare",
    "riscontrati": "riscontrare",
    "riscontrato": "riscontrare",
    "riscontrava": "riscontrare",
    "riscontravamo": "riscontrare",
    "riscontravan": "riscontrare",
    "riscontravano": "riscontrare",
    "riscontravate": "riscontrare",
    "riscontravi": "riscontrare",
    "riscontravo": "riscontrare",
    "riscontrerai": "riscontrare",
    "riscontreran": "riscontrare",
    "riscontreranno": "riscontrare",
    "riscontrerebbe": "riscontrare",
    "riscontrerebber": "riscontrare",
    "riscontrerebbero": "riscontrare",
    "riscontrerei": "riscontrare",
    "riscontreremmo": "riscontrare",
    "riscontreremo": "riscontrare",
    "riscontrereste": "riscontrare",
    "riscontreresti": "riscontrare",
    "riscontrerete": "riscontrare",
    "riscontrerà": "riscontrare",
    "riscontrerò": "riscontrare",
    "riscontri": "riscontro",
    "riscontriamo": "riscontrare",
    "riscontriate": "riscontrare",
    "riscontrin": "riscontrare",
    "riscontrino": "riscontrare",
    "riscontro": "riscontrare",
    "riscontrò": "riscontrare",
    "riscontò": "riscontare",
    "riscoperta": "riscoprire",
    "riscoperte": "riscoprire",
    "riscoperti": "riscoprire",
    "riscoperto": "riscoprire",
    "riscopra": "riscoprire",
    "riscopran": "riscoprire",
    "riscoprano": "riscoprire",
    "riscopre": "riscoprire",
    "riscoprendo": "riscoprire",
    "riscoprente": "riscoprire",
    "riscoprenti": "riscoprire",
    "riscopri": "riscoprire",
    "riscopriamo": "riscoprire",
    "riscopriate": "riscoprire",
    "riscoprii": "riscoprire",
    "riscoprimmo": "riscoprire",
    "riscoprir": "riscoprire",
    "riscoprirai": "riscoprire",
    "riscopriran": "riscoprire",
    "riscopriranno": "riscoprire",
    "riscoprirebbe": "riscoprire",
    "riscoprirebber": "riscoprire",
    "riscoprirebbero": "riscoprire",
    "riscoprirei": "riscoprire",
    "riscopriremmo": "riscoprire",
    "riscopriremo": "riscoprire",
    "riscoprireste": "riscoprire",
    "riscopriresti": "riscoprire",
    "riscoprirete": "riscoprire",
    "riscopriron": "riscoprire",
    "riscoprirono": "riscoprire",
    "riscoprirà": "riscoprire",
    "riscoprirò": "riscoprire",
    "riscoprisse": "riscoprire",
    "riscoprisser": "riscoprire",
    "riscoprissero": "riscoprire",
    "riscoprissi": "riscoprire",
    "riscoprissimo": "riscoprire",
    "riscopriste": "riscoprire",
    "riscopristi": "riscoprire",
    "riscoprite": "riscoprire",
    "riscopriva": "riscoprire",
    "riscoprivamo": "riscoprire",
    "riscoprivan": "riscoprire",
    "riscoprivano": "riscoprire",
    "riscoprivate": "riscoprire",
    "riscoprivi": "riscoprire",
    "riscoprivo": "riscoprire",
    "riscopro": "riscoprire",
    "riscopron": "riscoprire",
    "riscoprono": "riscoprire",
    "riscoprì": "riscoprire",
    "riscorra": "riscorrere",
    "riscorran": "riscorrere",
    "riscorrano": "riscorrere",
    "riscorre": "riscorrere",
    "riscorrei": "riscorrere",
    "riscorremmo": "riscorrere",
    "riscorrendo": "riscorrere",
    "riscorrente": "riscorrere",
    "riscorrenti": "riscorrere",
    "riscorrer": "riscorrere",
    "riscorrerai": "riscorrere",
    "riscorreran": "riscorrere",
    "riscorreranno": "riscorrere",
    "riscorrerebbe": "riscorrere",
    "riscorrerebber": "riscorrere",
    "riscorrerebbero": "riscorrere",
    "riscorrerei": "riscorrere",
    "riscorreremmo": "riscorrere",
    "riscorreremo": "riscorrere",
    "riscorrereste": "riscorrere",
    "riscorreresti": "riscorrere",
    "riscorrerete": "riscorrere",
    "riscorreron": "riscorrere",
    "riscorrerono": "riscorrere",
    "riscorrerà": "riscorrere",
    "riscorrerò": "riscorrere",
    "riscorresse": "riscorrere",
    "riscorresser": "riscorrere",
    "riscorressero": "riscorrere",
    "riscorressi": "riscorrere",
    "riscorressimo": "riscorrere",
    "riscorreste": "riscorrere",
    "riscorresti": "riscorrere",
    "riscorrete": "riscorrere",
    "riscorreva": "riscorrere",
    "riscorrevamo": "riscorrere",
    "riscorrevan": "riscorrere",
    "riscorrevano": "riscorrere",
    "riscorrevate": "riscorrere",
    "riscorrevi": "riscorrere",
    "riscorrevo": "riscorrere",
    "riscorri": "riscorrere",
    "riscorriamo": "riscorrere",
    "riscorriate": "riscorrere",
    "riscorro": "riscorrere",
    "riscorron": "riscorrere",
    "riscorrono": "riscorrere",
    "riscorruta": "riscorrere",
    "riscorrute": "riscorrere",
    "riscorruti": "riscorrere",
    "riscorruto": "riscorrere",
    "riscorrè": "riscorrere",
    "riscossa": "riscuotere",
    "riscosse": "riscuotere",
    "riscosser": "riscuotere",
    "riscossero": "riscuotere",
    "riscossi": "riscuotere",
    "riscossioni": "riscossione",
    "riscosso": "riscuotere",
    "riscrisse": "riscrivere",
    "riscrisser": "riscrivere",
    "riscrissero": "riscrivere",
    "riscrissi": "riscrivere",
    "riscritta": "riscrivere",
    "riscritte": "riscrivere",
    "riscritti": "riscrivere",
    "riscritto": "riscrivere",
    "riscritture": "riscrittura",
    "riscriva": "riscrivere",
    "riscrivan": "riscrivere",
    "riscrivano": "riscrivere",
    "riscrive": "riscrivere",
    "riscrivemmo": "riscrivere",
    "riscrivendo": "riscrivere",
    "riscrivente": "riscrivere",
    "riscriventi": "riscrivere",
    "riscriver": "riscrivere",
    "riscriverai": "riscrivere",
    "riscriveran": "riscrivere",
    "riscriveranno": "riscrivere",
    "riscriverebbe": "riscrivere",
    "riscriverebber": "riscrivere",
    "riscriverebbero": "riscrivere",
    "riscriverei": "riscrivere",
    "riscriveremmo": "riscrivere",
    "riscriveremo": "riscrivere",
    "riscrivereste": "riscrivere",
    "riscriveresti": "riscrivere",
    "riscriverete": "riscrivere",
    "riscriverà": "riscrivere",
    "riscriverò": "riscrivere",
    "riscrivesse": "riscrivere",
    "riscrivesser": "riscrivere",
    "riscrivessero": "riscrivere",
    "riscrivessi": "riscrivere",
    "riscrivessimo": "riscrivere",
    "riscriveste": "riscrivere",
    "riscrivesti": "riscrivere",
    "riscrivete": "riscrivere",
    "riscriveva": "riscrivere",
    "riscrivevamo": "riscrivere",
    "riscrivevan": "riscrivere",
    "riscrivevano": "riscrivere",
    "riscrivevate": "riscrivere",
    "riscrivevi": "riscrivere",
    "riscrivevo": "riscrivere",
    "riscrivi": "riscrivere",
    "riscriviamo": "riscrivere",
    "riscriviate": "riscrivere",
    "riscrivo": "riscrivere",
    "riscrivon": "riscrivere",
    "riscrivono": "riscrivere",
    "riscuota": "riscuotere",
    "riscuotan": "riscuotere",
    "riscuotano": "riscuotere",
    "riscuote": "riscuotere",
    "riscuotemmo": "riscuotere",
    "riscuoter": "riscuotere",
    "riscuoterai": "riscuotere",
    "riscuoteran": "riscuotere",
    "riscuoteranno": "riscuotere",
    "riscuoterebbe": "riscuotere",
    "riscuoterebber": "riscuotere",
    "riscuoterebbero": "riscuotere",
    "riscuoterei": "riscuotere",
    "riscuoteremmo": "riscuotere",
    "riscuoteremo": "riscuotere",
    "riscuotereste": "riscuotere",
    "riscuoteresti": "riscuotere",
    "riscuoterete": "riscuotere",
    "riscuoterà": "riscuotere",
    "riscuoterò": "riscuotere",
    "riscuotesse": "riscuotere",
    "riscuotessero": "riscuotere",
    "riscuotessi": "riscuotere",
    "riscuotessimo": "riscuotere",
    "riscuoteste": "riscuotere",
    "riscuotesti": "riscuotere",
    "riscuoteva": "riscuotere",
    "riscuotevamo": "riscuotere",
    "riscuotevano": "riscuotere",
    "riscuotevate": "riscuotere",
    "riscuotevi": "riscuotere",
    "riscuotevo": "riscuotere",
    "riscuoti": "riscuotere",
    "riscuotiamo": "riscuotere",
    "riscuotiate": "riscuotere",
    "riscuoto": "riscuotere",
    "riscuoton": "riscuotere",
    "riscuotono": "riscuotere",
    "rise": "ridere",
    "riseca": "risecare",
    "risecai": "risecare",
    "risecammo": "risecare",
    "risecan": "risecare",
    "risecando": "risecare",
    "risecano": "risecare",
    "risecante": "risecare",
    "risecanti": "risecare",
    "risecar": "risecare",
    "risecaron": "risecare",
    "risecarono": "risecare",
    "risecasse": "risecare",
    "risecasser": "risecare",
    "risecassero": "risecare",
    "risecassi": "risecare",
    "risecassimo": "risecare",
    "risecaste": "risecare",
    "risecasti": "risecare",
    "risecata": "risecare",
    "risecate": "risecare",
    "risecati": "risecare",
    "risecato": "risecare",
    "risecava": "risecare",
    "risecavamo": "risecare",
    "risecavan": "risecare",
    "risecavano": "risecare",
    "risecavate": "risecare",
    "risecavi": "risecare",
    "risecavo": "risecare",
    "risecherai": "risecare",
    "risecheran": "risecare",
    "risecheranno": "risecare",
    "risecherebbe": "risecare",
    "risecherebber": "risecare",
    "risecherebbero": "risecare",
    "risecherei": "risecare",
    "risecheremmo": "risecare",
    "risecheremo": "risecare",
    "risechereste": "risecare",
    "risecheresti": "risecare",
    "risecherete": "risecare",
    "risecherà": "risecare",
    "risecherò": "risecare",
    "risechi": "risecare",
    "risechiamo": "risecare",
    "risechiate": "risecare",
    "risechin": "risecare",
    "risechino": "risecare",
    "riseco": "risecare",
    "risecò": "risecare",
    "risedano": "risedere",
    "risedei": "risedere",
    "risedemmo": "risedere",
    "riseder": "risedere",
    "risederai": "risedere",
    "risederanno": "risedere",
    "risederebbe": "risedere",
    "risederebbero": "risedere",
    "risederei": "risedere",
    "risederemmo": "risedere",
    "risederemo": "risedere",
    "risedereste": "risedere",
    "risederesti": "risedere",
    "risederete": "risedere",
    "risederon": "risedere",
    "risederono": "risedere",
    "risederà": "risedere",
    "risederò": "risedere",
    "risedesse": "risedere",
    "risedesser": "risedere",
    "risedessero": "risedere",
    "risedessi": "risedere",
    "risedessimo": "risedere",
    "risedeste": "risedere",
    "risedesti": "risedere",
    "risedete": "risedere",
    "risedeva": "risedere",
    "risedevamo": "risedere",
    "risedevano": "risedere",
    "risedevate": "risedere",
    "risedevi": "risedere",
    "risedevo": "risedere",
    "risediamo": "risedere",
    "risediate": "risedere",
    "riseduta": "risedere",
    "risedute": "risedere",
    "riseduti": "risedere",
    "riseduto": "risedere",
    "risedè": "risedere",
    "risei": "riessere",
    "risemina": "riseminare",
    "riseminai": "riseminare",
    "riseminammo": "riseminare",
    "riseminan": "riseminare",
    "riseminando": "riseminare",
    "riseminano": "riseminare",
    "riseminante": "riseminare",
    "riseminanti": "riseminare",
    "riseminar": "riseminare",
    "riseminaron": "riseminare",
    "riseminarono": "riseminare",
    "riseminasse": "riseminare",
    "riseminasser": "riseminare",
    "riseminassero": "riseminare",
    "riseminassi": "riseminare",
    "riseminassimo": "riseminare",
    "riseminaste": "riseminare",
    "riseminasti": "riseminare",
    "riseminata": "riseminare",
    "riseminate": "riseminare",
    "riseminati": "riseminare",
    "riseminato": "riseminare",
    "riseminava": "riseminare",
    "riseminavamo": "riseminare",
    "riseminavan": "riseminare",
    "riseminavano": "riseminare",
    "riseminavate": "riseminare",
    "riseminavi": "riseminare",
    "riseminavo": "riseminare",
    "riseminerai": "riseminare",
    "risemineran": "riseminare",
    "risemineranno": "riseminare",
    "riseminerebbe": "riseminare",
    "riseminerebber": "riseminare",
    "riseminerebbero": "riseminare",
    "riseminerei": "riseminare",
    "risemineremmo": "riseminare",
    "risemineremo": "riseminare",
    "riseminereste": "riseminare",
    "risemineresti": "riseminare",
    "riseminerete": "riseminare",
    "riseminerà": "riseminare",
    "riseminerò": "riseminare",
    "risemini": "riseminare",
    "riseminiamo": "riseminare",
    "riseminiate": "riseminare",
    "riseminin": "riseminare",
    "riseminino": "riseminare",
    "risemino": "riseminare",
    "riseminò": "riseminare",
    "risenta": "risentire",
    "risentan": "risentire",
    "risentano": "risentire",
    "risente": "risentire",
    "risentendo": "risentire",
    "risentente": "risentire",
    "risententi": "risentire",
    "risenti": "risentire",
    "risentiamo": "risentire",
    "risentiate": "risentire",
    "risentii": "risentire",
    "risentimenti": "risentimento",
    "risentimmo": "risentire",
    "risentir": "risentire",
    "risentirai": "risentire",
    "risentiran": "risentire",
    "risentiranno": "risentire",
    "risentirebbe": "risentire",
    "risentirebber": "risentire",
    "risentirebbero": "risentire",
    "risentirei": "risentire",
    "risentiremmo": "risentire",
    "risentiremo": "risentire",
    "risentireste": "risentire",
    "risentiresti": "risentire",
    "risentirete": "risentire",
    "risentiron": "risentire",
    "risentirono": "risentire",
    "risentirà": "risentire",
    "risentirò": "risentire",
    "risentisse": "risentire",
    "risentisser": "risentire",
    "risentissero": "risentire",
    "risentissi": "risentire",
    "risentissimo": "risentire",
    "risentiste": "risentire",
    "risentisti": "risentire",
    "risentita": "risentito",
    "risentite": "risentito",
    "risentiti": "risentito",
    "risentito": "risentire",
    "risentiva": "risentire",
    "risentivamo": "risentire",
    "risentivan": "risentire",
    "risentivano": "risentire",
    "risentivate": "risentire",
    "risentivi": "risentire",
    "risentivo": "risentire",
    "risento": "risentire",
    "risenton": "risentire",
    "risentono": "risentire",
    "risentì": "risentire",
    "riseppe": "risapere",
    "risepper": "risapere",
    "riseppero": "risapere",
    "riseppi": "risapere",
    "riser": "ridere",
    "riserba": "riserbare",
    "riserbai": "riserbare",
    "riserbammo": "riserbare",
    "riserban": "riserbare",
    "riserbando": "riserbare",
    "riserbano": "riserbare",
    "riserbante": "riserbare",
    "riserbanti": "riserbare",
    "riserbar": "riserbare",
    "riserbaron": "riserbare",
    "riserbarono": "riserbare",
    "riserbasse": "riserbare",
    "riserbasser": "riserbare",
    "riserbassero": "riserbare",
    "riserbassi": "riserbare",
    "riserbassimo": "riserbare",
    "riserbaste": "riserbare",
    "riserbasti": "riserbare",
    "riserbata": "riserbare",
    "riserbate": "riserbare",
    "riserbati": "riserbare",
    "riserbato": "riserbare",
    "riserbava": "riserbare",
    "riserbavamo": "riserbare",
    "riserbavan": "riserbare",
    "riserbavano": "riserbare",
    "riserbavate": "riserbare",
    "riserbavi": "riserbare",
    "riserbavo": "riserbare",
    "riserberai": "riserbare",
    "riserberan": "riserbare",
    "riserberanno": "riserbare",
    "riserberebbe": "riserbare",
    "riserberebber": "riserbare",
    "riserberebbero": "riserbare",
    "riserberei": "riserbare",
    "riserberemmo": "riserbare",
    "riserberemo": "riserbare",
    "riserbereste": "riserbare",
    "riserberesti": "riserbare",
    "riserberete": "riserbare",
    "riserberà": "riserbare",
    "riserberò": "riserbare",
    "riserbi": "riserbo",
    "riserbiamo": "riserbare",
    "riserbiate": "riserbare",
    "riserbin": "riserbare",
    "riserbino": "riserbare",
    "riserbo": "riserbare",
    "riserbò": "riserbare",
    "risero": "ridere",
    "riserva": "riservare",
    "riservai": "riservare",
    "riservammo": "riservare",
    "riservan": "riservare",
    "riservando": "riservare",
    "riservano": "riservare",
    "riservante": "riservare",
    "riservanti": "riservare",
    "riservar": "riservare",
    "riservaron": "riservare",
    "riservarono": "riservare",
    "riservasse": "riservare",
    "riservasser": "riservare",
    "riservassero": "riservare",
    "riservassi": "riservare",
    "riservassimo": "riservare",
    "riservaste": "riservare",
    "riservasti": "riservare",
    "riservata": "riservato",
    "riservate": "riservato",
    "riservatezze": "riservatezza",
    "riservati": "riservato",
    "riservato": "riservare",
    "riservava": "riservare",
    "riservavamo": "riservare",
    "riservavan": "riservare",
    "riservavano": "riservare",
    "riservavate": "riservare",
    "riservavi": "riservare",
    "riservavo": "riservare",
    "riserve": "riserva",
    "riserverai": "riservare",
    "riserveran": "riservare",
    "riserveranno": "riservare",
    "riserverebbe": "riservare",
    "riserverebber": "riservare",
    "riserverebbero": "riservare",
    "riserverei": "riservare",
    "riserveremmo": "riservare",
    "riserveremo": "riservare",
    "riservereste": "riservare",
    "riserveresti": "riservare",
    "riserverete": "riservare",
    "riserverà": "riservare",
    "riserverò": "riservare",
    "riservi": "riservare",
    "riserviamo": "riservare",
    "riserviate": "riservare",
    "riservin": "riservare",
    "riservino": "riservare",
    "riservisti": "riservista",
    "riservo": "riservare",
    "riservò": "riservare",
    "risi": "riso",
    "risia": "riessere",
    "risiamo": "riessere",
    "risian": "riessere",
    "risiano": "riessere",
    "risiate": "riessere",
    "risibili": "risibile",
    "risicata": "risicato",
    "risicate": "risicato",
    "risicati": "risicato",
    "risieda": "risiedere",
    "risiedan": "risiedere",
    "risiedano": "risiedere",
    "risiede": "risiedere",
    "risiedei": "risiedere",
    "risiedemmo": "risiedere",
    "risiedendo": "risiedere",
    "risiedente": "risiedere",
    "risiedenti": "risiedere",
    "risieder": "risiedere",
    "risiederai": "risiedere",
    "risiederan": "risiedere",
    "risiederanno": "risiedere",
    "risiederebbe": "risiedere",
    "risiederebber": "risiedere",
    "risiederebbero": "risiedere",
    "risiederei": "risiedere",
    "risiederemmo": "risiedere",
    "risiederemo": "risiedere",
    "risiedereste": "risiedere",
    "risiederesti": "risiedere",
    "risiederete": "risiedere",
    "risiederon": "risiedere",
    "risiederono": "risiedere",
    "risiederà": "risiedere",
    "risiederò": "risiedere",
    "risiedesse": "risiedere",
    "risiedesser": "risiedere",
    "risiedessero": "risiedere",
    "risiedessi": "risiedere",
    "risiedessimo": "risiedere",
    "risiedeste": "risiedere",
    "risiedesti": "risiedere",
    "risiedete": "risiedere",
    "risiedeva": "risiedere",
    "risiedevamo": "risiedere",
    "risiedevan": "risiedere",
    "risiedevano": "risiedere",
    "risiedevate": "risiedere",
    "risiedevi": "risiedere",
    "risiedevo": "risiedere",
    "risiedi": "risiedere",
    "risiediamo": "risiedere",
    "risiediate": "risiedere",
    "risiedo": "risiedere",
    "risiedon": "risiedere",
    "risiedono": "risiedere",
    "risieduta": "risiedere",
    "risiedute": "risiedere",
    "risieduti": "risiedere",
    "risieduto": "risiedere",
    "risiedè": "risiedere",
    "risiete": "riessere",
    "risii": "riessere",
    "risistema": "risistemare",
    "risistemai": "risistemare",
    "risistemammo": "risistemare",
    "risisteman": "risistemare",
    "risistemando": "risistemare",
    "risistemano": "risistemare",
    "risistemante": "risistemare",
    "risistemanti": "risistemare",
    "risistemar": "risistemare",
    "risistemaron": "risistemare",
    "risistemarono": "risistemare",
    "risistemasse": "risistemare",
    "risistemasser": "risistemare",
    "risistemassero": "risistemare",
    "risistemassi": "risistemare",
    "risistemassimo": "risistemare",
    "risistemaste": "risistemare",
    "risistemasti": "risistemare",
    "risistemata": "risistemare",
    "risistemate": "risistemare",
    "risistemati": "risistemare",
    "risistemato": "risistemare",
    "risistemava": "risistemare",
    "risistemavamo": "risistemare",
    "risistemavan": "risistemare",
    "risistemavano": "risistemare",
    "risistemavate": "risistemare",
    "risistemavi": "risistemare",
    "risistemavo": "risistemare",
    "risistemazioni": "risistemazione",
    "risistemerai": "risistemare",
    "risistemeran": "risistemare",
    "risistemeranno": "risistemare",
    "risistemerebbe": "risistemare",
    "risistemerebber": "risistemare",
    "risistemerebbero": "risistemare",
    "risistemerei": "risistemare",
    "risistemeremmo": "risistemare",
    "risistemeremo": "risistemare",
    "risistemereste": "risistemare",
    "risistemeresti": "risistemare",
    "risistemerete": "risistemare",
    "risistemerà": "risistemare",
    "risistemerò": "risistemare",
    "risistemi": "risistemare",
    "risistemiamo": "risistemare",
    "risistemiate": "risistemare",
    "risistemin": "risistemare",
    "risistemino": "risistemare",
    "risistemo": "risistemare",
    "risistemò": "risistemare",
    "riso": "risapere",
    "risola": "risolare",
    "risolai": "risolare",
    "risolammo": "risolare",
    "risolan": "risolare",
    "risolando": "risolare",
    "risolano": "risolare",
    "risolante": "risolare",
    "risolanti": "risolare",
    "risolar": "risolare",
    "risolaron": "risolare",
    "risolarono": "risolare",
    "risolasse": "risolare",
    "risolasser": "risolare",
    "risolassero": "risolare",
    "risolassi": "risolare",
    "risolassimo": "risolare",
    "risolaste": "risolare",
    "risolasti": "risolare",
    "risolata": "risolare",
    "risolate": "risolare",
    "risolati": "risolare",
    "risolato": "risolare",
    "risolava": "risolare",
    "risolavamo": "risolare",
    "risolavan": "risolare",
    "risolavano": "risolare",
    "risolavate": "risolare",
    "risolavi": "risolare",
    "risolavo": "risolare",
    "risolerai": "risolare",
    "risoleran": "risolare",
    "risoleranno": "risolare",
    "risolerebbe": "risolare",
    "risolerebber": "risolare",
    "risolerebbero": "risolare",
    "risolerei": "risolare",
    "risoleremmo": "risolare",
    "risoleremo": "risolare",
    "risolereste": "risolare",
    "risoleresti": "risolare",
    "risolerete": "risolare",
    "risolerà": "risolare",
    "risolerò": "risolare",
    "risoli": "risolare",
    "risoliamo": "risolare",
    "risoliate": "risolare",
    "risolin": "risolare",
    "risolini": "risolino",
    "risolino": "risolare",
    "risolleva": "risollevare",
    "risollevai": "risollevare",
    "risollevammo": "risollevare",
    "risollevan": "risollevare",
    "risollevando": "risollevare",
    "risollevano": "risollevare",
    "risollevante": "risollevare",
    "risollevanti": "risollevare",
    "risollevar": "risollevare",
    "risollevaron": "risollevare",
    "risollevarono": "risollevare",
    "risollevasse": "risollevare",
    "risollevasser": "risollevare",
    "risollevassero": "risollevare",
    "risollevassi": "risollevare",
    "risollevassimo": "risollevare",
    "risollevaste": "risollevare",
    "risollevasti": "risollevare",
    "risollevata": "risollevare",
    "risollevate": "risollevare",
    "risollevati": "risollevare",
    "risollevato": "risollevare",
    "risollevava": "risollevare",
    "risollevavamo": "risollevare",
    "risollevavan": "risollevare",
    "risollevavano": "risollevare",
    "risollevavate": "risollevare",
    "risollevavi": "risollevare",
    "risollevavo": "risollevare",
    "risolleverai": "risollevare",
    "risolleveran": "risollevare",
    "risolleveranno": "risollevare",
    "risolleverebbe": "risollevare",
    "risolleverebber": "risollevare",
    "risolleverebbero": "risollevare",
    "risolleverei": "risollevare",
    "risolleveremmo": "risollevare",
    "risolleveremo": "risollevare",
    "risollevereste": "risollevare",
    "risolleveresti": "risollevare",
    "risolleverete": "risollevare",
    "risolleverà": "risollevare",
    "risolleverò": "risollevare",
    "risollevi": "risollevare",
    "risolleviamo": "risollevare",
    "risolleviate": "risollevare",
    "risollevin": "risollevare",
    "risollevino": "risollevare",
    "risollevo": "risollevare",
    "risollevò": "risollevare",
    "risolo": "risolare",
    "risolse": "risolvere",
    "risolser": "risolvere",
    "risolsero": "risolvere",
    "risolsi": "risolvere",
    "risolta": "risolvere",
    "risolte": "risolvere",
    "risolti": "risolvere",
    "risolto": "risolvere",
    "risoluta": "risoluto",
    "risolute": "risoluto",
    "risolutezze": "risolutezza",
    "risoluti": "risoluto",
    "risolutiva": "risolutivo",
    "risolutive": "risolutivo",
    "risolutivi": "risolutivo",
    "risoluzioni": "risoluzione",
    "risolva": "risolvere",
    "risolvan": "risolvere",
    "risolvano": "risolvere",
    "risolve": "risolvere",
    "risolvemmo": "risolvere",
    "risolvendo": "risolvere",
    "risolvente": "risolvere",
    "risolventi": "risolvere",
    "risolver": "risolvere",
    "risolverai": "risolvere",
    "risolveran": "risolvere",
    "risolveranno": "risolvere",
    "risolverebbe": "risolvere",
    "risolverebber": "risolvere",
    "risolverebbero": "risolvere",
    "risolverei": "risolvere",
    "risolveremmo": "risolvere",
    "risolveremo": "risolvere",
    "risolvereste": "risolvere",
    "risolveresti": "risolvere",
    "risolverete": "risolvere",
    "risolverà": "risolvere",
    "risolverò": "risolvere",
    "risolvesse": "risolvere",
    "risolvesser": "risolvere",
    "risolvessero": "risolvere",
    "risolvessi": "risolvere",
    "risolvessimo": "risolvere",
    "risolveste": "risolvere",
    "risolvesti": "risolvere",
    "risolvete": "risolvere",
    "risolveva": "risolvere",
    "risolvevamo": "risolvere",
    "risolvevan": "risolvere",
    "risolvevano": "risolvere",
    "risolvevate": "risolvere",
    "risolvevi": "risolvere",
    "risolvevo": "risolvere",
    "risolvi": "risolvere",
    "risolviamo": "risolvere",
    "risolviate": "risolvere",
    "risolvibili": "risolvibile",
    "risolvo": "risolvere",
    "risolvon": "risolvere",
    "risolvono": "risolvere",
    "risolò": "risolare",
    "rison": "riessere",
    "risona": "risonare",
    "risonai": "risonare",
    "risonammo": "risonare",
    "risonan": "risonare",
    "risonando": "risonare",
    "risonano": "risonare",
    "risonante": "risonare",
    "risonanti": "risonare",
    "risonanze": "risonanza",
    "risonar": "risonare",
    "risonaron": "risonare",
    "risonarono": "risonare",
    "risonasse": "risonare",
    "risonasser": "risonare",
    "risonassero": "risonare",
    "risonassi": "risonare",
    "risonassimo": "risonare",
    "risonaste": "risonare",
    "risonasti": "risonare",
    "risonata": "risonare",
    "risonate": "risonare",
    "risonati": "risonare",
    "risonato": "risonare",
    "risonava": "risonare",
    "risonavamo": "risonare",
    "risonavan": "risonare",
    "risonavano": "risonare",
    "risonavate": "risonare",
    "risonavi": "risonare",
    "risonavo": "risonare",
    "risonerai": "risonare",
    "risoneran": "risonare",
    "risoneranno": "risonare",
    "risonerebbe": "risonare",
    "risonerebber": "risonare",
    "risonerebbero": "risonare",
    "risonerei": "risonare",
    "risoneremmo": "risonare",
    "risoneremo": "risonare",
    "risonereste": "risonare",
    "risoneresti": "risonare",
    "risonerete": "risonare",
    "risonerà": "risonare",
    "risonerò": "risonare",
    "risoni": "risonare",
    "risoniamo": "risonare",
    "risoniate": "risonare",
    "risonin": "risonare",
    "risonino": "risonare",
    "risono": "risonare",
    "risonò": "risonare",
    "risorga": "risorgere",
    "risorgan": "risorgere",
    "risorgano": "risorgere",
    "risorge": "risorgere",
    "risorgemmo": "risorgere",
    "risorgendo": "risorgere",
    "risorgente": "risorgere",
    "risorgenti": "risorgere",
    "risorger": "risorgere",
    "risorgerai": "risorgere",
    "risorgeran": "risorgere",
    "risorgeranno": "risorgere",
    "risorgerebbe": "risorgere",
    "risorgerebber": "risorgere",
    "risorgerebbero": "risorgere",
    "risorgerei": "risorgere",
    "risorgeremmo": "risorgere",
    "risorgeremo": "risorgere",
    "risorgereste": "risorgere",
    "risorgeresti": "risorgere",
    "risorgerete": "risorgere",
    "risorgerà": "risorgere",
    "risorgerò": "risorgere",
    "risorgesse": "risorgere",
    "risorgesser": "risorgere",
    "risorgessero": "risorgere",
    "risorgessi": "risorgere",
    "risorgessimo": "risorgere",
    "risorgeste": "risorgere",
    "risorgesti": "risorgere",
    "risorgete": "risorgere",
    "risorgeva": "risorgere",
    "risorgevamo": "risorgere",
    "risorgevan": "risorgere",
    "risorgevano": "risorgere",
    "risorgevate": "risorgere",
    "risorgevi": "risorgere",
    "risorgevo": "risorgere",
    "risorgi": "risorgere",
    "risorgiamo": "risorgere",
    "risorgiate": "risorgere",
    "risorgimentali": "risorgimentale",
    "risorgimenti": "risorgimento",
    "risorgo": "risorgere",
    "risorgon": "risorgere",
    "risorgono": "risorgere",
    "risorse": "risorsa",
    "risorser": "risorgere",
    "risorsero": "risorgere",
    "risorsi": "risorgere",
    "risorta": "risorgere",
    "risorte": "risorgere",
    "risorti": "risorto",
    "risorto": "risorgere",
    "risospinga": "risospingere",
    "risospingan": "risospingere",
    "risospingano": "risospingere",
    "risospinge": "risospingere",
    "risospingemmo": "risospingere",
    "risospingendo": "risospingere",
    "risospingente": "risospingere",
    "risospingenti": "risospingere",
    "risospinger": "risospingere",
    "risospingerai": "risospingere",
    "risospingeran": "risospingere",
    "risospingeranno": "risospingere",
    "risospingerebbe": "risospingere",
    "risospingerebber": "risospingere",
    "risospingerebbero": "risospingere",
    "risospingerei": "risospingere",
    "risospingeremmo": "risospingere",
    "risospingeremo": "risospingere",
    "risospingereste": "risospingere",
    "risospingeresti": "risospingere",
    "risospingerete": "risospingere",
    "risospingerà": "risospingere",
    "risospingerò": "risospingere",
    "risospingesse": "risospingere",
    "risospingesser": "risospingere",
    "risospingessero": "risospingere",
    "risospingessi": "risospingere",
    "risospingessimo": "risospingere",
    "risospingeste": "risospingere",
    "risospingesti": "risospingere",
    "risospingete": "risospingere",
    "risospingeva": "risospingere",
    "risospingevamo": "risospingere",
    "risospingevan": "risospingere",
    "risospingevano": "risospingere",
    "risospingevate": "risospingere",
    "risospingevi": "risospingere",
    "risospingevo": "risospingere",
    "risospingi": "risospingere",
    "risospingiamo": "risospingere",
    "risospingiate": "risospingere",
    "risospingo": "risospingere",
    "risospingon": "risospingere",
    "risospingono": "risospingere",
    "risospinser": "risospingere",
    "risospinsero": "risospingere",
    "risospinsi": "risospingere",
    "risospinsè": "risospingere",
    "risospinta": "risospingere",
    "risospinte": "risospingere",
    "risospinti": "risospingere",
    "risospinto": "risospingere",
    "risostene": "risostenere",
    "risostenei": "risostenere",
    "risostenemmo": "risostenere",
    "risostenendo": "risostenere",
    "risostenente": "risostenere",
    "risostenenti": "risostenere",
    "risostener": "risostenere",
    "risostenerai": "risostenere",
    "risosteneran": "risostenere",
    "risosteneranno": "risostenere",
    "risostenerebbe": "risostenere",
    "risostenerebber": "risostenere",
    "risostenerebbero": "risostenere",
    "risostenerei": "risostenere",
    "risosteneremmo": "risostenere",
    "risosteneremo": "risostenere",
    "risostenereste": "risostenere",
    "risosteneresti": "risostenere",
    "risostenerete": "risostenere",
    "risosteneron": "risostenere",
    "risostenerono": "risostenere",
    "risostenerà": "risostenere",
    "risostenerò": "risostenere",
    "risostenesse": "risostenere",
    "risostenesser": "risostenere",
    "risostenessero": "risostenere",
    "risostenessi": "risostenere",
    "risostenessimo": "risostenere",
    "risosteneste": "risostenere",
    "risostenesti": "risostenere",
    "risostenete": "risostenere",
    "risosteneva": "risostenere",
    "risostenevamo": "risostenere",
    "risostenevan": "risostenere",
    "risostenevano": "risostenere",
    "risostenevate": "risostenere",
    "risostenevi": "risostenere",
    "risostenevo": "risostenere",
    "risostenga": "risostenere",
    "risostengan": "risostenere",
    "risostengano": "risostenere",
    "risostengo": "risostenere",
    "risostengon": "risostenere",
    "risostengono": "risostenere",
    "risosteni": "risostenere",
    "risosteniamo": "risostenere",
    "risosteniate": "risostenere",
    "risostenuta": "risostenere",
    "risostenute": "risostenere",
    "risostenuti": "risostenere",
    "risostenuto": "risostenere",
    "risostenè": "risostenere",
    "risotti": "risotto",
    "risparmi": "risparmio",
    "risparmia": "risparmiare",
    "risparmiai": "risparmiare",
    "risparmiammo": "risparmiare",
    "risparmiamo": "risparmiare",
    "risparmian": "risparmiare",
    "risparmiando": "risparmiare",
    "risparmiano": "risparmiare",
    "risparmiante": "risparmiare",
    "risparmianti": "risparmiare",
    "risparmiar": "risparmiare",
    "risparmiaron": "risparmiare",
    "risparmiarono": "risparmiare",
    "risparmiasse": "risparmiare",
    "risparmiasser": "risparmiare",
    "risparmiassero": "risparmiare",
    "risparmiassi": "risparmiare",
    "risparmiassimo": "risparmiare",
    "risparmiaste": "risparmiare",
    "risparmiasti": "risparmiare",
    "risparmiata": "risparmiare",
    "risparmiate": "risparmiare",
    "risparmiati": "risparmiare",
    "risparmiato": "risparmiare",
    "risparmiatori": "risparmiatore",
    "risparmiava": "risparmiare",
    "risparmiavamo": "risparmiare",
    "risparmiavan": "risparmiare",
    "risparmiavano": "risparmiare",
    "risparmiavate": "risparmiare",
    "risparmiavi": "risparmiare",
    "risparmiavo": "risparmiare",
    "risparmierai": "risparmiare",
    "risparmieran": "risparmiare",
    "risparmieranno": "risparmiare",
    "risparmierebbe": "risparmiare",
    "risparmierebber": "risparmiare",
    "risparmierebbero": "risparmiare",
    "risparmierei": "risparmiare",
    "risparmieremmo": "risparmiare",
    "risparmieremo": "risparmiare",
    "risparmiereste": "risparmiare",
    "risparmieresti": "risparmiare",
    "risparmierete": "risparmiare",
    "risparmierà": "risparmiare",
    "risparmierò": "risparmiare",
    "risparmin": "risparmiare",
    "risparmino": "risparmiare",
    "risparmio": "risparmiare",
    "risparmiò": "risparmiare",
    "rispecchi": "rispecchiare",
    "rispecchia": "rispecchiare",
    "rispecchiai": "rispecchiare",
    "rispecchiamenti": "rispecchiamento",
    "rispecchiammo": "rispecchiare",
    "rispecchiamo": "rispecchiare",
    "rispecchian": "rispecchiare",
    "rispecchiando": "rispecchiare",
    "rispecchiano": "rispecchiare",
    "rispecchiante": "rispecchiare",
    "rispecchianti": "rispecchiare",
    "rispecchiar": "rispecchiare",
    "rispecchiaron": "rispecchiare",
    "rispecchiarono": "rispecchiare",
    "rispecchiasse": "rispecchiare",
    "rispecchiasser": "rispecchiare",
    "rispecchiassero": "rispecchiare",
    "rispecchiassi": "rispecchiare",
    "rispecchiassimo": "rispecchiare",
    "rispecchiaste": "rispecchiare",
    "rispecchiasti": "rispecchiare",
    "rispecchiata": "rispecchiare",
    "rispecchiate": "rispecchiare",
    "rispecchiati": "rispecchiare",
    "rispecchiato": "rispecchiare",
    "rispecchiava": "rispecchiare",
    "rispecchiavamo": "rispecchiare",
    "rispecchiavan": "rispecchiare",
    "rispecchiavano": "rispecchiare",
    "rispecchiavate": "rispecchiare",
    "rispecchiavi": "rispecchiare",
    "rispecchiavo": "rispecchiare",
    "rispecchierai": "rispecchiare",
    "rispecchieran": "rispecchiare",
    "rispecchieranno": "rispecchiare",
    "rispecchierebbe": "rispecchiare",
    "rispecchierebber": "rispecchiare",
    "rispecchierebbero": "rispecchiare",
    "rispecchierei": "rispecchiare",
    "rispecchieremmo": "rispecchiare",
    "rispecchieremo": "rispecchiare",
    "rispecchiereste": "rispecchiare",
    "rispecchieresti": "rispecchiare",
    "rispecchierete": "rispecchiare",
    "rispecchierà": "rispecchiare",
    "rispecchierò": "rispecchiare",
    "rispecchin": "rispecchiare",
    "rispecchino": "rispecchiare",
    "rispecchio": "rispecchiare",
    "rispecchiò": "rispecchiare",
    "rispedendo": "rispedire",
    "rispedente": "rispedire",
    "rispedenti": "rispedire",
    "rispediamo": "rispedire",
    "rispediate": "rispedire",
    "rispedii": "rispedire",
    "rispedimmo": "rispedire",
    "rispedir": "rispedire",
    "rispedirai": "rispedire",
    "rispediran": "rispedire",
    "rispediranno": "rispedire",
    "rispedirebbe": "rispedire",
    "rispedirebber": "rispedire",
    "rispedirebbero": "rispedire",
    "rispedirei": "rispedire",
    "rispediremmo": "rispedire",
    "rispediremo": "rispedire",
    "rispedireste": "rispedire",
    "rispediresti": "rispedire",
    "rispedirete": "rispedire",
    "rispediron": "rispedire",
    "rispedirono": "rispedire",
    "rispedirà": "rispedire",
    "rispedirò": "rispedire",
    "rispedisca": "rispedire",
    "rispediscan": "rispedire",
    "rispediscano": "rispedire",
    "rispedisce": "rispedire",
    "rispedisci": "rispedire",
    "rispedisco": "rispedire",
    "rispediscon": "rispedire",
    "rispediscono": "rispedire",
    "rispedisse": "rispedire",
    "rispedisser": "rispedire",
    "rispedissero": "rispedire",
    "rispedissi": "rispedire",
    "rispedissimo": "rispedire",
    "rispediste": "rispedire",
    "rispedisti": "rispedire",
    "rispedita": "rispedire",
    "rispedite": "rispedire",
    "rispediti": "rispedire",
    "rispedito": "rispedire",
    "rispediva": "rispedire",
    "rispedivamo": "rispedire",
    "rispedivan": "rispedire",
    "rispedivano": "rispedire",
    "rispedivate": "rispedire",
    "rispedivi": "rispedire",
    "rispedivo": "rispedire",
    "rispedì": "rispedire",
    "rispetta": "rispettare",
    "rispettabili": "rispettabile",
    "rispettai": "rispettare",
    "rispettammo": "rispettare",
    "rispettan": "rispettare",
    "rispettando": "rispettare",
    "rispettano": "rispettare",
    "rispettante": "rispettare",
    "rispettanti": "rispettare",
    "rispettar": "rispettare",
    "rispettaron": "rispettare",
    "rispettarono": "rispettare",
    "rispettasse": "rispettare",
    "rispettasser": "rispettare",
    "rispettassero": "rispettare",
    "rispettassi": "rispettare",
    "rispettassimo": "rispettare",
    "rispettaste": "rispettare",
    "rispettasti": "rispettare",
    "rispettata": "rispettato",
    "rispettate": "rispettato",
    "rispettati": "rispettato",
    "rispettato": "rispettare",
    "rispettava": "rispettare",
    "rispettavamo": "rispettare",
    "rispettavan": "rispettare",
    "rispettavano": "rispettare",
    "rispettavate": "rispettare",
    "rispettavi": "rispettare",
    "rispettavo": "rispettare",
    "rispetterai": "rispettare",
    "rispetteran": "rispettare",
    "rispetteranno": "rispettare",
    "rispetterebbe": "rispettare",
    "rispetterebber": "rispettare",
    "rispetterebbero": "rispettare",
    "rispetterei": "rispettare",
    "rispetteremmo": "rispettare",
    "rispetteremo": "rispettare",
    "rispettereste": "rispettare",
    "rispetteresti": "rispettare",
    "rispetterete": "rispettare",
    "rispetterà": "rispettare",
    "rispetterò": "rispettare",
    "rispetti": "rispetto",
    "rispettiamo": "rispettare",
    "rispettiate": "rispettare",
    "rispettin": "rispettare",
    "rispettino": "rispettare",
    "rispettiva": "rispettivo",
    "rispettive": "rispettivo",
    "rispettivi": "rispettivo",
    "rispetto": "rispettare",
    "rispettosa": "rispettoso",
    "rispettose": "rispettoso",
    "rispettosi": "rispettoso",
    "rispettò": "rispettare",
    "rispiega": "rispiegare",
    "rispiegai": "rispiegare",
    "rispiegammo": "rispiegare",
    "rispiegan": "rispiegare",
    "rispiegando": "rispiegare",
    "rispiegano": "rispiegare",
    "rispiegante": "rispiegare",
    "rispieganti": "rispiegare",
    "rispiegar": "rispiegare",
    "rispiegaron": "rispiegare",
    "rispiegarono": "rispiegare",
    "rispiegasse": "rispiegare",
    "rispiegasser": "rispiegare",
    "rispiegassero": "rispiegare",
    "rispiegassi": "rispiegare",
    "rispiegassimo": "rispiegare",
    "rispiegaste": "rispiegare",
    "rispiegasti": "rispiegare",
    "rispiegata": "rispiegare",
    "rispiegate": "rispiegare",
    "rispiegati": "rispiegare",
    "rispiegato": "rispiegare",
    "rispiegava": "rispiegare",
    "rispiegavamo": "rispiegare",
    "rispiegavan": "rispiegare",
    "rispiegavano": "rispiegare",
    "rispiegavate": "rispiegare",
    "rispiegavi": "rispiegare",
    "rispiegavo": "rispiegare",
    "rispiegherai": "rispiegare",
    "rispiegheran": "rispiegare",
    "rispiegheranno": "rispiegare",
    "rispiegherebbe": "rispiegare",
    "rispiegherebber": "rispiegare",
    "rispiegherebbero": "rispiegare",
    "rispiegherei": "rispiegare",
    "rispiegheremmo": "rispiegare",
    "rispiegheremo": "rispiegare",
    "rispieghereste": "rispiegare",
    "rispiegheresti": "rispiegare",
    "rispiegherete": "rispiegare",
    "rispiegherà": "rispiegare",
    "rispiegherò": "rispiegare",
    "rispieghi": "rispiegare",
    "rispieghiamo": "rispiegare",
    "rispieghiate": "rispiegare",
    "rispieghin": "rispiegare",
    "rispieghino": "rispiegare",
    "rispiego": "rispiegare",
    "rispiegò": "rispiegare",
    "risplenda": "risplendere",
    "risplendan": "risplendere",
    "risplendano": "risplendere",
    "risplende": "risplendere",
    "risplendemmo": "risplendere",
    "risplendendo": "risplendere",
    "risplendente": "risplendere",
    "risplendenti": "risplendere",
    "risplender": "risplendere",
    "risplenderai": "risplendere",
    "risplenderan": "risplendere",
    "risplenderanno": "risplendere",
    "risplenderebbe": "risplendere",
    "risplenderebber": "risplendere",
    "risplenderebbero": "risplendere",
    "risplenderei": "risplendere",
    "risplenderemmo": "risplendere",
    "risplenderemo": "risplendere",
    "risplendereste": "risplendere",
    "risplenderesti": "risplendere",
    "risplenderete": "risplendere",
    "risplenderà": "risplendere",
    "risplenderò": "risplendere",
    "risplendesse": "risplendere",
    "risplendesser": "risplendere",
    "risplendessero": "risplendere",
    "risplendessi": "risplendere",
    "risplendessimo": "risplendere",
    "risplendeste": "risplendere",
    "risplendesti": "risplendere",
    "risplendete": "risplendere",
    "risplendeva": "risplendere",
    "risplendevamo": "risplendere",
    "risplendevan": "risplendere",
    "risplendevano": "risplendere",
    "risplendevate": "risplendere",
    "risplendevi": "risplendere",
    "risplendevo": "risplendere",
    "risplendi": "risplendere",
    "risplendiamo": "risplendere",
    "risplendiate": "risplendere",
    "risplendo": "risplendere",
    "risplendon": "risplendere",
    "risplendono": "risplendere",
    "risplesa": "risplendere",
    "risplese": "risplendere",
    "rispleser": "risplendere",
    "risplesero": "risplendere",
    "risplesi": "risplendere",
    "rispleso": "risplendere",
    "risplesè": "risplendere",
    "rispolvera": "rispolverare",
    "rispolverai": "rispolverare",
    "rispolverammo": "rispolverare",
    "rispolveran": "rispolverare",
    "rispolverando": "rispolverare",
    "rispolverano": "rispolverare",
    "rispolverante": "rispolverare",
    "rispolveranti": "rispolverare",
    "rispolverar": "rispolverare",
    "rispolveraron": "rispolverare",
    "rispolverarono": "rispolverare",
    "rispolverasse": "rispolverare",
    "rispolverasser": "rispolverare",
    "rispolverassero": "rispolverare",
    "rispolverassi": "rispolverare",
    "rispolverassimo": "rispolverare",
    "rispolveraste": "rispolverare",
    "rispolverasti": "rispolverare",
    "rispolverata": "rispolverare",
    "rispolverate": "rispolverare",
    "rispolverati": "rispolverare",
    "rispolverato": "rispolverare",
    "rispolverava": "rispolverare",
    "rispolveravamo": "rispolverare",
    "rispolveravan": "rispolverare",
    "rispolveravano": "rispolverare",
    "rispolveravate": "rispolverare",
    "rispolveravi": "rispolverare",
    "rispolveravo": "rispolverare",
    "rispolvererai": "rispolverare",
    "rispolvereran": "rispolverare",
    "rispolvereranno": "rispolverare",
    "rispolvererebbe": "rispolverare",
    "rispolvererebber": "rispolverare",
    "rispolvererebbero": "rispolverare",
    "rispolvererei": "rispolverare",
    "rispolvereremmo": "rispolverare",
    "rispolvereremo": "rispolverare",
    "rispolverereste": "rispolverare",
    "rispolvereresti": "rispolverare",
    "rispolvererete": "rispolverare",
    "rispolvererà": "rispolverare",
    "rispolvererò": "rispolverare",
    "rispolveri": "rispolverare",
    "rispolveriamo": "rispolverare",
    "rispolveriate": "rispolverare",
    "rispolverin": "rispolverare",
    "rispolverino": "rispolverare",
    "rispolvero": "rispolverare",
    "rispolverò": "rispolverare",
    "risponda": "rispondere",
    "rispondan": "rispondere",
    "rispondano": "rispondere",
    "risponde": "rispondere",
    "rispondemmo": "rispondere",
    "rispondendo": "rispondere",
    "rispondente": "rispondere",
    "rispondenti": "rispondere",
    "rispondenze": "rispondenza",
    "risponder": "rispondere",
    "risponderai": "rispondere",
    "risponderan": "rispondere",
    "risponderanno": "rispondere",
    "risponderebbe": "rispondere",
    "risponderebber": "rispondere",
    "risponderebbero": "rispondere",
    "risponderei": "rispondere",
    "risponderemmo": "rispondere",
    "risponderemo": "rispondere",
    "rispondereste": "rispondere",
    "risponderesti": "rispondere",
    "risponderete": "rispondere",
    "risponderà": "rispondere",
    "risponderò": "rispondere",
    "rispondesse": "rispondere",
    "rispondesser": "rispondere",
    "rispondessero": "rispondere",
    "rispondessi": "rispondere",
    "rispondessimo": "rispondere",
    "rispondeste": "rispondere",
    "rispondesti": "rispondere",
    "rispondete": "rispondere",
    "rispondeva": "rispondere",
    "rispondevamo": "rispondere",
    "rispondevan": "rispondere",
    "rispondevano": "rispondere",
    "rispondevate": "rispondere",
    "rispondevi": "rispondere",
    "rispondevo": "rispondere",
    "rispondi": "rispondere",
    "rispondiamo": "rispondere",
    "rispondiate": "rispondere",
    "rispondo": "rispondere",
    "rispondon": "rispondere",
    "rispondono": "rispondere",
    "risposa": "risposare",
    "risposai": "risposare",
    "risposammo": "risposare",
    "risposan": "risposare",
    "risposando": "risposare",
    "risposano": "risposare",
    "risposante": "risposare",
    "risposanti": "risposare",
    "risposar": "risposare",
    "risposaron": "risposare",
    "risposarono": "risposare",
    "risposasse": "risposare",
    "risposasser": "risposare",
    "risposassero": "risposare",
    "risposassi": "risposare",
    "risposassimo": "risposare",
    "risposaste": "risposare",
    "risposasti": "risposare",
    "risposata": "risposare",
    "risposate": "risposare",
    "risposati": "risposare",
    "risposato": "risposare",
    "risposava": "risposare",
    "risposavamo": "risposare",
    "risposavan": "risposare",
    "risposavano": "risposare",
    "risposavate": "risposare",
    "risposavi": "risposare",
    "risposavo": "risposare",
    "risposer": "rispondere",
    "risposerai": "risposare",
    "risposeran": "risposare",
    "risposeranno": "risposare",
    "risposerebbe": "risposare",
    "risposerebber": "risposare",
    "risposerebbero": "risposare",
    "risposerei": "risposare",
    "risposeremmo": "risposare",
    "risposeremo": "risposare",
    "risposereste": "risposare",
    "risposeresti": "risposare",
    "risposerete": "risposare",
    "risposero": "rispondere",
    "risposerà": "risposare",
    "risposerò": "risposare",
    "risposi": "risposare",
    "risposiamo": "risposare",
    "risposiate": "risposare",
    "risposin": "risposare",
    "risposino": "risposare",
    "risposo": "risposare",
    "risposta": "rispondere",
    "risposte": "risposta",
    "risposti": "rispondere",
    "risposto": "rispondere",
    "risposè": "rispondere",
    "risposò": "risposare",
    "rispunta": "rispuntare",
    "rispuntai": "rispuntare",
    "rispuntammo": "rispuntare",
    "rispuntan": "rispuntare",
    "rispuntando": "rispuntare",
    "rispuntano": "rispuntare",
    "rispuntante": "rispuntare",
    "rispuntanti": "rispuntare",
    "rispuntar": "rispuntare",
    "rispuntaron": "rispuntare",
    "rispuntarono": "rispuntare",
    "rispuntasse": "rispuntare",
    "rispuntasser": "rispuntare",
    "rispuntassero": "rispuntare",
    "rispuntassi": "rispuntare",
    "rispuntassimo": "rispuntare",
    "rispuntaste": "rispuntare",
    "rispuntasti": "rispuntare",
    "rispuntata": "rispuntare",
    "rispuntate": "rispuntare",
    "rispuntati": "rispuntare",
    "rispuntato": "rispuntare",
    "rispuntava": "rispuntare",
    "rispuntavamo": "rispuntare",
    "rispuntavan": "rispuntare",
    "rispuntavano": "rispuntare",
    "rispuntavate": "rispuntare",
    "rispuntavi": "rispuntare",
    "rispuntavo": "rispuntare",
    "rispunterai": "rispuntare",
    "rispunteran": "rispuntare",
    "rispunteranno": "rispuntare",
    "rispunterebbe": "rispuntare",
    "rispunterebber": "rispuntare",
    "rispunterebbero": "rispuntare",
    "rispunterei": "rispuntare",
    "rispunteremmo": "rispuntare",
    "rispunteremo": "rispuntare",
    "rispuntereste": "rispuntare",
    "rispunteresti": "rispuntare",
    "rispunterete": "rispuntare",
    "rispunterà": "rispuntare",
    "rispunterò": "rispuntare",
    "rispunti": "rispuntare",
    "rispuntiamo": "rispuntare",
    "rispuntiate": "rispuntare",
    "rispuntin": "rispuntare",
    "rispuntino": "rispuntare",
    "rispunto": "rispuntare",
    "rispuntò": "rispuntare",
    "rissa": "rissare",
    "rissai": "rissare",
    "rissammo": "rissare",
    "rissan": "rissare",
    "rissando": "rissare",
    "rissano": "rissare",
    "rissante": "rissare",
    "rissanti": "rissare",
    "rissar": "rissare",
    "rissaron": "rissare",
    "rissarono": "rissare",
    "rissasse": "rissare",
    "rissasser": "rissare",
    "rissassero": "rissare",
    "rissassi": "rissare",
    "rissassimo": "rissare",
    "rissaste": "rissare",
    "rissasti": "rissare",
    "rissata": "rissare",
    "rissate": "rissare",
    "rissati": "rissare",
    "rissato": "rissare",
    "rissava": "rissare",
    "rissavamo": "rissare",
    "rissavan": "rissare",
    "rissavano": "rissare",
    "rissavate": "rissare",
    "rissavi": "rissare",
    "rissavo": "rissare",
    "risse": "rissa",
    "risserai": "rissare",
    "risseran": "rissare",
    "risseranno": "rissare",
    "risserebbe": "rissare",
    "risserebber": "rissare",
    "risserebbero": "rissare",
    "risserei": "rissare",
    "risseremmo": "rissare",
    "risseremo": "rissare",
    "rissereste": "rissare",
    "risseresti": "rissare",
    "risserete": "rissare",
    "risserà": "rissare",
    "risserò": "rissare",
    "rissi": "rissare",
    "rissiamo": "rissare",
    "rissiate": "rissare",
    "rissin": "rissare",
    "rissino": "rissare",
    "risso": "rissare",
    "rissosa": "rissoso",
    "rissose": "rissoso",
    "rissosi": "rissoso",
    "rissò": "rissare",
    "rista": "ristare",
    "ristabilendo": "ristabilire",
    "ristabilente": "ristabilire",
    "ristabilenti": "ristabilire",
    "ristabiliamo": "ristabilire",
    "ristabiliate": "ristabilire",
    "ristabilii": "ristabilire",
    "ristabilimenti": "ristabilimento",
    "ristabilimmo": "ristabilire",
    "ristabilir": "ristabilire",
    "ristabilirai": "ristabilire",
    "ristabiliran": "ristabilire",
    "ristabiliranno": "ristabilire",
    "ristabilirebbe": "ristabilire",
    "ristabilirebber": "ristabilire",
    "ristabilirebbero": "ristabilire",
    "ristabilirei": "ristabilire",
    "ristabiliremmo": "ristabilire",
    "ristabiliremo": "ristabilire",
    "ristabilireste": "ristabilire",
    "ristabiliresti": "ristabilire",
    "ristabilirete": "ristabilire",
    "ristabiliron": "ristabilire",
    "ristabilirono": "ristabilire",
    "ristabilirà": "ristabilire",
    "ristabilirò": "ristabilire",
    "ristabilisca": "ristabilire",
    "ristabiliscan": "ristabilire",
    "ristabiliscano": "ristabilire",
    "ristabilisce": "ristabilire",
    "ristabilisci": "ristabilire",
    "ristabilisco": "ristabilire",
    "ristabiliscon": "ristabilire",
    "ristabiliscono": "ristabilire",
    "ristabilisse": "ristabilire",
    "ristabilisser": "ristabilire",
    "ristabilissero": "ristabilire",
    "ristabilissi": "ristabilire",
    "ristabilissimo": "ristabilire",
    "ristabiliste": "ristabilire",
    "ristabilisti": "ristabilire",
    "ristabilita": "ristabilire",
    "ristabilite": "ristabilire",
    "ristabiliti": "ristabilire",
    "ristabilito": "ristabilire",
    "ristabiliva": "ristabilire",
    "ristabilivamo": "ristabilire",
    "ristabilivan": "ristabilire",
    "ristabilivano": "ristabilire",
    "ristabilivate": "ristabilire",
    "ristabilivi": "ristabilire",
    "ristabilivo": "ristabilire",
    "ristabilì": "ristabilire",
    "ristagna": "ristagnare",
    "ristagnai": "ristagnare",
    "ristagnammo": "ristagnare",
    "ristagnan": "ristagnare",
    "ristagnando": "ristagnare",
    "ristagnano": "ristagnare",
    "ristagnante": "ristagnare",
    "ristagnanti": "ristagnare",
    "ristagnar": "ristagnare",
    "ristagnaron": "ristagnare",
    "ristagnarono": "ristagnare",
    "ristagnasse": "ristagnare",
    "ristagnasser": "ristagnare",
    "ristagnassero": "ristagnare",
    "ristagnassi": "ristagnare",
    "ristagnassimo": "ristagnare",
    "ristagnaste": "ristagnare",
    "ristagnasti": "ristagnare",
    "ristagnata": "ristagnare",
    "ristagnate": "ristagnare",
    "ristagnati": "ristagnare",
    "ristagnato": "ristagnare",
    "ristagnava": "ristagnare",
    "ristagnavamo": "ristagnare",
    "ristagnavan": "ristagnare",
    "ristagnavano": "ristagnare",
    "ristagnavate": "ristagnare",
    "ristagnavi": "ristagnare",
    "ristagnavo": "ristagnare",
    "ristagnerai": "ristagnare",
    "ristagneran": "ristagnare",
    "ristagneranno": "ristagnare",
    "ristagnerebbe": "ristagnare",
    "ristagnerebber": "ristagnare",
    "ristagnerebbero": "ristagnare",
    "ristagnerei": "ristagnare",
    "ristagneremmo": "ristagnare",
    "ristagneremo": "ristagnare",
    "ristagnereste": "ristagnare",
    "ristagneresti": "ristagnare",
    "ristagnerete": "ristagnare",
    "ristagnerà": "ristagnare",
    "ristagnerò": "ristagnare",
    "ristagni": "ristagno",
    "ristagniamo": "ristagnare",
    "ristagniate": "ristagnare",
    "ristagnin": "ristagnare",
    "ristagnino": "ristagnare",
    "ristagno": "ristagnare",
    "ristagnò": "ristagnare",
    "ristai": "ristare",
    "ristammo": "ristare",
    "ristampa": "ristampare",
    "ristampai": "ristampare",
    "ristampammo": "ristampare",
    "ristampan": "ristampare",
    "ristampando": "ristampare",
    "ristampano": "ristampare",
    "ristampante": "ristampare",
    "ristampanti": "ristampare",
    "ristampar": "ristampare",
    "ristamparon": "ristampare",
    "ristamparono": "ristampare",
    "ristampasse": "ristampare",
    "ristampasser": "ristampare",
    "ristampassero": "ristampare",
    "ristampassi": "ristampare",
    "ristampassimo": "ristampare",
    "ristampaste": "ristampare",
    "ristampasti": "ristampare",
    "ristampata": "ristampare",
    "ristampate": "ristampare",
    "ristampati": "ristampare",
    "ristampato": "ristampare",
    "ristampava": "ristampare",
    "ristampavamo": "ristampare",
    "ristampavan": "ristampare",
    "ristampavano": "ristampare",
    "ristampavate": "ristampare",
    "ristampavi": "ristampare",
    "ristampavo": "ristampare",
    "ristampe": "ristampa",
    "ristamperai": "ristampare",
    "ristamperan": "ristampare",
    "ristamperanno": "ristampare",
    "ristamperebbe": "ristampare",
    "ristamperebber": "ristampare",
    "ristamperebbero": "ristampare",
    "ristamperei": "ristampare",
    "ristamperemmo": "ristampare",
    "ristamperemo": "ristampare",
    "ristampereste": "ristampare",
    "ristamperesti": "ristampare",
    "ristamperete": "ristampare",
    "ristamperà": "ristampare",
    "ristamperò": "ristampare",
    "ristampi": "ristampare",
    "ristampiamo": "ristampare",
    "ristampiate": "ristampare",
    "ristampin": "ristampare",
    "ristampino": "ristampare",
    "ristampo": "ristampare",
    "ristampò": "ristampare",
    "ristan": "ristare",
    "ristando": "ristare",
    "ristano": "ristare",
    "ristante": "ristare",
    "ristanti": "ristare",
    "ristar": "ristare",
    "ristaron": "ristare",
    "ristarono": "ristare",
    "ristasse": "ristare",
    "ristasser": "ristare",
    "ristassero": "ristare",
    "ristassi": "ristare",
    "ristassimo": "ristare",
    "ristaste": "ristare",
    "ristasti": "ristare",
    "ristata": "ristare",
    "ristate": "ristare",
    "ristati": "ristare",
    "ristato": "ristare",
    "ristava": "ristare",
    "ristavamo": "ristare",
    "ristavan": "ristare",
    "ristavano": "ristare",
    "ristavate": "ristare",
    "ristavi": "ristare",
    "ristavo": "ristare",
    "risterai": "ristare",
    "risteran": "ristare",
    "risteranno": "ristare",
    "risterebbe": "ristare",
    "risterebber": "ristare",
    "risterebbero": "ristare",
    "risterei": "ristare",
    "risteremmo": "ristare",
    "risteremo": "ristare",
    "ristereste": "ristare",
    "risteresti": "ristare",
    "risterete": "ristare",
    "risterà": "ristare",
    "risterò": "ristare",
    "risti": "ristare",
    "ristiamo": "ristare",
    "ristiate": "ristare",
    "ristin": "ristare",
    "ristino": "ristare",
    "risto": "ristare",
    "ristora": "ristorare",
    "ristorai": "ristorare",
    "ristorammo": "ristorare",
    "ristoran": "ristorare",
    "ristorando": "ristorare",
    "ristorano": "ristorare",
    "ristorante": "ristorare",
    "ristoranti": "ristorare",
    "ristorantini": "ristorantino",
    "ristorar": "ristorare",
    "ristoraron": "ristorare",
    "ristorarono": "ristorare",
    "ristorasse": "ristorare",
    "ristorasser": "ristorare",
    "ristorassero": "ristorare",
    "ristorassi": "ristorare",
    "ristorassimo": "ristorare",
    "ristoraste": "ristorare",
    "ristorasti": "ristorare",
    "ristorata": "ristorare",
    "ristorate": "ristorare",
    "ristorati": "ristorare",
    "ristorato": "ristorare",
    "ristoratori": "ristoratore",
    "ristoratrice": "ristoratore",
    "ristoratrici": "ristoratore",
    "ristorava": "ristorare",
    "ristoravamo": "ristorare",
    "ristoravan": "ristorare",
    "ristoravano": "ristorare",
    "ristoravate": "ristorare",
    "ristoravi": "ristorare",
    "ristoravo": "ristorare",
    "ristorazioni": "ristorazione",
    "ristorerai": "ristorare",
    "ristoreran": "ristorare",
    "ristoreranno": "ristorare",
    "ristorerebbe": "ristorare",
    "ristorerebber": "ristorare",
    "ristorerebbero": "ristorare",
    "ristorerei": "ristorare",
    "ristoreremmo": "ristorare",
    "ristoreremo": "ristorare",
    "ristorereste": "ristorare",
    "ristoreresti": "ristorare",
    "ristorerete": "ristorare",
    "ristorerà": "ristorare",
    "ristorerò": "ristorare",
    "ristori": "ristoro",
    "ristoriamo": "ristorare",
    "ristoriate": "ristorare",
    "ristorin": "ristorare",
    "ristorino": "ristorare",
    "ristorni": "ristorno",
    "ristoro": "ristorare",
    "ristorò": "ristorare",
    "ristretta": "ristretto",
    "ristrette": "ristretto",
    "ristrettezze": "ristrettezza",
    "ristretti": "ristretto",
    "ristretto": "restringere",
    "ristringa": "ristringere",
    "ristringan": "ristringere",
    "ristringano": "ristringere",
    "ristringe": "ristringere",
    "ristringemmo": "ristringere",
    "ristringendo": "ristringere",
    "ristringente": "ristringere",
    "ristringenti": "ristringere",
    "ristringer": "ristringere",
    "ristringerai": "ristringere",
    "ristringeran": "ristringere",
    "ristringeranno": "ristringere",
    "ristringerebbe": "ristringere",
    "ristringerebber": "ristringere",
    "ristringerebbero": "ristringere",
    "ristringerei": "ristringere",
    "ristringeremmo": "ristringere",
    "ristringeremo": "ristringere",
    "ristringereste": "ristringere",
    "ristringeresti": "ristringere",
    "ristringerete": "ristringere",
    "ristringerà": "ristringere",
    "ristringerò": "ristringere",
    "ristringesse": "ristringere",
    "ristringesser": "ristringere",
    "ristringessero": "ristringere",
    "ristringessi": "ristringere",
    "ristringessimo": "ristringere",
    "ristringeste": "ristringere",
    "ristringesti": "ristringere",
    "ristringete": "ristringere",
    "ristringeva": "ristringere",
    "ristringevamo": "ristringere",
    "ristringevan": "ristringere",
    "ristringevano": "ristringere",
    "ristringevate": "ristringere",
    "ristringevi": "ristringere",
    "ristringevo": "ristringere",
    "ristringi": "ristringere",
    "ristringiamo": "ristringere",
    "ristringiate": "ristringere",
    "ristringo": "ristringere",
    "ristringon": "ristringere",
    "ristringono": "ristringere",
    "ristrinser": "ristringere",
    "ristrinsero": "ristringere",
    "ristrinsi": "ristringere",
    "ristrinsè": "ristringere",
    "ristrinta": "ristringere",
    "ristrinte": "ristringere",
    "ristrinti": "ristringere",
    "ristrinto": "ristringere",
    "ristruttura": "ristrutturare",
    "ristrutturai": "ristrutturare",
    "ristrutturammo": "ristrutturare",
    "ristrutturan": "ristrutturare",
    "ristrutturando": "ristrutturare",
    "ristrutturano": "ristrutturare",
    "ristrutturante": "ristrutturare",
    "ristrutturanti": "ristrutturare",
    "ristrutturar": "ristrutturare",
    "ristrutturaron": "ristrutturare",
    "ristrutturarono": "ristrutturare",
    "ristrutturasse": "ristrutturare",
    "ristrutturasser": "ristrutturare",
    "ristrutturassero": "ristrutturare",
    "ristrutturassi": "ristrutturare",
    "ristrutturassimo": "ristrutturare",
    "ristrutturaste": "ristrutturare",
    "ristrutturasti": "ristrutturare",
    "ristrutturata": "ristrutturare",
    "ristrutturate": "ristrutturare",
    "ristrutturati": "ristrutturare",
    "ristrutturato": "ristrutturare",
    "ristrutturava": "ristrutturare",
    "ristrutturavamo": "ristrutturare",
    "ristrutturavan": "ristrutturare",
    "ristrutturavano": "ristrutturare",
    "ristrutturavate": "ristrutturare",
    "ristrutturavi": "ristrutturare",
    "ristrutturavo": "ristrutturare",
    "ristrutturazioni": "ristrutturazione",
    "ristrutturerai": "ristrutturare",
    "ristruttureran": "ristrutturare",
    "ristruttureranno": "ristrutturare",
    "ristrutturerebbe": "ristrutturare",
    "ristrutturerebber": "ristrutturare",
    "ristrutturerebbero": "ristrutturare",
    "ristrutturerei": "ristrutturare",
    "ristruttureremmo": "ristrutturare",
    "ristruttureremo": "ristrutturare",
    "ristrutturereste": "ristrutturare",
    "ristruttureresti": "ristrutturare",
    "ristrutturerete": "ristrutturare",
    "ristrutturerà": "ristrutturare",
    "ristrutturerò": "ristrutturare",
    "ristrutturi": "ristrutturare",
    "ristrutturiamo": "ristrutturare",
    "ristrutturiate": "ristrutturare",
    "ristrutturin": "ristrutturare",
    "ristrutturino": "ristrutturare",
    "ristrutturo": "ristrutturare",
    "ristrutturò": "ristrutturare",
    "ristucca": "ristuccare",
    "ristuccai": "ristuccare",
    "ristuccammo": "ristuccare",
    "ristuccan": "ristuccare",
    "ristuccando": "ristuccare",
    "ristuccano": "ristuccare",
    "ristuccante": "ristuccare",
    "ristuccanti": "ristuccare",
    "ristuccar": "ristuccare",
    "ristuccaron": "ristuccare",
    "ristuccarono": "ristuccare",
    "ristuccasse": "ristuccare",
    "ristuccasser": "ristuccare",
    "ristuccassero": "ristuccare",
    "ristuccassi": "ristuccare",
    "ristuccassimo": "ristuccare",
    "ristuccaste": "ristuccare",
    "ristuccasti": "ristuccare",
    "ristuccata": "ristuccare",
    "ristuccate": "ristuccare",
    "ristuccati": "ristuccare",
    "ristuccato": "ristuccare",
    "ristuccava": "ristuccare",
    "ristuccavamo": "ristuccare",
    "ristuccavan": "ristuccare",
    "ristuccavano": "ristuccare",
    "ristuccavate": "ristuccare",
    "ristuccavi": "ristuccare",
    "ristuccavo": "ristuccare",
    "ristuccherai": "ristuccare",
    "ristuccheran": "ristuccare",
    "ristuccheranno": "ristuccare",
    "ristuccherebbe": "ristuccare",
    "ristuccherebber": "ristuccare",
    "ristuccherebbero": "ristuccare",
    "ristuccherei": "ristuccare",
    "ristuccheremmo": "ristuccare",
    "ristuccheremo": "ristuccare",
    "ristucchereste": "ristuccare",
    "ristuccheresti": "ristuccare",
    "ristuccherete": "ristuccare",
    "ristuccherà": "ristuccare",
    "ristuccherò": "ristuccare",
    "ristucchi": "ristuccare",
    "ristucchiamo": "ristuccare",
    "ristucchiate": "ristuccare",
    "ristucchin": "ristuccare",
    "ristucchino": "ristuccare",
    "ristucco": "ristuccare",
    "ristuccò": "ristuccare",
    "ristudi": "ristudiare",
    "ristudia": "ristudiare",
    "ristudiai": "ristudiare",
    "ristudiammo": "ristudiare",
    "ristudiamo": "ristudiare",
    "ristudian": "ristudiare",
    "ristudiando": "ristudiare",
    "ristudiano": "ristudiare",
    "ristudiante": "ristudiare",
    "ristudianti": "ristudiare",
    "ristudiar": "ristudiare",
    "ristudiaron": "ristudiare",
    "ristudiarono": "ristudiare",
    "ristudiasse": "ristudiare",
    "ristudiasser": "ristudiare",
    "ristudiassero": "ristudiare",
    "ristudiassi": "ristudiare",
    "ristudiassimo": "ristudiare",
    "ristudiaste": "ristudiare",
    "ristudiasti": "ristudiare",
    "ristudiata": "ristudiare",
    "ristudiate": "ristudiare",
    "ristudiati": "ristudiare",
    "ristudiato": "ristudiare",
    "ristudiava": "ristudiare",
    "ristudiavamo": "ristudiare",
    "ristudiavan": "ristudiare",
    "ristudiavano": "ristudiare",
    "ristudiavate": "ristudiare",
    "ristudiavi": "ristudiare",
    "ristudiavo": "ristudiare",
    "ristudierai": "ristudiare",
    "ristudieran": "ristudiare",
    "ristudieranno": "ristudiare",
    "ristudierebbe": "ristudiare",
    "ristudierebber": "ristudiare",
    "ristudierebbero": "ristudiare",
    "ristudierei": "ristudiare",
    "ristudieremmo": "ristudiare",
    "ristudieremo": "ristudiare",
    "ristudiereste": "ristudiare",
    "ristudieresti": "ristudiare",
    "ristudierete": "ristudiare",
    "ristudierà": "ristudiare",
    "ristudierò": "ristudiare",
    "ristudin": "ristudiare",
    "ristudino": "ristudiare",
    "ristudio": "ristudiare",
    "ristudiò": "ristudiare",
    "ristò": "ristare",
    "risucchi": "risucchio",
    "risucchia": "risucchiare",
    "risucchiai": "risucchiare",
    "risucchiammo": "risucchiare",
    "risucchiamo": "risucchiare",
    "risucchian": "risucchiare",
    "risucchiando": "risucchiare",
    "risucchiano": "risucchiare",
    "risucchiante": "risucchiare",
    "risucchianti": "risucchiare",
    "risucchiar": "risucchiare",
    "risucchiaron": "risucchiare",
    "risucchiarono": "risucchiare",
    "risucchiasse": "risucchiare",
    "risucchiasser": "risucchiare",
    "risucchiassero": "risucchiare",
    "risucchiassi": "risucchiare",
    "risucchiassimo": "risucchiare",
    "risucchiaste": "risucchiare",
    "risucchiasti": "risucchiare",
    "risucchiata": "risucchiare",
    "risucchiate": "risucchiare",
    "risucchiati": "risucchiare",
    "risucchiato": "risucchiare",
    "risucchiava": "risucchiare",
    "risucchiavamo": "risucchiare",
    "risucchiavan": "risucchiare",
    "risucchiavano": "risucchiare",
    "risucchiavate": "risucchiare",
    "risucchiavi": "risucchiare",
    "risucchiavo": "risucchiare",
    "risucchierai": "risucchiare",
    "risucchieran": "risucchiare",
    "risucchieranno": "risucchiare",
    "risucchierebbe": "risucchiare",
    "risucchierebber": "risucchiare",
    "risucchierebbero": "risucchiare",
    "risucchierei": "risucchiare",
    "risucchieremmo": "risucchiare",
    "risucchieremo": "risucchiare",
    "risucchiereste": "risucchiare",
    "risucchieresti": "risucchiare",
    "risucchierete": "risucchiare",
    "risucchierà": "risucchiare",
    "risucchierò": "risucchiare",
    "risucchin": "risucchiare",
    "risucchino": "risucchiare",
    "risucchio": "risucchiare",
    "risucchiò": "risucchiare",
    "risulati": "risulato",
    "risulta": "risultare",
    "risultai": "risultare",
    "risultammo": "risultare",
    "risultan": "risultare",
    "risultando": "risultare",
    "risultano": "risultare",
    "risultante": "risultare",
    "risultanti": "risultare",
    "risultanze": "risultanza",
    "risultar": "risultare",
    "risultaron": "risultare",
    "risultarono": "risultare",
    "risultasse": "risultare",
    "risultasser": "risultare",
    "risultassero": "risultare",
    "risultassi": "risultare",
    "risultassimo": "risultare",
    "risultaste": "risultare",
    "risultasti": "risultare",
    "risultata": "risultare",
    "risultate": "risultare",
    "risultati": "risultato",
    "risultato": "risultare",
    "risultava": "risultare",
    "risultavamo": "risultare",
    "risultavan": "risultare",
    "risultavano": "risultare",
    "risultavate": "risultare",
    "risultavi": "risultare",
    "risultavo": "risultare",
    "risulterai": "risultare",
    "risulteran": "risultare",
    "risulteranno": "risultare",
    "risulterebbe": "risultare",
    "risulterebber": "risultare",
    "risulterebbero": "risultare",
    "risulterei": "risultare",
    "risulteremmo": "risultare",
    "risulteremo": "risultare",
    "risultereste": "risultare",
    "risulteresti": "risultare",
    "risulterete": "risultare",
    "risulterà": "risultare",
    "risulterò": "risultare",
    "risulti": "risultare",
    "risultiamo": "risultare",
    "risultiate": "risultare",
    "risultin": "risultare",
    "risultino": "risultare",
    "risulto": "risultare",
    "risultò": "risultare",
    "risuola": "risuolare",
    "risuolai": "risuolare",
    "risuolammo": "risuolare",
    "risuolan": "risuolare",
    "risuolando": "risuolare",
    "risuolano": "risuolare",
    "risuolante": "risuolare",
    "risuolanti": "risuolare",
    "risuolar": "risuolare",
    "risuolaron": "risuolare",
    "risuolarono": "risuolare",
    "risuolasse": "risuolare",
    "risuolasser": "risuolare",
    "risuolassero": "risuolare",
    "risuolassi": "risuolare",
    "risuolassimo": "risuolare",
    "risuolaste": "risuolare",
    "risuolasti": "risuolare",
    "risuolata": "risuolare",
    "risuolate": "risuolare",
    "risuolati": "risuolare",
    "risuolato": "risuolare",
    "risuolava": "risuolare",
    "risuolavamo": "risuolare",
    "risuolavan": "risuolare",
    "risuolavano": "risuolare",
    "risuolavate": "risuolare",
    "risuolavi": "risuolare",
    "risuolavo": "risuolare",
    "risuolerai": "risuolare",
    "risuoleran": "risuolare",
    "risuoleranno": "risuolare",
    "risuolerebbe": "risuolare",
    "risuolerebber": "risuolare",
    "risuolerebbero": "risuolare",
    "risuolerei": "risuolare",
    "risuoleremmo": "risuolare",
    "risuoleremo": "risuolare",
    "risuolereste": "risuolare",
    "risuoleresti": "risuolare",
    "risuolerete": "risuolare",
    "risuolerà": "risuolare",
    "risuolerò": "risuolare",
    "risuoli": "risuolare",
    "risuoliamo": "risuolare",
    "risuoliate": "risuolare",
    "risuolin": "risuolare",
    "risuolino": "risuolare",
    "risuolo": "risuolare",
    "risuolò": "risuolare",
    "risuona": "risuonare",
    "risuonai": "risuonare",
    "risuonammo": "risuonare",
    "risuonan": "risuonare",
    "risuonando": "risuonare",
    "risuonano": "risuonare",
    "risuonante": "risuonare",
    "risuonanti": "risuonare",
    "risuonar": "risuonare",
    "risuonaron": "risuonare",
    "risuonarono": "risuonare",
    "risuonasse": "risuonare",
    "risuonasser": "risuonare",
    "risuonassero": "risuonare",
    "risuonassi": "risuonare",
    "risuonassimo": "risuonare",
    "risuonaste": "risuonare",
    "risuonasti": "risuonare",
    "risuonata": "risuonare",
    "risuonate": "risuonare",
    "risuonati": "risuonare",
    "risuonato": "risuonare",
    "risuonava": "risuonare",
    "risuonavamo": "risuonare",
    "risuonavan": "risuonare",
    "risuonavano": "risuonare",
    "risuonavate": "risuonare",
    "risuonavi": "risuonare",
    "risuonavo": "risuonare",
    "risuonerai": "risuonare",
    "risuoneran": "risuonare",
    "risuoneranno": "risuonare",
    "risuonerebbe": "risuonare",
    "risuonerebber": "risuonare",
    "risuonerebbero": "risuonare",
    "risuonerei": "risuonare",
    "risuoneremmo": "risuonare",
    "risuoneremo": "risuonare",
    "risuonereste": "risuonare",
    "risuoneresti": "risuonare",
    "risuonerete": "risuonare",
    "risuonerà": "risuonare",
    "risuonerò": "risuonare",
    "risuoni": "risuonare",
    "risuoniamo": "risuonare",
    "risuoniate": "risuonare",
    "risuonin": "risuonare",
    "risuonino": "risuonare",
    "risuono": "risuonare",
    "risuonò": "risuonare",
    "risurrezioni": "risurrezione",
    "risuscita": "risuscitare",
    "risuscitai": "risuscitare",
    "risuscitammo": "risuscitare",
    "risuscitan": "risuscitare",
    "risuscitando": "risuscitare",
    "risuscitano": "risuscitare",
    "risuscitante": "risuscitare",
    "risuscitanti": "risuscitare",
    "risuscitar": "risuscitare",
    "risuscitaron": "risuscitare",
    "risuscitarono": "risuscitare",
    "risuscitasse": "risuscitare",
    "risuscitasser": "risuscitare",
    "risuscitassero": "risuscitare",
    "risuscitassi": "risuscitare",
    "risuscitassimo": "risuscitare",
    "risuscitaste": "risuscitare",
    "risuscitasti": "risuscitare",
    "risuscitata": "risuscitare",
    "risuscitate": "risuscitare",
    "risuscitati": "risuscitare",
    "risuscitato": "risuscitare",
    "risuscitava": "risuscitare",
    "risuscitavamo": "risuscitare",
    "risuscitavan": "risuscitare",
    "risuscitavano": "risuscitare",
    "risuscitavate": "risuscitare",
    "risuscitavi": "risuscitare",
    "risuscitavo": "risuscitare",
    "risusciterai": "risuscitare",
    "risusciteran": "risuscitare",
    "risusciteranno": "risuscitare",
    "risusciterebbe": "risuscitare",
    "risusciterebber": "risuscitare",
    "risusciterebbero": "risuscitare",
    "risusciterei": "risuscitare",
    "risusciteremmo": "risuscitare",
    "risusciteremo": "risuscitare",
    "risuscitereste": "risuscitare",
    "risusciteresti": "risuscitare",
    "risusciterete": "risuscitare",
    "risusciterà": "risuscitare",
    "risusciterò": "risuscitare",
    "risusciti": "risuscitare",
    "risuscitiamo": "risuscitare",
    "risuscitiate": "risuscitare",
    "risuscitin": "risuscitare",
    "risuscitino": "risuscitare",
    "risuscito": "risuscitare",
    "risuscitò": "risuscitare",
    "risvegli": "risveglio",
    "risveglia": "risvegliare",
    "risvegliai": "risvegliare",
    "risvegliammo": "risvegliare",
    "risvegliamo": "risvegliare",
    "risveglian": "risvegliare",
    "risvegliando": "risvegliare",
    "risvegliano": "risvegliare",
    "risvegliante": "risvegliare",
    "risveglianti": "risvegliare",
    "risvegliar": "risvegliare",
    "risvegliaron": "risvegliare",
    "risvegliarono": "risvegliare",
    "risvegliasse": "risvegliare",
    "risvegliasser": "risvegliare",
    "risvegliassero": "risvegliare",
    "risvegliassi": "risvegliare",
    "risvegliassimo": "risvegliare",
    "risvegliaste": "risvegliare",
    "risvegliasti": "risvegliare",
    "risvegliata": "risvegliare",
    "risvegliate": "risvegliare",
    "risvegliati": "risvegliare",
    "risvegliato": "risvegliare",
    "risvegliava": "risvegliare",
    "risvegliavamo": "risvegliare",
    "risvegliavan": "risvegliare",
    "risvegliavano": "risvegliare",
    "risvegliavate": "risvegliare",
    "risvegliavi": "risvegliare",
    "risvegliavo": "risvegliare",
    "risveglierai": "risvegliare",
    "risveglieran": "risvegliare",
    "risveglieranno": "risvegliare",
    "risveglierebbe": "risvegliare",
    "risveglierebber": "risvegliare",
    "risveglierebbero": "risvegliare",
    "risveglierei": "risvegliare",
    "risveglieremmo": "risvegliare",
    "risveglieremo": "risvegliare",
    "risvegliereste": "risvegliare",
    "risveglieresti": "risvegliare",
    "risveglierete": "risvegliare",
    "risveglierà": "risvegliare",
    "risveglierò": "risvegliare",
    "risveglin": "risvegliare",
    "risveglino": "risvegliare",
    "risveglio": "risvegliare",
    "risvegliò": "risvegliare",
    "risvolti": "risvolto",
    "ritagli": "ritaglio",
    "ritaglia": "ritagliare",
    "ritagliai": "ritagliare",
    "ritagliammo": "ritagliare",
    "ritagliamo": "ritagliare",
    "ritaglian": "ritagliare",
    "ritagliando": "ritagliare",
    "ritagliano": "ritagliare",
    "ritagliante": "ritagliare",
    "ritaglianti": "ritagliare",
    "ritagliar": "ritagliare",
    "ritagliaron": "ritagliare",
    "ritagliarono": "ritagliare",
    "ritagliasse": "ritagliare",
    "ritagliasser": "ritagliare",
    "ritagliassero": "ritagliare",
    "ritagliassi": "ritagliare",
    "ritagliassimo": "ritagliare",
    "ritagliaste": "ritagliare",
    "ritagliasti": "ritagliare",
    "ritagliata": "ritagliare",
    "ritagliate": "ritagliare",
    "ritagliati": "ritagliare",
    "ritagliato": "ritagliare",
    "ritagliava": "ritagliare",
    "ritagliavamo": "ritagliare",
    "ritagliavan": "ritagliare",
    "ritagliavano": "ritagliare",
    "ritagliavate": "ritagliare",
    "ritagliavi": "ritagliare",
    "ritagliavo": "ritagliare",
    "ritaglierai": "ritagliare",
    "ritaglieran": "ritagliare",
    "ritaglieranno": "ritagliare",
    "ritaglierebbe": "ritagliare",
    "ritaglierebber": "ritagliare",
    "ritaglierebbero": "ritagliare",
    "ritaglierei": "ritagliare",
    "ritaglieremmo": "ritagliare",
    "ritaglieremo": "ritagliare",
    "ritagliereste": "ritagliare",
    "ritaglieresti": "ritagliare",
    "ritaglierete": "ritagliare",
    "ritaglierà": "ritagliare",
    "ritaglierò": "ritagliare",
    "ritaglin": "ritagliare",
    "ritaglino": "ritagliare",
    "ritaglio": "ritagliare",
    "ritagliò": "ritagliare",
    "ritarda": "ritardare",
    "ritardai": "ritardare",
    "ritardammo": "ritardare",
    "ritardan": "ritardare",
    "ritardando": "ritardare",
    "ritardano": "ritardare",
    "ritardante": "ritardare",
    "ritardanti": "ritardare",
    "ritardar": "ritardare",
    "ritardaron": "ritardare",
    "ritardarono": "ritardare",
    "ritardasse": "ritardare",
    "ritardasser": "ritardare",
    "ritardassero": "ritardare",
    "ritardassi": "ritardare",
    "ritardassimo": "ritardare",
    "ritardaste": "ritardare",
    "ritardasti": "ritardare",
    "ritardata": "ritardare",
    "ritardatari": "ritardatario",
    "ritardataria": "ritardatario",
    "ritardatarie": "ritardatario",
    "ritardate": "ritardare",
    "ritardati": "ritardare",
    "ritardato": "ritardare",
    "ritardava": "ritardare",
    "ritardavamo": "ritardare",
    "ritardavan": "ritardare",
    "ritardavano": "ritardare",
    "ritardavate": "ritardare",
    "ritardavi": "ritardare",
    "ritardavo": "ritardare",
    "ritarderai": "ritardare",
    "ritarderan": "ritardare",
    "ritarderanno": "ritardare",
    "ritarderebbe": "ritardare",
    "ritarderebber": "ritardare",
    "ritarderebbero": "ritardare",
    "ritarderei": "ritardare",
    "ritarderemmo": "ritardare",
    "ritarderemo": "ritardare",
    "ritardereste": "ritardare",
    "ritarderesti": "ritardare",
    "ritarderete": "ritardare",
    "ritarderà": "ritardare",
    "ritarderò": "ritardare",
    "ritardi": "ritardo",
    "ritardiamo": "ritardare",
    "ritardiate": "ritardare",
    "ritardin": "ritardare",
    "ritardino": "ritardare",
    "ritardo": "ritardare",
    "ritardò": "ritardare",
    "ritegni": "ritegno",
    "ritempra": "ritemprare",
    "ritemprai": "ritemprare",
    "ritemprammo": "ritemprare",
    "ritempran": "ritemprare",
    "ritemprando": "ritemprare",
    "ritemprano": "ritemprare",
    "ritemprante": "ritemprare",
    "ritempranti": "ritemprare",
    "ritemprar": "ritemprare",
    "ritempraron": "ritemprare",
    "ritemprarono": "ritemprare",
    "ritemprasse": "ritemprare",
    "ritemprasser": "ritemprare",
    "ritemprassero": "ritemprare",
    "ritemprassi": "ritemprare",
    "ritemprassimo": "ritemprare",
    "ritempraste": "ritemprare",
    "ritemprasti": "ritemprare",
    "ritemprata": "ritemprare",
    "ritemprate": "ritemprare",
    "ritemprati": "ritemprare",
    "ritemprato": "ritemprare",
    "ritemprava": "ritemprare",
    "ritempravamo": "ritemprare",
    "ritempravan": "ritemprare",
    "ritempravano": "ritemprare",
    "ritempravate": "ritemprare",
    "ritempravi": "ritemprare",
    "ritempravo": "ritemprare",
    "ritemprerai": "ritemprare",
    "ritempreran": "ritemprare",
    "ritempreranno": "ritemprare",
    "ritemprerebbe": "ritemprare",
    "ritemprerebber": "ritemprare",
    "ritemprerebbero": "ritemprare",
    "ritemprerei": "ritemprare",
    "ritempreremmo": "ritemprare",
    "ritempreremo": "ritemprare",
    "ritemprereste": "ritemprare",
    "ritempreresti": "ritemprare",
    "ritemprerete": "ritemprare",
    "ritemprerà": "ritemprare",
    "ritemprerò": "ritemprare",
    "ritempri": "ritemprare",
    "ritempriamo": "ritemprare",
    "ritempriate": "ritemprare",
    "ritemprin": "ritemprare",
    "ritemprino": "ritemprare",
    "ritempro": "ritemprare",
    "ritemprò": "ritemprare",
    "ritenemmo": "ritenere",
    "ritenendo": "ritenere",
    "ritenente": "ritenere",
    "ritenenti": "ritenere",
    "ritener": "ritenere",
    "ritenesse": "ritenere",
    "ritenesser": "ritenere",
    "ritenessero": "ritenere",
    "ritenessi": "ritenere",
    "ritenessimo": "ritenere",
    "riteneste": "ritenere",
    "ritenesti": "ritenere",
    "ritenete": "ritenere",
    "riteneva": "ritenere",
    "ritenevamo": "ritenere",
    "ritenevan": "ritenere",
    "ritenevano": "ritenere",
    "ritenevate": "ritenere",
    "ritenevi": "ritenere",
    "ritenevo": "ritenere",
    "ritenga": "ritenere",
    "ritengan": "ritenere",
    "ritengano": "ritenere",
    "ritengo": "ritenere",
    "ritengon": "ritenere",
    "ritengono": "ritenere",
    "riteniamo": "ritenere",
    "riteniate": "ritenere",
    "ritenne": "ritenere",
    "ritenner": "ritenere",
    "ritennero": "ritenere",
    "ritenni": "ritenere",
    "ritenta": "ritentare",
    "ritentai": "ritentare",
    "ritentammo": "ritentare",
    "ritentan": "ritentare",
    "ritentando": "ritentare",
    "ritentano": "ritentare",
    "ritentante": "ritentare",
    "ritentanti": "ritentare",
    "ritentar": "ritentare",
    "ritentaron": "ritentare",
    "ritentarono": "ritentare",
    "ritentasse": "ritentare",
    "ritentasser": "ritentare",
    "ritentassero": "ritentare",
    "ritentassi": "ritentare",
    "ritentassimo": "ritentare",
    "ritentaste": "ritentare",
    "ritentasti": "ritentare",
    "ritentata": "ritentare",
    "ritentate": "ritentare",
    "ritentati": "ritentare",
    "ritentato": "ritentare",
    "ritentava": "ritentare",
    "ritentavamo": "ritentare",
    "ritentavan": "ritentare",
    "ritentavano": "ritentare",
    "ritentavate": "ritentare",
    "ritentavi": "ritentare",
    "ritentavo": "ritentare",
    "ritenterai": "ritentare",
    "ritenteran": "ritentare",
    "ritenteranno": "ritentare",
    "ritenterebbe": "ritentare",
    "ritenterebber": "ritentare",
    "ritenterebbero": "ritentare",
    "ritenterei": "ritentare",
    "ritenteremmo": "ritentare",
    "ritenteremo": "ritentare",
    "ritentereste": "ritentare",
    "ritenteresti": "ritentare",
    "ritenterete": "ritentare",
    "ritenterà": "ritentare",
    "ritenterò": "ritentare",
    "ritenti": "ritentare",
    "ritentiamo": "ritentare",
    "ritentiate": "ritentare",
    "ritentin": "ritentare",
    "ritentino": "ritentare",
    "ritento": "ritentare",
    "ritentò": "ritentare",
    "ritenuta": "ritenere",
    "ritenute": "ritenere",
    "ritenuti": "ritenere",
    "ritenuto": "ritenere",
    "ritenzioni": "ritenzione",
    "riterrai": "ritenere",
    "riterran": "ritenere",
    "riterranno": "ritenere",
    "riterrebbe": "ritenere",
    "riterrebber": "ritenere",
    "riterrebbero": "ritenere",
    "riterrei": "ritenere",
    "riterremmo": "ritenere",
    "riterremo": "ritenere",
    "riterreste": "ritenere",
    "riterresti": "ritenere",
    "riterrete": "ritenere",
    "riterrà": "ritenere",
    "riterrò": "ritenere",
    "riti": "rito",
    "ritiene": "ritenere",
    "ritieni": "ritenere",
    "ritinga": "ritingere",
    "ritingan": "ritingere",
    "ritingano": "ritingere",
    "ritinge": "ritingere",
    "ritingemmo": "ritingere",
    "ritingendo": "ritingere",
    "ritingente": "ritingere",
    "ritingenti": "ritingere",
    "ritinger": "ritingere",
    "ritingerai": "ritingere",
    "ritingeran": "ritingere",
    "ritingeranno": "ritingere",
    "ritingerebbe": "ritingere",
    "ritingerebber": "ritingere",
    "ritingerebbero": "ritingere",
    "ritingerei": "ritingere",
    "ritingeremmo": "ritingere",
    "ritingeremo": "ritingere",
    "ritingereste": "ritingere",
    "ritingeresti": "ritingere",
    "ritingerete": "ritingere",
    "ritingerà": "ritingere",
    "ritingerò": "ritingere",
    "ritingesse": "ritingere",
    "ritingesser": "ritingere",
    "ritingessero": "ritingere",
    "ritingessi": "ritingere",
    "ritingessimo": "ritingere",
    "ritingeste": "ritingere",
    "ritingesti": "ritingere",
    "ritingete": "ritingere",
    "ritingeva": "ritingere",
    "ritingevamo": "ritingere",
    "ritingevan": "ritingere",
    "ritingevano": "ritingere",
    "ritingevate": "ritingere",
    "ritingevi": "ritingere",
    "ritingevo": "ritingere",
    "ritingi": "ritingere",
    "ritingiamo": "ritingere",
    "ritingiate": "ritingere",
    "ritingo": "ritingere",
    "ritingon": "ritingere",
    "ritingono": "ritingere",
    "ritinser": "ritingere",
    "ritinsero": "ritingere",
    "ritinsi": "ritingere",
    "ritinsè": "ritingere",
    "ritinta": "ritingere",
    "ritinte": "ritingere",
    "ritinti": "ritingere",
    "ritinto": "ritingere",
    "ritira": "ritirare",
    "ritirai": "ritirare",
    "ritirammo": "ritirare",
    "ritiran": "ritirare",
    "ritirando": "ritirare",
    "ritirano": "ritirare",
    "ritirante": "ritirare",
    "ritiranti": "ritirare",
    "ritirar": "ritirare",
    "ritiraron": "ritirare",
    "ritirarono": "ritirare",
    "ritirasse": "ritirare",
    "ritirasser": "ritirare",
    "ritirassero": "ritirare",
    "ritirassi": "ritirare",
    "ritirassimo": "ritirare",
    "ritiraste": "ritirare",
    "ritirasti": "ritirare",
    "ritirata": "ritirato",
    "ritirate": "ritirato",
    "ritirati": "ritirato",
    "ritirato": "ritirare",
    "ritirava": "ritirare",
    "ritiravamo": "ritirare",
    "ritiravan": "ritirare",
    "ritiravano": "ritirare",
    "ritiravate": "ritirare",
    "ritiravi": "ritirare",
    "ritiravo": "ritirare",
    "ritirerai": "ritirare",
    "ritireran": "ritirare",
    "ritireranno": "ritirare",
    "ritirerebbe": "ritirare",
    "ritirerebber": "ritirare",
    "ritirerebbero": "ritirare",
    "ritirerei": "ritirare",
    "ritireremmo": "ritirare",
    "ritireremo": "ritirare",
    "ritirereste": "ritirare",
    "ritireresti": "ritirare",
    "ritirerete": "ritirare",
    "ritirerà": "ritirare",
    "ritirerò": "ritirare",
    "ritiri": "ritiro",
    "ritiriamo": "ritirare",
    "ritiriate": "ritirare",
    "ritirin": "ritirare",
    "ritirino": "ritirare",
    "ritiro": "ritirare",
    "ritirò": "ritirare",
    "ritma": "ritmare",
    "ritmai": "ritmare",
    "ritmammo": "ritmare",
    "ritman": "ritmare",
    "ritmando": "ritmare",
    "ritmano": "ritmare",
    "ritmante": "ritmare",
    "ritmanti": "ritmare",
    "ritmar": "ritmare",
    "ritmaron": "ritmare",
    "ritmarono": "ritmare",
    "ritmasse": "ritmare",
    "ritmasser": "ritmare",
    "ritmassero": "ritmare",
    "ritmassi": "ritmare",
    "ritmassimo": "ritmare",
    "ritmaste": "ritmare",
    "ritmasti": "ritmare",
    "ritmata": "ritmare",
    "ritmate": "ritmare",
    "ritmati": "ritmare",
    "ritmato": "ritmare",
    "ritmava": "ritmare",
    "ritmavamo": "ritmare",
    "ritmavan": "ritmare",
    "ritmavano": "ritmare",
    "ritmavate": "ritmare",
    "ritmavi": "ritmare",
    "ritmavo": "ritmare",
    "ritmerai": "ritmare",
    "ritmeran": "ritmare",
    "ritmeranno": "ritmare",
    "ritmerebbe": "ritmare",
    "ritmerebber": "ritmare",
    "ritmerebbero": "ritmare",
    "ritmerei": "ritmare",
    "ritmeremmo": "ritmare",
    "ritmeremo": "ritmare",
    "ritmereste": "ritmare",
    "ritmeresti": "ritmare",
    "ritmerete": "ritmare",
    "ritmerà": "ritmare",
    "ritmerò": "ritmare",
    "ritmi": "ritmo",
    "ritmiamo": "ritmare",
    "ritmiate": "ritmare",
    "ritmica": "ritmico",
    "ritmiche": "ritmico",
    "ritmici": "ritmico",
    "ritmin": "ritmare",
    "ritmino": "ritmare",
    "ritmo": "ritmare",
    "ritmò": "ritmare",
    "ritocca": "ritoccare",
    "ritoccai": "ritoccare",
    "ritoccammo": "ritoccare",
    "ritoccan": "ritoccare",
    "ritoccando": "ritoccare",
    "ritoccano": "ritoccare",
    "ritoccante": "ritoccare",
    "ritoccanti": "ritoccare",
    "ritoccar": "ritoccare",
    "ritoccaron": "ritoccare",
    "ritoccarono": "ritoccare",
    "ritoccasse": "ritoccare",
    "ritoccasser": "ritoccare",
    "ritoccassero": "ritoccare",
    "ritoccassi": "ritoccare",
    "ritoccassimo": "ritoccare",
    "ritoccaste": "ritoccare",
    "ritoccasti": "ritoccare",
    "ritoccata": "ritoccare",
    "ritoccate": "ritoccare",
    "ritoccati": "ritoccare",
    "ritoccato": "ritoccare",
    "ritoccava": "ritoccare",
    "ritoccavamo": "ritoccare",
    "ritoccavan": "ritoccare",
    "ritoccavano": "ritoccare",
    "ritoccavate": "ritoccare",
    "ritoccavi": "ritoccare",
    "ritoccavo": "ritoccare",
    "ritoccherai": "ritoccare",
    "ritoccheran": "ritoccare",
    "ritoccheranno": "ritoccare",
    "ritoccherebbe": "ritoccare",
    "ritoccherebber": "ritoccare",
    "ritoccherebbero": "ritoccare",
    "ritoccherei": "ritoccare",
    "ritoccheremmo": "ritoccare",
    "ritoccheremo": "ritoccare",
    "ritocchereste": "ritoccare",
    "ritoccheresti": "ritoccare",
    "ritoccherete": "ritoccare",
    "ritoccherà": "ritoccare",
    "ritoccherò": "ritoccare",
    "ritocchi": "ritocco",
    "ritocchiamo": "ritoccare",
    "ritocchiate": "ritoccare",
    "ritocchin": "ritoccare",
    "ritocchino": "ritoccare",
    "ritocco": "ritoccare",
    "ritoccò": "ritoccare",
    "ritogli": "ritogliere",
    "ritogliamo": "ritogliere",
    "ritogliate": "ritogliere",
    "ritoglie": "ritogliere",
    "ritogliemmo": "ritogliere",
    "ritogliendo": "ritogliere",
    "ritogliente": "ritogliere",
    "ritoglienti": "ritogliere",
    "ritoglier": "ritogliere",
    "ritoglierai": "ritogliere",
    "ritoglieran": "ritogliere",
    "ritoglieranno": "ritogliere",
    "ritoglierebbe": "ritogliere",
    "ritoglierebber": "ritogliere",
    "ritoglierebbero": "ritogliere",
    "ritoglierei": "ritogliere",
    "ritoglieremmo": "ritogliere",
    "ritoglieremo": "ritogliere",
    "ritogliereste": "ritogliere",
    "ritoglieresti": "ritogliere",
    "ritoglierete": "ritogliere",
    "ritoglierà": "ritogliere",
    "ritoglierò": "ritogliere",
    "ritogliesse": "ritogliere",
    "ritogliesser": "ritogliere",
    "ritogliessero": "ritogliere",
    "ritogliessi": "ritogliere",
    "ritogliessimo": "ritogliere",
    "ritoglieste": "ritogliere",
    "ritogliesti": "ritogliere",
    "ritogliete": "ritogliere",
    "ritoglieva": "ritogliere",
    "ritoglievamo": "ritogliere",
    "ritoglievan": "ritogliere",
    "ritoglievano": "ritogliere",
    "ritoglievate": "ritogliere",
    "ritoglievi": "ritogliere",
    "ritoglievo": "ritogliere",
    "ritolga": "ritogliere",
    "ritolgan": "ritogliere",
    "ritolgano": "ritogliere",
    "ritolgo": "ritogliere",
    "ritolgon": "ritogliere",
    "ritolgono": "ritogliere",
    "ritolser": "ritogliere",
    "ritolsero": "ritogliere",
    "ritolsi": "ritogliere",
    "ritolsè": "ritogliere",
    "ritolta": "ritogliere",
    "ritolte": "ritogliere",
    "ritolti": "ritogliere",
    "ritolto": "ritogliere",
    "ritorca": "ritorcere",
    "ritorcan": "ritorcere",
    "ritorcano": "ritorcere",
    "ritorce": "ritorcere",
    "ritorcemmo": "ritorcere",
    "ritorcendo": "ritorcere",
    "ritorcente": "ritorcere",
    "ritorcenti": "ritorcere",
    "ritorcer": "ritorcere",
    "ritorcerai": "ritorcere",
    "ritorceran": "ritorcere",
    "ritorceranno": "ritorcere",
    "ritorcerebbe": "ritorcere",
    "ritorcerebber": "ritorcere",
    "ritorcerebbero": "ritorcere",
    "ritorcerei": "ritorcere",
    "ritorceremmo": "ritorcere",
    "ritorceremo": "ritorcere",
    "ritorcereste": "ritorcere",
    "ritorceresti": "ritorcere",
    "ritorcerete": "ritorcere",
    "ritorcerà": "ritorcere",
    "ritorcerò": "ritorcere",
    "ritorcesse": "ritorcere",
    "ritorcesser": "ritorcere",
    "ritorcessero": "ritorcere",
    "ritorcessi": "ritorcere",
    "ritorcessimo": "ritorcere",
    "ritorceste": "ritorcere",
    "ritorcesti": "ritorcere",
    "ritorcete": "ritorcere",
    "ritorceva": "ritorcere",
    "ritorcevamo": "ritorcere",
    "ritorcevan": "ritorcere",
    "ritorcevano": "ritorcere",
    "ritorcevate": "ritorcere",
    "ritorcevi": "ritorcere",
    "ritorcevo": "ritorcere",
    "ritorci": "ritorcere",
    "ritorciamo": "ritorcere",
    "ritorciate": "ritorcere",
    "ritorco": "ritorcere",
    "ritorcon": "ritorcere",
    "ritorcono": "ritorcere",
    "ritorna": "ritornare",
    "ritornai": "ritornare",
    "ritornammo": "ritornare",
    "ritornan": "ritornare",
    "ritornando": "ritornare",
    "ritornano": "ritornare",
    "ritornante": "ritornare",
    "ritornanti": "ritornare",
    "ritornar": "ritornare",
    "ritornaron": "ritornare",
    "ritornarono": "ritornare",
    "ritornasse": "ritornare",
    "ritornasser": "ritornare",
    "ritornassero": "ritornare",
    "ritornassi": "ritornare",
    "ritornassimo": "ritornare",
    "ritornaste": "ritornare",
    "ritornasti": "ritornare",
    "ritornata": "ritornare",
    "ritornate": "ritornare",
    "ritornati": "ritornare",
    "ritornato": "ritornare",
    "ritornava": "ritornare",
    "ritornavamo": "ritornare",
    "ritornavan": "ritornare",
    "ritornavano": "ritornare",
    "ritornavate": "ritornare",
    "ritornavi": "ritornare",
    "ritornavo": "ritornare",
    "ritornelli": "ritornello",
    "ritornerai": "ritornare",
    "ritorneran": "ritornare",
    "ritorneranno": "ritornare",
    "ritornerebbe": "ritornare",
    "ritornerebber": "ritornare",
    "ritornerebbero": "ritornare",
    "ritornerei": "ritornare",
    "ritorneremmo": "ritornare",
    "ritorneremo": "ritornare",
    "ritornereste": "ritornare",
    "ritorneresti": "ritornare",
    "ritornerete": "ritornare",
    "ritornerà": "ritornare",
    "ritornerò": "ritornare",
    "ritorni": "ritorno",
    "ritorniamo": "ritornare",
    "ritorniate": "ritornare",
    "ritornin": "ritornare",
    "ritornino": "ritornare",
    "ritorno": "ritornare",
    "ritornò": "ritornare",
    "ritorse": "ritorcere",
    "ritorser": "ritorcere",
    "ritorsero": "ritorcere",
    "ritorsi": "ritorcere",
    "ritorsioni": "ritorsione",
    "ritorta": "ritorto",
    "ritorte": "ritorto",
    "ritorti": "ritorto",
    "ritorto": "ritorcere",
    "ritrae": "ritrarre",
    "ritraemmo": "ritrarre",
    "ritraendo": "ritrarre",
    "ritraente": "ritrarre",
    "ritraenti": "ritrarre",
    "ritraesse": "ritrarre",
    "ritraesser": "ritrarre",
    "ritraessero": "ritrarre",
    "ritraessi": "ritrarre",
    "ritraessimo": "ritrarre",
    "ritraeste": "ritrarre",
    "ritraesti": "ritrarre",
    "ritraete": "ritrarre",
    "ritraeva": "ritrarre",
    "ritraevamo": "ritrarre",
    "ritraevan": "ritrarre",
    "ritraevano": "ritrarre",
    "ritraevate": "ritrarre",
    "ritraevi": "ritrarre",
    "ritraevo": "ritrarre",
    "ritragga": "ritrarre",
    "ritraggan": "ritrarre",
    "ritraggano": "ritrarre",
    "ritraggo": "ritrarre",
    "ritraggon": "ritrarre",
    "ritraggono": "ritrarre",
    "ritrai": "ritrarre",
    "ritraiamo": "ritrarre",
    "ritraiate": "ritrarre",
    "ritrarr": "ritrarre",
    "ritrarrai": "ritrarre",
    "ritrarran": "ritrarre",
    "ritrarranno": "ritrarre",
    "ritrarrebbe": "ritrarre",
    "ritrarrebber": "ritrarre",
    "ritrarrebbero": "ritrarre",
    "ritrarrei": "ritrarre",
    "ritrarremmo": "ritrarre",
    "ritrarremo": "ritrarre",
    "ritrarreste": "ritrarre",
    "ritrarresti": "ritrarre",
    "ritrarrete": "ritrarre",
    "ritrarrà": "ritrarre",
    "ritrarrò": "ritrarre",
    "ritrasmessa": "ritrasmettere",
    "ritrasmesse": "ritrasmettere",
    "ritrasmessi": "ritrasmettere",
    "ritrasmesso": "ritrasmettere",
    "ritrasmetta": "ritrasmettere",
    "ritrasmettan": "ritrasmettere",
    "ritrasmettano": "ritrasmettere",
    "ritrasmette": "ritrasmettere",
    "ritrasmettemmo": "ritrasmettere",
    "ritrasmettendo": "ritrasmettere",
    "ritrasmettente": "ritrasmettere",
    "ritrasmettenti": "ritrasmettere",
    "ritrasmetter": "ritrasmettere",
    "ritrasmetterai": "ritrasmettere",
    "ritrasmetteran": "ritrasmettere",
    "ritrasmetteranno": "ritrasmettere",
    "ritrasmetterebbe": "ritrasmettere",
    "ritrasmetterebber": "ritrasmettere",
    "ritrasmetterebbero": "ritrasmettere",
    "ritrasmetterei": "ritrasmettere",
    "ritrasmetteremmo": "ritrasmettere",
    "ritrasmetteremo": "ritrasmettere",
    "ritrasmettereste": "ritrasmettere",
    "ritrasmetteresti": "ritrasmettere",
    "ritrasmetterete": "ritrasmettere",
    "ritrasmetterà": "ritrasmettere",
    "ritrasmetterò": "ritrasmettere",
    "ritrasmettesse": "ritrasmettere",
    "ritrasmettesser": "ritrasmettere",
    "ritrasmettessero": "ritrasmettere",
    "ritrasmettessi": "ritrasmettere",
    "ritrasmettessimo": "ritrasmettere",
    "ritrasmetteste": "ritrasmettere",
    "ritrasmettesti": "ritrasmettere",
    "ritrasmettete": "ritrasmettere",
    "ritrasmetteva": "ritrasmettere",
    "ritrasmettevamo": "ritrasmettere",
    "ritrasmettevan": "ritrasmettere",
    "ritrasmettevano": "ritrasmettere",
    "ritrasmettevate": "ritrasmettere",
    "ritrasmettevi": "ritrasmettere",
    "ritrasmettevo": "ritrasmettere",
    "ritrasmetti": "ritrasmettere",
    "ritrasmettiamo": "ritrasmettere",
    "ritrasmettiate": "ritrasmettere",
    "ritrasmetto": "ritrasmettere",
    "ritrasmetton": "ritrasmettere",
    "ritrasmettono": "ritrasmettere",
    "ritrasmise": "ritrasmettere",
    "ritrasmiser": "ritrasmettere",
    "ritrasmisero": "ritrasmettere",
    "ritrasmisi": "ritrasmettere",
    "ritrasse": "ritrarre",
    "ritrasser": "ritrarre",
    "ritrassero": "ritrarre",
    "ritrassi": "ritrarre",
    "ritratta": "ritratto",
    "ritrattai": "ritrattare",
    "ritrattammo": "ritrattare",
    "ritrattan": "ritrattare",
    "ritrattando": "ritrattare",
    "ritrattano": "ritrattare",
    "ritrattante": "ritrattare",
    "ritrattanti": "ritrattare",
    "ritrattar": "ritrattare",
    "ritrattaron": "ritrattare",
    "ritrattarono": "ritrattare",
    "ritrattasse": "ritrattare",
    "ritrattasser": "ritrattare",
    "ritrattassero": "ritrattare",
    "ritrattassi": "ritrattare",
    "ritrattassimo": "ritrattare",
    "ritrattaste": "ritrattare",
    "ritrattasti": "ritrattare",
    "ritrattata": "ritrattare",
    "ritrattate": "ritrattare",
    "ritrattati": "ritrattare",
    "ritrattato": "ritrattare",
    "ritrattava": "ritrattare",
    "ritrattavamo": "ritrattare",
    "ritrattavan": "ritrattare",
    "ritrattavano": "ritrattare",
    "ritrattavate": "ritrattare",
    "ritrattavi": "ritrattare",
    "ritrattavo": "ritrattare",
    "ritrattazioni": "ritrattazione",
    "ritratte": "ritratto",
    "ritratterai": "ritrattare",
    "ritratteran": "ritrattare",
    "ritratteranno": "ritrattare",
    "ritratterebbe": "ritrattare",
    "ritratterebber": "ritrattare",
    "ritratterebbero": "ritrattare",
    "ritratterei": "ritrattare",
    "ritratteremmo": "ritrattare",
    "ritratteremo": "ritrattare",
    "ritrattereste": "ritrattare",
    "ritratteresti": "ritrattare",
    "ritratterete": "ritrattare",
    "ritratterà": "ritrattare",
    "ritratterò": "ritrattare",
    "ritratti": "ritratto",
    "ritrattiamo": "ritrattare",
    "ritrattiate": "ritrattare",
    "ritrattin": "ritrattare",
    "ritrattini": "ritrattino",
    "ritrattino": "ritrattare",
    "ritrattisti": "ritrattista",
    "ritrattistiche": "ritrattistica",
    "ritratto": "ritrattare",
    "ritrattò": "ritrattare",
    "ritrita": "ritrito",
    "ritrite": "ritrito",
    "ritriti": "ritrito",
    "ritrosa": "ritroso",
    "ritrose": "ritroso",
    "ritrosi": "ritroso",
    "ritrosie": "ritrosia",
    "ritrova": "ritrovare",
    "ritrovai": "ritrovare",
    "ritrovamenti": "ritrovamento",
    "ritrovammo": "ritrovare",
    "ritrovan": "ritrovare",
    "ritrovando": "ritrovare",
    "ritrovano": "ritrovare",
    "ritrovante": "ritrovare",
    "ritrovanti": "ritrovare",
    "ritrovar": "ritrovare",
    "ritrovaron": "ritrovare",
    "ritrovarono": "ritrovare",
    "ritrovasse": "ritrovare",
    "ritrovasser": "ritrovare",
    "ritrovassero": "ritrovare",
    "ritrovassi": "ritrovare",
    "ritrovassimo": "ritrovare",
    "ritrovaste": "ritrovare",
    "ritrovasti": "ritrovare",
    "ritrovata": "ritrovato",
    "ritrovate": "ritrovato",
    "ritrovati": "ritrovato",
    "ritrovato": "ritrovare",
    "ritrovava": "ritrovare",
    "ritrovavamo": "ritrovare",
    "ritrovavan": "ritrovare",
    "ritrovavano": "ritrovare",
    "ritrovavate": "ritrovare",
    "ritrovavi": "ritrovare",
    "ritrovavo": "ritrovare",
    "ritroverai": "ritrovare",
    "ritroveran": "ritrovare",
    "ritroveranno": "ritrovare",
    "ritroverebbe": "ritrovare",
    "ritroverebber": "ritrovare",
    "ritroverebbero": "ritrovare",
    "ritroverei": "ritrovare",
    "ritroveremmo": "ritrovare",
    "ritroveremo": "ritrovare",
    "ritrovereste": "ritrovare",
    "ritroveresti": "ritrovare",
    "ritroverete": "ritrovare",
    "ritroverà": "ritrovare",
    "ritroverò": "ritrovare",
    "ritrovi": "ritrovare",
    "ritroviamo": "ritrovare",
    "ritroviate": "ritrovare",
    "ritrovin": "ritrovare",
    "ritrovino": "ritrovare",
    "ritrovo": "ritrovare",
    "ritrovò": "ritrovare",
    "ritta": "ritto",
    "ritte": "ritto",
    "ritti": "ritto",
    "rituali": "rituale",
    "rituffa": "rituffare",
    "rituffai": "rituffare",
    "rituffammo": "rituffare",
    "rituffan": "rituffare",
    "rituffando": "rituffare",
    "rituffano": "rituffare",
    "rituffante": "rituffare",
    "rituffanti": "rituffare",
    "rituffar": "rituffare",
    "rituffaron": "rituffare",
    "rituffarono": "rituffare",
    "rituffasse": "rituffare",
    "rituffasser": "rituffare",
    "rituffassero": "rituffare",
    "rituffassi": "rituffare",
    "rituffassimo": "rituffare",
    "rituffaste": "rituffare",
    "rituffasti": "rituffare",
    "rituffata": "rituffare",
    "rituffate": "rituffare",
    "rituffati": "rituffare",
    "rituffato": "rituffare",
    "rituffava": "rituffare",
    "rituffavamo": "rituffare",
    "rituffavan": "rituffare",
    "rituffavano": "rituffare",
    "rituffavate": "rituffare",
    "rituffavi": "rituffare",
    "rituffavo": "rituffare",
    "ritufferai": "rituffare",
    "ritufferan": "rituffare",
    "ritufferanno": "rituffare",
    "ritufferebbe": "rituffare",
    "ritufferebber": "rituffare",
    "ritufferebbero": "rituffare",
    "ritufferei": "rituffare",
    "ritufferemmo": "rituffare",
    "ritufferemo": "rituffare",
    "rituffereste": "rituffare",
    "ritufferesti": "rituffare",
    "ritufferete": "rituffare",
    "ritufferà": "rituffare",
    "ritufferò": "rituffare",
    "rituffi": "rituffare",
    "rituffiamo": "rituffare",
    "rituffiate": "rituffare",
    "rituffin": "rituffare",
    "rituffino": "rituffare",
    "rituffo": "rituffare",
    "rituffò": "rituffare",
    "riuda": "riudire",
    "riudan": "riudire",
    "riudano": "riudire",
    "riude": "riudire",
    "riudendo": "riudire",
    "riudente": "riudire",
    "riudenti": "riudire",
    "riudi": "riudire",
    "riudiamo": "riudire",
    "riudiate": "riudire",
    "riudii": "riudire",
    "riudimmo": "riudire",
    "riudir": "riudire",
    "riudirai": "riudire",
    "riudiran": "riudire",
    "riudiranno": "riudire",
    "riudirebbe": "riudire",
    "riudirebber": "riudire",
    "riudirebbero": "riudire",
    "riudirei": "riudire",
    "riudiremmo": "riudire",
    "riudiremo": "riudire",
    "riudireste": "riudire",
    "riudiresti": "riudire",
    "riudirete": "riudire",
    "riudiron": "riudire",
    "riudirono": "riudire",
    "riudirà": "riudire",
    "riudirò": "riudire",
    "riudisse": "riudire",
    "riudisser": "riudire",
    "riudissero": "riudire",
    "riudissi": "riudire",
    "riudissimo": "riudire",
    "riudiste": "riudire",
    "riudisti": "riudire",
    "riudita": "riudire",
    "riudite": "riudire",
    "riuditi": "riudire",
    "riudito": "riudire",
    "riudiva": "riudire",
    "riudivamo": "riudire",
    "riudivan": "riudire",
    "riudivano": "riudire",
    "riudivate": "riudire",
    "riudivi": "riudire",
    "riudivo": "riudire",
    "riudo": "riudire",
    "riudon": "riudire",
    "riudono": "riudire",
    "riudì": "riudire",
    "riunendo": "riunire",
    "riunente": "riunire",
    "riunenti": "riunire",
    "riuniamo": "riunire",
    "riuniate": "riunire",
    "riunifica": "riunificare",
    "riunificai": "riunificare",
    "riunificammo": "riunificare",
    "riunifican": "riunificare",
    "riunificando": "riunificare",
    "riunificano": "riunificare",
    "riunificante": "riunificare",
    "riunificanti": "riunificare",
    "riunificar": "riunificare",
    "riunificaron": "riunificare",
    "riunificarono": "riunificare",
    "riunificasse": "riunificare",
    "riunificasser": "riunificare",
    "riunificassero": "riunificare",
    "riunificassi": "riunificare",
    "riunificassimo": "riunificare",
    "riunificaste": "riunificare",
    "riunificasti": "riunificare",
    "riunificata": "riunificare",
    "riunificate": "riunificare",
    "riunificati": "riunificare",
    "riunificato": "riunificare",
    "riunificava": "riunificare",
    "riunificavamo": "riunificare",
    "riunificavan": "riunificare",
    "riunificavano": "riunificare",
    "riunificavate": "riunificare",
    "riunificavi": "riunificare",
    "riunificavo": "riunificare",
    "riunificazioni": "riunificazione",
    "riunificherai": "riunificare",
    "riunificheran": "riunificare",
    "riunificheranno": "riunificare",
    "riunificherebbe": "riunificare",
    "riunificherebber": "riunificare",
    "riunificherebbero": "riunificare",
    "riunificherei": "riunificare",
    "riunificheremmo": "riunificare",
    "riunificheremo": "riunificare",
    "riunifichereste": "riunificare",
    "riunificheresti": "riunificare",
    "riunificherete": "riunificare",
    "riunificherà": "riunificare",
    "riunificherò": "riunificare",
    "riunifichi": "riunificare",
    "riunifichiamo": "riunificare",
    "riunifichiate": "riunificare",
    "riunifichin": "riunificare",
    "riunifichino": "riunificare",
    "riunifico": "riunificare",
    "riunificò": "riunificare",
    "riunii": "riunire",
    "riunimmo": "riunire",
    "riunioni": "riunione",
    "riunioni-fiume": "riunione-fiume",
    "riunir": "riunire",
    "riunirai": "riunire",
    "riuniran": "riunire",
    "riuniranno": "riunire",
    "riunirebbe": "riunire",
    "riunirebber": "riunire",
    "riunirebbero": "riunire",
    "riunirei": "riunire",
    "riuniremmo": "riunire",
    "riuniremo": "riunire",
    "riunireste": "riunire",
    "riuniresti": "riunire",
    "riunirete": "riunire",
    "riuniron": "riunire",
    "riunirono": "riunire",
    "riunirà": "riunire",
    "riunirò": "riunire",
    "riunisca": "riunire",
    "riuniscan": "riunire",
    "riuniscano": "riunire",
    "riunisce": "riunire",
    "riunisci": "riunire",
    "riunisco": "riunire",
    "riuniscon": "riunire",
    "riuniscono": "riunire",
    "riunisse": "riunire",
    "riunisser": "riunire",
    "riunissero": "riunire",
    "riunissi": "riunire",
    "riunissimo": "riunire",
    "riuniste": "riunire",
    "riunisti": "riunire",
    "riunita": "riunito",
    "riunite": "riunito",
    "riuniti": "riunito",
    "riunito": "riunire",
    "riuniva": "riunire",
    "riunivamo": "riunire",
    "riunivan": "riunire",
    "riunivano": "riunire",
    "riunivate": "riunire",
    "riunivi": "riunire",
    "riunivo": "riunire",
    "riunì": "riunire",
    "riuscendo": "riuscire",
    "riuscente": "riuscire",
    "riuscenti": "riuscire",
    "riusciamo": "riuscire",
    "riusciate": "riuscire",
    "riuscii": "riuscire",
    "riuscimmo": "riuscire",
    "riuscir": "riuscire",
    "riuscirai": "riuscire",
    "riusciran": "riuscire",
    "riusciranno": "riuscire",
    "riuscirebbe": "riuscire",
    "riuscirebber": "riuscire",
    "riuscirebbero": "riuscire",
    "riuscirei": "riuscire",
    "riusciremmo": "riuscire",
    "riusciremo": "riuscire",
    "riuscireste": "riuscire",
    "riusciresti": "riuscire",
    "riuscirete": "riuscire",
    "riusciron": "riuscire",
    "riuscirono": "riuscire",
    "riuscirà": "riuscire",
    "riuscirò": "riuscire",
    "riuscisse": "riuscire",
    "riuscisser": "riuscire",
    "riuscissero": "riuscire",
    "riuscissi": "riuscire",
    "riuscissimo": "riuscire",
    "riusciste": "riuscire",
    "riuscisti": "riuscire",
    "riuscita": "riuscire",
    "riuscite": "riuscire",
    "riusciti": "riuscire",
    "riuscito": "riuscire",
    "riusciva": "riuscire",
    "riuscivamo": "riuscire",
    "riuscivan": "riuscire",
    "riuscivano": "riuscire",
    "riuscivate": "riuscire",
    "riuscivi": "riuscire",
    "riuscivo": "riuscire",
    "riuscì": "riuscire",
    "riusi": "riuso",
    "riutilizza": "riutilizzare",
    "riutilizzai": "riutilizzare",
    "riutilizzammo": "riutilizzare",
    "riutilizzan": "riutilizzare",
    "riutilizzando": "riutilizzare",
    "riutilizzano": "riutilizzare",
    "riutilizzante": "riutilizzare",
    "riutilizzanti": "riutilizzare",
    "riutilizzar": "riutilizzare",
    "riutilizzaron": "riutilizzare",
    "riutilizzarono": "riutilizzare",
    "riutilizzasse": "riutilizzare",
    "riutilizzasser": "riutilizzare",
    "riutilizzassero": "riutilizzare",
    "riutilizzassi": "riutilizzare",
    "riutilizzassimo": "riutilizzare",
    "riutilizzaste": "riutilizzare",
    "riutilizzasti": "riutilizzare",
    "riutilizzata": "riutilizzare",
    "riutilizzate": "riutilizzare",
    "riutilizzati": "riutilizzare",
    "riutilizzato": "riutilizzare",
    "riutilizzava": "riutilizzare",
    "riutilizzavamo": "riutilizzare",
    "riutilizzavan": "riutilizzare",
    "riutilizzavano": "riutilizzare",
    "riutilizzavate": "riutilizzare",
    "riutilizzavi": "riutilizzare",
    "riutilizzavo": "riutilizzare",
    "riutilizzerai": "riutilizzare",
    "riutilizzeran": "riutilizzare",
    "riutilizzeranno": "riutilizzare",
    "riutilizzerebbe": "riutilizzare",
    "riutilizzerebber": "riutilizzare",
    "riutilizzerebbero": "riutilizzare",
    "riutilizzerei": "riutilizzare",
    "riutilizzeremmo": "riutilizzare",
    "riutilizzeremo": "riutilizzare",
    "riutilizzereste": "riutilizzare",
    "riutilizzeresti": "riutilizzare",
    "riutilizzerete": "riutilizzare",
    "riutilizzerà": "riutilizzare",
    "riutilizzerò": "riutilizzare",
    "riutilizzi": "riutilizzo",
    "riutilizziamo": "riutilizzare",
    "riutilizziate": "riutilizzare",
    "riutilizzin": "riutilizzare",
    "riutilizzino": "riutilizzare",
    "riutilizzo": "riutilizzare",
    "riutilizzò": "riutilizzare",
    "riva": "riandare",
    "riva'": "riandare",
    "rivaccina": "rivaccinare",
    "rivaccinai": "rivaccinare",
    "rivaccinammo": "rivaccinare",
    "rivaccinan": "rivaccinare",
    "rivaccinando": "rivaccinare",
    "rivaccinano": "rivaccinare",
    "rivaccinante": "rivaccinare",
    "rivaccinanti": "rivaccinare",
    "rivaccinar": "rivaccinare",
    "rivaccinaron": "rivaccinare",
    "rivaccinarono": "rivaccinare",
    "rivaccinasse": "rivaccinare",
    "rivaccinasser": "rivaccinare",
    "rivaccinassero": "rivaccinare",
    "rivaccinassi": "rivaccinare",
    "rivaccinassimo": "rivaccinare",
    "rivaccinaste": "rivaccinare",
    "rivaccinasti": "rivaccinare",
    "rivaccinata": "rivaccinare",
    "rivaccinate": "rivaccinare",
    "rivaccinati": "rivaccinare",
    "rivaccinato": "rivaccinare",
    "rivaccinava": "rivaccinare",
    "rivaccinavamo": "rivaccinare",
    "rivaccinavan": "rivaccinare",
    "rivaccinavano": "rivaccinare",
    "rivaccinavate": "rivaccinare",
    "rivaccinavi": "rivaccinare",
    "rivaccinavo": "rivaccinare",
    "rivaccinerai": "rivaccinare",
    "rivaccineran": "rivaccinare",
    "rivaccineranno": "rivaccinare",
    "rivaccinerebbe": "rivaccinare",
    "rivaccinerebber": "rivaccinare",
    "rivaccinerebbero": "rivaccinare",
    "rivaccinerei": "rivaccinare",
    "rivaccineremmo": "rivaccinare",
    "rivaccineremo": "rivaccinare",
    "rivaccinereste": "rivaccinare",
    "rivaccineresti": "rivaccinare",
    "rivaccinerete": "rivaccinare",
    "rivaccinerà": "rivaccinare",
    "rivaccinerò": "rivaccinare",
    "rivaccini": "rivaccinare",
    "rivacciniamo": "rivaccinare",
    "rivacciniate": "rivaccinare",
    "rivaccinin": "rivaccinare",
    "rivaccinino": "rivaccinare",
    "rivaccino": "rivaccinare",
    "rivaccinò": "rivaccinare",
    "rivada": "riandare",
    "rivadan": "riandare",
    "rivadano": "riandare",
    "rivado": "riandare",
    "rivai": "riandare",
    "rivale": "rivalere",
    "rivaleggerai": "rivaleggiare",
    "rivaleggeran": "rivaleggiare",
    "rivaleggeranno": "rivaleggiare",
    "rivaleggerebbe": "rivaleggiare",
    "rivaleggerebber": "rivaleggiare",
    "rivaleggerebbero": "rivaleggiare",
    "rivaleggerei": "rivaleggiare",
    "rivaleggeremmo": "rivaleggiare",
    "rivaleggeremo": "rivaleggiare",
    "rivaleggereste": "rivaleggiare",
    "rivaleggeresti": "rivaleggiare",
    "rivaleggerete": "rivaleggiare",
    "rivaleggerà": "rivaleggiare",
    "rivaleggerò": "rivaleggiare",
    "rivaleggi": "rivaleggiare",
    "rivaleggia": "rivaleggiare",
    "rivaleggiai": "rivaleggiare",
    "rivaleggiammo": "rivaleggiare",
    "rivaleggiamo": "rivaleggiare",
    "rivaleggian": "rivaleggiare",
    "rivaleggiando": "rivaleggiare",
    "rivaleggiano": "rivaleggiare",
    "rivaleggiante": "rivaleggiare",
    "rivaleggianti": "rivaleggiare",
    "rivaleggiar": "rivaleggiare",
    "rivaleggiaron": "rivaleggiare",
    "rivaleggiarono": "rivaleggiare",
    "rivaleggiasse": "rivaleggiare",
    "rivaleggiasser": "rivaleggiare",
    "rivaleggiassero": "rivaleggiare",
    "rivaleggiassi": "rivaleggiare",
    "rivaleggiassimo": "rivaleggiare",
    "rivaleggiaste": "rivaleggiare",
    "rivaleggiasti": "rivaleggiare",
    "rivaleggiata": "rivaleggiare",
    "rivaleggiate": "rivaleggiare",
    "rivaleggiati": "rivaleggiare",
    "rivaleggiato": "rivaleggiare",
    "rivaleggiava": "rivaleggiare",
    "rivaleggiavamo": "rivaleggiare",
    "rivaleggiavan": "rivaleggiare",
    "rivaleggiavano": "rivaleggiare",
    "rivaleggiavate": "rivaleggiare",
    "rivaleggiavi": "rivaleggiare",
    "rivaleggiavo": "rivaleggiare",
    "rivaleggin": "rivaleggiare",
    "rivaleggino": "rivaleggiare",
    "rivaleggio": "rivaleggiare",
    "rivaleggiò": "rivaleggiare",
    "rivalemmo": "rivalere",
    "rivalendo": "rivalere",
    "rivaler": "rivalere",
    "rivalesse": "rivalere",
    "rivalesser": "rivalere",
    "rivalessero": "rivalere",
    "rivalessi": "rivalere",
    "rivalessimo": "rivalere",
    "rivaleste": "rivalere",
    "rivalesti": "rivalere",
    "rivalete": "rivalere",
    "rivaleva": "rivalere",
    "rivalevamo": "rivalere",
    "rivalevan": "rivalere",
    "rivalevano": "rivalere",
    "rivalevate": "rivalere",
    "rivalevi": "rivalere",
    "rivalevo": "rivalere",
    "rivalga": "rivalere",
    "rivalgan": "rivalere",
    "rivalgano": "rivalere",
    "rivalgo": "rivalere",
    "rivalgon": "rivalere",
    "rivalgono": "rivalere",
    "rivali": "rivalere",
    "rivaliamo": "rivalere",
    "rivaliate": "rivalere",
    "rivalica": "rivalicare",
    "rivalicai": "rivalicare",
    "rivalicammo": "rivalicare",
    "rivalican": "rivalicare",
    "rivalicando": "rivalicare",
    "rivalicano": "rivalicare",
    "rivalicante": "rivalicare",
    "rivalicanti": "rivalicare",
    "rivalicar": "rivalicare",
    "rivalicaron": "rivalicare",
    "rivalicarono": "rivalicare",
    "rivalicasse": "rivalicare",
    "rivalicasser": "rivalicare",
    "rivalicassero": "rivalicare",
    "rivalicassi": "rivalicare",
    "rivalicassimo": "rivalicare",
    "rivalicaste": "rivalicare",
    "rivalicasti": "rivalicare",
    "rivalicata": "rivalicare",
    "rivalicate": "rivalicare",
    "rivalicati": "rivalicare",
    "rivalicato": "rivalicare",
    "rivalicava": "rivalicare",
    "rivalicavamo": "rivalicare",
    "rivalicavan": "rivalicare",
    "rivalicavano": "rivalicare",
    "rivalicavate": "rivalicare",
    "rivalicavi": "rivalicare",
    "rivalicavo": "rivalicare",
    "rivalicherai": "rivalicare",
    "rivalicheran": "rivalicare",
    "rivalicheranno": "rivalicare",
    "rivalicherebbe": "rivalicare",
    "rivalicherebber": "rivalicare",
    "rivalicherebbero": "rivalicare",
    "rivalicherei": "rivalicare",
    "rivalicheremmo": "rivalicare",
    "rivalicheremo": "rivalicare",
    "rivalichereste": "rivalicare",
    "rivalicheresti": "rivalicare",
    "rivalicherete": "rivalicare",
    "rivalicherà": "rivalicare",
    "rivalicherò": "rivalicare",
    "rivalichi": "rivalicare",
    "rivalichiamo": "rivalicare",
    "rivalichiate": "rivalicare",
    "rivalichin": "rivalicare",
    "rivalichino": "rivalicare",
    "rivalico": "rivalicare",
    "rivalicò": "rivalicare",
    "rivalorizza": "rivalorizzare",
    "rivalorizzai": "rivalorizzare",
    "rivalorizzammo": "rivalorizzare",
    "rivalorizzan": "rivalorizzare",
    "rivalorizzando": "rivalorizzare",
    "rivalorizzano": "rivalorizzare",
    "rivalorizzante": "rivalorizzare",
    "rivalorizzanti": "rivalorizzare",
    "rivalorizzar": "rivalorizzare",
    "rivalorizzaron": "rivalorizzare",
    "rivalorizzarono": "rivalorizzare",
    "rivalorizzasse": "rivalorizzare",
    "rivalorizzasser": "rivalorizzare",
    "rivalorizzassero": "rivalorizzare",
    "rivalorizzassi": "rivalorizzare",
    "rivalorizzassimo": "rivalorizzare",
    "rivalorizzaste": "rivalorizzare",
    "rivalorizzasti": "rivalorizzare",
    "rivalorizzata": "rivalorizzare",
    "rivalorizzate": "rivalorizzare",
    "rivalorizzati": "rivalorizzare",
    "rivalorizzato": "rivalorizzare",
    "rivalorizzava": "rivalorizzare",
    "rivalorizzavamo": "rivalorizzare",
    "rivalorizzavan": "rivalorizzare",
    "rivalorizzavano": "rivalorizzare",
    "rivalorizzavate": "rivalorizzare",
    "rivalorizzavi": "rivalorizzare",
    "rivalorizzavo": "rivalorizzare",
    "rivalorizzerai": "rivalorizzare",
    "rivalorizzeran": "rivalorizzare",
    "rivalorizzeranno": "rivalorizzare",
    "rivalorizzerebbe": "rivalorizzare",
    "rivalorizzerebber": "rivalorizzare",
    "rivalorizzerebbero": "rivalorizzare",
    "rivalorizzerei": "rivalorizzare",
    "rivalorizzeremmo": "rivalorizzare",
    "rivalorizzeremo": "rivalorizzare",
    "rivalorizzereste": "rivalorizzare",
    "rivalorizzeresti": "rivalorizzare",
    "rivalorizzerete": "rivalorizzare",
    "rivalorizzerà": "rivalorizzare",
    "rivalorizzerò": "rivalorizzare",
    "rivalorizzi": "rivalorizzare",
    "rivalorizziamo": "rivalorizzare",
    "rivalorizziate": "rivalorizzare",
    "rivalorizzin": "rivalorizzare",
    "rivalorizzino": "rivalorizzare",
    "rivalorizzo": "rivalorizzare",
    "rivalorizzò": "rivalorizzare",
    "rivalsa": "rivalere",
    "rivalse": "rivalsa",
    "rivalser": "rivalere",
    "rivalsero": "rivalere",
    "rivalsi": "rivalere",
    "rivalso": "rivalere",
    "rivaluta": "rivalutare",
    "rivalutai": "rivalutare",
    "rivalutammo": "rivalutare",
    "rivalutan": "rivalutare",
    "rivalutando": "rivalutare",
    "rivalutano": "rivalutare",
    "rivalutante": "rivalutare",
    "rivalutanti": "rivalutare",
    "rivalutar": "rivalutare",
    "rivalutaron": "rivalutare",
    "rivalutarono": "rivalutare",
    "rivalutasse": "rivalutare",
    "rivalutasser": "rivalutare",
    "rivalutassero": "rivalutare",
    "rivalutassi": "rivalutare",
    "rivalutassimo": "rivalutare",
    "rivalutaste": "rivalutare",
    "rivalutasti": "rivalutare",
    "rivalutata": "rivalutare",
    "rivalutate": "rivalutare",
    "rivalutati": "rivalutare",
    "rivalutato": "rivalutare",
    "rivalutava": "rivalutare",
    "rivalutavamo": "rivalutare",
    "rivalutavan": "rivalutare",
    "rivalutavano": "rivalutare",
    "rivalutavate": "rivalutare",
    "rivalutavi": "rivalutare",
    "rivalutavo": "rivalutare",
    "rivalutazioni": "rivalutazione",
    "rivaluterai": "rivalutare",
    "rivaluteran": "rivalutare",
    "rivaluteranno": "rivalutare",
    "rivaluterebbe": "rivalutare",
    "rivaluterebber": "rivalutare",
    "rivaluterebbero": "rivalutare",
    "rivaluterei": "rivalutare",
    "rivaluteremmo": "rivalutare",
    "rivaluteremo": "rivalutare",
    "rivalutereste": "rivalutare",
    "rivaluteresti": "rivalutare",
    "rivaluterete": "rivalutare",
    "rivaluterà": "rivalutare",
    "rivaluterò": "rivalutare",
    "rivaluti": "rivalutare",
    "rivalutiamo": "rivalutare",
    "rivalutiate": "rivalutare",
    "rivalutin": "rivalutare",
    "rivalutino": "rivalutare",
    "rivaluto": "rivalutare",
    "rivalutò": "rivalutare",
    "rivan": "riandare",
    "rivanga": "rivangare",
    "rivangai": "rivangare",
    "rivangammo": "rivangare",
    "rivangan": "rivangare",
    "rivangando": "rivangare",
    "rivangano": "rivangare",
    "rivangante": "rivangare",
    "rivanganti": "rivangare",
    "rivangar": "rivangare",
    "rivangaron": "rivangare",
    "rivangarono": "rivangare",
    "rivangasse": "rivangare",
    "rivangasser": "rivangare",
    "rivangassero": "rivangare",
    "rivangassi": "rivangare",
    "rivangassimo": "rivangare",
    "rivangaste": "rivangare",
    "rivangasti": "rivangare",
    "rivangata": "rivangare",
    "rivangate": "rivangare",
    "rivangati": "rivangare",
    "rivangato": "rivangare",
    "rivangava": "rivangare",
    "rivangavamo": "rivangare",
    "rivangavan": "rivangare",
    "rivangavano": "rivangare",
    "rivangavate": "rivangare",
    "rivangavi": "rivangare",
    "rivangavo": "rivangare",
    "rivangherai": "rivangare",
    "rivangheran": "rivangare",
    "rivangheranno": "rivangare",
    "rivangherebbe": "rivangare",
    "rivangherebber": "rivangare",
    "rivangherebbero": "rivangare",
    "rivangherei": "rivangare",
    "rivangheremmo": "rivangare",
    "rivangheremo": "rivangare",
    "rivanghereste": "rivangare",
    "rivangheresti": "rivangare",
    "rivangherete": "rivangare",
    "rivangherà": "rivangare",
    "rivangherò": "rivangare",
    "rivanghi": "rivangare",
    "rivanghiamo": "rivangare",
    "rivanghiate": "rivangare",
    "rivanghin": "rivangare",
    "rivanghino": "rivangare",
    "rivango": "rivangare",
    "rivangò": "rivangare",
    "rivanno": "riandare",
    "rivarrai": "rivalere",
    "rivarran": "rivalere",
    "rivarranno": "rivalere",
    "rivarrebbe": "rivalere",
    "rivarrebber": "rivalere",
    "rivarrebbero": "rivalere",
    "rivarrei": "rivalere",
    "rivarremmo": "rivalere",
    "rivarremo": "rivalere",
    "rivarreste": "rivalere",
    "rivarresti": "rivalere",
    "rivarrete": "rivalere",
    "rivarrà": "rivalere",
    "rivarrò": "rivalere",
    "rive": "riva",
    "riveda": "rivedere",
    "rivedan": "rivedere",
    "rivedano": "rivedere",
    "rivede": "rivedere",
    "rivedemmo": "rivedere",
    "rivedendo": "rivedere",
    "rivedente": "rivedere",
    "rivedenti": "rivedere",
    "riveder": "rivedere",
    "rivedesse": "rivedere",
    "rivedesser": "rivedere",
    "rivedessero": "rivedere",
    "rivedessi": "rivedere",
    "rivedessimo": "rivedere",
    "rivedeste": "rivedere",
    "rivedesti": "rivedere",
    "rivedete": "rivedere",
    "rivedeva": "rivedere",
    "rivedevamo": "rivedere",
    "rivedevan": "rivedere",
    "rivedevano": "rivedere",
    "rivedevate": "rivedere",
    "rivedevi": "rivedere",
    "rivedevo": "rivedere",
    "rivedi": "rivedere",
    "rivediamo": "rivedere",
    "rivediate": "rivedere",
    "rivedo": "rivedere",
    "rivedon": "rivedere",
    "rivedono": "rivedere",
    "rivedrai": "rivedere",
    "rivedran": "rivedere",
    "rivedranno": "rivedere",
    "rivedrebbe": "rivedere",
    "rivedrebber": "rivedere",
    "rivedrebbero": "rivedere",
    "rivedrei": "rivedere",
    "rivedremmo": "rivedere",
    "rivedremo": "rivedere",
    "rivedreste": "rivedere",
    "rivedresti": "rivedere",
    "rivedrete": "rivedere",
    "rivedrà": "rivedere",
    "rivedrò": "rivedere",
    "riveduta": "rivedere",
    "rivedute": "rivedere",
    "riveduti": "rivedere",
    "riveduto": "rivedere",
    "rivela": "rivelare",
    "rivelai": "rivelare",
    "rivelammo": "rivelare",
    "rivelan": "rivelare",
    "rivelando": "rivelare",
    "rivelano": "rivelare",
    "rivelante": "rivelare",
    "rivelanti": "rivelare",
    "rivelar": "rivelare",
    "rivelaron": "rivelare",
    "rivelarono": "rivelare",
    "rivelasse": "rivelare",
    "rivelasser": "rivelare",
    "rivelassero": "rivelare",
    "rivelassi": "rivelare",
    "rivelassimo": "rivelare",
    "rivelaste": "rivelare",
    "rivelasti": "rivelare",
    "rivelata": "rivelato",
    "rivelate": "rivelato",
    "rivelati": "rivelato",
    "rivelato": "rivelare",
    "rivelatori": "rivelatore",
    "rivelatrice": "rivelatore",
    "rivelatrici": "rivelatore",
    "rivelava": "rivelare",
    "rivelavamo": "rivelare",
    "rivelavan": "rivelare",
    "rivelavano": "rivelare",
    "rivelavate": "rivelare",
    "rivelavi": "rivelare",
    "rivelavo": "rivelare",
    "rivelazioni": "rivelazione",
    "rivelerai": "rivelare",
    "riveleran": "rivelare",
    "riveleranno": "rivelare",
    "rivelerebbe": "rivelare",
    "rivelerebber": "rivelare",
    "rivelerebbero": "rivelare",
    "rivelerei": "rivelare",
    "riveleremmo": "rivelare",
    "riveleremo": "rivelare",
    "rivelereste": "rivelare",
    "riveleresti": "rivelare",
    "rivelerete": "rivelare",
    "rivelerà": "rivelare",
    "rivelerò": "rivelare",
    "riveli": "rivelare",
    "riveliamo": "rivelare",
    "riveliate": "rivelare",
    "rivelin": "rivelare",
    "rivelino": "rivelare",
    "rivelo": "rivelare",
    "rivelò": "rivelare",
    "rivenda": "rivendere",
    "rivendan": "rivendere",
    "rivendano": "rivendere",
    "rivende": "rivendere",
    "rivendemmo": "rivendere",
    "rivendendo": "rivendere",
    "rivendente": "rivendere",
    "rivendenti": "rivendere",
    "rivender": "rivendere",
    "rivenderai": "rivendere",
    "rivenderan": "rivendere",
    "rivenderanno": "rivendere",
    "rivenderebbe": "rivendere",
    "rivenderebber": "rivendere",
    "rivenderebbero": "rivendere",
    "rivenderei": "rivendere",
    "rivenderemmo": "rivendere",
    "rivenderemo": "rivendere",
    "rivendereste": "rivendere",
    "rivenderesti": "rivendere",
    "rivenderete": "rivendere",
    "rivenderà": "rivendere",
    "rivenderò": "rivendere",
    "rivendesse": "rivendere",
    "rivendesser": "rivendere",
    "rivendessero": "rivendere",
    "rivendessi": "rivendere",
    "rivendessimo": "rivendere",
    "rivendeste": "rivendere",
    "rivendesti": "rivendere",
    "rivendete": "rivendere",
    "rivendette": "rivendere",
    "rivendetter": "rivendere",
    "rivendettero": "rivendere",
    "rivendetti": "rivendere",
    "rivendeva": "rivendere",
    "rivendevamo": "rivendere",
    "rivendevan": "rivendere",
    "rivendevano": "rivendere",
    "rivendevate": "rivendere",
    "rivendevi": "rivendere",
    "rivendevo": "rivendere",
    "rivendi": "rivendere",
    "rivendiamo": "rivendere",
    "rivendiate": "rivendere",
    "rivendica": "rivendicare",
    "rivendicai": "rivendicare",
    "rivendicammo": "rivendicare",
    "rivendican": "rivendicare",
    "rivendicando": "rivendicare",
    "rivendicano": "rivendicare",
    "rivendicante": "rivendicare",
    "rivendicanti": "rivendicare",
    "rivendicar": "rivendicare",
    "rivendicaron": "rivendicare",
    "rivendicarono": "rivendicare",
    "rivendicasse": "rivendicare",
    "rivendicasser": "rivendicare",
    "rivendicassero": "rivendicare",
    "rivendicassi": "rivendicare",
    "rivendicassimo": "rivendicare",
    "rivendicaste": "rivendicare",
    "rivendicasti": "rivendicare",
    "rivendicata": "rivendicare",
    "rivendicate": "rivendicare",
    "rivendicati": "rivendicare",
    "rivendicativa": "rivendicativo",
    "rivendicative": "rivendicativo",
    "rivendicativi": "rivendicativo",
    "rivendicato": "rivendicare",
    "rivendicava": "rivendicare",
    "rivendicavamo": "rivendicare",
    "rivendicavan": "rivendicare",
    "rivendicavano": "rivendicare",
    "rivendicavate": "rivendicare",
    "rivendicavi": "rivendicare",
    "rivendicavo": "rivendicare",
    "rivendicazioni": "rivendicazione",
    "rivendicherai": "rivendicare",
    "rivendicheran": "rivendicare",
    "rivendicheranno": "rivendicare",
    "rivendicherebbe": "rivendicare",
    "rivendicherebber": "rivendicare",
    "rivendicherebbero": "rivendicare",
    "rivendicherei": "rivendicare",
    "rivendicheremmo": "rivendicare",
    "rivendicheremo": "rivendicare",
    "rivendichereste": "rivendicare",
    "rivendicheresti": "rivendicare",
    "rivendicherete": "rivendicare",
    "rivendicherà": "rivendicare",
    "rivendicherò": "rivendicare",
    "rivendichi": "rivendicare",
    "rivendichiamo": "rivendicare",
    "rivendichiate": "rivendicare",
    "rivendichin": "rivendicare",
    "rivendichino": "rivendicare",
    "rivendico": "rivendicare",
    "rivendicò": "rivendicare",
    "rivendite": "rivendita",
    "rivenditori": "rivenditore",
    "rivendo": "rivendere",
    "rivendon": "rivendere",
    "rivendono": "rivendere",
    "rivenduta": "rivendere",
    "rivendute": "rivendere",
    "rivenduti": "rivendere",
    "rivenduto": "rivendere",
    "riverbera": "riverberare",
    "riverberai": "riverberare",
    "riverberammo": "riverberare",
    "riverberan": "riverberare",
    "riverberando": "riverberare",
    "riverberano": "riverberare",
    "riverberante": "riverberare",
    "riverberanti": "riverberare",
    "riverberar": "riverberare",
    "riverberaron": "riverberare",
    "riverberarono": "riverberare",
    "riverberasse": "riverberare",
    "riverberasser": "riverberare",
    "riverberassero": "riverberare",
    "riverberassi": "riverberare",
    "riverberassimo": "riverberare",
    "riverberaste": "riverberare",
    "riverberasti": "riverberare",
    "riverberata": "riverberare",
    "riverberate": "riverberare",
    "riverberati": "riverberare",
    "riverberato": "riverberare",
    "riverberava": "riverberare",
    "riverberavamo": "riverberare",
    "riverberavan": "riverberare",
    "riverberavano": "riverberare",
    "riverberavate": "riverberare",
    "riverberavi": "riverberare",
    "riverberavo": "riverberare",
    "riverbererai": "riverberare",
    "riverbereran": "riverberare",
    "riverbereranno": "riverberare",
    "riverbererebbe": "riverberare",
    "riverbererebber": "riverberare",
    "riverbererebbero": "riverberare",
    "riverbererei": "riverberare",
    "riverbereremmo": "riverberare",
    "riverbereremo": "riverberare",
    "riverberereste": "riverberare",
    "riverbereresti": "riverberare",
    "riverbererete": "riverberare",
    "riverbererà": "riverberare",
    "riverbererò": "riverberare",
    "riverberi": "riverbero",
    "riverberiamo": "riverberare",
    "riverberiate": "riverberare",
    "riverberin": "riverberare",
    "riverberino": "riverberare",
    "riverbero": "riverberare",
    "riverberò": "riverberare",
    "riverendo": "riverire",
    "riverente": "riverire",
    "riverenti": "riverire",
    "riverenze": "riverenza",
    "riveriamo": "riverire",
    "riveriate": "riverire",
    "riverii": "riverire",
    "riverimmo": "riverire",
    "riverir": "riverire",
    "riverirai": "riverire",
    "riveriran": "riverire",
    "riveriranno": "riverire",
    "riverirebbe": "riverire",
    "riverirebber": "riverire",
    "riverirebbero": "riverire",
    "riverirei": "riverire",
    "riveriremmo": "riverire",
    "riveriremo": "riverire",
    "riverireste": "riverire",
    "riveriresti": "riverire",
    "riverirete": "riverire",
    "riveriron": "riverire",
    "riverirono": "riverire",
    "riverirà": "riverire",
    "riverirò": "riverire",
    "riverisca": "riverire",
    "riveriscan": "riverire",
    "riveriscano": "riverire",
    "riverisce": "riverire",
    "riverisci": "riverire",
    "riverisco": "riverire",
    "riveriscon": "riverire",
    "riveriscono": "riverire",
    "riverisse": "riverire",
    "riverisser": "riverire",
    "riverissero": "riverire",
    "riverissi": "riverire",
    "riverissimo": "riverire",
    "riveriste": "riverire",
    "riveristi": "riverire",
    "riverita": "riverire",
    "riverite": "riverire",
    "riveriti": "riverire",
    "riverito": "riverire",
    "riveriva": "riverire",
    "riverivamo": "riverire",
    "riverivan": "riverire",
    "riverivano": "riverire",
    "riverivate": "riverire",
    "riverivi": "riverire",
    "riverivo": "riverire",
    "rivernicerai": "riverniciare",
    "riverniceran": "riverniciare",
    "riverniceranno": "riverniciare",
    "rivernicerebbe": "riverniciare",
    "rivernicerebber": "riverniciare",
    "rivernicerebbero": "riverniciare",
    "rivernicerei": "riverniciare",
    "riverniceremmo": "riverniciare",
    "riverniceremo": "riverniciare",
    "rivernicereste": "riverniciare",
    "riverniceresti": "riverniciare",
    "rivernicerete": "riverniciare",
    "rivernicerà": "riverniciare",
    "rivernicerò": "riverniciare",
    "rivernici": "riverniciare",
    "rivernicia": "riverniciare",
    "riverniciai": "riverniciare",
    "riverniciammo": "riverniciare",
    "riverniciamo": "riverniciare",
    "rivernician": "riverniciare",
    "riverniciando": "riverniciare",
    "riverniciano": "riverniciare",
    "riverniciante": "riverniciare",
    "rivernicianti": "riverniciare",
    "riverniciar": "riverniciare",
    "riverniciaron": "riverniciare",
    "riverniciarono": "riverniciare",
    "riverniciasse": "riverniciare",
    "riverniciasser": "riverniciare",
    "riverniciassero": "riverniciare",
    "riverniciassi": "riverniciare",
    "riverniciassimo": "riverniciare",
    "riverniciaste": "riverniciare",
    "riverniciasti": "riverniciare",
    "riverniciata": "riverniciare",
    "riverniciate": "riverniciare",
    "riverniciati": "riverniciare",
    "riverniciato": "riverniciare",
    "riverniciava": "riverniciare",
    "riverniciavamo": "riverniciare",
    "riverniciavan": "riverniciare",
    "riverniciavano": "riverniciare",
    "riverniciavate": "riverniciare",
    "riverniciavi": "riverniciare",
    "riverniciavo": "riverniciare",
    "rivernicin": "riverniciare",
    "rivernicino": "riverniciare",
    "rivernicio": "riverniciare",
    "riverniciò": "riverniciare",
    "riversa": "riverso",
    "riversai": "riversare",
    "riversammo": "riversare",
    "riversan": "riversare",
    "riversando": "riversare",
    "riversano": "riversare",
    "riversante": "riversare",
    "riversanti": "riversare",
    "riversar": "riversare",
    "riversaron": "riversare",
    "riversarono": "riversare",
    "riversasse": "riversare",
    "riversasser": "riversare",
    "riversassero": "riversare",
    "riversassi": "riversare",
    "riversassimo": "riversare",
    "riversaste": "riversare",
    "riversasti": "riversare",
    "riversata": "riversare",
    "riversate": "riversare",
    "riversati": "riversare",
    "riversato": "riversare",
    "riversava": "riversare",
    "riversavamo": "riversare",
    "riversavan": "riversare",
    "riversavano": "riversare",
    "riversavate": "riversare",
    "riversavi": "riversare",
    "riversavo": "riversare",
    "riverse": "riverso",
    "riverserai": "riversare",
    "riverseran": "riversare",
    "riverseranno": "riversare",
    "riverserebbe": "riversare",
    "riverserebber": "riversare",
    "riverserebbero": "riversare",
    "riverserei": "riversare",
    "riverseremmo": "riversare",
    "riverseremo": "riversare",
    "riversereste": "riversare",
    "riverseresti": "riversare",
    "riverserete": "riversare",
    "riverserà": "riversare",
    "riverserò": "riversare",
    "riversi": "riverso",
    "riversiamo": "riversare",
    "riversiate": "riversare",
    "riversin": "riversare",
    "riversino": "riversare",
    "riverso": "riversare",
    "riversò": "riversare",
    "riverì": "riverire",
    "rivesta": "rivestire",
    "rivestan": "rivestire",
    "rivestano": "rivestire",
    "riveste": "rivestire",
    "rivestendo": "rivestire",
    "rivestente": "rivestire",
    "rivestenti": "rivestire",
    "rivesti": "rivestire",
    "rivestiamo": "rivestire",
    "rivestiate": "rivestire",
    "rivestii": "rivestire",
    "rivestimenti": "rivestimento",
    "rivestimmo": "rivestire",
    "rivestir": "rivestire",
    "rivestirai": "rivestire",
    "rivestiran": "rivestire",
    "rivestiranno": "rivestire",
    "rivestirebbe": "rivestire",
    "rivestirebber": "rivestire",
    "rivestirebbero": "rivestire",
    "rivestirei": "rivestire",
    "rivestiremmo": "rivestire",
    "rivestiremo": "rivestire",
    "rivestireste": "rivestire",
    "rivestiresti": "rivestire",
    "rivestirete": "rivestire",
    "rivestiron": "rivestire",
    "rivestirono": "rivestire",
    "rivestirà": "rivestire",
    "rivestirò": "rivestire",
    "rivestisse": "rivestire",
    "rivestisser": "rivestire",
    "rivestissero": "rivestire",
    "rivestissi": "rivestire",
    "rivestissimo": "rivestire",
    "rivestiste": "rivestire",
    "rivestisti": "rivestire",
    "rivestita": "rivestito",
    "rivestite": "rivestito",
    "rivestiti": "rivestito",
    "rivestito": "rivestire",
    "rivestiva": "rivestire",
    "rivestivamo": "rivestire",
    "rivestivan": "rivestire",
    "rivestivano": "rivestire",
    "rivestivate": "rivestire",
    "rivestivi": "rivestire",
    "rivestivo": "rivestire",
    "rivesto": "rivestire",
    "riveston": "rivestire",
    "rivestono": "rivestire",
    "rivestì": "rivestire",
    "rivetta": "rivettare",
    "rivettai": "rivettare",
    "rivettammo": "rivettare",
    "rivettan": "rivettare",
    "rivettando": "rivettare",
    "rivettano": "rivettare",
    "rivettante": "rivettare",
    "rivettanti": "rivettare",
    "rivettar": "rivettare",
    "rivettaron": "rivettare",
    "rivettarono": "rivettare",
    "rivettasse": "rivettare",
    "rivettasser": "rivettare",
    "rivettassero": "rivettare",
    "rivettassi": "rivettare",
    "rivettassimo": "rivettare",
    "rivettaste": "rivettare",
    "rivettasti": "rivettare",
    "rivettata": "rivettare",
    "rivettate": "rivettare",
    "rivettati": "rivettare",
    "rivettato": "rivettare",
    "rivettava": "rivettare",
    "rivettavamo": "rivettare",
    "rivettavan": "rivettare",
    "rivettavano": "rivettare",
    "rivettavate": "rivettare",
    "rivettavi": "rivettare",
    "rivettavo": "rivettare",
    "rivetterai": "rivettare",
    "rivetteran": "rivettare",
    "rivetteranno": "rivettare",
    "rivetterebbe": "rivettare",
    "rivetterebber": "rivettare",
    "rivetterebbero": "rivettare",
    "rivetterei": "rivettare",
    "rivetteremmo": "rivettare",
    "rivetteremo": "rivettare",
    "rivettereste": "rivettare",
    "rivetteresti": "rivettare",
    "rivetterete": "rivettare",
    "rivetterà": "rivettare",
    "rivetterò": "rivettare",
    "rivetti": "rivettare",
    "rivettiamo": "rivettare",
    "rivettiate": "rivettare",
    "rivettin": "rivettare",
    "rivettino": "rivettare",
    "rivetto": "rivettare",
    "rivettò": "rivettare",
    "rivide": "rivedere",
    "rivider": "rivedere",
    "rividero": "rivedere",
    "rividi": "rivedere",
    "rivierasca": "rivierasco",
    "rivierasche": "rivierasco",
    "rivieraschi": "rivierasco",
    "riviere": "riviera",
    "rivinca": "rivincere",
    "rivincan": "rivincere",
    "rivincano": "rivincere",
    "rivince": "rivincere",
    "rivincei": "rivincere",
    "rivincemmo": "rivincere",
    "rivincendo": "rivincere",
    "rivincente": "rivincere",
    "rivincenti": "rivincere",
    "rivincer": "rivincere",
    "rivincerai": "rivincere",
    "rivinceran": "rivincere",
    "rivinceranno": "rivincere",
    "rivincerebbe": "rivincere",
    "rivincerebber": "rivincere",
    "rivincerebbero": "rivincere",
    "rivincerei": "rivincere",
    "rivinceremmo": "rivincere",
    "rivinceremo": "rivincere",
    "rivincereste": "rivincere",
    "rivinceresti": "rivincere",
    "rivincerete": "rivincere",
    "rivinceron": "rivincere",
    "rivincerono": "rivincere",
    "rivincerà": "rivincere",
    "rivincerò": "rivincere",
    "rivincesse": "rivincere",
    "rivincesser": "rivincere",
    "rivincessero": "rivincere",
    "rivincessi": "rivincere",
    "rivincessimo": "rivincere",
    "rivinceste": "rivincere",
    "rivincesti": "rivincere",
    "rivincete": "rivincere",
    "rivinceva": "rivincere",
    "rivincevamo": "rivincere",
    "rivincevan": "rivincere",
    "rivincevano": "rivincere",
    "rivincevate": "rivincere",
    "rivincevi": "rivincere",
    "rivincevo": "rivincere",
    "rivinci": "rivincere",
    "rivinciamo": "rivincere",
    "rivinciate": "rivincere",
    "rivincite": "rivincita",
    "rivinco": "rivincere",
    "rivincon": "rivincere",
    "rivincono": "rivincere",
    "rivincuta": "rivincere",
    "rivincute": "rivincere",
    "rivincuti": "rivincere",
    "rivincuto": "rivincere",
    "rivincè": "rivincere",
    "rivisita": "rivisitare",
    "rivisitai": "rivisitare",
    "rivisitammo": "rivisitare",
    "rivisitan": "rivisitare",
    "rivisitando": "rivisitare",
    "rivisitano": "rivisitare",
    "rivisitante": "rivisitare",
    "rivisitanti": "rivisitare",
    "rivisitar": "rivisitare",
    "rivisitaron": "rivisitare",
    "rivisitarono": "rivisitare",
    "rivisitasse": "rivisitare",
    "rivisitasser": "rivisitare",
    "rivisitassero": "rivisitare",
    "rivisitassi": "rivisitare",
    "rivisitassimo": "rivisitare",
    "rivisitaste": "rivisitare",
    "rivisitasti": "rivisitare",
    "rivisitata": "rivisitare",
    "rivisitate": "rivisitare",
    "rivisitati": "rivisitare",
    "rivisitato": "rivisitare",
    "rivisitava": "rivisitare",
    "rivisitavamo": "rivisitare",
    "rivisitavan": "rivisitare",
    "rivisitavano": "rivisitare",
    "rivisitavate": "rivisitare",
    "rivisitavi": "rivisitare",
    "rivisitavo": "rivisitare",
    "rivisitazioni": "rivisitazione",
    "rivisiterai": "rivisitare",
    "rivisiteran": "rivisitare",
    "rivisiteranno": "rivisitare",
    "rivisiterebbe": "rivisitare",
    "rivisiterebber": "rivisitare",
    "rivisiterebbero": "rivisitare",
    "rivisiterei": "rivisitare",
    "rivisiteremmo": "rivisitare",
    "rivisiteremo": "rivisitare",
    "rivisitereste": "rivisitare",
    "rivisiteresti": "rivisitare",
    "rivisiterete": "rivisitare",
    "rivisiterà": "rivisitare",
    "rivisiterò": "rivisitare",
    "rivisiti": "rivisitare",
    "rivisitiamo": "rivisitare",
    "rivisitiate": "rivisitare",
    "rivisitin": "rivisitare",
    "rivisitino": "rivisitare",
    "rivisito": "rivisitare",
    "rivisitò": "rivisitare",
    "rivisse": "rivivere",
    "rivisser": "rivivere",
    "rivissero": "rivivere",
    "rivissi": "rivivere",
    "rivissuta": "rivivere",
    "rivissute": "rivivere",
    "rivissuti": "rivivere",
    "rivissuto": "rivivere",
    "rivista": "rivisto",
    "rivistaiola": "rivistaiolo",
    "rivistaiole": "rivistaiolo",
    "rivistaioli": "rivistaiolo",
    "riviste": "rivisto",
    "rivisti": "rivisto",
    "rivistine": "rivistina",
    "rivitalizza": "rivitalizzare",
    "rivitalizzai": "rivitalizzare",
    "rivitalizzammo": "rivitalizzare",
    "rivitalizzan": "rivitalizzare",
    "rivitalizzando": "rivitalizzare",
    "rivitalizzano": "rivitalizzare",
    "rivitalizzante": "rivitalizzare",
    "rivitalizzanti": "rivitalizzare",
    "rivitalizzar": "rivitalizzare",
    "rivitalizzaron": "rivitalizzare",
    "rivitalizzarono": "rivitalizzare",
    "rivitalizzasse": "rivitalizzare",
    "rivitalizzasser": "rivitalizzare",
    "rivitalizzassero": "rivitalizzare",
    "rivitalizzassi": "rivitalizzare",
    "rivitalizzassimo": "rivitalizzare",
    "rivitalizzaste": "rivitalizzare",
    "rivitalizzasti": "rivitalizzare",
    "rivitalizzata": "rivitalizzare",
    "rivitalizzate": "rivitalizzare",
    "rivitalizzati": "rivitalizzare",
    "rivitalizzato": "rivitalizzare",
    "rivitalizzava": "rivitalizzare",
    "rivitalizzavamo": "rivitalizzare",
    "rivitalizzavan": "rivitalizzare",
    "rivitalizzavano": "rivitalizzare",
    "rivitalizzavate": "rivitalizzare",
    "rivitalizzavi": "rivitalizzare",
    "rivitalizzavo": "rivitalizzare",
    "rivitalizzazioni": "rivitalizzazione",
    "rivitalizzerai": "rivitalizzare",
    "rivitalizzeran": "rivitalizzare",
    "rivitalizzeranno": "rivitalizzare",
    "rivitalizzerebbe": "rivitalizzare",
    "rivitalizzerebber": "rivitalizzare",
    "rivitalizzerebbero": "rivitalizzare",
    "rivitalizzerei": "rivitalizzare",
    "rivitalizzeremmo": "rivitalizzare",
    "rivitalizzeremo": "rivitalizzare",
    "rivitalizzereste": "rivitalizzare",
    "rivitalizzeresti": "rivitalizzare",
    "rivitalizzerete": "rivitalizzare",
    "rivitalizzerà": "rivitalizzare",
    "rivitalizzerò": "rivitalizzare",
    "rivitalizzi": "rivitalizzare",
    "rivitalizziamo": "rivitalizzare",
    "rivitalizziate": "rivitalizzare",
    "rivitalizzin": "rivitalizzare",
    "rivitalizzino": "rivitalizzare",
    "rivitalizzo": "rivitalizzare",
    "rivitalizzò": "rivitalizzare",
    "riviva": "rivivere",
    "rivivan": "rivivere",
    "rivivano": "rivivere",
    "rivive": "rivivere",
    "rivivemmo": "rivivere",
    "rivivendo": "rivivere",
    "rivivente": "rivivere",
    "riviventi": "rivivere",
    "riviver": "rivivere",
    "rivivesse": "rivivere",
    "rivivesser": "rivivere",
    "rivivessero": "rivivere",
    "rivivessi": "rivivere",
    "rivivessimo": "rivivere",
    "riviveste": "rivivere",
    "rivivesti": "rivivere",
    "rivivete": "rivivere",
    "riviveva": "rivivere",
    "rivivevamo": "rivivere",
    "rivivevan": "rivivere",
    "rivivevano": "rivivere",
    "rivivevate": "rivivere",
    "rivivevi": "rivivere",
    "rivivevo": "rivivere",
    "rivivi": "rivivere",
    "riviviamo": "rivivere",
    "riviviate": "rivivere",
    "rivivo": "rivivere",
    "rivivon": "rivivere",
    "rivivono": "rivivere",
    "rivivrai": "rivivere",
    "rivivran": "rivivere",
    "rivivranno": "rivivere",
    "rivivrebbe": "rivivere",
    "rivivrebber": "rivivere",
    "rivivrebbero": "rivivere",
    "rivivrei": "rivivere",
    "rivivremmo": "rivivere",
    "rivivremo": "rivivere",
    "rivivreste": "rivivere",
    "rivivresti": "rivivere",
    "rivivrete": "rivivere",
    "rivivrà": "rivivere",
    "rivivrò": "rivivere",
    "rivoglia": "rivolere",
    "rivogliamo": "rivolere",
    "rivoglian": "rivolere",
    "rivogliano": "rivolere",
    "rivogliate": "rivolere",
    "rivoglio": "rivolere",
    "rivoglion": "rivolere",
    "rivogliono": "rivolere",
    "rivolemmo": "rivolere",
    "rivolendo": "rivolere",
    "rivolente": "rivolere",
    "rivolenti": "rivolere",
    "rivoler": "rivolere",
    "rivolesse": "rivolere",
    "rivolesser": "rivolere",
    "rivolessero": "rivolere",
    "rivolessi": "rivolere",
    "rivolessimo": "rivolere",
    "rivoleste": "rivolere",
    "rivolesti": "rivolere",
    "rivolete": "rivolere",
    "rivoleva": "rivolere",
    "rivolevamo": "rivolere",
    "rivolevan": "rivolere",
    "rivolevano": "rivolere",
    "rivolevate": "rivolere",
    "rivolevi": "rivolere",
    "rivolevo": "rivolere",
    "rivolga": "rivolgere",
    "rivolgan": "rivolgere",
    "rivolgano": "rivolgere",
    "rivolge": "rivolgere",
    "rivolgemmo": "rivolgere",
    "rivolgendo": "rivolgere",
    "rivolgente": "rivolgere",
    "rivolgenti": "rivolgere",
    "rivolger": "rivolgere",
    "rivolgerai": "rivolgere",
    "rivolgeran": "rivolgere",
    "rivolgeranno": "rivolgere",
    "rivolgerebbe": "rivolgere",
    "rivolgerebber": "rivolgere",
    "rivolgerebbero": "rivolgere",
    "rivolgerei": "rivolgere",
    "rivolgeremmo": "rivolgere",
    "rivolgeremo": "rivolgere",
    "rivolgereste": "rivolgere",
    "rivolgeresti": "rivolgere",
    "rivolgerete": "rivolgere",
    "rivolgerà": "rivolgere",
    "rivolgerò": "rivolgere",
    "rivolgesse": "rivolgere",
    "rivolgesser": "rivolgere",
    "rivolgessero": "rivolgere",
    "rivolgessi": "rivolgere",
    "rivolgessimo": "rivolgere",
    "rivolgeste": "rivolgere",
    "rivolgesti": "rivolgere",
    "rivolgete": "rivolgere",
    "rivolgeva": "rivolgere",
    "rivolgevamo": "rivolgere",
    "rivolgevan": "rivolgere",
    "rivolgevano": "rivolgere",
    "rivolgevate": "rivolgere",
    "rivolgevi": "rivolgere",
    "rivolgevo": "rivolgere",
    "rivolgi": "rivolgere",
    "rivolgiamo": "rivolgere",
    "rivolgiate": "rivolgere",
    "rivolgimenti": "rivolgimento",
    "rivolgo": "rivolgere",
    "rivolgon": "rivolgere",
    "rivolgono": "rivolgere",
    "rivoli": "rivolo",
    "rivolle": "rivolere",
    "rivoller": "rivolere",
    "rivollero": "rivolere",
    "rivolli": "rivolere",
    "rivolse": "rivolgere",
    "rivolser": "rivolgere",
    "rivolsero": "rivolgere",
    "rivolsi": "rivolgere",
    "rivolta": "rivolto",
    "rivoltai": "rivoltare",
    "rivoltammo": "rivoltare",
    "rivoltan": "rivoltare",
    "rivoltando": "rivoltare",
    "rivoltano": "rivoltare",
    "rivoltante": "rivoltare",
    "rivoltanti": "rivoltare",
    "rivoltar": "rivoltare",
    "rivoltaron": "rivoltare",
    "rivoltarono": "rivoltare",
    "rivoltasse": "rivoltare",
    "rivoltasser": "rivoltare",
    "rivoltassero": "rivoltare",
    "rivoltassi": "rivoltare",
    "rivoltassimo": "rivoltare",
    "rivoltaste": "rivoltare",
    "rivoltasti": "rivoltare",
    "rivoltata": "rivoltare",
    "rivoltate": "rivoltare",
    "rivoltati": "rivoltare",
    "rivoltato": "rivoltare",
    "rivoltava": "rivoltare",
    "rivoltavamo": "rivoltare",
    "rivoltavan": "rivoltare",
    "rivoltavano": "rivoltare",
    "rivoltavate": "rivoltare",
    "rivoltavi": "rivoltare",
    "rivoltavo": "rivoltare",
    "rivolte": "rivolto",
    "rivoltellate": "rivoltellata",
    "rivoltelle": "rivoltella",
    "rivolterai": "rivoltare",
    "rivolteran": "rivoltare",
    "rivolteranno": "rivoltare",
    "rivolterebbe": "rivoltare",
    "rivolterebber": "rivoltare",
    "rivolterebbero": "rivoltare",
    "rivolterei": "rivoltare",
    "rivolteremmo": "rivoltare",
    "rivolteremo": "rivoltare",
    "rivoltereste": "rivoltare",
    "rivolteresti": "rivoltare",
    "rivolterete": "rivoltare",
    "rivolterà": "rivoltare",
    "rivolterò": "rivoltare",
    "rivolti": "rivolto",
    "rivoltiamo": "rivoltare",
    "rivoltiate": "rivoltare",
    "rivoltin": "rivoltare",
    "rivoltino": "rivoltare",
    "rivolto": "rivoltare",
    "rivoltola": "rivoltolare",
    "rivoltolai": "rivoltolare",
    "rivoltolammo": "rivoltolare",
    "rivoltolan": "rivoltolare",
    "rivoltolando": "rivoltolare",
    "rivoltolano": "rivoltolare",
    "rivoltolante": "rivoltolare",
    "rivoltolanti": "rivoltolare",
    "rivoltolar": "rivoltolare",
    "rivoltolaron": "rivoltolare",
    "rivoltolarono": "rivoltolare",
    "rivoltolasse": "rivoltolare",
    "rivoltolasser": "rivoltolare",
    "rivoltolassero": "rivoltolare",
    "rivoltolassi": "rivoltolare",
    "rivoltolassimo": "rivoltolare",
    "rivoltolaste": "rivoltolare",
    "rivoltolasti": "rivoltolare",
    "rivoltolata": "rivoltolare",
    "rivoltolate": "rivoltolare",
    "rivoltolati": "rivoltolare",
    "rivoltolato": "rivoltolare",
    "rivoltolava": "rivoltolare",
    "rivoltolavamo": "rivoltolare",
    "rivoltolavan": "rivoltolare",
    "rivoltolavano": "rivoltolare",
    "rivoltolavate": "rivoltolare",
    "rivoltolavi": "rivoltolare",
    "rivoltolavo": "rivoltolare",
    "rivoltolerai": "rivoltolare",
    "rivoltoleran": "rivoltolare",
    "rivoltoleranno": "rivoltolare",
    "rivoltolerebbe": "rivoltolare",
    "rivoltolerebber": "rivoltolare",
    "rivoltolerebbero": "rivoltolare",
    "rivoltolerei": "rivoltolare",
    "rivoltoleremmo": "rivoltolare",
    "rivoltoleremo": "rivoltolare",
    "rivoltolereste": "rivoltolare",
    "rivoltoleresti": "rivoltolare",
    "rivoltolerete": "rivoltolare",
    "rivoltolerà": "rivoltolare",
    "rivoltolerò": "rivoltolare",
    "rivoltoli": "rivoltolare",
    "rivoltoliamo": "rivoltolare",
    "rivoltoliate": "rivoltolare",
    "rivoltolin": "rivoltolare",
    "rivoltolino": "rivoltolare",
    "rivoltolo": "rivoltolare",
    "rivoltolò": "rivoltolare",
    "rivoltosa": "rivoltoso",
    "rivoltose": "rivoltoso",
    "rivoltosi": "rivoltoso",
    "rivoltò": "rivoltare",
    "rivoluta": "rivolere",
    "rivolute": "rivolere",
    "rivoluti": "rivolere",
    "rivoluto": "rivolere",
    "rivoluziona": "rivoluzionare",
    "rivoluzionai": "rivoluzionare",
    "rivoluzionammo": "rivoluzionare",
    "rivoluzionan": "rivoluzionare",
    "rivoluzionando": "rivoluzionare",
    "rivoluzionano": "rivoluzionare",
    "rivoluzionante": "rivoluzionare",
    "rivoluzionanti": "rivoluzionare",
    "rivoluzionar": "rivoluzionare",
    "rivoluzionari": "rivoluzionario",
    "rivoluzionaria": "rivoluzionario",
    "rivoluzionarie": "rivoluzionario",
    "rivoluzionaron": "rivoluzionare",
    "rivoluzionarono": "rivoluzionare",
    "rivoluzionasse": "rivoluzionare",
    "rivoluzionasser": "rivoluzionare",
    "rivoluzionassero": "rivoluzionare",
    "rivoluzionassi": "rivoluzionare",
    "rivoluzionassimo": "rivoluzionare",
    "rivoluzionaste": "rivoluzionare",
    "rivoluzionasti": "rivoluzionare",
    "rivoluzionata": "rivoluzionare",
    "rivoluzionate": "rivoluzionare",
    "rivoluzionati": "rivoluzionare",
    "rivoluzionato": "rivoluzionare",
    "rivoluzionava": "rivoluzionare",
    "rivoluzionavamo": "rivoluzionare",
    "rivoluzionavan": "rivoluzionare",
    "rivoluzionavano": "rivoluzionare",
    "rivoluzionavate": "rivoluzionare",
    "rivoluzionavi": "rivoluzionare",
    "rivoluzionavo": "rivoluzionare",
    "rivoluzionerai": "rivoluzionare",
    "rivoluzioneran": "rivoluzionare",
    "rivoluzioneranno": "rivoluzionare",
    "rivoluzionerebbe": "rivoluzionare",
    "rivoluzionerebber": "rivoluzionare",
    "rivoluzionerebbero": "rivoluzionare",
    "rivoluzionerei": "rivoluzionare",
    "rivoluzioneremmo": "rivoluzionare",
    "rivoluzioneremo": "rivoluzionare",
    "rivoluzionereste": "rivoluzionare",
    "rivoluzioneresti": "rivoluzionare",
    "rivoluzionerete": "rivoluzionare",
    "rivoluzionerà": "rivoluzionare",
    "rivoluzionerò": "rivoluzionare",
    "rivoluzioni": "rivoluzione",
    "rivoluzioniamo": "rivoluzionare",
    "rivoluzioniate": "rivoluzionare",
    "rivoluzionin": "rivoluzionare",
    "rivoluzionino": "rivoluzionare",
    "rivoluziono": "rivoluzionare",
    "rivoluzionò": "rivoluzionare",
    "rivorrai": "rivolere",
    "rivorran": "rivolere",
    "rivorranno": "rivolere",
    "rivorrebbe": "rivolere",
    "rivorrebber": "rivolere",
    "rivorrebbero": "rivolere",
    "rivorrei": "rivolere",
    "rivorremmo": "rivolere",
    "rivorremo": "rivolere",
    "rivorreste": "rivolere",
    "rivorresti": "rivolere",
    "rivorrete": "rivolere",
    "rivorrà": "rivolere",
    "rivorrò": "rivolere",
    "rivuoi": "rivolere",
    "rivuole": "rivolere",
    "rizza": "rizzare",
    "rizzai": "rizzare",
    "rizzammo": "rizzare",
    "rizzan": "rizzare",
    "rizzando": "rizzare",
    "rizzano": "rizzare",
    "rizzante": "rizzare",
    "rizzanti": "rizzare",
    "rizzar": "rizzare",
    "rizzaron": "rizzare",
    "rizzarono": "rizzare",
    "rizzasse": "rizzare",
    "rizzasser": "rizzare",
    "rizzassero": "rizzare",
    "rizzassi": "rizzare",
    "rizzassimo": "rizzare",
    "rizzaste": "rizzare",
    "rizzasti": "rizzare",
    "rizzata": "rizzare",
    "rizzate": "rizzare",
    "rizzati": "rizzare",
    "rizzato": "rizzare",
    "rizzava": "rizzare",
    "rizzavamo": "rizzare",
    "rizzavan": "rizzare",
    "rizzavano": "rizzare",
    "rizzavate": "rizzare",
    "rizzavi": "rizzare",
    "rizzavo": "rizzare",
    "rizzerai": "rizzare",
    "rizzeran": "rizzare",
    "rizzeranno": "rizzare",
    "rizzerebbe": "rizzare",
    "rizzerebber": "rizzare",
    "rizzerebbero": "rizzare",
    "rizzerei": "rizzare",
    "rizzeremmo": "rizzare",
    "rizzeremo": "rizzare",
    "rizzereste": "rizzare",
    "rizzeresti": "rizzare",
    "rizzerete": "rizzare",
    "rizzerà": "rizzare",
    "rizzerò": "rizzare",
    "rizzi": "rizzare",
    "rizziamo": "rizzare",
    "rizziate": "rizzare",
    "rizzin": "rizzare",
    "rizzino": "rizzare",
    "rizzo": "rizzare",
    "rizzò": "rizzare",
    "riè": "riessere",
    "robacce": "robaccia",
    "robe": "roba",
    "roboanti": "roboante",
    "robotica": "robotico",
    "robotiche": "robotico",
    "robotici": "robotico",
    "robotizza": "robotizzare",
    "robotizzai": "robotizzare",
    "robotizzammo": "robotizzare",
    "robotizzan": "robotizzare",
    "robotizzando": "robotizzare",
    "robotizzano": "robotizzare",
    "robotizzante": "robotizzare",
    "robotizzanti": "robotizzare",
    "robotizzar": "robotizzare",
    "robotizzaron": "robotizzare",
    "robotizzarono": "robotizzare",
    "robotizzasse": "robotizzare",
    "robotizzasser": "robotizzare",
    "robotizzassero": "robotizzare",
    "robotizzassi": "robotizzare",
    "robotizzassimo": "robotizzare",
    "robotizzaste": "robotizzare",
    "robotizzasti": "robotizzare",
    "robotizzata": "robotizzare",
    "robotizzate": "robotizzare",
    "robotizzati": "robotizzare",
    "robotizzato": "robotizzare",
    "robotizzava": "robotizzare",
    "robotizzavamo": "robotizzare",
    "robotizzavan": "robotizzare",
    "robotizzavano": "robotizzare",
    "robotizzavate": "robotizzare",
    "robotizzavi": "robotizzare",
    "robotizzavo": "robotizzare",
    "robotizzerai": "robotizzare",
    "robotizzeran": "robotizzare",
    "robotizzeranno": "robotizzare",
    "robotizzerebbe": "robotizzare",
    "robotizzerebber": "robotizzare",
    "robotizzerebbero": "robotizzare",
    "robotizzerei": "robotizzare",
    "robotizzeremmo": "robotizzare",
    "robotizzeremo": "robotizzare",
    "robotizzereste": "robotizzare",
    "robotizzeresti": "robotizzare",
    "robotizzerete": "robotizzare",
    "robotizzerà": "robotizzare",
    "robotizzerò": "robotizzare",
    "robotizzi": "robotizzare",
    "robotizziamo": "robotizzare",
    "robotizziate": "robotizzare",
    "robotizzin": "robotizzare",
    "robotizzino": "robotizzare",
    "robotizzo": "robotizzare",
    "robotizzò": "robotizzare",
    "robottini": "robottino",
    "robusta": "robusto",
    "robuste": "robusto",
    "robustezze": "robustezza",
    "robusti": "robusto",
    "roca": "roco",
    "rocambolesca": "rocambolesco",
    "rocambolesche": "rocambolesco",
    "rocamboleschi": "rocambolesco",
    "roccaforti": "roccaforte",
    "rocce": "roccia",
    "rocche": "rocca",
    "roccheforti": "roccaforte",
    "rocchettari": "rocchettaro",
    "rocciatori": "rocciatore",
    "roccioni": "roccione",
    "rocciosa": "roccioso",
    "rocciose": "roccioso",
    "rocciosi": "roccioso",
    "roche": "roco",
    "roci": "roco",
    "rockettari": "rockettaro",
    "roda": "rodere",
    "rodaggi": "rodaggio",
    "rodai": "rodare",
    "rodammo": "rodare",
    "rodan": "rodere",
    "rodando": "rodare",
    "rodano": "rodere",
    "rodante": "rodare",
    "rodanti": "rodare",
    "rodar": "rodare",
    "rodaron": "rodare",
    "rodarono": "rodare",
    "rodasse": "rodare",
    "rodasser": "rodare",
    "rodassero": "rodare",
    "rodassi": "rodare",
    "rodassimo": "rodare",
    "rodaste": "rodare",
    "rodasti": "rodare",
    "rodata": "rodare",
    "rodate": "rodare",
    "rodati": "rodare",
    "rodato": "rodare",
    "rodava": "rodare",
    "rodavamo": "rodare",
    "rodavan": "rodare",
    "rodavano": "rodare",
    "rodavate": "rodare",
    "rodavi": "rodare",
    "rodavo": "rodare",
    "rode": "rodere",
    "rodemmo": "rodere",
    "rodendo": "rodere",
    "rodente": "rodere",
    "rodenti": "rodere",
    "roder": "rodere",
    "roderai": "rodere",
    "roderan": "rodere",
    "roderanno": "rodere",
    "roderebbe": "rodere",
    "roderebber": "rodere",
    "roderebbero": "rodere",
    "roderei": "rodere",
    "roderemmo": "rodere",
    "roderemo": "rodere",
    "rodereste": "rodere",
    "roderesti": "rodere",
    "roderete": "rodere",
    "roderà": "rodere",
    "roderò": "rodere",
    "rodesse": "rodere",
    "rodesser": "rodere",
    "rodessero": "rodere",
    "rodessi": "rodere",
    "rodessimo": "rodere",
    "rodeste": "rodere",
    "rodesti": "rodere",
    "rodete": "rodere",
    "rodeva": "rodere",
    "rodevamo": "rodere",
    "rodevan": "rodere",
    "rodevano": "rodere",
    "rodevate": "rodere",
    "rodevi": "rodere",
    "rodevo": "rodere",
    "rodi": "rodiare",
    "rodia": "rodiare",
    "rodiai": "rodiare",
    "rodiammo": "rodiare",
    "rodiamo": "rodiare",
    "rodian": "rodiare",
    "rodiando": "rodiare",
    "rodiano": "rodiare",
    "rodiante": "rodiare",
    "rodianti": "rodiare",
    "rodiar": "rodiare",
    "rodiaron": "rodiare",
    "rodiarono": "rodiare",
    "rodiasse": "rodiare",
    "rodiasser": "rodiare",
    "rodiassero": "rodiare",
    "rodiassi": "rodiare",
    "rodiassimo": "rodiare",
    "rodiaste": "rodiare",
    "rodiasti": "rodiare",
    "rodiata": "rodiare",
    "rodiate": "rodiare",
    "rodiati": "rodiare",
    "rodiato": "rodiare",
    "rodiava": "rodiare",
    "rodiavamo": "rodiare",
    "rodiavan": "rodiare",
    "rodiavano": "rodiare",
    "rodiavate": "rodiare",
    "rodiavi": "rodiare",
    "rodiavo": "rodiare",
    "rodierai": "rodiare",
    "rodieran": "rodiare",
    "rodieranno": "rodiare",
    "rodierebbe": "rodiare",
    "rodierebber": "rodiare",
    "rodierebbero": "rodiare",
    "rodierei": "rodiare",
    "rodieremmo": "rodiare",
    "rodieremo": "rodiare",
    "rodiereste": "rodiare",
    "rodieresti": "rodiare",
    "rodierete": "rodiare",
    "rodierà": "rodiare",
    "rodierò": "rodiare",
    "rodigina": "rodigino",
    "rodigine": "rodigino",
    "rodigini": "rodigino",
    "rodin": "rodiare",
    "rodino": "rodiare",
    "rodio": "rodiare",
    "roditori": "roditore",
    "rodiò": "rodiare",
    "rodo": "rodere",
    "rodon": "rodere",
    "rodono": "rodere",
    "rodò": "rodare",
    "roga": "rogare",
    "rogai": "rogare",
    "rogammo": "rogare",
    "rogan": "rogare",
    "rogando": "rogare",
    "rogano": "rogare",
    "rogante": "rogare",
    "roganti": "rogare",
    "rogar": "rogare",
    "rogaron": "rogare",
    "rogarono": "rogare",
    "rogasse": "rogare",
    "rogasser": "rogare",
    "rogassero": "rogare",
    "rogassi": "rogare",
    "rogassimo": "rogare",
    "rogaste": "rogare",
    "rogasti": "rogare",
    "rogata": "rogare",
    "rogate": "rogare",
    "rogati": "rogare",
    "rogato": "rogare",
    "rogatori": "rogatorio",
    "rogatoria": "rogatorio",
    "rogatorie": "rogatorio",
    "rogava": "rogare",
    "rogavamo": "rogare",
    "rogavan": "rogare",
    "rogavano": "rogare",
    "rogavate": "rogare",
    "rogavi": "rogare",
    "rogavo": "rogare",
    "rogge": "roggia",
    "rogherai": "rogare",
    "rogheran": "rogare",
    "rogheranno": "rogare",
    "rogherebbe": "rogare",
    "rogherebber": "rogare",
    "rogherebbero": "rogare",
    "rogherei": "rogare",
    "rogheremmo": "rogare",
    "rogheremo": "rogare",
    "roghereste": "rogare",
    "rogheresti": "rogare",
    "rogherete": "rogare",
    "rogherà": "rogare",
    "rogherò": "rogare",
    "roghi": "rogo",
    "roghiamo": "rogare",
    "roghiate": "rogare",
    "roghin": "rogare",
    "roghino": "rogare",
    "rogiti": "rogito",
    "rogne": "rogna",
    "rognosa": "rognoso",
    "rognose": "rognoso",
    "rognosi": "rognoso",
    "rogo": "rogare",
    "rogò": "rogare",
    "rolla": "rollare",
    "rollai": "rollare",
    "rollammo": "rollare",
    "rollan": "rollare",
    "rollando": "rollare",
    "rollano": "rollare",
    "rollante": "rollare",
    "rollanti": "rollare",
    "rollar": "rollare",
    "rollaron": "rollare",
    "rollarono": "rollare",
    "rollasse": "rollare",
    "rollasser": "rollare",
    "rollassero": "rollare",
    "rollassi": "rollare",
    "rollassimo": "rollare",
    "rollaste": "rollare",
    "rollasti": "rollare",
    "rollata": "rollare",
    "rollate": "rollare",
    "rollati": "rollare",
    "rollato": "rollare",
    "rollava": "rollare",
    "rollavamo": "rollare",
    "rollavan": "rollare",
    "rollavano": "rollare",
    "rollavate": "rollare",
    "rollavi": "rollare",
    "rollavo": "rollare",
    "rollerai": "rollare",
    "rolleran": "rollare",
    "rolleranno": "rollare",
    "rollerebbe": "rollare",
    "rollerebber": "rollare",
    "rollerebbero": "rollare",
    "rollerei": "rollare",
    "rolleremmo": "rollare",
    "rolleremo": "rollare",
    "rollereste": "rollare",
    "rolleresti": "rollare",
    "rollerete": "rollare",
    "rollerà": "rollare",
    "rollerò": "rollare",
    "rolli": "rollare",
    "rolliamo": "rollare",
    "rolliate": "rollare",
    "rollin": "rollare",
    "rollino": "rollare",
    "rollo": "rollare",
    "rollò": "rollare",
    "romagnola": "romagnolo",
    "romagnole": "romagnolo",
    "romagnoli": "romagnolo",
    "romana": "romano",
    "romane": "romano",
    "romanesca": "romanesco",
    "romanesche": "romanesco",
    "romaneschi": "romanesco",
    "romani": "romano",
    "romanica": "romanico",
    "romaniche": "romanico",
    "romanici": "romanico",
    "romanisti": "romanista",
    "romanizza": "romanizzare",
    "romanizzai": "romanizzare",
    "romanizzammo": "romanizzare",
    "romanizzan": "romanizzare",
    "romanizzando": "romanizzare",
    "romanizzano": "romanizzare",
    "romanizzante": "romanizzare",
    "romanizzanti": "romanizzare",
    "romanizzar": "romanizzare",
    "romanizzaron": "romanizzare",
    "romanizzarono": "romanizzare",
    "romanizzasse": "romanizzare",
    "romanizzasser": "romanizzare",
    "romanizzassero": "romanizzare",
    "romanizzassi": "romanizzare",
    "romanizzassimo": "romanizzare",
    "romanizzaste": "romanizzare",
    "romanizzasti": "romanizzare",
    "romanizzata": "romanizzare",
    "romanizzate": "romanizzare",
    "romanizzati": "romanizzare",
    "romanizzato": "romanizzare",
    "romanizzava": "romanizzare",
    "romanizzavamo": "romanizzare",
    "romanizzavan": "romanizzare",
    "romanizzavano": "romanizzare",
    "romanizzavate": "romanizzare",
    "romanizzavi": "romanizzare",
    "romanizzavo": "romanizzare",
    "romanizzerai": "romanizzare",
    "romanizzeran": "romanizzare",
    "romanizzeranno": "romanizzare",
    "romanizzerebbe": "romanizzare",
    "romanizzerebber": "romanizzare",
    "romanizzerebbero": "romanizzare",
    "romanizzerei": "romanizzare",
    "romanizzeremmo": "romanizzare",
    "romanizzeremo": "romanizzare",
    "romanizzereste": "romanizzare",
    "romanizzeresti": "romanizzare",
    "romanizzerete": "romanizzare",
    "romanizzerà": "romanizzare",
    "romanizzerò": "romanizzare",
    "romanizzi": "romanizzare",
    "romanizziamo": "romanizzare",
    "romanizziate": "romanizzare",
    "romanizzin": "romanizzare",
    "romanizzino": "romanizzare",
    "romanizzo": "romanizzare",
    "romanizzò": "romanizzare",
    "romantica": "romantico",
    "romantiche": "romantico",
    "romantici": "romantico",
    "romanticismi": "romanticismo",
    "romanticizzata": "romanticizzato",
    "romanticizzate": "romanticizzato",
    "romanticizzati": "romanticizzato",
    "romanza": "romanzo",
    "romanzai": "romanzare",
    "romanzammo": "romanzare",
    "romanzan": "romanzare",
    "romanzando": "romanzare",
    "romanzano": "romanzare",
    "romanzante": "romanzare",
    "romanzanti": "romanzare",
    "romanzar": "romanzare",
    "romanzaron": "romanzare",
    "romanzarono": "romanzare",
    "romanzasse": "romanzare",
    "romanzasser": "romanzare",
    "romanzassero": "romanzare",
    "romanzassi": "romanzare",
    "romanzassimo": "romanzare",
    "romanzaste": "romanzare",
    "romanzasti": "romanzare",
    "romanzata": "romanzare",
    "romanzate": "romanzare",
    "romanzati": "romanzare",
    "romanzato": "romanzare",
    "romanzava": "romanzare",
    "romanzavamo": "romanzare",
    "romanzavan": "romanzare",
    "romanzavano": "romanzare",
    "romanzavate": "romanzare",
    "romanzavi": "romanzare",
    "romanzavo": "romanzare",
    "romanze": "romanzo",
    "romanzerai": "romanzare",
    "romanzeran": "romanzare",
    "romanzeranno": "romanzare",
    "romanzerebbe": "romanzare",
    "romanzerebber": "romanzare",
    "romanzerebbero": "romanzare",
    "romanzerei": "romanzare",
    "romanzeremmo": "romanzare",
    "romanzeremo": "romanzare",
    "romanzereste": "romanzare",
    "romanzeresti": "romanzare",
    "romanzerete": "romanzare",
    "romanzerà": "romanzare",
    "romanzerò": "romanzare",
    "romanzesca": "romanzesco",
    "romanzesche": "romanzesco",
    "romanzeschi": "romanzesco",
    "romanzetti": "romanzetto",
    "romanzi": "romanzo",
    "romanziamo": "romanzare",
    "romanziate": "romanzare",
    "romanzieri": "romanziere",
    "romanzin": "romanzare",
    "romanzino": "romanzare",
    "romanzo": "romanzare",
    "romanzoni": "romanzone",
    "romanzò": "romanzare",
    "romba": "rombare",
    "rombai": "rombare",
    "rombammo": "rombare",
    "romban": "rombare",
    "rombando": "rombare",
    "rombano": "rombare",
    "rombante": "rombare",
    "rombanti": "rombare",
    "rombar": "rombare",
    "rombaron": "rombare",
    "rombarono": "rombare",
    "rombasse": "rombare",
    "rombasser": "rombare",
    "rombassero": "rombare",
    "rombassi": "rombare",
    "rombassimo": "rombare",
    "rombaste": "rombare",
    "rombasti": "rombare",
    "rombata": "rombare",
    "rombate": "rombare",
    "rombati": "rombare",
    "rombato": "rombare",
    "rombava": "rombare",
    "rombavamo": "rombare",
    "rombavan": "rombare",
    "rombavano": "rombare",
    "rombavate": "rombare",
    "rombavi": "rombare",
    "rombavo": "rombare",
    "romberai": "rombare",
    "romberan": "rombare",
    "romberanno": "rombare",
    "romberebbe": "rombare",
    "romberebber": "rombare",
    "romberebbero": "rombare",
    "romberei": "rombare",
    "romberemmo": "rombare",
    "romberemo": "rombare",
    "rombereste": "rombare",
    "romberesti": "rombare",
    "romberete": "rombare",
    "romberà": "rombare",
    "romberò": "rombare",
    "rombi": "rombo",
    "rombiamo": "rombare",
    "rombiate": "rombare",
    "rombin": "rombare",
    "rombino": "rombare",
    "rombo": "rombare",
    "rombò": "rombare",
    "romea": "romeo",
    "romee": "romeo",
    "romei": "romeo",
    "romena": "romeno",
    "romene": "romeno",
    "romeni": "romeno",
    "romita": "romito",
    "romitaggi": "romitaggio",
    "romite": "romito",
    "romiti": "romito",
    "romitiana": "romitiano",
    "romitiane": "romitiano",
    "romitiani": "romitiano",
    "rompa": "rompere",
    "rompan": "rompere",
    "rompano": "rompere",
    "rompe": "rompere",
    "rompemmo": "rompere",
    "rompendo": "rompere",
    "rompente": "rompere",
    "rompenti": "rompere",
    "romper": "rompere",
    "romperai": "rompere",
    "romperan": "rompere",
    "romperanno": "rompere",
    "romperebbe": "rompere",
    "romperebber": "rompere",
    "romperebbero": "rompere",
    "romperei": "rompere",
    "romperemmo": "rompere",
    "romperemo": "rompere",
    "rompereste": "rompere",
    "romperesti": "rompere",
    "romperete": "rompere",
    "romperà": "rompere",
    "romperò": "rompere",
    "rompesse": "rompere",
    "rompesser": "rompere",
    "rompessero": "rompere",
    "rompessi": "rompere",
    "rompessimo": "rompere",
    "rompeste": "rompere",
    "rompesti": "rompere",
    "rompete": "rompere",
    "rompeva": "rompere",
    "rompevamo": "rompere",
    "rompevan": "rompere",
    "rompevano": "rompere",
    "rompevate": "rompere",
    "rompevi": "rompere",
    "rompevo": "rompere",
    "rompi": "rompere",
    "rompiamo": "rompere",
    "rompiate": "rompere",
    "rompiscatoli": "rompiscatole",
    "rompo": "rompere",
    "rompon": "rompere",
    "rompono": "rompere",
    "ronde": "ronda",
    "rondini": "rondine",
    "ronfa": "ronfare",
    "ronfai": "ronfare",
    "ronfammo": "ronfare",
    "ronfan": "ronfare",
    "ronfando": "ronfare",
    "ronfano": "ronfare",
    "ronfante": "ronfare",
    "ronfanti": "ronfare",
    "ronfar": "ronfare",
    "ronfaron": "ronfare",
    "ronfarono": "ronfare",
    "ronfasse": "ronfare",
    "ronfasser": "ronfare",
    "ronfassero": "ronfare",
    "ronfassi": "ronfare",
    "ronfassimo": "ronfare",
    "ronfaste": "ronfare",
    "ronfasti": "ronfare",
    "ronfata": "ronfare",
    "ronfate": "ronfare",
    "ronfati": "ronfare",
    "ronfato": "ronfare",
    "ronfava": "ronfare",
    "ronfavamo": "ronfare",
    "ronfavan": "ronfare",
    "ronfavano": "ronfare",
    "ronfavate": "ronfare",
    "ronfavi": "ronfare",
    "ronfavo": "ronfare",
    "ronferai": "ronfare",
    "ronferan": "ronfare",
    "ronferanno": "ronfare",
    "ronferebbe": "ronfare",
    "ronferebber": "ronfare",
    "ronferebbero": "ronfare",
    "ronferei": "ronfare",
    "ronferemmo": "ronfare",
    "ronferemo": "ronfare",
    "ronfereste": "ronfare",
    "ronferesti": "ronfare",
    "ronferete": "ronfare",
    "ronferà": "ronfare",
    "ronferò": "ronfare",
    "ronfi": "ronfare",
    "ronfiamo": "ronfare",
    "ronfiate": "ronfare",
    "ronfin": "ronfare",
    "ronfino": "ronfare",
    "ronfo": "ronfare",
    "ronfò": "ronfare",
    "ronza": "ronzare",
    "ronzai": "ronzare",
    "ronzammo": "ronzare",
    "ronzan": "ronzare",
    "ronzando": "ronzare",
    "ronzano": "ronzare",
    "ronzante": "ronzare",
    "ronzanti": "ronzare",
    "ronzar": "ronzare",
    "ronzaron": "ronzare",
    "ronzarono": "ronzare",
    "ronzasse": "ronzare",
    "ronzasser": "ronzare",
    "ronzassero": "ronzare",
    "ronzassi": "ronzare",
    "ronzassimo": "ronzare",
    "ronzaste": "ronzare",
    "ronzasti": "ronzare",
    "ronzata": "ronzare",
    "ronzate": "ronzare",
    "ronzati": "ronzare",
    "ronzato": "ronzare",
    "ronzava": "ronzare",
    "ronzavamo": "ronzare",
    "ronzavan": "ronzare",
    "ronzavano": "ronzare",
    "ronzavate": "ronzare",
    "ronzavi": "ronzare",
    "ronzavo": "ronzare",
    "ronzerai": "ronzare",
    "ronzeran": "ronzare",
    "ronzeranno": "ronzare",
    "ronzerebbe": "ronzare",
    "ronzerebber": "ronzare",
    "ronzerebbero": "ronzare",
    "ronzerei": "ronzare",
    "ronzeremmo": "ronzare",
    "ronzeremo": "ronzare",
    "ronzereste": "ronzare",
    "ronzeresti": "ronzare",
    "ronzerete": "ronzare",
    "ronzerà": "ronzare",
    "ronzerò": "ronzare",
    "ronzi": "ronzare",
    "ronziamo": "ronzare",
    "ronziate": "ronzare",
    "ronzii": "ronzio",
    "ronzin": "ronzare",
    "ronzino": "ronzare",
    "ronzo": "ronzare",
    "ronzò": "ronzare",
    "rooseveltiana": "rooseveltiano",
    "rooseveltiane": "rooseveltiano",
    "rooseveltiani": "rooseveltiano",
    "rorida": "rorido",
    "roride": "rorido",
    "roridi": "rorido",
    "rosa": "roso",
    "rosari": "rosario",
    "rosata": "rosato",
    "rosate": "rosato",
    "rosati": "rosato",
    "rose": "roso",
    "rosea": "roseo",
    "rosee": "roseo",
    "rosei": "roseo",
    "roselline": "rosellina",
    "roser": "rodere",
    "rosero": "rodere",
    "roseti": "roseto",
    "rosette": "rosetta",
    "rosi": "roso",
    "rosica": "rosicare",
    "rosicai": "rosicare",
    "rosicammo": "rosicare",
    "rosican": "rosicare",
    "rosicando": "rosicare",
    "rosicano": "rosicare",
    "rosicante": "rosicare",
    "rosicanti": "rosicare",
    "rosicar": "rosicare",
    "rosicaron": "rosicare",
    "rosicarono": "rosicare",
    "rosicasse": "rosicare",
    "rosicasser": "rosicare",
    "rosicassero": "rosicare",
    "rosicassi": "rosicare",
    "rosicassimo": "rosicare",
    "rosicaste": "rosicare",
    "rosicasti": "rosicare",
    "rosicata": "rosicare",
    "rosicate": "rosicare",
    "rosicati": "rosicare",
    "rosicato": "rosicare",
    "rosicava": "rosicare",
    "rosicavamo": "rosicare",
    "rosicavan": "rosicare",
    "rosicavano": "rosicare",
    "rosicavate": "rosicare",
    "rosicavi": "rosicare",
    "rosicavo": "rosicare",
    "rosicchi": "rosicchiare",
    "rosicchia": "rosicchiare",
    "rosicchiai": "rosicchiare",
    "rosicchiammo": "rosicchiare",
    "rosicchiamo": "rosicchiare",
    "rosicchian": "rosicchiare",
    "rosicchiando": "rosicchiare",
    "rosicchiano": "rosicchiare",
    "rosicchiante": "rosicchiare",
    "rosicchianti": "rosicchiare",
    "rosicchiar": "rosicchiare",
    "rosicchiaron": "rosicchiare",
    "rosicchiarono": "rosicchiare",
    "rosicchiasse": "rosicchiare",
    "rosicchiasser": "rosicchiare",
    "rosicchiassero": "rosicchiare",
    "rosicchiassi": "rosicchiare",
    "rosicchiassimo": "rosicchiare",
    "rosicchiaste": "rosicchiare",
    "rosicchiasti": "rosicchiare",
    "rosicchiata": "rosicchiare",
    "rosicchiate": "rosicchiare",
    "rosicchiati": "rosicchiare",
    "rosicchiato": "rosicchiare",
    "rosicchiava": "rosicchiare",
    "rosicchiavamo": "rosicchiare",
    "rosicchiavan": "rosicchiare",
    "rosicchiavano": "rosicchiare",
    "rosicchiavate": "rosicchiare",
    "rosicchiavi": "rosicchiare",
    "rosicchiavo": "rosicchiare",
    "rosicchierai": "rosicchiare",
    "rosicchieran": "rosicchiare",
    "rosicchieranno": "rosicchiare",
    "rosicchierebbe": "rosicchiare",
    "rosicchierebber": "rosicchiare",
    "rosicchierebbero": "rosicchiare",
    "rosicchierei": "rosicchiare",
    "rosicchieremmo": "rosicchiare",
    "rosicchieremo": "rosicchiare",
    "rosicchiereste": "rosicchiare",
    "rosicchieresti": "rosicchiare",
    "rosicchierete": "rosicchiare",
    "rosicchierà": "rosicchiare",
    "rosicchierò": "rosicchiare",
    "rosicchin": "rosicchiare",
    "rosicchino": "rosicchiare",
    "rosicchio": "rosicchiare",
    "rosicchiò": "rosicchiare",
    "rosicherai": "rosicare",
    "rosicheran": "rosicare",
    "rosicheranno": "rosicare",
    "rosicherebbe": "rosicare",
    "rosicherebber": "rosicare",
    "rosicherebbero": "rosicare",
    "rosicherei": "rosicare",
    "rosicheremmo": "rosicare",
    "rosicheremo": "rosicare",
    "rosichereste": "rosicare",
    "rosicheresti": "rosicare",
    "rosicherete": "rosicare",
    "rosicherà": "rosicare",
    "rosicherò": "rosicare",
    "rosichi": "rosicare",
    "rosichiamo": "rosicare",
    "rosichiate": "rosicare",
    "rosichin": "rosicare",
    "rosichino": "rosicare",
    "rosico": "rosicare",
    "rosicò": "rosicare",
    "roso": "rodere",
    "rosola": "rosolare",
    "rosolai": "rosolare",
    "rosolammo": "rosolare",
    "rosolan": "rosolare",
    "rosolando": "rosolare",
    "rosolano": "rosolare",
    "rosolante": "rosolare",
    "rosolanti": "rosolare",
    "rosolar": "rosolare",
    "rosolaron": "rosolare",
    "rosolarono": "rosolare",
    "rosolasse": "rosolare",
    "rosolasser": "rosolare",
    "rosolassero": "rosolare",
    "rosolassi": "rosolare",
    "rosolassimo": "rosolare",
    "rosolaste": "rosolare",
    "rosolasti": "rosolare",
    "rosolata": "rosolare",
    "rosolate": "rosolare",
    "rosolati": "rosolare",
    "rosolato": "rosolare",
    "rosolava": "rosolare",
    "rosolavamo": "rosolare",
    "rosolavan": "rosolare",
    "rosolavano": "rosolare",
    "rosolavate": "rosolare",
    "rosolavi": "rosolare",
    "rosolavo": "rosolare",
    "rosolerai": "rosolare",
    "rosoleran": "rosolare",
    "rosoleranno": "rosolare",
    "rosolerebbe": "rosolare",
    "rosolerebber": "rosolare",
    "rosolerebbero": "rosolare",
    "rosolerei": "rosolare",
    "rosoleremmo": "rosolare",
    "rosoleremo": "rosolare",
    "rosolereste": "rosolare",
    "rosoleresti": "rosolare",
    "rosolerete": "rosolare",
    "rosolerà": "rosolare",
    "rosolerò": "rosolare",
    "rosoli": "rosolare",
    "rosoliamo": "rosolare",
    "rosoliate": "rosolare",
    "rosolie": "rosolia",
    "rosolin": "rosolare",
    "rosolino": "rosolare",
    "rosolo": "rosolare",
    "rosolò": "rosolare",
    "rosoni": "rosone",
    "rospi": "rospo",
    "rossa": "rosso",
    "rossastra": "rossastro",
    "rossastre": "rossastro",
    "rossastri": "rossastro",
    "rosse": "rosso",
    "rosseggerai": "rosseggiare",
    "rosseggeran": "rosseggiare",
    "rosseggeranno": "rosseggiare",
    "rosseggerebbe": "rosseggiare",
    "rosseggerebber": "rosseggiare",
    "rosseggerebbero": "rosseggiare",
    "rosseggerei": "rosseggiare",
    "rosseggeremmo": "rosseggiare",
    "rosseggeremo": "rosseggiare",
    "rosseggereste": "rosseggiare",
    "rosseggeresti": "rosseggiare",
    "rosseggerete": "rosseggiare",
    "rosseggerà": "rosseggiare",
    "rosseggerò": "rosseggiare",
    "rosseggi": "rosseggiare",
    "rosseggia": "rosseggiare",
    "rosseggiai": "rosseggiare",
    "rosseggiammo": "rosseggiare",
    "rosseggiamo": "rosseggiare",
    "rosseggian": "rosseggiare",
    "rosseggiando": "rosseggiare",
    "rosseggiano": "rosseggiare",
    "rosseggiante": "rosseggiare",
    "rosseggianti": "rosseggiare",
    "rosseggiar": "rosseggiare",
    "rosseggiaron": "rosseggiare",
    "rosseggiarono": "rosseggiare",
    "rosseggiasse": "rosseggiare",
    "rosseggiasser": "rosseggiare",
    "rosseggiassero": "rosseggiare",
    "rosseggiassi": "rosseggiare",
    "rosseggiassimo": "rosseggiare",
    "rosseggiaste": "rosseggiare",
    "rosseggiasti": "rosseggiare",
    "rosseggiata": "rosseggiare",
    "rosseggiate": "rosseggiare",
    "rosseggiati": "rosseggiare",
    "rosseggiato": "rosseggiare",
    "rosseggiava": "rosseggiare",
    "rosseggiavamo": "rosseggiare",
    "rosseggiavan": "rosseggiare",
    "rosseggiavano": "rosseggiare",
    "rosseggiavate": "rosseggiare",
    "rosseggiavi": "rosseggiare",
    "rosseggiavo": "rosseggiare",
    "rosseggin": "rosseggiare",
    "rosseggino": "rosseggiare",
    "rosseggio": "rosseggiare",
    "rosseggiò": "rosseggiare",
    "rossetti": "rossetto",
    "rossi": "rosso",
    "rosso-verdi": "rosso-verde",
    "rossonera": "rossonero",
    "rossonere": "rossonero",
    "rossoneri": "rossonero",
    "rossori": "rossore",
    "rosticcerie": "rosticceria",
    "rostrata": "rostrato",
    "rostrate": "rostrato",
    "rostrati": "rostrato",
    "rostri": "rostro",
    "rota": "rotare",
    "rotabili": "rotabile",
    "rotai": "rotare",
    "rotaie": "rotaia",
    "rotammo": "rotare",
    "rotan": "rotare",
    "rotando": "rotare",
    "rotano": "rotare",
    "rotante": "rotare",
    "rotanti": "rotare",
    "rotar": "rotare",
    "rotaron": "rotare",
    "rotarono": "rotare",
    "rotasse": "rotare",
    "rotasser": "rotare",
    "rotassero": "rotare",
    "rotassi": "rotare",
    "rotassimo": "rotare",
    "rotaste": "rotare",
    "rotasti": "rotare",
    "rotata": "rotare",
    "rotate": "rotare",
    "rotati": "rotare",
    "rotative": "rotativa",
    "rotato": "rotare",
    "rotatori": "rotatorio",
    "rotatoria": "rotatorio",
    "rotatorie": "rotatorio",
    "rotava": "rotare",
    "rotavamo": "rotare",
    "rotavan": "rotare",
    "rotavano": "rotare",
    "rotavate": "rotare",
    "rotavi": "rotare",
    "rotavo": "rotare",
    "rotazioni": "rotazione",
    "rotea": "roteare",
    "roteai": "roteare",
    "roteammo": "roteare",
    "rotean": "roteare",
    "roteando": "roteare",
    "roteano": "roteare",
    "roteante": "roteare",
    "roteanti": "roteare",
    "rotear": "roteare",
    "rotearon": "roteare",
    "rotearono": "roteare",
    "roteasse": "roteare",
    "roteasser": "roteare",
    "roteassero": "roteare",
    "roteassi": "roteare",
    "roteassimo": "roteare",
    "roteaste": "roteare",
    "roteasti": "roteare",
    "roteata": "roteare",
    "roteate": "roteare",
    "roteati": "roteare",
    "roteato": "roteare",
    "roteava": "roteare",
    "roteavamo": "roteare",
    "roteavan": "roteare",
    "roteavano": "roteare",
    "roteavate": "roteare",
    "roteavi": "roteare",
    "roteavo": "roteare",
    "roteerai": "roteare",
    "roteeran": "roteare",
    "roteeranno": "roteare",
    "roteerebbe": "roteare",
    "roteerebber": "roteare",
    "roteerebbero": "roteare",
    "roteerei": "roteare",
    "roteeremmo": "roteare",
    "roteeremo": "roteare",
    "roteereste": "roteare",
    "roteeresti": "roteare",
    "roteerete": "roteare",
    "roteerà": "roteare",
    "roteerò": "roteare",
    "rotei": "roteare",
    "roteiamo": "roteare",
    "roteiate": "roteare",
    "rotein": "roteare",
    "roteino": "roteare",
    "rotelle": "rotella",
    "roteo": "roteare",
    "roterai": "rotare",
    "roteran": "rotare",
    "roteranno": "rotare",
    "roterebbe": "rotare",
    "roterebber": "rotare",
    "roterebbero": "rotare",
    "roterei": "rotare",
    "roteremmo": "rotare",
    "roteremo": "rotare",
    "rotereste": "rotare",
    "roteresti": "rotare",
    "roterete": "rotare",
    "roterà": "rotare",
    "roterò": "rotare",
    "roteò": "roteare",
    "roti": "rotare",
    "rotiamo": "rotare",
    "rotiate": "rotare",
    "rotin": "rotare",
    "rotino": "rotare",
    "roto": "rotare",
    "rotocalchi": "rotocalco",
    "rotola": "rotolare",
    "rotolai": "rotolare",
    "rotolammo": "rotolare",
    "rotolan": "rotolare",
    "rotolando": "rotolare",
    "rotolano": "rotolare",
    "rotolante": "rotolare",
    "rotolanti": "rotolare",
    "rotolar": "rotolare",
    "rotolaron": "rotolare",
    "rotolarono": "rotolare",
    "rotolasse": "rotolare",
    "rotolasser": "rotolare",
    "rotolassero": "rotolare",
    "rotolassi": "rotolare",
    "rotolassimo": "rotolare",
    "rotolaste": "rotolare",
    "rotolasti": "rotolare",
    "rotolata": "rotolare",
    "rotolate": "rotolare",
    "rotolati": "rotolare",
    "rotolato": "rotolare",
    "rotolava": "rotolare",
    "rotolavamo": "rotolare",
    "rotolavan": "rotolare",
    "rotolavano": "rotolare",
    "rotolavate": "rotolare",
    "rotolavi": "rotolare",
    "rotolavo": "rotolare",
    "rotolerai": "rotolare",
    "rotoleran": "rotolare",
    "rotoleranno": "rotolare",
    "rotolerebbe": "rotolare",
    "rotolerebber": "rotolare",
    "rotolerebbero": "rotolare",
    "rotolerei": "rotolare",
    "rotoleremmo": "rotolare",
    "rotoleremo": "rotolare",
    "rotolereste": "rotolare",
    "rotoleresti": "rotolare",
    "rotolerete": "rotolare",
    "rotolerà": "rotolare",
    "rotolerò": "rotolare",
    "rotoli": "rotolo",
    "rotoliamo": "rotolare",
    "rotoliate": "rotolare",
    "rotolin": "rotolare",
    "rotolini": "rotolino",
    "rotolino": "rotolare",
    "rotolo": "rotolare",
    "rotolò": "rotolare",
    "rotonda": "rotondo",
    "rotonde": "rotondo",
    "rotondeggianti": "rotondeggiante",
    "rotondi": "rotondo",
    "rotori": "rotore",
    "rotta": "rotto",
    "rottama": "rottamare",
    "rottamai": "rottamare",
    "rottamammo": "rottamare",
    "rottaman": "rottamare",
    "rottamando": "rottamare",
    "rottamano": "rottamare",
    "rottamante": "rottamare",
    "rottamanti": "rottamare",
    "rottamar": "rottamare",
    "rottamaron": "rottamare",
    "rottamarono": "rottamare",
    "rottamasse": "rottamare",
    "rottamasser": "rottamare",
    "rottamassero": "rottamare",
    "rottamassi": "rottamare",
    "rottamassimo": "rottamare",
    "rottamaste": "rottamare",
    "rottamasti": "rottamare",
    "rottamata": "rottamare",
    "rottamate": "rottamare",
    "rottamati": "rottamare",
    "rottamato": "rottamare",
    "rottamava": "rottamare",
    "rottamavamo": "rottamare",
    "rottamavan": "rottamare",
    "rottamavano": "rottamare",
    "rottamavate": "rottamare",
    "rottamavi": "rottamare",
    "rottamavo": "rottamare",
    "rottamazioni": "rottamazione",
    "rottamerai": "rottamare",
    "rottameran": "rottamare",
    "rottameranno": "rottamare",
    "rottamerebbe": "rottamare",
    "rottamerebber": "rottamare",
    "rottamerebbero": "rottamare",
    "rottamerei": "rottamare",
    "rottameremmo": "rottamare",
    "rottameremo": "rottamare",
    "rottamereste": "rottamare",
    "rottameresti": "rottamare",
    "rottamerete": "rottamare",
    "rottamerà": "rottamare",
    "rottamerò": "rottamare",
    "rottami": "rottame",
    "rottamiamo": "rottamare",
    "rottamiate": "rottamare",
    "rottamin": "rottamare",
    "rottamino": "rottamare",
    "rottamo": "rottamare",
    "rottamò": "rottamare",
    "rotte": "rotto",
    "rotti": "rotto",
    "rotto": "rompere",
    "rotture": "rottura",
    "rotule": "rotula",
    "rotò": "rotare",
    "rovelli": "rovello",
    "roventi": "rovente",
    "rovesce": "rovescio",
    "rovescerai": "rovesciare",
    "rovesceran": "rovesciare",
    "rovesceranno": "rovesciare",
    "rovescerebbe": "rovesciare",
    "rovescerebber": "rovesciare",
    "rovescerebbero": "rovesciare",
    "rovescerei": "rovesciare",
    "rovesceremmo": "rovesciare",
    "rovesceremo": "rovesciare",
    "rovescereste": "rovesciare",
    "rovesceresti": "rovesciare",
    "rovescerete": "rovesciare",
    "rovescerà": "rovesciare",
    "rovescerò": "rovesciare",
    "rovesci": "rovescio",
    "rovescia": "rovescio",
    "rovesciai": "rovesciare",
    "rovesciamenti": "rovesciamento",
    "rovesciammo": "rovesciare",
    "rovesciamo": "rovesciare",
    "rovescian": "rovesciare",
    "rovesciando": "rovesciare",
    "rovesciano": "rovesciare",
    "rovesciante": "rovesciare",
    "rovescianti": "rovesciare",
    "rovesciar": "rovesciare",
    "rovesciaron": "rovesciare",
    "rovesciarono": "rovesciare",
    "rovesciasse": "rovesciare",
    "rovesciasser": "rovesciare",
    "rovesciassero": "rovesciare",
    "rovesciassi": "rovesciare",
    "rovesciassimo": "rovesciare",
    "rovesciaste": "rovesciare",
    "rovesciasti": "rovesciare",
    "rovesciata": "rovesciare",
    "rovesciate": "rovesciata",
    "rovesciati": "rovesciare",
    "rovesciato": "rovesciare",
    "rovesciava": "rovesciare",
    "rovesciavamo": "rovesciare",
    "rovesciavan": "rovesciare",
    "rovesciavano": "rovesciare",
    "rovesciavate": "rovesciare",
    "rovesciavi": "rovesciare",
    "rovesciavo": "rovesciare",
    "rovescin": "rovesciare",
    "rovescino": "rovesciare",
    "rovescio": "rovesciare",
    "rovesciò": "rovesciare",
    "rovi": "rovo",
    "rovina": "rovinare",
    "rovinai": "rovinare",
    "rovinammo": "rovinare",
    "rovinan": "rovinare",
    "rovinando": "rovinare",
    "rovinano": "rovinare",
    "rovinante": "rovinare",
    "rovinanti": "rovinare",
    "rovinar": "rovinare",
    "rovinaron": "rovinare",
    "rovinarono": "rovinare",
    "rovinasse": "rovinare",
    "rovinasser": "rovinare",
    "rovinassero": "rovinare",
    "rovinassi": "rovinare",
    "rovinassimo": "rovinare",
    "rovinaste": "rovinare",
    "rovinasti": "rovinare",
    "rovinata": "rovinare",
    "rovinate": "rovinare",
    "rovinati": "rovinare",
    "rovinato": "rovinare",
    "rovinava": "rovinare",
    "rovinavamo": "rovinare",
    "rovinavan": "rovinare",
    "rovinavano": "rovinare",
    "rovinavate": "rovinare",
    "rovinavi": "rovinare",
    "rovinavo": "rovinare",
    "rovine": "rovina",
    "rovinerai": "rovinare",
    "rovineran": "rovinare",
    "rovineranno": "rovinare",
    "rovinerebbe": "rovinare",
    "rovinerebber": "rovinare",
    "rovinerebbero": "rovinare",
    "rovinerei": "rovinare",
    "rovineremmo": "rovinare",
    "rovineremo": "rovinare",
    "rovinereste": "rovinare",
    "rovineresti": "rovinare",
    "rovinerete": "rovinare",
    "rovinerà": "rovinare",
    "rovinerò": "rovinare",
    "rovini": "rovinare",
    "roviniamo": "rovinare",
    "roviniate": "rovinare",
    "rovinin": "rovinare",
    "rovinino": "rovinare",
    "rovino": "rovinare",
    "rovinosa": "rovinoso",
    "rovinose": "rovinoso",
    "rovinosi": "rovinoso",
    "rovinò": "rovinare",
    "rovista": "rovistare",
    "rovistai": "rovistare",
    "rovistammo": "rovistare",
    "rovistan": "rovistare",
    "rovistando": "rovistare",
    "rovistano": "rovistare",
    "rovistante": "rovistare",
    "rovistanti": "rovistare",
    "rovistar": "rovistare",
    "rovistaron": "rovistare",
    "rovistarono": "rovistare",
    "rovistasse": "rovistare",
    "rovistasser": "rovistare",
    "rovistassero": "rovistare",
    "rovistassi": "rovistare",
    "rovistassimo": "rovistare",
    "rovistaste": "rovistare",
    "rovistasti": "rovistare",
    "rovistata": "rovistare",
    "rovistate": "rovistare",
    "rovistati": "rovistare",
    "rovistato": "rovistare",
    "rovistava": "rovistare",
    "rovistavamo": "rovistare",
    "rovistavan": "rovistare",
    "rovistavano": "rovistare",
    "rovistavate": "rovistare",
    "rovistavi": "rovistare",
    "rovistavo": "rovistare",
    "rovisterai": "rovistare",
    "rovisteran": "rovistare",
    "rovisteranno": "rovistare",
    "rovisterebbe": "rovistare",
    "rovisterebber": "rovistare",
    "rovisterebbero": "rovistare",
    "rovisterei": "rovistare",
    "rovisteremmo": "rovistare",
    "rovisteremo": "rovistare",
    "rovistereste": "rovistare",
    "rovisteresti": "rovistare",
    "rovisterete": "rovistare",
    "rovisterà": "rovistare",
    "rovisterò": "rovistare",
    "rovisti": "rovistare",
    "rovistiamo": "rovistare",
    "rovistiate": "rovistare",
    "rovistin": "rovistare",
    "rovistino": "rovistare",
    "rovisto": "rovistare",
    "rovistò": "rovistare",
    "royalties": "royalty",
    "rozza": "rozzo",
    "rozze": "rozzo",
    "rozzezze": "rozzezza",
    "rozzi": "rozzo",
    "ruandesi": "ruandese",
    "ruba": "rubare",
    "rubacchi": "rubacchiare",
    "rubacchia": "rubacchiare",
    "rubacchiai": "rubacchiare",
    "rubacchiammo": "rubacchiare",
    "rubacchiamo": "rubacchiare",
    "rubacchian": "rubacchiare",
    "rubacchiando": "rubacchiare",
    "rubacchiano": "rubacchiare",
    "rubacchiante": "rubacchiare",
    "rubacchianti": "rubacchiare",
    "rubacchiar": "rubacchiare",
    "rubacchiaron": "rubacchiare",
    "rubacchiarono": "rubacchiare",
    "rubacchiasse": "rubacchiare",
    "rubacchiasser": "rubacchiare",
    "rubacchiassero": "rubacchiare",
    "rubacchiassi": "rubacchiare",
    "rubacchiassimo": "rubacchiare",
    "rubacchiaste": "rubacchiare",
    "rubacchiasti": "rubacchiare",
    "rubacchiata": "rubacchiare",
    "rubacchiate": "rubacchiare",
    "rubacchiati": "rubacchiare",
    "rubacchiato": "rubacchiare",
    "rubacchiava": "rubacchiare",
    "rubacchiavamo": "rubacchiare",
    "rubacchiavan": "rubacchiare",
    "rubacchiavano": "rubacchiare",
    "rubacchiavate": "rubacchiare",
    "rubacchiavi": "rubacchiare",
    "rubacchiavo": "rubacchiare",
    "rubacchierai": "rubacchiare",
    "rubacchieran": "rubacchiare",
    "rubacchieranno": "rubacchiare",
    "rubacchierebbe": "rubacchiare",
    "rubacchierebber": "rubacchiare",
    "rubacchierebbero": "rubacchiare",
    "rubacchierei": "rubacchiare",
    "rubacchieremmo": "rubacchiare",
    "rubacchieremo": "rubacchiare",
    "rubacchiereste": "rubacchiare",
    "rubacchieresti": "rubacchiare",
    "rubacchierete": "rubacchiare",
    "rubacchierà": "rubacchiare",
    "rubacchierò": "rubacchiare",
    "rubacchin": "rubacchiare",
    "rubacchino": "rubacchiare",
    "rubacchio": "rubacchiare",
    "rubacchiò": "rubacchiare",
    "rubai": "rubare",
    "rubammo": "rubare",
    "ruban": "rubare",
    "rubando": "rubare",
    "rubano": "rubare",
    "rubante": "rubare",
    "rubanti": "rubare",
    "rubar": "rubare",
    "rubaron": "rubare",
    "rubarono": "rubare",
    "rubasse": "rubare",
    "rubasser": "rubare",
    "rubassero": "rubare",
    "rubassi": "rubare",
    "rubassimo": "rubare",
    "rubaste": "rubare",
    "rubasti": "rubare",
    "rubata": "rubato",
    "rubate": "rubato",
    "rubati": "rubato",
    "rubato": "rubare",
    "rubava": "rubare",
    "rubavamo": "rubare",
    "rubavan": "rubare",
    "rubavano": "rubare",
    "rubavate": "rubare",
    "rubavi": "rubare",
    "rubavo": "rubare",
    "ruberai": "rubare",
    "ruberan": "rubare",
    "ruberanno": "rubare",
    "ruberebbe": "rubare",
    "ruberebber": "rubare",
    "ruberebbero": "rubare",
    "ruberei": "rubare",
    "ruberemmo": "rubare",
    "ruberemo": "rubare",
    "rubereste": "rubare",
    "ruberesti": "rubare",
    "ruberete": "rubare",
    "ruberie": "ruberia",
    "ruberà": "rubare",
    "ruberò": "rubare",
    "rubi": "rubare",
    "rubiamo": "rubare",
    "rubiate": "rubare",
    "rubiconda": "rubicondo",
    "rubiconde": "rubicondo",
    "rubicondi": "rubicondo",
    "rubin": "rubare",
    "rubinetti": "rubinetto",
    "rubini": "rubino",
    "rubino": "rubare",
    "rubizza": "rubizzo",
    "rubizze": "rubizzo",
    "rubizzi": "rubizzo",
    "rubli": "rublo",
    "rubo": "rubare",
    "rubrica": "rubricare",
    "rubricai": "rubricare",
    "rubricammo": "rubricare",
    "rubrican": "rubricare",
    "rubricando": "rubricare",
    "rubricano": "rubricare",
    "rubricante": "rubricare",
    "rubricanti": "rubricare",
    "rubricar": "rubricare",
    "rubricaron": "rubricare",
    "rubricarono": "rubricare",
    "rubricasse": "rubricare",
    "rubricasser": "rubricare",
    "rubricassero": "rubricare",
    "rubricassi": "rubricare",
    "rubricassimo": "rubricare",
    "rubricaste": "rubricare",
    "rubricasti": "rubricare",
    "rubricata": "rubricare",
    "rubricate": "rubricare",
    "rubricati": "rubricare",
    "rubricato": "rubricare",
    "rubricava": "rubricare",
    "rubricavamo": "rubricare",
    "rubricavan": "rubricare",
    "rubricavano": "rubricare",
    "rubricavate": "rubricare",
    "rubricavi": "rubricare",
    "rubricavo": "rubricare",
    "rubriche": "rubrica",
    "rubricherai": "rubricare",
    "rubricheran": "rubricare",
    "rubricheranno": "rubricare",
    "rubricherebbe": "rubricare",
    "rubricherebber": "rubricare",
    "rubricherebbero": "rubricare",
    "rubricherei": "rubricare",
    "rubricheremmo": "rubricare",
    "rubricheremo": "rubricare",
    "rubrichereste": "rubricare",
    "rubricheresti": "rubricare",
    "rubricherete": "rubricare",
    "rubricherà": "rubricare",
    "rubricherò": "rubricare",
    "rubrichi": "rubricare",
    "rubrichiamo": "rubricare",
    "rubrichiate": "rubricare",
    "rubrichin": "rubricare",
    "rubrichino": "rubricare",
    "rubrico": "rubricare",
    "rubricò": "rubricare",
    "rubò": "rubare",
    "ruda": "rudere",
    "rudan": "rudere",
    "rudano": "rudere",
    "rude": "rudere",
    "rudei": "rudere",
    "rudemmo": "rudere",
    "rudendo": "rudere",
    "rudente": "rudere",
    "rudenti": "rudere",
    "ruder": "rudere",
    "ruderai": "rudere",
    "ruderan": "rudere",
    "ruderanno": "rudere",
    "ruderebbe": "rudere",
    "ruderebber": "rudere",
    "ruderebbero": "rudere",
    "ruderei": "rudere",
    "ruderemmo": "rudere",
    "ruderemo": "rudere",
    "rudereste": "rudere",
    "ruderesti": "rudere",
    "ruderete": "rudere",
    "ruderi": "rudere",
    "ruderon": "rudere",
    "ruderono": "rudere",
    "ruderà": "rudere",
    "ruderò": "rudere",
    "rudesse": "rudere",
    "rudesser": "rudere",
    "rudessero": "rudere",
    "rudessi": "rudere",
    "rudessimo": "rudere",
    "rudeste": "rudere",
    "rudesti": "rudere",
    "rudete": "rudere",
    "rudeva": "rudere",
    "rudevamo": "rudere",
    "rudevan": "rudere",
    "rudevano": "rudere",
    "rudevate": "rudere",
    "rudevi": "rudere",
    "rudevo": "rudere",
    "rudezze": "rudezza",
    "rudi": "rudere",
    "rudiamo": "rudere",
    "rudiate": "rudere",
    "rudimentali": "rudimentale",
    "rudimenti": "rudimento",
    "rudo": "rudere",
    "rudon": "rudere",
    "rudono": "rudere",
    "ruduta": "rudere",
    "rudute": "rudere",
    "ruduti": "rudere",
    "ruduto": "rudere",
    "rudè": "rudere",
    "ruffiana": "ruffiano",
    "ruffiane": "ruffiano",
    "ruffiani": "ruffiano",
    "rugbisti": "rugbista",
    "ruggendo": "ruggire",
    "ruggente": "ruggire",
    "ruggenti": "ruggire",
    "ruggiamo": "ruggire",
    "ruggiate": "ruggire",
    "ruggii": "ruggire",
    "ruggimmo": "ruggire",
    "ruggini": "ruggine",
    "rugginosa": "rugginoso",
    "rugginose": "rugginoso",
    "rugginosi": "rugginoso",
    "ruggir": "ruggire",
    "ruggirai": "ruggire",
    "ruggiran": "ruggire",
    "ruggiranno": "ruggire",
    "ruggirebbe": "ruggire",
    "ruggirebber": "ruggire",
    "ruggirebbero": "ruggire",
    "ruggirei": "ruggire",
    "ruggiremmo": "ruggire",
    "ruggiremo": "ruggire",
    "ruggireste": "ruggire",
    "ruggiresti": "ruggire",
    "ruggirete": "ruggire",
    "ruggiron": "ruggire",
    "ruggirono": "ruggire",
    "ruggirà": "ruggire",
    "ruggirò": "ruggire",
    "ruggisca": "ruggire",
    "ruggiscan": "ruggire",
    "ruggiscano": "ruggire",
    "ruggisce": "ruggire",
    "ruggisci": "ruggire",
    "ruggisco": "ruggire",
    "ruggiscon": "ruggire",
    "ruggiscono": "ruggire",
    "ruggisse": "ruggire",
    "ruggisser": "ruggire",
    "ruggissero": "ruggire",
    "ruggissi": "ruggire",
    "ruggissimo": "ruggire",
    "ruggiste": "ruggire",
    "ruggisti": "ruggire",
    "ruggita": "ruggire",
    "ruggite": "ruggire",
    "ruggiti": "ruggito",
    "ruggito": "ruggire",
    "ruggiva": "ruggire",
    "ruggivamo": "ruggire",
    "ruggivan": "ruggire",
    "ruggivano": "ruggire",
    "ruggivate": "ruggire",
    "ruggivi": "ruggire",
    "ruggivo": "ruggire",
    "ruggì": "ruggire",
    "rughe": "ruga",
    "rugiade": "rugiada",
    "rugiadosa": "rugiadoso",
    "rugiadose": "rugiadoso",
    "rugiadosi": "rugiadoso",
    "rugli": "rugliare",
    "ruglia": "rugliare",
    "rugliai": "rugliare",
    "rugliammo": "rugliare",
    "rugliamo": "rugliare",
    "ruglian": "rugliare",
    "rugliando": "rugliare",
    "rugliano": "rugliare",
    "rugliante": "rugliare",
    "ruglianti": "rugliare",
    "rugliar": "rugliare",
    "rugliaron": "rugliare",
    "rugliarono": "rugliare",
    "rugliasse": "rugliare",
    "rugliasser": "rugliare",
    "rugliassero": "rugliare",
    "rugliassi": "rugliare",
    "rugliassimo": "rugliare",
    "rugliaste": "rugliare",
    "rugliasti": "rugliare",
    "rugliata": "rugliare",
    "rugliate": "rugliare",
    "rugliati": "rugliare",
    "rugliato": "rugliare",
    "rugliava": "rugliare",
    "rugliavamo": "rugliare",
    "rugliavan": "rugliare",
    "rugliavano": "rugliare",
    "rugliavate": "rugliare",
    "rugliavi": "rugliare",
    "rugliavo": "rugliare",
    "ruglierai": "rugliare",
    "ruglieran": "rugliare",
    "ruglieranno": "rugliare",
    "ruglierebbe": "rugliare",
    "ruglierebber": "rugliare",
    "ruglierebbero": "rugliare",
    "ruglierei": "rugliare",
    "ruglieremmo": "rugliare",
    "ruglieremo": "rugliare",
    "rugliereste": "rugliare",
    "ruglieresti": "rugliare",
    "ruglierete": "rugliare",
    "ruglierà": "rugliare",
    "ruglierò": "rugliare",
    "ruglin": "rugliare",
    "ruglino": "rugliare",
    "ruglio": "rugliare",
    "rugliò": "rugliare",
    "rugosa": "rugoso",
    "rugose": "rugoso",
    "rugosi": "rugoso",
    "rulla": "rullare",
    "rullai": "rullare",
    "rullammo": "rullare",
    "rullan": "rullare",
    "rullando": "rullare",
    "rullano": "rullare",
    "rullante": "rullare",
    "rullanti": "rullare",
    "rullar": "rullare",
    "rullaron": "rullare",
    "rullarono": "rullare",
    "rullasse": "rullare",
    "rullasser": "rullare",
    "rullassero": "rullare",
    "rullassi": "rullare",
    "rullassimo": "rullare",
    "rullaste": "rullare",
    "rullasti": "rullare",
    "rullata": "rullare",
    "rullate": "rullare",
    "rullati": "rullare",
    "rullato": "rullare",
    "rullava": "rullare",
    "rullavamo": "rullare",
    "rullavan": "rullare",
    "rullavano": "rullare",
    "rullavate": "rullare",
    "rullavi": "rullare",
    "rullavo": "rullare",
    "rullerai": "rullare",
    "rulleran": "rullare",
    "rulleranno": "rullare",
    "rullerebbe": "rullare",
    "rullerebber": "rullare",
    "rullerebbero": "rullare",
    "rullerei": "rullare",
    "rulleremmo": "rullare",
    "rulleremo": "rullare",
    "rullereste": "rullare",
    "rulleresti": "rullare",
    "rullerete": "rullare",
    "rullerà": "rullare",
    "rullerò": "rullare",
    "rulli": "rullo",
    "rulliamo": "rullare",
    "rulliate": "rullare",
    "rullin": "rullare",
    "rullini": "rullino",
    "rullino": "rullare",
    "rullo": "rullare",
    "rullò": "rullare",
    "rumbe": "rumba",
    "rumena": "rumeno",
    "rumene": "rumeno",
    "rumeni": "rumeno",
    "rumina": "ruminare",
    "ruminai": "ruminare",
    "ruminammo": "ruminare",
    "ruminan": "ruminare",
    "ruminando": "ruminare",
    "ruminano": "ruminare",
    "ruminante": "ruminare",
    "ruminanti": "ruminare",
    "ruminar": "ruminare",
    "ruminaron": "ruminare",
    "ruminarono": "ruminare",
    "ruminasse": "ruminare",
    "ruminasser": "ruminare",
    "ruminassero": "ruminare",
    "ruminassi": "ruminare",
    "ruminassimo": "ruminare",
    "ruminaste": "ruminare",
    "ruminasti": "ruminare",
    "ruminata": "ruminare",
    "ruminate": "ruminare",
    "ruminati": "ruminare",
    "ruminato": "ruminare",
    "ruminava": "ruminare",
    "ruminavamo": "ruminare",
    "ruminavan": "ruminare",
    "ruminavano": "ruminare",
    "ruminavate": "ruminare",
    "ruminavi": "ruminare",
    "ruminavo": "ruminare",
    "ruminazioni": "ruminazione",
    "ruminerai": "ruminare",
    "rumineran": "ruminare",
    "rumineranno": "ruminare",
    "ruminerebbe": "ruminare",
    "ruminerebber": "ruminare",
    "ruminerebbero": "ruminare",
    "ruminerei": "ruminare",
    "rumineremmo": "ruminare",
    "rumineremo": "ruminare",
    "ruminereste": "ruminare",
    "rumineresti": "ruminare",
    "ruminerete": "ruminare",
    "ruminerà": "ruminare",
    "ruminerò": "ruminare",
    "rumini": "ruminare",
    "ruminiamo": "ruminare",
    "ruminiate": "ruminare",
    "ruminin": "ruminare",
    "ruminino": "ruminare",
    "rumino": "ruminare",
    "ruminò": "ruminare",
    "rumoreggerai": "rumoreggiare",
    "rumoreggeran": "rumoreggiare",
    "rumoreggeranno": "rumoreggiare",
    "rumoreggerebbe": "rumoreggiare",
    "rumoreggerebber": "rumoreggiare",
    "rumoreggerebbero": "rumoreggiare",
    "rumoreggerei": "rumoreggiare",
    "rumoreggeremmo": "rumoreggiare",
    "rumoreggeremo": "rumoreggiare",
    "rumoreggereste": "rumoreggiare",
    "rumoreggeresti": "rumoreggiare",
    "rumoreggerete": "rumoreggiare",
    "rumoreggerà": "rumoreggiare",
    "rumoreggerò": "rumoreggiare",
    "rumoreggi": "rumoreggiare",
    "rumoreggia": "rumoreggiare",
    "rumoreggiai": "rumoreggiare",
    "rumoreggiammo": "rumoreggiare",
    "rumoreggiamo": "rumoreggiare",
    "rumoreggian": "rumoreggiare",
    "rumoreggiando": "rumoreggiare",
    "rumoreggiano": "rumoreggiare",
    "rumoreggiante": "rumoreggiare",
    "rumoreggianti": "rumoreggiare",
    "rumoreggiar": "rumoreggiare",
    "rumoreggiaron": "rumoreggiare",
    "rumoreggiarono": "rumoreggiare",
    "rumoreggiasse": "rumoreggiare",
    "rumoreggiasser": "rumoreggiare",
    "rumoreggiassero": "rumoreggiare",
    "rumoreggiassi": "rumoreggiare",
    "rumoreggiassimo": "rumoreggiare",
    "rumoreggiaste": "rumoreggiare",
    "rumoreggiasti": "rumoreggiare",
    "rumoreggiata": "rumoreggiare",
    "rumoreggiate": "rumoreggiare",
    "rumoreggiati": "rumoreggiare",
    "rumoreggiato": "rumoreggiare",
    "rumoreggiava": "rumoreggiare",
    "rumoreggiavamo": "rumoreggiare",
    "rumoreggiavan": "rumoreggiare",
    "rumoreggiavano": "rumoreggiare",
    "rumoreggiavate": "rumoreggiare",
    "rumoreggiavi": "rumoreggiare",
    "rumoreggiavo": "rumoreggiare",
    "rumoreggin": "rumoreggiare",
    "rumoreggino": "rumoreggiare",
    "rumoreggio": "rumoreggiare",
    "rumoreggiò": "rumoreggiare",
    "rumori": "rumore",
    "rumorosa": "rumoroso",
    "rumorose": "rumoroso",
    "rumorosi": "rumoroso",
    "runica": "runico",
    "runiche": "runico",
    "runici": "runico",
    "ruoli": "ruolo",
    "ruoli-chiave": "ruolo-chiave",
    "ruoli-guida": "ruolo-guida",
    "ruolini": "ruolino",
    "ruota": "ruotare",
    "ruotai": "ruotare",
    "ruotammo": "ruotare",
    "ruotan": "ruotare",
    "ruotando": "ruotare",
    "ruotano": "ruotare",
    "ruotante": "ruotare",
    "ruotanti": "ruotare",
    "ruotar": "ruotare",
    "ruotaron": "ruotare",
    "ruotarono": "ruotare",
    "ruotasse": "ruotare",
    "ruotasser": "ruotare",
    "ruotassero": "ruotare",
    "ruotassi": "ruotare",
    "ruotassimo": "ruotare",
    "ruotaste": "ruotare",
    "ruotasti": "ruotare",
    "ruotata": "ruotare",
    "ruotate": "ruotare",
    "ruotati": "ruotare",
    "ruotato": "ruotare",
    "ruotava": "ruotare",
    "ruotavamo": "ruotare",
    "ruotavan": "ruotare",
    "ruotavano": "ruotare",
    "ruotavate": "ruotare",
    "ruotavi": "ruotare",
    "ruotavo": "ruotare",
    "ruote": "ruota",
    "ruoterai": "ruotare",
    "ruoteran": "ruotare",
    "ruoteranno": "ruotare",
    "ruoterebbe": "ruotare",
    "ruoterebber": "ruotare",
    "ruoterebbero": "ruotare",
    "ruoterei": "ruotare",
    "ruoteremmo": "ruotare",
    "ruoteremo": "ruotare",
    "ruotereste": "ruotare",
    "ruoteresti": "ruotare",
    "ruoterete": "ruotare",
    "ruoterà": "ruotare",
    "ruoterò": "ruotare",
    "ruoti": "ruotare",
    "ruotiamo": "ruotare",
    "ruotiate": "ruotare",
    "ruotin": "ruotare",
    "ruotino": "ruotare",
    "ruoto": "ruotare",
    "ruotò": "ruotare",
    "rupestri": "rupestre",
    "rupi": "rupe",
    "rupie": "rupia",
    "ruppe": "rompere",
    "rupper": "rompere",
    "ruppero": "rompere",
    "ruppi": "rompere",
    "rurali": "rurale",
    "ruscelli": "ruscello",
    "ruspa": "ruspare",
    "ruspai": "ruspare",
    "ruspammo": "ruspare",
    "ruspan": "ruspare",
    "ruspando": "ruspare",
    "ruspano": "ruspare",
    "ruspante": "ruspare",
    "ruspanti": "ruspare",
    "ruspar": "ruspare",
    "rusparon": "ruspare",
    "rusparono": "ruspare",
    "ruspasse": "ruspare",
    "ruspasser": "ruspare",
    "ruspassero": "ruspare",
    "ruspassi": "ruspare",
    "ruspassimo": "ruspare",
    "ruspaste": "ruspare",
    "ruspasti": "ruspare",
    "ruspata": "ruspare",
    "ruspate": "ruspare",
    "ruspati": "ruspare",
    "ruspato": "ruspare",
    "ruspava": "ruspare",
    "ruspavamo": "ruspare",
    "ruspavan": "ruspare",
    "ruspavano": "ruspare",
    "ruspavate": "ruspare",
    "ruspavi": "ruspare",
    "ruspavo": "ruspare",
    "ruspe": "ruspa",
    "rusperai": "ruspare",
    "rusperan": "ruspare",
    "rusperanno": "ruspare",
    "rusperebbe": "ruspare",
    "rusperebber": "ruspare",
    "rusperebbero": "ruspare",
    "rusperei": "ruspare",
    "rusperemmo": "ruspare",
    "rusperemo": "ruspare",
    "ruspereste": "ruspare",
    "rusperesti": "ruspare",
    "rusperete": "ruspare",
    "rusperà": "ruspare",
    "rusperò": "ruspare",
    "ruspi": "ruspare",
    "ruspiamo": "ruspare",
    "ruspiate": "ruspare",
    "ruspin": "ruspare",
    "ruspino": "ruspare",
    "ruspo": "ruspare",
    "ruspò": "ruspare",
    "russa": "russo",
    "russai": "russare",
    "russammo": "russare",
    "russan": "russare",
    "russando": "russare",
    "russano": "russare",
    "russante": "russare",
    "russanti": "russare",
    "russar": "russare",
    "russaron": "russare",
    "russarono": "russare",
    "russasse": "russare",
    "russasser": "russare",
    "russassero": "russare",
    "russassi": "russare",
    "russassimo": "russare",
    "russaste": "russare",
    "russasti": "russare",
    "russata": "russare",
    "russate": "russare",
    "russati": "russare",
    "russato": "russare",
    "russatori": "russatore",
    "russava": "russare",
    "russavamo": "russare",
    "russavan": "russare",
    "russavano": "russare",
    "russavate": "russare",
    "russavi": "russare",
    "russavo": "russare",
    "russe": "russo",
    "russerai": "russare",
    "russeran": "russare",
    "russeranno": "russare",
    "russerebbe": "russare",
    "russerebber": "russare",
    "russerebbero": "russare",
    "russerei": "russare",
    "russeremmo": "russare",
    "russeremo": "russare",
    "russereste": "russare",
    "russeresti": "russare",
    "russerete": "russare",
    "russerà": "russare",
    "russerò": "russare",
    "russi": "russo",
    "russiamo": "russare",
    "russiate": "russare",
    "russin": "russare",
    "russino": "russare",
    "russo": "russare",
    "russo-americana": "russo-americano",
    "russo-americane": "russo-americano",
    "russo-americani": "russo-americano",
    "russò": "russare",
    "rustica": "rustico",
    "rusticana": "rusticano",
    "rusticane": "rusticano",
    "rusticani": "rusticano",
    "rustiche": "rustico",
    "rustici": "rustico",
    "rute": "ruta",
    "rutta": "ruttare",
    "ruttai": "ruttare",
    "ruttammo": "ruttare",
    "ruttan": "ruttare",
    "ruttando": "ruttare",
    "ruttano": "ruttare",
    "ruttante": "ruttare",
    "ruttanti": "ruttare",
    "ruttar": "ruttare",
    "ruttaron": "ruttare",
    "ruttarono": "ruttare",
    "ruttasse": "ruttare",
    "ruttasser": "ruttare",
    "ruttassero": "ruttare",
    "ruttassi": "ruttare",
    "ruttassimo": "ruttare",
    "ruttaste": "ruttare",
    "ruttasti": "ruttare",
    "ruttata": "ruttare",
    "ruttate": "ruttare",
    "ruttati": "ruttare",
    "ruttato": "ruttare",
    "ruttava": "ruttare",
    "ruttavamo": "ruttare",
    "ruttavan": "ruttare",
    "ruttavano": "ruttare",
    "ruttavate": "ruttare",
    "ruttavi": "ruttare",
    "ruttavo": "ruttare",
    "rutterai": "ruttare",
    "rutteran": "ruttare",
    "rutteranno": "ruttare",
    "rutterebbe": "ruttare",
    "rutterebber": "ruttare",
    "rutterebbero": "ruttare",
    "rutterei": "ruttare",
    "rutteremmo": "ruttare",
    "rutteremo": "ruttare",
    "ruttereste": "ruttare",
    "rutteresti": "ruttare",
    "rutterete": "ruttare",
    "rutterà": "ruttare",
    "rutterò": "ruttare",
    "rutti": "rutto",
    "ruttiamo": "ruttare",
    "ruttiate": "ruttare",
    "ruttin": "ruttare",
    "ruttino": "ruttare",
    "rutto": "ruttare",
    "ruttò": "ruttare",
    "ruvida": "ruvido",
    "ruvide": "ruvido",
    "ruvidezze": "ruvidezza",
    "ruvidi": "ruvido",
    "ruzza": "ruzzare",
    "ruzzai": "ruzzare",
    "ruzzammo": "ruzzare",
    "ruzzan": "ruzzare",
    "ruzzando": "ruzzare",
    "ruzzano": "ruzzare",
    "ruzzante": "ruzzare",
    "ruzzanti": "ruzzare",
    "ruzzar": "ruzzare",
    "ruzzaron": "ruzzare",
    "ruzzarono": "ruzzare",
    "ruzzasse": "ruzzare",
    "ruzzasser": "ruzzare",
    "ruzzassero": "ruzzare",
    "ruzzassi": "ruzzare",
    "ruzzassimo": "ruzzare",
    "ruzzaste": "ruzzare",
    "ruzzasti": "ruzzare",
    "ruzzata": "ruzzare",
    "ruzzate": "ruzzare",
    "ruzzati": "ruzzare",
    "ruzzato": "ruzzare",
    "ruzzava": "ruzzare",
    "ruzzavamo": "ruzzare",
    "ruzzavan": "ruzzare",
    "ruzzavano": "ruzzare",
    "ruzzavate": "ruzzare",
    "ruzzavi": "ruzzare",
    "ruzzavo": "ruzzare",
    "ruzzerai": "ruzzare",
    "ruzzeran": "ruzzare",
    "ruzzeranno": "ruzzare",
    "ruzzerebbe": "ruzzare",
    "ruzzerebber": "ruzzare",
    "ruzzerebbero": "ruzzare",
    "ruzzerei": "ruzzare",
    "ruzzeremmo": "ruzzare",
    "ruzzeremo": "ruzzare",
    "ruzzereste": "ruzzare",
    "ruzzeresti": "ruzzare",
    "ruzzerete": "ruzzare",
    "ruzzerà": "ruzzare",
    "ruzzerò": "ruzzare",
    "ruzzi": "ruzzare",
    "ruzziamo": "ruzzare",
    "ruzziate": "ruzzare",
    "ruzzin": "ruzzare",
    "ruzzino": "ruzzare",
    "ruzzo": "ruzzare",
    "ruzzola": "ruzzolare",
    "ruzzolai": "ruzzolare",
    "ruzzolammo": "ruzzolare",
    "ruzzolan": "ruzzolare",
    "ruzzolando": "ruzzolare",
    "ruzzolano": "ruzzolare",
    "ruzzolante": "ruzzolare",
    "ruzzolanti": "ruzzolare",
    "ruzzolar": "ruzzolare",
    "ruzzolaron": "ruzzolare",
    "ruzzolarono": "ruzzolare",
    "ruzzolasse": "ruzzolare",
    "ruzzolasser": "ruzzolare",
    "ruzzolassero": "ruzzolare",
    "ruzzolassi": "ruzzolare",
    "ruzzolassimo": "ruzzolare",
    "ruzzolaste": "ruzzolare",
    "ruzzolasti": "ruzzolare",
    "ruzzolata": "ruzzolare",
    "ruzzolate": "ruzzolare",
    "ruzzolati": "ruzzolare",
    "ruzzolato": "ruzzolare",
    "ruzzolava": "ruzzolare",
    "ruzzolavamo": "ruzzolare",
    "ruzzolavan": "ruzzolare",
    "ruzzolavano": "ruzzolare",
    "ruzzolavate": "ruzzolare",
    "ruzzolavi": "ruzzolare",
    "ruzzolavo": "ruzzolare",
    "ruzzolerai": "ruzzolare",
    "ruzzoleran": "ruzzolare",
    "ruzzoleranno": "ruzzolare",
    "ruzzolerebbe": "ruzzolare",
    "ruzzolerebber": "ruzzolare",
    "ruzzolerebbero": "ruzzolare",
    "ruzzolerei": "ruzzolare",
    "ruzzoleremmo": "ruzzolare",
    "ruzzoleremo": "ruzzolare",
    "ruzzolereste": "ruzzolare",
    "ruzzoleresti": "ruzzolare",
    "ruzzolerete": "ruzzolare",
    "ruzzolerà": "ruzzolare",
    "ruzzolerò": "ruzzolare",
    "ruzzoli": "ruzzolare",
    "ruzzoliamo": "ruzzolare",
    "ruzzoliate": "ruzzolare",
    "ruzzolin": "ruzzolare",
    "ruzzolino": "ruzzolare",
    "ruzzolo": "ruzzolare",
    "ruzzoloni": "ruzzolone",
    "ruzzolò": "ruzzolare",
    "ruzzò": "ruzzare",
    "s'": "si",
    "sa": "sapere",
    "sabati": "sabato",
    "sabauda": "sabaudo",
    "sabaude": "sabaudo",
    "sabaudi": "sabaudo",
    "sabbatica": "sabbatico",
    "sabbatiche": "sabbatico",
    "sabbatici": "sabbatico",
    "sabbi": "sabbiare",
    "sabbia": "sabbiare",
    "sabbiai": "sabbiare",
    "sabbiammo": "sabbiare",
    "sabbiamo": "sabbiare",
    "sabbian": "sabbiare",
    "sabbiando": "sabbiare",
    "sabbiano": "sabbiare",
    "sabbiante": "sabbiare",
    "sabbianti": "sabbiare",
    "sabbiar": "sabbiare",
    "sabbiaron": "sabbiare",
    "sabbiarono": "sabbiare",
    "sabbiasse": "sabbiare",
    "sabbiasser": "sabbiare",
    "sabbiassero": "sabbiare",
    "sabbiassi": "sabbiare",
    "sabbiassimo": "sabbiare",
    "sabbiaste": "sabbiare",
    "sabbiasti": "sabbiare",
    "sabbiata": "sabbiare",
    "sabbiate": "sabbiare",
    "sabbiati": "sabbiare",
    "sabbiato": "sabbiare",
    "sabbiava": "sabbiare",
    "sabbiavamo": "sabbiare",
    "sabbiavan": "sabbiare",
    "sabbiavano": "sabbiare",
    "sabbiavate": "sabbiare",
    "sabbiavi": "sabbiare",
    "sabbiavo": "sabbiare",
    "sabbie": "sabbia",
    "sabbierai": "sabbiare",
    "sabbieran": "sabbiare",
    "sabbieranno": "sabbiare",
    "sabbierebbe": "sabbiare",
    "sabbierebber": "sabbiare",
    "sabbierebbero": "sabbiare",
    "sabbierei": "sabbiare",
    "sabbieremmo": "sabbiare",
    "sabbieremo": "sabbiare",
    "sabbiereste": "sabbiare",
    "sabbieresti": "sabbiare",
    "sabbierete": "sabbiare",
    "sabbierà": "sabbiare",
    "sabbierò": "sabbiare",
    "sabbin": "sabbiare",
    "sabbino": "sabbiare",
    "sabbio": "sabbiare",
    "sabbiosa": "sabbioso",
    "sabbiose": "sabbioso",
    "sabbiosi": "sabbioso",
    "sabbiò": "sabbiare",
    "sabota": "sabotare",
    "sabotaggi": "sabotaggio",
    "sabotai": "sabotare",
    "sabotammo": "sabotare",
    "sabotan": "sabotare",
    "sabotando": "sabotare",
    "sabotano": "sabotare",
    "sabotante": "sabotare",
    "sabotanti": "sabotare",
    "sabotar": "sabotare",
    "sabotaron": "sabotare",
    "sabotarono": "sabotare",
    "sabotasse": "sabotare",
    "sabotasser": "sabotare",
    "sabotassero": "sabotare",
    "sabotassi": "sabotare",
    "sabotassimo": "sabotare",
    "sabotaste": "sabotare",
    "sabotasti": "sabotare",
    "sabotata": "sabotare",
    "sabotate": "sabotare",
    "sabotati": "sabotare",
    "sabotato": "sabotare",
    "sabotatori": "sabotatore",
    "sabotava": "sabotare",
    "sabotavamo": "sabotare",
    "sabotavan": "sabotare",
    "sabotavano": "sabotare",
    "sabotavate": "sabotare",
    "sabotavi": "sabotare",
    "sabotavo": "sabotare",
    "saboterai": "sabotare",
    "saboteran": "sabotare",
    "saboteranno": "sabotare",
    "saboterebbe": "sabotare",
    "saboterebber": "sabotare",
    "saboterebbero": "sabotare",
    "saboterei": "sabotare",
    "saboteremmo": "sabotare",
    "saboteremo": "sabotare",
    "sabotereste": "sabotare",
    "saboteresti": "sabotare",
    "saboterete": "sabotare",
    "saboterà": "sabotare",
    "saboterò": "sabotare",
    "saboti": "sabotare",
    "sabotiamo": "sabotare",
    "sabotiate": "sabotare",
    "sabotin": "sabotare",
    "sabotino": "sabotare",
    "saboto": "sabotare",
    "sabotò": "sabotare",
    "saccarifera": "saccarifero",
    "saccarifere": "saccarifero",
    "saccariferi": "saccarifero",
    "saccature": "saccatura",
    "saccenti": "saccente",
    "sacche": "sacca",
    "saccheggerai": "saccheggiare",
    "saccheggeran": "saccheggiare",
    "saccheggeranno": "saccheggiare",
    "saccheggerebbe": "saccheggiare",
    "saccheggerebber": "saccheggiare",
    "saccheggerebbero": "saccheggiare",
    "saccheggerei": "saccheggiare",
    "saccheggeremmo": "saccheggiare",
    "saccheggeremo": "saccheggiare",
    "saccheggereste": "saccheggiare",
    "saccheggeresti": "saccheggiare",
    "saccheggerete": "saccheggiare",
    "saccheggerà": "saccheggiare",
    "saccheggerò": "saccheggiare",
    "saccheggi": "saccheggio",
    "saccheggia": "saccheggiare",
    "saccheggiai": "saccheggiare",
    "saccheggiammo": "saccheggiare",
    "saccheggiamo": "saccheggiare",
    "saccheggian": "saccheggiare",
    "saccheggiando": "saccheggiare",
    "saccheggiano": "saccheggiare",
    "saccheggiante": "saccheggiare",
    "saccheggianti": "saccheggiare",
    "saccheggiar": "saccheggiare",
    "saccheggiaron": "saccheggiare",
    "saccheggiarono": "saccheggiare",
    "saccheggiasse": "saccheggiare",
    "saccheggiasser": "saccheggiare",
    "saccheggiassero": "saccheggiare",
    "saccheggiassi": "saccheggiare",
    "saccheggiassimo": "saccheggiare",
    "saccheggiaste": "saccheggiare",
    "saccheggiasti": "saccheggiare",
    "saccheggiata": "saccheggiare",
    "saccheggiate": "saccheggiare",
    "saccheggiati": "saccheggiare",
    "saccheggiato": "saccheggiare",
    "saccheggiava": "saccheggiare",
    "saccheggiavamo": "saccheggiare",
    "saccheggiavan": "saccheggiare",
    "saccheggiavano": "saccheggiare",
    "saccheggiavate": "saccheggiare",
    "saccheggiavi": "saccheggiare",
    "saccheggiavo": "saccheggiare",
    "saccheggin": "saccheggiare",
    "saccheggino": "saccheggiare",
    "saccheggio": "saccheggiare",
    "saccheggiò": "saccheggiare",
    "sacchetti": "sacchetto",
    "sacchettini": "sacchettino",
    "sacchi": "sacco",
    "sacchiani": "sacchiano",
    "saccopelisti": "saccopelista",
    "sacerdotali": "sacerdotale",
    "sacerdotesse": "sacerdotessa",
    "sacerdoti": "sacerdote",
    "sacerdozi": "sacerdozio",
    "sacra": "sacro",
    "sacrali": "sacrale",
    "sacramenta": "sacramentare",
    "sacramentai": "sacramentare",
    "sacramentali": "sacramentale",
    "sacramentammo": "sacramentare",
    "sacramentan": "sacramentare",
    "sacramentando": "sacramentare",
    "sacramentano": "sacramentare",
    "sacramentante": "sacramentare",
    "sacramentanti": "sacramentare",
    "sacramentar": "sacramentare",
    "sacramentaron": "sacramentare",
    "sacramentarono": "sacramentare",
    "sacramentasse": "sacramentare",
    "sacramentasser": "sacramentare",
    "sacramentassero": "sacramentare",
    "sacramentassi": "sacramentare",
    "sacramentassimo": "sacramentare",
    "sacramentaste": "sacramentare",
    "sacramentasti": "sacramentare",
    "sacramentata": "sacramentare",
    "sacramentate": "sacramentare",
    "sacramentati": "sacramentare",
    "sacramentato": "sacramentare",
    "sacramentava": "sacramentare",
    "sacramentavamo": "sacramentare",
    "sacramentavan": "sacramentare",
    "sacramentavano": "sacramentare",
    "sacramentavate": "sacramentare",
    "sacramentavi": "sacramentare",
    "sacramentavo": "sacramentare",
    "sacramenterai": "sacramentare",
    "sacramenteran": "sacramentare",
    "sacramenteranno": "sacramentare",
    "sacramenterebbe": "sacramentare",
    "sacramenterebber": "sacramentare",
    "sacramenterebbero": "sacramentare",
    "sacramenterei": "sacramentare",
    "sacramenteremmo": "sacramentare",
    "sacramenteremo": "sacramentare",
    "sacramentereste": "sacramentare",
    "sacramenteresti": "sacramentare",
    "sacramenterete": "sacramentare",
    "sacramenterà": "sacramentare",
    "sacramenterò": "sacramentare",
    "sacramenti": "sacramento",
    "sacramentiamo": "sacramentare",
    "sacramentiate": "sacramentare",
    "sacramentin": "sacramentare",
    "sacramentino": "sacramentare",
    "sacramento": "sacramentare",
    "sacramentò": "sacramentare",
    "sacrari": "sacrario",
    "sacre": "sacro",
    "sacrestani": "sacrestano",
    "sacrestie": "sacrestia",
    "sacri": "sacro",
    "sacrifica": "sacrificare",
    "sacrificai": "sacrificare",
    "sacrificali": "sacrificale",
    "sacrificammo": "sacrificare",
    "sacrifican": "sacrificare",
    "sacrificando": "sacrificare",
    "sacrificano": "sacrificare",
    "sacrificante": "sacrificare",
    "sacrificanti": "sacrificare",
    "sacrificar": "sacrificare",
    "sacrificaron": "sacrificare",
    "sacrificarono": "sacrificare",
    "sacrificasse": "sacrificare",
    "sacrificasser": "sacrificare",
    "sacrificassero": "sacrificare",
    "sacrificassi": "sacrificare",
    "sacrificassimo": "sacrificare",
    "sacrificaste": "sacrificare",
    "sacrificasti": "sacrificare",
    "sacrificata": "sacrificato",
    "sacrificate": "sacrificato",
    "sacrificati": "sacrificato",
    "sacrificato": "sacrificare",
    "sacrificava": "sacrificare",
    "sacrificavamo": "sacrificare",
    "sacrificavan": "sacrificare",
    "sacrificavano": "sacrificare",
    "sacrificavate": "sacrificare",
    "sacrificavi": "sacrificare",
    "sacrificavo": "sacrificare",
    "sacrificherai": "sacrificare",
    "sacrificheran": "sacrificare",
    "sacrificheranno": "sacrificare",
    "sacrificherebbe": "sacrificare",
    "sacrificherebber": "sacrificare",
    "sacrificherebbero": "sacrificare",
    "sacrificherei": "sacrificare",
    "sacrificheremmo": "sacrificare",
    "sacrificheremo": "sacrificare",
    "sacrifichereste": "sacrificare",
    "sacrificheresti": "sacrificare",
    "sacrificherete": "sacrificare",
    "sacrificherà": "sacrificare",
    "sacrificherò": "sacrificare",
    "sacrifichi": "sacrificare",
    "sacrifichiamo": "sacrificare",
    "sacrifichiate": "sacrificare",
    "sacrifichin": "sacrificare",
    "sacrifichino": "sacrificare",
    "sacrifici": "sacrificio",
    "sacrifico": "sacrificare",
    "sacrificò": "sacrificare",
    "sacrilega": "sacrilego",
    "sacrileghe": "sacrilego",
    "sacrileghi": "sacrilego",
    "sacrilegi": "sacrilegio",
    "sacrosanta": "sacrosanto",
    "sacrosante": "sacrosanto",
    "sacrosanti": "sacrosanto",
    "sadica": "sadico",
    "sadiche": "sadico",
    "sadici": "sadico",
    "sadismi": "sadismo",
    "sadomasochismi": "sadomasochismo",
    "saetta": "saettare",
    "saettai": "saettare",
    "saettammo": "saettare",
    "saettan": "saettare",
    "saettando": "saettare",
    "saettano": "saettare",
    "saettante": "saettare",
    "saettanti": "saettare",
    "saettar": "saettare",
    "saettaron": "saettare",
    "saettarono": "saettare",
    "saettasse": "saettare",
    "saettasser": "saettare",
    "saettassero": "saettare",
    "saettassi": "saettare",
    "saettassimo": "saettare",
    "saettaste": "saettare",
    "saettasti": "saettare",
    "saettata": "saettare",
    "saettate": "saettare",
    "saettati": "saettare",
    "saettato": "saettare",
    "saettava": "saettare",
    "saettavamo": "saettare",
    "saettavan": "saettare",
    "saettavano": "saettare",
    "saettavate": "saettare",
    "saettavi": "saettare",
    "saettavo": "saettare",
    "saette": "saetta",
    "saetterai": "saettare",
    "saetteran": "saettare",
    "saetteranno": "saettare",
    "saetterebbe": "saettare",
    "saetterebber": "saettare",
    "saetterebbero": "saettare",
    "saetterei": "saettare",
    "saetteremmo": "saettare",
    "saetteremo": "saettare",
    "saettereste": "saettare",
    "saetteresti": "saettare",
    "saetterete": "saettare",
    "saetterà": "saettare",
    "saetterò": "saettare",
    "saetti": "saettare",
    "saettiamo": "saettare",
    "saettiate": "saettare",
    "saettin": "saettare",
    "saettino": "saettare",
    "saetto": "saettare",
    "saettò": "saettare",
    "sagaci": "sagace",
    "sagacie": "sagacia",
    "sagge": "saggio",
    "saggerai": "saggiare",
    "saggeran": "saggiare",
    "saggeranno": "saggiare",
    "saggerebbe": "saggiare",
    "saggerebber": "saggiare",
    "saggerebbero": "saggiare",
    "saggerei": "saggiare",
    "saggeremmo": "saggiare",
    "saggeremo": "saggiare",
    "saggereste": "saggiare",
    "saggeresti": "saggiare",
    "saggerete": "saggiare",
    "saggerà": "saggiare",
    "saggerò": "saggiare",
    "saggezze": "saggezza",
    "saggi": "saggio",
    "saggia": "saggio",
    "saggiai": "saggiare",
    "saggiammo": "saggiare",
    "saggiamo": "saggiare",
    "saggian": "saggiare",
    "saggiando": "saggiare",
    "saggiano": "saggiare",
    "saggiante": "saggiare",
    "saggianti": "saggiare",
    "saggiar": "saggiare",
    "saggiaron": "saggiare",
    "saggiarono": "saggiare",
    "saggiasse": "saggiare",
    "saggiasser": "saggiare",
    "saggiassero": "saggiare",
    "saggiassi": "saggiare",
    "saggiassimo": "saggiare",
    "saggiaste": "saggiare",
    "saggiasti": "saggiare",
    "saggiata": "saggiare",
    "saggiate": "saggiare",
    "saggiati": "saggiare",
    "saggiato": "saggiare",
    "saggiava": "saggiare",
    "saggiavamo": "saggiare",
    "saggiavan": "saggiare",
    "saggiavano": "saggiare",
    "saggiavate": "saggiare",
    "saggiavi": "saggiare",
    "saggiavo": "saggiare",
    "saggin": "saggiare",
    "saggina": "sagginare",
    "sagginai": "sagginare",
    "sagginammo": "sagginare",
    "sagginan": "sagginare",
    "sagginando": "sagginare",
    "sagginano": "sagginare",
    "sagginante": "sagginare",
    "sagginanti": "sagginare",
    "sagginar": "sagginare",
    "sagginaron": "sagginare",
    "sagginarono": "sagginare",
    "sagginasse": "sagginare",
    "sagginasser": "sagginare",
    "sagginassero": "sagginare",
    "sagginassi": "sagginare",
    "sagginassimo": "sagginare",
    "sagginaste": "sagginare",
    "sagginasti": "sagginare",
    "sagginata": "sagginare",
    "sagginate": "sagginare",
    "sagginati": "sagginare",
    "sagginato": "sagginare",
    "sagginava": "sagginare",
    "sagginavamo": "sagginare",
    "sagginavan": "sagginare",
    "sagginavano": "sagginare",
    "sagginavate": "sagginare",
    "sagginavi": "sagginare",
    "sagginavo": "sagginare",
    "sagginerai": "sagginare",
    "saggineran": "sagginare",
    "saggineranno": "sagginare",
    "sagginerebbe": "sagginare",
    "sagginerebber": "sagginare",
    "sagginerebbero": "sagginare",
    "sagginerei": "sagginare",
    "saggineremmo": "sagginare",
    "saggineremo": "sagginare",
    "sagginereste": "sagginare",
    "saggineresti": "sagginare",
    "sagginerete": "sagginare",
    "sagginerà": "sagginare",
    "sagginerò": "sagginare",
    "saggini": "sagginare",
    "sagginiamo": "sagginare",
    "sagginiate": "sagginare",
    "sagginin": "sagginare",
    "sagginino": "sagginare",
    "saggino": "sagginare",
    "sagginò": "sagginare",
    "saggio": "saggiare",
    "saggisti": "saggista",
    "saggistica": "saggistico",
    "saggistiche": "saggistico",
    "saggistici": "saggistico",
    "saggiò": "saggiare",
    "saghe": "saga",
    "sagoma": "sagomare",
    "sagomai": "sagomare",
    "sagomammo": "sagomare",
    "sagoman": "sagomare",
    "sagomando": "sagomare",
    "sagomano": "sagomare",
    "sagomante": "sagomare",
    "sagomanti": "sagomare",
    "sagomar": "sagomare",
    "sagomaron": "sagomare",
    "sagomarono": "sagomare",
    "sagomasse": "sagomare",
    "sagomasser": "sagomare",
    "sagomassero": "sagomare",
    "sagomassi": "sagomare",
    "sagomassimo": "sagomare",
    "sagomaste": "sagomare",
    "sagomasti": "sagomare",
    "sagomata": "sagomare",
    "sagomate": "sagomare",
    "sagomati": "sagomare",
    "sagomato": "sagomare",
    "sagomava": "sagomare",
    "sagomavamo": "sagomare",
    "sagomavan": "sagomare",
    "sagomavano": "sagomare",
    "sagomavate": "sagomare",
    "sagomavi": "sagomare",
    "sagomavo": "sagomare",
    "sagome": "sagoma",
    "sagomerai": "sagomare",
    "sagomeran": "sagomare",
    "sagomeranno": "sagomare",
    "sagomerebbe": "sagomare",
    "sagomerebber": "sagomare",
    "sagomerebbero": "sagomare",
    "sagomerei": "sagomare",
    "sagomeremmo": "sagomare",
    "sagomeremo": "sagomare",
    "sagomereste": "sagomare",
    "sagomeresti": "sagomare",
    "sagomerete": "sagomare",
    "sagomerà": "sagomare",
    "sagomerò": "sagomare",
    "sagomi": "sagomare",
    "sagomiamo": "sagomare",
    "sagomiate": "sagomare",
    "sagomin": "sagomare",
    "sagomino": "sagomare",
    "sagomo": "sagomare",
    "sagomò": "sagomare",
    "sagrati": "sagrato",
    "sagre": "sagra",
    "sagrestie": "sagrestia",
    "sai": "sapere",
    "sala": "salare",
    "salaci": "salace",
    "salai": "salare",
    "salami": "salame",
    "salamini": "salamino",
    "salammo": "salare",
    "salan": "salare",
    "salando": "salare",
    "salano": "salare",
    "salante": "salare",
    "salanti": "salare",
    "salar": "salare",
    "salari": "salario",
    "salaria": "salariare",
    "salariai": "salariare",
    "salariali": "salariale",
    "salariammo": "salariare",
    "salariamo": "salariare",
    "salarian": "salariare",
    "salariando": "salariare",
    "salariano": "salariare",
    "salariante": "salariare",
    "salarianti": "salariare",
    "salariar": "salariare",
    "salariaron": "salariare",
    "salariarono": "salariare",
    "salariasse": "salariare",
    "salariasser": "salariare",
    "salariassero": "salariare",
    "salariassi": "salariare",
    "salariassimo": "salariare",
    "salariaste": "salariare",
    "salariasti": "salariare",
    "salariata": "salariato",
    "salariate": "salariato",
    "salariati": "salariato",
    "salariato": "salariare",
    "salariava": "salariare",
    "salariavamo": "salariare",
    "salariavan": "salariare",
    "salariavano": "salariare",
    "salariavate": "salariare",
    "salariavi": "salariare",
    "salariavo": "salariare",
    "salarierai": "salariare",
    "salarieran": "salariare",
    "salarieranno": "salariare",
    "salarierebbe": "salariare",
    "salarierebber": "salariare",
    "salarierebbero": "salariare",
    "salarierei": "salariare",
    "salarieremmo": "salariare",
    "salarieremo": "salariare",
    "salariereste": "salariare",
    "salarieresti": "salariare",
    "salarierete": "salariare",
    "salarierà": "salariare",
    "salarierò": "salariare",
    "salarin": "salariare",
    "salarino": "salariare",
    "salario": "salariare",
    "salariò": "salariare",
    "salaron": "salare",
    "salarono": "salare",
    "salassa": "salassare",
    "salassai": "salassare",
    "salassammo": "salassare",
    "salassan": "salassare",
    "salassando": "salassare",
    "salassano": "salassare",
    "salassante": "salassare",
    "salassanti": "salassare",
    "salassar": "salassare",
    "salassaron": "salassare",
    "salassarono": "salassare",
    "salassasse": "salassare",
    "salassasser": "salassare",
    "salassassero": "salassare",
    "salassassi": "salassare",
    "salassassimo": "salassare",
    "salassaste": "salassare",
    "salassasti": "salassare",
    "salassata": "salassare",
    "salassate": "salassare",
    "salassati": "salassare",
    "salassato": "salassare",
    "salassava": "salassare",
    "salassavamo": "salassare",
    "salassavan": "salassare",
    "salassavano": "salassare",
    "salassavate": "salassare",
    "salassavi": "salassare",
    "salassavo": "salassare",
    "salasse": "salare",
    "salasser": "salare",
    "salasserai": "salassare",
    "salasseran": "salassare",
    "salasseranno": "salassare",
    "salasserebbe": "salassare",
    "salasserebber": "salassare",
    "salasserebbero": "salassare",
    "salasserei": "salassare",
    "salasseremmo": "salassare",
    "salasseremo": "salassare",
    "salassereste": "salassare",
    "salasseresti": "salassare",
    "salasserete": "salassare",
    "salassero": "salare",
    "salasserà": "salassare",
    "salasserò": "salassare",
    "salassi": "salasso",
    "salassiamo": "salassare",
    "salassiate": "salassare",
    "salassimo": "salare",
    "salassin": "salassare",
    "salassino": "salassare",
    "salasso": "salassare",
    "salassò": "salassare",
    "salaste": "salare",
    "salasti": "salare",
    "salata": "salato",
    "salate": "salato",
    "salati": "salato",
    "salatini": "salatino",
    "salato": "salare",
    "salava": "salare",
    "salavamo": "salare",
    "salavan": "salare",
    "salavano": "salare",
    "salavate": "salare",
    "salavi": "salare",
    "salavo": "salare",
    "salda": "saldo",
    "saldai": "saldare",
    "saldammo": "saldare",
    "saldan": "saldare",
    "saldando": "saldare",
    "saldano": "saldare",
    "saldante": "saldare",
    "saldanti": "saldare",
    "saldar": "saldare",
    "saldaron": "saldare",
    "saldarono": "saldare",
    "saldasse": "saldare",
    "saldasser": "saldare",
    "saldassero": "saldare",
    "saldassi": "saldare",
    "saldassimo": "saldare",
    "saldaste": "saldare",
    "saldasti": "saldare",
    "saldata": "saldare",
    "saldate": "saldare",
    "saldati": "saldare",
    "saldato": "saldare",
    "saldatori": "saldatore",
    "saldature": "saldatura",
    "saldava": "saldare",
    "saldavamo": "saldare",
    "saldavan": "saldare",
    "saldavano": "saldare",
    "saldavate": "saldare",
    "saldavi": "saldare",
    "saldavo": "saldare",
    "salde": "saldo",
    "salderai": "saldare",
    "salderan": "saldare",
    "salderanno": "saldare",
    "salderebbe": "saldare",
    "salderebber": "saldare",
    "salderebbero": "saldare",
    "salderei": "saldare",
    "salderemmo": "saldare",
    "salderemo": "saldare",
    "saldereste": "saldare",
    "salderesti": "saldare",
    "salderete": "saldare",
    "salderà": "saldare",
    "salderò": "saldare",
    "saldezze": "saldezza",
    "saldi": "saldo",
    "saldiamo": "saldare",
    "saldiate": "saldare",
    "saldin": "saldare",
    "saldino": "saldare",
    "saldo": "saldare",
    "saldò": "saldare",
    "sale": "salire",
    "salendo": "salire",
    "salente": "salire",
    "salenti": "salire",
    "salentini": "salentino",
    "salerai": "salare",
    "saleran": "salare",
    "saleranno": "salare",
    "salerebbe": "salare",
    "salerebber": "salare",
    "salerebbero": "salare",
    "salerei": "salare",
    "saleremmo": "salare",
    "saleremo": "salare",
    "salereste": "salare",
    "saleresti": "salare",
    "salerete": "salare",
    "salernitani": "salernitano",
    "salerà": "salare",
    "salerò": "salare",
    "salesiana": "salesiano",
    "salesiane": "salesiano",
    "salesiani": "salesiano",
    "salette": "saletta",
    "salga": "salire",
    "salgan": "salire",
    "salgano": "salire",
    "salgo": "salire",
    "salgon": "salire",
    "salgono": "salire",
    "sali": "salire",
    "saliamo": "salire",
    "saliate": "salire",
    "salica": "salico",
    "saliche": "salico",
    "salici": "salico",
    "salienti": "saliente",
    "salifica": "salificare",
    "salificai": "salificare",
    "salificammo": "salificare",
    "salifican": "salificare",
    "salificando": "salificare",
    "salificano": "salificare",
    "salificante": "salificare",
    "salificanti": "salificare",
    "salificar": "salificare",
    "salificaron": "salificare",
    "salificarono": "salificare",
    "salificasse": "salificare",
    "salificasser": "salificare",
    "salificassero": "salificare",
    "salificassi": "salificare",
    "salificassimo": "salificare",
    "salificaste": "salificare",
    "salificasti": "salificare",
    "salificata": "salificare",
    "salificate": "salificare",
    "salificati": "salificare",
    "salificato": "salificare",
    "salificava": "salificare",
    "salificavamo": "salificare",
    "salificavan": "salificare",
    "salificavano": "salificare",
    "salificavate": "salificare",
    "salificavi": "salificare",
    "salificavo": "salificare",
    "salificherai": "salificare",
    "salificheran": "salificare",
    "salificheranno": "salificare",
    "salificherebbe": "salificare",
    "salificherebber": "salificare",
    "salificherebbero": "salificare",
    "salificherei": "salificare",
    "salificheremmo": "salificare",
    "salificheremo": "salificare",
    "salifichereste": "salificare",
    "salificheresti": "salificare",
    "salificherete": "salificare",
    "salificherà": "salificare",
    "salificherò": "salificare",
    "salifichi": "salificare",
    "salifichiamo": "salificare",
    "salifichiate": "salificare",
    "salifichin": "salificare",
    "salifichino": "salificare",
    "salifico": "salificare",
    "salificò": "salificare",
    "salii": "salire",
    "salimmo": "salire",
    "salin": "salare",
    "salina": "salino",
    "salinai": "salinare",
    "salinammo": "salinare",
    "salinan": "salinare",
    "salinando": "salinare",
    "salinano": "salinare",
    "salinante": "salinare",
    "salinanti": "salinare",
    "salinar": "salinare",
    "salinaron": "salinare",
    "salinarono": "salinare",
    "salinasse": "salinare",
    "salinasser": "salinare",
    "salinassero": "salinare",
    "salinassi": "salinare",
    "salinassimo": "salinare",
    "salinaste": "salinare",
    "salinasti": "salinare",
    "salinata": "salinare",
    "salinate": "salinare",
    "salinati": "salinare",
    "salinato": "salinare",
    "salinava": "salinare",
    "salinavamo": "salinare",
    "salinavan": "salinare",
    "salinavano": "salinare",
    "salinavate": "salinare",
    "salinavi": "salinare",
    "salinavo": "salinare",
    "saline": "salino",
    "salinerai": "salinare",
    "salineran": "salinare",
    "salineranno": "salinare",
    "salinerebbe": "salinare",
    "salinerebber": "salinare",
    "salinerebbero": "salinare",
    "salinerei": "salinare",
    "salineremmo": "salinare",
    "salineremo": "salinare",
    "salinereste": "salinare",
    "salineresti": "salinare",
    "salinerete": "salinare",
    "salinerà": "salinare",
    "salinerò": "salinare",
    "salini": "salino",
    "saliniamo": "salinare",
    "saliniate": "salinare",
    "salinin": "salinare",
    "salinino": "salinare",
    "salino": "salinare",
    "salinò": "salinare",
    "salir": "salire",
    "salirai": "salire",
    "saliran": "salire",
    "saliranno": "salire",
    "salirebbe": "salire",
    "salirebber": "salire",
    "salirebbero": "salire",
    "salirei": "salire",
    "saliremmo": "salire",
    "saliremo": "salire",
    "salireste": "salire",
    "saliresti": "salire",
    "salirete": "salire",
    "saliron": "salire",
    "salirono": "salire",
    "salirà": "salire",
    "salirò": "salire",
    "salisburghesi": "salisburghese",
    "salisse": "salire",
    "salisser": "salire",
    "salissero": "salire",
    "salissi": "salire",
    "salissimo": "salire",
    "saliste": "salire",
    "salisti": "salire",
    "salita": "salire",
    "salite": "salita",
    "saliti": "salire",
    "salito": "salire",
    "saliva": "salivare",
    "salivai": "salivare",
    "salivammo": "salivare",
    "salivamo": "salire",
    "salivan": "salivare",
    "salivando": "salivare",
    "salivano": "salivare",
    "salivante": "salivare",
    "salivanti": "salivare",
    "salivar": "salivare",
    "salivaron": "salivare",
    "salivarono": "salivare",
    "salivasse": "salivare",
    "salivasser": "salivare",
    "salivassero": "salivare",
    "salivassi": "salivare",
    "salivassimo": "salivare",
    "salivaste": "salivare",
    "salivasti": "salivare",
    "salivata": "salivare",
    "salivate": "salivare",
    "salivati": "salivare",
    "salivato": "salivare",
    "salivava": "salivare",
    "salivavamo": "salivare",
    "salivavan": "salivare",
    "salivavano": "salivare",
    "salivavate": "salivare",
    "salivavi": "salivare",
    "salivavo": "salivare",
    "salive": "saliva",
    "saliverai": "salivare",
    "saliveran": "salivare",
    "saliveranno": "salivare",
    "saliverebbe": "salivare",
    "saliverebber": "salivare",
    "saliverebbero": "salivare",
    "saliverei": "salivare",
    "saliveremmo": "salivare",
    "saliveremo": "salivare",
    "salivereste": "salivare",
    "saliveresti": "salivare",
    "saliverete": "salivare",
    "saliverà": "salivare",
    "saliverò": "salivare",
    "salivi": "salivare",
    "saliviamo": "salivare",
    "saliviate": "salivare",
    "salivin": "salivare",
    "salivino": "salivare",
    "salivo": "salivare",
    "salivò": "salivare",
    "salmastra": "salmastro",
    "salmastre": "salmastro",
    "salmastri": "salmastro",
    "salme": "salma",
    "salmi": "salmo",
    "salmodi": "salmodiare",
    "salmodia": "salmodiare",
    "salmodiai": "salmodiare",
    "salmodiammo": "salmodiare",
    "salmodiamo": "salmodiare",
    "salmodian": "salmodiare",
    "salmodiando": "salmodiare",
    "salmodiano": "salmodiare",
    "salmodiante": "salmodiare",
    "salmodianti": "salmodiare",
    "salmodiar": "salmodiare",
    "salmodiaron": "salmodiare",
    "salmodiarono": "salmodiare",
    "salmodiasse": "salmodiare",
    "salmodiasser": "salmodiare",
    "salmodiassero": "salmodiare",
    "salmodiassi": "salmodiare",
    "salmodiassimo": "salmodiare",
    "salmodiaste": "salmodiare",
    "salmodiasti": "salmodiare",
    "salmodiata": "salmodiare",
    "salmodiate": "salmodiare",
    "salmodiati": "salmodiare",
    "salmodiato": "salmodiare",
    "salmodiava": "salmodiare",
    "salmodiavamo": "salmodiare",
    "salmodiavan": "salmodiare",
    "salmodiavano": "salmodiare",
    "salmodiavate": "salmodiare",
    "salmodiavi": "salmodiare",
    "salmodiavo": "salmodiare",
    "salmodierai": "salmodiare",
    "salmodieran": "salmodiare",
    "salmodieranno": "salmodiare",
    "salmodierebbe": "salmodiare",
    "salmodierebber": "salmodiare",
    "salmodierebbero": "salmodiare",
    "salmodierei": "salmodiare",
    "salmodieremmo": "salmodiare",
    "salmodieremo": "salmodiare",
    "salmodiereste": "salmodiare",
    "salmodieresti": "salmodiare",
    "salmodierete": "salmodiare",
    "salmodierà": "salmodiare",
    "salmodierò": "salmodiare",
    "salmodin": "salmodiare",
    "salmodino": "salmodiare",
    "salmodio": "salmodiare",
    "salmodiò": "salmodiare",
    "salmonelle": "salmonella",
    "salmoni": "salmone",
    "salo": "salare",
    "saloni": "salone",
    "salotti": "salotto",
    "salottiera": "salottiero",
    "salottiere": "salottiero",
    "salottieri": "salottiero",
    "salottini": "salottino",
    "salpa": "salpare",
    "salpai": "salpare",
    "salpammo": "salpare",
    "salpan": "salpare",
    "salpando": "salpare",
    "salpano": "salpare",
    "salpante": "salpare",
    "salpanti": "salpare",
    "salpar": "salpare",
    "salparon": "salpare",
    "salparono": "salpare",
    "salpasse": "salpare",
    "salpasser": "salpare",
    "salpassero": "salpare",
    "salpassi": "salpare",
    "salpassimo": "salpare",
    "salpaste": "salpare",
    "salpasti": "salpare",
    "salpata": "salpare",
    "salpate": "salpare",
    "salpati": "salpare",
    "salpato": "salpare",
    "salpava": "salpare",
    "salpavamo": "salpare",
    "salpavan": "salpare",
    "salpavano": "salpare",
    "salpavate": "salpare",
    "salpavi": "salpare",
    "salpavo": "salpare",
    "salperai": "salpare",
    "salperan": "salpare",
    "salperanno": "salpare",
    "salperebbe": "salpare",
    "salperebber": "salpare",
    "salperebbero": "salpare",
    "salperei": "salpare",
    "salperemmo": "salpare",
    "salperemo": "salpare",
    "salpereste": "salpare",
    "salperesti": "salpare",
    "salperete": "salpare",
    "salperà": "salpare",
    "salperò": "salpare",
    "salpi": "salpare",
    "salpiamo": "salpare",
    "salpiate": "salpare",
    "salpin": "salpare",
    "salpino": "salpare",
    "salpo": "salpare",
    "salpò": "salpare",
    "salsa": "salso",
    "salse": "salso",
    "salsedini": "salsedine",
    "salsi": "salso",
    "salsicce": "salsiccia",
    "salsicciotti": "salsicciotto",
    "salta": "saltare",
    "saltabecca": "saltabeccare",
    "saltabeccai": "saltabeccare",
    "saltabeccammo": "saltabeccare",
    "saltabeccan": "saltabeccare",
    "saltabeccando": "saltabeccare",
    "saltabeccano": "saltabeccare",
    "saltabeccante": "saltabeccare",
    "saltabeccanti": "saltabeccare",
    "saltabeccar": "saltabeccare",
    "saltabeccaron": "saltabeccare",
    "saltabeccarono": "saltabeccare",
    "saltabeccasse": "saltabeccare",
    "saltabeccasser": "saltabeccare",
    "saltabeccassero": "saltabeccare",
    "saltabeccassi": "saltabeccare",
    "saltabeccassimo": "saltabeccare",
    "saltabeccaste": "saltabeccare",
    "saltabeccasti": "saltabeccare",
    "saltabeccata": "saltabeccare",
    "saltabeccate": "saltabeccare",
    "saltabeccati": "saltabeccare",
    "saltabeccato": "saltabeccare",
    "saltabeccava": "saltabeccare",
    "saltabeccavamo": "saltabeccare",
    "saltabeccavan": "saltabeccare",
    "saltabeccavano": "saltabeccare",
    "saltabeccavate": "saltabeccare",
    "saltabeccavi": "saltabeccare",
    "saltabeccavo": "saltabeccare",
    "saltabeccherai": "saltabeccare",
    "saltabeccheran": "saltabeccare",
    "saltabeccheranno": "saltabeccare",
    "saltabeccherebbe": "saltabeccare",
    "saltabeccherebber": "saltabeccare",
    "saltabeccherebbero": "saltabeccare",
    "saltabeccherei": "saltabeccare",
    "saltabeccheremmo": "saltabeccare",
    "saltabeccheremo": "saltabeccare",
    "saltabecchereste": "saltabeccare",
    "saltabeccheresti": "saltabeccare",
    "saltabeccherete": "saltabeccare",
    "saltabeccherà": "saltabeccare",
    "saltabeccherò": "saltabeccare",
    "saltabecchi": "saltabeccare",
    "saltabecchiamo": "saltabeccare",
    "saltabecchiate": "saltabeccare",
    "saltabecchin": "saltabeccare",
    "saltabecchino": "saltabeccare",
    "saltabecco": "saltabeccare",
    "saltabeccò": "saltabeccare",
    "saltai": "saltare",
    "saltammo": "saltare",
    "saltan": "saltare",
    "saltando": "saltare",
    "saltano": "saltare",
    "saltante": "saltare",
    "saltanti": "saltare",
    "saltar": "saltare",
    "saltaron": "saltare",
    "saltarono": "saltare",
    "saltasse": "saltare",
    "saltasser": "saltare",
    "saltassero": "saltare",
    "saltassi": "saltare",
    "saltassimo": "saltare",
    "saltaste": "saltare",
    "saltasti": "saltare",
    "saltata": "saltare",
    "saltate": "saltare",
    "saltati": "saltare",
    "saltato": "saltare",
    "saltatori": "saltatore",
    "saltatrice": "saltatore",
    "saltatrici": "saltatrice",
    "saltava": "saltare",
    "saltavamo": "saltare",
    "saltavan": "saltare",
    "saltavano": "saltare",
    "saltavate": "saltare",
    "saltavi": "saltare",
    "saltavo": "saltare",
    "saltella": "saltellare",
    "saltellai": "saltellare",
    "saltellammo": "saltellare",
    "saltellan": "saltellare",
    "saltellando": "saltellare",
    "saltellano": "saltellare",
    "saltellante": "saltellare",
    "saltellanti": "saltellare",
    "saltellar": "saltellare",
    "saltellaron": "saltellare",
    "saltellarono": "saltellare",
    "saltellasse": "saltellare",
    "saltellasser": "saltellare",
    "saltellassero": "saltellare",
    "saltellassi": "saltellare",
    "saltellassimo": "saltellare",
    "saltellaste": "saltellare",
    "saltellasti": "saltellare",
    "saltellata": "saltellare",
    "saltellate": "saltellare",
    "saltellati": "saltellare",
    "saltellato": "saltellare",
    "saltellava": "saltellare",
    "saltellavamo": "saltellare",
    "saltellavan": "saltellare",
    "saltellavano": "saltellare",
    "saltellavate": "saltellare",
    "saltellavi": "saltellare",
    "saltellavo": "saltellare",
    "saltellerai": "saltellare",
    "saltelleran": "saltellare",
    "saltelleranno": "saltellare",
    "saltellerebbe": "saltellare",
    "saltellerebber": "saltellare",
    "saltellerebbero": "saltellare",
    "saltellerei": "saltellare",
    "saltelleremmo": "saltellare",
    "saltelleremo": "saltellare",
    "saltellereste": "saltellare",
    "saltelleresti": "saltellare",
    "saltellerete": "saltellare",
    "saltellerà": "saltellare",
    "saltellerò": "saltellare",
    "saltelli": "saltello",
    "saltelliamo": "saltellare",
    "saltelliate": "saltellare",
    "saltellin": "saltellare",
    "saltellino": "saltellare",
    "saltello": "saltellare",
    "saltellò": "saltellare",
    "salterai": "saltare",
    "salteran": "saltare",
    "salteranno": "saltare",
    "salterebbe": "saltare",
    "salterebber": "saltare",
    "salterebbero": "saltare",
    "salterei": "saltare",
    "salterella": "salterellare",
    "salterellai": "salterellare",
    "salterellammo": "salterellare",
    "salterellan": "salterellare",
    "salterellando": "salterellare",
    "salterellano": "salterellare",
    "salterellante": "salterellare",
    "salterellanti": "salterellare",
    "salterellar": "salterellare",
    "salterellaron": "salterellare",
    "salterellarono": "salterellare",
    "salterellasse": "salterellare",
    "salterellasser": "salterellare",
    "salterellassero": "salterellare",
    "salterellassi": "salterellare",
    "salterellassimo": "salterellare",
    "salterellaste": "salterellare",
    "salterellasti": "salterellare",
    "salterellata": "salterellare",
    "salterellate": "salterellare",
    "salterellati": "salterellare",
    "salterellato": "salterellare",
    "salterellava": "salterellare",
    "salterellavamo": "salterellare",
    "salterellavan": "salterellare",
    "salterellavano": "salterellare",
    "salterellavate": "salterellare",
    "salterellavi": "salterellare",
    "salterellavo": "salterellare",
    "salterellerai": "salterellare",
    "salterelleran": "salterellare",
    "salterelleranno": "salterellare",
    "salterellerebbe": "salterellare",
    "salterellerebber": "salterellare",
    "salterellerebbero": "salterellare",
    "salterellerei": "salterellare",
    "salterelleremmo": "salterellare",
    "salterelleremo": "salterellare",
    "salterellereste": "salterellare",
    "salterelleresti": "salterellare",
    "salterellerete": "salterellare",
    "salterellerà": "salterellare",
    "salterellerò": "salterellare",
    "salterelli": "salterellare",
    "salterelliamo": "salterellare",
    "salterelliate": "salterellare",
    "salterellin": "salterellare",
    "salterellino": "salterellare",
    "salterello": "salterellare",
    "salterellò": "salterellare",
    "salteremmo": "saltare",
    "salteremo": "saltare",
    "saltereste": "saltare",
    "salteresti": "saltare",
    "salterete": "saltare",
    "salterà": "saltare",
    "salterò": "saltare",
    "salti": "salto",
    "saltiamo": "saltare",
    "saltiate": "saltare",
    "saltimbanchi": "saltimbanco",
    "saltin": "saltare",
    "saltino": "saltare",
    "salto": "saltare",
    "saltuari": "saltuario",
    "saltuaria": "saltuario",
    "saltuarie": "saltuario",
    "saltò": "saltare",
    "saluberrima": "saluberrimo",
    "saluberrime": "saluberrimo",
    "saluberrimi": "saluberrimo",
    "salubri": "salubre",
    "salumerie": "salumeria",
    "salumi": "salume",
    "salumieri": "salumiere",
    "salumifici": "salumificio",
    "saluta": "salutare",
    "salutai": "salutare",
    "salutammo": "salutare",
    "salutan": "salutare",
    "salutando": "salutare",
    "salutano": "salutare",
    "salutante": "salutare",
    "salutanti": "salutare",
    "salutar": "salutare",
    "salutari": "salutare",
    "salutaron": "salutare",
    "salutarono": "salutare",
    "salutasse": "salutare",
    "salutasser": "salutare",
    "salutassero": "salutare",
    "salutassi": "salutare",
    "salutassimo": "salutare",
    "salutaste": "salutare",
    "salutasti": "salutare",
    "salutata": "salutare",
    "salutate": "salutare",
    "salutati": "salutare",
    "salutato": "salutare",
    "salutava": "salutare",
    "salutavamo": "salutare",
    "salutavan": "salutare",
    "salutavano": "salutare",
    "salutavate": "salutare",
    "salutavi": "salutare",
    "salutavo": "salutare",
    "saluterai": "salutare",
    "saluteran": "salutare",
    "saluteranno": "salutare",
    "saluterebbe": "salutare",
    "saluterebber": "salutare",
    "saluterebbero": "salutare",
    "saluterei": "salutare",
    "saluteremmo": "salutare",
    "saluteremo": "salutare",
    "salutereste": "salutare",
    "saluteresti": "salutare",
    "saluterete": "salutare",
    "saluterà": "salutare",
    "saluterò": "salutare",
    "saluti": "saluto",
    "salutiamo": "salutare",
    "salutiate": "salutare",
    "salutifera": "salutifero",
    "salutifere": "salutifero",
    "salutiferi": "salutifero",
    "salutin": "salutare",
    "salutino": "salutare",
    "salutiste": "salutista",
    "salutisti": "salutista",
    "saluto": "salutare",
    "salutò": "salutare",
    "salva": "salvo",
    "salvabili": "salvabile",
    "salvacondotti": "salvacondotto",
    "salvadanai": "salvadanaio",
    "salvadoregna": "salvadoregno",
    "salvadoregne": "salvadoregno",
    "salvadoregni": "salvadoregno",
    "salvagenti": "salvagente",
    "salvaguarda": "salvaguardare",
    "salvaguardai": "salvaguardare",
    "salvaguardammo": "salvaguardare",
    "salvaguardan": "salvaguardare",
    "salvaguardando": "salvaguardare",
    "salvaguardano": "salvaguardare",
    "salvaguardante": "salvaguardare",
    "salvaguardanti": "salvaguardare",
    "salvaguardar": "salvaguardare",
    "salvaguardaron": "salvaguardare",
    "salvaguardarono": "salvaguardare",
    "salvaguardasse": "salvaguardare",
    "salvaguardasser": "salvaguardare",
    "salvaguardassero": "salvaguardare",
    "salvaguardassi": "salvaguardare",
    "salvaguardassimo": "salvaguardare",
    "salvaguardaste": "salvaguardare",
    "salvaguardasti": "salvaguardare",
    "salvaguardata": "salvaguardare",
    "salvaguardate": "salvaguardare",
    "salvaguardati": "salvaguardare",
    "salvaguardato": "salvaguardare",
    "salvaguardava": "salvaguardare",
    "salvaguardavamo": "salvaguardare",
    "salvaguardavan": "salvaguardare",
    "salvaguardavano": "salvaguardare",
    "salvaguardavate": "salvaguardare",
    "salvaguardavi": "salvaguardare",
    "salvaguardavo": "salvaguardare",
    "salvaguarderai": "salvaguardare",
    "salvaguarderan": "salvaguardare",
    "salvaguarderanno": "salvaguardare",
    "salvaguarderebbe": "salvaguardare",
    "salvaguarderebber": "salvaguardare",
    "salvaguarderebbero": "salvaguardare",
    "salvaguarderei": "salvaguardare",
    "salvaguarderemmo": "salvaguardare",
    "salvaguarderemo": "salvaguardare",
    "salvaguardereste": "salvaguardare",
    "salvaguarderesti": "salvaguardare",
    "salvaguarderete": "salvaguardare",
    "salvaguarderà": "salvaguardare",
    "salvaguarderò": "salvaguardare",
    "salvaguardi": "salvaguardare",
    "salvaguardiamo": "salvaguardare",
    "salvaguardiate": "salvaguardare",
    "salvaguardie": "salvaguardia",
    "salvaguardin": "salvaguardare",
    "salvaguardino": "salvaguardare",
    "salvaguardo": "salvaguardare",
    "salvaguardò": "salvaguardare",
    "salvai": "salvare",
    "salvammo": "salvare",
    "salvan": "salvare",
    "salvando": "salvare",
    "salvano": "salvare",
    "salvante": "salvare",
    "salvanti": "salvare",
    "salvar": "salvare",
    "salvaron": "salvare",
    "salvarono": "salvare",
    "salvasse": "salvare",
    "salvasser": "salvare",
    "salvassero": "salvare",
    "salvassi": "salvare",
    "salvassimo": "salvare",
    "salvaste": "salvare",
    "salvasti": "salvare",
    "salvata": "salvare",
    "salvataggi": "salvataggio",
    "salvate": "salvare",
    "salvati": "salvare",
    "salvato": "salvare",
    "salvatori": "salvatore",
    "salvava": "salvare",
    "salvavamo": "salvare",
    "salvavan": "salvare",
    "salvavano": "salvare",
    "salvavate": "salvare",
    "salvavi": "salvare",
    "salvavo": "salvare",
    "salve": "salvo",
    "salverai": "salvare",
    "salveran": "salvare",
    "salveranno": "salvare",
    "salverebbe": "salvare",
    "salverebber": "salvare",
    "salverebbero": "salvare",
    "salverei": "salvare",
    "salveremmo": "salvare",
    "salveremo": "salvare",
    "salvereste": "salvare",
    "salveresti": "salvare",
    "salverete": "salvare",
    "salverà": "salvare",
    "salverò": "salvare",
    "salvezze": "salvezza",
    "salvi": "salvo",
    "salviamo": "salvare",
    "salviate": "salvare",
    "salvifica": "salvifico",
    "salvifiche": "salvifico",
    "salvifici": "salvifico",
    "salvin": "salvare",
    "salvino": "salvare",
    "salvo": "salvare",
    "salvò": "salvare",
    "salì": "salire",
    "salò": "salare",
    "samaritana": "samaritano",
    "samaritane": "samaritano",
    "samaritani": "samaritano",
    "sambe": "samba",
    "sammarinesi": "sammarinese",
    "sampdoriani": "sampdoriano",
    "sampietrini": "sampietrino",
    "san": "sapere",
    "sana": "sano",
    "sanabili": "sanabile",
    "sanai": "sanare",
    "sanammo": "sanare",
    "sanan": "sanare",
    "sanando": "sanare",
    "sanano": "sanare",
    "sanante": "sanare",
    "sananti": "sanare",
    "sanar": "sanare",
    "sanaron": "sanare",
    "sanarono": "sanare",
    "sanasse": "sanare",
    "sanasser": "sanare",
    "sanassero": "sanare",
    "sanassi": "sanare",
    "sanassimo": "sanare",
    "sanaste": "sanare",
    "sanasti": "sanare",
    "sanata": "sanare",
    "sanate": "sanare",
    "sanati": "sanare",
    "sanato": "sanare",
    "sanatori": "sanatorio",
    "sanatoria": "sanatorio",
    "sanatorie": "sanatorio",
    "sanava": "sanare",
    "sanavamo": "sanare",
    "sanavan": "sanare",
    "sanavano": "sanare",
    "sanavate": "sanare",
    "sanavi": "sanare",
    "sanavo": "sanare",
    "sancarlina": "sancarlino",
    "sancarline": "sancarlino",
    "sancarlini": "sancarlino",
    "sancendo": "sancire",
    "sancente": "sancire",
    "sancenti": "sancire",
    "sanciamo": "sancire",
    "sanciate": "sancire",
    "sancii": "sancire",
    "sancimmo": "sancire",
    "sancir": "sancire",
    "sancirai": "sancire",
    "sanciran": "sancire",
    "sanciranno": "sancire",
    "sancirebbe": "sancire",
    "sancirebber": "sancire",
    "sancirebbero": "sancire",
    "sancirei": "sancire",
    "sanciremmo": "sancire",
    "sanciremo": "sancire",
    "sancireste": "sancire",
    "sanciresti": "sancire",
    "sancirete": "sancire",
    "sanciron": "sancire",
    "sancirono": "sancire",
    "sancirà": "sancire",
    "sancirò": "sancire",
    "sancisca": "sancire",
    "sanciscan": "sancire",
    "sanciscano": "sancire",
    "sancisce": "sancire",
    "sancisci": "sancire",
    "sancisco": "sancire",
    "sanciscon": "sancire",
    "sanciscono": "sancire",
    "sancisse": "sancire",
    "sancisser": "sancire",
    "sancissero": "sancire",
    "sancissi": "sancire",
    "sancissimo": "sancire",
    "sanciste": "sancire",
    "sancisti": "sancire",
    "sancita": "sancire",
    "sancite": "sancire",
    "sanciti": "sancire",
    "sancito": "sancire",
    "sanciva": "sancire",
    "sancivamo": "sancire",
    "sancivan": "sancire",
    "sancivano": "sancire",
    "sancivate": "sancire",
    "sancivi": "sancire",
    "sancivo": "sancire",
    "sanculotti": "sanculotto",
    "sancì": "sancire",
    "sandali": "sandalo",
    "sandinismi": "sandinismo",
    "sandiniste": "sandinista",
    "sandinisti": "sandinista",
    "sane": "sano",
    "sanerai": "sanare",
    "saneran": "sanare",
    "saneranno": "sanare",
    "sanerebbe": "sanare",
    "sanerebber": "sanare",
    "sanerebbero": "sanare",
    "sanerei": "sanare",
    "saneremmo": "sanare",
    "saneremo": "sanare",
    "sanereste": "sanare",
    "saneresti": "sanare",
    "sanerete": "sanare",
    "sanerà": "sanare",
    "sanerò": "sanare",
    "sangui": "sangue",
    "sanguigna": "sanguigno",
    "sanguigne": "sanguigno",
    "sanguigni": "sanguigno",
    "sanguina": "sanguinare",
    "sanguinai": "sanguinare",
    "sanguinammo": "sanguinare",
    "sanguinan": "sanguinare",
    "sanguinando": "sanguinare",
    "sanguinano": "sanguinare",
    "sanguinante": "sanguinare",
    "sanguinanti": "sanguinare",
    "sanguinar": "sanguinare",
    "sanguinari": "sanguinario",
    "sanguinaria": "sanguinario",
    "sanguinarie": "sanguinario",
    "sanguinaron": "sanguinare",
    "sanguinarono": "sanguinare",
    "sanguinasse": "sanguinare",
    "sanguinasser": "sanguinare",
    "sanguinassero": "sanguinare",
    "sanguinassi": "sanguinare",
    "sanguinassimo": "sanguinare",
    "sanguinaste": "sanguinare",
    "sanguinasti": "sanguinare",
    "sanguinata": "sanguinare",
    "sanguinate": "sanguinare",
    "sanguinati": "sanguinare",
    "sanguinato": "sanguinare",
    "sanguinava": "sanguinare",
    "sanguinavamo": "sanguinare",
    "sanguinavan": "sanguinare",
    "sanguinavano": "sanguinare",
    "sanguinavate": "sanguinare",
    "sanguinavi": "sanguinare",
    "sanguinavo": "sanguinare",
    "sanguinerai": "sanguinare",
    "sanguineran": "sanguinare",
    "sanguineranno": "sanguinare",
    "sanguinerebbe": "sanguinare",
    "sanguinerebber": "sanguinare",
    "sanguinerebbero": "sanguinare",
    "sanguinerei": "sanguinare",
    "sanguineremmo": "sanguinare",
    "sanguineremo": "sanguinare",
    "sanguinereste": "sanguinare",
    "sanguineresti": "sanguinare",
    "sanguinerete": "sanguinare",
    "sanguinerà": "sanguinare",
    "sanguinerò": "sanguinare",
    "sanguini": "sanguinare",
    "sanguiniamo": "sanguinare",
    "sanguiniate": "sanguinare",
    "sanguinin": "sanguinare",
    "sanguinino": "sanguinare",
    "sanguino": "sanguinare",
    "sanguinolenta": "sanguinolento",
    "sanguinolente": "sanguinolento",
    "sanguinolenti": "sanguinolento",
    "sanguinosa": "sanguinoso",
    "sanguinose": "sanguinoso",
    "sanguinosi": "sanguinoso",
    "sanguinò": "sanguinare",
    "sanguisughe": "sanguisuga",
    "sani": "sano",
    "saniamo": "sanare",
    "saniate": "sanare",
    "sanin": "sanare",
    "sanino": "sanare",
    "sanitari": "sanitario",
    "sanitaria": "sanitario",
    "sanitarie": "sanitario",
    "sanitometri": "sanitometro",
    "sannite": "sannita",
    "sanniti": "sannita",
    "sanno": "sapere",
    "sano": "sanare",
    "sanremesi": "sanremese",
    "sanscriti": "sanscrito",
    "sant'": "santo",
    "santa": "santo",
    "santabarbare": "santabarbara",
    "sante": "santo",
    "santi": "santo",
    "santifica": "santificare",
    "santificai": "santificare",
    "santificammo": "santificare",
    "santifican": "santificare",
    "santificando": "santificare",
    "santificano": "santificare",
    "santificante": "santificare",
    "santificanti": "santificare",
    "santificar": "santificare",
    "santificaron": "santificare",
    "santificarono": "santificare",
    "santificasse": "santificare",
    "santificasser": "santificare",
    "santificassero": "santificare",
    "santificassi": "santificare",
    "santificassimo": "santificare",
    "santificaste": "santificare",
    "santificasti": "santificare",
    "santificata": "santificare",
    "santificate": "santificare",
    "santificati": "santificare",
    "santificato": "santificare",
    "santificava": "santificare",
    "santificavamo": "santificare",
    "santificavan": "santificare",
    "santificavano": "santificare",
    "santificavate": "santificare",
    "santificavi": "santificare",
    "santificavo": "santificare",
    "santificazioni": "santificazione",
    "santificherai": "santificare",
    "santificheran": "santificare",
    "santificheranno": "santificare",
    "santificherebbe": "santificare",
    "santificherebber": "santificare",
    "santificherebbero": "santificare",
    "santificherei": "santificare",
    "santificheremmo": "santificare",
    "santificheremo": "santificare",
    "santifichereste": "santificare",
    "santificheresti": "santificare",
    "santificherete": "santificare",
    "santificherà": "santificare",
    "santificherò": "santificare",
    "santifichi": "santificare",
    "santifichiamo": "santificare",
    "santifichiate": "santificare",
    "santifichin": "santificare",
    "santifichino": "santificare",
    "santifico": "santificare",
    "santificò": "santificare",
    "santini": "santino",
    "santone": "santona",
    "santoni": "santone",
    "santuari": "santuario",
    "sanziona": "sanzionare",
    "sanzionai": "sanzionare",
    "sanzionammo": "sanzionare",
    "sanzionan": "sanzionare",
    "sanzionando": "sanzionare",
    "sanzionano": "sanzionare",
    "sanzionante": "sanzionare",
    "sanzionanti": "sanzionare",
    "sanzionar": "sanzionare",
    "sanzionaron": "sanzionare",
    "sanzionarono": "sanzionare",
    "sanzionasse": "sanzionare",
    "sanzionasser": "sanzionare",
    "sanzionassero": "sanzionare",
    "sanzionassi": "sanzionare",
    "sanzionassimo": "sanzionare",
    "sanzionaste": "sanzionare",
    "sanzionasti": "sanzionare",
    "sanzionata": "sanzionare",
    "sanzionate": "sanzionare",
    "sanzionati": "sanzionare",
    "sanzionato": "sanzionare",
    "sanzionatori": "sanzionatorio",
    "sanzionatoria": "sanzionatorio",
    "sanzionatorie": "sanzionatorio",
    "sanzionava": "sanzionare",
    "sanzionavamo": "sanzionare",
    "sanzionavan": "sanzionare",
    "sanzionavano": "sanzionare",
    "sanzionavate": "sanzionare",
    "sanzionavi": "sanzionare",
    "sanzionavo": "sanzionare",
    "sanzionerai": "sanzionare",
    "sanzioneran": "sanzionare",
    "sanzioneranno": "sanzionare",
    "sanzionerebbe": "sanzionare",
    "sanzionerebber": "sanzionare",
    "sanzionerebbero": "sanzionare",
    "sanzionerei": "sanzionare",
    "sanzioneremmo": "sanzionare",
    "sanzioneremo": "sanzionare",
    "sanzionereste": "sanzionare",
    "sanzioneresti": "sanzionare",
    "sanzionerete": "sanzionare",
    "sanzionerà": "sanzionare",
    "sanzionerò": "sanzionare",
    "sanzioni": "sanzione",
    "sanzioniamo": "sanzionare",
    "sanzioniate": "sanzionare",
    "sanzionin": "sanzionare",
    "sanzionino": "sanzionare",
    "sanziono": "sanzionare",
    "sanzionò": "sanzionare",
    "sanò": "sanare",
    "sapemmo": "sapere",
    "sapendo": "sapere",
    "saper": "sapere",
    "saperi": "sapere",
    "sapesse": "sapere",
    "sapesser": "sapere",
    "sapessero": "sapere",
    "sapessi": "sapere",
    "sapessimo": "sapere",
    "sapeste": "sapere",
    "sapesti": "sapere",
    "sapete": "sapere",
    "sapeva": "sapere",
    "sapevamo": "sapere",
    "sapevan": "sapere",
    "sapevano": "sapere",
    "sapevate": "sapere",
    "sapevi": "sapere",
    "sapevo": "sapere",
    "sapida": "sapido",
    "sapide": "sapido",
    "sapidi": "sapido",
    "sapiente": "sapere",
    "sapienti": "sapiente",
    "sapienze": "sapienza",
    "saponette": "saponetta",
    "saponi": "sapone",
    "saponifica": "saponificare",
    "saponificai": "saponificare",
    "saponificammo": "saponificare",
    "saponifican": "saponificare",
    "saponificando": "saponificare",
    "saponificano": "saponificare",
    "saponificante": "saponificare",
    "saponificanti": "saponificare",
    "saponificar": "saponificare",
    "saponificaron": "saponificare",
    "saponificarono": "saponificare",
    "saponificasse": "saponificare",
    "saponificasser": "saponificare",
    "saponificassero": "saponificare",
    "saponificassi": "saponificare",
    "saponificassimo": "saponificare",
    "saponificaste": "saponificare",
    "saponificasti": "saponificare",
    "saponificata": "saponificare",
    "saponificate": "saponificare",
    "saponificati": "saponificare",
    "saponificato": "saponificare",
    "saponificava": "saponificare",
    "saponificavamo": "saponificare",
    "saponificavan": "saponificare",
    "saponificavano": "saponificare",
    "saponificavate": "saponificare",
    "saponificavi": "saponificare",
    "saponificavo": "saponificare",
    "saponificherai": "saponificare",
    "saponificheran": "saponificare",
    "saponificheranno": "saponificare",
    "saponificherebbe": "saponificare",
    "saponificherebber": "saponificare",
    "saponificherebbero": "saponificare",
    "saponificherei": "saponificare",
    "saponificheremmo": "saponificare",
    "saponificheremo": "saponificare",
    "saponifichereste": "saponificare",
    "saponificheresti": "saponificare",
    "saponificherete": "saponificare",
    "saponificherà": "saponificare",
    "saponificherò": "saponificare",
    "saponifichi": "saponificare",
    "saponifichiamo": "saponificare",
    "saponifichiate": "saponificare",
    "saponifichin": "saponificare",
    "saponifichino": "saponificare",
    "saponifico": "saponificare",
    "saponificò": "saponificare",
    "saponosa": "saponoso",
    "saponose": "saponoso",
    "saponosi": "saponoso",
    "sapora": "saporire",
    "saporan": "saporire",
    "saporano": "saporire",
    "sapore": "saporire",
    "saporendo": "saporire",
    "saporente": "saporire",
    "saporenti": "saporire",
    "sapori": "saporire",
    "saporiamo": "saporire",
    "saporiate": "saporire",
    "saporii": "saporire",
    "saporimmo": "saporire",
    "saporir": "saporire",
    "saporirai": "saporire",
    "saporiran": "saporire",
    "saporiranno": "saporire",
    "saporirebbe": "saporire",
    "saporirebber": "saporire",
    "saporirebbero": "saporire",
    "saporirei": "saporire",
    "saporiremmo": "saporire",
    "saporiremo": "saporire",
    "saporireste": "saporire",
    "saporiresti": "saporire",
    "saporirete": "saporire",
    "saporiron": "saporire",
    "saporirono": "saporire",
    "saporirà": "saporire",
    "saporirò": "saporire",
    "saporisse": "saporire",
    "saporisser": "saporire",
    "saporissero": "saporire",
    "saporissi": "saporire",
    "saporissimo": "saporire",
    "saporiste": "saporire",
    "saporisti": "saporire",
    "saporita": "saporito",
    "saporite": "saporito",
    "saporiti": "saporito",
    "saporito": "saporire",
    "saporiva": "saporire",
    "saporivamo": "saporire",
    "saporivan": "saporire",
    "saporivano": "saporire",
    "saporivate": "saporire",
    "saporivi": "saporire",
    "saporivo": "saporire",
    "saporo": "saporire",
    "saporon": "saporire",
    "saporono": "saporire",
    "saporosa": "saporoso",
    "saporose": "saporoso",
    "saporosi": "saporoso",
    "saporì": "saporire",
    "sappi": "sapere",
    "sappia": "sapere",
    "sappiamo": "sapere",
    "sappian": "sapere",
    "sappiano": "sapere",
    "sappiate": "sapere",
    "saprai": "sapere",
    "sapran": "sapere",
    "sapranno": "sapere",
    "saprebbe": "sapere",
    "saprebber": "sapere",
    "saprebbero": "sapere",
    "saprei": "sapere",
    "sapremmo": "sapere",
    "sapremo": "sapere",
    "sapreste": "sapere",
    "sapresti": "sapere",
    "saprete": "sapere",
    "saprà": "sapere",
    "saprò": "sapere",
    "saputa": "saputo",
    "sapute": "saputo",
    "saputi": "saputo",
    "saputo": "sapere",
    "sarabande": "sarabanda",
    "saracena": "saraceno",
    "saracene": "saraceno",
    "saraceni": "saraceno",
    "saracina": "saracino",
    "saracine": "saracino",
    "saracinesche": "saracinesca",
    "saracini": "saracino",
    "sarai": "essere",
    "saran": "essere",
    "saranno": "essere",
    "sarcasmi": "sarcasmo",
    "sarcastica": "sarcastico",
    "sarcastiche": "sarcastico",
    "sarcastici": "sarcastico",
    "sarchi": "sarchiare",
    "sarchia": "sarchiare",
    "sarchiai": "sarchiare",
    "sarchiammo": "sarchiare",
    "sarchiamo": "sarchiare",
    "sarchian": "sarchiare",
    "sarchiando": "sarchiare",
    "sarchiano": "sarchiare",
    "sarchiante": "sarchiare",
    "sarchianti": "sarchiare",
    "sarchiar": "sarchiare",
    "sarchiaron": "sarchiare",
    "sarchiarono": "sarchiare",
    "sarchiasse": "sarchiare",
    "sarchiasser": "sarchiare",
    "sarchiassero": "sarchiare",
    "sarchiassi": "sarchiare",
    "sarchiassimo": "sarchiare",
    "sarchiaste": "sarchiare",
    "sarchiasti": "sarchiare",
    "sarchiata": "sarchiare",
    "sarchiate": "sarchiare",
    "sarchiati": "sarchiare",
    "sarchiato": "sarchiare",
    "sarchiava": "sarchiare",
    "sarchiavamo": "sarchiare",
    "sarchiavan": "sarchiare",
    "sarchiavano": "sarchiare",
    "sarchiavate": "sarchiare",
    "sarchiavi": "sarchiare",
    "sarchiavo": "sarchiare",
    "sarchierai": "sarchiare",
    "sarchieran": "sarchiare",
    "sarchieranno": "sarchiare",
    "sarchierebbe": "sarchiare",
    "sarchierebber": "sarchiare",
    "sarchierebbero": "sarchiare",
    "sarchierei": "sarchiare",
    "sarchieremmo": "sarchiare",
    "sarchieremo": "sarchiare",
    "sarchiereste": "sarchiare",
    "sarchieresti": "sarchiare",
    "sarchierete": "sarchiare",
    "sarchierà": "sarchiare",
    "sarchierò": "sarchiare",
    "sarchin": "sarchiare",
    "sarchino": "sarchiare",
    "sarchio": "sarchiare",
    "sarchiò": "sarchiare",
    "sarcofaghi": "sarcofago",
    "sarcofagi": "sarcofago",
    "sarda": "sardo",
    "sarde": "sardo",
    "sardi": "sardo",
    "sardine": "sardina",
    "sardiste": "sardista",
    "sardisti": "sardista",
    "sardonica": "sardonico",
    "sardoniche": "sardonico",
    "sardonici": "sardonico",
    "sarebbe": "essere",
    "sarebber": "essere",
    "sarebbero": "essere",
    "sarei": "essere",
    "saremmo": "essere",
    "saremo": "essere",
    "sareste": "essere",
    "saresti": "essere",
    "sarete": "essere",
    "sarte": "sarta",
    "sarti": "sarto",
    "sartia": "sartiare",
    "sartiai": "sartiare",
    "sartiammo": "sartiare",
    "sartiamo": "sartiare",
    "sartian": "sartiare",
    "sartiando": "sartiare",
    "sartiano": "sartiare",
    "sartiante": "sartiare",
    "sartianti": "sartiare",
    "sartiar": "sartiare",
    "sartiaron": "sartiare",
    "sartiarono": "sartiare",
    "sartiasse": "sartiare",
    "sartiasser": "sartiare",
    "sartiassero": "sartiare",
    "sartiassi": "sartiare",
    "sartiassimo": "sartiare",
    "sartiaste": "sartiare",
    "sartiasti": "sartiare",
    "sartiata": "sartiare",
    "sartiate": "sartiare",
    "sartiati": "sartiare",
    "sartiato": "sartiare",
    "sartiava": "sartiare",
    "sartiavamo": "sartiare",
    "sartiavan": "sartiare",
    "sartiavano": "sartiare",
    "sartiavate": "sartiare",
    "sartiavi": "sartiare",
    "sartiavo": "sartiare",
    "sartie": "sartia",
    "sartierai": "sartiare",
    "sartieran": "sartiare",
    "sartieranno": "sartiare",
    "sartierebbe": "sartiare",
    "sartierebber": "sartiare",
    "sartierebbero": "sartiare",
    "sartierei": "sartiare",
    "sartieremmo": "sartiare",
    "sartieremo": "sartiare",
    "sartiereste": "sartiare",
    "sartieresti": "sartiare",
    "sartierete": "sartiare",
    "sartierà": "sartiare",
    "sartierò": "sartiare",
    "sartin": "sartiare",
    "sartine": "sartina",
    "sartino": "sartiare",
    "sartio": "sartiare",
    "sartiò": "sartiare",
    "sartoriali": "sartoriale",
    "sartorie": "sartoria",
    "sarà": "essere",
    "sarò": "essere",
    "sassaiole": "sassaiola",
    "sassaresi": "sassarese",
    "sassate": "sassata",
    "sassi": "sasso",
    "sassofoni": "sassofono",
    "sassofonisti": "sassofonista",
    "sassolini": "sassolino",
    "sassoni": "sassone",
    "sassosa": "sassoso",
    "sassose": "sassoso",
    "sassosi": "sassoso",
    "satanassi": "satanasso",
    "satanica": "satanico",
    "sataniche": "satanico",
    "satanici": "satanico",
    "satanismi": "satanismo",
    "satanisti": "satanista",
    "satellitari": "satellitare",
    "satelliti": "satellite",
    "satelliti-spia": "satellite-spia",
    "satina": "satinare",
    "satinai": "satinare",
    "satinammo": "satinare",
    "satinan": "satinare",
    "satinando": "satinare",
    "satinano": "satinare",
    "satinante": "satinare",
    "satinanti": "satinare",
    "satinar": "satinare",
    "satinaron": "satinare",
    "satinarono": "satinare",
    "satinasse": "satinare",
    "satinasser": "satinare",
    "satinassero": "satinare",
    "satinassi": "satinare",
    "satinassimo": "satinare",
    "satinaste": "satinare",
    "satinasti": "satinare",
    "satinata": "satinare",
    "satinate": "satinare",
    "satinati": "satinare",
    "satinato": "satinare",
    "satinava": "satinare",
    "satinavamo": "satinare",
    "satinavan": "satinare",
    "satinavano": "satinare",
    "satinavate": "satinare",
    "satinavi": "satinare",
    "satinavo": "satinare",
    "satinerai": "satinare",
    "satineran": "satinare",
    "satineranno": "satinare",
    "satinerebbe": "satinare",
    "satinerebber": "satinare",
    "satinerebbero": "satinare",
    "satinerei": "satinare",
    "satineremmo": "satinare",
    "satineremo": "satinare",
    "satinereste": "satinare",
    "satineresti": "satinare",
    "satinerete": "satinare",
    "satinerà": "satinare",
    "satinerò": "satinare",
    "satini": "satinare",
    "satiniamo": "satinare",
    "satiniate": "satinare",
    "satinin": "satinare",
    "satinino": "satinare",
    "satino": "satinare",
    "satinò": "satinare",
    "satire": "satira",
    "satireggerai": "satireggiare",
    "satireggeran": "satireggiare",
    "satireggeranno": "satireggiare",
    "satireggerebbe": "satireggiare",
    "satireggerebber": "satireggiare",
    "satireggerebbero": "satireggiare",
    "satireggerei": "satireggiare",
    "satireggeremmo": "satireggiare",
    "satireggeremo": "satireggiare",
    "satireggereste": "satireggiare",
    "satireggeresti": "satireggiare",
    "satireggerete": "satireggiare",
    "satireggerà": "satireggiare",
    "satireggerò": "satireggiare",
    "satireggi": "satireggiare",
    "satireggia": "satireggiare",
    "satireggiai": "satireggiare",
    "satireggiammo": "satireggiare",
    "satireggiamo": "satireggiare",
    "satireggian": "satireggiare",
    "satireggiando": "satireggiare",
    "satireggiano": "satireggiare",
    "satireggiante": "satireggiare",
    "satireggianti": "satireggiare",
    "satireggiar": "satireggiare",
    "satireggiaron": "satireggiare",
    "satireggiarono": "satireggiare",
    "satireggiasse": "satireggiare",
    "satireggiasser": "satireggiare",
    "satireggiassero": "satireggiare",
    "satireggiassi": "satireggiare",
    "satireggiassimo": "satireggiare",
    "satireggiaste": "satireggiare",
    "satireggiasti": "satireggiare",
    "satireggiata": "satireggiare",
    "satireggiate": "satireggiare",
    "satireggiati": "satireggiare",
    "satireggiato": "satireggiare",
    "satireggiava": "satireggiare",
    "satireggiavamo": "satireggiare",
    "satireggiavan": "satireggiare",
    "satireggiavano": "satireggiare",
    "satireggiavate": "satireggiare",
    "satireggiavi": "satireggiare",
    "satireggiavo": "satireggiare",
    "satireggin": "satireggiare",
    "satireggino": "satireggiare",
    "satireggio": "satireggiare",
    "satireggiò": "satireggiare",
    "satiri": "satiro",
    "satirica": "satirico",
    "satiriche": "satirico",
    "satirici": "satirico",
    "satolla": "satollo",
    "satollai": "satollare",
    "satollammo": "satollare",
    "satollan": "satollare",
    "satollando": "satollare",
    "satollano": "satollare",
    "satollante": "satollare",
    "satollanti": "satollare",
    "satollar": "satollare",
    "satollaron": "satollare",
    "satollarono": "satollare",
    "satollasse": "satollare",
    "satollasser": "satollare",
    "satollassero": "satollare",
    "satollassi": "satollare",
    "satollassimo": "satollare",
    "satollaste": "satollare",
    "satollasti": "satollare",
    "satollata": "satollare",
    "satollate": "satollare",
    "satollati": "satollare",
    "satollato": "satollare",
    "satollava": "satollare",
    "satollavamo": "satollare",
    "satollavan": "satollare",
    "satollavano": "satollare",
    "satollavate": "satollare",
    "satollavi": "satollare",
    "satollavo": "satollare",
    "satolle": "satollo",
    "satollerai": "satollare",
    "satolleran": "satollare",
    "satolleranno": "satollare",
    "satollerebbe": "satollare",
    "satollerebber": "satollare",
    "satollerebbero": "satollare",
    "satollerei": "satollare",
    "satolleremmo": "satollare",
    "satolleremo": "satollare",
    "satollereste": "satollare",
    "satolleresti": "satollare",
    "satollerete": "satollare",
    "satollerà": "satollare",
    "satollerò": "satollare",
    "satolli": "satollo",
    "satolliamo": "satollare",
    "satolliate": "satollare",
    "satollin": "satollare",
    "satollino": "satollare",
    "satollo": "satollare",
    "satollò": "satollare",
    "satrapi": "satrapo",
    "satura": "saturo",
    "saturai": "saturare",
    "saturammo": "saturare",
    "saturan": "saturare",
    "saturando": "saturare",
    "saturano": "saturare",
    "saturante": "saturare",
    "saturanti": "saturare",
    "saturar": "saturare",
    "saturaron": "saturare",
    "saturarono": "saturare",
    "saturasse": "saturare",
    "saturasser": "saturare",
    "saturassero": "saturare",
    "saturassi": "saturare",
    "saturassimo": "saturare",
    "saturaste": "saturare",
    "saturasti": "saturare",
    "saturata": "saturare",
    "saturate": "saturare",
    "saturati": "saturare",
    "saturato": "saturare",
    "saturava": "saturare",
    "saturavamo": "saturare",
    "saturavan": "saturare",
    "saturavano": "saturare",
    "saturavate": "saturare",
    "saturavi": "saturare",
    "saturavo": "saturare",
    "saturazioni": "saturazione",
    "sature": "saturo",
    "saturerai": "saturare",
    "satureran": "saturare",
    "satureranno": "saturare",
    "saturerebbe": "saturare",
    "saturerebber": "saturare",
    "saturerebbero": "saturare",
    "saturerei": "saturare",
    "satureremmo": "saturare",
    "satureremo": "saturare",
    "saturereste": "saturare",
    "satureresti": "saturare",
    "saturerete": "saturare",
    "saturerà": "saturare",
    "saturerò": "saturare",
    "saturi": "saturo",
    "saturiamo": "saturare",
    "saturiate": "saturare",
    "saturin": "saturare",
    "saturino": "saturare",
    "saturnizza": "saturnizzare",
    "saturnizzai": "saturnizzare",
    "saturnizzammo": "saturnizzare",
    "saturnizzan": "saturnizzare",
    "saturnizzando": "saturnizzare",
    "saturnizzano": "saturnizzare",
    "saturnizzante": "saturnizzare",
    "saturnizzanti": "saturnizzare",
    "saturnizzar": "saturnizzare",
    "saturnizzaron": "saturnizzare",
    "saturnizzarono": "saturnizzare",
    "saturnizzasse": "saturnizzare",
    "saturnizzasser": "saturnizzare",
    "saturnizzassero": "saturnizzare",
    "saturnizzassi": "saturnizzare",
    "saturnizzassimo": "saturnizzare",
    "saturnizzaste": "saturnizzare",
    "saturnizzasti": "saturnizzare",
    "saturnizzata": "saturnizzare",
    "saturnizzate": "saturnizzare",
    "saturnizzati": "saturnizzare",
    "saturnizzato": "saturnizzare",
    "saturnizzava": "saturnizzare",
    "saturnizzavamo": "saturnizzare",
    "saturnizzavan": "saturnizzare",
    "saturnizzavano": "saturnizzare",
    "saturnizzavate": "saturnizzare",
    "saturnizzavi": "saturnizzare",
    "saturnizzavo": "saturnizzare",
    "saturnizzerai": "saturnizzare",
    "saturnizzeran": "saturnizzare",
    "saturnizzeranno": "saturnizzare",
    "saturnizzerebbe": "saturnizzare",
    "saturnizzerebber": "saturnizzare",
    "saturnizzerebbero": "saturnizzare",
    "saturnizzerei": "saturnizzare",
    "saturnizzeremmo": "saturnizzare",
    "saturnizzeremo": "saturnizzare",
    "saturnizzereste": "saturnizzare",
    "saturnizzeresti": "saturnizzare",
    "saturnizzerete": "saturnizzare",
    "saturnizzerà": "saturnizzare",
    "saturnizzerò": "saturnizzare",
    "saturnizzi": "saturnizzare",
    "saturnizziamo": "saturnizzare",
    "saturnizziate": "saturnizzare",
    "saturnizzin": "saturnizzare",
    "saturnizzino": "saturnizzare",
    "saturnizzo": "saturnizzare",
    "saturnizzò": "saturnizzare",
    "saturo": "saturare",
    "saturò": "saturare",
    "saudite": "saudita",
    "sauditi": "saudita",
    "saune": "sauna",
    "saura": "sauro",
    "saure": "sauro",
    "sauri": "sauro",
    "savane": "savana",
    "savi": "savio",
    "savia": "savio",
    "savie": "savio",
    "savoiarda": "savoiardo",
    "savoiarde": "savoiardo",
    "savoiardi": "savoiardo",
    "sazi": "sazio",
    "sazia": "sazio",
    "saziai": "saziare",
    "saziammo": "saziare",
    "saziamo": "saziare",
    "sazian": "saziare",
    "saziando": "saziare",
    "saziano": "saziare",
    "saziante": "saziare",
    "sazianti": "saziare",
    "saziar": "saziare",
    "saziaron": "saziare",
    "saziarono": "saziare",
    "saziasse": "saziare",
    "saziasser": "saziare",
    "saziassero": "saziare",
    "saziassi": "saziare",
    "saziassimo": "saziare",
    "saziaste": "saziare",
    "saziasti": "saziare",
    "saziata": "saziare",
    "saziate": "saziare",
    "saziati": "saziare",
    "saziato": "saziare",
    "saziava": "saziare",
    "saziavamo": "saziare",
    "saziavan": "saziare",
    "saziavano": "saziare",
    "saziavate": "saziare",
    "saziavi": "saziare",
    "saziavo": "saziare",
    "sazie": "sazio",
    "sazierai": "saziare",
    "sazieran": "saziare",
    "sazieranno": "saziare",
    "sazierebbe": "saziare",
    "sazierebber": "saziare",
    "sazierebbero": "saziare",
    "sazierei": "saziare",
    "sazieremmo": "saziare",
    "sazieremo": "saziare",
    "saziereste": "saziare",
    "sazieresti": "saziare",
    "sazierete": "saziare",
    "sazierà": "saziare",
    "sazierò": "saziare",
    "sazin": "saziare",
    "sazino": "saziare",
    "sazio": "saziare",
    "saziò": "saziare",
    "sbaciucchi": "sbaciucchiare",
    "sbaciucchia": "sbaciucchiare",
    "sbaciucchiai": "sbaciucchiare",
    "sbaciucchiammo": "sbaciucchiare",
    "sbaciucchiamo": "sbaciucchiare",
    "sbaciucchian": "sbaciucchiare",
    "sbaciucchiando": "sbaciucchiare",
    "sbaciucchiano": "sbaciucchiare",
    "sbaciucchiante": "sbaciucchiare",
    "sbaciucchianti": "sbaciucchiare",
    "sbaciucchiar": "sbaciucchiare",
    "sbaciucchiaron": "sbaciucchiare",
    "sbaciucchiarono": "sbaciucchiare",
    "sbaciucchiasse": "sbaciucchiare",
    "sbaciucchiasser": "sbaciucchiare",
    "sbaciucchiassero": "sbaciucchiare",
    "sbaciucchiassi": "sbaciucchiare",
    "sbaciucchiassimo": "sbaciucchiare",
    "sbaciucchiaste": "sbaciucchiare",
    "sbaciucchiasti": "sbaciucchiare",
    "sbaciucchiata": "sbaciucchiare",
    "sbaciucchiate": "sbaciucchiare",
    "sbaciucchiati": "sbaciucchiare",
    "sbaciucchiato": "sbaciucchiare",
    "sbaciucchiava": "sbaciucchiare",
    "sbaciucchiavamo": "sbaciucchiare",
    "sbaciucchiavan": "sbaciucchiare",
    "sbaciucchiavano": "sbaciucchiare",
    "sbaciucchiavate": "sbaciucchiare",
    "sbaciucchiavi": "sbaciucchiare",
    "sbaciucchiavo": "sbaciucchiare",
    "sbaciucchierai": "sbaciucchiare",
    "sbaciucchieran": "sbaciucchiare",
    "sbaciucchieranno": "sbaciucchiare",
    "sbaciucchierebbe": "sbaciucchiare",
    "sbaciucchierebber": "sbaciucchiare",
    "sbaciucchierebbero": "sbaciucchiare",
    "sbaciucchierei": "sbaciucchiare",
    "sbaciucchieremmo": "sbaciucchiare",
    "sbaciucchieremo": "sbaciucchiare",
    "sbaciucchiereste": "sbaciucchiare",
    "sbaciucchieresti": "sbaciucchiare",
    "sbaciucchierete": "sbaciucchiare",
    "sbaciucchierà": "sbaciucchiare",
    "sbaciucchierò": "sbaciucchiare",
    "sbaciucchin": "sbaciucchiare",
    "sbaciucchino": "sbaciucchiare",
    "sbaciucchio": "sbaciucchiare",
    "sbaciucchiò": "sbaciucchiare",
    "sbadata": "sbadato",
    "sbadataggini": "sbadataggine",
    "sbadate": "sbadato",
    "sbadati": "sbadato",
    "sbadigli": "sbadiglio",
    "sbadiglia": "sbadigliare",
    "sbadigliai": "sbadigliare",
    "sbadigliammo": "sbadigliare",
    "sbadigliamo": "sbadigliare",
    "sbadiglian": "sbadigliare",
    "sbadigliando": "sbadigliare",
    "sbadigliano": "sbadigliare",
    "sbadigliante": "sbadigliare",
    "sbadiglianti": "sbadigliare",
    "sbadigliar": "sbadigliare",
    "sbadigliaron": "sbadigliare",
    "sbadigliarono": "sbadigliare",
    "sbadigliasse": "sbadigliare",
    "sbadigliasser": "sbadigliare",
    "sbadigliassero": "sbadigliare",
    "sbadigliassi": "sbadigliare",
    "sbadigliassimo": "sbadigliare",
    "sbadigliaste": "sbadigliare",
    "sbadigliasti": "sbadigliare",
    "sbadigliata": "sbadigliare",
    "sbadigliate": "sbadigliare",
    "sbadigliati": "sbadigliare",
    "sbadigliato": "sbadigliare",
    "sbadigliava": "sbadigliare",
    "sbadigliavamo": "sbadigliare",
    "sbadigliavan": "sbadigliare",
    "sbadigliavano": "sbadigliare",
    "sbadigliavate": "sbadigliare",
    "sbadigliavi": "sbadigliare",
    "sbadigliavo": "sbadigliare",
    "sbadiglierai": "sbadigliare",
    "sbadiglieran": "sbadigliare",
    "sbadiglieranno": "sbadigliare",
    "sbadiglierebbe": "sbadigliare",
    "sbadiglierebber": "sbadigliare",
    "sbadiglierebbero": "sbadigliare",
    "sbadiglierei": "sbadigliare",
    "sbadiglieremmo": "sbadigliare",
    "sbadiglieremo": "sbadigliare",
    "sbadigliereste": "sbadigliare",
    "sbadiglieresti": "sbadigliare",
    "sbadiglierete": "sbadigliare",
    "sbadiglierà": "sbadigliare",
    "sbadiglierò": "sbadigliare",
    "sbadiglin": "sbadigliare",
    "sbadiglino": "sbadigliare",
    "sbadiglio": "sbadigliare",
    "sbadigliò": "sbadigliare",
    "sbafa": "sbafare",
    "sbafai": "sbafare",
    "sbafammo": "sbafare",
    "sbafan": "sbafare",
    "sbafando": "sbafare",
    "sbafano": "sbafare",
    "sbafante": "sbafare",
    "sbafanti": "sbafare",
    "sbafar": "sbafare",
    "sbafaron": "sbafare",
    "sbafarono": "sbafare",
    "sbafasse": "sbafare",
    "sbafasser": "sbafare",
    "sbafassero": "sbafare",
    "sbafassi": "sbafare",
    "sbafassimo": "sbafare",
    "sbafaste": "sbafare",
    "sbafasti": "sbafare",
    "sbafata": "sbafare",
    "sbafate": "sbafare",
    "sbafati": "sbafare",
    "sbafato": "sbafare",
    "sbafava": "sbafare",
    "sbafavamo": "sbafare",
    "sbafavan": "sbafare",
    "sbafavano": "sbafare",
    "sbafavate": "sbafare",
    "sbafavi": "sbafare",
    "sbafavo": "sbafare",
    "sbaferai": "sbafare",
    "sbaferan": "sbafare",
    "sbaferanno": "sbafare",
    "sbaferebbe": "sbafare",
    "sbaferebber": "sbafare",
    "sbaferebbero": "sbafare",
    "sbaferei": "sbafare",
    "sbaferemmo": "sbafare",
    "sbaferemo": "sbafare",
    "sbafereste": "sbafare",
    "sbaferesti": "sbafare",
    "sbaferete": "sbafare",
    "sbaferà": "sbafare",
    "sbaferò": "sbafare",
    "sbafi": "sbafare",
    "sbafiamo": "sbafare",
    "sbafiate": "sbafare",
    "sbafin": "sbafare",
    "sbafino": "sbafare",
    "sbafo": "sbafare",
    "sbafò": "sbafare",
    "sbagli": "sbaglio",
    "sbaglia": "sbagliare",
    "sbagliai": "sbagliare",
    "sbagliammo": "sbagliare",
    "sbagliamo": "sbagliare",
    "sbaglian": "sbagliare",
    "sbagliando": "sbagliare",
    "sbagliano": "sbagliare",
    "sbagliante": "sbagliare",
    "sbaglianti": "sbagliare",
    "sbagliar": "sbagliare",
    "sbagliaron": "sbagliare",
    "sbagliarono": "sbagliare",
    "sbagliasse": "sbagliare",
    "sbagliasser": "sbagliare",
    "sbagliassero": "sbagliare",
    "sbagliassi": "sbagliare",
    "sbagliassimo": "sbagliare",
    "sbagliaste": "sbagliare",
    "sbagliasti": "sbagliare",
    "sbagliata": "sbagliato",
    "sbagliate": "sbagliato",
    "sbagliati": "sbagliato",
    "sbagliato": "sbagliare",
    "sbagliava": "sbagliare",
    "sbagliavamo": "sbagliare",
    "sbagliavan": "sbagliare",
    "sbagliavano": "sbagliare",
    "sbagliavate": "sbagliare",
    "sbagliavi": "sbagliare",
    "sbagliavo": "sbagliare",
    "sbaglierai": "sbagliare",
    "sbaglieran": "sbagliare",
    "sbaglieranno": "sbagliare",
    "sbaglierebbe": "sbagliare",
    "sbaglierebber": "sbagliare",
    "sbaglierebbero": "sbagliare",
    "sbaglierei": "sbagliare",
    "sbaglieremmo": "sbagliare",
    "sbaglieremo": "sbagliare",
    "sbagliereste": "sbagliare",
    "sbaglieresti": "sbagliare",
    "sbaglierete": "sbagliare",
    "sbaglierà": "sbagliare",
    "sbaglierò": "sbagliare",
    "sbaglin": "sbagliare",
    "sbaglino": "sbagliare",
    "sbaglio": "sbagliare",
    "sbagliò": "sbagliare",
    "sbalestra": "sbalestrare",
    "sbalestrai": "sbalestrare",
    "sbalestrammo": "sbalestrare",
    "sbalestran": "sbalestrare",
    "sbalestrando": "sbalestrare",
    "sbalestrano": "sbalestrare",
    "sbalestrante": "sbalestrare",
    "sbalestranti": "sbalestrare",
    "sbalestrar": "sbalestrare",
    "sbalestraron": "sbalestrare",
    "sbalestrarono": "sbalestrare",
    "sbalestrasse": "sbalestrare",
    "sbalestrasser": "sbalestrare",
    "sbalestrassero": "sbalestrare",
    "sbalestrassi": "sbalestrare",
    "sbalestrassimo": "sbalestrare",
    "sbalestraste": "sbalestrare",
    "sbalestrasti": "sbalestrare",
    "sbalestrata": "sbalestrare",
    "sbalestrate": "sbalestrare",
    "sbalestrati": "sbalestrare",
    "sbalestrato": "sbalestrare",
    "sbalestrava": "sbalestrare",
    "sbalestravamo": "sbalestrare",
    "sbalestravan": "sbalestrare",
    "sbalestravano": "sbalestrare",
    "sbalestravate": "sbalestrare",
    "sbalestravi": "sbalestrare",
    "sbalestravo": "sbalestrare",
    "sbalestrerai": "sbalestrare",
    "sbalestreran": "sbalestrare",
    "sbalestreranno": "sbalestrare",
    "sbalestrerebbe": "sbalestrare",
    "sbalestrerebber": "sbalestrare",
    "sbalestrerebbero": "sbalestrare",
    "sbalestrerei": "sbalestrare",
    "sbalestreremmo": "sbalestrare",
    "sbalestreremo": "sbalestrare",
    "sbalestrereste": "sbalestrare",
    "sbalestreresti": "sbalestrare",
    "sbalestrerete": "sbalestrare",
    "sbalestrerà": "sbalestrare",
    "sbalestrerò": "sbalestrare",
    "sbalestri": "sbalestrare",
    "sbalestriamo": "sbalestrare",
    "sbalestriate": "sbalestrare",
    "sbalestrin": "sbalestrare",
    "sbalestrino": "sbalestrare",
    "sbalestro": "sbalestrare",
    "sbalestrò": "sbalestrare",
    "sballa": "sballare",
    "sballai": "sballare",
    "sballammo": "sballare",
    "sballan": "sballare",
    "sballando": "sballare",
    "sballano": "sballare",
    "sballante": "sballare",
    "sballanti": "sballare",
    "sballar": "sballare",
    "sballaron": "sballare",
    "sballarono": "sballare",
    "sballasse": "sballare",
    "sballasser": "sballare",
    "sballassero": "sballare",
    "sballassi": "sballare",
    "sballassimo": "sballare",
    "sballaste": "sballare",
    "sballasti": "sballare",
    "sballata": "sballato",
    "sballate": "sballato",
    "sballati": "sballato",
    "sballato": "sballare",
    "sballava": "sballare",
    "sballavamo": "sballare",
    "sballavan": "sballare",
    "sballavano": "sballare",
    "sballavate": "sballare",
    "sballavi": "sballare",
    "sballavo": "sballare",
    "sballerai": "sballare",
    "sballeran": "sballare",
    "sballeranno": "sballare",
    "sballerebbe": "sballare",
    "sballerebber": "sballare",
    "sballerebbero": "sballare",
    "sballerei": "sballare",
    "sballeremmo": "sballare",
    "sballeremo": "sballare",
    "sballereste": "sballare",
    "sballeresti": "sballare",
    "sballerete": "sballare",
    "sballerà": "sballare",
    "sballerò": "sballare",
    "sballi": "sballo",
    "sballiamo": "sballare",
    "sballiate": "sballare",
    "sballin": "sballare",
    "sballino": "sballare",
    "sballo": "sballare",
    "sballotta": "sballottare",
    "sballottai": "sballottare",
    "sballottammo": "sballottare",
    "sballottan": "sballottare",
    "sballottando": "sballottare",
    "sballottano": "sballottare",
    "sballottante": "sballottare",
    "sballottanti": "sballottare",
    "sballottar": "sballottare",
    "sballottaron": "sballottare",
    "sballottarono": "sballottare",
    "sballottasse": "sballottare",
    "sballottasser": "sballottare",
    "sballottassero": "sballottare",
    "sballottassi": "sballottare",
    "sballottassimo": "sballottare",
    "sballottaste": "sballottare",
    "sballottasti": "sballottare",
    "sballottata": "sballottare",
    "sballottate": "sballottare",
    "sballottati": "sballottare",
    "sballottato": "sballottare",
    "sballottava": "sballottare",
    "sballottavamo": "sballottare",
    "sballottavan": "sballottare",
    "sballottavano": "sballottare",
    "sballottavate": "sballottare",
    "sballottavi": "sballottare",
    "sballottavo": "sballottare",
    "sballotterai": "sballottare",
    "sballotteran": "sballottare",
    "sballotteranno": "sballottare",
    "sballotterebbe": "sballottare",
    "sballotterebber": "sballottare",
    "sballotterebbero": "sballottare",
    "sballotterei": "sballottare",
    "sballotteremmo": "sballottare",
    "sballotteremo": "sballottare",
    "sballottereste": "sballottare",
    "sballotteresti": "sballottare",
    "sballotterete": "sballottare",
    "sballotterà": "sballottare",
    "sballotterò": "sballottare",
    "sballotti": "sballottare",
    "sballottiamo": "sballottare",
    "sballottiate": "sballottare",
    "sballottin": "sballottare",
    "sballottino": "sballottare",
    "sballotto": "sballottare",
    "sballottò": "sballottare",
    "sballò": "sballare",
    "sbalordendo": "sbalordire",
    "sbalordente": "sbalordire",
    "sbalordenti": "sbalordire",
    "sbalordiamo": "sbalordire",
    "sbalordiate": "sbalordire",
    "sbalordii": "sbalordire",
    "sbalordimenti": "sbalordimento",
    "sbalordimmo": "sbalordire",
    "sbalordir": "sbalordire",
    "sbalordirai": "sbalordire",
    "sbalordiran": "sbalordire",
    "sbalordiranno": "sbalordire",
    "sbalordirebbe": "sbalordire",
    "sbalordirebber": "sbalordire",
    "sbalordirebbero": "sbalordire",
    "sbalordirei": "sbalordire",
    "sbalordiremmo": "sbalordire",
    "sbalordiremo": "sbalordire",
    "sbalordireste": "sbalordire",
    "sbalordiresti": "sbalordire",
    "sbalordirete": "sbalordire",
    "sbalordiron": "sbalordire",
    "sbalordirono": "sbalordire",
    "sbalordirà": "sbalordire",
    "sbalordirò": "sbalordire",
    "sbalordisca": "sbalordire",
    "sbalordiscan": "sbalordire",
    "sbalordiscano": "sbalordire",
    "sbalordisce": "sbalordire",
    "sbalordisci": "sbalordire",
    "sbalordisco": "sbalordire",
    "sbalordiscon": "sbalordire",
    "sbalordiscono": "sbalordire",
    "sbalordisse": "sbalordire",
    "sbalordisser": "sbalordire",
    "sbalordissero": "sbalordire",
    "sbalordissi": "sbalordire",
    "sbalordissimo": "sbalordire",
    "sbalordiste": "sbalordire",
    "sbalordisti": "sbalordire",
    "sbalordita": "sbalordire",
    "sbalordite": "sbalordire",
    "sbalorditi": "sbalordire",
    "sbalorditiva": "sbalorditivo",
    "sbalorditive": "sbalorditivo",
    "sbalorditivi": "sbalorditivo",
    "sbalordito": "sbalordire",
    "sbalordiva": "sbalordire",
    "sbalordivamo": "sbalordire",
    "sbalordivan": "sbalordire",
    "sbalordivano": "sbalordire",
    "sbalordivate": "sbalordire",
    "sbalordivi": "sbalordire",
    "sbalordivo": "sbalordire",
    "sbalordì": "sbalordire",
    "sbalza": "sbalzare",
    "sbalzai": "sbalzare",
    "sbalzammo": "sbalzare",
    "sbalzan": "sbalzare",
    "sbalzando": "sbalzare",
    "sbalzano": "sbalzare",
    "sbalzante": "sbalzare",
    "sbalzanti": "sbalzare",
    "sbalzar": "sbalzare",
    "sbalzaron": "sbalzare",
    "sbalzarono": "sbalzare",
    "sbalzasse": "sbalzare",
    "sbalzasser": "sbalzare",
    "sbalzassero": "sbalzare",
    "sbalzassi": "sbalzare",
    "sbalzassimo": "sbalzare",
    "sbalzaste": "sbalzare",
    "sbalzasti": "sbalzare",
    "sbalzata": "sbalzare",
    "sbalzate": "sbalzare",
    "sbalzati": "sbalzare",
    "sbalzato": "sbalzare",
    "sbalzava": "sbalzare",
    "sbalzavamo": "sbalzare",
    "sbalzavan": "sbalzare",
    "sbalzavano": "sbalzare",
    "sbalzavate": "sbalzare",
    "sbalzavi": "sbalzare",
    "sbalzavo": "sbalzare",
    "sbalzerai": "sbalzare",
    "sbalzeran": "sbalzare",
    "sbalzeranno": "sbalzare",
    "sbalzerebbe": "sbalzare",
    "sbalzerebber": "sbalzare",
    "sbalzerebbero": "sbalzare",
    "sbalzerei": "sbalzare",
    "sbalzeremmo": "sbalzare",
    "sbalzeremo": "sbalzare",
    "sbalzereste": "sbalzare",
    "sbalzeresti": "sbalzare",
    "sbalzerete": "sbalzare",
    "sbalzerà": "sbalzare",
    "sbalzerò": "sbalzare",
    "sbalzi": "sbalzo",
    "sbalziamo": "sbalzare",
    "sbalziate": "sbalzare",
    "sbalzin": "sbalzare",
    "sbalzino": "sbalzare",
    "sbalzo": "sbalzare",
    "sbalzò": "sbalzare",
    "sbanca": "sbancare",
    "sbancai": "sbancare",
    "sbancamenti": "sbancamento",
    "sbancammo": "sbancare",
    "sbancan": "sbancare",
    "sbancando": "sbancare",
    "sbancano": "sbancare",
    "sbancante": "sbancare",
    "sbancanti": "sbancare",
    "sbancar": "sbancare",
    "sbancaron": "sbancare",
    "sbancarono": "sbancare",
    "sbancasse": "sbancare",
    "sbancasser": "sbancare",
    "sbancassero": "sbancare",
    "sbancassi": "sbancare",
    "sbancassimo": "sbancare",
    "sbancaste": "sbancare",
    "sbancasti": "sbancare",
    "sbancata": "sbancare",
    "sbancate": "sbancare",
    "sbancati": "sbancare",
    "sbancato": "sbancare",
    "sbancava": "sbancare",
    "sbancavamo": "sbancare",
    "sbancavan": "sbancare",
    "sbancavano": "sbancare",
    "sbancavate": "sbancare",
    "sbancavi": "sbancare",
    "sbancavo": "sbancare",
    "sbancherai": "sbancare",
    "sbancheran": "sbancare",
    "sbancheranno": "sbancare",
    "sbancherebbe": "sbancare",
    "sbancherebber": "sbancare",
    "sbancherebbero": "sbancare",
    "sbancherei": "sbancare",
    "sbancheremmo": "sbancare",
    "sbancheremo": "sbancare",
    "sbanchereste": "sbancare",
    "sbancheresti": "sbancare",
    "sbancherete": "sbancare",
    "sbancherà": "sbancare",
    "sbancherò": "sbancare",
    "sbanchi": "sbancare",
    "sbanchiamo": "sbancare",
    "sbanchiate": "sbancare",
    "sbanchin": "sbancare",
    "sbanchino": "sbancare",
    "sbanco": "sbancare",
    "sbancò": "sbancare",
    "sbanda": "sbandire",
    "sbandai": "sbandare",
    "sbandamenti": "sbandamento",
    "sbandammo": "sbandare",
    "sbandan": "sbandire",
    "sbandando": "sbandare",
    "sbandano": "sbandire",
    "sbandante": "sbandare",
    "sbandanti": "sbandare",
    "sbandar": "sbandare",
    "sbandaron": "sbandare",
    "sbandarono": "sbandare",
    "sbandasse": "sbandare",
    "sbandasser": "sbandare",
    "sbandassero": "sbandare",
    "sbandassi": "sbandare",
    "sbandassimo": "sbandare",
    "sbandaste": "sbandare",
    "sbandasti": "sbandare",
    "sbandata": "sbandato",
    "sbandate": "sbandato",
    "sbandati": "sbandato",
    "sbandato": "sbandare",
    "sbandava": "sbandare",
    "sbandavamo": "sbandare",
    "sbandavan": "sbandare",
    "sbandavano": "sbandare",
    "sbandavate": "sbandare",
    "sbandavi": "sbandare",
    "sbandavo": "sbandare",
    "sbande": "sbandire",
    "sbandendo": "sbandire",
    "sbandente": "sbandire",
    "sbandenti": "sbandire",
    "sbanderai": "sbandare",
    "sbanderan": "sbandare",
    "sbanderanno": "sbandare",
    "sbanderebbe": "sbandare",
    "sbanderebber": "sbandare",
    "sbanderebbero": "sbandare",
    "sbanderei": "sbandare",
    "sbanderemmo": "sbandare",
    "sbanderemo": "sbandare",
    "sbandereste": "sbandare",
    "sbanderesti": "sbandare",
    "sbanderete": "sbandare",
    "sbanderà": "sbandare",
    "sbanderò": "sbandare",
    "sbandi": "sbando",
    "sbandiamo": "sbandire",
    "sbandiate": "sbandire",
    "sbandiera": "sbandierare",
    "sbandierai": "sbandierare",
    "sbandieramenti": "sbandieramento",
    "sbandierammo": "sbandierare",
    "sbandieran": "sbandierare",
    "sbandierando": "sbandierare",
    "sbandierano": "sbandierare",
    "sbandierante": "sbandierare",
    "sbandieranti": "sbandierare",
    "sbandierar": "sbandierare",
    "sbandieraron": "sbandierare",
    "sbandierarono": "sbandierare",
    "sbandierasse": "sbandierare",
    "sbandierasser": "sbandierare",
    "sbandierassero": "sbandierare",
    "sbandierassi": "sbandierare",
    "sbandierassimo": "sbandierare",
    "sbandieraste": "sbandierare",
    "sbandierasti": "sbandierare",
    "sbandierata": "sbandierare",
    "sbandierate": "sbandierare",
    "sbandierati": "sbandierare",
    "sbandierato": "sbandierare",
    "sbandierava": "sbandierare",
    "sbandieravamo": "sbandierare",
    "sbandieravan": "sbandierare",
    "sbandieravano": "sbandierare",
    "sbandieravate": "sbandierare",
    "sbandieravi": "sbandierare",
    "sbandieravo": "sbandierare",
    "sbandiererai": "sbandierare",
    "sbandiereran": "sbandierare",
    "sbandiereranno": "sbandierare",
    "sbandiererebbe": "sbandierare",
    "sbandiererebber": "sbandierare",
    "sbandiererebbero": "sbandierare",
    "sbandiererei": "sbandierare",
    "sbandiereremmo": "sbandierare",
    "sbandiereremo": "sbandierare",
    "sbandierereste": "sbandierare",
    "sbandiereresti": "sbandierare",
    "sbandiererete": "sbandierare",
    "sbandiererà": "sbandierare",
    "sbandiererò": "sbandierare",
    "sbandieri": "sbandierare",
    "sbandieriamo": "sbandierare",
    "sbandieriate": "sbandierare",
    "sbandierin": "sbandierare",
    "sbandierino": "sbandierare",
    "sbandiero": "sbandierare",
    "sbandierò": "sbandierare",
    "sbandii": "sbandire",
    "sbandimmo": "sbandire",
    "sbandin": "sbandare",
    "sbandino": "sbandare",
    "sbandir": "sbandire",
    "sbandirai": "sbandire",
    "sbandiran": "sbandire",
    "sbandiranno": "sbandire",
    "sbandirebbe": "sbandire",
    "sbandirebber": "sbandire",
    "sbandirebbero": "sbandire",
    "sbandirei": "sbandire",
    "sbandiremmo": "sbandire",
    "sbandiremo": "sbandire",
    "sbandireste": "sbandire",
    "sbandiresti": "sbandire",
    "sbandirete": "sbandire",
    "sbandiron": "sbandire",
    "sbandirono": "sbandire",
    "sbandirà": "sbandire",
    "sbandirò": "sbandire",
    "sbandisse": "sbandire",
    "sbandisser": "sbandire",
    "sbandissero": "sbandire",
    "sbandissi": "sbandire",
    "sbandissimo": "sbandire",
    "sbandiste": "sbandire",
    "sbandisti": "sbandire",
    "sbandita": "sbandire",
    "sbandite": "sbandire",
    "sbanditi": "sbandire",
    "sbandito": "sbandire",
    "sbandiva": "sbandire",
    "sbandivamo": "sbandire",
    "sbandivan": "sbandire",
    "sbandivano": "sbandire",
    "sbandivate": "sbandire",
    "sbandivi": "sbandire",
    "sbandivo": "sbandire",
    "sbando": "sbandire",
    "sbandon": "sbandire",
    "sbandono": "sbandire",
    "sbandì": "sbandire",
    "sbandò": "sbandare",
    "sbaracca": "sbaraccare",
    "sbaraccai": "sbaraccare",
    "sbaraccammo": "sbaraccare",
    "sbaraccan": "sbaraccare",
    "sbaraccando": "sbaraccare",
    "sbaraccano": "sbaraccare",
    "sbaraccante": "sbaraccare",
    "sbaraccanti": "sbaraccare",
    "sbaraccar": "sbaraccare",
    "sbaraccaron": "sbaraccare",
    "sbaraccarono": "sbaraccare",
    "sbaraccasse": "sbaraccare",
    "sbaraccasser": "sbaraccare",
    "sbaraccassero": "sbaraccare",
    "sbaraccassi": "sbaraccare",
    "sbaraccassimo": "sbaraccare",
    "sbaraccaste": "sbaraccare",
    "sbaraccasti": "sbaraccare",
    "sbaraccata": "sbaraccare",
    "sbaraccate": "sbaraccare",
    "sbaraccati": "sbaraccare",
    "sbaraccato": "sbaraccare",
    "sbaraccava": "sbaraccare",
    "sbaraccavamo": "sbaraccare",
    "sbaraccavan": "sbaraccare",
    "sbaraccavano": "sbaraccare",
    "sbaraccavate": "sbaraccare",
    "sbaraccavi": "sbaraccare",
    "sbaraccavo": "sbaraccare",
    "sbaraccherai": "sbaraccare",
    "sbaraccheran": "sbaraccare",
    "sbaraccheranno": "sbaraccare",
    "sbaraccherebbe": "sbaraccare",
    "sbaraccherebber": "sbaraccare",
    "sbaraccherebbero": "sbaraccare",
    "sbaraccherei": "sbaraccare",
    "sbaraccheremmo": "sbaraccare",
    "sbaraccheremo": "sbaraccare",
    "sbaracchereste": "sbaraccare",
    "sbaraccheresti": "sbaraccare",
    "sbaraccherete": "sbaraccare",
    "sbaraccherà": "sbaraccare",
    "sbaraccherò": "sbaraccare",
    "sbaracchi": "sbaraccare",
    "sbaracchiamo": "sbaraccare",
    "sbaracchiate": "sbaraccare",
    "sbaracchin": "sbaraccare",
    "sbaracchino": "sbaraccare",
    "sbaracco": "sbaraccare",
    "sbaraccò": "sbaraccare",
    "sbaragli": "sbaragliare",
    "sbaraglia": "sbaragliare",
    "sbaragliai": "sbaragliare",
    "sbaragliammo": "sbaragliare",
    "sbaragliamo": "sbaragliare",
    "sbaraglian": "sbaragliare",
    "sbaragliando": "sbaragliare",
    "sbaragliano": "sbaragliare",
    "sbaragliante": "sbaragliare",
    "sbaraglianti": "sbaragliare",
    "sbaragliar": "sbaragliare",
    "sbaragliaron": "sbaragliare",
    "sbaragliarono": "sbaragliare",
    "sbaragliasse": "sbaragliare",
    "sbaragliasser": "sbaragliare",
    "sbaragliassero": "sbaragliare",
    "sbaragliassi": "sbaragliare",
    "sbaragliassimo": "sbaragliare",
    "sbaragliaste": "sbaragliare",
    "sbaragliasti": "sbaragliare",
    "sbaragliata": "sbaragliare",
    "sbaragliate": "sbaragliare",
    "sbaragliati": "sbaragliare",
    "sbaragliato": "sbaragliare",
    "sbaragliava": "sbaragliare",
    "sbaragliavamo": "sbaragliare",
    "sbaragliavan": "sbaragliare",
    "sbaragliavano": "sbaragliare",
    "sbaragliavate": "sbaragliare",
    "sbaragliavi": "sbaragliare",
    "sbaragliavo": "sbaragliare",
    "sbaraglierai": "sbaragliare",
    "sbaraglieran": "sbaragliare",
    "sbaraglieranno": "sbaragliare",
    "sbaraglierebbe": "sbaragliare",
    "sbaraglierebber": "sbaragliare",
    "sbaraglierebbero": "sbaragliare",
    "sbaraglierei": "sbaragliare",
    "sbaraglieremmo": "sbaragliare",
    "sbaraglieremo": "sbaragliare",
    "sbaragliereste": "sbaragliare",
    "sbaraglieresti": "sbaragliare",
    "sbaraglierete": "sbaragliare",
    "sbaraglierà": "sbaragliare",
    "sbaraglierò": "sbaragliare",
    "sbaraglin": "sbaragliare",
    "sbaraglino": "sbaragliare",
    "sbaraglio": "sbaragliare",
    "sbaragliò": "sbaragliare",
    "sbarazza": "sbarazzare",
    "sbarazzai": "sbarazzare",
    "sbarazzammo": "sbarazzare",
    "sbarazzan": "sbarazzare",
    "sbarazzando": "sbarazzare",
    "sbarazzano": "sbarazzare",
    "sbarazzante": "sbarazzare",
    "sbarazzanti": "sbarazzare",
    "sbarazzar": "sbarazzare",
    "sbarazzaron": "sbarazzare",
    "sbarazzarono": "sbarazzare",
    "sbarazzasse": "sbarazzare",
    "sbarazzasser": "sbarazzare",
    "sbarazzassero": "sbarazzare",
    "sbarazzassi": "sbarazzare",
    "sbarazzassimo": "sbarazzare",
    "sbarazzaste": "sbarazzare",
    "sbarazzasti": "sbarazzare",
    "sbarazzata": "sbarazzare",
    "sbarazzate": "sbarazzare",
    "sbarazzati": "sbarazzare",
    "sbarazzato": "sbarazzare",
    "sbarazzava": "sbarazzare",
    "sbarazzavamo": "sbarazzare",
    "sbarazzavan": "sbarazzare",
    "sbarazzavano": "sbarazzare",
    "sbarazzavate": "sbarazzare",
    "sbarazzavi": "sbarazzare",
    "sbarazzavo": "sbarazzare",
    "sbarazzerai": "sbarazzare",
    "sbarazzeran": "sbarazzare",
    "sbarazzeranno": "sbarazzare",
    "sbarazzerebbe": "sbarazzare",
    "sbarazzerebber": "sbarazzare",
    "sbarazzerebbero": "sbarazzare",
    "sbarazzerei": "sbarazzare",
    "sbarazzeremmo": "sbarazzare",
    "sbarazzeremo": "sbarazzare",
    "sbarazzereste": "sbarazzare",
    "sbarazzeresti": "sbarazzare",
    "sbarazzerete": "sbarazzare",
    "sbarazzerà": "sbarazzare",
    "sbarazzerò": "sbarazzare",
    "sbarazzi": "sbarazzare",
    "sbarazziamo": "sbarazzare",
    "sbarazziate": "sbarazzare",
    "sbarazzin": "sbarazzare",
    "sbarazzina": "sbarazzino",
    "sbarazzine": "sbarazzino",
    "sbarazzini": "sbarazzino",
    "sbarazzino": "sbarazzare",
    "sbarazzo": "sbarazzare",
    "sbarazzò": "sbarazzare",
    "sbarba": "sbarbare",
    "sbarbai": "sbarbare",
    "sbarbammo": "sbarbare",
    "sbarban": "sbarbare",
    "sbarbando": "sbarbare",
    "sbarbano": "sbarbare",
    "sbarbante": "sbarbare",
    "sbarbanti": "sbarbare",
    "sbarbar": "sbarbare",
    "sbarbaron": "sbarbare",
    "sbarbarono": "sbarbare",
    "sbarbasse": "sbarbare",
    "sbarbasser": "sbarbare",
    "sbarbassero": "sbarbare",
    "sbarbassi": "sbarbare",
    "sbarbassimo": "sbarbare",
    "sbarbaste": "sbarbare",
    "sbarbasti": "sbarbare",
    "sbarbata": "sbarbare",
    "sbarbate": "sbarbare",
    "sbarbati": "sbarbare",
    "sbarbato": "sbarbare",
    "sbarbava": "sbarbare",
    "sbarbavamo": "sbarbare",
    "sbarbavan": "sbarbare",
    "sbarbavano": "sbarbare",
    "sbarbavate": "sbarbare",
    "sbarbavi": "sbarbare",
    "sbarbavo": "sbarbare",
    "sbarberai": "sbarbare",
    "sbarberan": "sbarbare",
    "sbarberanno": "sbarbare",
    "sbarberebbe": "sbarbare",
    "sbarberebber": "sbarbare",
    "sbarberebbero": "sbarbare",
    "sbarberei": "sbarbare",
    "sbarberemmo": "sbarbare",
    "sbarberemo": "sbarbare",
    "sbarbereste": "sbarbare",
    "sbarberesti": "sbarbare",
    "sbarberete": "sbarbare",
    "sbarberà": "sbarbare",
    "sbarberò": "sbarbare",
    "sbarbi": "sbarbare",
    "sbarbiamo": "sbarbare",
    "sbarbiate": "sbarbare",
    "sbarbin": "sbarbare",
    "sbarbino": "sbarbare",
    "sbarbo": "sbarbare",
    "sbarbò": "sbarbare",
    "sbarca": "sbarcare",
    "sbarcai": "sbarcare",
    "sbarcammo": "sbarcare",
    "sbarcan": "sbarcare",
    "sbarcando": "sbarcare",
    "sbarcano": "sbarcare",
    "sbarcante": "sbarcare",
    "sbarcanti": "sbarcare",
    "sbarcar": "sbarcare",
    "sbarcaron": "sbarcare",
    "sbarcarono": "sbarcare",
    "sbarcasse": "sbarcare",
    "sbarcasser": "sbarcare",
    "sbarcassero": "sbarcare",
    "sbarcassi": "sbarcare",
    "sbarcassimo": "sbarcare",
    "sbarcaste": "sbarcare",
    "sbarcasti": "sbarcare",
    "sbarcata": "sbarcare",
    "sbarcate": "sbarcare",
    "sbarcati": "sbarcare",
    "sbarcato": "sbarcare",
    "sbarcava": "sbarcare",
    "sbarcavamo": "sbarcare",
    "sbarcavan": "sbarcare",
    "sbarcavano": "sbarcare",
    "sbarcavate": "sbarcare",
    "sbarcavi": "sbarcare",
    "sbarcavo": "sbarcare",
    "sbarcherai": "sbarcare",
    "sbarcheran": "sbarcare",
    "sbarcheranno": "sbarcare",
    "sbarcherebbe": "sbarcare",
    "sbarcherebber": "sbarcare",
    "sbarcherebbero": "sbarcare",
    "sbarcherei": "sbarcare",
    "sbarcheremmo": "sbarcare",
    "sbarcheremo": "sbarcare",
    "sbarchereste": "sbarcare",
    "sbarcheresti": "sbarcare",
    "sbarcherete": "sbarcare",
    "sbarcherà": "sbarcare",
    "sbarcherò": "sbarcare",
    "sbarchi": "sbarco",
    "sbarchiamo": "sbarcare",
    "sbarchiate": "sbarcare",
    "sbarchin": "sbarcare",
    "sbarchino": "sbarcare",
    "sbarco": "sbarcare",
    "sbarcò": "sbarcare",
    "sbarra": "sbarrare",
    "sbarrai": "sbarrare",
    "sbarramenti": "sbarramento",
    "sbarrammo": "sbarrare",
    "sbarran": "sbarrare",
    "sbarrando": "sbarrare",
    "sbarrano": "sbarrare",
    "sbarrante": "sbarrare",
    "sbarranti": "sbarrare",
    "sbarrar": "sbarrare",
    "sbarraron": "sbarrare",
    "sbarrarono": "sbarrare",
    "sbarrasse": "sbarrare",
    "sbarrasser": "sbarrare",
    "sbarrassero": "sbarrare",
    "sbarrassi": "sbarrare",
    "sbarrassimo": "sbarrare",
    "sbarraste": "sbarrare",
    "sbarrasti": "sbarrare",
    "sbarrata": "sbarrato",
    "sbarrate": "sbarrato",
    "sbarrati": "sbarrato",
    "sbarrato": "sbarrare",
    "sbarrava": "sbarrare",
    "sbarravamo": "sbarrare",
    "sbarravan": "sbarrare",
    "sbarravano": "sbarrare",
    "sbarravate": "sbarrare",
    "sbarravi": "sbarrare",
    "sbarravo": "sbarrare",
    "sbarre": "sbarra",
    "sbarrerai": "sbarrare",
    "sbarreran": "sbarrare",
    "sbarreranno": "sbarrare",
    "sbarrerebbe": "sbarrare",
    "sbarrerebber": "sbarrare",
    "sbarrerebbero": "sbarrare",
    "sbarrerei": "sbarrare",
    "sbarreremmo": "sbarrare",
    "sbarreremo": "sbarrare",
    "sbarrereste": "sbarrare",
    "sbarreresti": "sbarrare",
    "sbarrerete": "sbarrare",
    "sbarrerà": "sbarrare",
    "sbarrerò": "sbarrare",
    "sbarri": "sbarrare",
    "sbarriamo": "sbarrare",
    "sbarriate": "sbarrare",
    "sbarrin": "sbarrare",
    "sbarrino": "sbarrare",
    "sbarro": "sbarrare",
    "sbarrò": "sbarrare",
    "sbatacchi": "sbatacchiare",
    "sbatacchia": "sbatacchiare",
    "sbatacchiai": "sbatacchiare",
    "sbatacchiammo": "sbatacchiare",
    "sbatacchiamo": "sbatacchiare",
    "sbatacchian": "sbatacchiare",
    "sbatacchiando": "sbatacchiare",
    "sbatacchiano": "sbatacchiare",
    "sbatacchiante": "sbatacchiare",
    "sbatacchianti": "sbatacchiare",
    "sbatacchiar": "sbatacchiare",
    "sbatacchiaron": "sbatacchiare",
    "sbatacchiarono": "sbatacchiare",
    "sbatacchiasse": "sbatacchiare",
    "sbatacchiasser": "sbatacchiare",
    "sbatacchiassero": "sbatacchiare",
    "sbatacchiassi": "sbatacchiare",
    "sbatacchiassimo": "sbatacchiare",
    "sbatacchiaste": "sbatacchiare",
    "sbatacchiasti": "sbatacchiare",
    "sbatacchiata": "sbatacchiare",
    "sbatacchiate": "sbatacchiare",
    "sbatacchiati": "sbatacchiare",
    "sbatacchiato": "sbatacchiare",
    "sbatacchiava": "sbatacchiare",
    "sbatacchiavamo": "sbatacchiare",
    "sbatacchiavan": "sbatacchiare",
    "sbatacchiavano": "sbatacchiare",
    "sbatacchiavate": "sbatacchiare",
    "sbatacchiavi": "sbatacchiare",
    "sbatacchiavo": "sbatacchiare",
    "sbatacchierai": "sbatacchiare",
    "sbatacchieran": "sbatacchiare",
    "sbatacchieranno": "sbatacchiare",
    "sbatacchierebbe": "sbatacchiare",
    "sbatacchierebber": "sbatacchiare",
    "sbatacchierebbero": "sbatacchiare",
    "sbatacchierei": "sbatacchiare",
    "sbatacchieremmo": "sbatacchiare",
    "sbatacchieremo": "sbatacchiare",
    "sbatacchiereste": "sbatacchiare",
    "sbatacchieresti": "sbatacchiare",
    "sbatacchierete": "sbatacchiare",
    "sbatacchierà": "sbatacchiare",
    "sbatacchierò": "sbatacchiare",
    "sbatacchin": "sbatacchiare",
    "sbatacchino": "sbatacchiare",
    "sbatacchio": "sbatacchiare",
    "sbatacchiò": "sbatacchiare",
    "sbatta": "sbattere",
    "sbattan": "sbattere",
    "sbattano": "sbattere",
    "sbatte": "sbattere",
    "sbattei": "sbattere",
    "sbattemmo": "sbattere",
    "sbattendo": "sbattere",
    "sbattente": "sbattere",
    "sbattenti": "sbattere",
    "sbatter": "sbattere",
    "sbatterai": "sbattere",
    "sbatteran": "sbattere",
    "sbatteranno": "sbattere",
    "sbatterebbe": "sbattere",
    "sbatterebber": "sbattere",
    "sbatterebbero": "sbattere",
    "sbatterei": "sbattere",
    "sbatteremmo": "sbattere",
    "sbatteremo": "sbattere",
    "sbattereste": "sbattere",
    "sbatteresti": "sbattere",
    "sbatterete": "sbattere",
    "sbatteron": "sbattere",
    "sbatterono": "sbattere",
    "sbatterà": "sbattere",
    "sbatterò": "sbattere",
    "sbattesse": "sbattere",
    "sbattesser": "sbattere",
    "sbattessero": "sbattere",
    "sbattessi": "sbattere",
    "sbattessimo": "sbattere",
    "sbatteste": "sbattere",
    "sbattesti": "sbattere",
    "sbattete": "sbattere",
    "sbatteva": "sbattere",
    "sbattevamo": "sbattere",
    "sbattevan": "sbattere",
    "sbattevano": "sbattere",
    "sbattevate": "sbattere",
    "sbattevi": "sbattere",
    "sbattevo": "sbattere",
    "sbattezza": "sbattezzare",
    "sbattezzai": "sbattezzare",
    "sbattezzammo": "sbattezzare",
    "sbattezzan": "sbattezzare",
    "sbattezzando": "sbattezzare",
    "sbattezzano": "sbattezzare",
    "sbattezzante": "sbattezzare",
    "sbattezzanti": "sbattezzare",
    "sbattezzar": "sbattezzare",
    "sbattezzaron": "sbattezzare",
    "sbattezzarono": "sbattezzare",
    "sbattezzasse": "sbattezzare",
    "sbattezzasser": "sbattezzare",
    "sbattezzassero": "sbattezzare",
    "sbattezzassi": "sbattezzare",
    "sbattezzassimo": "sbattezzare",
    "sbattezzaste": "sbattezzare",
    "sbattezzasti": "sbattezzare",
    "sbattezzata": "sbattezzare",
    "sbattezzate": "sbattezzare",
    "sbattezzati": "sbattezzare",
    "sbattezzato": "sbattezzare",
    "sbattezzava": "sbattezzare",
    "sbattezzavamo": "sbattezzare",
    "sbattezzavan": "sbattezzare",
    "sbattezzavano": "sbattezzare",
    "sbattezzavate": "sbattezzare",
    "sbattezzavi": "sbattezzare",
    "sbattezzavo": "sbattezzare",
    "sbattezzerai": "sbattezzare",
    "sbattezzeran": "sbattezzare",
    "sbattezzeranno": "sbattezzare",
    "sbattezzerebbe": "sbattezzare",
    "sbattezzerebber": "sbattezzare",
    "sbattezzerebbero": "sbattezzare",
    "sbattezzerei": "sbattezzare",
    "sbattezzeremmo": "sbattezzare",
    "sbattezzeremo": "sbattezzare",
    "sbattezzereste": "sbattezzare",
    "sbattezzeresti": "sbattezzare",
    "sbattezzerete": "sbattezzare",
    "sbattezzerà": "sbattezzare",
    "sbattezzerò": "sbattezzare",
    "sbattezzi": "sbattezzare",
    "sbattezziamo": "sbattezzare",
    "sbattezziate": "sbattezzare",
    "sbattezzin": "sbattezzare",
    "sbattezzino": "sbattezzare",
    "sbattezzo": "sbattezzare",
    "sbattezzò": "sbattezzare",
    "sbatti": "sbattere",
    "sbattiamo": "sbattere",
    "sbattiate": "sbattere",
    "sbatto": "sbattere",
    "sbatton": "sbattere",
    "sbattono": "sbattere",
    "sbattuta": "sbattuto",
    "sbattute": "sbattuto",
    "sbattuti": "sbattuto",
    "sbattuto": "sbattere",
    "sbattè": "sbattere",
    "sbava": "sbavare",
    "sbavai": "sbavare",
    "sbavammo": "sbavare",
    "sbavan": "sbavare",
    "sbavando": "sbavare",
    "sbavano": "sbavare",
    "sbavante": "sbavare",
    "sbavanti": "sbavare",
    "sbavar": "sbavare",
    "sbavaron": "sbavare",
    "sbavarono": "sbavare",
    "sbavasse": "sbavare",
    "sbavasser": "sbavare",
    "sbavassero": "sbavare",
    "sbavassi": "sbavare",
    "sbavassimo": "sbavare",
    "sbavaste": "sbavare",
    "sbavasti": "sbavare",
    "sbavata": "sbavare",
    "sbavate": "sbavare",
    "sbavati": "sbavare",
    "sbavato": "sbavare",
    "sbavature": "sbavatura",
    "sbavava": "sbavare",
    "sbavavamo": "sbavare",
    "sbavavan": "sbavare",
    "sbavavano": "sbavare",
    "sbavavate": "sbavare",
    "sbavavi": "sbavare",
    "sbavavo": "sbavare",
    "sbaverai": "sbavare",
    "sbaveran": "sbavare",
    "sbaveranno": "sbavare",
    "sbaverebbe": "sbavare",
    "sbaverebber": "sbavare",
    "sbaverebbero": "sbavare",
    "sbaverei": "sbavare",
    "sbaveremmo": "sbavare",
    "sbaveremo": "sbavare",
    "sbavereste": "sbavare",
    "sbaveresti": "sbavare",
    "sbaverete": "sbavare",
    "sbaverà": "sbavare",
    "sbaverò": "sbavare",
    "sbavi": "sbavare",
    "sbaviamo": "sbavare",
    "sbaviate": "sbavare",
    "sbavin": "sbavare",
    "sbavino": "sbavare",
    "sbavo": "sbavare",
    "sbavò": "sbavare",
    "sbecca": "sbeccare",
    "sbeccai": "sbeccare",
    "sbeccammo": "sbeccare",
    "sbeccan": "sbeccare",
    "sbeccando": "sbeccare",
    "sbeccano": "sbeccare",
    "sbeccante": "sbeccare",
    "sbeccanti": "sbeccare",
    "sbeccar": "sbeccare",
    "sbeccaron": "sbeccare",
    "sbeccarono": "sbeccare",
    "sbeccasse": "sbeccare",
    "sbeccasser": "sbeccare",
    "sbeccassero": "sbeccare",
    "sbeccassi": "sbeccare",
    "sbeccassimo": "sbeccare",
    "sbeccaste": "sbeccare",
    "sbeccasti": "sbeccare",
    "sbeccata": "sbeccare",
    "sbeccate": "sbeccare",
    "sbeccati": "sbeccare",
    "sbeccato": "sbeccare",
    "sbeccava": "sbeccare",
    "sbeccavamo": "sbeccare",
    "sbeccavan": "sbeccare",
    "sbeccavano": "sbeccare",
    "sbeccavate": "sbeccare",
    "sbeccavi": "sbeccare",
    "sbeccavo": "sbeccare",
    "sbeccherai": "sbeccare",
    "sbeccheran": "sbeccare",
    "sbeccheranno": "sbeccare",
    "sbeccherebbe": "sbeccare",
    "sbeccherebber": "sbeccare",
    "sbeccherebbero": "sbeccare",
    "sbeccherei": "sbeccare",
    "sbeccheremmo": "sbeccare",
    "sbeccheremo": "sbeccare",
    "sbecchereste": "sbeccare",
    "sbeccheresti": "sbeccare",
    "sbeccherete": "sbeccare",
    "sbeccherà": "sbeccare",
    "sbeccherò": "sbeccare",
    "sbecchi": "sbeccare",
    "sbecchiamo": "sbeccare",
    "sbecchiate": "sbeccare",
    "sbecchin": "sbeccare",
    "sbecchino": "sbeccare",
    "sbecco": "sbeccare",
    "sbeccò": "sbeccare",
    "sbellica": "sbellicare",
    "sbellicai": "sbellicare",
    "sbellicammo": "sbellicare",
    "sbellican": "sbellicare",
    "sbellicando": "sbellicare",
    "sbellicano": "sbellicare",
    "sbellicar": "sbellicare",
    "sbellicaron": "sbellicare",
    "sbellicarono": "sbellicare",
    "sbellicasse": "sbellicare",
    "sbellicasser": "sbellicare",
    "sbellicassero": "sbellicare",
    "sbellicassi": "sbellicare",
    "sbellicassimo": "sbellicare",
    "sbellicaste": "sbellicare",
    "sbellicasti": "sbellicare",
    "sbellicata": "sbellicare",
    "sbellicate": "sbellicare",
    "sbellicati": "sbellicare",
    "sbellicato": "sbellicare",
    "sbellicava": "sbellicare",
    "sbellicavamo": "sbellicare",
    "sbellicavan": "sbellicare",
    "sbellicavano": "sbellicare",
    "sbellicavate": "sbellicare",
    "sbellicavi": "sbellicare",
    "sbellicavo": "sbellicare",
    "sbellicherai": "sbellicare",
    "sbellicheran": "sbellicare",
    "sbellicheranno": "sbellicare",
    "sbellicherebbe": "sbellicare",
    "sbellicherebber": "sbellicare",
    "sbellicherebbero": "sbellicare",
    "sbellicherei": "sbellicare",
    "sbellicheremmo": "sbellicare",
    "sbellicheremo": "sbellicare",
    "sbellichereste": "sbellicare",
    "sbellicheresti": "sbellicare",
    "sbellicherete": "sbellicare",
    "sbellicherà": "sbellicare",
    "sbellicherò": "sbellicare",
    "sbellichi": "sbellicare",
    "sbellichiamo": "sbellicare",
    "sbellichiate": "sbellicare",
    "sbellichin": "sbellicare",
    "sbellichino": "sbellicare",
    "sbellico": "sbellicare",
    "sbellicò": "sbellicare",
    "sbenda": "sbendare",
    "sbendai": "sbendare",
    "sbendammo": "sbendare",
    "sbendan": "sbendare",
    "sbendando": "sbendare",
    "sbendano": "sbendare",
    "sbendante": "sbendare",
    "sbendanti": "sbendare",
    "sbendar": "sbendare",
    "sbendaron": "sbendare",
    "sbendarono": "sbendare",
    "sbendasse": "sbendare",
    "sbendasser": "sbendare",
    "sbendassero": "sbendare",
    "sbendassi": "sbendare",
    "sbendassimo": "sbendare",
    "sbendaste": "sbendare",
    "sbendasti": "sbendare",
    "sbendata": "sbendare",
    "sbendate": "sbendare",
    "sbendati": "sbendare",
    "sbendato": "sbendare",
    "sbendava": "sbendare",
    "sbendavamo": "sbendare",
    "sbendavan": "sbendare",
    "sbendavano": "sbendare",
    "sbendavate": "sbendare",
    "sbendavi": "sbendare",
    "sbendavo": "sbendare",
    "sbenderai": "sbendare",
    "sbenderan": "sbendare",
    "sbenderanno": "sbendare",
    "sbenderebbe": "sbendare",
    "sbenderebber": "sbendare",
    "sbenderebbero": "sbendare",
    "sbenderei": "sbendare",
    "sbenderemmo": "sbendare",
    "sbenderemo": "sbendare",
    "sbendereste": "sbendare",
    "sbenderesti": "sbendare",
    "sbenderete": "sbendare",
    "sbenderà": "sbendare",
    "sbenderò": "sbendare",
    "sbendi": "sbendare",
    "sbendiamo": "sbendare",
    "sbendiate": "sbendare",
    "sbendin": "sbendare",
    "sbendino": "sbendare",
    "sbendo": "sbendare",
    "sbendò": "sbendare",
    "sberleffi": "sberleffo",
    "sbertuccerai": "sbertucciare",
    "sbertucceran": "sbertucciare",
    "sbertucceranno": "sbertucciare",
    "sbertuccerebbe": "sbertucciare",
    "sbertuccerebber": "sbertucciare",
    "sbertuccerebbero": "sbertucciare",
    "sbertuccerei": "sbertucciare",
    "sbertucceremmo": "sbertucciare",
    "sbertucceremo": "sbertucciare",
    "sbertuccereste": "sbertucciare",
    "sbertucceresti": "sbertucciare",
    "sbertuccerete": "sbertucciare",
    "sbertuccerà": "sbertucciare",
    "sbertuccerò": "sbertucciare",
    "sbertucci": "sbertucciare",
    "sbertuccia": "sbertucciare",
    "sbertucciai": "sbertucciare",
    "sbertucciammo": "sbertucciare",
    "sbertucciamo": "sbertucciare",
    "sbertuccian": "sbertucciare",
    "sbertucciando": "sbertucciare",
    "sbertucciano": "sbertucciare",
    "sbertucciante": "sbertucciare",
    "sbertuccianti": "sbertucciare",
    "sbertucciar": "sbertucciare",
    "sbertucciaron": "sbertucciare",
    "sbertucciarono": "sbertucciare",
    "sbertucciasse": "sbertucciare",
    "sbertucciasser": "sbertucciare",
    "sbertucciassero": "sbertucciare",
    "sbertucciassi": "sbertucciare",
    "sbertucciassimo": "sbertucciare",
    "sbertucciaste": "sbertucciare",
    "sbertucciasti": "sbertucciare",
    "sbertucciata": "sbertucciare",
    "sbertucciate": "sbertucciare",
    "sbertucciati": "sbertucciare",
    "sbertucciato": "sbertucciare",
    "sbertucciava": "sbertucciare",
    "sbertucciavamo": "sbertucciare",
    "sbertucciavan": "sbertucciare",
    "sbertucciavano": "sbertucciare",
    "sbertucciavate": "sbertucciare",
    "sbertucciavi": "sbertucciare",
    "sbertucciavo": "sbertucciare",
    "sbertuccin": "sbertucciare",
    "sbertuccino": "sbertucciare",
    "sbertuccio": "sbertucciare",
    "sbertucciò": "sbertucciare",
    "sbevazza": "sbevazzare",
    "sbevazzai": "sbevazzare",
    "sbevazzammo": "sbevazzare",
    "sbevazzan": "sbevazzare",
    "sbevazzando": "sbevazzare",
    "sbevazzano": "sbevazzare",
    "sbevazzante": "sbevazzare",
    "sbevazzanti": "sbevazzare",
    "sbevazzar": "sbevazzare",
    "sbevazzaron": "sbevazzare",
    "sbevazzarono": "sbevazzare",
    "sbevazzasse": "sbevazzare",
    "sbevazzasser": "sbevazzare",
    "sbevazzassero": "sbevazzare",
    "sbevazzassi": "sbevazzare",
    "sbevazzassimo": "sbevazzare",
    "sbevazzaste": "sbevazzare",
    "sbevazzasti": "sbevazzare",
    "sbevazzata": "sbevazzare",
    "sbevazzate": "sbevazzare",
    "sbevazzati": "sbevazzare",
    "sbevazzato": "sbevazzare",
    "sbevazzava": "sbevazzare",
    "sbevazzavamo": "sbevazzare",
    "sbevazzavan": "sbevazzare",
    "sbevazzavano": "sbevazzare",
    "sbevazzavate": "sbevazzare",
    "sbevazzavi": "sbevazzare",
    "sbevazzavo": "sbevazzare",
    "sbevazzerai": "sbevazzare",
    "sbevazzeran": "sbevazzare",
    "sbevazzeranno": "sbevazzare",
    "sbevazzerebbe": "sbevazzare",
    "sbevazzerebber": "sbevazzare",
    "sbevazzerebbero": "sbevazzare",
    "sbevazzerei": "sbevazzare",
    "sbevazzeremmo": "sbevazzare",
    "sbevazzeremo": "sbevazzare",
    "sbevazzereste": "sbevazzare",
    "sbevazzeresti": "sbevazzare",
    "sbevazzerete": "sbevazzare",
    "sbevazzerà": "sbevazzare",
    "sbevazzerò": "sbevazzare",
    "sbevazzi": "sbevazzare",
    "sbevazziamo": "sbevazzare",
    "sbevazziate": "sbevazzare",
    "sbevazzin": "sbevazzare",
    "sbevazzino": "sbevazzare",
    "sbevazzo": "sbevazzare",
    "sbevazzò": "sbevazzare",
    "sbiadendo": "sbiadire",
    "sbiadente": "sbiadire",
    "sbiadenti": "sbiadire",
    "sbiadiamo": "sbiadire",
    "sbiadiate": "sbiadire",
    "sbiadii": "sbiadire",
    "sbiadimmo": "sbiadire",
    "sbiadir": "sbiadire",
    "sbiadirai": "sbiadire",
    "sbiadiran": "sbiadire",
    "sbiadiranno": "sbiadire",
    "sbiadirebbe": "sbiadire",
    "sbiadirebber": "sbiadire",
    "sbiadirebbero": "sbiadire",
    "sbiadirei": "sbiadire",
    "sbiadiremmo": "sbiadire",
    "sbiadiremo": "sbiadire",
    "sbiadireste": "sbiadire",
    "sbiadiresti": "sbiadire",
    "sbiadirete": "sbiadire",
    "sbiadiron": "sbiadire",
    "sbiadirono": "sbiadire",
    "sbiadirà": "sbiadire",
    "sbiadirò": "sbiadire",
    "sbiadisca": "sbiadire",
    "sbiadiscan": "sbiadire",
    "sbiadiscano": "sbiadire",
    "sbiadisce": "sbiadire",
    "sbiadisci": "sbiadire",
    "sbiadisco": "sbiadire",
    "sbiadiscon": "sbiadire",
    "sbiadiscono": "sbiadire",
    "sbiadisse": "sbiadire",
    "sbiadisser": "sbiadire",
    "sbiadissero": "sbiadire",
    "sbiadissi": "sbiadire",
    "sbiadissimo": "sbiadire",
    "sbiadiste": "sbiadire",
    "sbiadisti": "sbiadire",
    "sbiadita": "sbiadito",
    "sbiadite": "sbiadito",
    "sbiaditi": "sbiadito",
    "sbiadito": "sbiadire",
    "sbiadiva": "sbiadire",
    "sbiadivamo": "sbiadire",
    "sbiadivan": "sbiadire",
    "sbiadivano": "sbiadire",
    "sbiadivate": "sbiadire",
    "sbiadivi": "sbiadire",
    "sbiadivo": "sbiadire",
    "sbiadì": "sbiadire",
    "sbianca": "sbiancare",
    "sbiancai": "sbiancare",
    "sbiancammo": "sbiancare",
    "sbiancan": "sbiancare",
    "sbiancando": "sbiancare",
    "sbiancano": "sbiancare",
    "sbiancante": "sbiancare",
    "sbiancanti": "sbiancare",
    "sbiancar": "sbiancare",
    "sbiancaron": "sbiancare",
    "sbiancarono": "sbiancare",
    "sbiancasse": "sbiancare",
    "sbiancasser": "sbiancare",
    "sbiancassero": "sbiancare",
    "sbiancassi": "sbiancare",
    "sbiancassimo": "sbiancare",
    "sbiancaste": "sbiancare",
    "sbiancasti": "sbiancare",
    "sbiancata": "sbiancare",
    "sbiancate": "sbiancare",
    "sbiancati": "sbiancare",
    "sbiancato": "sbiancare",
    "sbiancava": "sbiancare",
    "sbiancavamo": "sbiancare",
    "sbiancavan": "sbiancare",
    "sbiancavano": "sbiancare",
    "sbiancavate": "sbiancare",
    "sbiancavi": "sbiancare",
    "sbiancavo": "sbiancare",
    "sbiancherai": "sbiancare",
    "sbiancheran": "sbiancare",
    "sbiancheranno": "sbiancare",
    "sbiancherebbe": "sbiancare",
    "sbiancherebber": "sbiancare",
    "sbiancherebbero": "sbiancare",
    "sbiancherei": "sbiancare",
    "sbiancheremmo": "sbiancare",
    "sbiancheremo": "sbiancare",
    "sbianchereste": "sbiancare",
    "sbiancheresti": "sbiancare",
    "sbiancherete": "sbiancare",
    "sbiancherà": "sbiancare",
    "sbiancherò": "sbiancare",
    "sbianchi": "sbiancare",
    "sbianchiamo": "sbiancare",
    "sbianchiate": "sbiancare",
    "sbianchin": "sbiancare",
    "sbianchino": "sbiancare",
    "sbianco": "sbiancare",
    "sbiancò": "sbiancare",
    "sbigotta": "sbigottire",
    "sbigottan": "sbigottire",
    "sbigottano": "sbigottire",
    "sbigotte": "sbigottire",
    "sbigottendo": "sbigottire",
    "sbigottente": "sbigottire",
    "sbigottenti": "sbigottire",
    "sbigotti": "sbigottire",
    "sbigottiamo": "sbigottire",
    "sbigottiate": "sbigottire",
    "sbigottii": "sbigottire",
    "sbigottimenti": "sbigottimento",
    "sbigottimmo": "sbigottire",
    "sbigottir": "sbigottire",
    "sbigottirai": "sbigottire",
    "sbigottiran": "sbigottire",
    "sbigottiranno": "sbigottire",
    "sbigottirebbe": "sbigottire",
    "sbigottirebber": "sbigottire",
    "sbigottirebbero": "sbigottire",
    "sbigottirei": "sbigottire",
    "sbigottiremmo": "sbigottire",
    "sbigottiremo": "sbigottire",
    "sbigottireste": "sbigottire",
    "sbigottiresti": "sbigottire",
    "sbigottirete": "sbigottire",
    "sbigottiron": "sbigottire",
    "sbigottirono": "sbigottire",
    "sbigottirà": "sbigottire",
    "sbigottirò": "sbigottire",
    "sbigottisse": "sbigottire",
    "sbigottisser": "sbigottire",
    "sbigottissero": "sbigottire",
    "sbigottissi": "sbigottire",
    "sbigottissimo": "sbigottire",
    "sbigottiste": "sbigottire",
    "sbigottisti": "sbigottire",
    "sbigottita": "sbigottire",
    "sbigottite": "sbigottire",
    "sbigottiti": "sbigottito",
    "sbigottito": "sbigottire",
    "sbigottiva": "sbigottire",
    "sbigottivamo": "sbigottire",
    "sbigottivan": "sbigottire",
    "sbigottivano": "sbigottire",
    "sbigottivate": "sbigottire",
    "sbigottivi": "sbigottire",
    "sbigottivo": "sbigottire",
    "sbigotto": "sbigottire",
    "sbigotton": "sbigottire",
    "sbigottono": "sbigottire",
    "sbigottì": "sbigottire",
    "sbilancerai": "sbilanciare",
    "sbilanceran": "sbilanciare",
    "sbilanceranno": "sbilanciare",
    "sbilancerebbe": "sbilanciare",
    "sbilancerebber": "sbilanciare",
    "sbilancerebbero": "sbilanciare",
    "sbilancerei": "sbilanciare",
    "sbilanceremmo": "sbilanciare",
    "sbilanceremo": "sbilanciare",
    "sbilancereste": "sbilanciare",
    "sbilanceresti": "sbilanciare",
    "sbilancerete": "sbilanciare",
    "sbilancerà": "sbilanciare",
    "sbilancerò": "sbilanciare",
    "sbilanci": "sbilancio",
    "sbilancia": "sbilanciare",
    "sbilanciai": "sbilanciare",
    "sbilanciamenti": "sbilanciamento",
    "sbilanciammo": "sbilanciare",
    "sbilanciamo": "sbilanciare",
    "sbilancian": "sbilanciare",
    "sbilanciando": "sbilanciare",
    "sbilanciano": "sbilanciare",
    "sbilanciante": "sbilanciare",
    "sbilancianti": "sbilanciare",
    "sbilanciar": "sbilanciare",
    "sbilanciaron": "sbilanciare",
    "sbilanciarono": "sbilanciare",
    "sbilanciasse": "sbilanciare",
    "sbilanciasser": "sbilanciare",
    "sbilanciassero": "sbilanciare",
    "sbilanciassi": "sbilanciare",
    "sbilanciassimo": "sbilanciare",
    "sbilanciaste": "sbilanciare",
    "sbilanciasti": "sbilanciare",
    "sbilanciata": "sbilanciare",
    "sbilanciate": "sbilanciare",
    "sbilanciati": "sbilanciare",
    "sbilanciato": "sbilanciare",
    "sbilanciava": "sbilanciare",
    "sbilanciavamo": "sbilanciare",
    "sbilanciavan": "sbilanciare",
    "sbilanciavano": "sbilanciare",
    "sbilanciavate": "sbilanciare",
    "sbilanciavi": "sbilanciare",
    "sbilanciavo": "sbilanciare",
    "sbilancin": "sbilanciare",
    "sbilancino": "sbilanciare",
    "sbilancio": "sbilanciare",
    "sbilanciò": "sbilanciare",
    "sbilenca": "sbilenco",
    "sbilenche": "sbilenco",
    "sbilenchi": "sbilenco",
    "sbircerai": "sbirciare",
    "sbirceran": "sbirciare",
    "sbirceranno": "sbirciare",
    "sbircerebbe": "sbirciare",
    "sbircerebber": "sbirciare",
    "sbircerebbero": "sbirciare",
    "sbircerei": "sbirciare",
    "sbirceremmo": "sbirciare",
    "sbirceremo": "sbirciare",
    "sbircereste": "sbirciare",
    "sbirceresti": "sbirciare",
    "sbircerete": "sbirciare",
    "sbircerà": "sbirciare",
    "sbircerò": "sbirciare",
    "sbirci": "sbirciare",
    "sbircia": "sbirciare",
    "sbirciai": "sbirciare",
    "sbirciammo": "sbirciare",
    "sbirciamo": "sbirciare",
    "sbircian": "sbirciare",
    "sbirciando": "sbirciare",
    "sbirciano": "sbirciare",
    "sbirciante": "sbirciare",
    "sbircianti": "sbirciare",
    "sbirciar": "sbirciare",
    "sbirciaron": "sbirciare",
    "sbirciarono": "sbirciare",
    "sbirciasse": "sbirciare",
    "sbirciasser": "sbirciare",
    "sbirciassero": "sbirciare",
    "sbirciassi": "sbirciare",
    "sbirciassimo": "sbirciare",
    "sbirciaste": "sbirciare",
    "sbirciasti": "sbirciare",
    "sbirciata": "sbirciare",
    "sbirciate": "sbirciare",
    "sbirciati": "sbirciare",
    "sbirciato": "sbirciare",
    "sbirciava": "sbirciare",
    "sbirciavamo": "sbirciare",
    "sbirciavan": "sbirciare",
    "sbirciavano": "sbirciare",
    "sbirciavate": "sbirciare",
    "sbirciavi": "sbirciare",
    "sbirciavo": "sbirciare",
    "sbircin": "sbirciare",
    "sbircino": "sbirciare",
    "sbircio": "sbirciare",
    "sbirciò": "sbirciare",
    "sbirri": "sbirro",
    "sbizzarrendo": "sbizzarrire",
    "sbizzarrente": "sbizzarrire",
    "sbizzarrenti": "sbizzarrire",
    "sbizzarriamo": "sbizzarrire",
    "sbizzarriate": "sbizzarrire",
    "sbizzarrii": "sbizzarrire",
    "sbizzarrimmo": "sbizzarrire",
    "sbizzarrir": "sbizzarrire",
    "sbizzarrirai": "sbizzarrire",
    "sbizzarriran": "sbizzarrire",
    "sbizzarriranno": "sbizzarrire",
    "sbizzarrirebbe": "sbizzarrire",
    "sbizzarrirebber": "sbizzarrire",
    "sbizzarrirebbero": "sbizzarrire",
    "sbizzarrirei": "sbizzarrire",
    "sbizzarriremmo": "sbizzarrire",
    "sbizzarriremo": "sbizzarrire",
    "sbizzarrireste": "sbizzarrire",
    "sbizzarriresti": "sbizzarrire",
    "sbizzarrirete": "sbizzarrire",
    "sbizzarriron": "sbizzarrire",
    "sbizzarrirono": "sbizzarrire",
    "sbizzarrirà": "sbizzarrire",
    "sbizzarrirò": "sbizzarrire",
    "sbizzarrisca": "sbizzarrire",
    "sbizzarriscan": "sbizzarrire",
    "sbizzarriscano": "sbizzarrire",
    "sbizzarrisce": "sbizzarrire",
    "sbizzarrisci": "sbizzarrire",
    "sbizzarrisco": "sbizzarrire",
    "sbizzarriscon": "sbizzarrire",
    "sbizzarriscono": "sbizzarrire",
    "sbizzarrisse": "sbizzarrire",
    "sbizzarrisser": "sbizzarrire",
    "sbizzarrissero": "sbizzarrire",
    "sbizzarrissi": "sbizzarrire",
    "sbizzarrissimo": "sbizzarrire",
    "sbizzarriste": "sbizzarrire",
    "sbizzarristi": "sbizzarrire",
    "sbizzarrita": "sbizzarrire",
    "sbizzarrite": "sbizzarrire",
    "sbizzarriti": "sbizzarrire",
    "sbizzarrito": "sbizzarrire",
    "sbizzarriva": "sbizzarrire",
    "sbizzarrivamo": "sbizzarrire",
    "sbizzarrivan": "sbizzarrire",
    "sbizzarrivano": "sbizzarrire",
    "sbizzarrivate": "sbizzarrire",
    "sbizzarrivi": "sbizzarrire",
    "sbizzarrivo": "sbizzarrire",
    "sbizzarrì": "sbizzarrire",
    "sblocca": "sbloccare",
    "sbloccai": "sbloccare",
    "sbloccammo": "sbloccare",
    "sbloccan": "sbloccare",
    "sbloccando": "sbloccare",
    "sbloccano": "sbloccare",
    "sbloccante": "sbloccare",
    "sbloccanti": "sbloccare",
    "sbloccar": "sbloccare",
    "sbloccaron": "sbloccare",
    "sbloccarono": "sbloccare",
    "sbloccasse": "sbloccare",
    "sbloccasser": "sbloccare",
    "sbloccassero": "sbloccare",
    "sbloccassi": "sbloccare",
    "sbloccassimo": "sbloccare",
    "sbloccaste": "sbloccare",
    "sbloccasti": "sbloccare",
    "sbloccata": "sbloccare",
    "sbloccate": "sbloccare",
    "sbloccati": "sbloccare",
    "sbloccato": "sbloccare",
    "sbloccava": "sbloccare",
    "sbloccavamo": "sbloccare",
    "sbloccavan": "sbloccare",
    "sbloccavano": "sbloccare",
    "sbloccavate": "sbloccare",
    "sbloccavi": "sbloccare",
    "sbloccavo": "sbloccare",
    "sbloccherai": "sbloccare",
    "sbloccheran": "sbloccare",
    "sbloccheranno": "sbloccare",
    "sbloccherebbe": "sbloccare",
    "sbloccherebber": "sbloccare",
    "sbloccherebbero": "sbloccare",
    "sbloccherei": "sbloccare",
    "sbloccheremmo": "sbloccare",
    "sbloccheremo": "sbloccare",
    "sblocchereste": "sbloccare",
    "sbloccheresti": "sbloccare",
    "sbloccherete": "sbloccare",
    "sbloccherà": "sbloccare",
    "sbloccherò": "sbloccare",
    "sblocchi": "sblocco",
    "sblocchiamo": "sbloccare",
    "sblocchiate": "sbloccare",
    "sblocchin": "sbloccare",
    "sblocchino": "sbloccare",
    "sblocco": "sbloccare",
    "sbloccò": "sbloccare",
    "sbocca": "sboccare",
    "sboccai": "sboccare",
    "sboccammo": "sboccare",
    "sboccan": "sboccare",
    "sboccando": "sboccare",
    "sboccano": "sboccare",
    "sboccante": "sboccare",
    "sboccanti": "sboccare",
    "sboccar": "sboccare",
    "sboccaron": "sboccare",
    "sboccarono": "sboccare",
    "sboccasse": "sboccare",
    "sboccasser": "sboccare",
    "sboccassero": "sboccare",
    "sboccassi": "sboccare",
    "sboccassimo": "sboccare",
    "sboccaste": "sboccare",
    "sboccasti": "sboccare",
    "sboccata": "sboccato",
    "sboccate": "sboccato",
    "sboccati": "sboccato",
    "sboccato": "sboccare",
    "sboccava": "sboccare",
    "sboccavamo": "sboccare",
    "sboccavan": "sboccare",
    "sboccavano": "sboccare",
    "sboccavate": "sboccare",
    "sboccavi": "sboccare",
    "sboccavo": "sboccare",
    "sboccerai": "sbocciare",
    "sbocceran": "sbocciare",
    "sbocceranno": "sbocciare",
    "sboccerebbe": "sbocciare",
    "sboccerebber": "sbocciare",
    "sboccerebbero": "sbocciare",
    "sboccerei": "sbocciare",
    "sbocceremmo": "sbocciare",
    "sbocceremo": "sbocciare",
    "sboccereste": "sbocciare",
    "sbocceresti": "sbocciare",
    "sboccerete": "sbocciare",
    "sboccerà": "sbocciare",
    "sboccerò": "sbocciare",
    "sboccherai": "sboccare",
    "sboccheran": "sboccare",
    "sboccheranno": "sboccare",
    "sboccherebbe": "sboccare",
    "sboccherebber": "sboccare",
    "sboccherebbero": "sboccare",
    "sboccherei": "sboccare",
    "sboccheremmo": "sboccare",
    "sboccheremo": "sboccare",
    "sbocchereste": "sboccare",
    "sboccheresti": "sboccare",
    "sboccherete": "sboccare",
    "sboccherà": "sboccare",
    "sboccherò": "sboccare",
    "sbocchi": "sbocco",
    "sbocchiamo": "sboccare",
    "sbocchiate": "sboccare",
    "sbocchin": "sboccare",
    "sbocchino": "sboccare",
    "sbocci": "sbocciare",
    "sboccia": "sbocciare",
    "sbocciai": "sbocciare",
    "sbocciammo": "sbocciare",
    "sbocciamo": "sbocciare",
    "sboccian": "sbocciare",
    "sbocciando": "sbocciare",
    "sbocciano": "sbocciare",
    "sbocciante": "sbocciare",
    "sboccianti": "sbocciare",
    "sbocciar": "sbocciare",
    "sbocciaron": "sbocciare",
    "sbocciarono": "sbocciare",
    "sbocciasse": "sbocciare",
    "sbocciasser": "sbocciare",
    "sbocciassero": "sbocciare",
    "sbocciassi": "sbocciare",
    "sbocciassimo": "sbocciare",
    "sbocciaste": "sbocciare",
    "sbocciasti": "sbocciare",
    "sbocciata": "sbocciare",
    "sbocciate": "sbocciare",
    "sbocciati": "sbocciare",
    "sbocciato": "sbocciare",
    "sbocciava": "sbocciare",
    "sbocciavamo": "sbocciare",
    "sbocciavan": "sbocciare",
    "sbocciavano": "sbocciare",
    "sbocciavate": "sbocciare",
    "sbocciavi": "sbocciare",
    "sbocciavo": "sbocciare",
    "sboccin": "sbocciare",
    "sboccino": "sbocciare",
    "sboccio": "sbocciare",
    "sbocciò": "sbocciare",
    "sbocco": "sboccare",
    "sbocconcella": "sbocconcellare",
    "sbocconcellai": "sbocconcellare",
    "sbocconcellammo": "sbocconcellare",
    "sbocconcellan": "sbocconcellare",
    "sbocconcellando": "sbocconcellare",
    "sbocconcellano": "sbocconcellare",
    "sbocconcellante": "sbocconcellare",
    "sbocconcellanti": "sbocconcellare",
    "sbocconcellar": "sbocconcellare",
    "sbocconcellaron": "sbocconcellare",
    "sbocconcellarono": "sbocconcellare",
    "sbocconcellasse": "sbocconcellare",
    "sbocconcellasser": "sbocconcellare",
    "sbocconcellassero": "sbocconcellare",
    "sbocconcellassi": "sbocconcellare",
    "sbocconcellassimo": "sbocconcellare",
    "sbocconcellaste": "sbocconcellare",
    "sbocconcellasti": "sbocconcellare",
    "sbocconcellata": "sbocconcellare",
    "sbocconcellate": "sbocconcellare",
    "sbocconcellati": "sbocconcellare",
    "sbocconcellato": "sbocconcellare",
    "sbocconcellava": "sbocconcellare",
    "sbocconcellavamo": "sbocconcellare",
    "sbocconcellavan": "sbocconcellare",
    "sbocconcellavano": "sbocconcellare",
    "sbocconcellavate": "sbocconcellare",
    "sbocconcellavi": "sbocconcellare",
    "sbocconcellavo": "sbocconcellare",
    "sbocconcellerai": "sbocconcellare",
    "sbocconcelleran": "sbocconcellare",
    "sbocconcelleranno": "sbocconcellare",
    "sbocconcellerebbe": "sbocconcellare",
    "sbocconcellerebber": "sbocconcellare",
    "sbocconcellerebbero": "sbocconcellare",
    "sbocconcellerei": "sbocconcellare",
    "sbocconcelleremmo": "sbocconcellare",
    "sbocconcelleremo": "sbocconcellare",
    "sbocconcellereste": "sbocconcellare",
    "sbocconcelleresti": "sbocconcellare",
    "sbocconcellerete": "sbocconcellare",
    "sbocconcellerà": "sbocconcellare",
    "sbocconcellerò": "sbocconcellare",
    "sbocconcelli": "sbocconcellare",
    "sbocconcelliamo": "sbocconcellare",
    "sbocconcelliate": "sbocconcellare",
    "sbocconcellin": "sbocconcellare",
    "sbocconcellino": "sbocconcellare",
    "sbocconcello": "sbocconcellare",
    "sbocconcellò": "sbocconcellare",
    "sboccò": "sboccare",
    "sbollendo": "sbollire",
    "sbollenta": "sbollentare",
    "sbollentai": "sbollentare",
    "sbollentammo": "sbollentare",
    "sbollentan": "sbollentare",
    "sbollentando": "sbollentare",
    "sbollentano": "sbollentare",
    "sbollentante": "sbollentare",
    "sbollentanti": "sbollentare",
    "sbollentar": "sbollentare",
    "sbollentaron": "sbollentare",
    "sbollentarono": "sbollentare",
    "sbollentasse": "sbollentare",
    "sbollentasser": "sbollentare",
    "sbollentassero": "sbollentare",
    "sbollentassi": "sbollentare",
    "sbollentassimo": "sbollentare",
    "sbollentaste": "sbollentare",
    "sbollentasti": "sbollentare",
    "sbollentata": "sbollentare",
    "sbollentate": "sbollentare",
    "sbollentati": "sbollentare",
    "sbollentato": "sbollentare",
    "sbollentava": "sbollentare",
    "sbollentavamo": "sbollentare",
    "sbollentavan": "sbollentare",
    "sbollentavano": "sbollentare",
    "sbollentavate": "sbollentare",
    "sbollentavi": "sbollentare",
    "sbollentavo": "sbollentare",
    "sbollente": "sbollire",
    "sbollenterai": "sbollentare",
    "sbollenteran": "sbollentare",
    "sbollenteranno": "sbollentare",
    "sbollenterebbe": "sbollentare",
    "sbollenterebber": "sbollentare",
    "sbollenterebbero": "sbollentare",
    "sbollenterei": "sbollentare",
    "sbollenteremmo": "sbollentare",
    "sbollenteremo": "sbollentare",
    "sbollentereste": "sbollentare",
    "sbollenteresti": "sbollentare",
    "sbollenterete": "sbollentare",
    "sbollenterà": "sbollentare",
    "sbollenterò": "sbollentare",
    "sbollenti": "sbollire",
    "sbollentiamo": "sbollentare",
    "sbollentiate": "sbollentare",
    "sbollentin": "sbollentare",
    "sbollentino": "sbollentare",
    "sbollento": "sbollentare",
    "sbollentò": "sbollentare",
    "sbolliamo": "sbollire",
    "sbolliate": "sbollire",
    "sbollii": "sbollire",
    "sbollimmo": "sbollire",
    "sbollir": "sbollire",
    "sbollirai": "sbollire",
    "sbolliran": "sbollire",
    "sbolliranno": "sbollire",
    "sbollirebbe": "sbollire",
    "sbollirebber": "sbollire",
    "sbollirebbero": "sbollire",
    "sbollirei": "sbollire",
    "sbolliremmo": "sbollire",
    "sbolliremo": "sbollire",
    "sbollireste": "sbollire",
    "sbolliresti": "sbollire",
    "sbollirete": "sbollire",
    "sbolliron": "sbollire",
    "sbollirono": "sbollire",
    "sbollirà": "sbollire",
    "sbollirò": "sbollire",
    "sbollisca": "sbollire",
    "sbolliscan": "sbollire",
    "sbolliscano": "sbollire",
    "sbollisce": "sbollire",
    "sbollisci": "sbollire",
    "sbollisco": "sbollire",
    "sbolliscon": "sbollire",
    "sbolliscono": "sbollire",
    "sbollisse": "sbollire",
    "sbollisser": "sbollire",
    "sbollissero": "sbollire",
    "sbollissi": "sbollire",
    "sbollissimo": "sbollire",
    "sbolliste": "sbollire",
    "sbollisti": "sbollire",
    "sbollita": "sbollire",
    "sbollite": "sbollire",
    "sbolliti": "sbollire",
    "sbollito": "sbollire",
    "sbolliva": "sbollire",
    "sbollivamo": "sbollire",
    "sbollivan": "sbollire",
    "sbollivano": "sbollire",
    "sbollivate": "sbollire",
    "sbollivi": "sbollire",
    "sbollivo": "sbollire",
    "sbollì": "sbollire",
    "sbologna": "sbolognare",
    "sbolognai": "sbolognare",
    "sbolognammo": "sbolognare",
    "sbolognan": "sbolognare",
    "sbolognando": "sbolognare",
    "sbolognano": "sbolognare",
    "sbolognante": "sbolognare",
    "sbolognanti": "sbolognare",
    "sbolognar": "sbolognare",
    "sbolognaron": "sbolognare",
    "sbolognarono": "sbolognare",
    "sbolognasse": "sbolognare",
    "sbolognasser": "sbolognare",
    "sbolognassero": "sbolognare",
    "sbolognassi": "sbolognare",
    "sbolognassimo": "sbolognare",
    "sbolognaste": "sbolognare",
    "sbolognasti": "sbolognare",
    "sbolognata": "sbolognare",
    "sbolognate": "sbolognare",
    "sbolognati": "sbolognare",
    "sbolognato": "sbolognare",
    "sbolognava": "sbolognare",
    "sbolognavamo": "sbolognare",
    "sbolognavan": "sbolognare",
    "sbolognavano": "sbolognare",
    "sbolognavate": "sbolognare",
    "sbolognavi": "sbolognare",
    "sbolognavo": "sbolognare",
    "sbolognerai": "sbolognare",
    "sbologneran": "sbolognare",
    "sbologneranno": "sbolognare",
    "sbolognerebbe": "sbolognare",
    "sbolognerebber": "sbolognare",
    "sbolognerebbero": "sbolognare",
    "sbolognerei": "sbolognare",
    "sbologneremmo": "sbolognare",
    "sbologneremo": "sbolognare",
    "sbolognereste": "sbolognare",
    "sbologneresti": "sbolognare",
    "sbolognerete": "sbolognare",
    "sbolognerà": "sbolognare",
    "sbolognerò": "sbolognare",
    "sbologni": "sbolognare",
    "sbologniamo": "sbolognare",
    "sbologniate": "sbolognare",
    "sbolognin": "sbolognare",
    "sbolognino": "sbolognare",
    "sbologno": "sbolognare",
    "sbolognò": "sbolognare",
    "sborni": "sborniare",
    "sbornia": "sborniare",
    "sborniai": "sborniare",
    "sborniammo": "sborniare",
    "sborniamo": "sborniare",
    "sbornian": "sborniare",
    "sborniando": "sborniare",
    "sborniano": "sborniare",
    "sborniante": "sborniare",
    "sbornianti": "sborniare",
    "sborniar": "sborniare",
    "sborniaron": "sborniare",
    "sborniarono": "sborniare",
    "sborniasse": "sborniare",
    "sborniasser": "sborniare",
    "sborniassero": "sborniare",
    "sborniassi": "sborniare",
    "sborniassimo": "sborniare",
    "sborniaste": "sborniare",
    "sborniasti": "sborniare",
    "sborniata": "sborniare",
    "sborniate": "sborniare",
    "sborniati": "sborniare",
    "sborniato": "sborniare",
    "sborniava": "sborniare",
    "sborniavamo": "sborniare",
    "sborniavan": "sborniare",
    "sborniavano": "sborniare",
    "sborniavate": "sborniare",
    "sborniavi": "sborniare",
    "sborniavo": "sborniare",
    "sbornie": "sbornia",
    "sbornierai": "sborniare",
    "sbornieran": "sborniare",
    "sbornieranno": "sborniare",
    "sbornierebbe": "sborniare",
    "sbornierebber": "sborniare",
    "sbornierebbero": "sborniare",
    "sbornierei": "sborniare",
    "sbornieremmo": "sborniare",
    "sbornieremo": "sborniare",
    "sborniereste": "sborniare",
    "sbornieresti": "sborniare",
    "sbornierete": "sborniare",
    "sbornierà": "sborniare",
    "sbornierò": "sborniare",
    "sbornin": "sborniare",
    "sbornino": "sborniare",
    "sbornio": "sborniare",
    "sborniò": "sborniare",
    "sborsa": "sborsare",
    "sborsai": "sborsare",
    "sborsammo": "sborsare",
    "sborsan": "sborsare",
    "sborsando": "sborsare",
    "sborsano": "sborsare",
    "sborsante": "sborsare",
    "sborsanti": "sborsare",
    "sborsar": "sborsare",
    "sborsaron": "sborsare",
    "sborsarono": "sborsare",
    "sborsasse": "sborsare",
    "sborsasser": "sborsare",
    "sborsassero": "sborsare",
    "sborsassi": "sborsare",
    "sborsassimo": "sborsare",
    "sborsaste": "sborsare",
    "sborsasti": "sborsare",
    "sborsata": "sborsare",
    "sborsate": "sborsare",
    "sborsati": "sborsare",
    "sborsato": "sborsare",
    "sborsava": "sborsare",
    "sborsavamo": "sborsare",
    "sborsavan": "sborsare",
    "sborsavano": "sborsare",
    "sborsavate": "sborsare",
    "sborsavi": "sborsare",
    "sborsavo": "sborsare",
    "sborserai": "sborsare",
    "sborseran": "sborsare",
    "sborseranno": "sborsare",
    "sborserebbe": "sborsare",
    "sborserebber": "sborsare",
    "sborserebbero": "sborsare",
    "sborserei": "sborsare",
    "sborseremmo": "sborsare",
    "sborseremo": "sborsare",
    "sborsereste": "sborsare",
    "sborseresti": "sborsare",
    "sborserete": "sborsare",
    "sborserà": "sborsare",
    "sborserò": "sborsare",
    "sborsi": "sborsare",
    "sborsiamo": "sborsare",
    "sborsiate": "sborsare",
    "sborsin": "sborsare",
    "sborsino": "sborsare",
    "sborso": "sborsare",
    "sborsò": "sborsare",
    "sbotta": "sbottare",
    "sbottai": "sbottare",
    "sbottammo": "sbottare",
    "sbottan": "sbottare",
    "sbottando": "sbottare",
    "sbottano": "sbottare",
    "sbottante": "sbottare",
    "sbottanti": "sbottare",
    "sbottar": "sbottare",
    "sbottaron": "sbottare",
    "sbottarono": "sbottare",
    "sbottasse": "sbottare",
    "sbottasser": "sbottare",
    "sbottassero": "sbottare",
    "sbottassi": "sbottare",
    "sbottassimo": "sbottare",
    "sbottaste": "sbottare",
    "sbottasti": "sbottare",
    "sbottata": "sbottare",
    "sbottate": "sbottare",
    "sbottati": "sbottare",
    "sbottato": "sbottare",
    "sbottava": "sbottare",
    "sbottavamo": "sbottare",
    "sbottavan": "sbottare",
    "sbottavano": "sbottare",
    "sbottavate": "sbottare",
    "sbottavi": "sbottare",
    "sbottavo": "sbottare",
    "sbotterai": "sbottare",
    "sbotteran": "sbottare",
    "sbotteranno": "sbottare",
    "sbotterebbe": "sbottare",
    "sbotterebber": "sbottare",
    "sbotterebbero": "sbottare",
    "sbotterei": "sbottare",
    "sbotteremmo": "sbottare",
    "sbotteremo": "sbottare",
    "sbottereste": "sbottare",
    "sbotteresti": "sbottare",
    "sbotterete": "sbottare",
    "sbotterà": "sbottare",
    "sbotterò": "sbottare",
    "sbotti": "sbottare",
    "sbottiamo": "sbottare",
    "sbottiate": "sbottare",
    "sbottin": "sbottare",
    "sbottino": "sbottare",
    "sbotto": "sbottare",
    "sbottona": "sbottonare",
    "sbottonai": "sbottonare",
    "sbottonammo": "sbottonare",
    "sbottonan": "sbottonare",
    "sbottonando": "sbottonare",
    "sbottonano": "sbottonare",
    "sbottonante": "sbottonare",
    "sbottonanti": "sbottonare",
    "sbottonar": "sbottonare",
    "sbottonaron": "sbottonare",
    "sbottonarono": "sbottonare",
    "sbottonasse": "sbottonare",
    "sbottonasser": "sbottonare",
    "sbottonassero": "sbottonare",
    "sbottonassi": "sbottonare",
    "sbottonassimo": "sbottonare",
    "sbottonaste": "sbottonare",
    "sbottonasti": "sbottonare",
    "sbottonata": "sbottonare",
    "sbottonate": "sbottonare",
    "sbottonati": "sbottonare",
    "sbottonato": "sbottonare",
    "sbottonava": "sbottonare",
    "sbottonavamo": "sbottonare",
    "sbottonavan": "sbottonare",
    "sbottonavano": "sbottonare",
    "sbottonavate": "sbottonare",
    "sbottonavi": "sbottonare",
    "sbottonavo": "sbottonare",
    "sbottonerai": "sbottonare",
    "sbottoneran": "sbottonare",
    "sbottoneranno": "sbottonare",
    "sbottonerebbe": "sbottonare",
    "sbottonerebber": "sbottonare",
    "sbottonerebbero": "sbottonare",
    "sbottonerei": "sbottonare",
    "sbottoneremmo": "sbottonare",
    "sbottoneremo": "sbottonare",
    "sbottonereste": "sbottonare",
    "sbottoneresti": "sbottonare",
    "sbottonerete": "sbottonare",
    "sbottonerà": "sbottonare",
    "sbottonerò": "sbottonare",
    "sbottoni": "sbottonare",
    "sbottoniamo": "sbottonare",
    "sbottoniate": "sbottonare",
    "sbottonin": "sbottonare",
    "sbottonino": "sbottonare",
    "sbottono": "sbottonare",
    "sbottonò": "sbottonare",
    "sbottò": "sbottare",
    "sbozza": "sbozzare",
    "sbozzai": "sbozzare",
    "sbozzammo": "sbozzare",
    "sbozzan": "sbozzare",
    "sbozzando": "sbozzare",
    "sbozzano": "sbozzare",
    "sbozzante": "sbozzare",
    "sbozzanti": "sbozzare",
    "sbozzar": "sbozzare",
    "sbozzaron": "sbozzare",
    "sbozzarono": "sbozzare",
    "sbozzasse": "sbozzare",
    "sbozzasser": "sbozzare",
    "sbozzassero": "sbozzare",
    "sbozzassi": "sbozzare",
    "sbozzassimo": "sbozzare",
    "sbozzaste": "sbozzare",
    "sbozzasti": "sbozzare",
    "sbozzata": "sbozzare",
    "sbozzate": "sbozzare",
    "sbozzati": "sbozzare",
    "sbozzato": "sbozzare",
    "sbozzava": "sbozzare",
    "sbozzavamo": "sbozzare",
    "sbozzavan": "sbozzare",
    "sbozzavano": "sbozzare",
    "sbozzavate": "sbozzare",
    "sbozzavi": "sbozzare",
    "sbozzavo": "sbozzare",
    "sbozzerai": "sbozzare",
    "sbozzeran": "sbozzare",
    "sbozzeranno": "sbozzare",
    "sbozzerebbe": "sbozzare",
    "sbozzerebber": "sbozzare",
    "sbozzerebbero": "sbozzare",
    "sbozzerei": "sbozzare",
    "sbozzeremmo": "sbozzare",
    "sbozzeremo": "sbozzare",
    "sbozzereste": "sbozzare",
    "sbozzeresti": "sbozzare",
    "sbozzerete": "sbozzare",
    "sbozzerà": "sbozzare",
    "sbozzerò": "sbozzare",
    "sbozzi": "sbozzare",
    "sbozziamo": "sbozzare",
    "sbozziate": "sbozzare",
    "sbozzin": "sbozzare",
    "sbozzino": "sbozzare",
    "sbozzo": "sbozzare",
    "sbozzò": "sbozzare",
    "sbraca": "sbracare",
    "sbracai": "sbracare",
    "sbracammo": "sbracare",
    "sbracan": "sbracare",
    "sbracando": "sbracare",
    "sbracano": "sbracare",
    "sbracante": "sbracare",
    "sbracanti": "sbracare",
    "sbracar": "sbracare",
    "sbracaron": "sbracare",
    "sbracarono": "sbracare",
    "sbracasse": "sbracare",
    "sbracasser": "sbracare",
    "sbracassero": "sbracare",
    "sbracassi": "sbracare",
    "sbracassimo": "sbracare",
    "sbracaste": "sbracare",
    "sbracasti": "sbracare",
    "sbracata": "sbracato",
    "sbracate": "sbracato",
    "sbracati": "sbracato",
    "sbracato": "sbracare",
    "sbracava": "sbracare",
    "sbracavamo": "sbracare",
    "sbracavan": "sbracare",
    "sbracavano": "sbracare",
    "sbracavate": "sbracare",
    "sbracavi": "sbracare",
    "sbracavo": "sbracare",
    "sbraccerai": "sbracciare",
    "sbracceran": "sbracciare",
    "sbracceranno": "sbracciare",
    "sbraccerebbe": "sbracciare",
    "sbraccerebber": "sbracciare",
    "sbraccerebbero": "sbracciare",
    "sbraccerei": "sbracciare",
    "sbracceremmo": "sbracciare",
    "sbracceremo": "sbracciare",
    "sbraccereste": "sbracciare",
    "sbracceresti": "sbracciare",
    "sbraccerete": "sbracciare",
    "sbraccerà": "sbracciare",
    "sbraccerò": "sbracciare",
    "sbracci": "sbracciare",
    "sbraccia": "sbracciare",
    "sbracciai": "sbracciare",
    "sbracciammo": "sbracciare",
    "sbracciamo": "sbracciare",
    "sbraccian": "sbracciare",
    "sbracciando": "sbracciare",
    "sbracciano": "sbracciare",
    "sbracciar": "sbracciare",
    "sbracciaron": "sbracciare",
    "sbracciarono": "sbracciare",
    "sbracciasse": "sbracciare",
    "sbracciasser": "sbracciare",
    "sbracciassero": "sbracciare",
    "sbracciassi": "sbracciare",
    "sbracciassimo": "sbracciare",
    "sbracciaste": "sbracciare",
    "sbracciasti": "sbracciare",
    "sbracciata": "sbracciare",
    "sbracciate": "sbracciare",
    "sbracciati": "sbracciare",
    "sbracciato": "sbracciare",
    "sbracciava": "sbracciare",
    "sbracciavamo": "sbracciare",
    "sbracciavan": "sbracciare",
    "sbracciavano": "sbracciare",
    "sbracciavate": "sbracciare",
    "sbracciavi": "sbracciare",
    "sbracciavo": "sbracciare",
    "sbraccin": "sbracciare",
    "sbraccino": "sbracciare",
    "sbraccio": "sbracciare",
    "sbracciò": "sbracciare",
    "sbracherai": "sbracare",
    "sbracheran": "sbracare",
    "sbracheranno": "sbracare",
    "sbracherebbe": "sbracare",
    "sbracherebber": "sbracare",
    "sbracherebbero": "sbracare",
    "sbracherei": "sbracare",
    "sbracheremmo": "sbracare",
    "sbracheremo": "sbracare",
    "sbrachereste": "sbracare",
    "sbracheresti": "sbracare",
    "sbracherete": "sbracare",
    "sbracherà": "sbracare",
    "sbracherò": "sbracare",
    "sbrachi": "sbracare",
    "sbrachiamo": "sbracare",
    "sbrachiate": "sbracare",
    "sbrachin": "sbracare",
    "sbrachino": "sbracare",
    "sbraco": "sbracare",
    "sbracò": "sbracare",
    "sbraita": "sbraitare",
    "sbraitai": "sbraitare",
    "sbraitammo": "sbraitare",
    "sbraitan": "sbraitare",
    "sbraitando": "sbraitare",
    "sbraitano": "sbraitare",
    "sbraitante": "sbraitare",
    "sbraitanti": "sbraitare",
    "sbraitar": "sbraitare",
    "sbraitaron": "sbraitare",
    "sbraitarono": "sbraitare",
    "sbraitasse": "sbraitare",
    "sbraitasser": "sbraitare",
    "sbraitassero": "sbraitare",
    "sbraitassi": "sbraitare",
    "sbraitassimo": "sbraitare",
    "sbraitaste": "sbraitare",
    "sbraitasti": "sbraitare",
    "sbraitata": "sbraitare",
    "sbraitate": "sbraitare",
    "sbraitati": "sbraitare",
    "sbraitato": "sbraitare",
    "sbraitava": "sbraitare",
    "sbraitavamo": "sbraitare",
    "sbraitavan": "sbraitare",
    "sbraitavano": "sbraitare",
    "sbraitavate": "sbraitare",
    "sbraitavi": "sbraitare",
    "sbraitavo": "sbraitare",
    "sbraiterai": "sbraitare",
    "sbraiteran": "sbraitare",
    "sbraiteranno": "sbraitare",
    "sbraiterebbe": "sbraitare",
    "sbraiterebber": "sbraitare",
    "sbraiterebbero": "sbraitare",
    "sbraiterei": "sbraitare",
    "sbraiteremmo": "sbraitare",
    "sbraiteremo": "sbraitare",
    "sbraitereste": "sbraitare",
    "sbraiteresti": "sbraitare",
    "sbraiterete": "sbraitare",
    "sbraiterà": "sbraitare",
    "sbraiterò": "sbraitare",
    "sbraiti": "sbraitare",
    "sbraitiamo": "sbraitare",
    "sbraitiate": "sbraitare",
    "sbraitin": "sbraitare",
    "sbraitino": "sbraitare",
    "sbraito": "sbraitare",
    "sbraitò": "sbraitare",
    "sbrama": "sbramare",
    "sbramai": "sbramare",
    "sbramammo": "sbramare",
    "sbraman": "sbramare",
    "sbramando": "sbramare",
    "sbramano": "sbramare",
    "sbramante": "sbramare",
    "sbramanti": "sbramare",
    "sbramar": "sbramare",
    "sbramaron": "sbramare",
    "sbramarono": "sbramare",
    "sbramasse": "sbramare",
    "sbramasser": "sbramare",
    "sbramassero": "sbramare",
    "sbramassi": "sbramare",
    "sbramassimo": "sbramare",
    "sbramaste": "sbramare",
    "sbramasti": "sbramare",
    "sbramata": "sbramare",
    "sbramate": "sbramare",
    "sbramati": "sbramare",
    "sbramato": "sbramare",
    "sbramava": "sbramare",
    "sbramavamo": "sbramare",
    "sbramavan": "sbramare",
    "sbramavano": "sbramare",
    "sbramavate": "sbramare",
    "sbramavi": "sbramare",
    "sbramavo": "sbramare",
    "sbramerai": "sbramare",
    "sbrameran": "sbramare",
    "sbrameranno": "sbramare",
    "sbramerebbe": "sbramare",
    "sbramerebber": "sbramare",
    "sbramerebbero": "sbramare",
    "sbramerei": "sbramare",
    "sbrameremmo": "sbramare",
    "sbrameremo": "sbramare",
    "sbramereste": "sbramare",
    "sbrameresti": "sbramare",
    "sbramerete": "sbramare",
    "sbramerà": "sbramare",
    "sbramerò": "sbramare",
    "sbrami": "sbramare",
    "sbramiamo": "sbramare",
    "sbramiate": "sbramare",
    "sbramin": "sbramare",
    "sbramino": "sbramare",
    "sbramo": "sbramare",
    "sbramò": "sbramare",
    "sbrana": "sbranare",
    "sbranai": "sbranare",
    "sbranammo": "sbranare",
    "sbranan": "sbranare",
    "sbranando": "sbranare",
    "sbranano": "sbranare",
    "sbranante": "sbranare",
    "sbrananti": "sbranare",
    "sbranar": "sbranare",
    "sbranaron": "sbranare",
    "sbranarono": "sbranare",
    "sbranasse": "sbranare",
    "sbranasser": "sbranare",
    "sbranassero": "sbranare",
    "sbranassi": "sbranare",
    "sbranassimo": "sbranare",
    "sbranaste": "sbranare",
    "sbranasti": "sbranare",
    "sbranata": "sbranare",
    "sbranate": "sbranare",
    "sbranati": "sbranare",
    "sbranato": "sbranare",
    "sbranava": "sbranare",
    "sbranavamo": "sbranare",
    "sbranavan": "sbranare",
    "sbranavano": "sbranare",
    "sbranavate": "sbranare",
    "sbranavi": "sbranare",
    "sbranavo": "sbranare",
    "sbranca": "sbrancare",
    "sbrancai": "sbrancare",
    "sbrancammo": "sbrancare",
    "sbrancan": "sbrancare",
    "sbrancando": "sbrancare",
    "sbrancano": "sbrancare",
    "sbrancante": "sbrancare",
    "sbrancanti": "sbrancare",
    "sbrancar": "sbrancare",
    "sbrancaron": "sbrancare",
    "sbrancarono": "sbrancare",
    "sbrancasse": "sbrancare",
    "sbrancasser": "sbrancare",
    "sbrancassero": "sbrancare",
    "sbrancassi": "sbrancare",
    "sbrancassimo": "sbrancare",
    "sbrancaste": "sbrancare",
    "sbrancasti": "sbrancare",
    "sbrancata": "sbrancare",
    "sbrancate": "sbrancare",
    "sbrancati": "sbrancare",
    "sbrancato": "sbrancare",
    "sbrancava": "sbrancare",
    "sbrancavamo": "sbrancare",
    "sbrancavan": "sbrancare",
    "sbrancavano": "sbrancare",
    "sbrancavate": "sbrancare",
    "sbrancavi": "sbrancare",
    "sbrancavo": "sbrancare",
    "sbrancherai": "sbrancare",
    "sbrancheran": "sbrancare",
    "sbrancheranno": "sbrancare",
    "sbrancherebbe": "sbrancare",
    "sbrancherebber": "sbrancare",
    "sbrancherebbero": "sbrancare",
    "sbrancherei": "sbrancare",
    "sbrancheremmo": "sbrancare",
    "sbrancheremo": "sbrancare",
    "sbranchereste": "sbrancare",
    "sbrancheresti": "sbrancare",
    "sbrancherete": "sbrancare",
    "sbrancherà": "sbrancare",
    "sbrancherò": "sbrancare",
    "sbranchi": "sbrancare",
    "sbranchiamo": "sbrancare",
    "sbranchiate": "sbrancare",
    "sbranchin": "sbrancare",
    "sbranchino": "sbrancare",
    "sbranco": "sbrancare",
    "sbrancò": "sbrancare",
    "sbranerai": "sbranare",
    "sbraneran": "sbranare",
    "sbraneranno": "sbranare",
    "sbranerebbe": "sbranare",
    "sbranerebber": "sbranare",
    "sbranerebbero": "sbranare",
    "sbranerei": "sbranare",
    "sbraneremmo": "sbranare",
    "sbraneremo": "sbranare",
    "sbranereste": "sbranare",
    "sbraneresti": "sbranare",
    "sbranerete": "sbranare",
    "sbranerà": "sbranare",
    "sbranerò": "sbranare",
    "sbrani": "sbranare",
    "sbraniamo": "sbranare",
    "sbraniate": "sbranare",
    "sbranin": "sbranare",
    "sbranino": "sbranare",
    "sbrano": "sbranare",
    "sbranò": "sbranare",
    "sbrecca": "sbreccare",
    "sbreccai": "sbreccare",
    "sbreccammo": "sbreccare",
    "sbreccan": "sbreccare",
    "sbreccando": "sbreccare",
    "sbreccano": "sbreccare",
    "sbreccante": "sbreccare",
    "sbreccanti": "sbreccare",
    "sbreccar": "sbreccare",
    "sbreccaron": "sbreccare",
    "sbreccarono": "sbreccare",
    "sbreccasse": "sbreccare",
    "sbreccasser": "sbreccare",
    "sbreccassero": "sbreccare",
    "sbreccassi": "sbreccare",
    "sbreccassimo": "sbreccare",
    "sbreccaste": "sbreccare",
    "sbreccasti": "sbreccare",
    "sbreccata": "sbreccare",
    "sbreccate": "sbreccare",
    "sbreccati": "sbreccare",
    "sbreccato": "sbreccare",
    "sbreccava": "sbreccare",
    "sbreccavamo": "sbreccare",
    "sbreccavan": "sbreccare",
    "sbreccavano": "sbreccare",
    "sbreccavate": "sbreccare",
    "sbreccavi": "sbreccare",
    "sbreccavo": "sbreccare",
    "sbreccerai": "sbrecciare",
    "sbrecceran": "sbrecciare",
    "sbrecceranno": "sbrecciare",
    "sbreccerebbe": "sbrecciare",
    "sbreccerebber": "sbrecciare",
    "sbreccerebbero": "sbrecciare",
    "sbreccerei": "sbrecciare",
    "sbrecceremmo": "sbrecciare",
    "sbrecceremo": "sbrecciare",
    "sbreccereste": "sbrecciare",
    "sbrecceresti": "sbrecciare",
    "sbreccerete": "sbrecciare",
    "sbreccerà": "sbrecciare",
    "sbreccerò": "sbrecciare",
    "sbreccherai": "sbreccare",
    "sbreccheran": "sbreccare",
    "sbreccheranno": "sbreccare",
    "sbreccherebbe": "sbreccare",
    "sbreccherebber": "sbreccare",
    "sbreccherebbero": "sbreccare",
    "sbreccherei": "sbreccare",
    "sbreccheremmo": "sbreccare",
    "sbreccheremo": "sbreccare",
    "sbrecchereste": "sbreccare",
    "sbreccheresti": "sbreccare",
    "sbreccherete": "sbreccare",
    "sbreccherà": "sbreccare",
    "sbreccherò": "sbreccare",
    "sbrecchi": "sbreccare",
    "sbrecchiamo": "sbreccare",
    "sbrecchiate": "sbreccare",
    "sbrecchin": "sbreccare",
    "sbrecchino": "sbreccare",
    "sbrecci": "sbrecciare",
    "sbreccia": "sbrecciare",
    "sbrecciai": "sbrecciare",
    "sbrecciammo": "sbrecciare",
    "sbrecciamo": "sbrecciare",
    "sbreccian": "sbrecciare",
    "sbrecciando": "sbrecciare",
    "sbrecciano": "sbrecciare",
    "sbrecciante": "sbrecciare",
    "sbreccianti": "sbrecciare",
    "sbrecciar": "sbrecciare",
    "sbrecciaron": "sbrecciare",
    "sbrecciarono": "sbrecciare",
    "sbrecciasse": "sbrecciare",
    "sbrecciasser": "sbrecciare",
    "sbrecciassero": "sbrecciare",
    "sbrecciassi": "sbrecciare",
    "sbrecciassimo": "sbrecciare",
    "sbrecciaste": "sbrecciare",
    "sbrecciasti": "sbrecciare",
    "sbrecciata": "sbrecciare",
    "sbrecciate": "sbrecciare",
    "sbrecciati": "sbrecciare",
    "sbrecciato": "sbrecciare",
    "sbrecciava": "sbrecciare",
    "sbrecciavamo": "sbrecciare",
    "sbrecciavan": "sbrecciare",
    "sbrecciavano": "sbrecciare",
    "sbrecciavate": "sbrecciare",
    "sbrecciavi": "sbrecciare",
    "sbrecciavo": "sbrecciare",
    "sbreccin": "sbrecciare",
    "sbreccino": "sbrecciare",
    "sbreccio": "sbrecciare",
    "sbrecciò": "sbrecciare",
    "sbrecco": "sbreccare",
    "sbreccò": "sbreccare",
    "sbriciola": "sbriciolare",
    "sbriciolai": "sbriciolare",
    "sbriciolamenti": "sbriciolamento",
    "sbriciolammo": "sbriciolare",
    "sbriciolan": "sbriciolare",
    "sbriciolando": "sbriciolare",
    "sbriciolano": "sbriciolare",
    "sbriciolante": "sbriciolare",
    "sbriciolanti": "sbriciolare",
    "sbriciolar": "sbriciolare",
    "sbriciolaron": "sbriciolare",
    "sbriciolarono": "sbriciolare",
    "sbriciolasse": "sbriciolare",
    "sbriciolasser": "sbriciolare",
    "sbriciolassero": "sbriciolare",
    "sbriciolassi": "sbriciolare",
    "sbriciolassimo": "sbriciolare",
    "sbriciolaste": "sbriciolare",
    "sbriciolasti": "sbriciolare",
    "sbriciolata": "sbriciolare",
    "sbriciolate": "sbriciolare",
    "sbriciolati": "sbriciolare",
    "sbriciolato": "sbriciolare",
    "sbriciolava": "sbriciolare",
    "sbriciolavamo": "sbriciolare",
    "sbriciolavan": "sbriciolare",
    "sbriciolavano": "sbriciolare",
    "sbriciolavate": "sbriciolare",
    "sbriciolavi": "sbriciolare",
    "sbriciolavo": "sbriciolare",
    "sbriciolerai": "sbriciolare",
    "sbricioleran": "sbriciolare",
    "sbricioleranno": "sbriciolare",
    "sbriciolerebbe": "sbriciolare",
    "sbriciolerebber": "sbriciolare",
    "sbriciolerebbero": "sbriciolare",
    "sbriciolerei": "sbriciolare",
    "sbricioleremmo": "sbriciolare",
    "sbricioleremo": "sbriciolare",
    "sbriciolereste": "sbriciolare",
    "sbricioleresti": "sbriciolare",
    "sbriciolerete": "sbriciolare",
    "sbriciolerà": "sbriciolare",
    "sbriciolerò": "sbriciolare",
    "sbricioli": "sbriciolare",
    "sbricioliamo": "sbriciolare",
    "sbricioliate": "sbriciolare",
    "sbriciolin": "sbriciolare",
    "sbriciolino": "sbriciolare",
    "sbriciolo": "sbriciolare",
    "sbriciolò": "sbriciolare",
    "sbriga": "sbrigare",
    "sbrigai": "sbrigare",
    "sbrigammo": "sbrigare",
    "sbrigan": "sbrigare",
    "sbrigando": "sbrigare",
    "sbrigano": "sbrigare",
    "sbrigante": "sbrigare",
    "sbriganti": "sbrigare",
    "sbrigar": "sbrigare",
    "sbrigaron": "sbrigare",
    "sbrigarono": "sbrigare",
    "sbrigasse": "sbrigare",
    "sbrigasser": "sbrigare",
    "sbrigassero": "sbrigare",
    "sbrigassi": "sbrigare",
    "sbrigassimo": "sbrigare",
    "sbrigaste": "sbrigare",
    "sbrigasti": "sbrigare",
    "sbrigata": "sbrigare",
    "sbrigate": "sbrigare",
    "sbrigati": "sbrigare",
    "sbrigativa": "sbrigativo",
    "sbrigative": "sbrigativo",
    "sbrigativi": "sbrigativo",
    "sbrigato": "sbrigare",
    "sbrigava": "sbrigare",
    "sbrigavamo": "sbrigare",
    "sbrigavan": "sbrigare",
    "sbrigavano": "sbrigare",
    "sbrigavate": "sbrigare",
    "sbrigavi": "sbrigare",
    "sbrigavo": "sbrigare",
    "sbrigherai": "sbrigare",
    "sbrigheran": "sbrigare",
    "sbrigheranno": "sbrigare",
    "sbrigherebbe": "sbrigare",
    "sbrigherebber": "sbrigare",
    "sbrigherebbero": "sbrigare",
    "sbrigherei": "sbrigare",
    "sbrigheremmo": "sbrigare",
    "sbrigheremo": "sbrigare",
    "sbrighereste": "sbrigare",
    "sbrigheresti": "sbrigare",
    "sbrigherete": "sbrigare",
    "sbrigherà": "sbrigare",
    "sbrigherò": "sbrigare",
    "sbrighi": "sbrigare",
    "sbrighiamo": "sbrigare",
    "sbrighiate": "sbrigare",
    "sbrighin": "sbrigare",
    "sbrighino": "sbrigare",
    "sbrigli": "sbrigliare",
    "sbriglia": "sbrigliare",
    "sbrigliai": "sbrigliare",
    "sbrigliammo": "sbrigliare",
    "sbrigliamo": "sbrigliare",
    "sbriglian": "sbrigliare",
    "sbrigliando": "sbrigliare",
    "sbrigliano": "sbrigliare",
    "sbrigliante": "sbrigliare",
    "sbriglianti": "sbrigliare",
    "sbrigliar": "sbrigliare",
    "sbrigliaron": "sbrigliare",
    "sbrigliarono": "sbrigliare",
    "sbrigliasse": "sbrigliare",
    "sbrigliasser": "sbrigliare",
    "sbrigliassero": "sbrigliare",
    "sbrigliassi": "sbrigliare",
    "sbrigliassimo": "sbrigliare",
    "sbrigliaste": "sbrigliare",
    "sbrigliasti": "sbrigliare",
    "sbrigliata": "sbrigliato",
    "sbrigliate": "sbrigliato",
    "sbrigliati": "sbrigliato",
    "sbrigliato": "sbrigliare",
    "sbrigliava": "sbrigliare",
    "sbrigliavamo": "sbrigliare",
    "sbrigliavan": "sbrigliare",
    "sbrigliavano": "sbrigliare",
    "sbrigliavate": "sbrigliare",
    "sbrigliavi": "sbrigliare",
    "sbrigliavo": "sbrigliare",
    "sbriglierai": "sbrigliare",
    "sbriglieran": "sbrigliare",
    "sbriglieranno": "sbrigliare",
    "sbriglierebbe": "sbrigliare",
    "sbriglierebber": "sbrigliare",
    "sbriglierebbero": "sbrigliare",
    "sbriglierei": "sbrigliare",
    "sbriglieremmo": "sbrigliare",
    "sbriglieremo": "sbrigliare",
    "sbrigliereste": "sbrigliare",
    "sbriglieresti": "sbrigliare",
    "sbriglierete": "sbrigliare",
    "sbriglierà": "sbrigliare",
    "sbriglierò": "sbrigliare",
    "sbriglin": "sbrigliare",
    "sbriglino": "sbrigliare",
    "sbriglio": "sbrigliare",
    "sbrigliò": "sbrigliare",
    "sbrigo": "sbrigare",
    "sbrigò": "sbrigare",
    "sbrina": "sbrinare",
    "sbrinai": "sbrinare",
    "sbrinammo": "sbrinare",
    "sbrinan": "sbrinare",
    "sbrinando": "sbrinare",
    "sbrinano": "sbrinare",
    "sbrinante": "sbrinare",
    "sbrinanti": "sbrinare",
    "sbrinar": "sbrinare",
    "sbrinaron": "sbrinare",
    "sbrinarono": "sbrinare",
    "sbrinasse": "sbrinare",
    "sbrinasser": "sbrinare",
    "sbrinassero": "sbrinare",
    "sbrinassi": "sbrinare",
    "sbrinassimo": "sbrinare",
    "sbrinaste": "sbrinare",
    "sbrinasti": "sbrinare",
    "sbrinata": "sbrinare",
    "sbrinate": "sbrinare",
    "sbrinati": "sbrinare",
    "sbrinato": "sbrinare",
    "sbrinava": "sbrinare",
    "sbrinavamo": "sbrinare",
    "sbrinavan": "sbrinare",
    "sbrinavano": "sbrinare",
    "sbrinavate": "sbrinare",
    "sbrinavi": "sbrinare",
    "sbrinavo": "sbrinare",
    "sbrindella": "sbrindellare",
    "sbrindellai": "sbrindellare",
    "sbrindellammo": "sbrindellare",
    "sbrindellan": "sbrindellare",
    "sbrindellando": "sbrindellare",
    "sbrindellano": "sbrindellare",
    "sbrindellante": "sbrindellare",
    "sbrindellanti": "sbrindellare",
    "sbrindellar": "sbrindellare",
    "sbrindellaron": "sbrindellare",
    "sbrindellarono": "sbrindellare",
    "sbrindellasse": "sbrindellare",
    "sbrindellasser": "sbrindellare",
    "sbrindellassero": "sbrindellare",
    "sbrindellassi": "sbrindellare",
    "sbrindellassimo": "sbrindellare",
    "sbrindellaste": "sbrindellare",
    "sbrindellasti": "sbrindellare",
    "sbrindellata": "sbrindellato",
    "sbrindellate": "sbrindellato",
    "sbrindellati": "sbrindellato",
    "sbrindellato": "sbrindellare",
    "sbrindellava": "sbrindellare",
    "sbrindellavamo": "sbrindellare",
    "sbrindellavan": "sbrindellare",
    "sbrindellavano": "sbrindellare",
    "sbrindellavate": "sbrindellare",
    "sbrindellavi": "sbrindellare",
    "sbrindellavo": "sbrindellare",
    "sbrindellerai": "sbrindellare",
    "sbrindelleran": "sbrindellare",
    "sbrindelleranno": "sbrindellare",
    "sbrindellerebbe": "sbrindellare",
    "sbrindellerebber": "sbrindellare",
    "sbrindellerebbero": "sbrindellare",
    "sbrindellerei": "sbrindellare",
    "sbrindelleremmo": "sbrindellare",
    "sbrindelleremo": "sbrindellare",
    "sbrindellereste": "sbrindellare",
    "sbrindelleresti": "sbrindellare",
    "sbrindellerete": "sbrindellare",
    "sbrindellerà": "sbrindellare",
    "sbrindellerò": "sbrindellare",
    "sbrindelli": "sbrindellare",
    "sbrindelliamo": "sbrindellare",
    "sbrindelliate": "sbrindellare",
    "sbrindellin": "sbrindellare",
    "sbrindellino": "sbrindellare",
    "sbrindello": "sbrindellare",
    "sbrindellò": "sbrindellare",
    "sbrinerai": "sbrinare",
    "sbrineran": "sbrinare",
    "sbrineranno": "sbrinare",
    "sbrinerebbe": "sbrinare",
    "sbrinerebber": "sbrinare",
    "sbrinerebbero": "sbrinare",
    "sbrinerei": "sbrinare",
    "sbrineremmo": "sbrinare",
    "sbrineremo": "sbrinare",
    "sbrinereste": "sbrinare",
    "sbrineresti": "sbrinare",
    "sbrinerete": "sbrinare",
    "sbrinerà": "sbrinare",
    "sbrinerò": "sbrinare",
    "sbrini": "sbrinare",
    "sbriniamo": "sbrinare",
    "sbriniate": "sbrinare",
    "sbrinin": "sbrinare",
    "sbrinino": "sbrinare",
    "sbrino": "sbrinare",
    "sbrinò": "sbrinare",
    "sbrodola": "sbrodolare",
    "sbrodolai": "sbrodolare",
    "sbrodolammo": "sbrodolare",
    "sbrodolan": "sbrodolare",
    "sbrodolando": "sbrodolare",
    "sbrodolano": "sbrodolare",
    "sbrodolante": "sbrodolare",
    "sbrodolanti": "sbrodolare",
    "sbrodolar": "sbrodolare",
    "sbrodolaron": "sbrodolare",
    "sbrodolarono": "sbrodolare",
    "sbrodolasse": "sbrodolare",
    "sbrodolasser": "sbrodolare",
    "sbrodolassero": "sbrodolare",
    "sbrodolassi": "sbrodolare",
    "sbrodolassimo": "sbrodolare",
    "sbrodolaste": "sbrodolare",
    "sbrodolasti": "sbrodolare",
    "sbrodolata": "sbrodolare",
    "sbrodolate": "sbrodolare",
    "sbrodolati": "sbrodolare",
    "sbrodolato": "sbrodolare",
    "sbrodolava": "sbrodolare",
    "sbrodolavamo": "sbrodolare",
    "sbrodolavan": "sbrodolare",
    "sbrodolavano": "sbrodolare",
    "sbrodolavate": "sbrodolare",
    "sbrodolavi": "sbrodolare",
    "sbrodolavo": "sbrodolare",
    "sbrodolerai": "sbrodolare",
    "sbrodoleran": "sbrodolare",
    "sbrodoleranno": "sbrodolare",
    "sbrodolerebbe": "sbrodolare",
    "sbrodolerebber": "sbrodolare",
    "sbrodolerebbero": "sbrodolare",
    "sbrodolerei": "sbrodolare",
    "sbrodoleremmo": "sbrodolare",
    "sbrodoleremo": "sbrodolare",
    "sbrodolereste": "sbrodolare",
    "sbrodoleresti": "sbrodolare",
    "sbrodolerete": "sbrodolare",
    "sbrodolerà": "sbrodolare",
    "sbrodolerò": "sbrodolare",
    "sbrodoli": "sbrodolare",
    "sbrodoliamo": "sbrodolare",
    "sbrodoliate": "sbrodolare",
    "sbrodolin": "sbrodolare",
    "sbrodolino": "sbrodolare",
    "sbrodolo": "sbrodolare",
    "sbrodolò": "sbrodolare",
    "sbrogli": "sbrogliare",
    "sbroglia": "sbrogliare",
    "sbrogliai": "sbrogliare",
    "sbrogliammo": "sbrogliare",
    "sbrogliamo": "sbrogliare",
    "sbroglian": "sbrogliare",
    "sbrogliando": "sbrogliare",
    "sbrogliano": "sbrogliare",
    "sbrogliante": "sbrogliare",
    "sbroglianti": "sbrogliare",
    "sbrogliar": "sbrogliare",
    "sbrogliaron": "sbrogliare",
    "sbrogliarono": "sbrogliare",
    "sbrogliasse": "sbrogliare",
    "sbrogliasser": "sbrogliare",
    "sbrogliassero": "sbrogliare",
    "sbrogliassi": "sbrogliare",
    "sbrogliassimo": "sbrogliare",
    "sbrogliaste": "sbrogliare",
    "sbrogliasti": "sbrogliare",
    "sbrogliata": "sbrogliare",
    "sbrogliate": "sbrogliare",
    "sbrogliati": "sbrogliare",
    "sbrogliato": "sbrogliare",
    "sbrogliava": "sbrogliare",
    "sbrogliavamo": "sbrogliare",
    "sbrogliavan": "sbrogliare",
    "sbrogliavano": "sbrogliare",
    "sbrogliavate": "sbrogliare",
    "sbrogliavi": "sbrogliare",
    "sbrogliavo": "sbrogliare",
    "sbroglierai": "sbrogliare",
    "sbroglieran": "sbrogliare",
    "sbroglieranno": "sbrogliare",
    "sbroglierebbe": "sbrogliare",
    "sbroglierebber": "sbrogliare",
    "sbroglierebbero": "sbrogliare",
    "sbroglierei": "sbrogliare",
    "sbroglieremmo": "sbrogliare",
    "sbroglieremo": "sbrogliare",
    "sbrogliereste": "sbrogliare",
    "sbroglieresti": "sbrogliare",
    "sbroglierete": "sbrogliare",
    "sbroglierà": "sbrogliare",
    "sbroglierò": "sbrogliare",
    "sbroglin": "sbrogliare",
    "sbroglino": "sbrogliare",
    "sbroglio": "sbrogliare",
    "sbrogliò": "sbrogliare",
    "sbronza": "sbronzo",
    "sbronzai": "sbronzare",
    "sbronzammo": "sbronzare",
    "sbronzan": "sbronzare",
    "sbronzando": "sbronzare",
    "sbronzano": "sbronzare",
    "sbronzar": "sbronzare",
    "sbronzaron": "sbronzare",
    "sbronzarono": "sbronzare",
    "sbronzasse": "sbronzare",
    "sbronzasser": "sbronzare",
    "sbronzassero": "sbronzare",
    "sbronzassi": "sbronzare",
    "sbronzassimo": "sbronzare",
    "sbronzaste": "sbronzare",
    "sbronzasti": "sbronzare",
    "sbronzata": "sbronzare",
    "sbronzate": "sbronzare",
    "sbronzati": "sbronzare",
    "sbronzato": "sbronzare",
    "sbronzava": "sbronzare",
    "sbronzavamo": "sbronzare",
    "sbronzavan": "sbronzare",
    "sbronzavano": "sbronzare",
    "sbronzavate": "sbronzare",
    "sbronzavi": "sbronzare",
    "sbronzavo": "sbronzare",
    "sbronze": "sbronzo",
    "sbronzerai": "sbronzare",
    "sbronzeran": "sbronzare",
    "sbronzeranno": "sbronzare",
    "sbronzerebbe": "sbronzare",
    "sbronzerebber": "sbronzare",
    "sbronzerebbero": "sbronzare",
    "sbronzerei": "sbronzare",
    "sbronzeremmo": "sbronzare",
    "sbronzeremo": "sbronzare",
    "sbronzereste": "sbronzare",
    "sbronzeresti": "sbronzare",
    "sbronzerete": "sbronzare",
    "sbronzerà": "sbronzare",
    "sbronzerò": "sbronzare",
    "sbronzi": "sbronzo",
    "sbronziamo": "sbronzare",
    "sbronziate": "sbronzare",
    "sbronzin": "sbronzare",
    "sbronzino": "sbronzare",
    "sbronzo": "sbronzare",
    "sbronzò": "sbronzare",
    "sbruffa": "sbruffare",
    "sbruffai": "sbruffare",
    "sbruffammo": "sbruffare",
    "sbruffan": "sbruffare",
    "sbruffando": "sbruffare",
    "sbruffano": "sbruffare",
    "sbruffante": "sbruffare",
    "sbruffanti": "sbruffare",
    "sbruffar": "sbruffare",
    "sbruffaron": "sbruffare",
    "sbruffarono": "sbruffare",
    "sbruffasse": "sbruffare",
    "sbruffasser": "sbruffare",
    "sbruffassero": "sbruffare",
    "sbruffassi": "sbruffare",
    "sbruffassimo": "sbruffare",
    "sbruffaste": "sbruffare",
    "sbruffasti": "sbruffare",
    "sbruffata": "sbruffare",
    "sbruffate": "sbruffare",
    "sbruffati": "sbruffare",
    "sbruffato": "sbruffare",
    "sbruffava": "sbruffare",
    "sbruffavamo": "sbruffare",
    "sbruffavan": "sbruffare",
    "sbruffavano": "sbruffare",
    "sbruffavate": "sbruffare",
    "sbruffavi": "sbruffare",
    "sbruffavo": "sbruffare",
    "sbrufferai": "sbruffare",
    "sbrufferan": "sbruffare",
    "sbrufferanno": "sbruffare",
    "sbrufferebbe": "sbruffare",
    "sbrufferebber": "sbruffare",
    "sbrufferebbero": "sbruffare",
    "sbrufferei": "sbruffare",
    "sbrufferemmo": "sbruffare",
    "sbrufferemo": "sbruffare",
    "sbruffereste": "sbruffare",
    "sbrufferesti": "sbruffare",
    "sbrufferete": "sbruffare",
    "sbrufferà": "sbruffare",
    "sbrufferò": "sbruffare",
    "sbruffi": "sbruffare",
    "sbruffiamo": "sbruffare",
    "sbruffiate": "sbruffare",
    "sbruffin": "sbruffare",
    "sbruffino": "sbruffare",
    "sbruffo": "sbruffare",
    "sbruffonate": "sbruffonata",
    "sbruffoni": "sbruffone",
    "sbruffò": "sbruffare",
    "sbuca": "sbucare",
    "sbucai": "sbucare",
    "sbucammo": "sbucare",
    "sbucan": "sbucare",
    "sbucando": "sbucare",
    "sbucano": "sbucare",
    "sbucante": "sbucare",
    "sbucanti": "sbucare",
    "sbucar": "sbucare",
    "sbucaron": "sbucare",
    "sbucarono": "sbucare",
    "sbucasse": "sbucare",
    "sbucasser": "sbucare",
    "sbucassero": "sbucare",
    "sbucassi": "sbucare",
    "sbucassimo": "sbucare",
    "sbucaste": "sbucare",
    "sbucasti": "sbucare",
    "sbucata": "sbucare",
    "sbucate": "sbucare",
    "sbucati": "sbucare",
    "sbucato": "sbucare",
    "sbucava": "sbucare",
    "sbucavamo": "sbucare",
    "sbucavan": "sbucare",
    "sbucavano": "sbucare",
    "sbucavate": "sbucare",
    "sbucavi": "sbucare",
    "sbucavo": "sbucare",
    "sbuccerai": "sbucciare",
    "sbucceran": "sbucciare",
    "sbucceranno": "sbucciare",
    "sbuccerebbe": "sbucciare",
    "sbuccerebber": "sbucciare",
    "sbuccerebbero": "sbucciare",
    "sbuccerei": "sbucciare",
    "sbucceremmo": "sbucciare",
    "sbucceremo": "sbucciare",
    "sbuccereste": "sbucciare",
    "sbucceresti": "sbucciare",
    "sbuccerete": "sbucciare",
    "sbuccerà": "sbucciare",
    "sbuccerò": "sbucciare",
    "sbucci": "sbucciare",
    "sbuccia": "sbucciare",
    "sbucciai": "sbucciare",
    "sbucciammo": "sbucciare",
    "sbucciamo": "sbucciare",
    "sbuccian": "sbucciare",
    "sbucciando": "sbucciare",
    "sbucciano": "sbucciare",
    "sbucciante": "sbucciare",
    "sbuccianti": "sbucciare",
    "sbucciar": "sbucciare",
    "sbucciaron": "sbucciare",
    "sbucciarono": "sbucciare",
    "sbucciasse": "sbucciare",
    "sbucciasser": "sbucciare",
    "sbucciassero": "sbucciare",
    "sbucciassi": "sbucciare",
    "sbucciassimo": "sbucciare",
    "sbucciaste": "sbucciare",
    "sbucciasti": "sbucciare",
    "sbucciata": "sbucciare",
    "sbucciate": "sbucciare",
    "sbucciati": "sbucciare",
    "sbucciato": "sbucciare",
    "sbucciava": "sbucciare",
    "sbucciavamo": "sbucciare",
    "sbucciavan": "sbucciare",
    "sbucciavano": "sbucciare",
    "sbucciavate": "sbucciare",
    "sbucciavi": "sbucciare",
    "sbucciavo": "sbucciare",
    "sbuccin": "sbucciare",
    "sbuccino": "sbucciare",
    "sbuccio": "sbucciare",
    "sbucciò": "sbucciare",
    "sbucherai": "sbucare",
    "sbucheran": "sbucare",
    "sbucheranno": "sbucare",
    "sbucherebbe": "sbucare",
    "sbucherebber": "sbucare",
    "sbucherebbero": "sbucare",
    "sbucherei": "sbucare",
    "sbucheremmo": "sbucare",
    "sbucheremo": "sbucare",
    "sbuchereste": "sbucare",
    "sbucheresti": "sbucare",
    "sbucherete": "sbucare",
    "sbucherà": "sbucare",
    "sbucherò": "sbucare",
    "sbuchi": "sbucare",
    "sbuchiamo": "sbucare",
    "sbuchiate": "sbucare",
    "sbuchin": "sbucare",
    "sbuchino": "sbucare",
    "sbuco": "sbucare",
    "sbucò": "sbucare",
    "sbudella": "sbudellare",
    "sbudellai": "sbudellare",
    "sbudellammo": "sbudellare",
    "sbudellan": "sbudellare",
    "sbudellando": "sbudellare",
    "sbudellano": "sbudellare",
    "sbudellante": "sbudellare",
    "sbudellanti": "sbudellare",
    "sbudellar": "sbudellare",
    "sbudellaron": "sbudellare",
    "sbudellarono": "sbudellare",
    "sbudellasse": "sbudellare",
    "sbudellasser": "sbudellare",
    "sbudellassero": "sbudellare",
    "sbudellassi": "sbudellare",
    "sbudellassimo": "sbudellare",
    "sbudellaste": "sbudellare",
    "sbudellasti": "sbudellare",
    "sbudellata": "sbudellare",
    "sbudellate": "sbudellare",
    "sbudellati": "sbudellare",
    "sbudellato": "sbudellare",
    "sbudellava": "sbudellare",
    "sbudellavamo": "sbudellare",
    "sbudellavan": "sbudellare",
    "sbudellavano": "sbudellare",
    "sbudellavate": "sbudellare",
    "sbudellavi": "sbudellare",
    "sbudellavo": "sbudellare",
    "sbudellerai": "sbudellare",
    "sbudelleran": "sbudellare",
    "sbudelleranno": "sbudellare",
    "sbudellerebbe": "sbudellare",
    "sbudellerebber": "sbudellare",
    "sbudellerebbero": "sbudellare",
    "sbudellerei": "sbudellare",
    "sbudelleremmo": "sbudellare",
    "sbudelleremo": "sbudellare",
    "sbudellereste": "sbudellare",
    "sbudelleresti": "sbudellare",
    "sbudellerete": "sbudellare",
    "sbudellerà": "sbudellare",
    "sbudellerò": "sbudellare",
    "sbudelli": "sbudellare",
    "sbudelliamo": "sbudellare",
    "sbudelliate": "sbudellare",
    "sbudellin": "sbudellare",
    "sbudellino": "sbudellare",
    "sbudello": "sbudellare",
    "sbudellò": "sbudellare",
    "sbuffa": "sbuffare",
    "sbuffai": "sbuffare",
    "sbuffammo": "sbuffare",
    "sbuffan": "sbuffare",
    "sbuffando": "sbuffare",
    "sbuffano": "sbuffare",
    "sbuffante": "sbuffare",
    "sbuffanti": "sbuffare",
    "sbuffar": "sbuffare",
    "sbuffaron": "sbuffare",
    "sbuffarono": "sbuffare",
    "sbuffasse": "sbuffare",
    "sbuffasser": "sbuffare",
    "sbuffassero": "sbuffare",
    "sbuffassi": "sbuffare",
    "sbuffassimo": "sbuffare",
    "sbuffaste": "sbuffare",
    "sbuffasti": "sbuffare",
    "sbuffata": "sbuffare",
    "sbuffate": "sbuffare",
    "sbuffati": "sbuffare",
    "sbuffato": "sbuffare",
    "sbuffava": "sbuffare",
    "sbuffavamo": "sbuffare",
    "sbuffavan": "sbuffare",
    "sbuffavano": "sbuffare",
    "sbuffavate": "sbuffare",
    "sbuffavi": "sbuffare",
    "sbuffavo": "sbuffare",
    "sbufferai": "sbuffare",
    "sbufferan": "sbuffare",
    "sbufferanno": "sbuffare",
    "sbufferebbe": "sbuffare",
    "sbufferebber": "sbuffare",
    "sbufferebbero": "sbuffare",
    "sbufferei": "sbuffare",
    "sbufferemmo": "sbuffare",
    "sbufferemo": "sbuffare",
    "sbuffereste": "sbuffare",
    "sbufferesti": "sbuffare",
    "sbufferete": "sbuffare",
    "sbufferà": "sbuffare",
    "sbufferò": "sbuffare",
    "sbuffi": "sbuffo",
    "sbuffiamo": "sbuffare",
    "sbuffiate": "sbuffare",
    "sbuffin": "sbuffare",
    "sbuffino": "sbuffare",
    "sbuffo": "sbuffare",
    "sbuffò": "sbuffare",
    "sbugiarda": "sbugiardare",
    "sbugiardai": "sbugiardare",
    "sbugiardammo": "sbugiardare",
    "sbugiardan": "sbugiardare",
    "sbugiardando": "sbugiardare",
    "sbugiardano": "sbugiardare",
    "sbugiardante": "sbugiardare",
    "sbugiardanti": "sbugiardare",
    "sbugiardar": "sbugiardare",
    "sbugiardaron": "sbugiardare",
    "sbugiardarono": "sbugiardare",
    "sbugiardasse": "sbugiardare",
    "sbugiardasser": "sbugiardare",
    "sbugiardassero": "sbugiardare",
    "sbugiardassi": "sbugiardare",
    "sbugiardassimo": "sbugiardare",
    "sbugiardaste": "sbugiardare",
    "sbugiardasti": "sbugiardare",
    "sbugiardata": "sbugiardare",
    "sbugiardate": "sbugiardare",
    "sbugiardati": "sbugiardare",
    "sbugiardato": "sbugiardare",
    "sbugiardava": "sbugiardare",
    "sbugiardavamo": "sbugiardare",
    "sbugiardavan": "sbugiardare",
    "sbugiardavano": "sbugiardare",
    "sbugiardavate": "sbugiardare",
    "sbugiardavi": "sbugiardare",
    "sbugiardavo": "sbugiardare",
    "sbugiarderai": "sbugiardare",
    "sbugiarderan": "sbugiardare",
    "sbugiarderanno": "sbugiardare",
    "sbugiarderebbe": "sbugiardare",
    "sbugiarderebber": "sbugiardare",
    "sbugiarderebbero": "sbugiardare",
    "sbugiarderei": "sbugiardare",
    "sbugiarderemmo": "sbugiardare",
    "sbugiarderemo": "sbugiardare",
    "sbugiardereste": "sbugiardare",
    "sbugiarderesti": "sbugiardare",
    "sbugiarderete": "sbugiardare",
    "sbugiarderà": "sbugiardare",
    "sbugiarderò": "sbugiardare",
    "sbugiardi": "sbugiardare",
    "sbugiardiamo": "sbugiardare",
    "sbugiardiate": "sbugiardare",
    "sbugiardin": "sbugiardare",
    "sbugiardino": "sbugiardare",
    "sbugiardo": "sbugiardare",
    "sbugiardò": "sbugiardare",
    "sbullona": "sbullonare",
    "sbullonai": "sbullonare",
    "sbullonammo": "sbullonare",
    "sbullonan": "sbullonare",
    "sbullonando": "sbullonare",
    "sbullonano": "sbullonare",
    "sbullonante": "sbullonare",
    "sbullonanti": "sbullonare",
    "sbullonar": "sbullonare",
    "sbullonaron": "sbullonare",
    "sbullonarono": "sbullonare",
    "sbullonasse": "sbullonare",
    "sbullonasser": "sbullonare",
    "sbullonassero": "sbullonare",
    "sbullonassi": "sbullonare",
    "sbullonassimo": "sbullonare",
    "sbullonaste": "sbullonare",
    "sbullonasti": "sbullonare",
    "sbullonata": "sbullonare",
    "sbullonate": "sbullonare",
    "sbullonati": "sbullonare",
    "sbullonato": "sbullonare",
    "sbullonava": "sbullonare",
    "sbullonavamo": "sbullonare",
    "sbullonavan": "sbullonare",
    "sbullonavano": "sbullonare",
    "sbullonavate": "sbullonare",
    "sbullonavi": "sbullonare",
    "sbullonavo": "sbullonare",
    "sbullonerai": "sbullonare",
    "sbulloneran": "sbullonare",
    "sbulloneranno": "sbullonare",
    "sbullonerebbe": "sbullonare",
    "sbullonerebber": "sbullonare",
    "sbullonerebbero": "sbullonare",
    "sbullonerei": "sbullonare",
    "sbulloneremmo": "sbullonare",
    "sbulloneremo": "sbullonare",
    "sbullonereste": "sbullonare",
    "sbulloneresti": "sbullonare",
    "sbullonerete": "sbullonare",
    "sbullonerà": "sbullonare",
    "sbullonerò": "sbullonare",
    "sbulloni": "sbullonare",
    "sbulloniamo": "sbullonare",
    "sbulloniate": "sbullonare",
    "sbullonin": "sbullonare",
    "sbullonino": "sbullonare",
    "sbullono": "sbullonare",
    "sbullonò": "sbullonare",
    "sbuzza": "sbuzzare",
    "sbuzzai": "sbuzzare",
    "sbuzzammo": "sbuzzare",
    "sbuzzan": "sbuzzare",
    "sbuzzando": "sbuzzare",
    "sbuzzano": "sbuzzare",
    "sbuzzante": "sbuzzare",
    "sbuzzanti": "sbuzzare",
    "sbuzzar": "sbuzzare",
    "sbuzzaron": "sbuzzare",
    "sbuzzarono": "sbuzzare",
    "sbuzzasse": "sbuzzare",
    "sbuzzasser": "sbuzzare",
    "sbuzzassero": "sbuzzare",
    "sbuzzassi": "sbuzzare",
    "sbuzzassimo": "sbuzzare",
    "sbuzzaste": "sbuzzare",
    "sbuzzasti": "sbuzzare",
    "sbuzzata": "sbuzzare",
    "sbuzzate": "sbuzzare",
    "sbuzzati": "sbuzzare",
    "sbuzzato": "sbuzzare",
    "sbuzzava": "sbuzzare",
    "sbuzzavamo": "sbuzzare",
    "sbuzzavan": "sbuzzare",
    "sbuzzavano": "sbuzzare",
    "sbuzzavate": "sbuzzare",
    "sbuzzavi": "sbuzzare",
    "sbuzzavo": "sbuzzare",
    "sbuzzerai": "sbuzzare",
    "sbuzzeran": "sbuzzare",
    "sbuzzeranno": "sbuzzare",
    "sbuzzerebbe": "sbuzzare",
    "sbuzzerebber": "sbuzzare",
    "sbuzzerebbero": "sbuzzare",
    "sbuzzerei": "sbuzzare",
    "sbuzzeremmo": "sbuzzare",
    "sbuzzeremo": "sbuzzare",
    "sbuzzereste": "sbuzzare",
    "sbuzzeresti": "sbuzzare",
    "sbuzzerete": "sbuzzare",
    "sbuzzerà": "sbuzzare",
    "sbuzzerò": "sbuzzare",
    "sbuzzi": "sbuzzare",
    "sbuzziamo": "sbuzzare",
    "sbuzziate": "sbuzzare",
    "sbuzzin": "sbuzzare",
    "sbuzzino": "sbuzzare",
    "sbuzzo": "sbuzzare",
    "sbuzzò": "sbuzzare",
    "scabra": "scabro",
    "scabre": "scabro",
    "scabri": "scabro",
    "scabrosa": "scabroso",
    "scabrose": "scabroso",
    "scabrosi": "scabroso",
    "scaccerai": "scacciare",
    "scacceran": "scacciare",
    "scacceranno": "scacciare",
    "scaccerebbe": "scacciare",
    "scaccerebber": "scacciare",
    "scaccerebbero": "scacciare",
    "scaccerei": "scacciare",
    "scacceremmo": "scacciare",
    "scacceremo": "scacciare",
    "scaccereste": "scacciare",
    "scacceresti": "scacciare",
    "scaccerete": "scacciare",
    "scaccerà": "scacciare",
    "scaccerò": "scacciare",
    "scacchi": "scacco",
    "scacchia": "scacchiare",
    "scacchiai": "scacchiare",
    "scacchiammo": "scacchiare",
    "scacchiamo": "scacchiare",
    "scacchian": "scacchiare",
    "scacchiando": "scacchiare",
    "scacchiano": "scacchiare",
    "scacchiante": "scacchiare",
    "scacchianti": "scacchiare",
    "scacchiar": "scacchiare",
    "scacchiaron": "scacchiare",
    "scacchiarono": "scacchiare",
    "scacchiasse": "scacchiare",
    "scacchiasser": "scacchiare",
    "scacchiassero": "scacchiare",
    "scacchiassi": "scacchiare",
    "scacchiassimo": "scacchiare",
    "scacchiaste": "scacchiare",
    "scacchiasti": "scacchiare",
    "scacchiata": "scacchiare",
    "scacchiate": "scacchiare",
    "scacchiati": "scacchiare",
    "scacchiato": "scacchiare",
    "scacchiava": "scacchiare",
    "scacchiavamo": "scacchiare",
    "scacchiavan": "scacchiare",
    "scacchiavano": "scacchiare",
    "scacchiavate": "scacchiare",
    "scacchiavi": "scacchiare",
    "scacchiavo": "scacchiare",
    "scacchierai": "scacchiare",
    "scacchieran": "scacchiare",
    "scacchieranno": "scacchiare",
    "scacchiere": "scacchiera",
    "scacchierebbe": "scacchiare",
    "scacchierebber": "scacchiare",
    "scacchierebbero": "scacchiare",
    "scacchierei": "scacchiare",
    "scacchieremmo": "scacchiare",
    "scacchieremo": "scacchiare",
    "scacchiereste": "scacchiare",
    "scacchieresti": "scacchiare",
    "scacchierete": "scacchiare",
    "scacchieri": "scacchiere",
    "scacchierà": "scacchiare",
    "scacchierò": "scacchiare",
    "scacchin": "scacchiare",
    "scacchino": "scacchiare",
    "scacchio": "scacchiare",
    "scacchisti": "scacchista",
    "scacchistica": "scacchistico",
    "scacchistiche": "scacchistico",
    "scacchistici": "scacchistico",
    "scacchiò": "scacchiare",
    "scacci": "scacciare",
    "scaccia": "scacciare",
    "scacciai": "scacciare",
    "scacciammo": "scacciare",
    "scacciamo": "scacciare",
    "scaccian": "scacciare",
    "scacciando": "scacciare",
    "scacciano": "scacciare",
    "scacciante": "scacciare",
    "scaccianti": "scacciare",
    "scacciar": "scacciare",
    "scacciaron": "scacciare",
    "scacciarono": "scacciare",
    "scacciasse": "scacciare",
    "scacciasser": "scacciare",
    "scacciassero": "scacciare",
    "scacciassi": "scacciare",
    "scacciassimo": "scacciare",
    "scacciaste": "scacciare",
    "scacciasti": "scacciare",
    "scacciata": "scacciare",
    "scacciate": "scacciare",
    "scacciati": "scacciare",
    "scacciato": "scacciare",
    "scacciava": "scacciare",
    "scacciavamo": "scacciare",
    "scacciavan": "scacciare",
    "scacciavano": "scacciare",
    "scacciavate": "scacciare",
    "scacciavi": "scacciare",
    "scacciavo": "scacciare",
    "scaccin": "scacciare",
    "scaccino": "scacciare",
    "scaccio": "scacciare",
    "scacciò": "scacciare",
    "scada": "scadere",
    "scadan": "scadere",
    "scadano": "scadere",
    "scadde": "scadere",
    "scadder": "scadere",
    "scaddero": "scadere",
    "scaddi": "scadere",
    "scade": "scadere",
    "scademmo": "scadere",
    "scadendo": "scadere",
    "scadente": "scadere",
    "scadenti": "scadere",
    "scadenza": "scadenzare",
    "scadenzai": "scadenzare",
    "scadenzammo": "scadenzare",
    "scadenzan": "scadenzare",
    "scadenzando": "scadenzare",
    "scadenzano": "scadenzare",
    "scadenzante": "scadenzare",
    "scadenzanti": "scadenzare",
    "scadenzar": "scadenzare",
    "scadenzaron": "scadenzare",
    "scadenzarono": "scadenzare",
    "scadenzasse": "scadenzare",
    "scadenzasser": "scadenzare",
    "scadenzassero": "scadenzare",
    "scadenzassi": "scadenzare",
    "scadenzassimo": "scadenzare",
    "scadenzaste": "scadenzare",
    "scadenzasti": "scadenzare",
    "scadenzata": "scadenzare",
    "scadenzate": "scadenzare",
    "scadenzati": "scadenzare",
    "scadenzato": "scadenzare",
    "scadenzava": "scadenzare",
    "scadenzavamo": "scadenzare",
    "scadenzavan": "scadenzare",
    "scadenzavano": "scadenzare",
    "scadenzavate": "scadenzare",
    "scadenzavi": "scadenzare",
    "scadenzavo": "scadenzare",
    "scadenze": "scadenza",
    "scadenzerai": "scadenzare",
    "scadenzeran": "scadenzare",
    "scadenzeranno": "scadenzare",
    "scadenzerebbe": "scadenzare",
    "scadenzerebber": "scadenzare",
    "scadenzerebbero": "scadenzare",
    "scadenzerei": "scadenzare",
    "scadenzeremmo": "scadenzare",
    "scadenzeremo": "scadenzare",
    "scadenzereste": "scadenzare",
    "scadenzeresti": "scadenzare",
    "scadenzerete": "scadenzare",
    "scadenzerà": "scadenzare",
    "scadenzerò": "scadenzare",
    "scadenzi": "scadenzare",
    "scadenziamo": "scadenzare",
    "scadenziate": "scadenzare",
    "scadenzin": "scadenzare",
    "scadenzino": "scadenzare",
    "scadenzo": "scadenzare",
    "scadenzò": "scadenzare",
    "scader": "scadere",
    "scadesse": "scadere",
    "scadesser": "scadere",
    "scadessero": "scadere",
    "scadessi": "scadere",
    "scadessimo": "scadere",
    "scadeste": "scadere",
    "scadesti": "scadere",
    "scadete": "scadere",
    "scadeva": "scadere",
    "scadevamo": "scadere",
    "scadevan": "scadere",
    "scadevano": "scadere",
    "scadevate": "scadere",
    "scadevi": "scadere",
    "scadevo": "scadere",
    "scadi": "scadere",
    "scadiamo": "scadere",
    "scadiate": "scadere",
    "scadimenti": "scadimento",
    "scado": "scadere",
    "scadon": "scadere",
    "scadono": "scadere",
    "scadrai": "scadere",
    "scadran": "scadere",
    "scadranno": "scadere",
    "scadrebbe": "scadere",
    "scadrebber": "scadere",
    "scadrebbero": "scadere",
    "scadrei": "scadere",
    "scadremmo": "scadere",
    "scadremo": "scadere",
    "scadreste": "scadere",
    "scadresti": "scadere",
    "scadrete": "scadere",
    "scadrà": "scadere",
    "scadrò": "scadere",
    "scaduta": "scadere",
    "scadute": "scadere",
    "scaduti": "scadere",
    "scaduto": "scadere",
    "scafa": "scafare",
    "scafai": "scafare",
    "scafammo": "scafare",
    "scafan": "scafare",
    "scafando": "scafare",
    "scafandri": "scafandro",
    "scafano": "scafare",
    "scafante": "scafare",
    "scafanti": "scafare",
    "scafar": "scafare",
    "scafaron": "scafare",
    "scafarono": "scafare",
    "scafasse": "scafare",
    "scafasser": "scafare",
    "scafassero": "scafare",
    "scafassi": "scafare",
    "scafassimo": "scafare",
    "scafaste": "scafare",
    "scafasti": "scafare",
    "scafata": "scafare",
    "scafate": "scafare",
    "scafati": "scafare",
    "scafato": "scafare",
    "scafava": "scafare",
    "scafavamo": "scafare",
    "scafavan": "scafare",
    "scafavano": "scafare",
    "scafavate": "scafare",
    "scafavi": "scafare",
    "scafavo": "scafare",
    "scaferai": "scafare",
    "scaferan": "scafare",
    "scaferanno": "scafare",
    "scaferebbe": "scafare",
    "scaferebber": "scafare",
    "scaferebbero": "scafare",
    "scaferei": "scafare",
    "scaferemmo": "scafare",
    "scaferemo": "scafare",
    "scafereste": "scafare",
    "scaferesti": "scafare",
    "scaferete": "scafare",
    "scaferà": "scafare",
    "scaferò": "scafare",
    "scaffala": "scaffalare",
    "scaffalai": "scaffalare",
    "scaffalammo": "scaffalare",
    "scaffalan": "scaffalare",
    "scaffalando": "scaffalare",
    "scaffalano": "scaffalare",
    "scaffalante": "scaffalare",
    "scaffalanti": "scaffalare",
    "scaffalar": "scaffalare",
    "scaffalaron": "scaffalare",
    "scaffalarono": "scaffalare",
    "scaffalasse": "scaffalare",
    "scaffalasser": "scaffalare",
    "scaffalassero": "scaffalare",
    "scaffalassi": "scaffalare",
    "scaffalassimo": "scaffalare",
    "scaffalaste": "scaffalare",
    "scaffalasti": "scaffalare",
    "scaffalata": "scaffalare",
    "scaffalate": "scaffalare",
    "scaffalati": "scaffalare",
    "scaffalato": "scaffalare",
    "scaffalature": "scaffalatura",
    "scaffalava": "scaffalare",
    "scaffalavamo": "scaffalare",
    "scaffalavan": "scaffalare",
    "scaffalavano": "scaffalare",
    "scaffalavate": "scaffalare",
    "scaffalavi": "scaffalare",
    "scaffalavo": "scaffalare",
    "scaffalerai": "scaffalare",
    "scaffaleran": "scaffalare",
    "scaffaleranno": "scaffalare",
    "scaffalerebbe": "scaffalare",
    "scaffalerebber": "scaffalare",
    "scaffalerebbero": "scaffalare",
    "scaffalerei": "scaffalare",
    "scaffaleremmo": "scaffalare",
    "scaffaleremo": "scaffalare",
    "scaffalereste": "scaffalare",
    "scaffaleresti": "scaffalare",
    "scaffalerete": "scaffalare",
    "scaffalerà": "scaffalare",
    "scaffalerò": "scaffalare",
    "scaffali": "scaffale",
    "scaffaliamo": "scaffalare",
    "scaffaliate": "scaffalare",
    "scaffalin": "scaffalare",
    "scaffalino": "scaffalare",
    "scaffalo": "scaffalare",
    "scaffalò": "scaffalare",
    "scafi": "scafo",
    "scafiamo": "scafare",
    "scafiate": "scafare",
    "scafin": "scafare",
    "scafino": "scafare",
    "scafisti": "scafista",
    "scafo": "scafare",
    "scafò": "scafare",
    "scagiona": "scagionare",
    "scagionai": "scagionare",
    "scagionammo": "scagionare",
    "scagionan": "scagionare",
    "scagionando": "scagionare",
    "scagionano": "scagionare",
    "scagionante": "scagionare",
    "scagionanti": "scagionare",
    "scagionar": "scagionare",
    "scagionaron": "scagionare",
    "scagionarono": "scagionare",
    "scagionasse": "scagionare",
    "scagionasser": "scagionare",
    "scagionassero": "scagionare",
    "scagionassi": "scagionare",
    "scagionassimo": "scagionare",
    "scagionaste": "scagionare",
    "scagionasti": "scagionare",
    "scagionata": "scagionare",
    "scagionate": "scagionare",
    "scagionati": "scagionare",
    "scagionato": "scagionare",
    "scagionava": "scagionare",
    "scagionavamo": "scagionare",
    "scagionavan": "scagionare",
    "scagionavano": "scagionare",
    "scagionavate": "scagionare",
    "scagionavi": "scagionare",
    "scagionavo": "scagionare",
    "scagionerai": "scagionare",
    "scagioneran": "scagionare",
    "scagioneranno": "scagionare",
    "scagionerebbe": "scagionare",
    "scagionerebber": "scagionare",
    "scagionerebbero": "scagionare",
    "scagionerei": "scagionare",
    "scagioneremmo": "scagionare",
    "scagioneremo": "scagionare",
    "scagionereste": "scagionare",
    "scagioneresti": "scagionare",
    "scagionerete": "scagionare",
    "scagionerà": "scagionare",
    "scagionerò": "scagionare",
    "scagioni": "scagionare",
    "scagioniamo": "scagionare",
    "scagioniate": "scagionare",
    "scagionin": "scagionare",
    "scagionino": "scagionare",
    "scagiono": "scagionare",
    "scagionò": "scagionare",
    "scagli": "scagliare",
    "scaglia": "scagliare",
    "scagliai": "scagliare",
    "scagliammo": "scagliare",
    "scagliamo": "scagliare",
    "scaglian": "scagliare",
    "scagliando": "scagliare",
    "scagliano": "scagliare",
    "scagliante": "scagliare",
    "scaglianti": "scagliare",
    "scagliar": "scagliare",
    "scagliaron": "scagliare",
    "scagliarono": "scagliare",
    "scagliasse": "scagliare",
    "scagliasser": "scagliare",
    "scagliassero": "scagliare",
    "scagliassi": "scagliare",
    "scagliassimo": "scagliare",
    "scagliaste": "scagliare",
    "scagliasti": "scagliare",
    "scagliata": "scagliare",
    "scagliate": "scagliare",
    "scagliati": "scagliare",
    "scagliato": "scagliare",
    "scagliava": "scagliare",
    "scagliavamo": "scagliare",
    "scagliavan": "scagliare",
    "scagliavano": "scagliare",
    "scagliavate": "scagliare",
    "scagliavi": "scagliare",
    "scagliavo": "scagliare",
    "scaglie": "scaglia",
    "scaglierai": "scagliare",
    "scaglieran": "scagliare",
    "scaglieranno": "scagliare",
    "scaglierebbe": "scagliare",
    "scaglierebber": "scagliare",
    "scaglierebbero": "scagliare",
    "scaglierei": "scagliare",
    "scaglieremmo": "scagliare",
    "scaglieremo": "scagliare",
    "scagliereste": "scagliare",
    "scaglieresti": "scagliare",
    "scaglierete": "scagliare",
    "scaglierà": "scagliare",
    "scaglierò": "scagliare",
    "scaglin": "scagliare",
    "scaglino": "scagliare",
    "scaglio": "scagliare",
    "scagliona": "scaglionare",
    "scaglionai": "scaglionare",
    "scaglionamenti": "scaglionamento",
    "scaglionammo": "scaglionare",
    "scaglionan": "scaglionare",
    "scaglionando": "scaglionare",
    "scaglionano": "scaglionare",
    "scaglionante": "scaglionare",
    "scaglionanti": "scaglionare",
    "scaglionar": "scaglionare",
    "scaglionaron": "scaglionare",
    "scaglionarono": "scaglionare",
    "scaglionasse": "scaglionare",
    "scaglionasser": "scaglionare",
    "scaglionassero": "scaglionare",
    "scaglionassi": "scaglionare",
    "scaglionassimo": "scaglionare",
    "scaglionaste": "scaglionare",
    "scaglionasti": "scaglionare",
    "scaglionata": "scaglionare",
    "scaglionate": "scaglionare",
    "scaglionati": "scaglionare",
    "scaglionato": "scaglionare",
    "scaglionava": "scaglionare",
    "scaglionavamo": "scaglionare",
    "scaglionavan": "scaglionare",
    "scaglionavano": "scaglionare",
    "scaglionavate": "scaglionare",
    "scaglionavi": "scaglionare",
    "scaglionavo": "scaglionare",
    "scaglionerai": "scaglionare",
    "scaglioneran": "scaglionare",
    "scaglioneranno": "scaglionare",
    "scaglionerebbe": "scaglionare",
    "scaglionerebber": "scaglionare",
    "scaglionerebbero": "scaglionare",
    "scaglionerei": "scaglionare",
    "scaglioneremmo": "scaglionare",
    "scaglioneremo": "scaglionare",
    "scaglionereste": "scaglionare",
    "scaglioneresti": "scaglionare",
    "scaglionerete": "scaglionare",
    "scaglionerà": "scaglionare",
    "scaglionerò": "scaglionare",
    "scaglioni": "scaglione",
    "scaglioniamo": "scaglionare",
    "scaglioniate": "scaglionare",
    "scaglionin": "scaglionare",
    "scaglionino": "scaglionare",
    "scagliono": "scaglionare",
    "scaglionò": "scaglionare",
    "scagliò": "scagliare",
    "scala": "scalare",
    "scalai": "scalare",
    "scalammo": "scalare",
    "scalan": "scalare",
    "scalando": "scalare",
    "scalano": "scalare",
    "scalante": "scalare",
    "scalanti": "scalare",
    "scalar": "scalare",
    "scalari": "scalare",
    "scalaron": "scalare",
    "scalarono": "scalare",
    "scalasse": "scalare",
    "scalasser": "scalare",
    "scalassero": "scalare",
    "scalassi": "scalare",
    "scalassimo": "scalare",
    "scalaste": "scalare",
    "scalasti": "scalare",
    "scalata": "scalare",
    "scalate": "scalata",
    "scalati": "scalare",
    "scalato": "scalare",
    "scalatori": "scalatore",
    "scalava": "scalare",
    "scalavamo": "scalare",
    "scalavan": "scalare",
    "scalavano": "scalare",
    "scalavate": "scalare",
    "scalavi": "scalare",
    "scalavo": "scalare",
    "scalca": "scalcare",
    "scalcagnata": "scalcagnato",
    "scalcagnate": "scalcagnato",
    "scalcagnati": "scalcagnato",
    "scalcai": "scalcare",
    "scalcammo": "scalcare",
    "scalcan": "scalcare",
    "scalcando": "scalcare",
    "scalcano": "scalcare",
    "scalcante": "scalcare",
    "scalcanti": "scalcare",
    "scalcar": "scalcare",
    "scalcaron": "scalcare",
    "scalcarono": "scalcare",
    "scalcasse": "scalcare",
    "scalcasser": "scalcare",
    "scalcassero": "scalcare",
    "scalcassi": "scalcare",
    "scalcassimo": "scalcare",
    "scalcaste": "scalcare",
    "scalcasti": "scalcare",
    "scalcata": "scalcare",
    "scalcate": "scalcare",
    "scalcati": "scalcare",
    "scalcato": "scalcare",
    "scalcava": "scalcare",
    "scalcavamo": "scalcare",
    "scalcavan": "scalcare",
    "scalcavano": "scalcare",
    "scalcavate": "scalcare",
    "scalcavi": "scalcare",
    "scalcavo": "scalcare",
    "scalcerai": "scalciare",
    "scalceran": "scalciare",
    "scalceranno": "scalciare",
    "scalcerebbe": "scalciare",
    "scalcerebber": "scalciare",
    "scalcerebbero": "scalciare",
    "scalcerei": "scalciare",
    "scalceremmo": "scalciare",
    "scalceremo": "scalciare",
    "scalcereste": "scalciare",
    "scalceresti": "scalciare",
    "scalcerete": "scalciare",
    "scalcerà": "scalciare",
    "scalcerò": "scalciare",
    "scalcherai": "scalcare",
    "scalcheran": "scalcare",
    "scalcheranno": "scalcare",
    "scalcherebbe": "scalcare",
    "scalcherebber": "scalcare",
    "scalcherebbero": "scalcare",
    "scalcherei": "scalcare",
    "scalcheremmo": "scalcare",
    "scalcheremo": "scalcare",
    "scalchereste": "scalcare",
    "scalcheresti": "scalcare",
    "scalcherete": "scalcare",
    "scalcherà": "scalcare",
    "scalcherò": "scalcare",
    "scalchi": "scalcare",
    "scalchiamo": "scalcare",
    "scalchiate": "scalcare",
    "scalchin": "scalcare",
    "scalchino": "scalcare",
    "scalci": "scalciare",
    "scalcia": "scalciare",
    "scalciai": "scalciare",
    "scalciammo": "scalciare",
    "scalciamo": "scalciare",
    "scalcian": "scalciare",
    "scalciando": "scalciare",
    "scalciano": "scalciare",
    "scalciante": "scalciare",
    "scalcianti": "scalciare",
    "scalciar": "scalciare",
    "scalciaron": "scalciare",
    "scalciarono": "scalciare",
    "scalciasse": "scalciare",
    "scalciasser": "scalciare",
    "scalciassero": "scalciare",
    "scalciassi": "scalciare",
    "scalciassimo": "scalciare",
    "scalciaste": "scalciare",
    "scalciasti": "scalciare",
    "scalciata": "scalciare",
    "scalciate": "scalciare",
    "scalciati": "scalciare",
    "scalciato": "scalciare",
    "scalciava": "scalciare",
    "scalciavamo": "scalciare",
    "scalciavan": "scalciare",
    "scalciavano": "scalciare",
    "scalciavate": "scalciare",
    "scalciavi": "scalciare",
    "scalciavo": "scalciare",
    "scalcin": "scalciare",
    "scalcina": "scalcinare",
    "scalcinai": "scalcinare",
    "scalcinammo": "scalcinare",
    "scalcinan": "scalcinare",
    "scalcinando": "scalcinare",
    "scalcinano": "scalcinare",
    "scalcinante": "scalcinare",
    "scalcinanti": "scalcinare",
    "scalcinar": "scalcinare",
    "scalcinaron": "scalcinare",
    "scalcinarono": "scalcinare",
    "scalcinasse": "scalcinare",
    "scalcinasser": "scalcinare",
    "scalcinassero": "scalcinare",
    "scalcinassi": "scalcinare",
    "scalcinassimo": "scalcinare",
    "scalcinaste": "scalcinare",
    "scalcinasti": "scalcinare",
    "scalcinata": "scalcinato",
    "scalcinate": "scalcinato",
    "scalcinati": "scalcinato",
    "scalcinato": "scalcinare",
    "scalcinava": "scalcinare",
    "scalcinavamo": "scalcinare",
    "scalcinavan": "scalcinare",
    "scalcinavano": "scalcinare",
    "scalcinavate": "scalcinare",
    "scalcinavi": "scalcinare",
    "scalcinavo": "scalcinare",
    "scalcinerai": "scalcinare",
    "scalcineran": "scalcinare",
    "scalcineranno": "scalcinare",
    "scalcinerebbe": "scalcinare",
    "scalcinerebber": "scalcinare",
    "scalcinerebbero": "scalcinare",
    "scalcinerei": "scalcinare",
    "scalcineremmo": "scalcinare",
    "scalcineremo": "scalcinare",
    "scalcinereste": "scalcinare",
    "scalcineresti": "scalcinare",
    "scalcinerete": "scalcinare",
    "scalcinerà": "scalcinare",
    "scalcinerò": "scalcinare",
    "scalcini": "scalcinare",
    "scalciniamo": "scalcinare",
    "scalciniate": "scalcinare",
    "scalcinin": "scalcinare",
    "scalcinino": "scalcinare",
    "scalcino": "scalcinare",
    "scalcinò": "scalcinare",
    "scalcio": "scalciare",
    "scalciò": "scalciare",
    "scalco": "scalcare",
    "scalcò": "scalcare",
    "scalda": "scaldare",
    "scaldabagni": "scaldabagno",
    "scaldai": "scaldare",
    "scaldammo": "scaldare",
    "scaldan": "scaldare",
    "scaldando": "scaldare",
    "scaldano": "scaldare",
    "scaldante": "scaldare",
    "scaldanti": "scaldare",
    "scaldar": "scaldare",
    "scaldaron": "scaldare",
    "scaldarono": "scaldare",
    "scaldasse": "scaldare",
    "scaldasser": "scaldare",
    "scaldassero": "scaldare",
    "scaldassi": "scaldare",
    "scaldassimo": "scaldare",
    "scaldaste": "scaldare",
    "scaldasti": "scaldare",
    "scaldata": "scaldare",
    "scaldate": "scaldare",
    "scaldati": "scaldare",
    "scaldato": "scaldare",
    "scaldava": "scaldare",
    "scaldavamo": "scaldare",
    "scaldavan": "scaldare",
    "scaldavano": "scaldare",
    "scaldavate": "scaldare",
    "scaldavi": "scaldare",
    "scaldavo": "scaldare",
    "scalderai": "scaldare",
    "scalderan": "scaldare",
    "scalderanno": "scaldare",
    "scalderebbe": "scaldare",
    "scalderebber": "scaldare",
    "scalderebbero": "scaldare",
    "scalderei": "scaldare",
    "scalderemmo": "scaldare",
    "scalderemo": "scaldare",
    "scaldereste": "scaldare",
    "scalderesti": "scaldare",
    "scalderete": "scaldare",
    "scalderà": "scaldare",
    "scalderò": "scaldare",
    "scaldi": "scaldare",
    "scaldiamo": "scaldare",
    "scaldiate": "scaldare",
    "scaldin": "scaldare",
    "scaldino": "scaldare",
    "scaldo": "scaldare",
    "scaldò": "scaldare",
    "scale": "scala",
    "scalee": "scalea",
    "scalerai": "scalare",
    "scaleran": "scalare",
    "scaleranno": "scalare",
    "scalerebbe": "scalare",
    "scalerebber": "scalare",
    "scalerebbero": "scalare",
    "scalerei": "scalare",
    "scaleremmo": "scalare",
    "scaleremo": "scalare",
    "scalereste": "scalare",
    "scaleresti": "scalare",
    "scalerete": "scalare",
    "scalerà": "scalare",
    "scalerò": "scalare",
    "scalette": "scaletta",
    "scalfa": "scalfare",
    "scalfai": "scalfare",
    "scalfammo": "scalfare",
    "scalfan": "scalfare",
    "scalfando": "scalfare",
    "scalfano": "scalfare",
    "scalfante": "scalfare",
    "scalfanti": "scalfare",
    "scalfar": "scalfare",
    "scalfaron": "scalfare",
    "scalfarono": "scalfare",
    "scalfasse": "scalfare",
    "scalfasser": "scalfare",
    "scalfassero": "scalfare",
    "scalfassi": "scalfare",
    "scalfassimo": "scalfare",
    "scalfaste": "scalfare",
    "scalfasti": "scalfare",
    "scalfata": "scalfare",
    "scalfate": "scalfare",
    "scalfati": "scalfare",
    "scalfato": "scalfare",
    "scalfava": "scalfare",
    "scalfavamo": "scalfare",
    "scalfavan": "scalfare",
    "scalfavano": "scalfare",
    "scalfavate": "scalfare",
    "scalfavi": "scalfare",
    "scalfavo": "scalfare",
    "scalfendo": "scalfire",
    "scalfente": "scalfire",
    "scalfenti": "scalfire",
    "scalferai": "scalfare",
    "scalferan": "scalfare",
    "scalferanno": "scalfare",
    "scalferebbe": "scalfare",
    "scalferebber": "scalfare",
    "scalferebbero": "scalfare",
    "scalferei": "scalfare",
    "scalferemmo": "scalfare",
    "scalferemo": "scalfare",
    "scalfereste": "scalfare",
    "scalferesti": "scalfare",
    "scalferete": "scalfare",
    "scalferà": "scalfare",
    "scalferò": "scalfare",
    "scalfi": "scalfare",
    "scalfiamo": "scalfire",
    "scalfiate": "scalfire",
    "scalfii": "scalfire",
    "scalfimmo": "scalfire",
    "scalfin": "scalfare",
    "scalfino": "scalfare",
    "scalfir": "scalfire",
    "scalfirai": "scalfire",
    "scalfiran": "scalfire",
    "scalfiranno": "scalfire",
    "scalfirebbe": "scalfire",
    "scalfirebber": "scalfire",
    "scalfirebbero": "scalfire",
    "scalfirei": "scalfire",
    "scalfiremmo": "scalfire",
    "scalfiremo": "scalfire",
    "scalfireste": "scalfire",
    "scalfiresti": "scalfire",
    "scalfirete": "scalfire",
    "scalfiron": "scalfire",
    "scalfirono": "scalfire",
    "scalfirà": "scalfire",
    "scalfirò": "scalfire",
    "scalfisca": "scalfire",
    "scalfiscan": "scalfire",
    "scalfiscano": "scalfire",
    "scalfisce": "scalfire",
    "scalfisci": "scalfire",
    "scalfisco": "scalfire",
    "scalfiscon": "scalfire",
    "scalfiscono": "scalfire",
    "scalfisse": "scalfire",
    "scalfisser": "scalfire",
    "scalfissero": "scalfire",
    "scalfissi": "scalfire",
    "scalfissimo": "scalfire",
    "scalfiste": "scalfire",
    "scalfisti": "scalfire",
    "scalfita": "scalfire",
    "scalfite": "scalfire",
    "scalfiti": "scalfire",
    "scalfito": "scalfire",
    "scalfitture": "scalfittura",
    "scalfiva": "scalfire",
    "scalfivamo": "scalfire",
    "scalfivan": "scalfire",
    "scalfivano": "scalfire",
    "scalfivate": "scalfire",
    "scalfivi": "scalfire",
    "scalfivo": "scalfire",
    "scalfo": "scalfare",
    "scalfì": "scalfire",
    "scalfò": "scalfare",
    "scali": "scalo",
    "scaliamo": "scalare",
    "scaliate": "scalare",
    "scaligera": "scaligero",
    "scaligere": "scaligero",
    "scaligeri": "scaligero",
    "scalin": "scalare",
    "scalina": "scalinare",
    "scalinai": "scalinare",
    "scalinammo": "scalinare",
    "scalinan": "scalinare",
    "scalinando": "scalinare",
    "scalinano": "scalinare",
    "scalinante": "scalinare",
    "scalinanti": "scalinare",
    "scalinar": "scalinare",
    "scalinaron": "scalinare",
    "scalinarono": "scalinare",
    "scalinasse": "scalinare",
    "scalinasser": "scalinare",
    "scalinassero": "scalinare",
    "scalinassi": "scalinare",
    "scalinassimo": "scalinare",
    "scalinaste": "scalinare",
    "scalinasti": "scalinare",
    "scalinata": "scalinare",
    "scalinate": "scalinata",
    "scalinati": "scalinare",
    "scalinato": "scalinare",
    "scalinava": "scalinare",
    "scalinavamo": "scalinare",
    "scalinavan": "scalinare",
    "scalinavano": "scalinare",
    "scalinavate": "scalinare",
    "scalinavi": "scalinare",
    "scalinavo": "scalinare",
    "scalinerai": "scalinare",
    "scalineran": "scalinare",
    "scalineranno": "scalinare",
    "scalinerebbe": "scalinare",
    "scalinerebber": "scalinare",
    "scalinerebbero": "scalinare",
    "scalinerei": "scalinare",
    "scalineremmo": "scalinare",
    "scalineremo": "scalinare",
    "scalinereste": "scalinare",
    "scalineresti": "scalinare",
    "scalinerete": "scalinare",
    "scalinerà": "scalinare",
    "scalinerò": "scalinare",
    "scalini": "scalino",
    "scaliniamo": "scalinare",
    "scaliniate": "scalinare",
    "scalinin": "scalinare",
    "scalinino": "scalinare",
    "scalino": "scalinare",
    "scalinò": "scalinare",
    "scalmana": "scalmanare",
    "scalmanai": "scalmanare",
    "scalmanammo": "scalmanare",
    "scalmanan": "scalmanare",
    "scalmanando": "scalmanare",
    "scalmanano": "scalmanare",
    "scalmanar": "scalmanare",
    "scalmanaron": "scalmanare",
    "scalmanarono": "scalmanare",
    "scalmanasse": "scalmanare",
    "scalmanasser": "scalmanare",
    "scalmanassero": "scalmanare",
    "scalmanassi": "scalmanare",
    "scalmanassimo": "scalmanare",
    "scalmanaste": "scalmanare",
    "scalmanasti": "scalmanare",
    "scalmanata": "scalmanare",
    "scalmanate": "scalmanare",
    "scalmanati": "scalmanare",
    "scalmanato": "scalmanare",
    "scalmanava": "scalmanare",
    "scalmanavamo": "scalmanare",
    "scalmanavan": "scalmanare",
    "scalmanavano": "scalmanare",
    "scalmanavate": "scalmanare",
    "scalmanavi": "scalmanare",
    "scalmanavo": "scalmanare",
    "scalmanerai": "scalmanare",
    "scalmaneran": "scalmanare",
    "scalmaneranno": "scalmanare",
    "scalmanerebbe": "scalmanare",
    "scalmanerebber": "scalmanare",
    "scalmanerebbero": "scalmanare",
    "scalmanerei": "scalmanare",
    "scalmaneremmo": "scalmanare",
    "scalmaneremo": "scalmanare",
    "scalmanereste": "scalmanare",
    "scalmaneresti": "scalmanare",
    "scalmanerete": "scalmanare",
    "scalmanerà": "scalmanare",
    "scalmanerò": "scalmanare",
    "scalmani": "scalmanare",
    "scalmaniamo": "scalmanare",
    "scalmaniate": "scalmanare",
    "scalmanin": "scalmanare",
    "scalmanino": "scalmanare",
    "scalmano": "scalmanare",
    "scalmanò": "scalmanare",
    "scalo": "scalare",
    "scalognata": "scalognato",
    "scalognate": "scalognato",
    "scalognati": "scalognato",
    "scaloni": "scalone",
    "scalpa": "scalpare",
    "scalpai": "scalpare",
    "scalpammo": "scalpare",
    "scalpan": "scalpare",
    "scalpando": "scalpare",
    "scalpano": "scalpare",
    "scalpante": "scalpare",
    "scalpanti": "scalpare",
    "scalpar": "scalpare",
    "scalparon": "scalpare",
    "scalparono": "scalpare",
    "scalpasse": "scalpare",
    "scalpasser": "scalpare",
    "scalpassero": "scalpare",
    "scalpassi": "scalpare",
    "scalpassimo": "scalpare",
    "scalpaste": "scalpare",
    "scalpasti": "scalpare",
    "scalpata": "scalpare",
    "scalpate": "scalpare",
    "scalpati": "scalpare",
    "scalpato": "scalpare",
    "scalpava": "scalpare",
    "scalpavamo": "scalpare",
    "scalpavan": "scalpare",
    "scalpavano": "scalpare",
    "scalpavate": "scalpare",
    "scalpavi": "scalpare",
    "scalpavo": "scalpare",
    "scalpella": "scalpellare",
    "scalpellai": "scalpellare",
    "scalpellammo": "scalpellare",
    "scalpellan": "scalpellare",
    "scalpellando": "scalpellare",
    "scalpellano": "scalpellare",
    "scalpellante": "scalpellare",
    "scalpellanti": "scalpellare",
    "scalpellar": "scalpellare",
    "scalpellaron": "scalpellare",
    "scalpellarono": "scalpellare",
    "scalpellasse": "scalpellare",
    "scalpellasser": "scalpellare",
    "scalpellassero": "scalpellare",
    "scalpellassi": "scalpellare",
    "scalpellassimo": "scalpellare",
    "scalpellaste": "scalpellare",
    "scalpellasti": "scalpellare",
    "scalpellata": "scalpellare",
    "scalpellate": "scalpellare",
    "scalpellati": "scalpellare",
    "scalpellato": "scalpellare",
    "scalpellava": "scalpellare",
    "scalpellavamo": "scalpellare",
    "scalpellavan": "scalpellare",
    "scalpellavano": "scalpellare",
    "scalpellavate": "scalpellare",
    "scalpellavi": "scalpellare",
    "scalpellavo": "scalpellare",
    "scalpellerai": "scalpellare",
    "scalpelleran": "scalpellare",
    "scalpelleranno": "scalpellare",
    "scalpellerebbe": "scalpellare",
    "scalpellerebber": "scalpellare",
    "scalpellerebbero": "scalpellare",
    "scalpellerei": "scalpellare",
    "scalpelleremmo": "scalpellare",
    "scalpelleremo": "scalpellare",
    "scalpellereste": "scalpellare",
    "scalpelleresti": "scalpellare",
    "scalpellerete": "scalpellare",
    "scalpellerà": "scalpellare",
    "scalpellerò": "scalpellare",
    "scalpelli": "scalpello",
    "scalpelliamo": "scalpellare",
    "scalpelliate": "scalpellare",
    "scalpellin": "scalpellare",
    "scalpellini": "scalpellino",
    "scalpellino": "scalpellare",
    "scalpello": "scalpellare",
    "scalpellò": "scalpellare",
    "scalperai": "scalpare",
    "scalperan": "scalpare",
    "scalperanno": "scalpare",
    "scalperebbe": "scalpare",
    "scalperebber": "scalpare",
    "scalperebbero": "scalpare",
    "scalperei": "scalpare",
    "scalperemmo": "scalpare",
    "scalperemo": "scalpare",
    "scalpereste": "scalpare",
    "scalperesti": "scalpare",
    "scalperete": "scalpare",
    "scalperà": "scalpare",
    "scalperò": "scalpare",
    "scalpi": "scalpo",
    "scalpiamo": "scalpare",
    "scalpiate": "scalpare",
    "scalpiccerai": "scalpicciare",
    "scalpicceran": "scalpicciare",
    "scalpicceranno": "scalpicciare",
    "scalpiccerebbe": "scalpicciare",
    "scalpiccerebber": "scalpicciare",
    "scalpiccerebbero": "scalpicciare",
    "scalpiccerei": "scalpicciare",
    "scalpicceremmo": "scalpicciare",
    "scalpicceremo": "scalpicciare",
    "scalpiccereste": "scalpicciare",
    "scalpicceresti": "scalpicciare",
    "scalpiccerete": "scalpicciare",
    "scalpiccerà": "scalpicciare",
    "scalpiccerò": "scalpicciare",
    "scalpicci": "scalpicciare",
    "scalpiccia": "scalpicciare",
    "scalpicciai": "scalpicciare",
    "scalpicciammo": "scalpicciare",
    "scalpicciamo": "scalpicciare",
    "scalpiccian": "scalpicciare",
    "scalpicciando": "scalpicciare",
    "scalpicciano": "scalpicciare",
    "scalpicciante": "scalpicciare",
    "scalpiccianti": "scalpicciare",
    "scalpicciar": "scalpicciare",
    "scalpicciaron": "scalpicciare",
    "scalpicciarono": "scalpicciare",
    "scalpicciasse": "scalpicciare",
    "scalpicciasser": "scalpicciare",
    "scalpicciassero": "scalpicciare",
    "scalpicciassi": "scalpicciare",
    "scalpicciassimo": "scalpicciare",
    "scalpicciaste": "scalpicciare",
    "scalpicciasti": "scalpicciare",
    "scalpicciata": "scalpicciare",
    "scalpicciate": "scalpicciare",
    "scalpicciati": "scalpicciare",
    "scalpicciato": "scalpicciare",
    "scalpicciava": "scalpicciare",
    "scalpicciavamo": "scalpicciare",
    "scalpicciavan": "scalpicciare",
    "scalpicciavano": "scalpicciare",
    "scalpicciavate": "scalpicciare",
    "scalpicciavi": "scalpicciare",
    "scalpicciavo": "scalpicciare",
    "scalpiccin": "scalpicciare",
    "scalpiccino": "scalpicciare",
    "scalpiccio": "scalpicciare",
    "scalpicciò": "scalpicciare",
    "scalpin": "scalpare",
    "scalpino": "scalpare",
    "scalpita": "scalpitare",
    "scalpitai": "scalpitare",
    "scalpitammo": "scalpitare",
    "scalpitan": "scalpitare",
    "scalpitando": "scalpitare",
    "scalpitano": "scalpitare",
    "scalpitante": "scalpitare",
    "scalpitanti": "scalpitare",
    "scalpitar": "scalpitare",
    "scalpitaron": "scalpitare",
    "scalpitarono": "scalpitare",
    "scalpitasse": "scalpitare",
    "scalpitasser": "scalpitare",
    "scalpitassero": "scalpitare",
    "scalpitassi": "scalpitare",
    "scalpitassimo": "scalpitare",
    "scalpitaste": "scalpitare",
    "scalpitasti": "scalpitare",
    "scalpitata": "scalpitare",
    "scalpitate": "scalpitare",
    "scalpitati": "scalpitare",
    "scalpitato": "scalpitare",
    "scalpitava": "scalpitare",
    "scalpitavamo": "scalpitare",
    "scalpitavan": "scalpitare",
    "scalpitavano": "scalpitare",
    "scalpitavate": "scalpitare",
    "scalpitavi": "scalpitare",
    "scalpitavo": "scalpitare",
    "scalpiterai": "scalpitare",
    "scalpiteran": "scalpitare",
    "scalpiteranno": "scalpitare",
    "scalpiterebbe": "scalpitare",
    "scalpiterebber": "scalpitare",
    "scalpiterebbero": "scalpitare",
    "scalpiterei": "scalpitare",
    "scalpiteremmo": "scalpitare",
    "scalpiteremo": "scalpitare",
    "scalpitereste": "scalpitare",
    "scalpiteresti": "scalpitare",
    "scalpiterete": "scalpitare",
    "scalpiterà": "scalpitare",
    "scalpiterò": "scalpitare",
    "scalpiti": "scalpitare",
    "scalpitiamo": "scalpitare",
    "scalpitiate": "scalpitare",
    "scalpitin": "scalpitare",
    "scalpitino": "scalpitare",
    "scalpito": "scalpitare",
    "scalpitò": "scalpitare",
    "scalpo": "scalpare",
    "scalpori": "scalpore",
    "scalpò": "scalpare",
    "scaltra": "scaltro",
    "scaltran": "scaltrire",
    "scaltrano": "scaltrire",
    "scaltre": "scaltro",
    "scaltrendo": "scaltrire",
    "scaltrente": "scaltrire",
    "scaltrenti": "scaltrire",
    "scaltrezze": "scaltrezza",
    "scaltri": "scaltro",
    "scaltriamo": "scaltrire",
    "scaltriate": "scaltrire",
    "scaltrii": "scaltrire",
    "scaltrimmo": "scaltrire",
    "scaltrir": "scaltrire",
    "scaltrirai": "scaltrire",
    "scaltriran": "scaltrire",
    "scaltriranno": "scaltrire",
    "scaltrirebbe": "scaltrire",
    "scaltrirebber": "scaltrire",
    "scaltrirebbero": "scaltrire",
    "scaltrirei": "scaltrire",
    "scaltriremmo": "scaltrire",
    "scaltriremo": "scaltrire",
    "scaltrireste": "scaltrire",
    "scaltriresti": "scaltrire",
    "scaltrirete": "scaltrire",
    "scaltriron": "scaltrire",
    "scaltrirono": "scaltrire",
    "scaltrirà": "scaltrire",
    "scaltrirò": "scaltrire",
    "scaltrisse": "scaltrire",
    "scaltrisser": "scaltrire",
    "scaltrissero": "scaltrire",
    "scaltrissi": "scaltrire",
    "scaltrissimo": "scaltrire",
    "scaltriste": "scaltrire",
    "scaltristi": "scaltrire",
    "scaltrita": "scaltrire",
    "scaltrite": "scaltrire",
    "scaltriti": "scaltrire",
    "scaltrito": "scaltrire",
    "scaltriva": "scaltrire",
    "scaltrivamo": "scaltrire",
    "scaltrivan": "scaltrire",
    "scaltrivano": "scaltrire",
    "scaltrivate": "scaltrire",
    "scaltrivi": "scaltrire",
    "scaltrivo": "scaltrire",
    "scaltro": "scaltrire",
    "scaltron": "scaltrire",
    "scaltrono": "scaltrire",
    "scaltrì": "scaltrire",
    "scalza": "scalzo",
    "scalzai": "scalzare",
    "scalzammo": "scalzare",
    "scalzan": "scalzare",
    "scalzando": "scalzare",
    "scalzano": "scalzare",
    "scalzante": "scalzare",
    "scalzanti": "scalzare",
    "scalzar": "scalzare",
    "scalzaron": "scalzare",
    "scalzarono": "scalzare",
    "scalzasse": "scalzare",
    "scalzasser": "scalzare",
    "scalzassero": "scalzare",
    "scalzassi": "scalzare",
    "scalzassimo": "scalzare",
    "scalzaste": "scalzare",
    "scalzasti": "scalzare",
    "scalzata": "scalzare",
    "scalzate": "scalzare",
    "scalzati": "scalzare",
    "scalzato": "scalzare",
    "scalzava": "scalzare",
    "scalzavamo": "scalzare",
    "scalzavan": "scalzare",
    "scalzavano": "scalzare",
    "scalzavate": "scalzare",
    "scalzavi": "scalzare",
    "scalzavo": "scalzare",
    "scalze": "scalzo",
    "scalzerai": "scalzare",
    "scalzeran": "scalzare",
    "scalzeranno": "scalzare",
    "scalzerebbe": "scalzare",
    "scalzerebber": "scalzare",
    "scalzerebbero": "scalzare",
    "scalzerei": "scalzare",
    "scalzeremmo": "scalzare",
    "scalzeremo": "scalzare",
    "scalzereste": "scalzare",
    "scalzeresti": "scalzare",
    "scalzerete": "scalzare",
    "scalzerà": "scalzare",
    "scalzerò": "scalzare",
    "scalzi": "scalzo",
    "scalziamo": "scalzare",
    "scalziate": "scalzare",
    "scalzin": "scalzare",
    "scalzino": "scalzare",
    "scalzo": "scalzare",
    "scalzò": "scalzare",
    "scalò": "scalare",
    "scambi": "scambio",
    "scambia": "scambiare",
    "scambiai": "scambiare",
    "scambiammo": "scambiare",
    "scambiamo": "scambiare",
    "scambian": "scambiare",
    "scambiando": "scambiare",
    "scambiano": "scambiare",
    "scambiante": "scambiare",
    "scambianti": "scambiare",
    "scambiar": "scambiare",
    "scambiaron": "scambiare",
    "scambiarono": "scambiare",
    "scambiasse": "scambiare",
    "scambiasser": "scambiare",
    "scambiassero": "scambiare",
    "scambiassi": "scambiare",
    "scambiassimo": "scambiare",
    "scambiaste": "scambiare",
    "scambiasti": "scambiare",
    "scambiata": "scambiare",
    "scambiate": "scambiare",
    "scambiati": "scambiare",
    "scambiato": "scambiare",
    "scambiava": "scambiare",
    "scambiavamo": "scambiare",
    "scambiavan": "scambiare",
    "scambiavano": "scambiare",
    "scambiavate": "scambiare",
    "scambiavi": "scambiare",
    "scambiavo": "scambiare",
    "scambierai": "scambiare",
    "scambieran": "scambiare",
    "scambieranno": "scambiare",
    "scambierebbe": "scambiare",
    "scambierebber": "scambiare",
    "scambierebbero": "scambiare",
    "scambierei": "scambiare",
    "scambieremmo": "scambiare",
    "scambieremo": "scambiare",
    "scambiereste": "scambiare",
    "scambieresti": "scambiare",
    "scambierete": "scambiare",
    "scambierà": "scambiare",
    "scambierò": "scambiare",
    "scambin": "scambiare",
    "scambino": "scambiare",
    "scambio": "scambiare",
    "scambisti": "scambista",
    "scambiò": "scambiare",
    "scamicerai": "scamiciare",
    "scamiceran": "scamiciare",
    "scamiceranno": "scamiciare",
    "scamicerebbe": "scamiciare",
    "scamicerebber": "scamiciare",
    "scamicerebbero": "scamiciare",
    "scamicerei": "scamiciare",
    "scamiceremmo": "scamiciare",
    "scamiceremo": "scamiciare",
    "scamicereste": "scamiciare",
    "scamiceresti": "scamiciare",
    "scamicerete": "scamiciare",
    "scamicerà": "scamiciare",
    "scamicerò": "scamiciare",
    "scamici": "scamiciare",
    "scamicia": "scamiciare",
    "scamiciai": "scamiciare",
    "scamiciammo": "scamiciare",
    "scamiciamo": "scamiciare",
    "scamician": "scamiciare",
    "scamiciando": "scamiciare",
    "scamiciano": "scamiciare",
    "scamiciar": "scamiciare",
    "scamiciaron": "scamiciare",
    "scamiciarono": "scamiciare",
    "scamiciasse": "scamiciare",
    "scamiciasser": "scamiciare",
    "scamiciassero": "scamiciare",
    "scamiciassi": "scamiciare",
    "scamiciassimo": "scamiciare",
    "scamiciaste": "scamiciare",
    "scamiciasti": "scamiciare",
    "scamiciata": "scamiciare",
    "scamiciate": "scamiciare",
    "scamiciati": "scamiciare",
    "scamiciato": "scamiciare",
    "scamiciava": "scamiciare",
    "scamiciavamo": "scamiciare",
    "scamiciavan": "scamiciare",
    "scamiciavano": "scamiciare",
    "scamiciavate": "scamiciare",
    "scamiciavi": "scamiciare",
    "scamiciavo": "scamiciare",
    "scamicin": "scamiciare",
    "scamicino": "scamiciare",
    "scamicio": "scamiciare",
    "scamiciò": "scamiciare",
    "scamoscerai": "scamosciare",
    "scamosceran": "scamosciare",
    "scamosceranno": "scamosciare",
    "scamoscerebbe": "scamosciare",
    "scamoscerebber": "scamosciare",
    "scamoscerebbero": "scamosciare",
    "scamoscerei": "scamosciare",
    "scamosceremmo": "scamosciare",
    "scamosceremo": "scamosciare",
    "scamoscereste": "scamosciare",
    "scamosceresti": "scamosciare",
    "scamoscerete": "scamosciare",
    "scamoscerà": "scamosciare",
    "scamoscerò": "scamosciare",
    "scamosci": "scamosciare",
    "scamoscia": "scamosciare",
    "scamosciai": "scamosciare",
    "scamosciammo": "scamosciare",
    "scamosciamo": "scamosciare",
    "scamoscian": "scamosciare",
    "scamosciando": "scamosciare",
    "scamosciano": "scamosciare",
    "scamosciante": "scamosciare",
    "scamoscianti": "scamosciare",
    "scamosciar": "scamosciare",
    "scamosciaron": "scamosciare",
    "scamosciarono": "scamosciare",
    "scamosciasse": "scamosciare",
    "scamosciasser": "scamosciare",
    "scamosciassero": "scamosciare",
    "scamosciassi": "scamosciare",
    "scamosciassimo": "scamosciare",
    "scamosciaste": "scamosciare",
    "scamosciasti": "scamosciare",
    "scamosciata": "scamosciare",
    "scamosciate": "scamosciare",
    "scamosciati": "scamosciare",
    "scamosciato": "scamosciare",
    "scamosciava": "scamosciare",
    "scamosciavamo": "scamosciare",
    "scamosciavan": "scamosciare",
    "scamosciavano": "scamosciare",
    "scamosciavate": "scamosciare",
    "scamosciavi": "scamosciare",
    "scamosciavo": "scamosciare",
    "scamoscin": "scamosciare",
    "scamoscino": "scamosciare",
    "scamoscio": "scamosciare",
    "scamosciò": "scamosciare",
    "scamozza": "scamozzare",
    "scamozzai": "scamozzare",
    "scamozzammo": "scamozzare",
    "scamozzan": "scamozzare",
    "scamozzando": "scamozzare",
    "scamozzano": "scamozzare",
    "scamozzante": "scamozzare",
    "scamozzanti": "scamozzare",
    "scamozzar": "scamozzare",
    "scamozzaron": "scamozzare",
    "scamozzarono": "scamozzare",
    "scamozzasse": "scamozzare",
    "scamozzasser": "scamozzare",
    "scamozzassero": "scamozzare",
    "scamozzassi": "scamozzare",
    "scamozzassimo": "scamozzare",
    "scamozzaste": "scamozzare",
    "scamozzasti": "scamozzare",
    "scamozzata": "scamozzare",
    "scamozzate": "scamozzare",
    "scamozzati": "scamozzare",
    "scamozzato": "scamozzare",
    "scamozzava": "scamozzare",
    "scamozzavamo": "scamozzare",
    "scamozzavan": "scamozzare",
    "scamozzavano": "scamozzare",
    "scamozzavate": "scamozzare",
    "scamozzavi": "scamozzare",
    "scamozzavo": "scamozzare",
    "scamozzerai": "scamozzare",
    "scamozzeran": "scamozzare",
    "scamozzeranno": "scamozzare",
    "scamozzerebbe": "scamozzare",
    "scamozzerebber": "scamozzare",
    "scamozzerebbero": "scamozzare",
    "scamozzerei": "scamozzare",
    "scamozzeremmo": "scamozzare",
    "scamozzeremo": "scamozzare",
    "scamozzereste": "scamozzare",
    "scamozzeresti": "scamozzare",
    "scamozzerete": "scamozzare",
    "scamozzerà": "scamozzare",
    "scamozzerò": "scamozzare",
    "scamozzi": "scamozzare",
    "scamozziamo": "scamozzare",
    "scamozziate": "scamozzare",
    "scamozzin": "scamozzare",
    "scamozzino": "scamozzare",
    "scamozzo": "scamozzare",
    "scamozzò": "scamozzare",
    "scampa": "scampare",
    "scampagnate": "scampagnata",
    "scampai": "scampare",
    "scampammo": "scampare",
    "scampan": "scampare",
    "scampana": "scampanare",
    "scampanai": "scampanare",
    "scampanammo": "scampanare",
    "scampanan": "scampanare",
    "scampanando": "scampanare",
    "scampanano": "scampanare",
    "scampanante": "scampanare",
    "scampananti": "scampanare",
    "scampanar": "scampanare",
    "scampanaron": "scampanare",
    "scampanarono": "scampanare",
    "scampanasse": "scampanare",
    "scampanasser": "scampanare",
    "scampanassero": "scampanare",
    "scampanassi": "scampanare",
    "scampanassimo": "scampanare",
    "scampanaste": "scampanare",
    "scampanasti": "scampanare",
    "scampanata": "scampanare",
    "scampanate": "scampanare",
    "scampanati": "scampanare",
    "scampanato": "scampanare",
    "scampanava": "scampanare",
    "scampanavamo": "scampanare",
    "scampanavan": "scampanare",
    "scampanavano": "scampanare",
    "scampanavate": "scampanare",
    "scampanavi": "scampanare",
    "scampanavo": "scampanare",
    "scampando": "scampare",
    "scampanella": "scampanellare",
    "scampanellai": "scampanellare",
    "scampanellammo": "scampanellare",
    "scampanellan": "scampanellare",
    "scampanellando": "scampanellare",
    "scampanellano": "scampanellare",
    "scampanellante": "scampanellare",
    "scampanellanti": "scampanellare",
    "scampanellar": "scampanellare",
    "scampanellaron": "scampanellare",
    "scampanellarono": "scampanellare",
    "scampanellasse": "scampanellare",
    "scampanellasser": "scampanellare",
    "scampanellassero": "scampanellare",
    "scampanellassi": "scampanellare",
    "scampanellassimo": "scampanellare",
    "scampanellaste": "scampanellare",
    "scampanellasti": "scampanellare",
    "scampanellata": "scampanellare",
    "scampanellate": "scampanellare",
    "scampanellati": "scampanellare",
    "scampanellato": "scampanellare",
    "scampanellava": "scampanellare",
    "scampanellavamo": "scampanellare",
    "scampanellavan": "scampanellare",
    "scampanellavano": "scampanellare",
    "scampanellavate": "scampanellare",
    "scampanellavi": "scampanellare",
    "scampanellavo": "scampanellare",
    "scampanellerai": "scampanellare",
    "scampanelleran": "scampanellare",
    "scampanelleranno": "scampanellare",
    "scampanellerebbe": "scampanellare",
    "scampanellerebber": "scampanellare",
    "scampanellerebbero": "scampanellare",
    "scampanellerei": "scampanellare",
    "scampanelleremmo": "scampanellare",
    "scampanelleremo": "scampanellare",
    "scampanellereste": "scampanellare",
    "scampanelleresti": "scampanellare",
    "scampanellerete": "scampanellare",
    "scampanellerà": "scampanellare",
    "scampanellerò": "scampanellare",
    "scampanelli": "scampanellare",
    "scampanelliamo": "scampanellare",
    "scampanelliate": "scampanellare",
    "scampanellin": "scampanellare",
    "scampanellino": "scampanellare",
    "scampanello": "scampanellare",
    "scampanellò": "scampanellare",
    "scampanerai": "scampanare",
    "scampaneran": "scampanare",
    "scampaneranno": "scampanare",
    "scampanerebbe": "scampanare",
    "scampanerebber": "scampanare",
    "scampanerebbero": "scampanare",
    "scampanerei": "scampanare",
    "scampaneremmo": "scampanare",
    "scampaneremo": "scampanare",
    "scampanereste": "scampanare",
    "scampaneresti": "scampanare",
    "scampanerete": "scampanare",
    "scampanerà": "scampanare",
    "scampanerò": "scampanare",
    "scampani": "scampanare",
    "scampaniamo": "scampanare",
    "scampaniate": "scampanare",
    "scampanin": "scampanare",
    "scampanino": "scampanare",
    "scampano": "scampare",
    "scampante": "scampare",
    "scampanti": "scampare",
    "scampanò": "scampanare",
    "scampar": "scampare",
    "scamparon": "scampare",
    "scamparono": "scampare",
    "scampasse": "scampare",
    "scampasser": "scampare",
    "scampassero": "scampare",
    "scampassi": "scampare",
    "scampassimo": "scampare",
    "scampaste": "scampare",
    "scampasti": "scampare",
    "scampata": "scampato",
    "scampate": "scampato",
    "scampati": "scampato",
    "scampato": "scampare",
    "scampava": "scampare",
    "scampavamo": "scampare",
    "scampavan": "scampare",
    "scampavano": "scampare",
    "scampavate": "scampare",
    "scampavi": "scampare",
    "scampavo": "scampare",
    "scamperai": "scampare",
    "scamperan": "scampare",
    "scamperanno": "scampare",
    "scamperebbe": "scampare",
    "scamperebber": "scampare",
    "scamperebbero": "scampare",
    "scamperei": "scampare",
    "scamperemmo": "scampare",
    "scamperemo": "scampare",
    "scampereste": "scampare",
    "scamperesti": "scampare",
    "scamperete": "scampare",
    "scamperà": "scampare",
    "scamperò": "scampare",
    "scampi": "scampo",
    "scampiamo": "scampare",
    "scampiate": "scampare",
    "scampin": "scampare",
    "scampino": "scampare",
    "scampo": "scampare",
    "scampoli": "scampolo",
    "scampò": "scampare",
    "scanala": "scanalare",
    "scanalai": "scanalare",
    "scanalammo": "scanalare",
    "scanalan": "scanalare",
    "scanalando": "scanalare",
    "scanalano": "scanalare",
    "scanalante": "scanalare",
    "scanalanti": "scanalare",
    "scanalar": "scanalare",
    "scanalaron": "scanalare",
    "scanalarono": "scanalare",
    "scanalasse": "scanalare",
    "scanalasser": "scanalare",
    "scanalassero": "scanalare",
    "scanalassi": "scanalare",
    "scanalassimo": "scanalare",
    "scanalaste": "scanalare",
    "scanalasti": "scanalare",
    "scanalata": "scanalare",
    "scanalate": "scanalare",
    "scanalati": "scanalare",
    "scanalato": "scanalare",
    "scanalature": "scanalatura",
    "scanalava": "scanalare",
    "scanalavamo": "scanalare",
    "scanalavan": "scanalare",
    "scanalavano": "scanalare",
    "scanalavate": "scanalare",
    "scanalavi": "scanalare",
    "scanalavo": "scanalare",
    "scanalerai": "scanalare",
    "scanaleran": "scanalare",
    "scanaleranno": "scanalare",
    "scanalerebbe": "scanalare",
    "scanalerebber": "scanalare",
    "scanalerebbero": "scanalare",
    "scanalerei": "scanalare",
    "scanaleremmo": "scanalare",
    "scanaleremo": "scanalare",
    "scanalereste": "scanalare",
    "scanaleresti": "scanalare",
    "scanalerete": "scanalare",
    "scanalerà": "scanalare",
    "scanalerò": "scanalare",
    "scanali": "scanalare",
    "scanaliamo": "scanalare",
    "scanaliate": "scanalare",
    "scanalin": "scanalare",
    "scanalino": "scanalare",
    "scanalo": "scanalare",
    "scanalò": "scanalare",
    "scanda": "scandere",
    "scandagli": "scandagliare",
    "scandaglia": "scandagliare",
    "scandagliai": "scandagliare",
    "scandagliammo": "scandagliare",
    "scandagliamo": "scandagliare",
    "scandaglian": "scandagliare",
    "scandagliando": "scandagliare",
    "scandagliano": "scandagliare",
    "scandagliante": "scandagliare",
    "scandaglianti": "scandagliare",
    "scandagliar": "scandagliare",
    "scandagliaron": "scandagliare",
    "scandagliarono": "scandagliare",
    "scandagliasse": "scandagliare",
    "scandagliasser": "scandagliare",
    "scandagliassero": "scandagliare",
    "scandagliassi": "scandagliare",
    "scandagliassimo": "scandagliare",
    "scandagliaste": "scandagliare",
    "scandagliasti": "scandagliare",
    "scandagliata": "scandagliare",
    "scandagliate": "scandagliare",
    "scandagliati": "scandagliare",
    "scandagliato": "scandagliare",
    "scandagliava": "scandagliare",
    "scandagliavamo": "scandagliare",
    "scandagliavan": "scandagliare",
    "scandagliavano": "scandagliare",
    "scandagliavate": "scandagliare",
    "scandagliavi": "scandagliare",
    "scandagliavo": "scandagliare",
    "scandaglierai": "scandagliare",
    "scandaglieran": "scandagliare",
    "scandaglieranno": "scandagliare",
    "scandaglierebbe": "scandagliare",
    "scandaglierebber": "scandagliare",
    "scandaglierebbero": "scandagliare",
    "scandaglierei": "scandagliare",
    "scandaglieremmo": "scandagliare",
    "scandaglieremo": "scandagliare",
    "scandagliereste": "scandagliare",
    "scandaglieresti": "scandagliare",
    "scandaglierete": "scandagliare",
    "scandaglierà": "scandagliare",
    "scandaglierò": "scandagliare",
    "scandaglii": "scandaglio",
    "scandaglin": "scandagliare",
    "scandaglino": "scandagliare",
    "scandaglio": "scandagliare",
    "scandagliò": "scandagliare",
    "scandaletti": "scandaletto",
    "scandali": "scandalo",
    "scandalismi": "scandalismo",
    "scandalistica": "scandalistico",
    "scandalistiche": "scandalistico",
    "scandalistici": "scandalistico",
    "scandalizza": "scandalizzare",
    "scandalizzai": "scandalizzare",
    "scandalizzammo": "scandalizzare",
    "scandalizzan": "scandalizzare",
    "scandalizzando": "scandalizzare",
    "scandalizzano": "scandalizzare",
    "scandalizzante": "scandalizzare",
    "scandalizzanti": "scandalizzare",
    "scandalizzar": "scandalizzare",
    "scandalizzaron": "scandalizzare",
    "scandalizzarono": "scandalizzare",
    "scandalizzasse": "scandalizzare",
    "scandalizzasser": "scandalizzare",
    "scandalizzassero": "scandalizzare",
    "scandalizzassi": "scandalizzare",
    "scandalizzassimo": "scandalizzare",
    "scandalizzaste": "scandalizzare",
    "scandalizzasti": "scandalizzare",
    "scandalizzata": "scandalizzare",
    "scandalizzate": "scandalizzare",
    "scandalizzati": "scandalizzare",
    "scandalizzato": "scandalizzare",
    "scandalizzava": "scandalizzare",
    "scandalizzavamo": "scandalizzare",
    "scandalizzavan": "scandalizzare",
    "scandalizzavano": "scandalizzare",
    "scandalizzavate": "scandalizzare",
    "scandalizzavi": "scandalizzare",
    "scandalizzavo": "scandalizzare",
    "scandalizzerai": "scandalizzare",
    "scandalizzeran": "scandalizzare",
    "scandalizzeranno": "scandalizzare",
    "scandalizzerebbe": "scandalizzare",
    "scandalizzerebber": "scandalizzare",
    "scandalizzerebbero": "scandalizzare",
    "scandalizzerei": "scandalizzare",
    "scandalizzeremmo": "scandalizzare",
    "scandalizzeremo": "scandalizzare",
    "scandalizzereste": "scandalizzare",
    "scandalizzeresti": "scandalizzare",
    "scandalizzerete": "scandalizzare",
    "scandalizzerà": "scandalizzare",
    "scandalizzerò": "scandalizzare",
    "scandalizzi": "scandalizzare",
    "scandalizziamo": "scandalizzare",
    "scandalizziate": "scandalizzare",
    "scandalizzin": "scandalizzare",
    "scandalizzino": "scandalizzare",
    "scandalizzo": "scandalizzare",
    "scandalizzò": "scandalizzare",
    "scandalosa": "scandaloso",
    "scandalose": "scandaloso",
    "scandalosi": "scandaloso",
    "scandan": "scandere",
    "scandano": "scandere",
    "scande": "scandere",
    "scandemmo": "scandere",
    "scandendo": "scandire",
    "scandente": "scandire",
    "scandenti": "scandire",
    "scandenze": "scandenza",
    "scander": "scandere",
    "scanderai": "scandere",
    "scanderan": "scandere",
    "scanderanno": "scandere",
    "scanderebbe": "scandere",
    "scanderebber": "scandere",
    "scanderebbero": "scandere",
    "scanderei": "scandere",
    "scanderemmo": "scandere",
    "scanderemo": "scandere",
    "scandereste": "scandere",
    "scanderesti": "scandere",
    "scanderete": "scandere",
    "scanderà": "scandere",
    "scanderò": "scandere",
    "scandesse": "scandere",
    "scandesser": "scandere",
    "scandessero": "scandere",
    "scandessi": "scandere",
    "scandessimo": "scandere",
    "scandeste": "scandere",
    "scandesti": "scandere",
    "scandete": "scandere",
    "scandeva": "scandere",
    "scandevamo": "scandere",
    "scandevan": "scandere",
    "scandevano": "scandere",
    "scandevate": "scandere",
    "scandevi": "scandere",
    "scandevo": "scandere",
    "scandi": "scandere",
    "scandiamo": "scandire",
    "scandiate": "scandire",
    "scandii": "scandire",
    "scandimmo": "scandire",
    "scandinava": "scandinavo",
    "scandinave": "scandinavo",
    "scandinavi": "scandinavo",
    "scandir": "scandire",
    "scandirai": "scandire",
    "scandiran": "scandire",
    "scandiranno": "scandire",
    "scandirebbe": "scandire",
    "scandirebber": "scandire",
    "scandirebbero": "scandire",
    "scandirei": "scandire",
    "scandiremmo": "scandire",
    "scandiremo": "scandire",
    "scandireste": "scandire",
    "scandiresti": "scandire",
    "scandirete": "scandire",
    "scandiron": "scandire",
    "scandirono": "scandire",
    "scandirà": "scandire",
    "scandirò": "scandire",
    "scandisca": "scandire",
    "scandiscan": "scandire",
    "scandiscano": "scandire",
    "scandisce": "scandire",
    "scandisci": "scandire",
    "scandisco": "scandire",
    "scandiscon": "scandire",
    "scandiscono": "scandire",
    "scandisse": "scandire",
    "scandisser": "scandire",
    "scandissero": "scandire",
    "scandissi": "scandire",
    "scandissimo": "scandire",
    "scandiste": "scandire",
    "scandisti": "scandire",
    "scandita": "scandire",
    "scandite": "scandire",
    "scanditi": "scandire",
    "scandito": "scandire",
    "scandiva": "scandire",
    "scandivamo": "scandire",
    "scandivan": "scandire",
    "scandivano": "scandire",
    "scandivate": "scandire",
    "scandivi": "scandire",
    "scandivo": "scandire",
    "scando": "scandere",
    "scandon": "scandere",
    "scandono": "scandere",
    "scanduta": "scandere",
    "scandute": "scandere",
    "scanduti": "scandere",
    "scanduto": "scandere",
    "scandì": "scandire",
    "scanna": "scannare",
    "scannai": "scannare",
    "scannammo": "scannare",
    "scannan": "scannare",
    "scannando": "scannare",
    "scannano": "scannare",
    "scannante": "scannare",
    "scannanti": "scannare",
    "scannar": "scannare",
    "scannaron": "scannare",
    "scannarono": "scannare",
    "scannasse": "scannare",
    "scannasser": "scannare",
    "scannassero": "scannare",
    "scannassi": "scannare",
    "scannassimo": "scannare",
    "scannaste": "scannare",
    "scannasti": "scannare",
    "scannata": "scannare",
    "scannate": "scannare",
    "scannati": "scannare",
    "scannato": "scannare",
    "scannava": "scannare",
    "scannavamo": "scannare",
    "scannavan": "scannare",
    "scannavano": "scannare",
    "scannavate": "scannare",
    "scannavi": "scannare",
    "scannavo": "scannare",
    "scannella": "scannellare",
    "scannellai": "scannellare",
    "scannellammo": "scannellare",
    "scannellan": "scannellare",
    "scannellando": "scannellare",
    "scannellano": "scannellare",
    "scannellante": "scannellare",
    "scannellanti": "scannellare",
    "scannellar": "scannellare",
    "scannellaron": "scannellare",
    "scannellarono": "scannellare",
    "scannellasse": "scannellare",
    "scannellasser": "scannellare",
    "scannellassero": "scannellare",
    "scannellassi": "scannellare",
    "scannellassimo": "scannellare",
    "scannellaste": "scannellare",
    "scannellasti": "scannellare",
    "scannellata": "scannellare",
    "scannellate": "scannellare",
    "scannellati": "scannellare",
    "scannellato": "scannellare",
    "scannellava": "scannellare",
    "scannellavamo": "scannellare",
    "scannellavan": "scannellare",
    "scannellavano": "scannellare",
    "scannellavate": "scannellare",
    "scannellavi": "scannellare",
    "scannellavo": "scannellare",
    "scannellerai": "scannellare",
    "scannelleran": "scannellare",
    "scannelleranno": "scannellare",
    "scannellerebbe": "scannellare",
    "scannellerebber": "scannellare",
    "scannellerebbero": "scannellare",
    "scannellerei": "scannellare",
    "scannelleremmo": "scannellare",
    "scannelleremo": "scannellare",
    "scannellereste": "scannellare",
    "scannelleresti": "scannellare",
    "scannellerete": "scannellare",
    "scannellerà": "scannellare",
    "scannellerò": "scannellare",
    "scannelli": "scannellare",
    "scannelliamo": "scannellare",
    "scannelliate": "scannellare",
    "scannellin": "scannellare",
    "scannellino": "scannellare",
    "scannello": "scannellare",
    "scannellò": "scannellare",
    "scannerai": "scannare",
    "scanneran": "scannare",
    "scanneranno": "scannare",
    "scannerebbe": "scannare",
    "scannerebber": "scannare",
    "scannerebbero": "scannare",
    "scannerei": "scannare",
    "scanneremmo": "scannare",
    "scanneremo": "scannare",
    "scannereste": "scannare",
    "scanneresti": "scannare",
    "scannerete": "scannare",
    "scannerà": "scannare",
    "scannerò": "scannare",
    "scanni": "scanno",
    "scanniamo": "scannare",
    "scanniate": "scannare",
    "scannin": "scannare",
    "scannino": "scannare",
    "scanno": "scannare",
    "scannò": "scannare",
    "scansa": "scansare",
    "scansai": "scansare",
    "scansammo": "scansare",
    "scansan": "scansare",
    "scansando": "scansare",
    "scansano": "scansare",
    "scansante": "scansare",
    "scansanti": "scansare",
    "scansar": "scansare",
    "scansaron": "scansare",
    "scansarono": "scansare",
    "scansasse": "scansare",
    "scansasser": "scansare",
    "scansassero": "scansare",
    "scansassi": "scansare",
    "scansassimo": "scansare",
    "scansaste": "scansare",
    "scansasti": "scansare",
    "scansata": "scansare",
    "scansate": "scansare",
    "scansati": "scansare",
    "scansato": "scansare",
    "scansava": "scansare",
    "scansavamo": "scansare",
    "scansavan": "scansare",
    "scansavano": "scansare",
    "scansavate": "scansare",
    "scansavi": "scansare",
    "scansavo": "scansare",
    "scanserai": "scansare",
    "scanseran": "scansare",
    "scanseranno": "scansare",
    "scanserebbe": "scansare",
    "scanserebber": "scansare",
    "scanserebbero": "scansare",
    "scanserei": "scansare",
    "scanseremmo": "scansare",
    "scanseremo": "scansare",
    "scansereste": "scansare",
    "scanseresti": "scansare",
    "scanserete": "scansare",
    "scanserà": "scansare",
    "scanserò": "scansare",
    "scansi": "scansare",
    "scansiamo": "scansare",
    "scansiate": "scansare",
    "scansie": "scansia",
    "scansin": "scansare",
    "scansino": "scansare",
    "scansioni": "scansione",
    "scanso": "scansare",
    "scansò": "scansare",
    "scantina": "scantinare",
    "scantinai": "scantinare",
    "scantinammo": "scantinare",
    "scantinan": "scantinare",
    "scantinando": "scantinare",
    "scantinano": "scantinare",
    "scantinante": "scantinare",
    "scantinanti": "scantinare",
    "scantinar": "scantinare",
    "scantinaron": "scantinare",
    "scantinarono": "scantinare",
    "scantinasse": "scantinare",
    "scantinasser": "scantinare",
    "scantinassero": "scantinare",
    "scantinassi": "scantinare",
    "scantinassimo": "scantinare",
    "scantinaste": "scantinare",
    "scantinasti": "scantinare",
    "scantinata": "scantinare",
    "scantinate": "scantinare",
    "scantinati": "scantinato",
    "scantinato": "scantinare",
    "scantinava": "scantinare",
    "scantinavamo": "scantinare",
    "scantinavan": "scantinare",
    "scantinavano": "scantinare",
    "scantinavate": "scantinare",
    "scantinavi": "scantinare",
    "scantinavo": "scantinare",
    "scantinerai": "scantinare",
    "scantineran": "scantinare",
    "scantineranno": "scantinare",
    "scantinerebbe": "scantinare",
    "scantinerebber": "scantinare",
    "scantinerebbero": "scantinare",
    "scantinerei": "scantinare",
    "scantineremmo": "scantinare",
    "scantineremo": "scantinare",
    "scantinereste": "scantinare",
    "scantineresti": "scantinare",
    "scantinerete": "scantinare",
    "scantinerà": "scantinare",
    "scantinerò": "scantinare",
    "scantini": "scantinare",
    "scantiniamo": "scantinare",
    "scantiniate": "scantinare",
    "scantinin": "scantinare",
    "scantinino": "scantinare",
    "scantino": "scantinare",
    "scantinò": "scantinare",
    "scantona": "scantonare",
    "scantonai": "scantonare",
    "scantonammo": "scantonare",
    "scantonan": "scantonare",
    "scantonando": "scantonare",
    "scantonano": "scantonare",
    "scantonante": "scantonare",
    "scantonanti": "scantonare",
    "scantonar": "scantonare",
    "scantonaron": "scantonare",
    "scantonarono": "scantonare",
    "scantonasse": "scantonare",
    "scantonasser": "scantonare",
    "scantonassero": "scantonare",
    "scantonassi": "scantonare",
    "scantonassimo": "scantonare",
    "scantonaste": "scantonare",
    "scantonasti": "scantonare",
    "scantonata": "scantonare",
    "scantonate": "scantonare",
    "scantonati": "scantonare",
    "scantonato": "scantonare",
    "scantonava": "scantonare",
    "scantonavamo": "scantonare",
    "scantonavan": "scantonare",
    "scantonavano": "scantonare",
    "scantonavate": "scantonare",
    "scantonavi": "scantonare",
    "scantonavo": "scantonare",
    "scantonerai": "scantonare",
    "scantoneran": "scantonare",
    "scantoneranno": "scantonare",
    "scantonerebbe": "scantonare",
    "scantonerebber": "scantonare",
    "scantonerebbero": "scantonare",
    "scantonerei": "scantonare",
    "scantoneremmo": "scantonare",
    "scantoneremo": "scantonare",
    "scantonereste": "scantonare",
    "scantoneresti": "scantonare",
    "scantonerete": "scantonare",
    "scantonerà": "scantonare",
    "scantonerò": "scantonare",
    "scantoni": "scantonare",
    "scantoniamo": "scantonare",
    "scantoniate": "scantonare",
    "scantonin": "scantonare",
    "scantonino": "scantonare",
    "scantono": "scantonare",
    "scantonò": "scantonare",
    "scanzonata": "scanzonato",
    "scanzonate": "scanzonato",
    "scanzonati": "scanzonato",
    "scapestrata": "scapestrato",
    "scapestrate": "scapestrato",
    "scapestrati": "scapestrato",
    "scapicolla": "scapicollare",
    "scapicollai": "scapicollare",
    "scapicollammo": "scapicollare",
    "scapicollan": "scapicollare",
    "scapicollando": "scapicollare",
    "scapicollano": "scapicollare",
    "scapicollar": "scapicollare",
    "scapicollaron": "scapicollare",
    "scapicollarono": "scapicollare",
    "scapicollasse": "scapicollare",
    "scapicollasser": "scapicollare",
    "scapicollassero": "scapicollare",
    "scapicollassi": "scapicollare",
    "scapicollassimo": "scapicollare",
    "scapicollaste": "scapicollare",
    "scapicollasti": "scapicollare",
    "scapicollata": "scapicollare",
    "scapicollate": "scapicollare",
    "scapicollati": "scapicollare",
    "scapicollato": "scapicollare",
    "scapicollava": "scapicollare",
    "scapicollavamo": "scapicollare",
    "scapicollavan": "scapicollare",
    "scapicollavano": "scapicollare",
    "scapicollavate": "scapicollare",
    "scapicollavi": "scapicollare",
    "scapicollavo": "scapicollare",
    "scapicollerai": "scapicollare",
    "scapicolleran": "scapicollare",
    "scapicolleranno": "scapicollare",
    "scapicollerebbe": "scapicollare",
    "scapicollerebber": "scapicollare",
    "scapicollerebbero": "scapicollare",
    "scapicollerei": "scapicollare",
    "scapicolleremmo": "scapicollare",
    "scapicolleremo": "scapicollare",
    "scapicollereste": "scapicollare",
    "scapicolleresti": "scapicollare",
    "scapicollerete": "scapicollare",
    "scapicollerà": "scapicollare",
    "scapicollerò": "scapicollare",
    "scapicolli": "scapicollare",
    "scapicolliamo": "scapicollare",
    "scapicolliate": "scapicollare",
    "scapicollin": "scapicollare",
    "scapicollino": "scapicollare",
    "scapicollo": "scapicollare",
    "scapicollò": "scapicollare",
    "scapigli": "scapigliare",
    "scapiglia": "scapigliare",
    "scapigliai": "scapigliare",
    "scapigliammo": "scapigliare",
    "scapigliamo": "scapigliare",
    "scapiglian": "scapigliare",
    "scapigliando": "scapigliare",
    "scapigliano": "scapigliare",
    "scapigliante": "scapigliare",
    "scapiglianti": "scapigliare",
    "scapigliar": "scapigliare",
    "scapigliaron": "scapigliare",
    "scapigliarono": "scapigliare",
    "scapigliasse": "scapigliare",
    "scapigliasser": "scapigliare",
    "scapigliassero": "scapigliare",
    "scapigliassi": "scapigliare",
    "scapigliassimo": "scapigliare",
    "scapigliaste": "scapigliare",
    "scapigliasti": "scapigliare",
    "scapigliata": "scapigliato",
    "scapigliate": "scapigliato",
    "scapigliati": "scapigliato",
    "scapigliato": "scapigliare",
    "scapigliava": "scapigliare",
    "scapigliavamo": "scapigliare",
    "scapigliavan": "scapigliare",
    "scapigliavano": "scapigliare",
    "scapigliavate": "scapigliare",
    "scapigliavi": "scapigliare",
    "scapigliavo": "scapigliare",
    "scapiglierai": "scapigliare",
    "scapiglieran": "scapigliare",
    "scapiglieranno": "scapigliare",
    "scapiglierebbe": "scapigliare",
    "scapiglierebber": "scapigliare",
    "scapiglierebbero": "scapigliare",
    "scapiglierei": "scapigliare",
    "scapiglieremmo": "scapigliare",
    "scapiglieremo": "scapigliare",
    "scapigliereste": "scapigliare",
    "scapiglieresti": "scapigliare",
    "scapiglierete": "scapigliare",
    "scapiglierà": "scapigliare",
    "scapiglierò": "scapigliare",
    "scapiglin": "scapigliare",
    "scapiglino": "scapigliare",
    "scapiglio": "scapigliare",
    "scapigliò": "scapigliare",
    "scapita": "scapitare",
    "scapitai": "scapitare",
    "scapitammo": "scapitare",
    "scapitan": "scapitare",
    "scapitando": "scapitare",
    "scapitano": "scapitare",
    "scapitante": "scapitare",
    "scapitanti": "scapitare",
    "scapitar": "scapitare",
    "scapitaron": "scapitare",
    "scapitarono": "scapitare",
    "scapitasse": "scapitare",
    "scapitasser": "scapitare",
    "scapitassero": "scapitare",
    "scapitassi": "scapitare",
    "scapitassimo": "scapitare",
    "scapitaste": "scapitare",
    "scapitasti": "scapitare",
    "scapitata": "scapitare",
    "scapitate": "scapitare",
    "scapitati": "scapitare",
    "scapitato": "scapitare",
    "scapitava": "scapitare",
    "scapitavamo": "scapitare",
    "scapitavan": "scapitare",
    "scapitavano": "scapitare",
    "scapitavate": "scapitare",
    "scapitavi": "scapitare",
    "scapitavo": "scapitare",
    "scapiterai": "scapitare",
    "scapiteran": "scapitare",
    "scapiteranno": "scapitare",
    "scapiterebbe": "scapitare",
    "scapiterebber": "scapitare",
    "scapiterebbero": "scapitare",
    "scapiterei": "scapitare",
    "scapiteremmo": "scapitare",
    "scapiteremo": "scapitare",
    "scapitereste": "scapitare",
    "scapiteresti": "scapitare",
    "scapiterete": "scapitare",
    "scapiterà": "scapitare",
    "scapiterò": "scapitare",
    "scapiti": "scapitare",
    "scapitiamo": "scapitare",
    "scapitiate": "scapitare",
    "scapitin": "scapitare",
    "scapitino": "scapitare",
    "scapito": "scapitare",
    "scapitozza": "scapitozzare",
    "scapitozzai": "scapitozzare",
    "scapitozzammo": "scapitozzare",
    "scapitozzan": "scapitozzare",
    "scapitozzando": "scapitozzare",
    "scapitozzano": "scapitozzare",
    "scapitozzante": "scapitozzare",
    "scapitozzanti": "scapitozzare",
    "scapitozzar": "scapitozzare",
    "scapitozzaron": "scapitozzare",
    "scapitozzarono": "scapitozzare",
    "scapitozzasse": "scapitozzare",
    "scapitozzasser": "scapitozzare",
    "scapitozzassero": "scapitozzare",
    "scapitozzassi": "scapitozzare",
    "scapitozzassimo": "scapitozzare",
    "scapitozzaste": "scapitozzare",
    "scapitozzasti": "scapitozzare",
    "scapitozzata": "scapitozzare",
    "scapitozzate": "scapitozzare",
    "scapitozzati": "scapitozzare",
    "scapitozzato": "scapitozzare",
    "scapitozzava": "scapitozzare",
    "scapitozzavamo": "scapitozzare",
    "scapitozzavan": "scapitozzare",
    "scapitozzavano": "scapitozzare",
    "scapitozzavate": "scapitozzare",
    "scapitozzavi": "scapitozzare",
    "scapitozzavo": "scapitozzare",
    "scapitozzerai": "scapitozzare",
    "scapitozzeran": "scapitozzare",
    "scapitozzeranno": "scapitozzare",
    "scapitozzerebbe": "scapitozzare",
    "scapitozzerebber": "scapitozzare",
    "scapitozzerebbero": "scapitozzare",
    "scapitozzerei": "scapitozzare",
    "scapitozzeremmo": "scapitozzare",
    "scapitozzeremo": "scapitozzare",
    "scapitozzereste": "scapitozzare",
    "scapitozzeresti": "scapitozzare",
    "scapitozzerete": "scapitozzare",
    "scapitozzerà": "scapitozzare",
    "scapitozzerò": "scapitozzare",
    "scapitozzi": "scapitozzare",
    "scapitozziamo": "scapitozzare",
    "scapitozziate": "scapitozzare",
    "scapitozzin": "scapitozzare",
    "scapitozzino": "scapitozzare",
    "scapitozzo": "scapitozzare",
    "scapitozzò": "scapitozzare",
    "scapitò": "scapitare",
    "scapola": "scapolo",
    "scapolai": "scapolare",
    "scapolammo": "scapolare",
    "scapolan": "scapolare",
    "scapolando": "scapolare",
    "scapolano": "scapolare",
    "scapolante": "scapolare",
    "scapolanti": "scapolare",
    "scapolar": "scapolare",
    "scapolaron": "scapolare",
    "scapolarono": "scapolare",
    "scapolasse": "scapolare",
    "scapolasser": "scapolare",
    "scapolassero": "scapolare",
    "scapolassi": "scapolare",
    "scapolassimo": "scapolare",
    "scapolaste": "scapolare",
    "scapolasti": "scapolare",
    "scapolata": "scapolare",
    "scapolate": "scapolare",
    "scapolati": "scapolare",
    "scapolato": "scapolare",
    "scapolava": "scapolare",
    "scapolavamo": "scapolare",
    "scapolavan": "scapolare",
    "scapolavano": "scapolare",
    "scapolavate": "scapolare",
    "scapolavi": "scapolare",
    "scapolavo": "scapolare",
    "scapole": "scapolo",
    "scapolerai": "scapolare",
    "scapoleran": "scapolare",
    "scapoleranno": "scapolare",
    "scapolerebbe": "scapolare",
    "scapolerebber": "scapolare",
    "scapolerebbero": "scapolare",
    "scapolerei": "scapolare",
    "scapoleremmo": "scapolare",
    "scapoleremo": "scapolare",
    "scapolereste": "scapolare",
    "scapoleresti": "scapolare",
    "scapolerete": "scapolare",
    "scapolerà": "scapolare",
    "scapolerò": "scapolare",
    "scapoli": "scapolo",
    "scapoliamo": "scapolare",
    "scapoliate": "scapolare",
    "scapolin": "scapolare",
    "scapolino": "scapolare",
    "scapolo": "scapolare",
    "scapolò": "scapolare",
    "scappa": "scappare",
    "scappai": "scappare",
    "scappamenti": "scappamento",
    "scappammo": "scappare",
    "scappan": "scappare",
    "scappando": "scappare",
    "scappano": "scappare",
    "scappante": "scappare",
    "scappanti": "scappare",
    "scappar": "scappare",
    "scapparon": "scappare",
    "scapparono": "scappare",
    "scappasse": "scappare",
    "scappasser": "scappare",
    "scappassero": "scappare",
    "scappassi": "scappare",
    "scappassimo": "scappare",
    "scappaste": "scappare",
    "scappasti": "scappare",
    "scappata": "scappare",
    "scappate": "scappare",
    "scappatelle": "scappatella",
    "scappati": "scappare",
    "scappato": "scappare",
    "scappatoie": "scappatoia",
    "scappava": "scappare",
    "scappavamo": "scappare",
    "scappavan": "scappare",
    "scappavano": "scappare",
    "scappavate": "scappare",
    "scappavi": "scappare",
    "scappavo": "scappare",
    "scappella": "scappellare",
    "scappellai": "scappellare",
    "scappellammo": "scappellare",
    "scappellan": "scappellare",
    "scappellando": "scappellare",
    "scappellano": "scappellare",
    "scappellante": "scappellare",
    "scappellanti": "scappellare",
    "scappellar": "scappellare",
    "scappellaron": "scappellare",
    "scappellarono": "scappellare",
    "scappellasse": "scappellare",
    "scappellasser": "scappellare",
    "scappellassero": "scappellare",
    "scappellassi": "scappellare",
    "scappellassimo": "scappellare",
    "scappellaste": "scappellare",
    "scappellasti": "scappellare",
    "scappellata": "scappellare",
    "scappellate": "scappellare",
    "scappellati": "scappellare",
    "scappellato": "scappellare",
    "scappellava": "scappellare",
    "scappellavamo": "scappellare",
    "scappellavan": "scappellare",
    "scappellavano": "scappellare",
    "scappellavate": "scappellare",
    "scappellavi": "scappellare",
    "scappellavo": "scappellare",
    "scappellerai": "scappellare",
    "scappelleran": "scappellare",
    "scappelleranno": "scappellare",
    "scappellerebbe": "scappellare",
    "scappellerebber": "scappellare",
    "scappellerebbero": "scappellare",
    "scappellerei": "scappellare",
    "scappelleremmo": "scappellare",
    "scappelleremo": "scappellare",
    "scappellereste": "scappellare",
    "scappelleresti": "scappellare",
    "scappellerete": "scappellare",
    "scappellerà": "scappellare",
    "scappellerò": "scappellare",
    "scappelli": "scappellare",
    "scappelliamo": "scappellare",
    "scappelliate": "scappellare",
    "scappellin": "scappellare",
    "scappellino": "scappellare",
    "scappello": "scappellare",
    "scappellò": "scappellare",
    "scapperai": "scappare",
    "scapperan": "scappare",
    "scapperanno": "scappare",
    "scapperebbe": "scappare",
    "scapperebber": "scappare",
    "scapperebbero": "scappare",
    "scapperei": "scappare",
    "scapperemmo": "scappare",
    "scapperemo": "scappare",
    "scappereste": "scappare",
    "scapperesti": "scappare",
    "scapperete": "scappare",
    "scapperà": "scappare",
    "scapperò": "scappare",
    "scappi": "scappare",
    "scappiamo": "scappare",
    "scappiate": "scappare",
    "scappin": "scappare",
    "scappino": "scappare",
    "scappo": "scappare",
    "scappò": "scappare",
    "scapriccerai": "scapricciare",
    "scapricceran": "scapricciare",
    "scapricceranno": "scapricciare",
    "scapriccerebbe": "scapricciare",
    "scapriccerebber": "scapricciare",
    "scapriccerebbero": "scapricciare",
    "scapriccerei": "scapricciare",
    "scapricceremmo": "scapricciare",
    "scapricceremo": "scapricciare",
    "scapriccereste": "scapricciare",
    "scapricceresti": "scapricciare",
    "scapriccerete": "scapricciare",
    "scapriccerà": "scapricciare",
    "scapriccerò": "scapricciare",
    "scapricci": "scapricciare",
    "scapriccia": "scapricciare",
    "scapricciai": "scapricciare",
    "scapricciammo": "scapricciare",
    "scapricciamo": "scapricciare",
    "scapriccian": "scapricciare",
    "scapricciando": "scapricciare",
    "scapricciano": "scapricciare",
    "scapricciante": "scapricciare",
    "scapriccianti": "scapricciare",
    "scapricciar": "scapricciare",
    "scapricciaron": "scapricciare",
    "scapricciarono": "scapricciare",
    "scapricciasse": "scapricciare",
    "scapricciasser": "scapricciare",
    "scapricciassero": "scapricciare",
    "scapricciassi": "scapricciare",
    "scapricciassimo": "scapricciare",
    "scapricciaste": "scapricciare",
    "scapricciasti": "scapricciare",
    "scapricciata": "scapricciare",
    "scapricciate": "scapricciare",
    "scapricciati": "scapricciare",
    "scapricciato": "scapricciare",
    "scapricciava": "scapricciare",
    "scapricciavamo": "scapricciare",
    "scapricciavan": "scapricciare",
    "scapricciavano": "scapricciare",
    "scapricciavate": "scapricciare",
    "scapricciavi": "scapricciare",
    "scapricciavo": "scapricciare",
    "scapriccin": "scapricciare",
    "scapriccino": "scapricciare",
    "scapriccio": "scapricciare",
    "scapricciò": "scapricciare",
    "scarabei": "scarabeo",
    "scarabocchi": "scarabocchio",
    "scarabocchia": "scarabocchiare",
    "scarabocchiai": "scarabocchiare",
    "scarabocchiammo": "scarabocchiare",
    "scarabocchiamo": "scarabocchiare",
    "scarabocchian": "scarabocchiare",
    "scarabocchiando": "scarabocchiare",
    "scarabocchiano": "scarabocchiare",
    "scarabocchiante": "scarabocchiare",
    "scarabocchianti": "scarabocchiare",
    "scarabocchiar": "scarabocchiare",
    "scarabocchiaron": "scarabocchiare",
    "scarabocchiarono": "scarabocchiare",
    "scarabocchiasse": "scarabocchiare",
    "scarabocchiasser": "scarabocchiare",
    "scarabocchiassero": "scarabocchiare",
    "scarabocchiassi": "scarabocchiare",
    "scarabocchiassimo": "scarabocchiare",
    "scarabocchiaste": "scarabocchiare",
    "scarabocchiasti": "scarabocchiare",
    "scarabocchiata": "scarabocchiare",
    "scarabocchiate": "scarabocchiare",
    "scarabocchiati": "scarabocchiare",
    "scarabocchiato": "scarabocchiare",
    "scarabocchiava": "scarabocchiare",
    "scarabocchiavamo": "scarabocchiare",
    "scarabocchiavan": "scarabocchiare",
    "scarabocchiavano": "scarabocchiare",
    "scarabocchiavate": "scarabocchiare",
    "scarabocchiavi": "scarabocchiare",
    "scarabocchiavo": "scarabocchiare",
    "scarabocchierai": "scarabocchiare",
    "scarabocchieran": "scarabocchiare",
    "scarabocchieranno": "scarabocchiare",
    "scarabocchierebbe": "scarabocchiare",
    "scarabocchierebber": "scarabocchiare",
    "scarabocchierebbero": "scarabocchiare",
    "scarabocchierei": "scarabocchiare",
    "scarabocchieremmo": "scarabocchiare",
    "scarabocchieremo": "scarabocchiare",
    "scarabocchiereste": "scarabocchiare",
    "scarabocchieresti": "scarabocchiare",
    "scarabocchierete": "scarabocchiare",
    "scarabocchierà": "scarabocchiare",
    "scarabocchierò": "scarabocchiare",
    "scarabocchin": "scarabocchiare",
    "scarabocchino": "scarabocchiare",
    "scarabocchio": "scarabocchiare",
    "scarabocchiò": "scarabocchiare",
    "scaracchi": "scaracchiare",
    "scaracchia": "scaracchiare",
    "scaracchiai": "scaracchiare",
    "scaracchiammo": "scaracchiare",
    "scaracchiamo": "scaracchiare",
    "scaracchian": "scaracchiare",
    "scaracchiando": "scaracchiare",
    "scaracchiano": "scaracchiare",
    "scaracchiante": "scaracchiare",
    "scaracchianti": "scaracchiare",
    "scaracchiar": "scaracchiare",
    "scaracchiaron": "scaracchiare",
    "scaracchiarono": "scaracchiare",
    "scaracchiasse": "scaracchiare",
    "scaracchiasser": "scaracchiare",
    "scaracchiassero": "scaracchiare",
    "scaracchiassi": "scaracchiare",
    "scaracchiassimo": "scaracchiare",
    "scaracchiaste": "scaracchiare",
    "scaracchiasti": "scaracchiare",
    "scaracchiata": "scaracchiare",
    "scaracchiate": "scaracchiare",
    "scaracchiati": "scaracchiare",
    "scaracchiato": "scaracchiare",
    "scaracchiava": "scaracchiare",
    "scaracchiavamo": "scaracchiare",
    "scaracchiavan": "scaracchiare",
    "scaracchiavano": "scaracchiare",
    "scaracchiavate": "scaracchiare",
    "scaracchiavi": "scaracchiare",
    "scaracchiavo": "scaracchiare",
    "scaracchierai": "scaracchiare",
    "scaracchieran": "scaracchiare",
    "scaracchieranno": "scaracchiare",
    "scaracchierebbe": "scaracchiare",
    "scaracchierebber": "scaracchiare",
    "scaracchierebbero": "scaracchiare",
    "scaracchierei": "scaracchiare",
    "scaracchieremmo": "scaracchiare",
    "scaracchieremo": "scaracchiare",
    "scaracchiereste": "scaracchiare",
    "scaracchieresti": "scaracchiare",
    "scaracchierete": "scaracchiare",
    "scaracchierà": "scaracchiare",
    "scaracchierò": "scaracchiare",
    "scaracchin": "scaracchiare",
    "scaracchino": "scaracchiare",
    "scaracchio": "scaracchiare",
    "scaracchiò": "scaracchiare",
    "scarafaggi": "scarafaggio",
    "scaramantica": "scaramantico",
    "scaramantiche": "scaramantico",
    "scaramantici": "scaramantico",
    "scaramanzie": "scaramanzia",
    "scaramucce": "scaramuccia",
    "scaraventa": "scaraventare",
    "scaraventai": "scaraventare",
    "scaraventammo": "scaraventare",
    "scaraventan": "scaraventare",
    "scaraventando": "scaraventare",
    "scaraventano": "scaraventare",
    "scaraventante": "scaraventare",
    "scaraventanti": "scaraventare",
    "scaraventar": "scaraventare",
    "scaraventaron": "scaraventare",
    "scaraventarono": "scaraventare",
    "scaraventasse": "scaraventare",
    "scaraventasser": "scaraventare",
    "scaraventassero": "scaraventare",
    "scaraventassi": "scaraventare",
    "scaraventassimo": "scaraventare",
    "scaraventaste": "scaraventare",
    "scaraventasti": "scaraventare",
    "scaraventata": "scaraventare",
    "scaraventate": "scaraventare",
    "scaraventati": "scaraventare",
    "scaraventato": "scaraventare",
    "scaraventava": "scaraventare",
    "scaraventavamo": "scaraventare",
    "scaraventavan": "scaraventare",
    "scaraventavano": "scaraventare",
    "scaraventavate": "scaraventare",
    "scaraventavi": "scaraventare",
    "scaraventavo": "scaraventare",
    "scaraventerai": "scaraventare",
    "scaraventeran": "scaraventare",
    "scaraventeranno": "scaraventare",
    "scaraventerebbe": "scaraventare",
    "scaraventerebber": "scaraventare",
    "scaraventerebbero": "scaraventare",
    "scaraventerei": "scaraventare",
    "scaraventeremmo": "scaraventare",
    "scaraventeremo": "scaraventare",
    "scaraventereste": "scaraventare",
    "scaraventeresti": "scaraventare",
    "scaraventerete": "scaraventare",
    "scaraventerà": "scaraventare",
    "scaraventerò": "scaraventare",
    "scaraventi": "scaraventare",
    "scaraventiamo": "scaraventare",
    "scaraventiate": "scaraventare",
    "scaraventin": "scaraventare",
    "scaraventino": "scaraventare",
    "scaravento": "scaraventare",
    "scaraventò": "scaraventare",
    "scarcera": "scarcerare",
    "scarcerai": "scarcerare",
    "scarcerammo": "scarcerare",
    "scarceran": "scarcerare",
    "scarcerando": "scarcerare",
    "scarcerano": "scarcerare",
    "scarcerante": "scarcerare",
    "scarceranti": "scarcerare",
    "scarcerar": "scarcerare",
    "scarceraron": "scarcerare",
    "scarcerarono": "scarcerare",
    "scarcerasse": "scarcerare",
    "scarcerasser": "scarcerare",
    "scarcerassero": "scarcerare",
    "scarcerassi": "scarcerare",
    "scarcerassimo": "scarcerare",
    "scarceraste": "scarcerare",
    "scarcerasti": "scarcerare",
    "scarcerata": "scarcerare",
    "scarcerate": "scarcerare",
    "scarcerati": "scarcerare",
    "scarcerato": "scarcerare",
    "scarcerava": "scarcerare",
    "scarceravamo": "scarcerare",
    "scarceravan": "scarcerare",
    "scarceravano": "scarcerare",
    "scarceravate": "scarcerare",
    "scarceravi": "scarcerare",
    "scarceravo": "scarcerare",
    "scarcerazioni": "scarcerazione",
    "scarcererai": "scarcerare",
    "scarcereran": "scarcerare",
    "scarcereranno": "scarcerare",
    "scarcererebbe": "scarcerare",
    "scarcererebber": "scarcerare",
    "scarcererebbero": "scarcerare",
    "scarcererei": "scarcerare",
    "scarcereremmo": "scarcerare",
    "scarcereremo": "scarcerare",
    "scarcerereste": "scarcerare",
    "scarcereresti": "scarcerare",
    "scarcererete": "scarcerare",
    "scarcererà": "scarcerare",
    "scarcererò": "scarcerare",
    "scarceri": "scarcerare",
    "scarceriamo": "scarcerare",
    "scarceriate": "scarcerare",
    "scarcerin": "scarcerare",
    "scarcerino": "scarcerare",
    "scarcero": "scarcerare",
    "scarcerò": "scarcerare",
    "scardassa": "scardassare",
    "scardassai": "scardassare",
    "scardassammo": "scardassare",
    "scardassan": "scardassare",
    "scardassando": "scardassare",
    "scardassano": "scardassare",
    "scardassante": "scardassare",
    "scardassanti": "scardassare",
    "scardassar": "scardassare",
    "scardassaron": "scardassare",
    "scardassarono": "scardassare",
    "scardassasse": "scardassare",
    "scardassasser": "scardassare",
    "scardassassero": "scardassare",
    "scardassassi": "scardassare",
    "scardassassimo": "scardassare",
    "scardassaste": "scardassare",
    "scardassasti": "scardassare",
    "scardassata": "scardassare",
    "scardassate": "scardassare",
    "scardassati": "scardassare",
    "scardassato": "scardassare",
    "scardassava": "scardassare",
    "scardassavamo": "scardassare",
    "scardassavan": "scardassare",
    "scardassavano": "scardassare",
    "scardassavate": "scardassare",
    "scardassavi": "scardassare",
    "scardassavo": "scardassare",
    "scardasserai": "scardassare",
    "scardasseran": "scardassare",
    "scardasseranno": "scardassare",
    "scardasserebbe": "scardassare",
    "scardasserebber": "scardassare",
    "scardasserebbero": "scardassare",
    "scardasserei": "scardassare",
    "scardasseremmo": "scardassare",
    "scardasseremo": "scardassare",
    "scardassereste": "scardassare",
    "scardasseresti": "scardassare",
    "scardasserete": "scardassare",
    "scardasserà": "scardassare",
    "scardasserò": "scardassare",
    "scardassi": "scardassare",
    "scardassiamo": "scardassare",
    "scardassiate": "scardassare",
    "scardassin": "scardassare",
    "scardassino": "scardassare",
    "scardasso": "scardassare",
    "scardassò": "scardassare",
    "scardina": "scardinare",
    "scardinai": "scardinare",
    "scardinamenti": "scardinamento",
    "scardinammo": "scardinare",
    "scardinan": "scardinare",
    "scardinando": "scardinare",
    "scardinano": "scardinare",
    "scardinante": "scardinare",
    "scardinanti": "scardinare",
    "scardinar": "scardinare",
    "scardinaron": "scardinare",
    "scardinarono": "scardinare",
    "scardinasse": "scardinare",
    "scardinasser": "scardinare",
    "scardinassero": "scardinare",
    "scardinassi": "scardinare",
    "scardinassimo": "scardinare",
    "scardinaste": "scardinare",
    "scardinasti": "scardinare",
    "scardinata": "scardinare",
    "scardinate": "scardinare",
    "scardinati": "scardinare",
    "scardinato": "scardinare",
    "scardinava": "scardinare",
    "scardinavamo": "scardinare",
    "scardinavan": "scardinare",
    "scardinavano": "scardinare",
    "scardinavate": "scardinare",
    "scardinavi": "scardinare",
    "scardinavo": "scardinare",
    "scardinerai": "scardinare",
    "scardineran": "scardinare",
    "scardineranno": "scardinare",
    "scardinerebbe": "scardinare",
    "scardinerebber": "scardinare",
    "scardinerebbero": "scardinare",
    "scardinerei": "scardinare",
    "scardineremmo": "scardinare",
    "scardineremo": "scardinare",
    "scardinereste": "scardinare",
    "scardineresti": "scardinare",
    "scardinerete": "scardinare",
    "scardinerà": "scardinare",
    "scardinerò": "scardinare",
    "scardini": "scardinare",
    "scardiniamo": "scardinare",
    "scardiniate": "scardinare",
    "scardinin": "scardinare",
    "scardinino": "scardinare",
    "scardino": "scardinare",
    "scardinò": "scardinare",
    "scarica": "scarico",
    "scaricai": "scaricare",
    "scaricammo": "scaricare",
    "scarican": "scaricare",
    "scaricando": "scaricare",
    "scaricano": "scaricare",
    "scaricante": "scaricare",
    "scaricanti": "scaricare",
    "scaricar": "scaricare",
    "scaricaron": "scaricare",
    "scaricarono": "scaricare",
    "scaricasse": "scaricare",
    "scaricasser": "scaricare",
    "scaricassero": "scaricare",
    "scaricassi": "scaricare",
    "scaricassimo": "scaricare",
    "scaricaste": "scaricare",
    "scaricasti": "scaricare",
    "scaricata": "scaricare",
    "scaricate": "scaricare",
    "scaricati": "scaricare",
    "scaricato": "scaricare",
    "scaricatori": "scaricatore",
    "scaricatrice": "scaricatore",
    "scaricatrici": "scaricatore",
    "scaricava": "scaricare",
    "scaricavamo": "scaricare",
    "scaricavan": "scaricare",
    "scaricavano": "scaricare",
    "scaricavate": "scaricare",
    "scaricavi": "scaricare",
    "scaricavo": "scaricare",
    "scariche": "scarico",
    "scaricherai": "scaricare",
    "scaricheran": "scaricare",
    "scaricheranno": "scaricare",
    "scaricherebbe": "scaricare",
    "scaricherebber": "scaricare",
    "scaricherebbero": "scaricare",
    "scaricherei": "scaricare",
    "scaricheremmo": "scaricare",
    "scaricheremo": "scaricare",
    "scarichereste": "scaricare",
    "scaricheresti": "scaricare",
    "scaricherete": "scaricare",
    "scaricherà": "scaricare",
    "scaricherò": "scaricare",
    "scarichi": "scarico",
    "scarichiamo": "scaricare",
    "scarichiate": "scaricare",
    "scarichin": "scaricare",
    "scarichino": "scaricare",
    "scarici": "scarico",
    "scarico": "scaricare",
    "scaricò": "scaricare",
    "scarifica": "scarificare",
    "scarificai": "scarificare",
    "scarificammo": "scarificare",
    "scarifican": "scarificare",
    "scarificando": "scarificare",
    "scarificano": "scarificare",
    "scarificante": "scarificare",
    "scarificanti": "scarificare",
    "scarificar": "scarificare",
    "scarificaron": "scarificare",
    "scarificarono": "scarificare",
    "scarificasse": "scarificare",
    "scarificasser": "scarificare",
    "scarificassero": "scarificare",
    "scarificassi": "scarificare",
    "scarificassimo": "scarificare",
    "scarificaste": "scarificare",
    "scarificasti": "scarificare",
    "scarificata": "scarificare",
    "scarificate": "scarificare",
    "scarificati": "scarificare",
    "scarificato": "scarificare",
    "scarificava": "scarificare",
    "scarificavamo": "scarificare",
    "scarificavan": "scarificare",
    "scarificavano": "scarificare",
    "scarificavate": "scarificare",
    "scarificavi": "scarificare",
    "scarificavo": "scarificare",
    "scarificherai": "scarificare",
    "scarificheran": "scarificare",
    "scarificheranno": "scarificare",
    "scarificherebbe": "scarificare",
    "scarificherebber": "scarificare",
    "scarificherebbero": "scarificare",
    "scarificherei": "scarificare",
    "scarificheremmo": "scarificare",
    "scarificheremo": "scarificare",
    "scarifichereste": "scarificare",
    "scarificheresti": "scarificare",
    "scarificherete": "scarificare",
    "scarificherà": "scarificare",
    "scarificherò": "scarificare",
    "scarifichi": "scarificare",
    "scarifichiamo": "scarificare",
    "scarifichiate": "scarificare",
    "scarifichin": "scarificare",
    "scarifichino": "scarificare",
    "scarifico": "scarificare",
    "scarificò": "scarificare",
    "scarmigli": "scarmigliare",
    "scarmiglia": "scarmigliare",
    "scarmigliai": "scarmigliare",
    "scarmigliammo": "scarmigliare",
    "scarmigliamo": "scarmigliare",
    "scarmiglian": "scarmigliare",
    "scarmigliando": "scarmigliare",
    "scarmigliano": "scarmigliare",
    "scarmigliante": "scarmigliare",
    "scarmiglianti": "scarmigliare",
    "scarmigliar": "scarmigliare",
    "scarmigliaron": "scarmigliare",
    "scarmigliarono": "scarmigliare",
    "scarmigliasse": "scarmigliare",
    "scarmigliasser": "scarmigliare",
    "scarmigliassero": "scarmigliare",
    "scarmigliassi": "scarmigliare",
    "scarmigliassimo": "scarmigliare",
    "scarmigliaste": "scarmigliare",
    "scarmigliasti": "scarmigliare",
    "scarmigliata": "scarmigliare",
    "scarmigliate": "scarmigliare",
    "scarmigliati": "scarmigliare",
    "scarmigliato": "scarmigliare",
    "scarmigliava": "scarmigliare",
    "scarmigliavamo": "scarmigliare",
    "scarmigliavan": "scarmigliare",
    "scarmigliavano": "scarmigliare",
    "scarmigliavate": "scarmigliare",
    "scarmigliavi": "scarmigliare",
    "scarmigliavo": "scarmigliare",
    "scarmiglierai": "scarmigliare",
    "scarmiglieran": "scarmigliare",
    "scarmiglieranno": "scarmigliare",
    "scarmiglierebbe": "scarmigliare",
    "scarmiglierebber": "scarmigliare",
    "scarmiglierebbero": "scarmigliare",
    "scarmiglierei": "scarmigliare",
    "scarmiglieremmo": "scarmigliare",
    "scarmiglieremo": "scarmigliare",
    "scarmigliereste": "scarmigliare",
    "scarmiglieresti": "scarmigliare",
    "scarmiglierete": "scarmigliare",
    "scarmiglierà": "scarmigliare",
    "scarmiglierò": "scarmigliare",
    "scarmiglin": "scarmigliare",
    "scarmiglino": "scarmigliare",
    "scarmiglio": "scarmigliare",
    "scarmigliò": "scarmigliare",
    "scarna": "scarno",
    "scarnan": "scarnire",
    "scarnano": "scarnire",
    "scarne": "scarno",
    "scarnendo": "scarnire",
    "scarnente": "scarnire",
    "scarnenti": "scarnire",
    "scarni": "scarno",
    "scarniamo": "scarnire",
    "scarniate": "scarnire",
    "scarnifica": "scarnificare",
    "scarnificai": "scarnificare",
    "scarnificammo": "scarnificare",
    "scarnifican": "scarnificare",
    "scarnificando": "scarnificare",
    "scarnificano": "scarnificare",
    "scarnificante": "scarnificare",
    "scarnificanti": "scarnificare",
    "scarnificar": "scarnificare",
    "scarnificaron": "scarnificare",
    "scarnificarono": "scarnificare",
    "scarnificasse": "scarnificare",
    "scarnificasser": "scarnificare",
    "scarnificassero": "scarnificare",
    "scarnificassi": "scarnificare",
    "scarnificassimo": "scarnificare",
    "scarnificaste": "scarnificare",
    "scarnificasti": "scarnificare",
    "scarnificata": "scarnificare",
    "scarnificate": "scarnificare",
    "scarnificati": "scarnificare",
    "scarnificato": "scarnificare",
    "scarnificava": "scarnificare",
    "scarnificavamo": "scarnificare",
    "scarnificavan": "scarnificare",
    "scarnificavano": "scarnificare",
    "scarnificavate": "scarnificare",
    "scarnificavi": "scarnificare",
    "scarnificavo": "scarnificare",
    "scarnificherai": "scarnificare",
    "scarnificheran": "scarnificare",
    "scarnificheranno": "scarnificare",
    "scarnificherebbe": "scarnificare",
    "scarnificherebber": "scarnificare",
    "scarnificherebbero": "scarnificare",
    "scarnificherei": "scarnificare",
    "scarnificheremmo": "scarnificare",
    "scarnificheremo": "scarnificare",
    "scarnifichereste": "scarnificare",
    "scarnificheresti": "scarnificare",
    "scarnificherete": "scarnificare",
    "scarnificherà": "scarnificare",
    "scarnificherò": "scarnificare",
    "scarnifichi": "scarnificare",
    "scarnifichiamo": "scarnificare",
    "scarnifichiate": "scarnificare",
    "scarnifichin": "scarnificare",
    "scarnifichino": "scarnificare",
    "scarnifico": "scarnificare",
    "scarnificò": "scarnificare",
    "scarnii": "scarnire",
    "scarnimmo": "scarnire",
    "scarnir": "scarnire",
    "scarnirai": "scarnire",
    "scarniran": "scarnire",
    "scarniranno": "scarnire",
    "scarnirebbe": "scarnire",
    "scarnirebber": "scarnire",
    "scarnirebbero": "scarnire",
    "scarnirei": "scarnire",
    "scarniremmo": "scarnire",
    "scarniremo": "scarnire",
    "scarnireste": "scarnire",
    "scarniresti": "scarnire",
    "scarnirete": "scarnire",
    "scarniron": "scarnire",
    "scarnirono": "scarnire",
    "scarnirà": "scarnire",
    "scarnirò": "scarnire",
    "scarnisse": "scarnire",
    "scarnisser": "scarnire",
    "scarnissero": "scarnire",
    "scarnissi": "scarnire",
    "scarnissimo": "scarnire",
    "scarniste": "scarnire",
    "scarnisti": "scarnire",
    "scarnita": "scarnire",
    "scarnite": "scarnire",
    "scarniti": "scarnire",
    "scarnito": "scarnire",
    "scarniva": "scarnire",
    "scarnivamo": "scarnire",
    "scarnivan": "scarnire",
    "scarnivano": "scarnire",
    "scarnivate": "scarnire",
    "scarnivi": "scarnire",
    "scarnivo": "scarnire",
    "scarno": "scarnire",
    "scarnon": "scarnire",
    "scarnono": "scarnire",
    "scarnì": "scarnire",
    "scarpate": "scarpata",
    "scarpe": "scarpa",
    "scarpette": "scarpetta",
    "scarpina": "scarpinare",
    "scarpinai": "scarpinare",
    "scarpinammo": "scarpinare",
    "scarpinan": "scarpinare",
    "scarpinando": "scarpinare",
    "scarpinano": "scarpinare",
    "scarpinante": "scarpinare",
    "scarpinanti": "scarpinare",
    "scarpinar": "scarpinare",
    "scarpinaron": "scarpinare",
    "scarpinarono": "scarpinare",
    "scarpinasse": "scarpinare",
    "scarpinasser": "scarpinare",
    "scarpinassero": "scarpinare",
    "scarpinassi": "scarpinare",
    "scarpinassimo": "scarpinare",
    "scarpinaste": "scarpinare",
    "scarpinasti": "scarpinare",
    "scarpinata": "scarpinare",
    "scarpinate": "scarpinare",
    "scarpinati": "scarpinare",
    "scarpinato": "scarpinare",
    "scarpinava": "scarpinare",
    "scarpinavamo": "scarpinare",
    "scarpinavan": "scarpinare",
    "scarpinavano": "scarpinare",
    "scarpinavate": "scarpinare",
    "scarpinavi": "scarpinare",
    "scarpinavo": "scarpinare",
    "scarpine": "scarpina",
    "scarpinerai": "scarpinare",
    "scarpineran": "scarpinare",
    "scarpineranno": "scarpinare",
    "scarpinerebbe": "scarpinare",
    "scarpinerebber": "scarpinare",
    "scarpinerebbero": "scarpinare",
    "scarpinerei": "scarpinare",
    "scarpineremmo": "scarpinare",
    "scarpineremo": "scarpinare",
    "scarpinereste": "scarpinare",
    "scarpineresti": "scarpinare",
    "scarpinerete": "scarpinare",
    "scarpinerà": "scarpinare",
    "scarpinerò": "scarpinare",
    "scarpini": "scarpino",
    "scarpiniamo": "scarpinare",
    "scarpiniate": "scarpinare",
    "scarpinin": "scarpinare",
    "scarpinino": "scarpinare",
    "scarpino": "scarpinare",
    "scarpinò": "scarpinare",
    "scarponi": "scarpone",
    "scarrozza": "scarrozzare",
    "scarrozzai": "scarrozzare",
    "scarrozzammo": "scarrozzare",
    "scarrozzan": "scarrozzare",
    "scarrozzando": "scarrozzare",
    "scarrozzano": "scarrozzare",
    "scarrozzante": "scarrozzare",
    "scarrozzanti": "scarrozzare",
    "scarrozzar": "scarrozzare",
    "scarrozzaron": "scarrozzare",
    "scarrozzarono": "scarrozzare",
    "scarrozzasse": "scarrozzare",
    "scarrozzasser": "scarrozzare",
    "scarrozzassero": "scarrozzare",
    "scarrozzassi": "scarrozzare",
    "scarrozzassimo": "scarrozzare",
    "scarrozzaste": "scarrozzare",
    "scarrozzasti": "scarrozzare",
    "scarrozzata": "scarrozzare",
    "scarrozzate": "scarrozzare",
    "scarrozzati": "scarrozzare",
    "scarrozzato": "scarrozzare",
    "scarrozzava": "scarrozzare",
    "scarrozzavamo": "scarrozzare",
    "scarrozzavan": "scarrozzare",
    "scarrozzavano": "scarrozzare",
    "scarrozzavate": "scarrozzare",
    "scarrozzavi": "scarrozzare",
    "scarrozzavo": "scarrozzare",
    "scarrozzerai": "scarrozzare",
    "scarrozzeran": "scarrozzare",
    "scarrozzeranno": "scarrozzare",
    "scarrozzerebbe": "scarrozzare",
    "scarrozzerebber": "scarrozzare",
    "scarrozzerebbero": "scarrozzare",
    "scarrozzerei": "scarrozzare",
    "scarrozzeremmo": "scarrozzare",
    "scarrozzeremo": "scarrozzare",
    "scarrozzereste": "scarrozzare",
    "scarrozzeresti": "scarrozzare",
    "scarrozzerete": "scarrozzare",
    "scarrozzerà": "scarrozzare",
    "scarrozzerò": "scarrozzare",
    "scarrozzi": "scarrozzare",
    "scarrozziamo": "scarrozzare",
    "scarrozziate": "scarrozzare",
    "scarrozzin": "scarrozzare",
    "scarrozzino": "scarrozzare",
    "scarrozzo": "scarrozzare",
    "scarrozzò": "scarrozzare",
    "scarrucola": "scarrucolare",
    "scarrucolai": "scarrucolare",
    "scarrucolammo": "scarrucolare",
    "scarrucolan": "scarrucolare",
    "scarrucolando": "scarrucolare",
    "scarrucolano": "scarrucolare",
    "scarrucolante": "scarrucolare",
    "scarrucolanti": "scarrucolare",
    "scarrucolar": "scarrucolare",
    "scarrucolaron": "scarrucolare",
    "scarrucolarono": "scarrucolare",
    "scarrucolasse": "scarrucolare",
    "scarrucolasser": "scarrucolare",
    "scarrucolassero": "scarrucolare",
    "scarrucolassi": "scarrucolare",
    "scarrucolassimo": "scarrucolare",
    "scarrucolaste": "scarrucolare",
    "scarrucolasti": "scarrucolare",
    "scarrucolata": "scarrucolare",
    "scarrucolate": "scarrucolare",
    "scarrucolati": "scarrucolare",
    "scarrucolato": "scarrucolare",
    "scarrucolava": "scarrucolare",
    "scarrucolavamo": "scarrucolare",
    "scarrucolavan": "scarrucolare",
    "scarrucolavano": "scarrucolare",
    "scarrucolavate": "scarrucolare",
    "scarrucolavi": "scarrucolare",
    "scarrucolavo": "scarrucolare",
    "scarrucolerai": "scarrucolare",
    "scarrucoleran": "scarrucolare",
    "scarrucoleranno": "scarrucolare",
    "scarrucolerebbe": "scarrucolare",
    "scarrucolerebber": "scarrucolare",
    "scarrucolerebbero": "scarrucolare",
    "scarrucolerei": "scarrucolare",
    "scarrucoleremmo": "scarrucolare",
    "scarrucoleremo": "scarrucolare",
    "scarrucolereste": "scarrucolare",
    "scarrucoleresti": "scarrucolare",
    "scarrucolerete": "scarrucolare",
    "scarrucolerà": "scarrucolare",
    "scarrucolerò": "scarrucolare",
    "scarrucoli": "scarrucolare",
    "scarrucoliamo": "scarrucolare",
    "scarrucoliate": "scarrucolare",
    "scarrucolin": "scarrucolare",
    "scarrucolino": "scarrucolare",
    "scarrucolo": "scarrucolare",
    "scarrucolò": "scarrucolare",
    "scarruffa": "scarruffare",
    "scarruffai": "scarruffare",
    "scarruffammo": "scarruffare",
    "scarruffan": "scarruffare",
    "scarruffando": "scarruffare",
    "scarruffano": "scarruffare",
    "scarruffante": "scarruffare",
    "scarruffanti": "scarruffare",
    "scarruffar": "scarruffare",
    "scarruffaron": "scarruffare",
    "scarruffarono": "scarruffare",
    "scarruffasse": "scarruffare",
    "scarruffasser": "scarruffare",
    "scarruffassero": "scarruffare",
    "scarruffassi": "scarruffare",
    "scarruffassimo": "scarruffare",
    "scarruffaste": "scarruffare",
    "scarruffasti": "scarruffare",
    "scarruffata": "scarruffare",
    "scarruffate": "scarruffare",
    "scarruffati": "scarruffare",
    "scarruffato": "scarruffare",
    "scarruffava": "scarruffare",
    "scarruffavamo": "scarruffare",
    "scarruffavan": "scarruffare",
    "scarruffavano": "scarruffare",
    "scarruffavate": "scarruffare",
    "scarruffavi": "scarruffare",
    "scarruffavo": "scarruffare",
    "scarrufferai": "scarruffare",
    "scarrufferan": "scarruffare",
    "scarrufferanno": "scarruffare",
    "scarrufferebbe": "scarruffare",
    "scarrufferebber": "scarruffare",
    "scarrufferebbero": "scarruffare",
    "scarrufferei": "scarruffare",
    "scarrufferemmo": "scarruffare",
    "scarrufferemo": "scarruffare",
    "scarruffereste": "scarruffare",
    "scarrufferesti": "scarruffare",
    "scarrufferete": "scarruffare",
    "scarrufferà": "scarruffare",
    "scarrufferò": "scarruffare",
    "scarruffi": "scarruffare",
    "scarruffiamo": "scarruffare",
    "scarruffiate": "scarruffare",
    "scarruffin": "scarruffare",
    "scarruffino": "scarruffare",
    "scarruffo": "scarruffare",
    "scarruffò": "scarruffare",
    "scarsa": "scarso",
    "scarse": "scarso",
    "scarseggerai": "scarseggiare",
    "scarseggeran": "scarseggiare",
    "scarseggeranno": "scarseggiare",
    "scarseggerebbe": "scarseggiare",
    "scarseggerebber": "scarseggiare",
    "scarseggerebbero": "scarseggiare",
    "scarseggerei": "scarseggiare",
    "scarseggeremmo": "scarseggiare",
    "scarseggeremo": "scarseggiare",
    "scarseggereste": "scarseggiare",
    "scarseggeresti": "scarseggiare",
    "scarseggerete": "scarseggiare",
    "scarseggerà": "scarseggiare",
    "scarseggerò": "scarseggiare",
    "scarseggi": "scarseggiare",
    "scarseggia": "scarseggiare",
    "scarseggiai": "scarseggiare",
    "scarseggiammo": "scarseggiare",
    "scarseggiamo": "scarseggiare",
    "scarseggian": "scarseggiare",
    "scarseggiando": "scarseggiare",
    "scarseggiano": "scarseggiare",
    "scarseggiante": "scarseggiare",
    "scarseggianti": "scarseggiare",
    "scarseggiar": "scarseggiare",
    "scarseggiaron": "scarseggiare",
    "scarseggiarono": "scarseggiare",
    "scarseggiasse": "scarseggiare",
    "scarseggiasser": "scarseggiare",
    "scarseggiassero": "scarseggiare",
    "scarseggiassi": "scarseggiare",
    "scarseggiassimo": "scarseggiare",
    "scarseggiaste": "scarseggiare",
    "scarseggiasti": "scarseggiare",
    "scarseggiata": "scarseggiare",
    "scarseggiate": "scarseggiare",
    "scarseggiati": "scarseggiare",
    "scarseggiato": "scarseggiare",
    "scarseggiava": "scarseggiare",
    "scarseggiavamo": "scarseggiare",
    "scarseggiavan": "scarseggiare",
    "scarseggiavano": "scarseggiare",
    "scarseggiavate": "scarseggiare",
    "scarseggiavi": "scarseggiare",
    "scarseggiavo": "scarseggiare",
    "scarseggin": "scarseggiare",
    "scarseggino": "scarseggiare",
    "scarseggio": "scarseggiare",
    "scarseggiò": "scarseggiare",
    "scarsezze": "scarsezza",
    "scarsi": "scarso",
    "scarta": "scartare",
    "scartabella": "scartabellare",
    "scartabellai": "scartabellare",
    "scartabellammo": "scartabellare",
    "scartabellan": "scartabellare",
    "scartabellando": "scartabellare",
    "scartabellano": "scartabellare",
    "scartabellante": "scartabellare",
    "scartabellanti": "scartabellare",
    "scartabellar": "scartabellare",
    "scartabellaron": "scartabellare",
    "scartabellarono": "scartabellare",
    "scartabellasse": "scartabellare",
    "scartabellasser": "scartabellare",
    "scartabellassero": "scartabellare",
    "scartabellassi": "scartabellare",
    "scartabellassimo": "scartabellare",
    "scartabellaste": "scartabellare",
    "scartabellasti": "scartabellare",
    "scartabellata": "scartabellare",
    "scartabellate": "scartabellare",
    "scartabellati": "scartabellare",
    "scartabellato": "scartabellare",
    "scartabellava": "scartabellare",
    "scartabellavamo": "scartabellare",
    "scartabellavan": "scartabellare",
    "scartabellavano": "scartabellare",
    "scartabellavate": "scartabellare",
    "scartabellavi": "scartabellare",
    "scartabellavo": "scartabellare",
    "scartabellerai": "scartabellare",
    "scartabelleran": "scartabellare",
    "scartabelleranno": "scartabellare",
    "scartabellerebbe": "scartabellare",
    "scartabellerebber": "scartabellare",
    "scartabellerebbero": "scartabellare",
    "scartabellerei": "scartabellare",
    "scartabelleremmo": "scartabellare",
    "scartabelleremo": "scartabellare",
    "scartabellereste": "scartabellare",
    "scartabelleresti": "scartabellare",
    "scartabellerete": "scartabellare",
    "scartabellerà": "scartabellare",
    "scartabellerò": "scartabellare",
    "scartabelli": "scartabellare",
    "scartabelliamo": "scartabellare",
    "scartabelliate": "scartabellare",
    "scartabellin": "scartabellare",
    "scartabellino": "scartabellare",
    "scartabello": "scartabellare",
    "scartabellò": "scartabellare",
    "scartafacci": "scartafaccio",
    "scartai": "scartare",
    "scartammo": "scartare",
    "scartan": "scartare",
    "scartando": "scartare",
    "scartano": "scartare",
    "scartante": "scartare",
    "scartanti": "scartare",
    "scartar": "scartare",
    "scartaron": "scartare",
    "scartarono": "scartare",
    "scartasse": "scartare",
    "scartasser": "scartare",
    "scartassero": "scartare",
    "scartassi": "scartare",
    "scartassimo": "scartare",
    "scartaste": "scartare",
    "scartasti": "scartare",
    "scartata": "scartare",
    "scartate": "scartare",
    "scartati": "scartare",
    "scartato": "scartare",
    "scartava": "scartare",
    "scartavamo": "scartare",
    "scartavan": "scartare",
    "scartavano": "scartare",
    "scartavate": "scartare",
    "scartavetra": "scartavetrare",
    "scartavetrai": "scartavetrare",
    "scartavetrammo": "scartavetrare",
    "scartavetran": "scartavetrare",
    "scartavetrando": "scartavetrare",
    "scartavetrano": "scartavetrare",
    "scartavetrante": "scartavetrare",
    "scartavetranti": "scartavetrare",
    "scartavetrar": "scartavetrare",
    "scartavetraron": "scartavetrare",
    "scartavetrarono": "scartavetrare",
    "scartavetrasse": "scartavetrare",
    "scartavetrasser": "scartavetrare",
    "scartavetrassero": "scartavetrare",
    "scartavetrassi": "scartavetrare",
    "scartavetrassimo": "scartavetrare",
    "scartavetraste": "scartavetrare",
    "scartavetrasti": "scartavetrare",
    "scartavetrata": "scartavetrare",
    "scartavetrate": "scartavetrare",
    "scartavetrati": "scartavetrare",
    "scartavetrato": "scartavetrare",
    "scartavetrava": "scartavetrare",
    "scartavetravamo": "scartavetrare",
    "scartavetravan": "scartavetrare",
    "scartavetravano": "scartavetrare",
    "scartavetravate": "scartavetrare",
    "scartavetravi": "scartavetrare",
    "scartavetravo": "scartavetrare",
    "scartavetrerai": "scartavetrare",
    "scartavetreran": "scartavetrare",
    "scartavetreranno": "scartavetrare",
    "scartavetrerebbe": "scartavetrare",
    "scartavetrerebber": "scartavetrare",
    "scartavetrerebbero": "scartavetrare",
    "scartavetrerei": "scartavetrare",
    "scartavetreremmo": "scartavetrare",
    "scartavetreremo": "scartavetrare",
    "scartavetrereste": "scartavetrare",
    "scartavetreresti": "scartavetrare",
    "scartavetrerete": "scartavetrare",
    "scartavetrerà": "scartavetrare",
    "scartavetrerò": "scartavetrare",
    "scartavetri": "scartavetrare",
    "scartavetriamo": "scartavetrare",
    "scartavetriate": "scartavetrare",
    "scartavetrin": "scartavetrare",
    "scartavetrino": "scartavetrare",
    "scartavetro": "scartavetrare",
    "scartavetrò": "scartavetrare",
    "scartavi": "scartare",
    "scartavo": "scartare",
    "scarterai": "scartare",
    "scarteran": "scartare",
    "scarteranno": "scartare",
    "scarterebbe": "scartare",
    "scarterebber": "scartare",
    "scarterebbero": "scartare",
    "scarterei": "scartare",
    "scarteremmo": "scartare",
    "scarteremo": "scartare",
    "scartereste": "scartare",
    "scarteresti": "scartare",
    "scarterete": "scartare",
    "scarterà": "scartare",
    "scarterò": "scartare",
    "scarti": "scarto",
    "scartiamo": "scartare",
    "scartiate": "scartare",
    "scartin": "scartare",
    "scartine": "scartina",
    "scartino": "scartare",
    "scarto": "scartare",
    "scartoccerai": "scartocciare",
    "scartocceran": "scartocciare",
    "scartocceranno": "scartocciare",
    "scartoccerebbe": "scartocciare",
    "scartoccerebber": "scartocciare",
    "scartoccerebbero": "scartocciare",
    "scartoccerei": "scartocciare",
    "scartocceremmo": "scartocciare",
    "scartocceremo": "scartocciare",
    "scartoccereste": "scartocciare",
    "scartocceresti": "scartocciare",
    "scartoccerete": "scartocciare",
    "scartoccerà": "scartocciare",
    "scartoccerò": "scartocciare",
    "scartocci": "scartocciare",
    "scartoccia": "scartocciare",
    "scartocciai": "scartocciare",
    "scartocciammo": "scartocciare",
    "scartocciamo": "scartocciare",
    "scartoccian": "scartocciare",
    "scartocciando": "scartocciare",
    "scartocciano": "scartocciare",
    "scartocciante": "scartocciare",
    "scartoccianti": "scartocciare",
    "scartocciar": "scartocciare",
    "scartocciaron": "scartocciare",
    "scartocciarono": "scartocciare",
    "scartocciasse": "scartocciare",
    "scartocciasser": "scartocciare",
    "scartocciassero": "scartocciare",
    "scartocciassi": "scartocciare",
    "scartocciassimo": "scartocciare",
    "scartocciaste": "scartocciare",
    "scartocciasti": "scartocciare",
    "scartocciata": "scartocciare",
    "scartocciate": "scartocciare",
    "scartocciati": "scartocciare",
    "scartocciato": "scartocciare",
    "scartocciava": "scartocciare",
    "scartocciavamo": "scartocciare",
    "scartocciavan": "scartocciare",
    "scartocciavano": "scartocciare",
    "scartocciavate": "scartocciare",
    "scartocciavi": "scartocciare",
    "scartocciavo": "scartocciare",
    "scartoccin": "scartocciare",
    "scartoccino": "scartocciare",
    "scartoccio": "scartocciare",
    "scartocciò": "scartocciare",
    "scartoffie": "scartoffia",
    "scartò": "scartare",
    "scaser": "scandere",
    "scasero": "scandere",
    "scasi": "scandere",
    "scassa": "scassare",
    "scassai": "scassare",
    "scassammo": "scassare",
    "scassan": "scassare",
    "scassando": "scassare",
    "scassano": "scassare",
    "scassante": "scassare",
    "scassanti": "scassare",
    "scassar": "scassare",
    "scassaron": "scassare",
    "scassarono": "scassare",
    "scassasse": "scassare",
    "scassasser": "scassare",
    "scassassero": "scassare",
    "scassassi": "scassare",
    "scassassimo": "scassare",
    "scassaste": "scassare",
    "scassasti": "scassare",
    "scassata": "scassare",
    "scassate": "scassare",
    "scassati": "scassare",
    "scassato": "scassare",
    "scassava": "scassare",
    "scassavamo": "scassare",
    "scassavan": "scassare",
    "scassavano": "scassare",
    "scassavate": "scassare",
    "scassavi": "scassare",
    "scassavo": "scassare",
    "scasserai": "scassare",
    "scasseran": "scassare",
    "scasseranno": "scassare",
    "scasserebbe": "scassare",
    "scasserebber": "scassare",
    "scasserebbero": "scassare",
    "scasserei": "scassare",
    "scasseremmo": "scassare",
    "scasseremo": "scassare",
    "scassereste": "scassare",
    "scasseresti": "scassare",
    "scasserete": "scassare",
    "scasserà": "scassare",
    "scasserò": "scassare",
    "scassi": "scassare",
    "scassiamo": "scassare",
    "scassiate": "scassare",
    "scassin": "scassare",
    "scassina": "scassinare",
    "scassinai": "scassinare",
    "scassinammo": "scassinare",
    "scassinan": "scassinare",
    "scassinando": "scassinare",
    "scassinano": "scassinare",
    "scassinante": "scassinare",
    "scassinanti": "scassinare",
    "scassinar": "scassinare",
    "scassinaron": "scassinare",
    "scassinarono": "scassinare",
    "scassinasse": "scassinare",
    "scassinasser": "scassinare",
    "scassinassero": "scassinare",
    "scassinassi": "scassinare",
    "scassinassimo": "scassinare",
    "scassinaste": "scassinare",
    "scassinasti": "scassinare",
    "scassinata": "scassinare",
    "scassinate": "scassinare",
    "scassinati": "scassinare",
    "scassinato": "scassinare",
    "scassinatori": "scassinatore",
    "scassinava": "scassinare",
    "scassinavamo": "scassinare",
    "scassinavan": "scassinare",
    "scassinavano": "scassinare",
    "scassinavate": "scassinare",
    "scassinavi": "scassinare",
    "scassinavo": "scassinare",
    "scassinerai": "scassinare",
    "scassineran": "scassinare",
    "scassineranno": "scassinare",
    "scassinerebbe": "scassinare",
    "scassinerebber": "scassinare",
    "scassinerebbero": "scassinare",
    "scassinerei": "scassinare",
    "scassineremmo": "scassinare",
    "scassineremo": "scassinare",
    "scassinereste": "scassinare",
    "scassineresti": "scassinare",
    "scassinerete": "scassinare",
    "scassinerà": "scassinare",
    "scassinerò": "scassinare",
    "scassini": "scassinare",
    "scassiniamo": "scassinare",
    "scassiniate": "scassinare",
    "scassinin": "scassinare",
    "scassinino": "scassinare",
    "scassino": "scassinare",
    "scassinò": "scassinare",
    "scasso": "scassare",
    "scassò": "scassare",
    "scasè": "scandere",
    "scatafasci": "scatafascio",
    "scatarra": "scatarrare",
    "scatarrai": "scatarrare",
    "scatarrammo": "scatarrare",
    "scatarran": "scatarrare",
    "scatarrando": "scatarrare",
    "scatarrano": "scatarrare",
    "scatarrante": "scatarrare",
    "scatarranti": "scatarrare",
    "scatarrar": "scatarrare",
    "scatarraron": "scatarrare",
    "scatarrarono": "scatarrare",
    "scatarrasse": "scatarrare",
    "scatarrasser": "scatarrare",
    "scatarrassero": "scatarrare",
    "scatarrassi": "scatarrare",
    "scatarrassimo": "scatarrare",
    "scatarraste": "scatarrare",
    "scatarrasti": "scatarrare",
    "scatarrata": "scatarrare",
    "scatarrate": "scatarrare",
    "scatarrati": "scatarrare",
    "scatarrato": "scatarrare",
    "scatarrava": "scatarrare",
    "scatarravamo": "scatarrare",
    "scatarravan": "scatarrare",
    "scatarravano": "scatarrare",
    "scatarravate": "scatarrare",
    "scatarravi": "scatarrare",
    "scatarravo": "scatarrare",
    "scatarrerai": "scatarrare",
    "scatarreran": "scatarrare",
    "scatarreranno": "scatarrare",
    "scatarrerebbe": "scatarrare",
    "scatarrerebber": "scatarrare",
    "scatarrerebbero": "scatarrare",
    "scatarrerei": "scatarrare",
    "scatarreremmo": "scatarrare",
    "scatarreremo": "scatarrare",
    "scatarrereste": "scatarrare",
    "scatarreresti": "scatarrare",
    "scatarrerete": "scatarrare",
    "scatarrerà": "scatarrare",
    "scatarrerò": "scatarrare",
    "scatarri": "scatarrare",
    "scatarriamo": "scatarrare",
    "scatarriate": "scatarrare",
    "scatarrin": "scatarrare",
    "scatarrino": "scatarrare",
    "scatarro": "scatarrare",
    "scatarrò": "scatarrare",
    "scatena": "scatenare",
    "scatenai": "scatenare",
    "scatenamenti": "scatenamento",
    "scatenammo": "scatenare",
    "scatenan": "scatenare",
    "scatenando": "scatenare",
    "scatenano": "scatenare",
    "scatenante": "scatenare",
    "scatenanti": "scatenare",
    "scatenar": "scatenare",
    "scatenaron": "scatenare",
    "scatenarono": "scatenare",
    "scatenasse": "scatenare",
    "scatenasser": "scatenare",
    "scatenassero": "scatenare",
    "scatenassi": "scatenare",
    "scatenassimo": "scatenare",
    "scatenaste": "scatenare",
    "scatenasti": "scatenare",
    "scatenata": "scatenato",
    "scatenate": "scatenato",
    "scatenati": "scatenato",
    "scatenato": "scatenare",
    "scatenava": "scatenare",
    "scatenavamo": "scatenare",
    "scatenavan": "scatenare",
    "scatenavano": "scatenare",
    "scatenavate": "scatenare",
    "scatenavi": "scatenare",
    "scatenavo": "scatenare",
    "scatenerai": "scatenare",
    "scateneran": "scatenare",
    "scateneranno": "scatenare",
    "scatenerebbe": "scatenare",
    "scatenerebber": "scatenare",
    "scatenerebbero": "scatenare",
    "scatenerei": "scatenare",
    "scateneremmo": "scatenare",
    "scateneremo": "scatenare",
    "scatenereste": "scatenare",
    "scateneresti": "scatenare",
    "scatenerete": "scatenare",
    "scatenerà": "scatenare",
    "scatenerò": "scatenare",
    "scateni": "scatenare",
    "scateniamo": "scatenare",
    "scateniate": "scatenare",
    "scatenin": "scatenare",
    "scatenino": "scatenare",
    "scateno": "scatenare",
    "scatenò": "scatenare",
    "scatola": "scatolare",
    "scatolai": "scatolare",
    "scatolammo": "scatolare",
    "scatolan": "scatolare",
    "scatolando": "scatolare",
    "scatolano": "scatolare",
    "scatolante": "scatolare",
    "scatolanti": "scatolare",
    "scatolar": "scatolare",
    "scatolaron": "scatolare",
    "scatolarono": "scatolare",
    "scatolasse": "scatolare",
    "scatolasser": "scatolare",
    "scatolassero": "scatolare",
    "scatolassi": "scatolare",
    "scatolassimo": "scatolare",
    "scatolaste": "scatolare",
    "scatolasti": "scatolare",
    "scatolata": "scatolare",
    "scatolate": "scatolare",
    "scatolati": "scatolare",
    "scatolato": "scatolare",
    "scatolava": "scatolare",
    "scatolavamo": "scatolare",
    "scatolavan": "scatolare",
    "scatolavano": "scatolare",
    "scatolavate": "scatolare",
    "scatolavi": "scatolare",
    "scatolavo": "scatolare",
    "scatole": "scatola",
    "scatolerai": "scatolare",
    "scatoleran": "scatolare",
    "scatoleranno": "scatolare",
    "scatolerebbe": "scatolare",
    "scatolerebber": "scatolare",
    "scatolerebbero": "scatolare",
    "scatolerei": "scatolare",
    "scatoleremmo": "scatolare",
    "scatoleremo": "scatolare",
    "scatolereste": "scatolare",
    "scatoleresti": "scatolare",
    "scatolerete": "scatolare",
    "scatolerà": "scatolare",
    "scatolerò": "scatolare",
    "scatolette": "scatoletta",
    "scatoli": "scatolare",
    "scatoliamo": "scatolare",
    "scatoliate": "scatolare",
    "scatolin": "scatolare",
    "scatoline": "scatolina",
    "scatolino": "scatolare",
    "scatolo": "scatolare",
    "scatoloni": "scatolone",
    "scatolò": "scatolare",
    "scatta": "scattare",
    "scattai": "scattare",
    "scattammo": "scattare",
    "scattan": "scattare",
    "scattando": "scattare",
    "scattano": "scattare",
    "scattante": "scattare",
    "scattanti": "scattare",
    "scattar": "scattare",
    "scattaron": "scattare",
    "scattarono": "scattare",
    "scattasse": "scattare",
    "scattasser": "scattare",
    "scattassero": "scattare",
    "scattassi": "scattare",
    "scattassimo": "scattare",
    "scattaste": "scattare",
    "scattasti": "scattare",
    "scattata": "scattare",
    "scattate": "scattare",
    "scattati": "scattare",
    "scattato": "scattare",
    "scattava": "scattare",
    "scattavamo": "scattare",
    "scattavan": "scattare",
    "scattavano": "scattare",
    "scattavate": "scattare",
    "scattavi": "scattare",
    "scattavo": "scattare",
    "scatterai": "scattare",
    "scatteran": "scattare",
    "scatteranno": "scattare",
    "scatterebbe": "scattare",
    "scatterebber": "scattare",
    "scatterebbero": "scattare",
    "scatterei": "scattare",
    "scatteremmo": "scattare",
    "scatteremo": "scattare",
    "scattereste": "scattare",
    "scatteresti": "scattare",
    "scatterete": "scattare",
    "scatterà": "scattare",
    "scatterò": "scattare",
    "scatti": "scatto",
    "scattiamo": "scattare",
    "scattiate": "scattare",
    "scattin": "scattare",
    "scattino": "scattare",
    "scattisti": "scattista",
    "scatto": "scattare",
    "scattò": "scattare",
    "scaturendo": "scaturire",
    "scaturente": "scaturire",
    "scaturenti": "scaturire",
    "scaturiamo": "scaturire",
    "scaturiate": "scaturire",
    "scaturigini": "scaturigine",
    "scaturii": "scaturire",
    "scaturimmo": "scaturire",
    "scaturir": "scaturire",
    "scaturirai": "scaturire",
    "scaturiran": "scaturire",
    "scaturiranno": "scaturire",
    "scaturirebbe": "scaturire",
    "scaturirebber": "scaturire",
    "scaturirebbero": "scaturire",
    "scaturirei": "scaturire",
    "scaturiremmo": "scaturire",
    "scaturiremo": "scaturire",
    "scaturireste": "scaturire",
    "scaturiresti": "scaturire",
    "scaturirete": "scaturire",
    "scaturiron": "scaturire",
    "scaturirono": "scaturire",
    "scaturirà": "scaturire",
    "scaturirò": "scaturire",
    "scaturisca": "scaturire",
    "scaturiscan": "scaturire",
    "scaturiscano": "scaturire",
    "scaturisce": "scaturire",
    "scaturisci": "scaturire",
    "scaturisco": "scaturire",
    "scaturiscon": "scaturire",
    "scaturiscono": "scaturire",
    "scaturisse": "scaturire",
    "scaturisser": "scaturire",
    "scaturissero": "scaturire",
    "scaturissi": "scaturire",
    "scaturissimo": "scaturire",
    "scaturiste": "scaturire",
    "scaturisti": "scaturire",
    "scaturita": "scaturire",
    "scaturite": "scaturire",
    "scaturiti": "scaturire",
    "scaturito": "scaturire",
    "scaturiva": "scaturire",
    "scaturivamo": "scaturire",
    "scaturivan": "scaturire",
    "scaturivano": "scaturire",
    "scaturivate": "scaturire",
    "scaturivi": "scaturire",
    "scaturivo": "scaturire",
    "scaturì": "scaturire",
    "scava": "scavare",
    "scavai": "scavare",
    "scavalca": "scavalcare",
    "scavalcai": "scavalcare",
    "scavalcamenti": "scavalcamento",
    "scavalcammo": "scavalcare",
    "scavalcan": "scavalcare",
    "scavalcando": "scavalcare",
    "scavalcano": "scavalcare",
    "scavalcante": "scavalcare",
    "scavalcanti": "scavalcare",
    "scavalcar": "scavalcare",
    "scavalcaron": "scavalcare",
    "scavalcarono": "scavalcare",
    "scavalcasse": "scavalcare",
    "scavalcasser": "scavalcare",
    "scavalcassero": "scavalcare",
    "scavalcassi": "scavalcare",
    "scavalcassimo": "scavalcare",
    "scavalcaste": "scavalcare",
    "scavalcasti": "scavalcare",
    "scavalcata": "scavalcare",
    "scavalcate": "scavalcare",
    "scavalcati": "scavalcare",
    "scavalcato": "scavalcare",
    "scavalcava": "scavalcare",
    "scavalcavamo": "scavalcare",
    "scavalcavan": "scavalcare",
    "scavalcavano": "scavalcare",
    "scavalcavate": "scavalcare",
    "scavalcavi": "scavalcare",
    "scavalcavo": "scavalcare",
    "scavalcherai": "scavalcare",
    "scavalcheran": "scavalcare",
    "scavalcheranno": "scavalcare",
    "scavalcherebbe": "scavalcare",
    "scavalcherebber": "scavalcare",
    "scavalcherebbero": "scavalcare",
    "scavalcherei": "scavalcare",
    "scavalcheremmo": "scavalcare",
    "scavalcheremo": "scavalcare",
    "scavalchereste": "scavalcare",
    "scavalcheresti": "scavalcare",
    "scavalcherete": "scavalcare",
    "scavalcherà": "scavalcare",
    "scavalcherò": "scavalcare",
    "scavalchi": "scavalcare",
    "scavalchiamo": "scavalcare",
    "scavalchiate": "scavalcare",
    "scavalchin": "scavalcare",
    "scavalchino": "scavalcare",
    "scavalco": "scavalcare",
    "scavalcò": "scavalcare",
    "scavammo": "scavare",
    "scavan": "scavare",
    "scavando": "scavare",
    "scavano": "scavare",
    "scavante": "scavare",
    "scavanti": "scavare",
    "scavar": "scavare",
    "scavaron": "scavare",
    "scavarono": "scavare",
    "scavasse": "scavare",
    "scavasser": "scavare",
    "scavassero": "scavare",
    "scavassi": "scavare",
    "scavassimo": "scavare",
    "scavaste": "scavare",
    "scavasti": "scavare",
    "scavata": "scavato",
    "scavate": "scavato",
    "scavati": "scavato",
    "scavato": "scavare",
    "scavatori": "scavatore",
    "scavatrici": "scavatrice",
    "scavava": "scavare",
    "scavavamo": "scavare",
    "scavavan": "scavare",
    "scavavano": "scavare",
    "scavavate": "scavare",
    "scavavi": "scavare",
    "scavavo": "scavare",
    "scaverai": "scavare",
    "scaveran": "scavare",
    "scaveranno": "scavare",
    "scaverebbe": "scavare",
    "scaverebber": "scavare",
    "scaverebbero": "scavare",
    "scaverei": "scavare",
    "scaveremmo": "scavare",
    "scaveremo": "scavare",
    "scavereste": "scavare",
    "scaveresti": "scavare",
    "scaverete": "scavare",
    "scaverà": "scavare",
    "scaverò": "scavare",
    "scavezza": "scavezzare",
    "scavezzai": "scavezzare",
    "scavezzammo": "scavezzare",
    "scavezzan": "scavezzare",
    "scavezzando": "scavezzare",
    "scavezzano": "scavezzare",
    "scavezzante": "scavezzare",
    "scavezzanti": "scavezzare",
    "scavezzar": "scavezzare",
    "scavezzaron": "scavezzare",
    "scavezzarono": "scavezzare",
    "scavezzasse": "scavezzare",
    "scavezzasser": "scavezzare",
    "scavezzassero": "scavezzare",
    "scavezzassi": "scavezzare",
    "scavezzassimo": "scavezzare",
    "scavezzaste": "scavezzare",
    "scavezzasti": "scavezzare",
    "scavezzata": "scavezzare",
    "scavezzate": "scavezzare",
    "scavezzati": "scavezzare",
    "scavezzato": "scavezzare",
    "scavezzava": "scavezzare",
    "scavezzavamo": "scavezzare",
    "scavezzavan": "scavezzare",
    "scavezzavano": "scavezzare",
    "scavezzavate": "scavezzare",
    "scavezzavi": "scavezzare",
    "scavezzavo": "scavezzare",
    "scavezzerai": "scavezzare",
    "scavezzeran": "scavezzare",
    "scavezzeranno": "scavezzare",
    "scavezzerebbe": "scavezzare",
    "scavezzerebber": "scavezzare",
    "scavezzerebbero": "scavezzare",
    "scavezzerei": "scavezzare",
    "scavezzeremmo": "scavezzare",
    "scavezzeremo": "scavezzare",
    "scavezzereste": "scavezzare",
    "scavezzeresti": "scavezzare",
    "scavezzerete": "scavezzare",
    "scavezzerà": "scavezzare",
    "scavezzerò": "scavezzare",
    "scavezzi": "scavezzare",
    "scavezziamo": "scavezzare",
    "scavezziate": "scavezzare",
    "scavezzin": "scavezzare",
    "scavezzino": "scavezzare",
    "scavezzo": "scavezzare",
    "scavezzò": "scavezzare",
    "scavi": "scavo",
    "scaviamo": "scavare",
    "scaviate": "scavare",
    "scavin": "scavare",
    "scavino": "scavare",
    "scavo": "scavare",
    "scavò": "scavare",
    "scazzotta": "scazzottare",
    "scazzottai": "scazzottare",
    "scazzottammo": "scazzottare",
    "scazzottan": "scazzottare",
    "scazzottando": "scazzottare",
    "scazzottano": "scazzottare",
    "scazzottante": "scazzottare",
    "scazzottanti": "scazzottare",
    "scazzottar": "scazzottare",
    "scazzottaron": "scazzottare",
    "scazzottarono": "scazzottare",
    "scazzottasse": "scazzottare",
    "scazzottasser": "scazzottare",
    "scazzottassero": "scazzottare",
    "scazzottassi": "scazzottare",
    "scazzottassimo": "scazzottare",
    "scazzottaste": "scazzottare",
    "scazzottasti": "scazzottare",
    "scazzottata": "scazzottare",
    "scazzottate": "scazzottata",
    "scazzottati": "scazzottare",
    "scazzottato": "scazzottare",
    "scazzottava": "scazzottare",
    "scazzottavamo": "scazzottare",
    "scazzottavan": "scazzottare",
    "scazzottavano": "scazzottare",
    "scazzottavate": "scazzottare",
    "scazzottavi": "scazzottare",
    "scazzottavo": "scazzottare",
    "scazzotterai": "scazzottare",
    "scazzotteran": "scazzottare",
    "scazzotteranno": "scazzottare",
    "scazzotterebbe": "scazzottare",
    "scazzotterebber": "scazzottare",
    "scazzotterebbero": "scazzottare",
    "scazzotterei": "scazzottare",
    "scazzotteremmo": "scazzottare",
    "scazzotteremo": "scazzottare",
    "scazzottereste": "scazzottare",
    "scazzotteresti": "scazzottare",
    "scazzotterete": "scazzottare",
    "scazzotterà": "scazzottare",
    "scazzotterò": "scazzottare",
    "scazzotti": "scazzottare",
    "scazzottiamo": "scazzottare",
    "scazzottiate": "scazzottare",
    "scazzottin": "scazzottare",
    "scazzottino": "scazzottare",
    "scazzotto": "scazzottare",
    "scazzottò": "scazzottare",
    "scegli": "scegliere",
    "scegliamo": "scegliere",
    "scegliate": "scegliere",
    "sceglie": "scegliere",
    "scegliemmo": "scegliere",
    "scegliendo": "scegliere",
    "scegliente": "scegliere",
    "sceglienti": "scegliere",
    "sceglier": "scegliere",
    "sceglierai": "scegliere",
    "sceglieran": "scegliere",
    "sceglieranno": "scegliere",
    "sceglierebbe": "scegliere",
    "sceglierebber": "scegliere",
    "sceglierebbero": "scegliere",
    "sceglierei": "scegliere",
    "sceglieremmo": "scegliere",
    "sceglieremo": "scegliere",
    "scegliereste": "scegliere",
    "sceglieresti": "scegliere",
    "sceglierete": "scegliere",
    "sceglierà": "scegliere",
    "sceglierò": "scegliere",
    "scegliesse": "scegliere",
    "scegliesser": "scegliere",
    "scegliessero": "scegliere",
    "scegliessi": "scegliere",
    "scegliessimo": "scegliere",
    "sceglieste": "scegliere",
    "scegliesti": "scegliere",
    "scegliete": "scegliere",
    "sceglieva": "scegliere",
    "sceglievamo": "scegliere",
    "sceglievan": "scegliere",
    "sceglievano": "scegliere",
    "sceglievate": "scegliere",
    "sceglievi": "scegliere",
    "sceglievo": "scegliere",
    "sceicchi": "sceicco",
    "scelga": "scegliere",
    "scelgan": "scegliere",
    "scelgano": "scegliere",
    "scelgo": "scegliere",
    "scelgon": "scegliere",
    "scelgono": "scegliere",
    "scellerata": "scellerato",
    "scellerate": "scellerato",
    "scelleratezze": "scelleratezza",
    "scellerati": "scellerato",
    "scellini": "scellino",
    "scelser": "scegliere",
    "scelsero": "scegliere",
    "scelsi": "scegliere",
    "scelsè": "scegliere",
    "scelta": "scelto",
    "scelte": "scelto",
    "scelti": "scelto",
    "scelto": "scegliere",
    "scema": "scemo",
    "scemai": "scemare",
    "scemammo": "scemare",
    "sceman": "scemare",
    "scemando": "scemare",
    "scemano": "scemare",
    "scemante": "scemare",
    "scemanti": "scemare",
    "scemar": "scemare",
    "scemaron": "scemare",
    "scemarono": "scemare",
    "scemasse": "scemare",
    "scemasser": "scemare",
    "scemassero": "scemare",
    "scemassi": "scemare",
    "scemassimo": "scemare",
    "scemaste": "scemare",
    "scemasti": "scemare",
    "scemata": "scemare",
    "scemate": "scemare",
    "scemati": "scemare",
    "scemato": "scemare",
    "scemava": "scemare",
    "scemavamo": "scemare",
    "scemavan": "scemare",
    "scemavano": "scemare",
    "scemavate": "scemare",
    "scemavi": "scemare",
    "scemavo": "scemare",
    "sceme": "scemo",
    "scemenze": "scemenza",
    "scemerai": "scemare",
    "scemeran": "scemare",
    "scemeranno": "scemare",
    "scemerebbe": "scemare",
    "scemerebber": "scemare",
    "scemerebbero": "scemare",
    "scemerei": "scemare",
    "scemeremmo": "scemare",
    "scemeremo": "scemare",
    "scemereste": "scemare",
    "scemeresti": "scemare",
    "scemerete": "scemare",
    "scemerà": "scemare",
    "scemerò": "scemare",
    "scemi": "scemo",
    "scemiamo": "scemare",
    "scemiate": "scemare",
    "scemin": "scemare",
    "scemino": "scemare",
    "scemo": "scemare",
    "scempi": "scempio",
    "scempia": "scempio",
    "scempiaggini": "scempiaggine",
    "scempiai": "scempiare",
    "scempiammo": "scempiare",
    "scempiamo": "scempiare",
    "scempian": "scempiare",
    "scempiando": "scempiare",
    "scempiano": "scempiare",
    "scempiante": "scempiare",
    "scempianti": "scempiare",
    "scempiar": "scempiare",
    "scempiaron": "scempiare",
    "scempiarono": "scempiare",
    "scempiasse": "scempiare",
    "scempiasser": "scempiare",
    "scempiassero": "scempiare",
    "scempiassi": "scempiare",
    "scempiassimo": "scempiare",
    "scempiaste": "scempiare",
    "scempiasti": "scempiare",
    "scempiata": "scempiare",
    "scempiate": "scempiare",
    "scempiati": "scempiare",
    "scempiato": "scempiare",
    "scempiava": "scempiare",
    "scempiavamo": "scempiare",
    "scempiavan": "scempiare",
    "scempiavano": "scempiare",
    "scempiavate": "scempiare",
    "scempiavi": "scempiare",
    "scempiavo": "scempiare",
    "scempie": "scempio",
    "scempierai": "scempiare",
    "scempieran": "scempiare",
    "scempieranno": "scempiare",
    "scempierebbe": "scempiare",
    "scempierebber": "scempiare",
    "scempierebbero": "scempiare",
    "scempierei": "scempiare",
    "scempieremmo": "scempiare",
    "scempieremo": "scempiare",
    "scempiereste": "scempiare",
    "scempieresti": "scempiare",
    "scempierete": "scempiare",
    "scempierà": "scempiare",
    "scempierò": "scempiare",
    "scempin": "scempiare",
    "scempino": "scempiare",
    "scempio": "scempiare",
    "scempiò": "scempiare",
    "scemò": "scemare",
    "scenari": "scenario",
    "scenate": "scenata",
    "scenda": "scendere",
    "scendan": "scendere",
    "scendano": "scendere",
    "scende": "scendere",
    "scendemmo": "scendere",
    "scendendo": "scendere",
    "scendente": "scendere",
    "scendenti": "scendere",
    "scender": "scendere",
    "scenderai": "scendere",
    "scenderan": "scendere",
    "scenderanno": "scendere",
    "scenderebbe": "scendere",
    "scenderebber": "scendere",
    "scenderebbero": "scendere",
    "scenderei": "scendere",
    "scenderemmo": "scendere",
    "scenderemo": "scendere",
    "scendereste": "scendere",
    "scenderesti": "scendere",
    "scenderete": "scendere",
    "scenderà": "scendere",
    "scenderò": "scendere",
    "scendesse": "scendere",
    "scendesser": "scendere",
    "scendessero": "scendere",
    "scendessi": "scendere",
    "scendessimo": "scendere",
    "scendeste": "scendere",
    "scendesti": "scendere",
    "scendete": "scendere",
    "scendeva": "scendere",
    "scendevamo": "scendere",
    "scendevan": "scendere",
    "scendevano": "scendere",
    "scendevate": "scendere",
    "scendevi": "scendere",
    "scendevo": "scendere",
    "scendi": "scendere",
    "scendiamo": "scendere",
    "scendiate": "scendere",
    "scendo": "scendere",
    "scendon": "scendere",
    "scendono": "scendere",
    "scene": "scena",
    "sceneggerai": "sceneggiare",
    "sceneggeran": "sceneggiare",
    "sceneggeranno": "sceneggiare",
    "sceneggerebbe": "sceneggiare",
    "sceneggerebber": "sceneggiare",
    "sceneggerebbero": "sceneggiare",
    "sceneggerei": "sceneggiare",
    "sceneggeremmo": "sceneggiare",
    "sceneggeremo": "sceneggiare",
    "sceneggereste": "sceneggiare",
    "sceneggeresti": "sceneggiare",
    "sceneggerete": "sceneggiare",
    "sceneggerà": "sceneggiare",
    "sceneggerò": "sceneggiare",
    "sceneggi": "sceneggiare",
    "sceneggia": "sceneggiare",
    "sceneggiai": "sceneggiare",
    "sceneggiammo": "sceneggiare",
    "sceneggiamo": "sceneggiare",
    "sceneggian": "sceneggiare",
    "sceneggiando": "sceneggiare",
    "sceneggiano": "sceneggiare",
    "sceneggiante": "sceneggiare",
    "sceneggianti": "sceneggiare",
    "sceneggiar": "sceneggiare",
    "sceneggiaron": "sceneggiare",
    "sceneggiarono": "sceneggiare",
    "sceneggiasse": "sceneggiare",
    "sceneggiasser": "sceneggiare",
    "sceneggiassero": "sceneggiare",
    "sceneggiassi": "sceneggiare",
    "sceneggiassimo": "sceneggiare",
    "sceneggiaste": "sceneggiare",
    "sceneggiasti": "sceneggiare",
    "sceneggiata": "sceneggiato",
    "sceneggiate": "sceneggiato",
    "sceneggiati": "sceneggiato",
    "sceneggiato": "sceneggiare",
    "sceneggiatori": "sceneggiatore",
    "sceneggiatrici": "sceneggiatrice",
    "sceneggiature": "sceneggiatura",
    "sceneggiava": "sceneggiare",
    "sceneggiavamo": "sceneggiare",
    "sceneggiavan": "sceneggiare",
    "sceneggiavano": "sceneggiare",
    "sceneggiavate": "sceneggiare",
    "sceneggiavi": "sceneggiare",
    "sceneggiavo": "sceneggiare",
    "sceneggin": "sceneggiare",
    "sceneggino": "sceneggiare",
    "sceneggio": "sceneggiare",
    "sceneggiò": "sceneggiare",
    "scenette": "scenetta",
    "scenica": "scenico",
    "sceniche": "scenico",
    "scenici": "scenico",
    "scenografi": "scenografo",
    "scenografica": "scenografico",
    "scenografiche": "scenografico",
    "scenografici": "scenografico",
    "scenografie": "scenografia",
    "scerai": "sciare",
    "sceran": "sciare",
    "sceranno": "sciare",
    "scerebbe": "sciare",
    "scerebber": "sciare",
    "scerebbero": "sciare",
    "scerei": "sciare",
    "sceremmo": "sciare",
    "sceremo": "sciare",
    "scereste": "sciare",
    "sceresti": "sciare",
    "scerete": "sciare",
    "sceriffi": "sceriffo",
    "sceriffiana": "sceriffiano",
    "sceriffiane": "sceriffiano",
    "sceriffiani": "sceriffiano",
    "scerne": "scernere",
    "scernei": "scernere",
    "scernemmo": "scernere",
    "scernendo": "scernere",
    "scernente": "scernere",
    "scernenti": "scernere",
    "scerner": "scernere",
    "scernerai": "scernere",
    "scerneran": "scernere",
    "scerneranno": "scernere",
    "scernerebbe": "scernere",
    "scernerebber": "scernere",
    "scernerebbero": "scernere",
    "scernerei": "scernere",
    "scerneremmo": "scernere",
    "scerneremo": "scernere",
    "scernereste": "scernere",
    "scerneresti": "scernere",
    "scernerete": "scernere",
    "scerneron": "scernere",
    "scernerono": "scernere",
    "scernerà": "scernere",
    "scernerò": "scernere",
    "scernesse": "scernere",
    "scernesser": "scernere",
    "scernessero": "scernere",
    "scernessi": "scernere",
    "scernessimo": "scernere",
    "scerneste": "scernere",
    "scernesti": "scernere",
    "scernete": "scernere",
    "scerneva": "scernere",
    "scernevamo": "scernere",
    "scernevan": "scernere",
    "scernevano": "scernere",
    "scernevate": "scernere",
    "scernevi": "scernere",
    "scernevo": "scernere",
    "scernga": "scernere",
    "scerngan": "scernere",
    "scerngano": "scernere",
    "scerngo": "scernere",
    "scerngon": "scernere",
    "scerngono": "scernere",
    "scerni": "scernere",
    "scerniamo": "scernere",
    "scerniate": "scernere",
    "scernuta": "scernere",
    "scernute": "scernere",
    "scernuti": "scernere",
    "scernuto": "scernere",
    "scernè": "scernere",
    "scervella": "scervellare",
    "scervellai": "scervellare",
    "scervellammo": "scervellare",
    "scervellan": "scervellare",
    "scervellando": "scervellare",
    "scervellano": "scervellare",
    "scervellar": "scervellare",
    "scervellaron": "scervellare",
    "scervellarono": "scervellare",
    "scervellasse": "scervellare",
    "scervellasser": "scervellare",
    "scervellassero": "scervellare",
    "scervellassi": "scervellare",
    "scervellassimo": "scervellare",
    "scervellaste": "scervellare",
    "scervellasti": "scervellare",
    "scervellata": "scervellato",
    "scervellate": "scervellato",
    "scervellati": "scervellato",
    "scervellato": "scervellare",
    "scervellava": "scervellare",
    "scervellavamo": "scervellare",
    "scervellavan": "scervellare",
    "scervellavano": "scervellare",
    "scervellavate": "scervellare",
    "scervellavi": "scervellare",
    "scervellavo": "scervellare",
    "scervellerai": "scervellare",
    "scervelleran": "scervellare",
    "scervelleranno": "scervellare",
    "scervellerebbe": "scervellare",
    "scervellerebber": "scervellare",
    "scervellerebbero": "scervellare",
    "scervellerei": "scervellare",
    "scervelleremmo": "scervellare",
    "scervelleremo": "scervellare",
    "scervellereste": "scervellare",
    "scervelleresti": "scervellare",
    "scervellerete": "scervellare",
    "scervellerà": "scervellare",
    "scervellerò": "scervellare",
    "scervelli": "scervellare",
    "scervelliamo": "scervellare",
    "scervelliate": "scervellare",
    "scervellin": "scervellare",
    "scervellino": "scervellare",
    "scervello": "scervellare",
    "scervellò": "scervellare",
    "scerà": "sciare",
    "scerò": "sciare",
    "scesa": "scendere",
    "scese": "scendere",
    "sceser": "scendere",
    "scesero": "scendere",
    "scesi": "scendere",
    "sceso": "scendere",
    "scesè": "scendere",
    "scettica": "scettico",
    "scettiche": "scettico",
    "scettici": "scettico",
    "scetticismi": "scetticismo",
    "scettri": "scettro",
    "scevera": "sceverare",
    "sceverai": "sceverare",
    "sceverammo": "sceverare",
    "sceveran": "sceverare",
    "sceverando": "sceverare",
    "sceverano": "sceverare",
    "sceverante": "sceverare",
    "sceveranti": "sceverare",
    "sceverar": "sceverare",
    "sceveraron": "sceverare",
    "sceverarono": "sceverare",
    "sceverasse": "sceverare",
    "sceverasser": "sceverare",
    "sceverassero": "sceverare",
    "sceverassi": "sceverare",
    "sceverassimo": "sceverare",
    "sceveraste": "sceverare",
    "sceverasti": "sceverare",
    "sceverata": "sceverare",
    "sceverate": "sceverare",
    "sceverati": "sceverare",
    "sceverato": "sceverare",
    "sceverava": "sceverare",
    "sceveravamo": "sceverare",
    "sceveravan": "sceverare",
    "sceveravano": "sceverare",
    "sceveravate": "sceverare",
    "sceveravi": "sceverare",
    "sceveravo": "sceverare",
    "scevererai": "sceverare",
    "scevereran": "sceverare",
    "scevereranno": "sceverare",
    "scevererebbe": "sceverare",
    "scevererebber": "sceverare",
    "scevererebbero": "sceverare",
    "scevererei": "sceverare",
    "scevereremmo": "sceverare",
    "scevereremo": "sceverare",
    "sceverereste": "sceverare",
    "scevereresti": "sceverare",
    "scevererete": "sceverare",
    "scevererà": "sceverare",
    "scevererò": "sceverare",
    "sceveri": "sceverare",
    "sceveriamo": "sceverare",
    "sceveriate": "sceverare",
    "sceverin": "sceverare",
    "sceverino": "sceverare",
    "scevero": "sceverare",
    "sceverò": "sceverare",
    "scevra": "scevro",
    "scevre": "scevro",
    "scevri": "scevro",
    "scheda": "schedare",
    "schedai": "schedare",
    "schedammo": "schedare",
    "schedan": "schedare",
    "schedando": "schedare",
    "schedano": "schedare",
    "schedante": "schedare",
    "schedanti": "schedare",
    "schedar": "schedare",
    "schedari": "schedario",
    "schedaron": "schedare",
    "schedarono": "schedare",
    "schedasse": "schedare",
    "schedasser": "schedare",
    "schedassero": "schedare",
    "schedassi": "schedare",
    "schedassimo": "schedare",
    "schedaste": "schedare",
    "schedasti": "schedare",
    "schedata": "schedato",
    "schedate": "schedato",
    "schedati": "schedato",
    "schedato": "schedare",
    "schedature": "schedatura",
    "schedava": "schedare",
    "schedavamo": "schedare",
    "schedavan": "schedare",
    "schedavano": "schedare",
    "schedavate": "schedare",
    "schedavi": "schedare",
    "schedavo": "schedare",
    "schede": "scheda",
    "schederai": "schedare",
    "schederan": "schedare",
    "schederanno": "schedare",
    "schederebbe": "schedare",
    "schederebber": "schedare",
    "schederebbero": "schedare",
    "schederei": "schedare",
    "schederemmo": "schedare",
    "schederemo": "schedare",
    "schedereste": "schedare",
    "schederesti": "schedare",
    "schederete": "schedare",
    "schederà": "schedare",
    "schederò": "schedare",
    "schedi": "schedare",
    "schediamo": "schedare",
    "schediate": "schedare",
    "schedin": "schedare",
    "schedine": "schedina",
    "schedino": "schedare",
    "schedo": "schedare",
    "schedò": "schedare",
    "schegge": "scheggia",
    "scheggerai": "scheggiare",
    "scheggeran": "scheggiare",
    "scheggeranno": "scheggiare",
    "scheggerebbe": "scheggiare",
    "scheggerebber": "scheggiare",
    "scheggerebbero": "scheggiare",
    "scheggerei": "scheggiare",
    "scheggeremmo": "scheggiare",
    "scheggeremo": "scheggiare",
    "scheggereste": "scheggiare",
    "scheggeresti": "scheggiare",
    "scheggerete": "scheggiare",
    "scheggerà": "scheggiare",
    "scheggerò": "scheggiare",
    "scheggi": "scheggiare",
    "scheggia": "scheggiare",
    "scheggiai": "scheggiare",
    "scheggiammo": "scheggiare",
    "scheggiamo": "scheggiare",
    "scheggian": "scheggiare",
    "scheggiando": "scheggiare",
    "scheggiano": "scheggiare",
    "scheggiante": "scheggiare",
    "scheggianti": "scheggiare",
    "scheggiar": "scheggiare",
    "scheggiaron": "scheggiare",
    "scheggiarono": "scheggiare",
    "scheggiasse": "scheggiare",
    "scheggiasser": "scheggiare",
    "scheggiassero": "scheggiare",
    "scheggiassi": "scheggiare",
    "scheggiassimo": "scheggiare",
    "scheggiaste": "scheggiare",
    "scheggiasti": "scheggiare",
    "scheggiata": "scheggiare",
    "scheggiate": "scheggiare",
    "scheggiati": "scheggiare",
    "scheggiato": "scheggiare",
    "scheggiava": "scheggiare",
    "scheggiavamo": "scheggiare",
    "scheggiavan": "scheggiare",
    "scheggiavano": "scheggiare",
    "scheggiavate": "scheggiare",
    "scheggiavi": "scheggiare",
    "scheggiavo": "scheggiare",
    "scheggin": "scheggiare",
    "scheggino": "scheggiare",
    "scheggio": "scheggiare",
    "scheggiò": "scheggiare",
    "scheletra": "scheletrire",
    "scheletran": "scheletrire",
    "scheletrano": "scheletrire",
    "scheletre": "scheletrire",
    "scheletrendo": "scheletrire",
    "scheletrente": "scheletrire",
    "scheletrenti": "scheletrire",
    "scheletri": "scheletro",
    "scheletriamo": "scheletrire",
    "scheletriate": "scheletrire",
    "scheletrica": "scheletrico",
    "scheletriche": "scheletrico",
    "scheletrici": "scheletrico",
    "scheletrii": "scheletrire",
    "scheletrimmo": "scheletrire",
    "scheletrir": "scheletrire",
    "scheletrirai": "scheletrire",
    "scheletriran": "scheletrire",
    "scheletriranno": "scheletrire",
    "scheletrirebbe": "scheletrire",
    "scheletrirebber": "scheletrire",
    "scheletrirebbero": "scheletrire",
    "scheletrirei": "scheletrire",
    "scheletriremmo": "scheletrire",
    "scheletriremo": "scheletrire",
    "scheletrireste": "scheletrire",
    "scheletriresti": "scheletrire",
    "scheletrirete": "scheletrire",
    "scheletriron": "scheletrire",
    "scheletrirono": "scheletrire",
    "scheletrirà": "scheletrire",
    "scheletrirò": "scheletrire",
    "scheletrisse": "scheletrire",
    "scheletrisser": "scheletrire",
    "scheletrissero": "scheletrire",
    "scheletrissi": "scheletrire",
    "scheletrissimo": "scheletrire",
    "scheletriste": "scheletrire",
    "scheletristi": "scheletrire",
    "scheletrita": "scheletrire",
    "scheletrite": "scheletrire",
    "scheletriti": "scheletrire",
    "scheletrito": "scheletrire",
    "scheletriva": "scheletrire",
    "scheletrivamo": "scheletrire",
    "scheletrivan": "scheletrire",
    "scheletrivano": "scheletrire",
    "scheletrivate": "scheletrire",
    "scheletrivi": "scheletrire",
    "scheletrivo": "scheletrire",
    "scheletro": "scheletrire",
    "scheletron": "scheletrire",
    "scheletrono": "scheletrire",
    "scheletrì": "scheletrire",
    "schematica": "schematico",
    "schematiche": "schematico",
    "schematici": "schematico",
    "schematismi": "schematismo",
    "schematizza": "schematizzare",
    "schematizzai": "schematizzare",
    "schematizzammo": "schematizzare",
    "schematizzan": "schematizzare",
    "schematizzando": "schematizzare",
    "schematizzano": "schematizzare",
    "schematizzante": "schematizzare",
    "schematizzanti": "schematizzare",
    "schematizzar": "schematizzare",
    "schematizzaron": "schematizzare",
    "schematizzarono": "schematizzare",
    "schematizzasse": "schematizzare",
    "schematizzasser": "schematizzare",
    "schematizzassero": "schematizzare",
    "schematizzassi": "schematizzare",
    "schematizzassimo": "schematizzare",
    "schematizzaste": "schematizzare",
    "schematizzasti": "schematizzare",
    "schematizzata": "schematizzare",
    "schematizzate": "schematizzare",
    "schematizzati": "schematizzare",
    "schematizzato": "schematizzare",
    "schematizzava": "schematizzare",
    "schematizzavamo": "schematizzare",
    "schematizzavan": "schematizzare",
    "schematizzavano": "schematizzare",
    "schematizzavate": "schematizzare",
    "schematizzavi": "schematizzare",
    "schematizzavo": "schematizzare",
    "schematizzazioni": "schematizzazione",
    "schematizzerai": "schematizzare",
    "schematizzeran": "schematizzare",
    "schematizzeranno": "schematizzare",
    "schematizzerebbe": "schematizzare",
    "schematizzerebber": "schematizzare",
    "schematizzerebbero": "schematizzare",
    "schematizzerei": "schematizzare",
    "schematizzeremmo": "schematizzare",
    "schematizzeremo": "schematizzare",
    "schematizzereste": "schematizzare",
    "schematizzeresti": "schematizzare",
    "schematizzerete": "schematizzare",
    "schematizzerà": "schematizzare",
    "schematizzerò": "schematizzare",
    "schematizzi": "schematizzare",
    "schematizziamo": "schematizzare",
    "schematizziate": "schematizzare",
    "schematizzin": "schematizzare",
    "schematizzino": "schematizzare",
    "schematizzo": "schematizzare",
    "schematizzò": "schematizzare",
    "schemi": "schema",
    "schemini": "schemino",
    "scherma": "schermare",
    "schermaglie": "schermaglia",
    "schermai": "schermare",
    "schermammo": "schermare",
    "scherman": "schermare",
    "schermando": "schermare",
    "schermano": "schermare",
    "schermante": "schermare",
    "schermanti": "schermare",
    "schermar": "schermare",
    "schermaron": "schermare",
    "schermarono": "schermare",
    "schermasse": "schermare",
    "schermasser": "schermare",
    "schermassero": "schermare",
    "schermassi": "schermare",
    "schermassimo": "schermare",
    "schermaste": "schermare",
    "schermasti": "schermare",
    "schermata": "schermare",
    "schermate": "schermare",
    "schermati": "schermare",
    "schermato": "schermare",
    "schermava": "schermare",
    "schermavamo": "schermare",
    "schermavan": "schermare",
    "schermavano": "schermare",
    "schermavate": "schermare",
    "schermavi": "schermare",
    "schermavo": "schermare",
    "scherme": "scherma",
    "schermendo": "schermire",
    "schermente": "schermire",
    "schermenti": "schermire",
    "schermerai": "schermare",
    "schermeran": "schermare",
    "schermeranno": "schermare",
    "schermerebbe": "schermare",
    "schermerebber": "schermare",
    "schermerebbero": "schermare",
    "schermerei": "schermare",
    "schermeremmo": "schermare",
    "schermeremo": "schermare",
    "schermereste": "schermare",
    "schermeresti": "schermare",
    "schermerete": "schermare",
    "schermerà": "schermare",
    "schermerò": "schermare",
    "schermi": "schermo",
    "schermiamo": "schermire",
    "schermiate": "schermire",
    "schermidori": "schermidore",
    "schermii": "schermire",
    "schermimmo": "schermire",
    "schermin": "schermare",
    "schermino": "schermare",
    "schermir": "schermire",
    "schermirai": "schermire",
    "schermiran": "schermire",
    "schermiranno": "schermire",
    "schermirebbe": "schermire",
    "schermirebber": "schermire",
    "schermirebbero": "schermire",
    "schermirei": "schermire",
    "schermiremmo": "schermire",
    "schermiremo": "schermire",
    "schermireste": "schermire",
    "schermiresti": "schermire",
    "schermirete": "schermire",
    "schermiron": "schermire",
    "schermirono": "schermire",
    "schermirà": "schermire",
    "schermirò": "schermire",
    "schermisca": "schermire",
    "schermiscan": "schermire",
    "schermiscano": "schermire",
    "schermisce": "schermire",
    "schermisci": "schermire",
    "schermisco": "schermire",
    "schermiscon": "schermire",
    "schermiscono": "schermire",
    "schermisse": "schermire",
    "schermisser": "schermire",
    "schermissero": "schermire",
    "schermissi": "schermire",
    "schermissimo": "schermire",
    "schermiste": "schermire",
    "schermisti": "schermire",
    "schermita": "schermire",
    "schermite": "schermire",
    "schermiti": "schermire",
    "schermito": "schermire",
    "schermitori": "schermitore",
    "schermiva": "schermire",
    "schermivamo": "schermire",
    "schermivan": "schermire",
    "schermivano": "schermire",
    "schermivate": "schermire",
    "schermivi": "schermire",
    "schermivo": "schermire",
    "schermo": "schermare",
    "schermì": "schermire",
    "schermò": "schermare",
    "schernendo": "schernire",
    "schernente": "schernire",
    "schernenti": "schernire",
    "scherni": "scherno",
    "scherniamo": "schernire",
    "scherniate": "schernire",
    "schernii": "schernire",
    "schernimmo": "schernire",
    "schernir": "schernire",
    "schernirai": "schernire",
    "scherniran": "schernire",
    "scherniranno": "schernire",
    "schernirebbe": "schernire",
    "schernirebber": "schernire",
    "schernirebbero": "schernire",
    "schernirei": "schernire",
    "scherniremmo": "schernire",
    "scherniremo": "schernire",
    "schernireste": "schernire",
    "scherniresti": "schernire",
    "schernirete": "schernire",
    "scherniron": "schernire",
    "schernirono": "schernire",
    "schernirà": "schernire",
    "schernirò": "schernire",
    "schernisca": "schernire",
    "scherniscan": "schernire",
    "scherniscano": "schernire",
    "schernisce": "schernire",
    "schernisci": "schernire",
    "schernisco": "schernire",
    "scherniscon": "schernire",
    "scherniscono": "schernire",
    "schernisse": "schernire",
    "schernisser": "schernire",
    "schernissero": "schernire",
    "schernissi": "schernire",
    "schernissimo": "schernire",
    "scherniste": "schernire",
    "schernisti": "schernire",
    "schernita": "schernire",
    "schernite": "schernire",
    "scherniti": "schernire",
    "schernito": "schernire",
    "scherniva": "schernire",
    "schernivamo": "schernire",
    "schernivan": "schernire",
    "schernivano": "schernire",
    "schernivate": "schernire",
    "schernivi": "schernire",
    "schernivo": "schernire",
    "schernì": "schernire",
    "scherza": "scherzare",
    "scherzai": "scherzare",
    "scherzammo": "scherzare",
    "scherzan": "scherzare",
    "scherzando": "scherzare",
    "scherzano": "scherzare",
    "scherzante": "scherzare",
    "scherzanti": "scherzare",
    "scherzar": "scherzare",
    "scherzaron": "scherzare",
    "scherzarono": "scherzare",
    "scherzasse": "scherzare",
    "scherzasser": "scherzare",
    "scherzassero": "scherzare",
    "scherzassi": "scherzare",
    "scherzassimo": "scherzare",
    "scherzaste": "scherzare",
    "scherzasti": "scherzare",
    "scherzata": "scherzare",
    "scherzate": "scherzare",
    "scherzati": "scherzare",
    "scherzato": "scherzare",
    "scherzava": "scherzare",
    "scherzavamo": "scherzare",
    "scherzavan": "scherzare",
    "scherzavano": "scherzare",
    "scherzavate": "scherzare",
    "scherzavi": "scherzare",
    "scherzavo": "scherzare",
    "scherzerai": "scherzare",
    "scherzeran": "scherzare",
    "scherzeranno": "scherzare",
    "scherzerebbe": "scherzare",
    "scherzerebber": "scherzare",
    "scherzerebbero": "scherzare",
    "scherzerei": "scherzare",
    "scherzeremmo": "scherzare",
    "scherzeremo": "scherzare",
    "scherzereste": "scherzare",
    "scherzeresti": "scherzare",
    "scherzerete": "scherzare",
    "scherzerà": "scherzare",
    "scherzerò": "scherzare",
    "scherzetti": "scherzetto",
    "scherzi": "scherzo",
    "scherziamo": "scherzare",
    "scherziate": "scherzare",
    "scherzin": "scherzare",
    "scherzino": "scherzare",
    "scherzo": "scherzare",
    "scherzosa": "scherzoso",
    "scherzose": "scherzoso",
    "scherzosi": "scherzoso",
    "scherzò": "scherzare",
    "schettina": "schettinare",
    "schettinai": "schettinare",
    "schettinammo": "schettinare",
    "schettinan": "schettinare",
    "schettinando": "schettinare",
    "schettinano": "schettinare",
    "schettinante": "schettinare",
    "schettinanti": "schettinare",
    "schettinar": "schettinare",
    "schettinaron": "schettinare",
    "schettinarono": "schettinare",
    "schettinasse": "schettinare",
    "schettinasser": "schettinare",
    "schettinassero": "schettinare",
    "schettinassi": "schettinare",
    "schettinassimo": "schettinare",
    "schettinaste": "schettinare",
    "schettinasti": "schettinare",
    "schettinata": "schettinare",
    "schettinate": "schettinare",
    "schettinati": "schettinare",
    "schettinato": "schettinare",
    "schettinava": "schettinare",
    "schettinavamo": "schettinare",
    "schettinavan": "schettinare",
    "schettinavano": "schettinare",
    "schettinavate": "schettinare",
    "schettinavi": "schettinare",
    "schettinavo": "schettinare",
    "schettinerai": "schettinare",
    "schettineran": "schettinare",
    "schettineranno": "schettinare",
    "schettinerebbe": "schettinare",
    "schettinerebber": "schettinare",
    "schettinerebbero": "schettinare",
    "schettinerei": "schettinare",
    "schettineremmo": "schettinare",
    "schettineremo": "schettinare",
    "schettinereste": "schettinare",
    "schettineresti": "schettinare",
    "schettinerete": "schettinare",
    "schettinerà": "schettinare",
    "schettinerò": "schettinare",
    "schettini": "schettinare",
    "schettiniamo": "schettinare",
    "schettiniate": "schettinare",
    "schettinin": "schettinare",
    "schettinino": "schettinare",
    "schettino": "schettinare",
    "schettinò": "schettinare",
    "schiaccerai": "schiacciare",
    "schiacceran": "schiacciare",
    "schiacceranno": "schiacciare",
    "schiaccerebbe": "schiacciare",
    "schiaccerebber": "schiacciare",
    "schiaccerebbero": "schiacciare",
    "schiaccerei": "schiacciare",
    "schiacceremmo": "schiacciare",
    "schiacceremo": "schiacciare",
    "schiaccereste": "schiacciare",
    "schiacceresti": "schiacciare",
    "schiaccerete": "schiacciare",
    "schiaccerà": "schiacciare",
    "schiaccerò": "schiacciare",
    "schiacci": "schiacciare",
    "schiaccia": "schiacciare",
    "schiacciai": "schiacciare",
    "schiacciamenti": "schiacciamento",
    "schiacciammo": "schiacciare",
    "schiacciamo": "schiacciare",
    "schiaccian": "schiacciare",
    "schiacciando": "schiacciare",
    "schiacciano": "schiacciare",
    "schiacciante": "schiacciare",
    "schiaccianti": "schiacciare",
    "schiacciar": "schiacciare",
    "schiacciaron": "schiacciare",
    "schiacciarono": "schiacciare",
    "schiacciasse": "schiacciare",
    "schiacciasser": "schiacciare",
    "schiacciassero": "schiacciare",
    "schiacciassi": "schiacciare",
    "schiacciassimo": "schiacciare",
    "schiacciaste": "schiacciare",
    "schiacciasti": "schiacciare",
    "schiacciata": "schiacciato",
    "schiacciate": "schiacciato",
    "schiacciati": "schiacciato",
    "schiacciato": "schiacciare",
    "schiacciatori": "schiacciatore",
    "schiacciava": "schiacciare",
    "schiacciavamo": "schiacciare",
    "schiacciavan": "schiacciare",
    "schiacciavano": "schiacciare",
    "schiacciavate": "schiacciare",
    "schiacciavi": "schiacciare",
    "schiacciavo": "schiacciare",
    "schiaccin": "schiacciare",
    "schiaccino": "schiacciare",
    "schiaccio": "schiacciare",
    "schiacciò": "schiacciare",
    "schiaffa": "schiaffare",
    "schiaffai": "schiaffare",
    "schiaffammo": "schiaffare",
    "schiaffan": "schiaffare",
    "schiaffando": "schiaffare",
    "schiaffano": "schiaffare",
    "schiaffante": "schiaffare",
    "schiaffanti": "schiaffare",
    "schiaffar": "schiaffare",
    "schiaffaron": "schiaffare",
    "schiaffarono": "schiaffare",
    "schiaffasse": "schiaffare",
    "schiaffasser": "schiaffare",
    "schiaffassero": "schiaffare",
    "schiaffassi": "schiaffare",
    "schiaffassimo": "schiaffare",
    "schiaffaste": "schiaffare",
    "schiaffasti": "schiaffare",
    "schiaffata": "schiaffare",
    "schiaffate": "schiaffare",
    "schiaffati": "schiaffare",
    "schiaffato": "schiaffare",
    "schiaffava": "schiaffare",
    "schiaffavamo": "schiaffare",
    "schiaffavan": "schiaffare",
    "schiaffavano": "schiaffare",
    "schiaffavate": "schiaffare",
    "schiaffavi": "schiaffare",
    "schiaffavo": "schiaffare",
    "schiaffeggerai": "schiaffeggiare",
    "schiaffeggeran": "schiaffeggiare",
    "schiaffeggeranno": "schiaffeggiare",
    "schiaffeggerebbe": "schiaffeggiare",
    "schiaffeggerebber": "schiaffeggiare",
    "schiaffeggerebbero": "schiaffeggiare",
    "schiaffeggerei": "schiaffeggiare",
    "schiaffeggeremmo": "schiaffeggiare",
    "schiaffeggeremo": "schiaffeggiare",
    "schiaffeggereste": "schiaffeggiare",
    "schiaffeggeresti": "schiaffeggiare",
    "schiaffeggerete": "schiaffeggiare",
    "schiaffeggerà": "schiaffeggiare",
    "schiaffeggerò": "schiaffeggiare",
    "schiaffeggi": "schiaffeggiare",
    "schiaffeggia": "schiaffeggiare",
    "schiaffeggiai": "schiaffeggiare",
    "schiaffeggiammo": "schiaffeggiare",
    "schiaffeggiamo": "schiaffeggiare",
    "schiaffeggian": "schiaffeggiare",
    "schiaffeggiando": "schiaffeggiare",
    "schiaffeggiano": "schiaffeggiare",
    "schiaffeggiante": "schiaffeggiare",
    "schiaffeggianti": "schiaffeggiare",
    "schiaffeggiar": "schiaffeggiare",
    "schiaffeggiaron": "schiaffeggiare",
    "schiaffeggiarono": "schiaffeggiare",
    "schiaffeggiasse": "schiaffeggiare",
    "schiaffeggiasser": "schiaffeggiare",
    "schiaffeggiassero": "schiaffeggiare",
    "schiaffeggiassi": "schiaffeggiare",
    "schiaffeggiassimo": "schiaffeggiare",
    "schiaffeggiaste": "schiaffeggiare",
    "schiaffeggiasti": "schiaffeggiare",
    "schiaffeggiata": "schiaffeggiare",
    "schiaffeggiate": "schiaffeggiare",
    "schiaffeggiati": "schiaffeggiare",
    "schiaffeggiato": "schiaffeggiare",
    "schiaffeggiava": "schiaffeggiare",
    "schiaffeggiavamo": "schiaffeggiare",
    "schiaffeggiavan": "schiaffeggiare",
    "schiaffeggiavano": "schiaffeggiare",
    "schiaffeggiavate": "schiaffeggiare",
    "schiaffeggiavi": "schiaffeggiare",
    "schiaffeggiavo": "schiaffeggiare",
    "schiaffeggin": "schiaffeggiare",
    "schiaffeggino": "schiaffeggiare",
    "schiaffeggio": "schiaffeggiare",
    "schiaffeggiò": "schiaffeggiare",
    "schiafferai": "schiaffare",
    "schiafferan": "schiaffare",
    "schiafferanno": "schiaffare",
    "schiafferebbe": "schiaffare",
    "schiafferebber": "schiaffare",
    "schiafferebbero": "schiaffare",
    "schiafferei": "schiaffare",
    "schiafferemmo": "schiaffare",
    "schiafferemo": "schiaffare",
    "schiaffereste": "schiaffare",
    "schiafferesti": "schiaffare",
    "schiafferete": "schiaffare",
    "schiafferà": "schiaffare",
    "schiafferò": "schiaffare",
    "schiaffi": "schiaffo",
    "schiaffiamo": "schiaffare",
    "schiaffiate": "schiaffare",
    "schiaffin": "schiaffare",
    "schiaffino": "schiaffare",
    "schiaffo": "schiaffare",
    "schiaffoni": "schiaffone",
    "schiaffò": "schiaffare",
    "schiamazza": "schiamazzare",
    "schiamazzai": "schiamazzare",
    "schiamazzammo": "schiamazzare",
    "schiamazzan": "schiamazzare",
    "schiamazzando": "schiamazzare",
    "schiamazzano": "schiamazzare",
    "schiamazzante": "schiamazzare",
    "schiamazzanti": "schiamazzare",
    "schiamazzar": "schiamazzare",
    "schiamazzaron": "schiamazzare",
    "schiamazzarono": "schiamazzare",
    "schiamazzasse": "schiamazzare",
    "schiamazzasser": "schiamazzare",
    "schiamazzassero": "schiamazzare",
    "schiamazzassi": "schiamazzare",
    "schiamazzassimo": "schiamazzare",
    "schiamazzaste": "schiamazzare",
    "schiamazzasti": "schiamazzare",
    "schiamazzata": "schiamazzare",
    "schiamazzate": "schiamazzare",
    "schiamazzati": "schiamazzare",
    "schiamazzato": "schiamazzare",
    "schiamazzava": "schiamazzare",
    "schiamazzavamo": "schiamazzare",
    "schiamazzavan": "schiamazzare",
    "schiamazzavano": "schiamazzare",
    "schiamazzavate": "schiamazzare",
    "schiamazzavi": "schiamazzare",
    "schiamazzavo": "schiamazzare",
    "schiamazzerai": "schiamazzare",
    "schiamazzeran": "schiamazzare",
    "schiamazzeranno": "schiamazzare",
    "schiamazzerebbe": "schiamazzare",
    "schiamazzerebber": "schiamazzare",
    "schiamazzerebbero": "schiamazzare",
    "schiamazzerei": "schiamazzare",
    "schiamazzeremmo": "schiamazzare",
    "schiamazzeremo": "schiamazzare",
    "schiamazzereste": "schiamazzare",
    "schiamazzeresti": "schiamazzare",
    "schiamazzerete": "schiamazzare",
    "schiamazzerà": "schiamazzare",
    "schiamazzerò": "schiamazzare",
    "schiamazzi": "schiamazzo",
    "schiamazziamo": "schiamazzare",
    "schiamazziate": "schiamazzare",
    "schiamazzin": "schiamazzare",
    "schiamazzino": "schiamazzare",
    "schiamazzo": "schiamazzare",
    "schiamazzò": "schiamazzare",
    "schianta": "schiantare",
    "schiantai": "schiantare",
    "schiantammo": "schiantare",
    "schiantan": "schiantare",
    "schiantando": "schiantare",
    "schiantano": "schiantare",
    "schiantante": "schiantare",
    "schiantanti": "schiantare",
    "schiantar": "schiantare",
    "schiantaron": "schiantare",
    "schiantarono": "schiantare",
    "schiantasse": "schiantare",
    "schiantasser": "schiantare",
    "schiantassero": "schiantare",
    "schiantassi": "schiantare",
    "schiantassimo": "schiantare",
    "schiantaste": "schiantare",
    "schiantasti": "schiantare",
    "schiantata": "schiantare",
    "schiantate": "schiantare",
    "schiantati": "schiantare",
    "schiantato": "schiantare",
    "schiantava": "schiantare",
    "schiantavamo": "schiantare",
    "schiantavan": "schiantare",
    "schiantavano": "schiantare",
    "schiantavate": "schiantare",
    "schiantavi": "schiantare",
    "schiantavo": "schiantare",
    "schianterai": "schiantare",
    "schianteran": "schiantare",
    "schianteranno": "schiantare",
    "schianterebbe": "schiantare",
    "schianterebber": "schiantare",
    "schianterebbero": "schiantare",
    "schianterei": "schiantare",
    "schianteremmo": "schiantare",
    "schianteremo": "schiantare",
    "schiantereste": "schiantare",
    "schianteresti": "schiantare",
    "schianterete": "schiantare",
    "schianterà": "schiantare",
    "schianterò": "schiantare",
    "schianti": "schianto",
    "schiantiamo": "schiantare",
    "schiantiate": "schiantare",
    "schiantin": "schiantare",
    "schiantino": "schiantare",
    "schianto": "schiantare",
    "schiantò": "schiantare",
    "schiappe": "schiappa",
    "schiarendo": "schiarire",
    "schiarente": "schiarire",
    "schiarenti": "schiarire",
    "schiariamo": "schiarire",
    "schiariate": "schiarire",
    "schiarii": "schiarire",
    "schiarimmo": "schiarire",
    "schiarir": "schiarire",
    "schiarirai": "schiarire",
    "schiariran": "schiarire",
    "schiariranno": "schiarire",
    "schiarirebbe": "schiarire",
    "schiarirebber": "schiarire",
    "schiarirebbero": "schiarire",
    "schiarirei": "schiarire",
    "schiariremmo": "schiarire",
    "schiariremo": "schiarire",
    "schiarireste": "schiarire",
    "schiariresti": "schiarire",
    "schiarirete": "schiarire",
    "schiariron": "schiarire",
    "schiarirono": "schiarire",
    "schiarirà": "schiarire",
    "schiarirò": "schiarire",
    "schiarisca": "schiarire",
    "schiariscan": "schiarire",
    "schiariscano": "schiarire",
    "schiarisce": "schiarire",
    "schiarisci": "schiarire",
    "schiarisco": "schiarire",
    "schiariscon": "schiarire",
    "schiariscono": "schiarire",
    "schiarisse": "schiarire",
    "schiarisser": "schiarire",
    "schiarissero": "schiarire",
    "schiarissi": "schiarire",
    "schiarissimo": "schiarire",
    "schiariste": "schiarire",
    "schiaristi": "schiarire",
    "schiarita": "schiarire",
    "schiarite": "schiarita",
    "schiariti": "schiarire",
    "schiarito": "schiarire",
    "schiariva": "schiarire",
    "schiarivamo": "schiarire",
    "schiarivan": "schiarire",
    "schiarivano": "schiarire",
    "schiarivate": "schiarire",
    "schiarivi": "schiarire",
    "schiarivo": "schiarire",
    "schiarì": "schiarire",
    "schiatta": "schiattare",
    "schiattai": "schiattare",
    "schiattammo": "schiattare",
    "schiattan": "schiattare",
    "schiattando": "schiattare",
    "schiattano": "schiattare",
    "schiattante": "schiattare",
    "schiattanti": "schiattare",
    "schiattar": "schiattare",
    "schiattaron": "schiattare",
    "schiattarono": "schiattare",
    "schiattasse": "schiattare",
    "schiattasser": "schiattare",
    "schiattassero": "schiattare",
    "schiattassi": "schiattare",
    "schiattassimo": "schiattare",
    "schiattaste": "schiattare",
    "schiattasti": "schiattare",
    "schiattata": "schiattare",
    "schiattate": "schiattare",
    "schiattati": "schiattare",
    "schiattato": "schiattare",
    "schiattava": "schiattare",
    "schiattavamo": "schiattare",
    "schiattavan": "schiattare",
    "schiattavano": "schiattare",
    "schiattavate": "schiattare",
    "schiattavi": "schiattare",
    "schiattavo": "schiattare",
    "schiatte": "schiatta",
    "schiatterai": "schiattare",
    "schiatteran": "schiattare",
    "schiatteranno": "schiattare",
    "schiatterebbe": "schiattare",
    "schiatterebber": "schiattare",
    "schiatterebbero": "schiattare",
    "schiatterei": "schiattare",
    "schiatteremmo": "schiattare",
    "schiatteremo": "schiattare",
    "schiattereste": "schiattare",
    "schiatteresti": "schiattare",
    "schiatterete": "schiattare",
    "schiatterà": "schiattare",
    "schiatterò": "schiattare",
    "schiatti": "schiattare",
    "schiattiamo": "schiattare",
    "schiattiate": "schiattare",
    "schiattin": "schiattare",
    "schiattino": "schiattare",
    "schiatto": "schiattare",
    "schiattò": "schiattare",
    "schiava": "schiavo",
    "schiave": "schiavo",
    "schiavi": "schiavo",
    "schiavismi": "schiavismo",
    "schiavisti": "schiavista",
    "schiavistica": "schiavistico",
    "schiavistiche": "schiavistico",
    "schiavistici": "schiavistico",
    "schiavizza": "schiavizzare",
    "schiavizzai": "schiavizzare",
    "schiavizzammo": "schiavizzare",
    "schiavizzan": "schiavizzare",
    "schiavizzando": "schiavizzare",
    "schiavizzano": "schiavizzare",
    "schiavizzante": "schiavizzare",
    "schiavizzanti": "schiavizzare",
    "schiavizzar": "schiavizzare",
    "schiavizzaron": "schiavizzare",
    "schiavizzarono": "schiavizzare",
    "schiavizzasse": "schiavizzare",
    "schiavizzasser": "schiavizzare",
    "schiavizzassero": "schiavizzare",
    "schiavizzassi": "schiavizzare",
    "schiavizzassimo": "schiavizzare",
    "schiavizzaste": "schiavizzare",
    "schiavizzasti": "schiavizzare",
    "schiavizzata": "schiavizzare",
    "schiavizzate": "schiavizzare",
    "schiavizzati": "schiavizzare",
    "schiavizzato": "schiavizzare",
    "schiavizzava": "schiavizzare",
    "schiavizzavamo": "schiavizzare",
    "schiavizzavan": "schiavizzare",
    "schiavizzavano": "schiavizzare",
    "schiavizzavate": "schiavizzare",
    "schiavizzavi": "schiavizzare",
    "schiavizzavo": "schiavizzare",
    "schiavizzerai": "schiavizzare",
    "schiavizzeran": "schiavizzare",
    "schiavizzeranno": "schiavizzare",
    "schiavizzerebbe": "schiavizzare",
    "schiavizzerebber": "schiavizzare",
    "schiavizzerebbero": "schiavizzare",
    "schiavizzerei": "schiavizzare",
    "schiavizzeremmo": "schiavizzare",
    "schiavizzeremo": "schiavizzare",
    "schiavizzereste": "schiavizzare",
    "schiavizzeresti": "schiavizzare",
    "schiavizzerete": "schiavizzare",
    "schiavizzerà": "schiavizzare",
    "schiavizzerò": "schiavizzare",
    "schiavizzi": "schiavizzare",
    "schiavizziamo": "schiavizzare",
    "schiavizziate": "schiavizzare",
    "schiavizzin": "schiavizzare",
    "schiavizzino": "schiavizzare",
    "schiavizzo": "schiavizzare",
    "schiavizzò": "schiavizzare",
    "schidiona": "schidionare",
    "schidionai": "schidionare",
    "schidionammo": "schidionare",
    "schidionan": "schidionare",
    "schidionando": "schidionare",
    "schidionano": "schidionare",
    "schidionante": "schidionare",
    "schidionanti": "schidionare",
    "schidionar": "schidionare",
    "schidionaron": "schidionare",
    "schidionarono": "schidionare",
    "schidionasse": "schidionare",
    "schidionasser": "schidionare",
    "schidionassero": "schidionare",
    "schidionassi": "schidionare",
    "schidionassimo": "schidionare",
    "schidionaste": "schidionare",
    "schidionasti": "schidionare",
    "schidionata": "schidionare",
    "schidionate": "schidionare",
    "schidionati": "schidionare",
    "schidionato": "schidionare",
    "schidionava": "schidionare",
    "schidionavamo": "schidionare",
    "schidionavan": "schidionare",
    "schidionavano": "schidionare",
    "schidionavate": "schidionare",
    "schidionavi": "schidionare",
    "schidionavo": "schidionare",
    "schidionerai": "schidionare",
    "schidioneran": "schidionare",
    "schidioneranno": "schidionare",
    "schidionerebbe": "schidionare",
    "schidionerebber": "schidionare",
    "schidionerebbero": "schidionare",
    "schidionerei": "schidionare",
    "schidioneremmo": "schidionare",
    "schidioneremo": "schidionare",
    "schidionereste": "schidionare",
    "schidioneresti": "schidionare",
    "schidionerete": "schidionare",
    "schidionerà": "schidionare",
    "schidionerò": "schidionare",
    "schidioni": "schidionare",
    "schidioniamo": "schidionare",
    "schidioniate": "schidionare",
    "schidionin": "schidionare",
    "schidionino": "schidionare",
    "schidiono": "schidionare",
    "schidionò": "schidionare",
    "schienali": "schienale",
    "schiene": "schiena",
    "schiera": "schierare",
    "schierai": "schierare",
    "schieramenti": "schieramento",
    "schierammo": "schierare",
    "schieran": "schierare",
    "schierando": "schierare",
    "schierano": "schierare",
    "schierante": "schierare",
    "schieranti": "schierare",
    "schierar": "schierare",
    "schieraron": "schierare",
    "schierarono": "schierare",
    "schierasse": "schierare",
    "schierasser": "schierare",
    "schierassero": "schierare",
    "schierassi": "schierare",
    "schierassimo": "schierare",
    "schieraste": "schierare",
    "schierasti": "schierare",
    "schierata": "schierare",
    "schierate": "schierare",
    "schierati": "schierare",
    "schierato": "schierare",
    "schierava": "schierare",
    "schieravamo": "schierare",
    "schieravan": "schierare",
    "schieravano": "schierare",
    "schieravate": "schierare",
    "schieravi": "schierare",
    "schieravo": "schierare",
    "schiere": "schiera",
    "schiererai": "schierare",
    "schiereran": "schierare",
    "schiereranno": "schierare",
    "schiererebbe": "schierare",
    "schiererebber": "schierare",
    "schiererebbero": "schierare",
    "schiererei": "schierare",
    "schiereremmo": "schierare",
    "schiereremo": "schierare",
    "schierereste": "schierare",
    "schiereresti": "schierare",
    "schiererete": "schierare",
    "schiererà": "schierare",
    "schiererò": "schierare",
    "schieri": "schierare",
    "schieriamo": "schierare",
    "schieriate": "schierare",
    "schierin": "schierare",
    "schierino": "schierare",
    "schiero": "schierare",
    "schierò": "schierare",
    "schietta": "schietto",
    "schiette": "schietto",
    "schietti": "schietto",
    "schifa": "schifare",
    "schifai": "schifare",
    "schifammo": "schifare",
    "schifan": "schifare",
    "schifando": "schifare",
    "schifano": "schifare",
    "schifante": "schifare",
    "schifanti": "schifare",
    "schifar": "schifare",
    "schifaron": "schifare",
    "schifarono": "schifare",
    "schifasse": "schifare",
    "schifasser": "schifare",
    "schifassero": "schifare",
    "schifassi": "schifare",
    "schifassimo": "schifare",
    "schifaste": "schifare",
    "schifasti": "schifare",
    "schifata": "schifare",
    "schifate": "schifare",
    "schifati": "schifare",
    "schifato": "schifare",
    "schifava": "schifare",
    "schifavamo": "schifare",
    "schifavan": "schifare",
    "schifavano": "schifare",
    "schifavate": "schifare",
    "schifavi": "schifare",
    "schifavo": "schifare",
    "schiferai": "schifare",
    "schiferan": "schifare",
    "schiferanno": "schifare",
    "schiferebbe": "schifare",
    "schiferebber": "schifare",
    "schiferebbero": "schifare",
    "schiferei": "schifare",
    "schiferemmo": "schifare",
    "schiferemo": "schifare",
    "schifereste": "schifare",
    "schiferesti": "schifare",
    "schiferete": "schifare",
    "schiferà": "schifare",
    "schiferò": "schifare",
    "schifezze": "schifezza",
    "schifi": "schifo",
    "schifiamo": "schifare",
    "schifiate": "schifare",
    "schifiltosa": "schifiltoso",
    "schifiltose": "schifiltoso",
    "schifiltosi": "schifiltoso",
    "schifin": "schifare",
    "schifino": "schifare",
    "schifo": "schifare",
    "schifosa": "schifoso",
    "schifose": "schifoso",
    "schifosi": "schifoso",
    "schifò": "schifare",
    "schiocca": "schioccare",
    "schioccai": "schioccare",
    "schioccammo": "schioccare",
    "schioccan": "schioccare",
    "schioccando": "schioccare",
    "schioccano": "schioccare",
    "schioccante": "schioccare",
    "schioccanti": "schioccare",
    "schioccar": "schioccare",
    "schioccaron": "schioccare",
    "schioccarono": "schioccare",
    "schioccasse": "schioccare",
    "schioccasser": "schioccare",
    "schioccassero": "schioccare",
    "schioccassi": "schioccare",
    "schioccassimo": "schioccare",
    "schioccaste": "schioccare",
    "schioccasti": "schioccare",
    "schioccata": "schioccare",
    "schioccate": "schioccare",
    "schioccati": "schioccare",
    "schioccato": "schioccare",
    "schioccava": "schioccare",
    "schioccavamo": "schioccare",
    "schioccavan": "schioccare",
    "schioccavano": "schioccare",
    "schioccavate": "schioccare",
    "schioccavi": "schioccare",
    "schioccavo": "schioccare",
    "schioccherai": "schioccare",
    "schioccheran": "schioccare",
    "schioccheranno": "schioccare",
    "schioccherebbe": "schioccare",
    "schioccherebber": "schioccare",
    "schioccherebbero": "schioccare",
    "schioccherei": "schioccare",
    "schioccheremmo": "schioccare",
    "schioccheremo": "schioccare",
    "schiocchereste": "schioccare",
    "schioccheresti": "schioccare",
    "schioccherete": "schioccare",
    "schioccherà": "schioccare",
    "schioccherò": "schioccare",
    "schiocchezze": "schiocchezza",
    "schiocchi": "schiocco",
    "schiocchiamo": "schioccare",
    "schiocchiate": "schioccare",
    "schiocchin": "schioccare",
    "schiocchino": "schioccare",
    "schiocco": "schioccare",
    "schioccò": "schioccare",
    "schioda": "schiodare",
    "schiodai": "schiodare",
    "schiodammo": "schiodare",
    "schiodan": "schiodare",
    "schiodando": "schiodare",
    "schiodano": "schiodare",
    "schiodante": "schiodare",
    "schiodanti": "schiodare",
    "schiodar": "schiodare",
    "schiodaron": "schiodare",
    "schiodarono": "schiodare",
    "schiodasse": "schiodare",
    "schiodasser": "schiodare",
    "schiodassero": "schiodare",
    "schiodassi": "schiodare",
    "schiodassimo": "schiodare",
    "schiodaste": "schiodare",
    "schiodasti": "schiodare",
    "schiodata": "schiodare",
    "schiodate": "schiodare",
    "schiodati": "schiodare",
    "schiodato": "schiodare",
    "schiodava": "schiodare",
    "schiodavamo": "schiodare",
    "schiodavan": "schiodare",
    "schiodavano": "schiodare",
    "schiodavate": "schiodare",
    "schiodavi": "schiodare",
    "schiodavo": "schiodare",
    "schioderai": "schiodare",
    "schioderan": "schiodare",
    "schioderanno": "schiodare",
    "schioderebbe": "schiodare",
    "schioderebber": "schiodare",
    "schioderebbero": "schiodare",
    "schioderei": "schiodare",
    "schioderemmo": "schiodare",
    "schioderemo": "schiodare",
    "schiodereste": "schiodare",
    "schioderesti": "schiodare",
    "schioderete": "schiodare",
    "schioderà": "schiodare",
    "schioderò": "schiodare",
    "schiodi": "schiodare",
    "schiodiamo": "schiodare",
    "schiodiate": "schiodare",
    "schiodin": "schiodare",
    "schiodino": "schiodare",
    "schiodo": "schiodare",
    "schiodò": "schiodare",
    "schiuda": "schiudere",
    "schiudan": "schiudere",
    "schiudano": "schiudere",
    "schiude": "schiudere",
    "schiudei": "schiudere",
    "schiudemmo": "schiudere",
    "schiudendo": "schiudere",
    "schiudente": "schiudere",
    "schiudenti": "schiudere",
    "schiuder": "schiudere",
    "schiuderai": "schiudere",
    "schiuderan": "schiudere",
    "schiuderanno": "schiudere",
    "schiuderebbe": "schiudere",
    "schiuderebber": "schiudere",
    "schiuderebbero": "schiudere",
    "schiuderei": "schiudere",
    "schiuderemmo": "schiudere",
    "schiuderemo": "schiudere",
    "schiudereste": "schiudere",
    "schiuderesti": "schiudere",
    "schiuderete": "schiudere",
    "schiuderon": "schiudere",
    "schiuderono": "schiudere",
    "schiuderà": "schiudere",
    "schiuderò": "schiudere",
    "schiudesse": "schiudere",
    "schiudesser": "schiudere",
    "schiudessero": "schiudere",
    "schiudessi": "schiudere",
    "schiudessimo": "schiudere",
    "schiudeste": "schiudere",
    "schiudesti": "schiudere",
    "schiudete": "schiudere",
    "schiudeva": "schiudere",
    "schiudevamo": "schiudere",
    "schiudevan": "schiudere",
    "schiudevano": "schiudere",
    "schiudevate": "schiudere",
    "schiudevi": "schiudere",
    "schiudevo": "schiudere",
    "schiudi": "schiudere",
    "schiudiamo": "schiudere",
    "schiudiate": "schiudere",
    "schiudo": "schiudere",
    "schiudon": "schiudere",
    "schiudono": "schiudere",
    "schiuduta": "schiudere",
    "schiudute": "schiudere",
    "schiuduti": "schiudere",
    "schiuduto": "schiudere",
    "schiudè": "schiudere",
    "schiuma": "schiumare",
    "schiumai": "schiumare",
    "schiumammo": "schiumare",
    "schiuman": "schiumare",
    "schiumando": "schiumare",
    "schiumano": "schiumare",
    "schiumante": "schiumare",
    "schiumanti": "schiumare",
    "schiumar": "schiumare",
    "schiumaron": "schiumare",
    "schiumarono": "schiumare",
    "schiumasse": "schiumare",
    "schiumasser": "schiumare",
    "schiumassero": "schiumare",
    "schiumassi": "schiumare",
    "schiumassimo": "schiumare",
    "schiumaste": "schiumare",
    "schiumasti": "schiumare",
    "schiumata": "schiumare",
    "schiumate": "schiumare",
    "schiumati": "schiumare",
    "schiumato": "schiumare",
    "schiumava": "schiumare",
    "schiumavamo": "schiumare",
    "schiumavan": "schiumare",
    "schiumavano": "schiumare",
    "schiumavate": "schiumare",
    "schiumavi": "schiumare",
    "schiumavo": "schiumare",
    "schiume": "schiuma",
    "schiumerai": "schiumare",
    "schiumeran": "schiumare",
    "schiumeranno": "schiumare",
    "schiumerebbe": "schiumare",
    "schiumerebber": "schiumare",
    "schiumerebbero": "schiumare",
    "schiumerei": "schiumare",
    "schiumeremmo": "schiumare",
    "schiumeremo": "schiumare",
    "schiumereste": "schiumare",
    "schiumeresti": "schiumare",
    "schiumerete": "schiumare",
    "schiumerà": "schiumare",
    "schiumerò": "schiumare",
    "schiumi": "schiumare",
    "schiumiamo": "schiumare",
    "schiumiate": "schiumare",
    "schiumin": "schiumare",
    "schiumino": "schiumare",
    "schiumo": "schiumare",
    "schiumosa": "schiumoso",
    "schiumose": "schiumoso",
    "schiumosi": "schiumoso",
    "schiumò": "schiumare",
    "schiva": "schivo",
    "schivai": "schivare",
    "schivammo": "schivare",
    "schivan": "schivare",
    "schivando": "schivare",
    "schivano": "schivare",
    "schivante": "schivare",
    "schivanti": "schivare",
    "schivar": "schivare",
    "schivaron": "schivare",
    "schivarono": "schivare",
    "schivasse": "schivare",
    "schivasser": "schivare",
    "schivassero": "schivare",
    "schivassi": "schivare",
    "schivassimo": "schivare",
    "schivaste": "schivare",
    "schivasti": "schivare",
    "schivata": "schivare",
    "schivate": "schivare",
    "schivati": "schivare",
    "schivato": "schivare",
    "schivava": "schivare",
    "schivavamo": "schivare",
    "schivavan": "schivare",
    "schivavano": "schivare",
    "schivavate": "schivare",
    "schivavi": "schivare",
    "schivavo": "schivare",
    "schive": "schivo",
    "schiverai": "schivare",
    "schiveran": "schivare",
    "schiveranno": "schivare",
    "schiverebbe": "schivare",
    "schiverebber": "schivare",
    "schiverebbero": "schivare",
    "schiverei": "schivare",
    "schiveremmo": "schivare",
    "schiveremo": "schivare",
    "schivereste": "schivare",
    "schiveresti": "schivare",
    "schiverete": "schivare",
    "schiverà": "schivare",
    "schiverò": "schivare",
    "schivi": "schivo",
    "schiviamo": "schivare",
    "schiviate": "schivare",
    "schivin": "schivare",
    "schivino": "schivare",
    "schivo": "schivare",
    "schivò": "schivare",
    "schizofrenica": "schizofrenico",
    "schizofreniche": "schizofrenico",
    "schizofrenici": "schizofrenico",
    "schizofrenie": "schizofrenia",
    "schizoidi": "schizoide",
    "schizza": "schizzare",
    "schizzai": "schizzare",
    "schizzammo": "schizzare",
    "schizzan": "schizzare",
    "schizzando": "schizzare",
    "schizzano": "schizzare",
    "schizzante": "schizzare",
    "schizzanti": "schizzare",
    "schizzar": "schizzare",
    "schizzaron": "schizzare",
    "schizzarono": "schizzare",
    "schizzasse": "schizzare",
    "schizzasser": "schizzare",
    "schizzassero": "schizzare",
    "schizzassi": "schizzare",
    "schizzassimo": "schizzare",
    "schizzaste": "schizzare",
    "schizzasti": "schizzare",
    "schizzata": "schizzare",
    "schizzate": "schizzare",
    "schizzati": "schizzare",
    "schizzato": "schizzare",
    "schizzava": "schizzare",
    "schizzavamo": "schizzare",
    "schizzavan": "schizzare",
    "schizzavano": "schizzare",
    "schizzavate": "schizzare",
    "schizzavi": "schizzare",
    "schizzavo": "schizzare",
    "schizzerai": "schizzare",
    "schizzeran": "schizzare",
    "schizzeranno": "schizzare",
    "schizzerebbe": "schizzare",
    "schizzerebber": "schizzare",
    "schizzerebbero": "schizzare",
    "schizzerei": "schizzare",
    "schizzeremmo": "schizzare",
    "schizzeremo": "schizzare",
    "schizzereste": "schizzare",
    "schizzeresti": "schizzare",
    "schizzerete": "schizzare",
    "schizzerà": "schizzare",
    "schizzerò": "schizzare",
    "schizzi": "schizzo",
    "schizziamo": "schizzare",
    "schizziate": "schizzare",
    "schizzin": "schizzare",
    "schizzino": "schizzare",
    "schizzinosa": "schizzinoso",
    "schizzinose": "schizzinoso",
    "schizzinosi": "schizzinoso",
    "schizzo": "schizzare",
    "schizzò": "schizzare",
    "sci": "sciare",
    "scia": "sciare",
    "sciabola": "sciabolare",
    "sciabolai": "sciabolare",
    "sciabolammo": "sciabolare",
    "sciabolan": "sciabolare",
    "sciabolando": "sciabolare",
    "sciabolano": "sciabolare",
    "sciabolante": "sciabolare",
    "sciabolanti": "sciabolare",
    "sciabolar": "sciabolare",
    "sciabolaron": "sciabolare",
    "sciabolarono": "sciabolare",
    "sciabolasse": "sciabolare",
    "sciabolasser": "sciabolare",
    "sciabolassero": "sciabolare",
    "sciabolassi": "sciabolare",
    "sciabolassimo": "sciabolare",
    "sciabolaste": "sciabolare",
    "sciabolasti": "sciabolare",
    "sciabolata": "sciabolare",
    "sciabolate": "sciabolata",
    "sciabolati": "sciabolare",
    "sciabolato": "sciabolare",
    "sciabolava": "sciabolare",
    "sciabolavamo": "sciabolare",
    "sciabolavan": "sciabolare",
    "sciabolavano": "sciabolare",
    "sciabolavate": "sciabolare",
    "sciabolavi": "sciabolare",
    "sciabolavo": "sciabolare",
    "sciabole": "sciabola",
    "sciabolerai": "sciabolare",
    "sciaboleran": "sciabolare",
    "sciaboleranno": "sciabolare",
    "sciabolerebbe": "sciabolare",
    "sciabolerebber": "sciabolare",
    "sciabolerebbero": "sciabolare",
    "sciabolerei": "sciabolare",
    "sciaboleremmo": "sciabolare",
    "sciaboleremo": "sciabolare",
    "sciabolereste": "sciabolare",
    "sciaboleresti": "sciabolare",
    "sciabolerete": "sciabolare",
    "sciabolerà": "sciabolare",
    "sciabolerò": "sciabolare",
    "sciaboli": "sciabolare",
    "sciaboliamo": "sciabolare",
    "sciaboliate": "sciabolare",
    "sciabolin": "sciabolare",
    "sciabolino": "sciabolare",
    "sciabolo": "sciabolare",
    "sciabolò": "sciabolare",
    "sciaborda": "sciabordare",
    "sciabordai": "sciabordare",
    "sciabordammo": "sciabordare",
    "sciabordan": "sciabordare",
    "sciabordando": "sciabordare",
    "sciabordano": "sciabordare",
    "sciabordante": "sciabordare",
    "sciabordanti": "sciabordare",
    "sciabordar": "sciabordare",
    "sciabordaron": "sciabordare",
    "sciabordarono": "sciabordare",
    "sciabordasse": "sciabordare",
    "sciabordasser": "sciabordare",
    "sciabordassero": "sciabordare",
    "sciabordassi": "sciabordare",
    "sciabordassimo": "sciabordare",
    "sciabordaste": "sciabordare",
    "sciabordasti": "sciabordare",
    "sciabordata": "sciabordare",
    "sciabordate": "sciabordare",
    "sciabordati": "sciabordare",
    "sciabordato": "sciabordare",
    "sciabordava": "sciabordare",
    "sciabordavamo": "sciabordare",
    "sciabordavan": "sciabordare",
    "sciabordavano": "sciabordare",
    "sciabordavate": "sciabordare",
    "sciabordavi": "sciabordare",
    "sciabordavo": "sciabordare",
    "sciaborderai": "sciabordare",
    "sciaborderan": "sciabordare",
    "sciaborderanno": "sciabordare",
    "sciaborderebbe": "sciabordare",
    "sciaborderebber": "sciabordare",
    "sciaborderebbero": "sciabordare",
    "sciaborderei": "sciabordare",
    "sciaborderemmo": "sciabordare",
    "sciaborderemo": "sciabordare",
    "sciabordereste": "sciabordare",
    "sciaborderesti": "sciabordare",
    "sciaborderete": "sciabordare",
    "sciaborderà": "sciabordare",
    "sciaborderò": "sciabordare",
    "sciabordi": "sciabordare",
    "sciabordiamo": "sciabordare",
    "sciabordiate": "sciabordare",
    "sciabordin": "sciabordare",
    "sciabordino": "sciabordare",
    "sciabordo": "sciabordare",
    "sciabordò": "sciabordare",
    "sciacalli": "sciacallo",
    "sciacqua": "sciacquare",
    "sciacquai": "sciacquare",
    "sciacquammo": "sciacquare",
    "sciacquan": "sciacquare",
    "sciacquando": "sciacquare",
    "sciacquano": "sciacquare",
    "sciacquante": "sciacquare",
    "sciacquanti": "sciacquare",
    "sciacquar": "sciacquare",
    "sciacquaron": "sciacquare",
    "sciacquarono": "sciacquare",
    "sciacquasse": "sciacquare",
    "sciacquasser": "sciacquare",
    "sciacquassero": "sciacquare",
    "sciacquassi": "sciacquare",
    "sciacquassimo": "sciacquare",
    "sciacquaste": "sciacquare",
    "sciacquasti": "sciacquare",
    "sciacquata": "sciacquare",
    "sciacquate": "sciacquare",
    "sciacquati": "sciacquare",
    "sciacquato": "sciacquare",
    "sciacquava": "sciacquare",
    "sciacquavamo": "sciacquare",
    "sciacquavan": "sciacquare",
    "sciacquavano": "sciacquare",
    "sciacquavate": "sciacquare",
    "sciacquavi": "sciacquare",
    "sciacquavo": "sciacquare",
    "sciacquerai": "sciacquare",
    "sciacqueran": "sciacquare",
    "sciacqueranno": "sciacquare",
    "sciacquerebbe": "sciacquare",
    "sciacquerebber": "sciacquare",
    "sciacquerebbero": "sciacquare",
    "sciacquerei": "sciacquare",
    "sciacqueremmo": "sciacquare",
    "sciacqueremo": "sciacquare",
    "sciacquereste": "sciacquare",
    "sciacqueresti": "sciacquare",
    "sciacquerete": "sciacquare",
    "sciacquerà": "sciacquare",
    "sciacquerò": "sciacquare",
    "sciacqui": "sciacquare",
    "sciacquiamo": "sciacquare",
    "sciacquiate": "sciacquare",
    "sciacquin": "sciacquare",
    "sciacquino": "sciacquare",
    "sciacquo": "sciacquare",
    "sciacquoni": "sciacquone",
    "sciacquò": "sciacquare",
    "sciagurata": "sciagurato",
    "sciagurate": "sciagurato",
    "sciagurati": "sciagurato",
    "sciagure": "sciagura",
    "sciai": "sciare",
    "sciala": "scialare",
    "scialacqua": "scialacquare",
    "scialacquai": "scialacquare",
    "scialacquammo": "scialacquare",
    "scialacquan": "scialacquare",
    "scialacquando": "scialacquare",
    "scialacquano": "scialacquare",
    "scialacquante": "scialacquare",
    "scialacquanti": "scialacquare",
    "scialacquar": "scialacquare",
    "scialacquaron": "scialacquare",
    "scialacquarono": "scialacquare",
    "scialacquasse": "scialacquare",
    "scialacquasser": "scialacquare",
    "scialacquassero": "scialacquare",
    "scialacquassi": "scialacquare",
    "scialacquassimo": "scialacquare",
    "scialacquaste": "scialacquare",
    "scialacquasti": "scialacquare",
    "scialacquata": "scialacquare",
    "scialacquate": "scialacquare",
    "scialacquati": "scialacquare",
    "scialacquato": "scialacquare",
    "scialacquava": "scialacquare",
    "scialacquavamo": "scialacquare",
    "scialacquavan": "scialacquare",
    "scialacquavano": "scialacquare",
    "scialacquavate": "scialacquare",
    "scialacquavi": "scialacquare",
    "scialacquavo": "scialacquare",
    "scialacquerai": "scialacquare",
    "scialacqueran": "scialacquare",
    "scialacqueranno": "scialacquare",
    "scialacquerebbe": "scialacquare",
    "scialacquerebber": "scialacquare",
    "scialacquerebbero": "scialacquare",
    "scialacquerei": "scialacquare",
    "scialacqueremmo": "scialacquare",
    "scialacqueremo": "scialacquare",
    "scialacquereste": "scialacquare",
    "scialacqueresti": "scialacquare",
    "scialacquerete": "scialacquare",
    "scialacquerà": "scialacquare",
    "scialacquerò": "scialacquare",
    "scialacqui": "scialacquare",
    "scialacquiamo": "scialacquare",
    "scialacquiate": "scialacquare",
    "scialacquin": "scialacquare",
    "scialacquino": "scialacquare",
    "scialacquo": "scialacquare",
    "scialacquò": "scialacquare",
    "scialai": "scialare",
    "scialammo": "scialare",
    "scialan": "scialare",
    "scialando": "scialare",
    "scialano": "scialare",
    "scialante": "scialare",
    "scialanti": "scialare",
    "scialar": "scialare",
    "scialaron": "scialare",
    "scialarono": "scialare",
    "scialasse": "scialare",
    "scialasser": "scialare",
    "scialassero": "scialare",
    "scialassi": "scialare",
    "scialassimo": "scialare",
    "scialaste": "scialare",
    "scialasti": "scialare",
    "scialata": "scialare",
    "scialate": "scialare",
    "scialati": "scialare",
    "scialato": "scialare",
    "scialava": "scialare",
    "scialavamo": "scialare",
    "scialavan": "scialare",
    "scialavano": "scialare",
    "scialavate": "scialare",
    "scialavi": "scialare",
    "scialavo": "scialare",
    "scialba": "scialbo",
    "scialbai": "scialbare",
    "scialbammo": "scialbare",
    "scialban": "scialbare",
    "scialbando": "scialbare",
    "scialbano": "scialbare",
    "scialbante": "scialbare",
    "scialbanti": "scialbare",
    "scialbar": "scialbare",
    "scialbaron": "scialbare",
    "scialbarono": "scialbare",
    "scialbasse": "scialbare",
    "scialbasser": "scialbare",
    "scialbassero": "scialbare",
    "scialbassi": "scialbare",
    "scialbassimo": "scialbare",
    "scialbaste": "scialbare",
    "scialbasti": "scialbare",
    "scialbata": "scialbare",
    "scialbate": "scialbare",
    "scialbati": "scialbare",
    "scialbato": "scialbare",
    "scialbava": "scialbare",
    "scialbavamo": "scialbare",
    "scialbavan": "scialbare",
    "scialbavano": "scialbare",
    "scialbavate": "scialbare",
    "scialbavi": "scialbare",
    "scialbavo": "scialbare",
    "scialbe": "scialbo",
    "scialberai": "scialbare",
    "scialberan": "scialbare",
    "scialberanno": "scialbare",
    "scialberebbe": "scialbare",
    "scialberebber": "scialbare",
    "scialberebbero": "scialbare",
    "scialberei": "scialbare",
    "scialberemmo": "scialbare",
    "scialberemo": "scialbare",
    "scialbereste": "scialbare",
    "scialberesti": "scialbare",
    "scialberete": "scialbare",
    "scialberà": "scialbare",
    "scialberò": "scialbare",
    "scialbi": "scialbo",
    "scialbiamo": "scialbare",
    "scialbiate": "scialbare",
    "scialbin": "scialbare",
    "scialbino": "scialbare",
    "scialbo": "scialbare",
    "scialbò": "scialbare",
    "scialerai": "scialare",
    "scialeran": "scialare",
    "scialeranno": "scialare",
    "scialerebbe": "scialare",
    "scialerebber": "scialare",
    "scialerebbero": "scialare",
    "scialerei": "scialare",
    "scialeremmo": "scialare",
    "scialeremo": "scialare",
    "scialereste": "scialare",
    "scialeresti": "scialare",
    "scialerete": "scialare",
    "scialerà": "scialare",
    "scialerò": "scialare",
    "sciali": "scialo",
    "scialiamo": "scialare",
    "scialiate": "scialare",
    "scialin": "scialare",
    "scialino": "scialare",
    "sciallata": "sciallato",
    "sciallate": "sciallato",
    "sciallati": "sciallato",
    "scialli": "scialle",
    "scialo": "scialare",
    "scialuppe": "scialuppa",
    "scialò": "scialare",
    "sciama": "sciamare",
    "sciamai": "sciamare",
    "sciamammo": "sciamare",
    "sciaman": "sciamare",
    "sciamando": "sciamare",
    "sciamani": "sciamano",
    "sciamanna": "sciamannare",
    "sciamannai": "sciamannare",
    "sciamannammo": "sciamannare",
    "sciamannan": "sciamannare",
    "sciamannando": "sciamannare",
    "sciamannano": "sciamannare",
    "sciamannante": "sciamannare",
    "sciamannanti": "sciamannare",
    "sciamannar": "sciamannare",
    "sciamannaron": "sciamannare",
    "sciamannarono": "sciamannare",
    "sciamannasse": "sciamannare",
    "sciamannasser": "sciamannare",
    "sciamannassero": "sciamannare",
    "sciamannassi": "sciamannare",
    "sciamannassimo": "sciamannare",
    "sciamannaste": "sciamannare",
    "sciamannasti": "sciamannare",
    "sciamannata": "sciamannato",
    "sciamannate": "sciamannato",
    "sciamannati": "sciamannato",
    "sciamannato": "sciamannare",
    "sciamannava": "sciamannare",
    "sciamannavamo": "sciamannare",
    "sciamannavan": "sciamannare",
    "sciamannavano": "sciamannare",
    "sciamannavate": "sciamannare",
    "sciamannavi": "sciamannare",
    "sciamannavo": "sciamannare",
    "sciamannerai": "sciamannare",
    "sciamanneran": "sciamannare",
    "sciamanneranno": "sciamannare",
    "sciamannerebbe": "sciamannare",
    "sciamannerebber": "sciamannare",
    "sciamannerebbero": "sciamannare",
    "sciamannerei": "sciamannare",
    "sciamanneremmo": "sciamannare",
    "sciamanneremo": "sciamannare",
    "sciamannereste": "sciamannare",
    "sciamanneresti": "sciamannare",
    "sciamannerete": "sciamannare",
    "sciamannerà": "sciamannare",
    "sciamannerò": "sciamannare",
    "sciamanni": "sciamannare",
    "sciamanniamo": "sciamannare",
    "sciamanniate": "sciamannare",
    "sciamannin": "sciamannare",
    "sciamannino": "sciamannare",
    "sciamanno": "sciamannare",
    "sciamannò": "sciamannare",
    "sciamano": "sciamare",
    "sciamante": "sciamare",
    "sciamanti": "sciamare",
    "sciamar": "sciamare",
    "sciamaron": "sciamare",
    "sciamarono": "sciamare",
    "sciamasse": "sciamare",
    "sciamasser": "sciamare",
    "sciamassero": "sciamare",
    "sciamassi": "sciamare",
    "sciamassimo": "sciamare",
    "sciamaste": "sciamare",
    "sciamasti": "sciamare",
    "sciamata": "sciamare",
    "sciamate": "sciamare",
    "sciamati": "sciamare",
    "sciamato": "sciamare",
    "sciamava": "sciamare",
    "sciamavamo": "sciamare",
    "sciamavan": "sciamare",
    "sciamavano": "sciamare",
    "sciamavate": "sciamare",
    "sciamavi": "sciamare",
    "sciamavo": "sciamare",
    "sciamerai": "sciamare",
    "sciameran": "sciamare",
    "sciameranno": "sciamare",
    "sciamerebbe": "sciamare",
    "sciamerebber": "sciamare",
    "sciamerebbero": "sciamare",
    "sciamerei": "sciamare",
    "sciameremmo": "sciamare",
    "sciameremo": "sciamare",
    "sciamereste": "sciamare",
    "sciameresti": "sciamare",
    "sciamerete": "sciamare",
    "sciamerà": "sciamare",
    "sciamerò": "sciamare",
    "sciami": "sciame",
    "sciamiamo": "sciamare",
    "sciamiate": "sciamare",
    "sciamin": "sciamare",
    "sciamino": "sciamare",
    "sciammo": "sciare",
    "sciamo": "sciare",
    "sciamò": "sciamare",
    "scian": "sciare",
    "scianca": "sciancare",
    "sciancai": "sciancare",
    "sciancammo": "sciancare",
    "sciancan": "sciancare",
    "sciancando": "sciancare",
    "sciancano": "sciancare",
    "sciancante": "sciancare",
    "sciancanti": "sciancare",
    "sciancar": "sciancare",
    "sciancaron": "sciancare",
    "sciancarono": "sciancare",
    "sciancasse": "sciancare",
    "sciancasser": "sciancare",
    "sciancassero": "sciancare",
    "sciancassi": "sciancare",
    "sciancassimo": "sciancare",
    "sciancaste": "sciancare",
    "sciancasti": "sciancare",
    "sciancata": "sciancato",
    "sciancate": "sciancato",
    "sciancati": "sciancato",
    "sciancato": "sciancare",
    "sciancava": "sciancare",
    "sciancavamo": "sciancare",
    "sciancavan": "sciancare",
    "sciancavano": "sciancare",
    "sciancavate": "sciancare",
    "sciancavi": "sciancare",
    "sciancavo": "sciancare",
    "sciancherai": "sciancare",
    "sciancheran": "sciancare",
    "sciancheranno": "sciancare",
    "sciancherebbe": "sciancare",
    "sciancherebber": "sciancare",
    "sciancherebbero": "sciancare",
    "sciancherei": "sciancare",
    "sciancheremmo": "sciancare",
    "sciancheremo": "sciancare",
    "scianchereste": "sciancare",
    "sciancheresti": "sciancare",
    "sciancherete": "sciancare",
    "sciancherà": "sciancare",
    "sciancherò": "sciancare",
    "scianchi": "sciancare",
    "scianchiamo": "sciancare",
    "scianchiate": "sciancare",
    "scianchin": "sciancare",
    "scianchino": "sciancare",
    "scianco": "sciancare",
    "sciancò": "sciancare",
    "sciando": "sciare",
    "sciano": "sciare",
    "sciante": "sciare",
    "scianti": "sciare",
    "sciar": "sciare",
    "sciarade": "sciarada",
    "sciaron": "sciare",
    "sciarono": "sciare",
    "sciarpe": "sciarpa",
    "sciasse": "sciare",
    "sciasser": "sciare",
    "sciassero": "sciare",
    "sciassi": "sciare",
    "sciassimo": "sciare",
    "sciaste": "sciare",
    "sciasti": "sciare",
    "sciata": "sciare",
    "sciate": "sciata",
    "sciati": "sciare",
    "sciatica": "sciatico",
    "sciatiche": "sciatico",
    "sciatici": "sciatico",
    "sciato": "sciare",
    "sciatori": "sciatorio",
    "sciatoria": "sciatorio",
    "sciatorie": "sciatorio",
    "sciatrice": "sciatore",
    "sciatrici": "sciatrice",
    "sciatta": "sciatto",
    "sciatte": "sciatto",
    "sciatterie": "sciatteria",
    "sciatti": "sciatto",
    "sciava": "sciare",
    "sciavamo": "sciare",
    "sciavan": "sciare",
    "sciavano": "sciare",
    "sciavate": "sciare",
    "sciavi": "sciare",
    "sciavo": "sciare",
    "scie": "scia",
    "scientifica": "scientifico",
    "scientifiche": "scientifico",
    "scientifici": "scientifico",
    "scienze": "scienza",
    "scienziate": "scienziata",
    "scienziati": "scienziato",
    "sciistica": "sciistico",
    "sciistiche": "sciistico",
    "sciistici": "sciistico",
    "sciite": "sciita",
    "sciiti": "sciita",
    "scimitarre": "scimitarra",
    "scimmie": "scimmia",
    "scimmiette": "scimmietta",
    "scimmioni": "scimmione",
    "scimmiotta": "scimmiottare",
    "scimmiottai": "scimmiottare",
    "scimmiottammo": "scimmiottare",
    "scimmiottan": "scimmiottare",
    "scimmiottando": "scimmiottare",
    "scimmiottano": "scimmiottare",
    "scimmiottante": "scimmiottare",
    "scimmiottanti": "scimmiottare",
    "scimmiottar": "scimmiottare",
    "scimmiottaron": "scimmiottare",
    "scimmiottarono": "scimmiottare",
    "scimmiottasse": "scimmiottare",
    "scimmiottasser": "scimmiottare",
    "scimmiottassero": "scimmiottare",
    "scimmiottassi": "scimmiottare",
    "scimmiottassimo": "scimmiottare",
    "scimmiottaste": "scimmiottare",
    "scimmiottasti": "scimmiottare",
    "scimmiottata": "scimmiottare",
    "scimmiottate": "scimmiottare",
    "scimmiottati": "scimmiottare",
    "scimmiottato": "scimmiottare",
    "scimmiottava": "scimmiottare",
    "scimmiottavamo": "scimmiottare",
    "scimmiottavan": "scimmiottare",
    "scimmiottavano": "scimmiottare",
    "scimmiottavate": "scimmiottare",
    "scimmiottavi": "scimmiottare",
    "scimmiottavo": "scimmiottare",
    "scimmiotterai": "scimmiottare",
    "scimmiotteran": "scimmiottare",
    "scimmiotteranno": "scimmiottare",
    "scimmiotterebbe": "scimmiottare",
    "scimmiotterebber": "scimmiottare",
    "scimmiotterebbero": "scimmiottare",
    "scimmiotterei": "scimmiottare",
    "scimmiotteremmo": "scimmiottare",
    "scimmiotteremo": "scimmiottare",
    "scimmiottereste": "scimmiottare",
    "scimmiotteresti": "scimmiottare",
    "scimmiotterete": "scimmiottare",
    "scimmiotterà": "scimmiottare",
    "scimmiotterò": "scimmiottare",
    "scimmiotti": "scimmiottare",
    "scimmiottiamo": "scimmiottare",
    "scimmiottiate": "scimmiottare",
    "scimmiottin": "scimmiottare",
    "scimmiottino": "scimmiottare",
    "scimmiotto": "scimmiottare",
    "scimmiottò": "scimmiottare",
    "scin": "sciare",
    "scinda": "scindere",
    "scindan": "scindere",
    "scindano": "scindere",
    "scinde": "scindere",
    "scindemmo": "scindere",
    "scindendo": "scindere",
    "scindente": "scindere",
    "scindenti": "scindere",
    "scinder": "scindere",
    "scinderai": "scindere",
    "scinderan": "scindere",
    "scinderanno": "scindere",
    "scinderebbe": "scindere",
    "scinderebber": "scindere",
    "scinderebbero": "scindere",
    "scinderei": "scindere",
    "scinderemmo": "scindere",
    "scinderemo": "scindere",
    "scindereste": "scindere",
    "scinderesti": "scindere",
    "scinderete": "scindere",
    "scinderà": "scindere",
    "scinderò": "scindere",
    "scindesse": "scindere",
    "scindesser": "scindere",
    "scindessero": "scindere",
    "scindessi": "scindere",
    "scindessimo": "scindere",
    "scindeste": "scindere",
    "scindesti": "scindere",
    "scindete": "scindere",
    "scindeva": "scindere",
    "scindevamo": "scindere",
    "scindevan": "scindere",
    "scindevano": "scindere",
    "scindevate": "scindere",
    "scindevi": "scindere",
    "scindevo": "scindere",
    "scindi": "scindere",
    "scindiamo": "scindere",
    "scindiate": "scindere",
    "scindo": "scindere",
    "scindon": "scindere",
    "scindono": "scindere",
    "scino": "sciare",
    "scintilla": "scintillare",
    "scintillai": "scintillare",
    "scintillammo": "scintillare",
    "scintillan": "scintillare",
    "scintillando": "scintillare",
    "scintillano": "scintillare",
    "scintillante": "scintillare",
    "scintillanti": "scintillare",
    "scintillar": "scintillare",
    "scintillaron": "scintillare",
    "scintillarono": "scintillare",
    "scintillasse": "scintillare",
    "scintillasser": "scintillare",
    "scintillassero": "scintillare",
    "scintillassi": "scintillare",
    "scintillassimo": "scintillare",
    "scintillaste": "scintillare",
    "scintillasti": "scintillare",
    "scintillata": "scintillare",
    "scintillate": "scintillare",
    "scintillati": "scintillare",
    "scintillato": "scintillare",
    "scintillava": "scintillare",
    "scintillavamo": "scintillare",
    "scintillavan": "scintillare",
    "scintillavano": "scintillare",
    "scintillavate": "scintillare",
    "scintillavi": "scintillare",
    "scintillavo": "scintillare",
    "scintille": "scintilla",
    "scintillerai": "scintillare",
    "scintilleran": "scintillare",
    "scintilleranno": "scintillare",
    "scintillerebbe": "scintillare",
    "scintillerebber": "scintillare",
    "scintillerebbero": "scintillare",
    "scintillerei": "scintillare",
    "scintilleremmo": "scintillare",
    "scintilleremo": "scintillare",
    "scintillereste": "scintillare",
    "scintilleresti": "scintillare",
    "scintillerete": "scintillare",
    "scintillerà": "scintillare",
    "scintillerò": "scintillare",
    "scintilli": "scintillare",
    "scintilliamo": "scintillare",
    "scintilliate": "scintillare",
    "scintillii": "scintillio",
    "scintillin": "scintillare",
    "scintillino": "scintillare",
    "scintillo": "scintillare",
    "scintillò": "scintillare",
    "scio": "sciare",
    "sciocca": "sciocco",
    "scioccai": "scioccare",
    "scioccammo": "scioccare",
    "scioccan": "scioccare",
    "scioccando": "scioccare",
    "scioccano": "scioccare",
    "scioccante": "scioccare",
    "scioccanti": "scioccare",
    "scioccar": "scioccare",
    "scioccaron": "scioccare",
    "scioccarono": "scioccare",
    "scioccasse": "scioccare",
    "scioccasser": "scioccare",
    "scioccassero": "scioccare",
    "scioccassi": "scioccare",
    "scioccassimo": "scioccare",
    "scioccaste": "scioccare",
    "scioccasti": "scioccare",
    "scioccata": "scioccare",
    "scioccate": "scioccare",
    "scioccati": "scioccare",
    "scioccato": "scioccare",
    "scioccava": "scioccare",
    "scioccavamo": "scioccare",
    "scioccavan": "scioccare",
    "scioccavano": "scioccare",
    "scioccavate": "scioccare",
    "scioccavi": "scioccare",
    "scioccavo": "scioccare",
    "sciocche": "sciocco",
    "scioccherai": "scioccare",
    "scioccheran": "scioccare",
    "scioccheranno": "scioccare",
    "scioccherebbe": "scioccare",
    "scioccherebber": "scioccare",
    "scioccherebbero": "scioccare",
    "scioccherei": "scioccare",
    "scioccheremmo": "scioccare",
    "scioccheremo": "scioccare",
    "sciocchereste": "scioccare",
    "scioccheresti": "scioccare",
    "scioccherete": "scioccare",
    "scioccherà": "scioccare",
    "scioccherò": "scioccare",
    "sciocchezze": "sciocchezza",
    "sciocchi": "sciocco",
    "sciocchiamo": "scioccare",
    "sciocchiate": "scioccare",
    "sciocchin": "scioccare",
    "sciocchino": "scioccare",
    "sciocco": "scioccare",
    "scioccò": "scioccare",
    "sciogli": "sciogliere",
    "sciogliamo": "sciogliere",
    "sciogliate": "sciogliere",
    "scioglibili": "scioglibile",
    "scioglie": "sciogliere",
    "sciogliemmo": "sciogliere",
    "sciogliendo": "sciogliere",
    "sciogliente": "sciogliere",
    "scioglienti": "sciogliere",
    "scioglier": "sciogliere",
    "scioglierai": "sciogliere",
    "scioglieran": "sciogliere",
    "scioglieranno": "sciogliere",
    "scioglierebbe": "sciogliere",
    "scioglierebber": "sciogliere",
    "scioglierebbero": "sciogliere",
    "scioglierei": "sciogliere",
    "scioglieremmo": "sciogliere",
    "scioglieremo": "sciogliere",
    "sciogliereste": "sciogliere",
    "scioglieresti": "sciogliere",
    "scioglierete": "sciogliere",
    "scioglierà": "sciogliere",
    "scioglierò": "sciogliere",
    "sciogliesse": "sciogliere",
    "sciogliesser": "sciogliere",
    "sciogliessero": "sciogliere",
    "sciogliessi": "sciogliere",
    "sciogliessimo": "sciogliere",
    "scioglieste": "sciogliere",
    "sciogliesti": "sciogliere",
    "sciogliete": "sciogliere",
    "scioglieva": "sciogliere",
    "scioglievamo": "sciogliere",
    "scioglievan": "sciogliere",
    "scioglievano": "sciogliere",
    "scioglievate": "sciogliere",
    "scioglievi": "sciogliere",
    "scioglievo": "sciogliere",
    "scioglimenti": "scioglimento",
    "sciolga": "sciogliere",
    "sciolgan": "sciogliere",
    "sciolgano": "sciogliere",
    "sciolgo": "sciogliere",
    "sciolgon": "sciogliere",
    "sciolgono": "sciogliere",
    "sciolina": "sciolinare",
    "sciolinai": "sciolinare",
    "sciolinammo": "sciolinare",
    "sciolinan": "sciolinare",
    "sciolinando": "sciolinare",
    "sciolinano": "sciolinare",
    "sciolinante": "sciolinare",
    "sciolinanti": "sciolinare",
    "sciolinar": "sciolinare",
    "sciolinaron": "sciolinare",
    "sciolinarono": "sciolinare",
    "sciolinasse": "sciolinare",
    "sciolinasser": "sciolinare",
    "sciolinassero": "sciolinare",
    "sciolinassi": "sciolinare",
    "sciolinassimo": "sciolinare",
    "sciolinaste": "sciolinare",
    "sciolinasti": "sciolinare",
    "sciolinata": "sciolinare",
    "sciolinate": "sciolinare",
    "sciolinati": "sciolinare",
    "sciolinato": "sciolinare",
    "sciolinava": "sciolinare",
    "sciolinavamo": "sciolinare",
    "sciolinavan": "sciolinare",
    "sciolinavano": "sciolinare",
    "sciolinavate": "sciolinare",
    "sciolinavi": "sciolinare",
    "sciolinavo": "sciolinare",
    "scioline": "sciolina",
    "sciolinerai": "sciolinare",
    "sciolineran": "sciolinare",
    "sciolineranno": "sciolinare",
    "sciolinerebbe": "sciolinare",
    "sciolinerebber": "sciolinare",
    "sciolinerebbero": "sciolinare",
    "sciolinerei": "sciolinare",
    "sciolineremmo": "sciolinare",
    "sciolineremo": "sciolinare",
    "sciolinereste": "sciolinare",
    "sciolineresti": "sciolinare",
    "sciolinerete": "sciolinare",
    "sciolinerà": "sciolinare",
    "sciolinerò": "sciolinare",
    "sciolini": "sciolinare",
    "scioliniamo": "sciolinare",
    "scioliniate": "sciolinare",
    "sciolinin": "sciolinare",
    "sciolinino": "sciolinare",
    "sciolino": "sciolinare",
    "sciolinò": "sciolinare",
    "sciolse": "sciogliere",
    "sciolser": "sciogliere",
    "sciolsero": "sciogliere",
    "sciolsi": "sciogliere",
    "sciolta": "sciolto",
    "sciolte": "sciolto",
    "scioltezze": "scioltezza",
    "sciolti": "sciolto",
    "sciolto": "sciogliere",
    "sciopera": "scioperare",
    "scioperai": "scioperare",
    "scioperammo": "scioperare",
    "scioperan": "scioperare",
    "scioperando": "scioperare",
    "scioperano": "scioperare",
    "scioperante": "scioperare",
    "scioperanti": "scioperare",
    "scioperar": "scioperare",
    "scioperaron": "scioperare",
    "scioperarono": "scioperare",
    "scioperasse": "scioperare",
    "scioperasser": "scioperare",
    "scioperassero": "scioperare",
    "scioperassi": "scioperare",
    "scioperassimo": "scioperare",
    "scioperaste": "scioperare",
    "scioperasti": "scioperare",
    "scioperata": "scioperato",
    "scioperate": "scioperato",
    "scioperati": "scioperato",
    "scioperato": "scioperare",
    "scioperava": "scioperare",
    "scioperavamo": "scioperare",
    "scioperavan": "scioperare",
    "scioperavano": "scioperare",
    "scioperavate": "scioperare",
    "scioperavi": "scioperare",
    "scioperavo": "scioperare",
    "sciopererai": "scioperare",
    "sciopereran": "scioperare",
    "sciopereranno": "scioperare",
    "sciopererebbe": "scioperare",
    "sciopererebber": "scioperare",
    "sciopererebbero": "scioperare",
    "sciopererei": "scioperare",
    "sciopereremmo": "scioperare",
    "sciopereremo": "scioperare",
    "scioperereste": "scioperare",
    "sciopereresti": "scioperare",
    "sciopererete": "scioperare",
    "sciopererà": "scioperare",
    "sciopererò": "scioperare",
    "scioperi": "sciopero",
    "scioperiamo": "scioperare",
    "scioperiate": "scioperare",
    "scioperin": "scioperare",
    "scioperino": "scioperare",
    "sciopero": "scioperare",
    "scioperò": "scioperare",
    "sciorina": "sciorinare",
    "sciorinai": "sciorinare",
    "sciorinammo": "sciorinare",
    "sciorinan": "sciorinare",
    "sciorinando": "sciorinare",
    "sciorinano": "sciorinare",
    "sciorinante": "sciorinare",
    "sciorinanti": "sciorinare",
    "sciorinar": "sciorinare",
    "sciorinaron": "sciorinare",
    "sciorinarono": "sciorinare",
    "sciorinasse": "sciorinare",
    "sciorinasser": "sciorinare",
    "sciorinassero": "sciorinare",
    "sciorinassi": "sciorinare",
    "sciorinassimo": "sciorinare",
    "sciorinaste": "sciorinare",
    "sciorinasti": "sciorinare",
    "sciorinata": "sciorinare",
    "sciorinate": "sciorinare",
    "sciorinati": "sciorinare",
    "sciorinato": "sciorinare",
    "sciorinava": "sciorinare",
    "sciorinavamo": "sciorinare",
    "sciorinavan": "sciorinare",
    "sciorinavano": "sciorinare",
    "sciorinavate": "sciorinare",
    "sciorinavi": "sciorinare",
    "sciorinavo": "sciorinare",
    "sciorinerai": "sciorinare",
    "sciorineran": "sciorinare",
    "sciorineranno": "sciorinare",
    "sciorinerebbe": "sciorinare",
    "sciorinerebber": "sciorinare",
    "sciorinerebbero": "sciorinare",
    "sciorinerei": "sciorinare",
    "sciorineremmo": "sciorinare",
    "sciorineremo": "sciorinare",
    "sciorinereste": "sciorinare",
    "sciorineresti": "sciorinare",
    "sciorinerete": "sciorinare",
    "sciorinerà": "sciorinare",
    "sciorinerò": "sciorinare",
    "sciorini": "sciorinare",
    "scioriniamo": "sciorinare",
    "scioriniate": "sciorinare",
    "sciorinin": "sciorinare",
    "sciorinino": "sciorinare",
    "sciorino": "sciorinare",
    "sciorinò": "sciorinare",
    "sciovinismi": "sciovinismo",
    "scioviniste": "sciovinista",
    "sciovinisti": "sciovinista",
    "sciovinistica": "sciovinistico",
    "sciovinistiche": "sciovinistico",
    "sciovinistici": "sciovinistico",
    "scipita": "scipito",
    "scipite": "scipito",
    "scipiti": "scipito",
    "scippa": "scippare",
    "scippai": "scippare",
    "scippammo": "scippare",
    "scippan": "scippare",
    "scippando": "scippare",
    "scippano": "scippare",
    "scippante": "scippare",
    "scippanti": "scippare",
    "scippar": "scippare",
    "scipparon": "scippare",
    "scipparono": "scippare",
    "scippasse": "scippare",
    "scippasser": "scippare",
    "scippassero": "scippare",
    "scippassi": "scippare",
    "scippassimo": "scippare",
    "scippaste": "scippare",
    "scippasti": "scippare",
    "scippata": "scippare",
    "scippate": "scippare",
    "scippati": "scippare",
    "scippato": "scippare",
    "scippatori": "scippatore",
    "scippava": "scippare",
    "scippavamo": "scippare",
    "scippavan": "scippare",
    "scippavano": "scippare",
    "scippavate": "scippare",
    "scippavi": "scippare",
    "scippavo": "scippare",
    "scipperai": "scippare",
    "scipperan": "scippare",
    "scipperanno": "scippare",
    "scipperebbe": "scippare",
    "scipperebber": "scippare",
    "scipperebbero": "scippare",
    "scipperei": "scippare",
    "scipperemmo": "scippare",
    "scipperemo": "scippare",
    "scippereste": "scippare",
    "scipperesti": "scippare",
    "scipperete": "scippare",
    "scipperà": "scippare",
    "scipperò": "scippare",
    "scippi": "scippo",
    "scippiamo": "scippare",
    "scippiate": "scippare",
    "scippin": "scippare",
    "scippino": "scippare",
    "scippo": "scippare",
    "scippò": "scippare",
    "scirocchi": "scirocco",
    "sciroppa": "sciroppare",
    "sciroppai": "sciroppare",
    "sciroppammo": "sciroppare",
    "sciroppan": "sciroppare",
    "sciroppando": "sciroppare",
    "sciroppano": "sciroppare",
    "sciroppante": "sciroppare",
    "sciroppanti": "sciroppare",
    "sciroppar": "sciroppare",
    "sciropparon": "sciroppare",
    "sciropparono": "sciroppare",
    "sciroppasse": "sciroppare",
    "sciroppasser": "sciroppare",
    "sciroppassero": "sciroppare",
    "sciroppassi": "sciroppare",
    "sciroppassimo": "sciroppare",
    "sciroppaste": "sciroppare",
    "sciroppasti": "sciroppare",
    "sciroppata": "sciroppare",
    "sciroppate": "sciroppare",
    "sciroppati": "sciroppare",
    "sciroppato": "sciroppare",
    "sciroppava": "sciroppare",
    "sciroppavamo": "sciroppare",
    "sciroppavan": "sciroppare",
    "sciroppavano": "sciroppare",
    "sciroppavate": "sciroppare",
    "sciroppavi": "sciroppare",
    "sciroppavo": "sciroppare",
    "sciropperai": "sciroppare",
    "sciropperan": "sciroppare",
    "sciropperanno": "sciroppare",
    "sciropperebbe": "sciroppare",
    "sciropperebber": "sciroppare",
    "sciropperebbero": "sciroppare",
    "sciropperei": "sciroppare",
    "sciropperemmo": "sciroppare",
    "sciropperemo": "sciroppare",
    "sciroppereste": "sciroppare",
    "sciropperesti": "sciroppare",
    "sciropperete": "sciroppare",
    "sciropperà": "sciroppare",
    "sciropperò": "sciroppare",
    "sciroppi": "sciroppo",
    "sciroppiamo": "sciroppare",
    "sciroppiate": "sciroppare",
    "sciroppin": "sciroppare",
    "sciroppino": "sciroppare",
    "sciroppo": "sciroppare",
    "sciropposa": "sciropposo",
    "sciroppose": "sciropposo",
    "sciropposi": "sciropposo",
    "sciroppò": "sciroppare",
    "scismatica": "scismatico",
    "scismatiche": "scismatico",
    "scismatici": "scismatico",
    "scismi": "scisma",
    "scissa": "scisso",
    "scisse": "scisso",
    "scisser": "scindere",
    "scissero": "scindere",
    "scissi": "scisso",
    "scissioni": "scissione",
    "scissioniste": "scissionista",
    "scissionisti": "scissionista",
    "scissionistica": "scissionistico",
    "scissionistiche": "scissionistico",
    "scissionistici": "scissionistico",
    "scisso": "scindere",
    "scistosa": "scistoso",
    "scistose": "scistoso",
    "scistosi": "scistoso",
    "sciupa": "sciupare",
    "sciupai": "sciupare",
    "sciupammo": "sciupare",
    "sciupan": "sciupare",
    "sciupando": "sciupare",
    "sciupano": "sciupare",
    "sciupante": "sciupare",
    "sciupanti": "sciupare",
    "sciupar": "sciupare",
    "sciuparon": "sciupare",
    "sciuparono": "sciupare",
    "sciupasse": "sciupare",
    "sciupasser": "sciupare",
    "sciupassero": "sciupare",
    "sciupassi": "sciupare",
    "sciupassimo": "sciupare",
    "sciupaste": "sciupare",
    "sciupasti": "sciupare",
    "sciupata": "sciupare",
    "sciupate": "sciupare",
    "sciupati": "sciupare",
    "sciupato": "sciupare",
    "sciupava": "sciupare",
    "sciupavamo": "sciupare",
    "sciupavan": "sciupare",
    "sciupavano": "sciupare",
    "sciupavate": "sciupare",
    "sciupavi": "sciupare",
    "sciupavo": "sciupare",
    "sciuperai": "sciupare",
    "sciuperan": "sciupare",
    "sciuperanno": "sciupare",
    "sciuperebbe": "sciupare",
    "sciuperebber": "sciupare",
    "sciuperebbero": "sciupare",
    "sciuperei": "sciupare",
    "sciuperemmo": "sciupare",
    "sciuperemo": "sciupare",
    "sciupereste": "sciupare",
    "sciuperesti": "sciupare",
    "sciuperete": "sciupare",
    "sciuperà": "sciupare",
    "sciuperò": "sciupare",
    "sciupi": "sciupare",
    "sciupiamo": "sciupare",
    "sciupiate": "sciupare",
    "sciupin": "sciupare",
    "sciupino": "sciupare",
    "sciupo": "sciupare",
    "sciupò": "sciupare",
    "scivola": "scivolare",
    "scivolai": "scivolare",
    "scivolamenti": "scivolamento",
    "scivolammo": "scivolare",
    "scivolan": "scivolare",
    "scivolando": "scivolare",
    "scivolano": "scivolare",
    "scivolante": "scivolare",
    "scivolanti": "scivolare",
    "scivolar": "scivolare",
    "scivolaron": "scivolare",
    "scivolarono": "scivolare",
    "scivolasse": "scivolare",
    "scivolasser": "scivolare",
    "scivolassero": "scivolare",
    "scivolassi": "scivolare",
    "scivolassimo": "scivolare",
    "scivolaste": "scivolare",
    "scivolasti": "scivolare",
    "scivolata": "scivolare",
    "scivolate": "scivolata",
    "scivolati": "scivolare",
    "scivolato": "scivolare",
    "scivolava": "scivolare",
    "scivolavamo": "scivolare",
    "scivolavan": "scivolare",
    "scivolavano": "scivolare",
    "scivolavate": "scivolare",
    "scivolavi": "scivolare",
    "scivolavo": "scivolare",
    "scivolerai": "scivolare",
    "scivoleran": "scivolare",
    "scivoleranno": "scivolare",
    "scivolerebbe": "scivolare",
    "scivolerebber": "scivolare",
    "scivolerebbero": "scivolare",
    "scivolerei": "scivolare",
    "scivoleremmo": "scivolare",
    "scivoleremo": "scivolare",
    "scivolereste": "scivolare",
    "scivoleresti": "scivolare",
    "scivolerete": "scivolare",
    "scivolerà": "scivolare",
    "scivolerò": "scivolare",
    "scivoli": "scivolo",
    "scivoliamo": "scivolare",
    "scivoliate": "scivolare",
    "scivolin": "scivolare",
    "scivolino": "scivolare",
    "scivolo": "scivolare",
    "scivoloni": "scivolone",
    "scivolosa": "scivoloso",
    "scivolose": "scivoloso",
    "scivolosi": "scivoloso",
    "scivolò": "scivolare",
    "sciò": "sciare",
    "sclerosa": "sclerosare",
    "sclerosai": "sclerosare",
    "sclerosammo": "sclerosare",
    "sclerosan": "sclerosare",
    "sclerosando": "sclerosare",
    "sclerosano": "sclerosare",
    "sclerosante": "sclerosare",
    "sclerosanti": "sclerosare",
    "sclerosar": "sclerosare",
    "sclerosaron": "sclerosare",
    "sclerosarono": "sclerosare",
    "sclerosasse": "sclerosare",
    "sclerosasser": "sclerosare",
    "sclerosassero": "sclerosare",
    "sclerosassi": "sclerosare",
    "sclerosassimo": "sclerosare",
    "sclerosaste": "sclerosare",
    "sclerosasti": "sclerosare",
    "sclerosata": "sclerosare",
    "sclerosate": "sclerosare",
    "sclerosati": "sclerosare",
    "sclerosato": "sclerosare",
    "sclerosava": "sclerosare",
    "sclerosavamo": "sclerosare",
    "sclerosavan": "sclerosare",
    "sclerosavano": "sclerosare",
    "sclerosavate": "sclerosare",
    "sclerosavi": "sclerosare",
    "sclerosavo": "sclerosare",
    "scleroserai": "sclerosare",
    "scleroseran": "sclerosare",
    "scleroseranno": "sclerosare",
    "scleroserebbe": "sclerosare",
    "scleroserebber": "sclerosare",
    "scleroserebbero": "sclerosare",
    "scleroserei": "sclerosare",
    "scleroseremmo": "sclerosare",
    "scleroseremo": "sclerosare",
    "sclerosereste": "sclerosare",
    "scleroseresti": "sclerosare",
    "scleroserete": "sclerosare",
    "scleroserà": "sclerosare",
    "scleroserò": "sclerosare",
    "sclerosi": "sclerosare",
    "sclerosiamo": "sclerosare",
    "sclerosiate": "sclerosare",
    "sclerosin": "sclerosare",
    "sclerosino": "sclerosare",
    "scleroso": "sclerosare",
    "sclerosò": "sclerosare",
    "sclerotica": "sclerotico",
    "sclerotiche": "sclerotico",
    "sclerotici": "sclerotico",
    "sclerotizza": "sclerotizzare",
    "sclerotizzai": "sclerotizzare",
    "sclerotizzammo": "sclerotizzare",
    "sclerotizzan": "sclerotizzare",
    "sclerotizzando": "sclerotizzare",
    "sclerotizzano": "sclerotizzare",
    "sclerotizzante": "sclerotizzare",
    "sclerotizzanti": "sclerotizzare",
    "sclerotizzar": "sclerotizzare",
    "sclerotizzaron": "sclerotizzare",
    "sclerotizzarono": "sclerotizzare",
    "sclerotizzasse": "sclerotizzare",
    "sclerotizzasser": "sclerotizzare",
    "sclerotizzassero": "sclerotizzare",
    "sclerotizzassi": "sclerotizzare",
    "sclerotizzassimo": "sclerotizzare",
    "sclerotizzaste": "sclerotizzare",
    "sclerotizzasti": "sclerotizzare",
    "sclerotizzata": "sclerotizzare",
    "sclerotizzate": "sclerotizzare",
    "sclerotizzati": "sclerotizzare",
    "sclerotizzato": "sclerotizzare",
    "sclerotizzava": "sclerotizzare",
    "sclerotizzavamo": "sclerotizzare",
    "sclerotizzavan": "sclerotizzare",
    "sclerotizzavano": "sclerotizzare",
    "sclerotizzavate": "sclerotizzare",
    "sclerotizzavi": "sclerotizzare",
    "sclerotizzavo": "sclerotizzare",
    "sclerotizzerai": "sclerotizzare",
    "sclerotizzeran": "sclerotizzare",
    "sclerotizzeranno": "sclerotizzare",
    "sclerotizzerebbe": "sclerotizzare",
    "sclerotizzerebber": "sclerotizzare",
    "sclerotizzerebbero": "sclerotizzare",
    "sclerotizzerei": "sclerotizzare",
    "sclerotizzeremmo": "sclerotizzare",
    "sclerotizzeremo": "sclerotizzare",
    "sclerotizzereste": "sclerotizzare",
    "sclerotizzeresti": "sclerotizzare",
    "sclerotizzerete": "sclerotizzare",
    "sclerotizzerà": "sclerotizzare",
    "sclerotizzerò": "sclerotizzare",
    "sclerotizzi": "sclerotizzare",
    "sclerotizziamo": "sclerotizzare",
    "sclerotizziate": "sclerotizzare",
    "sclerotizzin": "sclerotizzare",
    "sclerotizzino": "sclerotizzare",
    "sclerotizzo": "sclerotizzare",
    "sclerotizzò": "sclerotizzare",
    "scocca": "scoccare",
    "scoccai": "scoccare",
    "scoccammo": "scoccare",
    "scoccan": "scoccare",
    "scoccando": "scoccare",
    "scoccano": "scoccare",
    "scoccante": "scoccare",
    "scoccanti": "scoccare",
    "scoccar": "scoccare",
    "scoccaron": "scoccare",
    "scoccarono": "scoccare",
    "scoccasse": "scoccare",
    "scoccasser": "scoccare",
    "scoccassero": "scoccare",
    "scoccassi": "scoccare",
    "scoccassimo": "scoccare",
    "scoccaste": "scoccare",
    "scoccasti": "scoccare",
    "scoccata": "scoccare",
    "scoccate": "scoccare",
    "scoccati": "scoccare",
    "scoccato": "scoccare",
    "scoccava": "scoccare",
    "scoccavamo": "scoccare",
    "scoccavan": "scoccare",
    "scoccavano": "scoccare",
    "scoccavate": "scoccare",
    "scoccavi": "scoccare",
    "scoccavo": "scoccare",
    "scoccerai": "scocciare",
    "scocceran": "scocciare",
    "scocceranno": "scocciare",
    "scoccerebbe": "scocciare",
    "scoccerebber": "scocciare",
    "scoccerebbero": "scocciare",
    "scoccerei": "scocciare",
    "scocceremmo": "scocciare",
    "scocceremo": "scocciare",
    "scoccereste": "scocciare",
    "scocceresti": "scocciare",
    "scoccerete": "scocciare",
    "scoccerà": "scocciare",
    "scoccerò": "scocciare",
    "scocche": "scocca",
    "scoccherai": "scoccare",
    "scoccheran": "scoccare",
    "scoccheranno": "scoccare",
    "scoccherebbe": "scoccare",
    "scoccherebber": "scoccare",
    "scoccherebbero": "scoccare",
    "scoccherei": "scoccare",
    "scoccheremmo": "scoccare",
    "scoccheremo": "scoccare",
    "scocchereste": "scoccare",
    "scoccheresti": "scoccare",
    "scoccherete": "scoccare",
    "scoccherà": "scoccare",
    "scoccherò": "scoccare",
    "scocchi": "scoccare",
    "scocchiamo": "scoccare",
    "scocchiate": "scoccare",
    "scocchin": "scoccare",
    "scocchino": "scoccare",
    "scocci": "scocciare",
    "scoccia": "scocciare",
    "scocciai": "scocciare",
    "scocciammo": "scocciare",
    "scocciamo": "scocciare",
    "scoccian": "scocciare",
    "scocciando": "scocciare",
    "scocciano": "scocciare",
    "scocciante": "scocciare",
    "scoccianti": "scocciare",
    "scocciar": "scocciare",
    "scocciaron": "scocciare",
    "scocciarono": "scocciare",
    "scocciasse": "scocciare",
    "scocciasser": "scocciare",
    "scocciassero": "scocciare",
    "scocciassi": "scocciare",
    "scocciassimo": "scocciare",
    "scocciaste": "scocciare",
    "scocciasti": "scocciare",
    "scocciata": "scocciato",
    "scocciate": "scocciato",
    "scocciati": "scocciato",
    "scocciato": "scocciare",
    "scocciatori": "scocciatore",
    "scocciature": "scocciatura",
    "scocciava": "scocciare",
    "scocciavamo": "scocciare",
    "scocciavan": "scocciare",
    "scocciavano": "scocciare",
    "scocciavate": "scocciare",
    "scocciavi": "scocciare",
    "scocciavo": "scocciare",
    "scoccin": "scocciare",
    "scoccino": "scocciare",
    "scoccio": "scocciare",
    "scocciò": "scocciare",
    "scocco": "scoccare",
    "scoccò": "scoccare",
    "scoda": "scodare",
    "scodai": "scodare",
    "scodammo": "scodare",
    "scodan": "scodare",
    "scodando": "scodare",
    "scodano": "scodare",
    "scodante": "scodare",
    "scodanti": "scodare",
    "scodar": "scodare",
    "scodaron": "scodare",
    "scodarono": "scodare",
    "scodasse": "scodare",
    "scodasser": "scodare",
    "scodassero": "scodare",
    "scodassi": "scodare",
    "scodassimo": "scodare",
    "scodaste": "scodare",
    "scodasti": "scodare",
    "scodata": "scodare",
    "scodate": "scodare",
    "scodati": "scodare",
    "scodato": "scodare",
    "scodava": "scodare",
    "scodavamo": "scodare",
    "scodavan": "scodare",
    "scodavano": "scodare",
    "scodavate": "scodare",
    "scodavi": "scodare",
    "scodavo": "scodare",
    "scodella": "scodellare",
    "scodellai": "scodellare",
    "scodellammo": "scodellare",
    "scodellan": "scodellare",
    "scodellando": "scodellare",
    "scodellano": "scodellare",
    "scodellante": "scodellare",
    "scodellanti": "scodellare",
    "scodellar": "scodellare",
    "scodellaron": "scodellare",
    "scodellarono": "scodellare",
    "scodellasse": "scodellare",
    "scodellasser": "scodellare",
    "scodellassero": "scodellare",
    "scodellassi": "scodellare",
    "scodellassimo": "scodellare",
    "scodellaste": "scodellare",
    "scodellasti": "scodellare",
    "scodellata": "scodellare",
    "scodellate": "scodellare",
    "scodellati": "scodellare",
    "scodellato": "scodellare",
    "scodellava": "scodellare",
    "scodellavamo": "scodellare",
    "scodellavan": "scodellare",
    "scodellavano": "scodellare",
    "scodellavate": "scodellare",
    "scodellavi": "scodellare",
    "scodellavo": "scodellare",
    "scodelle": "scodella",
    "scodellerai": "scodellare",
    "scodelleran": "scodellare",
    "scodelleranno": "scodellare",
    "scodellerebbe": "scodellare",
    "scodellerebber": "scodellare",
    "scodellerebbero": "scodellare",
    "scodellerei": "scodellare",
    "scodelleremmo": "scodellare",
    "scodelleremo": "scodellare",
    "scodellereste": "scodellare",
    "scodelleresti": "scodellare",
    "scodellerete": "scodellare",
    "scodellerà": "scodellare",
    "scodellerò": "scodellare",
    "scodelli": "scodellare",
    "scodelliamo": "scodellare",
    "scodelliate": "scodellare",
    "scodellin": "scodellare",
    "scodellino": "scodellare",
    "scodello": "scodellare",
    "scodellò": "scodellare",
    "scoderai": "scodare",
    "scoderan": "scodare",
    "scoderanno": "scodare",
    "scoderebbe": "scodare",
    "scoderebber": "scodare",
    "scoderebbero": "scodare",
    "scoderei": "scodare",
    "scoderemmo": "scodare",
    "scoderemo": "scodare",
    "scodereste": "scodare",
    "scoderesti": "scodare",
    "scoderete": "scodare",
    "scoderà": "scodare",
    "scoderò": "scodare",
    "scodi": "scodare",
    "scodiamo": "scodare",
    "scodiate": "scodare",
    "scodin": "scodare",
    "scodino": "scodare",
    "scodinzola": "scodinzolare",
    "scodinzolai": "scodinzolare",
    "scodinzolammo": "scodinzolare",
    "scodinzolan": "scodinzolare",
    "scodinzolando": "scodinzolare",
    "scodinzolano": "scodinzolare",
    "scodinzolante": "scodinzolare",
    "scodinzolanti": "scodinzolare",
    "scodinzolar": "scodinzolare",
    "scodinzolaron": "scodinzolare",
    "scodinzolarono": "scodinzolare",
    "scodinzolasse": "scodinzolare",
    "scodinzolasser": "scodinzolare",
    "scodinzolassero": "scodinzolare",
    "scodinzolassi": "scodinzolare",
    "scodinzolassimo": "scodinzolare",
    "scodinzolaste": "scodinzolare",
    "scodinzolasti": "scodinzolare",
    "scodinzolata": "scodinzolare",
    "scodinzolate": "scodinzolare",
    "scodinzolati": "scodinzolare",
    "scodinzolato": "scodinzolare",
    "scodinzolava": "scodinzolare",
    "scodinzolavamo": "scodinzolare",
    "scodinzolavan": "scodinzolare",
    "scodinzolavano": "scodinzolare",
    "scodinzolavate": "scodinzolare",
    "scodinzolavi": "scodinzolare",
    "scodinzolavo": "scodinzolare",
    "scodinzolerai": "scodinzolare",
    "scodinzoleran": "scodinzolare",
    "scodinzoleranno": "scodinzolare",
    "scodinzolerebbe": "scodinzolare",
    "scodinzolerebber": "scodinzolare",
    "scodinzolerebbero": "scodinzolare",
    "scodinzolerei": "scodinzolare",
    "scodinzoleremmo": "scodinzolare",
    "scodinzoleremo": "scodinzolare",
    "scodinzolereste": "scodinzolare",
    "scodinzoleresti": "scodinzolare",
    "scodinzolerete": "scodinzolare",
    "scodinzolerà": "scodinzolare",
    "scodinzolerò": "scodinzolare",
    "scodinzoli": "scodinzolare",
    "scodinzoliamo": "scodinzolare",
    "scodinzoliate": "scodinzolare",
    "scodinzolin": "scodinzolare",
    "scodinzolino": "scodinzolare",
    "scodinzolo": "scodinzolare",
    "scodinzolò": "scodinzolare",
    "scodo": "scodare",
    "scodò": "scodare",
    "scogli": "scoglio",
    "scogliere": "scogliera",
    "scogliosa": "scoglioso",
    "scogliose": "scoglioso",
    "scogliosi": "scoglioso",
    "scoiattoli": "scoiattolo",
    "scola": "scolare",
    "scolai": "scolare",
    "scolammo": "scolare",
    "scolan": "scolare",
    "scolando": "scolare",
    "scolano": "scolare",
    "scolante": "scolare",
    "scolanti": "scolare",
    "scolar": "scolare",
    "scolaresche": "scolaresca",
    "scolarette": "scolaretta",
    "scolaretti": "scolaretto",
    "scolari": "scolaro",
    "scolarizzazioni": "scolarizzazione",
    "scolaron": "scolare",
    "scolarono": "scolare",
    "scolasse": "scolare",
    "scolasser": "scolare",
    "scolassero": "scolare",
    "scolassi": "scolare",
    "scolassimo": "scolare",
    "scolaste": "scolare",
    "scolasti": "scolare",
    "scolastica": "scolastico",
    "scolastiche": "scolastico",
    "scolastici": "scolastico",
    "scolata": "scolare",
    "scolate": "scolare",
    "scolati": "scolare",
    "scolato": "scolare",
    "scolava": "scolare",
    "scolavamo": "scolare",
    "scolavan": "scolare",
    "scolavano": "scolare",
    "scolavate": "scolare",
    "scolavi": "scolare",
    "scolavo": "scolare",
    "scolerai": "scolare",
    "scoleran": "scolare",
    "scoleranno": "scolare",
    "scolerebbe": "scolare",
    "scolerebber": "scolare",
    "scolerebbero": "scolare",
    "scolerei": "scolare",
    "scoleremmo": "scolare",
    "scoleremo": "scolare",
    "scolereste": "scolare",
    "scoleresti": "scolare",
    "scolerete": "scolare",
    "scolerà": "scolare",
    "scolerò": "scolare",
    "scoli": "scolare",
    "scoliamo": "scolare",
    "scoliate": "scolare",
    "scolin": "scolare",
    "scolino": "scolare",
    "scolla": "scollare",
    "scollaccerai": "scollacciare",
    "scollacceran": "scollacciare",
    "scollacceranno": "scollacciare",
    "scollaccerebbe": "scollacciare",
    "scollaccerebber": "scollacciare",
    "scollaccerebbero": "scollacciare",
    "scollaccerei": "scollacciare",
    "scollacceremmo": "scollacciare",
    "scollacceremo": "scollacciare",
    "scollaccereste": "scollacciare",
    "scollacceresti": "scollacciare",
    "scollaccerete": "scollacciare",
    "scollaccerà": "scollacciare",
    "scollaccerò": "scollacciare",
    "scollacci": "scollacciare",
    "scollaccia": "scollacciare",
    "scollacciai": "scollacciare",
    "scollacciammo": "scollacciare",
    "scollacciamo": "scollacciare",
    "scollaccian": "scollacciare",
    "scollacciando": "scollacciare",
    "scollacciano": "scollacciare",
    "scollacciar": "scollacciare",
    "scollacciaron": "scollacciare",
    "scollacciarono": "scollacciare",
    "scollacciasse": "scollacciare",
    "scollacciasser": "scollacciare",
    "scollacciassero": "scollacciare",
    "scollacciassi": "scollacciare",
    "scollacciassimo": "scollacciare",
    "scollacciaste": "scollacciare",
    "scollacciasti": "scollacciare",
    "scollacciata": "scollacciato",
    "scollacciate": "scollacciato",
    "scollacciati": "scollacciato",
    "scollacciato": "scollacciare",
    "scollacciava": "scollacciare",
    "scollacciavamo": "scollacciare",
    "scollacciavan": "scollacciare",
    "scollacciavano": "scollacciare",
    "scollacciavate": "scollacciare",
    "scollacciavi": "scollacciare",
    "scollacciavo": "scollacciare",
    "scollaccin": "scollacciare",
    "scollaccino": "scollacciare",
    "scollaccio": "scollacciare",
    "scollacciò": "scollacciare",
    "scollai": "scollare",
    "scollamenti": "scollamento",
    "scollammo": "scollare",
    "scollan": "scollare",
    "scollando": "scollare",
    "scollano": "scollare",
    "scollante": "scollare",
    "scollanti": "scollare",
    "scollar": "scollare",
    "scollaron": "scollare",
    "scollarono": "scollare",
    "scollasse": "scollare",
    "scollasser": "scollare",
    "scollassero": "scollare",
    "scollassi": "scollare",
    "scollassimo": "scollare",
    "scollaste": "scollare",
    "scollasti": "scollare",
    "scollata": "scollato",
    "scollate": "scollato",
    "scollati": "scollato",
    "scollato": "scollare",
    "scollature": "scollatura",
    "scollava": "scollare",
    "scollavamo": "scollare",
    "scollavan": "scollare",
    "scollavano": "scollare",
    "scollavate": "scollare",
    "scollavi": "scollare",
    "scollavo": "scollare",
    "scollerai": "scollare",
    "scolleran": "scollare",
    "scolleranno": "scollare",
    "scollerebbe": "scollare",
    "scollerebber": "scollare",
    "scollerebbero": "scollare",
    "scollerei": "scollare",
    "scolleremmo": "scollare",
    "scolleremo": "scollare",
    "scollereste": "scollare",
    "scolleresti": "scollare",
    "scollerete": "scollare",
    "scollerà": "scollare",
    "scollerò": "scollare",
    "scolli": "scollo",
    "scolliamo": "scollare",
    "scolliate": "scollare",
    "scollin": "scollare",
    "scollino": "scollare",
    "scollo": "scollare",
    "scollò": "scollare",
    "scolo": "scolare",
    "scolora": "scolorire",
    "scolorai": "scolorare",
    "scolorammo": "scolorare",
    "scoloran": "scolorire",
    "scolorando": "scolorare",
    "scolorano": "scolorire",
    "scolorante": "scolorare",
    "scoloranti": "scolorare",
    "scolorar": "scolorare",
    "scoloraron": "scolorare",
    "scolorarono": "scolorare",
    "scolorasse": "scolorare",
    "scolorasser": "scolorare",
    "scolorassero": "scolorare",
    "scolorassi": "scolorare",
    "scolorassimo": "scolorare",
    "scoloraste": "scolorare",
    "scolorasti": "scolorare",
    "scolorata": "scolorare",
    "scolorate": "scolorare",
    "scolorati": "scolorare",
    "scolorato": "scolorare",
    "scolorava": "scolorare",
    "scoloravamo": "scolorare",
    "scoloravan": "scolorare",
    "scoloravano": "scolorare",
    "scoloravate": "scolorare",
    "scoloravi": "scolorare",
    "scoloravo": "scolorare",
    "scolore": "scolorire",
    "scolorendo": "scolorire",
    "scolorente": "scolorire",
    "scolorenti": "scolorire",
    "scolorerai": "scolorare",
    "scoloreran": "scolorare",
    "scoloreranno": "scolorare",
    "scolorerebbe": "scolorare",
    "scolorerebber": "scolorare",
    "scolorerebbero": "scolorare",
    "scolorerei": "scolorare",
    "scoloreremmo": "scolorare",
    "scoloreremo": "scolorare",
    "scolorereste": "scolorare",
    "scoloreresti": "scolorare",
    "scolorerete": "scolorare",
    "scolorerà": "scolorare",
    "scolorerò": "scolorare",
    "scolori": "scolorire",
    "scoloriamo": "scolorire",
    "scoloriate": "scolorire",
    "scolorii": "scolorire",
    "scolorimmo": "scolorire",
    "scolorin": "scolorare",
    "scolorino": "scolorare",
    "scolorir": "scolorire",
    "scolorirai": "scolorire",
    "scoloriran": "scolorire",
    "scoloriranno": "scolorire",
    "scolorirebbe": "scolorire",
    "scolorirebber": "scolorire",
    "scolorirebbero": "scolorire",
    "scolorirei": "scolorire",
    "scoloriremmo": "scolorire",
    "scoloriremo": "scolorire",
    "scolorireste": "scolorire",
    "scoloriresti": "scolorire",
    "scolorirete": "scolorire",
    "scoloriron": "scolorire",
    "scolorirono": "scolorire",
    "scolorirà": "scolorire",
    "scolorirò": "scolorire",
    "scolorisse": "scolorire",
    "scolorisser": "scolorire",
    "scolorissero": "scolorire",
    "scolorissi": "scolorire",
    "scolorissimo": "scolorire",
    "scoloriste": "scolorire",
    "scoloristi": "scolorire",
    "scolorita": "scolorire",
    "scolorite": "scolorire",
    "scoloriti": "scolorire",
    "scolorito": "scolorire",
    "scoloriva": "scolorire",
    "scolorivamo": "scolorire",
    "scolorivan": "scolorire",
    "scolorivano": "scolorire",
    "scolorivate": "scolorire",
    "scolorivi": "scolorire",
    "scolorivo": "scolorire",
    "scoloro": "scolorire",
    "scoloron": "scolorire",
    "scolorono": "scolorire",
    "scolorì": "scolorire",
    "scolorò": "scolorare",
    "scolpa": "scolpare",
    "scolpai": "scolpare",
    "scolpammo": "scolpare",
    "scolpan": "scolpare",
    "scolpando": "scolpare",
    "scolpano": "scolpare",
    "scolpante": "scolpare",
    "scolpanti": "scolpare",
    "scolpar": "scolpare",
    "scolparon": "scolpare",
    "scolparono": "scolpare",
    "scolpasse": "scolpare",
    "scolpasser": "scolpare",
    "scolpassero": "scolpare",
    "scolpassi": "scolpare",
    "scolpassimo": "scolpare",
    "scolpaste": "scolpare",
    "scolpasti": "scolpare",
    "scolpata": "scolpare",
    "scolpate": "scolpare",
    "scolpati": "scolpare",
    "scolpato": "scolpare",
    "scolpava": "scolpare",
    "scolpavamo": "scolpare",
    "scolpavan": "scolpare",
    "scolpavano": "scolpare",
    "scolpavate": "scolpare",
    "scolpavi": "scolpare",
    "scolpavo": "scolpare",
    "scolpendo": "scolpire",
    "scolpente": "scolpire",
    "scolpenti": "scolpire",
    "scolperai": "scolpare",
    "scolperan": "scolpare",
    "scolperanno": "scolpare",
    "scolperebbe": "scolpare",
    "scolperebber": "scolpare",
    "scolperebbero": "scolpare",
    "scolperei": "scolpare",
    "scolperemmo": "scolpare",
    "scolperemo": "scolpare",
    "scolpereste": "scolpare",
    "scolperesti": "scolpare",
    "scolperete": "scolpare",
    "scolperà": "scolpare",
    "scolperò": "scolpare",
    "scolpi": "scolpare",
    "scolpiamo": "scolpire",
    "scolpiate": "scolpire",
    "scolpii": "scolpire",
    "scolpimmo": "scolpire",
    "scolpin": "scolpare",
    "scolpino": "scolpare",
    "scolpir": "scolpire",
    "scolpirai": "scolpire",
    "scolpiran": "scolpire",
    "scolpiranno": "scolpire",
    "scolpirebbe": "scolpire",
    "scolpirebber": "scolpire",
    "scolpirebbero": "scolpire",
    "scolpirei": "scolpire",
    "scolpiremmo": "scolpire",
    "scolpiremo": "scolpire",
    "scolpireste": "scolpire",
    "scolpiresti": "scolpire",
    "scolpirete": "scolpire",
    "scolpiron": "scolpire",
    "scolpirono": "scolpire",
    "scolpirà": "scolpire",
    "scolpirò": "scolpire",
    "scolpisca": "scolpire",
    "scolpiscan": "scolpire",
    "scolpiscano": "scolpire",
    "scolpisce": "scolpire",
    "scolpisci": "scolpire",
    "scolpisco": "scolpire",
    "scolpiscon": "scolpire",
    "scolpiscono": "scolpire",
    "scolpisse": "scolpire",
    "scolpisser": "scolpire",
    "scolpissero": "scolpire",
    "scolpissi": "scolpire",
    "scolpissimo": "scolpire",
    "scolpiste": "scolpire",
    "scolpisti": "scolpire",
    "scolpita": "scolpito",
    "scolpite": "scolpito",
    "scolpiti": "scolpito",
    "scolpito": "scolpire",
    "scolpiva": "scolpire",
    "scolpivamo": "scolpire",
    "scolpivan": "scolpire",
    "scolpivano": "scolpire",
    "scolpivate": "scolpire",
    "scolpivi": "scolpire",
    "scolpivo": "scolpire",
    "scolpo": "scolpare",
    "scolpì": "scolpire",
    "scolpò": "scolpare",
    "scolò": "scolare",
    "scombicchera": "scombiccherare",
    "scombiccherai": "scombiccherare",
    "scombiccherammo": "scombiccherare",
    "scombiccheran": "scombiccherare",
    "scombiccherando": "scombiccherare",
    "scombiccherano": "scombiccherare",
    "scombiccherante": "scombiccherare",
    "scombiccheranti": "scombiccherare",
    "scombiccherar": "scombiccherare",
    "scombiccheraron": "scombiccherare",
    "scombiccherarono": "scombiccherare",
    "scombiccherasse": "scombiccherare",
    "scombiccherasser": "scombiccherare",
    "scombiccherassero": "scombiccherare",
    "scombiccherassi": "scombiccherare",
    "scombiccherassimo": "scombiccherare",
    "scombiccheraste": "scombiccherare",
    "scombiccherasti": "scombiccherare",
    "scombiccherata": "scombiccherare",
    "scombiccherate": "scombiccherare",
    "scombiccherati": "scombiccherare",
    "scombiccherato": "scombiccherare",
    "scombiccherava": "scombiccherare",
    "scombiccheravamo": "scombiccherare",
    "scombiccheravan": "scombiccherare",
    "scombiccheravano": "scombiccherare",
    "scombiccheravate": "scombiccherare",
    "scombiccheravi": "scombiccherare",
    "scombiccheravo": "scombiccherare",
    "scombicchererai": "scombiccherare",
    "scombicchereran": "scombiccherare",
    "scombicchereranno": "scombiccherare",
    "scombicchererebbe": "scombiccherare",
    "scombicchererebber": "scombiccherare",
    "scombicchererebbero": "scombiccherare",
    "scombicchererei": "scombiccherare",
    "scombicchereremmo": "scombiccherare",
    "scombicchereremo": "scombiccherare",
    "scombiccherereste": "scombiccherare",
    "scombicchereresti": "scombiccherare",
    "scombicchererete": "scombiccherare",
    "scombicchererà": "scombiccherare",
    "scombicchererò": "scombiccherare",
    "scombiccheri": "scombiccherare",
    "scombiccheriamo": "scombiccherare",
    "scombiccheriate": "scombiccherare",
    "scombiccherin": "scombiccherare",
    "scombiccherino": "scombiccherare",
    "scombicchero": "scombiccherare",
    "scombiccherò": "scombiccherare",
    "scombina": "scombinare",
    "scombinai": "scombinare",
    "scombinammo": "scombinare",
    "scombinan": "scombinare",
    "scombinando": "scombinare",
    "scombinano": "scombinare",
    "scombinante": "scombinare",
    "scombinanti": "scombinare",
    "scombinar": "scombinare",
    "scombinaron": "scombinare",
    "scombinarono": "scombinare",
    "scombinasse": "scombinare",
    "scombinasser": "scombinare",
    "scombinassero": "scombinare",
    "scombinassi": "scombinare",
    "scombinassimo": "scombinare",
    "scombinaste": "scombinare",
    "scombinasti": "scombinare",
    "scombinata": "scombinato",
    "scombinate": "scombinato",
    "scombinati": "scombinato",
    "scombinato": "scombinare",
    "scombinava": "scombinare",
    "scombinavamo": "scombinare",
    "scombinavan": "scombinare",
    "scombinavano": "scombinare",
    "scombinavate": "scombinare",
    "scombinavi": "scombinare",
    "scombinavo": "scombinare",
    "scombinerai": "scombinare",
    "scombineran": "scombinare",
    "scombineranno": "scombinare",
    "scombinerebbe": "scombinare",
    "scombinerebber": "scombinare",
    "scombinerebbero": "scombinare",
    "scombinerei": "scombinare",
    "scombineremmo": "scombinare",
    "scombineremo": "scombinare",
    "scombinereste": "scombinare",
    "scombineresti": "scombinare",
    "scombinerete": "scombinare",
    "scombinerà": "scombinare",
    "scombinerò": "scombinare",
    "scombini": "scombinare",
    "scombiniamo": "scombinare",
    "scombiniate": "scombinare",
    "scombinin": "scombinare",
    "scombinino": "scombinare",
    "scombino": "scombinare",
    "scombinò": "scombinare",
    "scombui": "scombuiare",
    "scombuia": "scombuiare",
    "scombuiai": "scombuiare",
    "scombuiammo": "scombuiare",
    "scombuiamo": "scombuiare",
    "scombuian": "scombuiare",
    "scombuiando": "scombuiare",
    "scombuiano": "scombuiare",
    "scombuiante": "scombuiare",
    "scombuianti": "scombuiare",
    "scombuiar": "scombuiare",
    "scombuiaron": "scombuiare",
    "scombuiarono": "scombuiare",
    "scombuiasse": "scombuiare",
    "scombuiasser": "scombuiare",
    "scombuiassero": "scombuiare",
    "scombuiassi": "scombuiare",
    "scombuiassimo": "scombuiare",
    "scombuiaste": "scombuiare",
    "scombuiasti": "scombuiare",
    "scombuiata": "scombuiare",
    "scombuiate": "scombuiare",
    "scombuiati": "scombuiare",
    "scombuiato": "scombuiare",
    "scombuiava": "scombuiare",
    "scombuiavamo": "scombuiare",
    "scombuiavan": "scombuiare",
    "scombuiavano": "scombuiare",
    "scombuiavate": "scombuiare",
    "scombuiavi": "scombuiare",
    "scombuiavo": "scombuiare",
    "scombuierai": "scombuiare",
    "scombuieran": "scombuiare",
    "scombuieranno": "scombuiare",
    "scombuierebbe": "scombuiare",
    "scombuierebber": "scombuiare",
    "scombuierebbero": "scombuiare",
    "scombuierei": "scombuiare",
    "scombuieremmo": "scombuiare",
    "scombuieremo": "scombuiare",
    "scombuiereste": "scombuiare",
    "scombuieresti": "scombuiare",
    "scombuierete": "scombuiare",
    "scombuierà": "scombuiare",
    "scombuierò": "scombuiare",
    "scombuin": "scombuiare",
    "scombuino": "scombuiare",
    "scombuio": "scombuiare",
    "scombuiò": "scombuiare",
    "scombussola": "scombussolare",
    "scombussolai": "scombussolare",
    "scombussolamenti": "scombussolamento",
    "scombussolammo": "scombussolare",
    "scombussolan": "scombussolare",
    "scombussolando": "scombussolare",
    "scombussolano": "scombussolare",
    "scombussolante": "scombussolare",
    "scombussolanti": "scombussolare",
    "scombussolar": "scombussolare",
    "scombussolaron": "scombussolare",
    "scombussolarono": "scombussolare",
    "scombussolasse": "scombussolare",
    "scombussolasser": "scombussolare",
    "scombussolassero": "scombussolare",
    "scombussolassi": "scombussolare",
    "scombussolassimo": "scombussolare",
    "scombussolaste": "scombussolare",
    "scombussolasti": "scombussolare",
    "scombussolata": "scombussolare",
    "scombussolate": "scombussolare",
    "scombussolati": "scombussolare",
    "scombussolato": "scombussolare",
    "scombussolava": "scombussolare",
    "scombussolavamo": "scombussolare",
    "scombussolavan": "scombussolare",
    "scombussolavano": "scombussolare",
    "scombussolavate": "scombussolare",
    "scombussolavi": "scombussolare",
    "scombussolavo": "scombussolare",
    "scombussolerai": "scombussolare",
    "scombussoleran": "scombussolare",
    "scombussoleranno": "scombussolare",
    "scombussolerebbe": "scombussolare",
    "scombussolerebber": "scombussolare",
    "scombussolerebbero": "scombussolare",
    "scombussolerei": "scombussolare",
    "scombussoleremmo": "scombussolare",
    "scombussoleremo": "scombussolare",
    "scombussolereste": "scombussolare",
    "scombussoleresti": "scombussolare",
    "scombussolerete": "scombussolare",
    "scombussolerà": "scombussolare",
    "scombussolerò": "scombussolare",
    "scombussoli": "scombussolare",
    "scombussoliamo": "scombussolare",
    "scombussoliate": "scombussolare",
    "scombussolin": "scombussolare",
    "scombussolino": "scombussolare",
    "scombussolo": "scombussolare",
    "scombussolò": "scombussolare",
    "scommessa": "scommettere",
    "scommesse": "scommettere",
    "scommessi": "scommettere",
    "scommesso": "scommettere",
    "scommetta": "scommettere",
    "scommettan": "scommettere",
    "scommettano": "scommettere",
    "scommette": "scommettere",
    "scommettemmo": "scommettere",
    "scommettendo": "scommettere",
    "scommettente": "scommettere",
    "scommettenti": "scommettere",
    "scommetter": "scommettere",
    "scommetterai": "scommettere",
    "scommetteran": "scommettere",
    "scommetteranno": "scommettere",
    "scommetterebbe": "scommettere",
    "scommetterebber": "scommettere",
    "scommetterebbero": "scommettere",
    "scommetterei": "scommettere",
    "scommetteremmo": "scommettere",
    "scommetteremo": "scommettere",
    "scommettereste": "scommettere",
    "scommetteresti": "scommettere",
    "scommetterete": "scommettere",
    "scommetterà": "scommettere",
    "scommetterò": "scommettere",
    "scommettesse": "scommettere",
    "scommettesser": "scommettere",
    "scommettessero": "scommettere",
    "scommettessi": "scommettere",
    "scommettessimo": "scommettere",
    "scommetteste": "scommettere",
    "scommettesti": "scommettere",
    "scommettete": "scommettere",
    "scommetteva": "scommettere",
    "scommettevamo": "scommettere",
    "scommettevan": "scommettere",
    "scommettevano": "scommettere",
    "scommettevate": "scommettere",
    "scommettevi": "scommettere",
    "scommettevo": "scommettere",
    "scommetti": "scommettere",
    "scommettiamo": "scommettere",
    "scommettiate": "scommettere",
    "scommettitori": "scommettitore",
    "scommetto": "scommettere",
    "scommetton": "scommettere",
    "scommettono": "scommettere",
    "scommise": "scommettere",
    "scommiser": "scommettere",
    "scommisero": "scommettere",
    "scommisi": "scommettere",
    "scomoda": "scomodo",
    "scomodai": "scomodare",
    "scomodammo": "scomodare",
    "scomodan": "scomodare",
    "scomodando": "scomodare",
    "scomodano": "scomodare",
    "scomodante": "scomodare",
    "scomodanti": "scomodare",
    "scomodar": "scomodare",
    "scomodaron": "scomodare",
    "scomodarono": "scomodare",
    "scomodasse": "scomodare",
    "scomodasser": "scomodare",
    "scomodassero": "scomodare",
    "scomodassi": "scomodare",
    "scomodassimo": "scomodare",
    "scomodaste": "scomodare",
    "scomodasti": "scomodare",
    "scomodata": "scomodare",
    "scomodate": "scomodare",
    "scomodati": "scomodare",
    "scomodato": "scomodare",
    "scomodava": "scomodare",
    "scomodavamo": "scomodare",
    "scomodavan": "scomodare",
    "scomodavano": "scomodare",
    "scomodavate": "scomodare",
    "scomodavi": "scomodare",
    "scomodavo": "scomodare",
    "scomode": "scomodo",
    "scomoderai": "scomodare",
    "scomoderan": "scomodare",
    "scomoderanno": "scomodare",
    "scomoderebbe": "scomodare",
    "scomoderebber": "scomodare",
    "scomoderebbero": "scomodare",
    "scomoderei": "scomodare",
    "scomoderemmo": "scomodare",
    "scomoderemo": "scomodare",
    "scomodereste": "scomodare",
    "scomoderesti": "scomodare",
    "scomoderete": "scomodare",
    "scomoderà": "scomodare",
    "scomoderò": "scomodare",
    "scomodi": "scomodo",
    "scomodiamo": "scomodare",
    "scomodiate": "scomodare",
    "scomodin": "scomodare",
    "scomodino": "scomodare",
    "scomodo": "scomodare",
    "scomodò": "scomodare",
    "scompagina": "scompaginare",
    "scompaginai": "scompaginare",
    "scompaginammo": "scompaginare",
    "scompaginan": "scompaginare",
    "scompaginando": "scompaginare",
    "scompaginano": "scompaginare",
    "scompaginante": "scompaginare",
    "scompaginanti": "scompaginare",
    "scompaginar": "scompaginare",
    "scompaginaron": "scompaginare",
    "scompaginarono": "scompaginare",
    "scompaginasse": "scompaginare",
    "scompaginasser": "scompaginare",
    "scompaginassero": "scompaginare",
    "scompaginassi": "scompaginare",
    "scompaginassimo": "scompaginare",
    "scompaginaste": "scompaginare",
    "scompaginasti": "scompaginare",
    "scompaginata": "scompaginare",
    "scompaginate": "scompaginare",
    "scompaginati": "scompaginare",
    "scompaginato": "scompaginare",
    "scompaginava": "scompaginare",
    "scompaginavamo": "scompaginare",
    "scompaginavan": "scompaginare",
    "scompaginavano": "scompaginare",
    "scompaginavate": "scompaginare",
    "scompaginavi": "scompaginare",
    "scompaginavo": "scompaginare",
    "scompaginerai": "scompaginare",
    "scompagineran": "scompaginare",
    "scompagineranno": "scompaginare",
    "scompaginerebbe": "scompaginare",
    "scompaginerebber": "scompaginare",
    "scompaginerebbero": "scompaginare",
    "scompaginerei": "scompaginare",
    "scompagineremmo": "scompaginare",
    "scompagineremo": "scompaginare",
    "scompaginereste": "scompaginare",
    "scompagineresti": "scompaginare",
    "scompaginerete": "scompaginare",
    "scompaginerà": "scompaginare",
    "scompaginerò": "scompaginare",
    "scompagini": "scompaginare",
    "scompaginiamo": "scompaginare",
    "scompaginiate": "scompaginare",
    "scompaginin": "scompaginare",
    "scompaginino": "scompaginare",
    "scompagino": "scompaginare",
    "scompaginò": "scompaginare",
    "scompagna": "scompagnare",
    "scompagnai": "scompagnare",
    "scompagnammo": "scompagnare",
    "scompagnan": "scompagnare",
    "scompagnando": "scompagnare",
    "scompagnano": "scompagnare",
    "scompagnante": "scompagnare",
    "scompagnanti": "scompagnare",
    "scompagnar": "scompagnare",
    "scompagnaron": "scompagnare",
    "scompagnarono": "scompagnare",
    "scompagnasse": "scompagnare",
    "scompagnasser": "scompagnare",
    "scompagnassero": "scompagnare",
    "scompagnassi": "scompagnare",
    "scompagnassimo": "scompagnare",
    "scompagnaste": "scompagnare",
    "scompagnasti": "scompagnare",
    "scompagnata": "scompagnare",
    "scompagnate": "scompagnare",
    "scompagnati": "scompagnare",
    "scompagnato": "scompagnare",
    "scompagnava": "scompagnare",
    "scompagnavamo": "scompagnare",
    "scompagnavan": "scompagnare",
    "scompagnavano": "scompagnare",
    "scompagnavate": "scompagnare",
    "scompagnavi": "scompagnare",
    "scompagnavo": "scompagnare",
    "scompagnerai": "scompagnare",
    "scompagneran": "scompagnare",
    "scompagneranno": "scompagnare",
    "scompagnerebbe": "scompagnare",
    "scompagnerebber": "scompagnare",
    "scompagnerebbero": "scompagnare",
    "scompagnerei": "scompagnare",
    "scompagneremmo": "scompagnare",
    "scompagneremo": "scompagnare",
    "scompagnereste": "scompagnare",
    "scompagneresti": "scompagnare",
    "scompagnerete": "scompagnare",
    "scompagnerà": "scompagnare",
    "scompagnerò": "scompagnare",
    "scompagni": "scompagnare",
    "scompagniamo": "scompagnare",
    "scompagniate": "scompagnare",
    "scompagnin": "scompagnare",
    "scompagnino": "scompagnare",
    "scompagno": "scompagnare",
    "scompagnò": "scompagnare",
    "scompaia": "scomparire",
    "scompaian": "scomparire",
    "scompaiano": "scomparire",
    "scompaio": "scomparire",
    "scompaion": "scomparire",
    "scompaiono": "scomparire",
    "scompare": "scomparire",
    "scomparendo": "scomparire",
    "scomparente": "scomparire",
    "scomparenti": "scomparire",
    "scompari": "scomparire",
    "scompariamo": "scomparire",
    "scompariate": "scomparire",
    "scomparimmo": "scomparire",
    "scomparir": "scomparire",
    "scomparirai": "scomparire",
    "scompariran": "scomparire",
    "scompariranno": "scomparire",
    "scomparirebbe": "scomparire",
    "scomparirebber": "scomparire",
    "scomparirebbero": "scomparire",
    "scomparirei": "scomparire",
    "scompariremmo": "scomparire",
    "scompariremo": "scomparire",
    "scomparireste": "scomparire",
    "scompariresti": "scomparire",
    "scomparirete": "scomparire",
    "scomparirà": "scomparire",
    "scomparirò": "scomparire",
    "scomparisse": "scomparire",
    "scomparisser": "scomparire",
    "scomparissero": "scomparire",
    "scomparissi": "scomparire",
    "scomparissimo": "scomparire",
    "scompariste": "scomparire",
    "scomparisti": "scomparire",
    "scomparite": "scomparire",
    "scompariva": "scomparire",
    "scomparivamo": "scomparire",
    "scomparivan": "scomparire",
    "scomparivano": "scomparire",
    "scomparivate": "scomparire",
    "scomparivi": "scomparire",
    "scomparivo": "scomparire",
    "scomparsa": "scomparso",
    "scomparse": "scomparso",
    "scomparsi": "scomparso",
    "scomparso": "scomparire",
    "scomparta": "scompartire",
    "scompartan": "scompartire",
    "scompartano": "scompartire",
    "scomparte": "scompartire",
    "scompartendo": "scompartire",
    "scompartente": "scompartire",
    "scompartenti": "scompartire",
    "scomparti": "scomparto",
    "scompartiamo": "scompartire",
    "scompartiate": "scompartire",
    "scompartii": "scompartire",
    "scompartimenti": "scompartimento",
    "scompartimmo": "scompartire",
    "scompartir": "scompartire",
    "scompartirai": "scompartire",
    "scompartiran": "scompartire",
    "scompartiranno": "scompartire",
    "scompartirebbe": "scompartire",
    "scompartirebber": "scompartire",
    "scompartirebbero": "scompartire",
    "scompartirei": "scompartire",
    "scompartiremmo": "scompartire",
    "scompartiremo": "scompartire",
    "scompartireste": "scompartire",
    "scompartiresti": "scompartire",
    "scompartirete": "scompartire",
    "scompartiron": "scompartire",
    "scompartirono": "scompartire",
    "scompartirà": "scompartire",
    "scompartirò": "scompartire",
    "scompartisse": "scompartire",
    "scompartisser": "scompartire",
    "scompartissero": "scompartire",
    "scompartissi": "scompartire",
    "scompartissimo": "scompartire",
    "scompartiste": "scompartire",
    "scompartisti": "scompartire",
    "scompartita": "scompartire",
    "scompartite": "scompartire",
    "scompartiti": "scompartire",
    "scompartito": "scompartire",
    "scompartiva": "scompartire",
    "scompartivamo": "scompartire",
    "scompartivan": "scompartire",
    "scompartivano": "scompartire",
    "scompartivate": "scompartire",
    "scompartivi": "scompartire",
    "scompartivo": "scompartire",
    "scomparto": "scompartire",
    "scomparton": "scompartire",
    "scompartono": "scompartire",
    "scompartì": "scompartire",
    "scomparve": "scomparire",
    "scomparver": "scomparire",
    "scomparvero": "scomparire",
    "scomparvi": "scomparire",
    "scompensa": "scompensare",
    "scompensai": "scompensare",
    "scompensammo": "scompensare",
    "scompensan": "scompensare",
    "scompensando": "scompensare",
    "scompensano": "scompensare",
    "scompensante": "scompensare",
    "scompensanti": "scompensare",
    "scompensar": "scompensare",
    "scompensaron": "scompensare",
    "scompensarono": "scompensare",
    "scompensasse": "scompensare",
    "scompensasser": "scompensare",
    "scompensassero": "scompensare",
    "scompensassi": "scompensare",
    "scompensassimo": "scompensare",
    "scompensaste": "scompensare",
    "scompensasti": "scompensare",
    "scompensata": "scompensare",
    "scompensate": "scompensare",
    "scompensati": "scompensare",
    "scompensato": "scompensare",
    "scompensava": "scompensare",
    "scompensavamo": "scompensare",
    "scompensavan": "scompensare",
    "scompensavano": "scompensare",
    "scompensavate": "scompensare",
    "scompensavi": "scompensare",
    "scompensavo": "scompensare",
    "scompenserai": "scompensare",
    "scompenseran": "scompensare",
    "scompenseranno": "scompensare",
    "scompenserebbe": "scompensare",
    "scompenserebber": "scompensare",
    "scompenserebbero": "scompensare",
    "scompenserei": "scompensare",
    "scompenseremmo": "scompensare",
    "scompenseremo": "scompensare",
    "scompensereste": "scompensare",
    "scompenseresti": "scompensare",
    "scompenserete": "scompensare",
    "scompenserà": "scompensare",
    "scompenserò": "scompensare",
    "scompensi": "scompenso",
    "scompensiamo": "scompensare",
    "scompensiate": "scompensare",
    "scompensin": "scompensare",
    "scompensino": "scompensare",
    "scompenso": "scompensare",
    "scompensò": "scompensare",
    "scompigli": "scompiglio",
    "scompiglia": "scompigliare",
    "scompigliai": "scompigliare",
    "scompigliammo": "scompigliare",
    "scompigliamo": "scompigliare",
    "scompiglian": "scompigliare",
    "scompigliando": "scompigliare",
    "scompigliano": "scompigliare",
    "scompigliante": "scompigliare",
    "scompiglianti": "scompigliare",
    "scompigliar": "scompigliare",
    "scompigliaron": "scompigliare",
    "scompigliarono": "scompigliare",
    "scompigliasse": "scompigliare",
    "scompigliasser": "scompigliare",
    "scompigliassero": "scompigliare",
    "scompigliassi": "scompigliare",
    "scompigliassimo": "scompigliare",
    "scompigliaste": "scompigliare",
    "scompigliasti": "scompigliare",
    "scompigliata": "scompigliare",
    "scompigliate": "scompigliare",
    "scompigliati": "scompigliare",
    "scompigliato": "scompigliare",
    "scompigliava": "scompigliare",
    "scompigliavamo": "scompigliare",
    "scompigliavan": "scompigliare",
    "scompigliavano": "scompigliare",
    "scompigliavate": "scompigliare",
    "scompigliavi": "scompigliare",
    "scompigliavo": "scompigliare",
    "scompiglierai": "scompigliare",
    "scompiglieran": "scompigliare",
    "scompiglieranno": "scompigliare",
    "scompiglierebbe": "scompigliare",
    "scompiglierebber": "scompigliare",
    "scompiglierebbero": "scompigliare",
    "scompiglierei": "scompigliare",
    "scompiglieremmo": "scompigliare",
    "scompiglieremo": "scompigliare",
    "scompigliereste": "scompigliare",
    "scompiglieresti": "scompigliare",
    "scompiglierete": "scompigliare",
    "scompiglierà": "scompigliare",
    "scompiglierò": "scompigliare",
    "scompiglin": "scompigliare",
    "scompiglino": "scompigliare",
    "scompiglio": "scompigliare",
    "scompigliò": "scompigliare",
    "scompone": "scomporre",
    "scomponemmo": "scomporre",
    "scomponendo": "scomporre",
    "scomponente": "scomporre",
    "scomponenti": "scomporre",
    "scomponesse": "scomporre",
    "scomponesser": "scomporre",
    "scomponessero": "scomporre",
    "scomponessi": "scomporre",
    "scomponessimo": "scomporre",
    "scomponeste": "scomporre",
    "scomponesti": "scomporre",
    "scomponete": "scomporre",
    "scomponeva": "scomporre",
    "scomponevamo": "scomporre",
    "scomponevan": "scomporre",
    "scomponevano": "scomporre",
    "scomponevate": "scomporre",
    "scomponevi": "scomporre",
    "scomponevo": "scomporre",
    "scomponga": "scomporre",
    "scompongan": "scomporre",
    "scompongano": "scomporre",
    "scompongo": "scomporre",
    "scompongon": "scomporre",
    "scompongono": "scomporre",
    "scomponi": "scomporre",
    "scomponiamo": "scomporre",
    "scomponiate": "scomporre",
    "scomponibili": "scomponibile",
    "scomporr": "scomporre",
    "scomporrai": "scomporre",
    "scomporran": "scomporre",
    "scomporranno": "scomporre",
    "scomporrebbe": "scomporre",
    "scomporrebber": "scomporre",
    "scomporrebbero": "scomporre",
    "scomporrei": "scomporre",
    "scomporremmo": "scomporre",
    "scomporremo": "scomporre",
    "scomporreste": "scomporre",
    "scomporresti": "scomporre",
    "scomporrete": "scomporre",
    "scomporrà": "scomporre",
    "scomporrò": "scomporre",
    "scompose": "scomporre",
    "scomposer": "scomporre",
    "scomposero": "scomporre",
    "scomposi": "scomporre",
    "scomposizioni": "scomposizione",
    "scomposta": "scomposto",
    "scomposte": "scomposto",
    "scomposti": "scomposto",
    "scomposto": "scomporre",
    "scomunica": "scomunicare",
    "scomunicai": "scomunicare",
    "scomunicammo": "scomunicare",
    "scomunican": "scomunicare",
    "scomunicando": "scomunicare",
    "scomunicano": "scomunicare",
    "scomunicante": "scomunicare",
    "scomunicanti": "scomunicare",
    "scomunicar": "scomunicare",
    "scomunicaron": "scomunicare",
    "scomunicarono": "scomunicare",
    "scomunicasse": "scomunicare",
    "scomunicasser": "scomunicare",
    "scomunicassero": "scomunicare",
    "scomunicassi": "scomunicare",
    "scomunicassimo": "scomunicare",
    "scomunicaste": "scomunicare",
    "scomunicasti": "scomunicare",
    "scomunicata": "scomunicare",
    "scomunicate": "scomunicare",
    "scomunicati": "scomunicare",
    "scomunicato": "scomunicare",
    "scomunicava": "scomunicare",
    "scomunicavamo": "scomunicare",
    "scomunicavan": "scomunicare",
    "scomunicavano": "scomunicare",
    "scomunicavate": "scomunicare",
    "scomunicavi": "scomunicare",
    "scomunicavo": "scomunicare",
    "scomuniche": "scomunica",
    "scomunicherai": "scomunicare",
    "scomunicheran": "scomunicare",
    "scomunicheranno": "scomunicare",
    "scomunicherebbe": "scomunicare",
    "scomunicherebber": "scomunicare",
    "scomunicherebbero": "scomunicare",
    "scomunicherei": "scomunicare",
    "scomunicheremmo": "scomunicare",
    "scomunicheremo": "scomunicare",
    "scomunichereste": "scomunicare",
    "scomunicheresti": "scomunicare",
    "scomunicherete": "scomunicare",
    "scomunicherà": "scomunicare",
    "scomunicherò": "scomunicare",
    "scomunichi": "scomunicare",
    "scomunichiamo": "scomunicare",
    "scomunichiate": "scomunicare",
    "scomunichin": "scomunicare",
    "scomunichino": "scomunicare",
    "scomunico": "scomunicare",
    "scomunicò": "scomunicare",
    "sconce": "sconcio",
    "sconcerai": "sconciare",
    "sconceran": "sconciare",
    "sconceranno": "sconciare",
    "sconcerebbe": "sconciare",
    "sconcerebber": "sconciare",
    "sconcerebbero": "sconciare",
    "sconcerei": "sconciare",
    "sconceremmo": "sconciare",
    "sconceremo": "sconciare",
    "sconcereste": "sconciare",
    "sconceresti": "sconciare",
    "sconcerete": "sconciare",
    "sconcerta": "sconcertare",
    "sconcertai": "sconcertare",
    "sconcertammo": "sconcertare",
    "sconcertan": "sconcertare",
    "sconcertando": "sconcertare",
    "sconcertano": "sconcertare",
    "sconcertante": "sconcertare",
    "sconcertanti": "sconcertare",
    "sconcertar": "sconcertare",
    "sconcertaron": "sconcertare",
    "sconcertarono": "sconcertare",
    "sconcertasse": "sconcertare",
    "sconcertasser": "sconcertare",
    "sconcertassero": "sconcertare",
    "sconcertassi": "sconcertare",
    "sconcertassimo": "sconcertare",
    "sconcertaste": "sconcertare",
    "sconcertasti": "sconcertare",
    "sconcertata": "sconcertato",
    "sconcertate": "sconcertato",
    "sconcertati": "sconcertato",
    "sconcertato": "sconcertare",
    "sconcertava": "sconcertare",
    "sconcertavamo": "sconcertare",
    "sconcertavan": "sconcertare",
    "sconcertavano": "sconcertare",
    "sconcertavate": "sconcertare",
    "sconcertavi": "sconcertare",
    "sconcertavo": "sconcertare",
    "sconcerterai": "sconcertare",
    "sconcerteran": "sconcertare",
    "sconcerteranno": "sconcertare",
    "sconcerterebbe": "sconcertare",
    "sconcerterebber": "sconcertare",
    "sconcerterebbero": "sconcertare",
    "sconcerterei": "sconcertare",
    "sconcerteremmo": "sconcertare",
    "sconcerteremo": "sconcertare",
    "sconcertereste": "sconcertare",
    "sconcerteresti": "sconcertare",
    "sconcerterete": "sconcertare",
    "sconcerterà": "sconcertare",
    "sconcerterò": "sconcertare",
    "sconcerti": "sconcerto",
    "sconcertiamo": "sconcertare",
    "sconcertiate": "sconcertare",
    "sconcertin": "sconcertare",
    "sconcertino": "sconcertare",
    "sconcerto": "sconcertare",
    "sconcertò": "sconcertare",
    "sconcerà": "sconciare",
    "sconcerò": "sconciare",
    "sconcezze": "sconcezza",
    "sconci": "sconcio",
    "sconcia": "sconcio",
    "sconciai": "sconciare",
    "sconciammo": "sconciare",
    "sconciamo": "sconciare",
    "sconcian": "sconciare",
    "sconciando": "sconciare",
    "sconciano": "sconciare",
    "sconciante": "sconciare",
    "sconcianti": "sconciare",
    "sconciar": "sconciare",
    "sconciaron": "sconciare",
    "sconciarono": "sconciare",
    "sconciasse": "sconciare",
    "sconciasser": "sconciare",
    "sconciassero": "sconciare",
    "sconciassi": "sconciare",
    "sconciassimo": "sconciare",
    "sconciaste": "sconciare",
    "sconciasti": "sconciare",
    "sconciata": "sconciare",
    "sconciate": "sconciare",
    "sconciati": "sconciare",
    "sconciato": "sconciare",
    "sconciava": "sconciare",
    "sconciavamo": "sconciare",
    "sconciavan": "sconciare",
    "sconciavano": "sconciare",
    "sconciavate": "sconciare",
    "sconciavi": "sconciare",
    "sconciavo": "sconciare",
    "sconcin": "sconciare",
    "sconcino": "sconciare",
    "sconcio": "sconciare",
    "sconciò": "sconciare",
    "sconclusionata": "sconclusionato",
    "sconclusionate": "sconclusionato",
    "sconclusionati": "sconclusionato",
    "sconfessa": "sconfessare",
    "sconfessai": "sconfessare",
    "sconfessammo": "sconfessare",
    "sconfessan": "sconfessare",
    "sconfessando": "sconfessare",
    "sconfessano": "sconfessare",
    "sconfessante": "sconfessare",
    "sconfessanti": "sconfessare",
    "sconfessar": "sconfessare",
    "sconfessaron": "sconfessare",
    "sconfessarono": "sconfessare",
    "sconfessasse": "sconfessare",
    "sconfessasser": "sconfessare",
    "sconfessassero": "sconfessare",
    "sconfessassi": "sconfessare",
    "sconfessassimo": "sconfessare",
    "sconfessaste": "sconfessare",
    "sconfessasti": "sconfessare",
    "sconfessata": "sconfessare",
    "sconfessate": "sconfessare",
    "sconfessati": "sconfessare",
    "sconfessato": "sconfessare",
    "sconfessava": "sconfessare",
    "sconfessavamo": "sconfessare",
    "sconfessavan": "sconfessare",
    "sconfessavano": "sconfessare",
    "sconfessavate": "sconfessare",
    "sconfessavi": "sconfessare",
    "sconfessavo": "sconfessare",
    "sconfesserai": "sconfessare",
    "sconfesseran": "sconfessare",
    "sconfesseranno": "sconfessare",
    "sconfesserebbe": "sconfessare",
    "sconfesserebber": "sconfessare",
    "sconfesserebbero": "sconfessare",
    "sconfesserei": "sconfessare",
    "sconfesseremmo": "sconfessare",
    "sconfesseremo": "sconfessare",
    "sconfessereste": "sconfessare",
    "sconfesseresti": "sconfessare",
    "sconfesserete": "sconfessare",
    "sconfesserà": "sconfessare",
    "sconfesserò": "sconfessare",
    "sconfessi": "sconfessare",
    "sconfessiamo": "sconfessare",
    "sconfessiate": "sconfessare",
    "sconfessin": "sconfessare",
    "sconfessino": "sconfessare",
    "sconfessioni": "sconfessione",
    "sconfesso": "sconfessare",
    "sconfessò": "sconfessare",
    "sconficca": "sconficcare",
    "sconficcai": "sconficcare",
    "sconficcammo": "sconficcare",
    "sconficcan": "sconficcare",
    "sconficcando": "sconficcare",
    "sconficcano": "sconficcare",
    "sconficcante": "sconficcare",
    "sconficcanti": "sconficcare",
    "sconficcar": "sconficcare",
    "sconficcaron": "sconficcare",
    "sconficcarono": "sconficcare",
    "sconficcasse": "sconficcare",
    "sconficcasser": "sconficcare",
    "sconficcassero": "sconficcare",
    "sconficcassi": "sconficcare",
    "sconficcassimo": "sconficcare",
    "sconficcaste": "sconficcare",
    "sconficcasti": "sconficcare",
    "sconficcata": "sconficcare",
    "sconficcate": "sconficcare",
    "sconficcati": "sconficcare",
    "sconficcato": "sconficcare",
    "sconficcava": "sconficcare",
    "sconficcavamo": "sconficcare",
    "sconficcavan": "sconficcare",
    "sconficcavano": "sconficcare",
    "sconficcavate": "sconficcare",
    "sconficcavi": "sconficcare",
    "sconficcavo": "sconficcare",
    "sconficcherai": "sconficcare",
    "sconficcheran": "sconficcare",
    "sconficcheranno": "sconficcare",
    "sconficcherebbe": "sconficcare",
    "sconficcherebber": "sconficcare",
    "sconficcherebbero": "sconficcare",
    "sconficcherei": "sconficcare",
    "sconficcheremmo": "sconficcare",
    "sconficcheremo": "sconficcare",
    "sconficchereste": "sconficcare",
    "sconficcheresti": "sconficcare",
    "sconficcherete": "sconficcare",
    "sconficcherà": "sconficcare",
    "sconficcherò": "sconficcare",
    "sconficchi": "sconficcare",
    "sconficchiamo": "sconficcare",
    "sconficchiate": "sconficcare",
    "sconficchin": "sconficcare",
    "sconficchino": "sconficcare",
    "sconficco": "sconficcare",
    "sconficcò": "sconficcare",
    "sconfigga": "sconfiggere",
    "sconfiggan": "sconfiggere",
    "sconfiggano": "sconfiggere",
    "sconfigge": "sconfiggere",
    "sconfiggemmo": "sconfiggere",
    "sconfiggendo": "sconfiggere",
    "sconfiggente": "sconfiggere",
    "sconfiggenti": "sconfiggere",
    "sconfigger": "sconfiggere",
    "sconfiggerai": "sconfiggere",
    "sconfiggeran": "sconfiggere",
    "sconfiggeranno": "sconfiggere",
    "sconfiggerebbe": "sconfiggere",
    "sconfiggerebber": "sconfiggere",
    "sconfiggerebbero": "sconfiggere",
    "sconfiggerei": "sconfiggere",
    "sconfiggeremmo": "sconfiggere",
    "sconfiggeremo": "sconfiggere",
    "sconfiggereste": "sconfiggere",
    "sconfiggeresti": "sconfiggere",
    "sconfiggerete": "sconfiggere",
    "sconfiggerà": "sconfiggere",
    "sconfiggerò": "sconfiggere",
    "sconfiggesse": "sconfiggere",
    "sconfiggesser": "sconfiggere",
    "sconfiggessero": "sconfiggere",
    "sconfiggessi": "sconfiggere",
    "sconfiggessimo": "sconfiggere",
    "sconfiggeste": "sconfiggere",
    "sconfiggesti": "sconfiggere",
    "sconfiggete": "sconfiggere",
    "sconfiggeva": "sconfiggere",
    "sconfiggevamo": "sconfiggere",
    "sconfiggevan": "sconfiggere",
    "sconfiggevano": "sconfiggere",
    "sconfiggevate": "sconfiggere",
    "sconfiggevi": "sconfiggere",
    "sconfiggevo": "sconfiggere",
    "sconfiggi": "sconfiggere",
    "sconfiggiamo": "sconfiggere",
    "sconfiggiate": "sconfiggere",
    "sconfiggo": "sconfiggere",
    "sconfiggon": "sconfiggere",
    "sconfiggono": "sconfiggere",
    "sconfina": "sconfinare",
    "sconfinai": "sconfinare",
    "sconfinamenti": "sconfinamento",
    "sconfinammo": "sconfinare",
    "sconfinan": "sconfinare",
    "sconfinando": "sconfinare",
    "sconfinano": "sconfinare",
    "sconfinante": "sconfinare",
    "sconfinanti": "sconfinare",
    "sconfinar": "sconfinare",
    "sconfinaron": "sconfinare",
    "sconfinarono": "sconfinare",
    "sconfinasse": "sconfinare",
    "sconfinasser": "sconfinare",
    "sconfinassero": "sconfinare",
    "sconfinassi": "sconfinare",
    "sconfinassimo": "sconfinare",
    "sconfinaste": "sconfinare",
    "sconfinasti": "sconfinare",
    "sconfinata": "sconfinare",
    "sconfinate": "sconfinare",
    "sconfinati": "sconfinare",
    "sconfinato": "sconfinare",
    "sconfinava": "sconfinare",
    "sconfinavamo": "sconfinare",
    "sconfinavan": "sconfinare",
    "sconfinavano": "sconfinare",
    "sconfinavate": "sconfinare",
    "sconfinavi": "sconfinare",
    "sconfinavo": "sconfinare",
    "sconfinerai": "sconfinare",
    "sconfineran": "sconfinare",
    "sconfineranno": "sconfinare",
    "sconfinerebbe": "sconfinare",
    "sconfinerebber": "sconfinare",
    "sconfinerebbero": "sconfinare",
    "sconfinerei": "sconfinare",
    "sconfineremmo": "sconfinare",
    "sconfineremo": "sconfinare",
    "sconfinereste": "sconfinare",
    "sconfineresti": "sconfinare",
    "sconfinerete": "sconfinare",
    "sconfinerà": "sconfinare",
    "sconfinerò": "sconfinare",
    "sconfini": "sconfinare",
    "sconfiniamo": "sconfinare",
    "sconfiniate": "sconfinare",
    "sconfinin": "sconfinare",
    "sconfinino": "sconfinare",
    "sconfino": "sconfinare",
    "sconfinò": "sconfinare",
    "sconfisser": "sconfiggere",
    "sconfissero": "sconfiggere",
    "sconfissi": "sconfiggere",
    "sconfissè": "sconfiggere",
    "sconfitta": "sconfitto",
    "sconfitte": "sconfitto",
    "sconfitti": "sconfitto",
    "sconfitto": "sconfiggere",
    "sconfortanti": "sconfortante",
    "sconfortata": "sconfortato",
    "sconfortate": "sconfortato",
    "sconfortati": "sconfortato",
    "sconforti": "sconforto",
    "scongela": "scongelare",
    "scongelai": "scongelare",
    "scongelamenti": "scongelamento",
    "scongelammo": "scongelare",
    "scongelan": "scongelare",
    "scongelando": "scongelare",
    "scongelano": "scongelare",
    "scongelante": "scongelare",
    "scongelanti": "scongelare",
    "scongelar": "scongelare",
    "scongelaron": "scongelare",
    "scongelarono": "scongelare",
    "scongelasse": "scongelare",
    "scongelasser": "scongelare",
    "scongelassero": "scongelare",
    "scongelassi": "scongelare",
    "scongelassimo": "scongelare",
    "scongelaste": "scongelare",
    "scongelasti": "scongelare",
    "scongelata": "scongelare",
    "scongelate": "scongelare",
    "scongelati": "scongelare",
    "scongelato": "scongelare",
    "scongelava": "scongelare",
    "scongelavamo": "scongelare",
    "scongelavan": "scongelare",
    "scongelavano": "scongelare",
    "scongelavate": "scongelare",
    "scongelavi": "scongelare",
    "scongelavo": "scongelare",
    "scongelerai": "scongelare",
    "scongeleran": "scongelare",
    "scongeleranno": "scongelare",
    "scongelerebbe": "scongelare",
    "scongelerebber": "scongelare",
    "scongelerebbero": "scongelare",
    "scongelerei": "scongelare",
    "scongeleremmo": "scongelare",
    "scongeleremo": "scongelare",
    "scongelereste": "scongelare",
    "scongeleresti": "scongelare",
    "scongelerete": "scongelare",
    "scongelerà": "scongelare",
    "scongelerò": "scongelare",
    "scongeli": "scongelare",
    "scongeliamo": "scongelare",
    "scongeliate": "scongelare",
    "scongelin": "scongelare",
    "scongelino": "scongelare",
    "scongelo": "scongelare",
    "scongelò": "scongelare",
    "scongiura": "scongiurare",
    "scongiurai": "scongiurare",
    "scongiurammo": "scongiurare",
    "scongiuran": "scongiurare",
    "scongiurando": "scongiurare",
    "scongiurano": "scongiurare",
    "scongiurante": "scongiurare",
    "scongiuranti": "scongiurare",
    "scongiurar": "scongiurare",
    "scongiuraron": "scongiurare",
    "scongiurarono": "scongiurare",
    "scongiurasse": "scongiurare",
    "scongiurasser": "scongiurare",
    "scongiurassero": "scongiurare",
    "scongiurassi": "scongiurare",
    "scongiurassimo": "scongiurare",
    "scongiuraste": "scongiurare",
    "scongiurasti": "scongiurare",
    "scongiurata": "scongiurare",
    "scongiurate": "scongiurare",
    "scongiurati": "scongiurare",
    "scongiurato": "scongiurare",
    "scongiurava": "scongiurare",
    "scongiuravamo": "scongiurare",
    "scongiuravan": "scongiurare",
    "scongiuravano": "scongiurare",
    "scongiuravate": "scongiurare",
    "scongiuravi": "scongiurare",
    "scongiuravo": "scongiurare",
    "scongiurerai": "scongiurare",
    "scongiureran": "scongiurare",
    "scongiureranno": "scongiurare",
    "scongiurerebbe": "scongiurare",
    "scongiurerebber": "scongiurare",
    "scongiurerebbero": "scongiurare",
    "scongiurerei": "scongiurare",
    "scongiureremmo": "scongiurare",
    "scongiureremo": "scongiurare",
    "scongiurereste": "scongiurare",
    "scongiureresti": "scongiurare",
    "scongiurerete": "scongiurare",
    "scongiurerà": "scongiurare",
    "scongiurerò": "scongiurare",
    "scongiuri": "scongiurare",
    "scongiuriamo": "scongiurare",
    "scongiuriate": "scongiurare",
    "scongiurin": "scongiurare",
    "scongiurino": "scongiurare",
    "scongiuro": "scongiurare",
    "scongiurò": "scongiurare",
    "sconnessa": "sconnettere",
    "sconnesse": "sconnettere",
    "sconnessi": "sconnettere",
    "sconnessioni": "sconnessione",
    "sconnesso": "sconnettere",
    "sconnetta": "sconnettere",
    "sconnettan": "sconnettere",
    "sconnettano": "sconnettere",
    "sconnette": "sconnettere",
    "sconnettei": "sconnettere",
    "sconnettemmo": "sconnettere",
    "sconnettendo": "sconnettere",
    "sconnettente": "sconnettere",
    "sconnettenti": "sconnettere",
    "sconnetter": "sconnettere",
    "sconnetterai": "sconnettere",
    "sconnetteran": "sconnettere",
    "sconnetteranno": "sconnettere",
    "sconnetterebbe": "sconnettere",
    "sconnetterebber": "sconnettere",
    "sconnetterebbero": "sconnettere",
    "sconnetterei": "sconnettere",
    "sconnetteremmo": "sconnettere",
    "sconnetteremo": "sconnettere",
    "sconnettereste": "sconnettere",
    "sconnetteresti": "sconnettere",
    "sconnetterete": "sconnettere",
    "sconnetteron": "sconnettere",
    "sconnetterono": "sconnettere",
    "sconnetterà": "sconnettere",
    "sconnetterò": "sconnettere",
    "sconnettesse": "sconnettere",
    "sconnettesser": "sconnettere",
    "sconnettessero": "sconnettere",
    "sconnettessi": "sconnettere",
    "sconnettessimo": "sconnettere",
    "sconnetteste": "sconnettere",
    "sconnettesti": "sconnettere",
    "sconnettete": "sconnettere",
    "sconnetteva": "sconnettere",
    "sconnettevamo": "sconnettere",
    "sconnettevan": "sconnettere",
    "sconnettevano": "sconnettere",
    "sconnettevate": "sconnettere",
    "sconnettevi": "sconnettere",
    "sconnettevo": "sconnettere",
    "sconnetti": "sconnettere",
    "sconnettiamo": "sconnettere",
    "sconnettiate": "sconnettere",
    "sconnetto": "sconnettere",
    "sconnetton": "sconnettere",
    "sconnettono": "sconnettere",
    "sconnettè": "sconnettere",
    "sconosca": "sconoscere",
    "sconoscan": "sconoscere",
    "sconoscano": "sconoscere",
    "sconosce": "sconoscere",
    "sconoscei": "sconoscere",
    "sconoscemmo": "sconoscere",
    "sconoscendo": "sconoscere",
    "sconoscente": "sconoscere",
    "sconoscenti": "sconoscere",
    "sconoscer": "sconoscere",
    "sconoscerai": "sconoscere",
    "sconosceran": "sconoscere",
    "sconosceranno": "sconoscere",
    "sconoscerebbe": "sconoscere",
    "sconoscerebber": "sconoscere",
    "sconoscerebbero": "sconoscere",
    "sconoscerei": "sconoscere",
    "sconosceremmo": "sconoscere",
    "sconosceremo": "sconoscere",
    "sconoscereste": "sconoscere",
    "sconosceresti": "sconoscere",
    "sconoscerete": "sconoscere",
    "sconosceron": "sconoscere",
    "sconoscerono": "sconoscere",
    "sconoscerà": "sconoscere",
    "sconoscerò": "sconoscere",
    "sconoscesse": "sconoscere",
    "sconoscesser": "sconoscere",
    "sconoscessero": "sconoscere",
    "sconoscessi": "sconoscere",
    "sconoscessimo": "sconoscere",
    "sconosceste": "sconoscere",
    "sconoscesti": "sconoscere",
    "sconoscete": "sconoscere",
    "sconosceva": "sconoscere",
    "sconoscevamo": "sconoscere",
    "sconoscevan": "sconoscere",
    "sconoscevano": "sconoscere",
    "sconoscevate": "sconoscere",
    "sconoscevi": "sconoscere",
    "sconoscevo": "sconoscere",
    "sconosci": "sconoscere",
    "sconosciamo": "sconoscere",
    "sconosciate": "sconoscere",
    "sconosciuta": "sconosciuto",
    "sconosciute": "sconosciuto",
    "sconosciuti": "sconosciuto",
    "sconosciuto": "sconoscere",
    "sconosco": "sconoscere",
    "sconoscon": "sconoscere",
    "sconoscono": "sconoscere",
    "sconoscè": "sconoscere",
    "sconquassa": "sconquassare",
    "sconquassai": "sconquassare",
    "sconquassammo": "sconquassare",
    "sconquassan": "sconquassare",
    "sconquassando": "sconquassare",
    "sconquassano": "sconquassare",
    "sconquassante": "sconquassare",
    "sconquassanti": "sconquassare",
    "sconquassar": "sconquassare",
    "sconquassaron": "sconquassare",
    "sconquassarono": "sconquassare",
    "sconquassasse": "sconquassare",
    "sconquassasser": "sconquassare",
    "sconquassassero": "sconquassare",
    "sconquassassi": "sconquassare",
    "sconquassassimo": "sconquassare",
    "sconquassaste": "sconquassare",
    "sconquassasti": "sconquassare",
    "sconquassata": "sconquassare",
    "sconquassate": "sconquassare",
    "sconquassati": "sconquassare",
    "sconquassato": "sconquassare",
    "sconquassava": "sconquassare",
    "sconquassavamo": "sconquassare",
    "sconquassavan": "sconquassare",
    "sconquassavano": "sconquassare",
    "sconquassavate": "sconquassare",
    "sconquassavi": "sconquassare",
    "sconquassavo": "sconquassare",
    "sconquasserai": "sconquassare",
    "sconquasseran": "sconquassare",
    "sconquasseranno": "sconquassare",
    "sconquasserebbe": "sconquassare",
    "sconquasserebber": "sconquassare",
    "sconquasserebbero": "sconquassare",
    "sconquasserei": "sconquassare",
    "sconquasseremmo": "sconquassare",
    "sconquasseremo": "sconquassare",
    "sconquassereste": "sconquassare",
    "sconquasseresti": "sconquassare",
    "sconquasserete": "sconquassare",
    "sconquasserà": "sconquassare",
    "sconquasserò": "sconquassare",
    "sconquassi": "sconquasso",
    "sconquassiamo": "sconquassare",
    "sconquassiate": "sconquassare",
    "sconquassin": "sconquassare",
    "sconquassino": "sconquassare",
    "sconquasso": "sconquassare",
    "sconquassò": "sconquassare",
    "sconsacra": "sconsacrare",
    "sconsacrai": "sconsacrare",
    "sconsacrammo": "sconsacrare",
    "sconsacran": "sconsacrare",
    "sconsacrando": "sconsacrare",
    "sconsacrano": "sconsacrare",
    "sconsacrante": "sconsacrare",
    "sconsacranti": "sconsacrare",
    "sconsacrar": "sconsacrare",
    "sconsacraron": "sconsacrare",
    "sconsacrarono": "sconsacrare",
    "sconsacrasse": "sconsacrare",
    "sconsacrasser": "sconsacrare",
    "sconsacrassero": "sconsacrare",
    "sconsacrassi": "sconsacrare",
    "sconsacrassimo": "sconsacrare",
    "sconsacraste": "sconsacrare",
    "sconsacrasti": "sconsacrare",
    "sconsacrata": "sconsacrare",
    "sconsacrate": "sconsacrare",
    "sconsacrati": "sconsacrare",
    "sconsacrato": "sconsacrare",
    "sconsacrava": "sconsacrare",
    "sconsacravamo": "sconsacrare",
    "sconsacravan": "sconsacrare",
    "sconsacravano": "sconsacrare",
    "sconsacravate": "sconsacrare",
    "sconsacravi": "sconsacrare",
    "sconsacravo": "sconsacrare",
    "sconsacrerai": "sconsacrare",
    "sconsacreran": "sconsacrare",
    "sconsacreranno": "sconsacrare",
    "sconsacrerebbe": "sconsacrare",
    "sconsacrerebber": "sconsacrare",
    "sconsacrerebbero": "sconsacrare",
    "sconsacrerei": "sconsacrare",
    "sconsacreremmo": "sconsacrare",
    "sconsacreremo": "sconsacrare",
    "sconsacrereste": "sconsacrare",
    "sconsacreresti": "sconsacrare",
    "sconsacrerete": "sconsacrare",
    "sconsacrerà": "sconsacrare",
    "sconsacrerò": "sconsacrare",
    "sconsacri": "sconsacrare",
    "sconsacriamo": "sconsacrare",
    "sconsacriate": "sconsacrare",
    "sconsacrin": "sconsacrare",
    "sconsacrino": "sconsacrare",
    "sconsacro": "sconsacrare",
    "sconsacrò": "sconsacrare",
    "sconsiderata": "sconsiderato",
    "sconsiderate": "sconsiderato",
    "sconsiderati": "sconsiderato",
    "sconsigli": "sconsigliare",
    "sconsiglia": "sconsigliare",
    "sconsigliai": "sconsigliare",
    "sconsigliammo": "sconsigliare",
    "sconsigliamo": "sconsigliare",
    "sconsiglian": "sconsigliare",
    "sconsigliando": "sconsigliare",
    "sconsigliano": "sconsigliare",
    "sconsigliante": "sconsigliare",
    "sconsiglianti": "sconsigliare",
    "sconsigliar": "sconsigliare",
    "sconsigliaron": "sconsigliare",
    "sconsigliarono": "sconsigliare",
    "sconsigliasse": "sconsigliare",
    "sconsigliasser": "sconsigliare",
    "sconsigliassero": "sconsigliare",
    "sconsigliassi": "sconsigliare",
    "sconsigliassimo": "sconsigliare",
    "sconsigliaste": "sconsigliare",
    "sconsigliasti": "sconsigliare",
    "sconsigliata": "sconsigliato",
    "sconsigliate": "sconsigliato",
    "sconsigliati": "sconsigliato",
    "sconsigliato": "sconsigliare",
    "sconsigliava": "sconsigliare",
    "sconsigliavamo": "sconsigliare",
    "sconsigliavan": "sconsigliare",
    "sconsigliavano": "sconsigliare",
    "sconsigliavate": "sconsigliare",
    "sconsigliavi": "sconsigliare",
    "sconsigliavo": "sconsigliare",
    "sconsiglierai": "sconsigliare",
    "sconsiglieran": "sconsigliare",
    "sconsiglieranno": "sconsigliare",
    "sconsiglierebbe": "sconsigliare",
    "sconsiglierebber": "sconsigliare",
    "sconsiglierebbero": "sconsigliare",
    "sconsiglierei": "sconsigliare",
    "sconsiglieremmo": "sconsigliare",
    "sconsiglieremo": "sconsigliare",
    "sconsigliereste": "sconsigliare",
    "sconsiglieresti": "sconsigliare",
    "sconsiglierete": "sconsigliare",
    "sconsiglierà": "sconsigliare",
    "sconsiglierò": "sconsigliare",
    "sconsiglin": "sconsigliare",
    "sconsiglino": "sconsigliare",
    "sconsiglio": "sconsigliare",
    "sconsigliò": "sconsigliare",
    "sconsola": "sconsolare",
    "sconsolai": "sconsolare",
    "sconsolammo": "sconsolare",
    "sconsolan": "sconsolare",
    "sconsolando": "sconsolare",
    "sconsolano": "sconsolare",
    "sconsolante": "sconsolare",
    "sconsolanti": "sconsolare",
    "sconsolar": "sconsolare",
    "sconsolaron": "sconsolare",
    "sconsolarono": "sconsolare",
    "sconsolasse": "sconsolare",
    "sconsolasser": "sconsolare",
    "sconsolassero": "sconsolare",
    "sconsolassi": "sconsolare",
    "sconsolassimo": "sconsolare",
    "sconsolaste": "sconsolare",
    "sconsolasti": "sconsolare",
    "sconsolata": "sconsolato",
    "sconsolate": "sconsolato",
    "sconsolati": "sconsolato",
    "sconsolato": "sconsolare",
    "sconsolava": "sconsolare",
    "sconsolavamo": "sconsolare",
    "sconsolavan": "sconsolare",
    "sconsolavano": "sconsolare",
    "sconsolavate": "sconsolare",
    "sconsolavi": "sconsolare",
    "sconsolavo": "sconsolare",
    "sconsolerai": "sconsolare",
    "sconsoleran": "sconsolare",
    "sconsoleranno": "sconsolare",
    "sconsolerebbe": "sconsolare",
    "sconsolerebber": "sconsolare",
    "sconsolerebbero": "sconsolare",
    "sconsolerei": "sconsolare",
    "sconsoleremmo": "sconsolare",
    "sconsoleremo": "sconsolare",
    "sconsolereste": "sconsolare",
    "sconsoleresti": "sconsolare",
    "sconsolerete": "sconsolare",
    "sconsolerà": "sconsolare",
    "sconsolerò": "sconsolare",
    "sconsoli": "sconsolare",
    "sconsoliamo": "sconsolare",
    "sconsoliate": "sconsolare",
    "sconsolin": "sconsolare",
    "sconsolino": "sconsolare",
    "sconsolo": "sconsolare",
    "sconsolò": "sconsolare",
    "sconta": "scontare",
    "scontai": "scontare",
    "scontammo": "scontare",
    "scontan": "scontare",
    "scontando": "scontare",
    "scontano": "scontare",
    "scontante": "scontare",
    "scontanti": "scontare",
    "scontar": "scontare",
    "scontaron": "scontare",
    "scontarono": "scontare",
    "scontasse": "scontare",
    "scontasser": "scontare",
    "scontassero": "scontare",
    "scontassi": "scontare",
    "scontassimo": "scontare",
    "scontaste": "scontare",
    "scontasti": "scontare",
    "scontata": "scontato",
    "scontate": "scontato",
    "scontati": "scontato",
    "scontato": "scontare",
    "scontava": "scontare",
    "scontavamo": "scontare",
    "scontavan": "scontare",
    "scontavano": "scontare",
    "scontavate": "scontare",
    "scontavi": "scontare",
    "scontavo": "scontare",
    "scontenta": "scontento",
    "scontentai": "scontentare",
    "scontentammo": "scontentare",
    "scontentan": "scontentare",
    "scontentando": "scontentare",
    "scontentano": "scontentare",
    "scontentante": "scontentare",
    "scontentanti": "scontentare",
    "scontentar": "scontentare",
    "scontentaron": "scontentare",
    "scontentarono": "scontentare",
    "scontentasse": "scontentare",
    "scontentasser": "scontentare",
    "scontentassero": "scontentare",
    "scontentassi": "scontentare",
    "scontentassimo": "scontentare",
    "scontentaste": "scontentare",
    "scontentasti": "scontentare",
    "scontentata": "scontentare",
    "scontentate": "scontentare",
    "scontentati": "scontentare",
    "scontentato": "scontentare",
    "scontentava": "scontentare",
    "scontentavamo": "scontentare",
    "scontentavan": "scontentare",
    "scontentavano": "scontentare",
    "scontentavate": "scontentare",
    "scontentavi": "scontentare",
    "scontentavo": "scontentare",
    "scontente": "scontento",
    "scontenterai": "scontentare",
    "scontenteran": "scontentare",
    "scontenteranno": "scontentare",
    "scontenterebbe": "scontentare",
    "scontenterebber": "scontentare",
    "scontenterebbero": "scontentare",
    "scontenterei": "scontentare",
    "scontenteremmo": "scontentare",
    "scontenteremo": "scontentare",
    "scontentereste": "scontentare",
    "scontenteresti": "scontentare",
    "scontenterete": "scontentare",
    "scontenterà": "scontentare",
    "scontenterò": "scontentare",
    "scontentezze": "scontentezza",
    "scontenti": "scontento",
    "scontentiamo": "scontentare",
    "scontentiate": "scontentare",
    "scontentin": "scontentare",
    "scontentino": "scontentare",
    "scontento": "scontentare",
    "scontentò": "scontentare",
    "sconterai": "scontare",
    "sconteran": "scontare",
    "sconteranno": "scontare",
    "sconterebbe": "scontare",
    "sconterebber": "scontare",
    "sconterebbero": "scontare",
    "sconterei": "scontare",
    "sconteremmo": "scontare",
    "sconteremo": "scontare",
    "scontereste": "scontare",
    "sconteresti": "scontare",
    "sconterete": "scontare",
    "sconterà": "scontare",
    "sconterò": "scontare",
    "sconti": "sconto",
    "scontiamo": "scontare",
    "scontiate": "scontare",
    "scontin": "scontare",
    "scontino": "scontare",
    "sconto": "scontare",
    "scontra": "scontrare",
    "scontrai": "scontrare",
    "scontrammo": "scontrare",
    "scontran": "scontrare",
    "scontrando": "scontrare",
    "scontrano": "scontrare",
    "scontrante": "scontrare",
    "scontranti": "scontrare",
    "scontrar": "scontrare",
    "scontraron": "scontrare",
    "scontrarono": "scontrare",
    "scontrasse": "scontrare",
    "scontrasser": "scontrare",
    "scontrassero": "scontrare",
    "scontrassi": "scontrare",
    "scontrassimo": "scontrare",
    "scontraste": "scontrare",
    "scontrasti": "scontrare",
    "scontrata": "scontrare",
    "scontrate": "scontrare",
    "scontrati": "scontrare",
    "scontrato": "scontrare",
    "scontrava": "scontrare",
    "scontravamo": "scontrare",
    "scontravan": "scontrare",
    "scontravano": "scontrare",
    "scontravate": "scontrare",
    "scontravi": "scontrare",
    "scontravo": "scontrare",
    "scontrerai": "scontrare",
    "scontreran": "scontrare",
    "scontreranno": "scontrare",
    "scontrerebbe": "scontrare",
    "scontrerebber": "scontrare",
    "scontrerebbero": "scontrare",
    "scontrerei": "scontrare",
    "scontreremmo": "scontrare",
    "scontreremo": "scontrare",
    "scontrereste": "scontrare",
    "scontreresti": "scontrare",
    "scontrerete": "scontrare",
    "scontrerà": "scontrare",
    "scontrerò": "scontrare",
    "scontri": "scontro",
    "scontriamo": "scontrare",
    "scontriate": "scontrare",
    "scontrin": "scontrare",
    "scontrini": "scontrino",
    "scontrino": "scontrare",
    "scontro": "scontrare",
    "scontrosa": "scontroso",
    "scontrose": "scontroso",
    "scontrosi": "scontroso",
    "scontrò": "scontrare",
    "scontò": "scontare",
    "sconvena": "sconvenire",
    "sconvenan": "sconvenire",
    "sconvenano": "sconvenire",
    "sconvene": "sconvenire",
    "sconvenendo": "sconvenire",
    "sconvenente": "sconvenire",
    "sconvenenti": "sconvenire",
    "sconveni": "sconvenire",
    "sconveniamo": "sconvenire",
    "sconveniate": "sconvenire",
    "sconvenienti": "sconveniente",
    "sconvenii": "sconvenire",
    "sconvenimmo": "sconvenire",
    "sconvenir": "sconvenire",
    "sconvenirai": "sconvenire",
    "sconveniran": "sconvenire",
    "sconveniranno": "sconvenire",
    "sconvenirebbe": "sconvenire",
    "sconvenirebber": "sconvenire",
    "sconvenirebbero": "sconvenire",
    "sconvenirei": "sconvenire",
    "sconveniremmo": "sconvenire",
    "sconveniremo": "sconvenire",
    "sconvenireste": "sconvenire",
    "sconveniresti": "sconvenire",
    "sconvenirete": "sconvenire",
    "sconveniron": "sconvenire",
    "sconvenirono": "sconvenire",
    "sconvenirà": "sconvenire",
    "sconvenirò": "sconvenire",
    "sconvenisse": "sconvenire",
    "sconvenisser": "sconvenire",
    "sconvenissero": "sconvenire",
    "sconvenissi": "sconvenire",
    "sconvenissimo": "sconvenire",
    "sconveniste": "sconvenire",
    "sconvenisti": "sconvenire",
    "sconvenita": "sconvenire",
    "sconvenite": "sconvenire",
    "sconveniti": "sconvenire",
    "sconvenito": "sconvenire",
    "sconveniva": "sconvenire",
    "sconvenivamo": "sconvenire",
    "sconvenivan": "sconvenire",
    "sconvenivano": "sconvenire",
    "sconvenivate": "sconvenire",
    "sconvenivi": "sconvenire",
    "sconvenivo": "sconvenire",
    "sconveno": "sconvenire",
    "sconvenon": "sconvenire",
    "sconvenono": "sconvenire",
    "sconvenì": "sconvenire",
    "sconvolga": "sconvolgere",
    "sconvolgan": "sconvolgere",
    "sconvolgano": "sconvolgere",
    "sconvolge": "sconvolgere",
    "sconvolgemmo": "sconvolgere",
    "sconvolgendo": "sconvolgere",
    "sconvolgente": "sconvolgere",
    "sconvolgenti": "sconvolgere",
    "sconvolger": "sconvolgere",
    "sconvolgerai": "sconvolgere",
    "sconvolgeran": "sconvolgere",
    "sconvolgeranno": "sconvolgere",
    "sconvolgerebbe": "sconvolgere",
    "sconvolgerebber": "sconvolgere",
    "sconvolgerebbero": "sconvolgere",
    "sconvolgerei": "sconvolgere",
    "sconvolgeremmo": "sconvolgere",
    "sconvolgeremo": "sconvolgere",
    "sconvolgereste": "sconvolgere",
    "sconvolgeresti": "sconvolgere",
    "sconvolgerete": "sconvolgere",
    "sconvolgerà": "sconvolgere",
    "sconvolgerò": "sconvolgere",
    "sconvolgesse": "sconvolgere",
    "sconvolgesser": "sconvolgere",
    "sconvolgessero": "sconvolgere",
    "sconvolgessi": "sconvolgere",
    "sconvolgessimo": "sconvolgere",
    "sconvolgeste": "sconvolgere",
    "sconvolgesti": "sconvolgere",
    "sconvolgete": "sconvolgere",
    "sconvolgeva": "sconvolgere",
    "sconvolgevamo": "sconvolgere",
    "sconvolgevan": "sconvolgere",
    "sconvolgevano": "sconvolgere",
    "sconvolgevate": "sconvolgere",
    "sconvolgevi": "sconvolgere",
    "sconvolgevo": "sconvolgere",
    "sconvolgi": "sconvolgere",
    "sconvolgiamo": "sconvolgere",
    "sconvolgiate": "sconvolgere",
    "sconvolgimenti": "sconvolgimento",
    "sconvolgo": "sconvolgere",
    "sconvolgon": "sconvolgere",
    "sconvolgono": "sconvolgere",
    "sconvolse": "sconvolgere",
    "sconvolser": "sconvolgere",
    "sconvolsero": "sconvolgere",
    "sconvolsi": "sconvolgere",
    "sconvolta": "sconvolto",
    "sconvolte": "sconvolto",
    "sconvolti": "sconvolto",
    "sconvolto": "sconvolgere",
    "scopa": "scopare",
    "scopai": "scopare",
    "scopammo": "scopare",
    "scopan": "scopare",
    "scopando": "scopare",
    "scopano": "scopare",
    "scopante": "scopare",
    "scopanti": "scopare",
    "scopar": "scopare",
    "scoparon": "scopare",
    "scoparono": "scopare",
    "scopasse": "scopare",
    "scopasser": "scopare",
    "scopassero": "scopare",
    "scopassi": "scopare",
    "scopassimo": "scopare",
    "scopaste": "scopare",
    "scopasti": "scopare",
    "scopata": "scopare",
    "scopate": "scopata",
    "scopati": "scopare",
    "scopato": "scopare",
    "scopava": "scopare",
    "scopavamo": "scopare",
    "scopavan": "scopare",
    "scopavano": "scopare",
    "scopavate": "scopare",
    "scopavi": "scopare",
    "scopavo": "scopare",
    "scope": "scopa",
    "scoperai": "scopare",
    "scoperan": "scopare",
    "scoperanno": "scopare",
    "scoperchi": "scoperchiare",
    "scoperchia": "scoperchiare",
    "scoperchiai": "scoperchiare",
    "scoperchiammo": "scoperchiare",
    "scoperchiamo": "scoperchiare",
    "scoperchian": "scoperchiare",
    "scoperchiando": "scoperchiare",
    "scoperchiano": "scoperchiare",
    "scoperchiante": "scoperchiare",
    "scoperchianti": "scoperchiare",
    "scoperchiar": "scoperchiare",
    "scoperchiaron": "scoperchiare",
    "scoperchiarono": "scoperchiare",
    "scoperchiasse": "scoperchiare",
    "scoperchiasser": "scoperchiare",
    "scoperchiassero": "scoperchiare",
    "scoperchiassi": "scoperchiare",
    "scoperchiassimo": "scoperchiare",
    "scoperchiaste": "scoperchiare",
    "scoperchiasti": "scoperchiare",
    "scoperchiata": "scoperchiare",
    "scoperchiate": "scoperchiare",
    "scoperchiati": "scoperchiare",
    "scoperchiato": "scoperchiare",
    "scoperchiava": "scoperchiare",
    "scoperchiavamo": "scoperchiare",
    "scoperchiavan": "scoperchiare",
    "scoperchiavano": "scoperchiare",
    "scoperchiavate": "scoperchiare",
    "scoperchiavi": "scoperchiare",
    "scoperchiavo": "scoperchiare",
    "scoperchierai": "scoperchiare",
    "scoperchieran": "scoperchiare",
    "scoperchieranno": "scoperchiare",
    "scoperchierebbe": "scoperchiare",
    "scoperchierebber": "scoperchiare",
    "scoperchierebbero": "scoperchiare",
    "scoperchierei": "scoperchiare",
    "scoperchieremmo": "scoperchiare",
    "scoperchieremo": "scoperchiare",
    "scoperchiereste": "scoperchiare",
    "scoperchieresti": "scoperchiare",
    "scoperchierete": "scoperchiare",
    "scoperchierà": "scoperchiare",
    "scoperchierò": "scoperchiare",
    "scoperchin": "scoperchiare",
    "scoperchino": "scoperchiare",
    "scoperchio": "scoperchiare",
    "scoperchiò": "scoperchiare",
    "scoperebbe": "scopare",
    "scoperebber": "scopare",
    "scoperebbero": "scopare",
    "scoperei": "scopare",
    "scoperemmo": "scopare",
    "scoperemo": "scopare",
    "scopereste": "scopare",
    "scoperesti": "scopare",
    "scoperete": "scopare",
    "scoperta": "scoprire",
    "scoperte": "scoprire",
    "scoperti": "scoprire",
    "scoperto": "scoprire",
    "scoperà": "scopare",
    "scoperò": "scopare",
    "scopi": "scopo",
    "scopiamo": "scopare",
    "scopiate": "scopare",
    "scopiazza": "scopiazzare",
    "scopiazzai": "scopiazzare",
    "scopiazzammo": "scopiazzare",
    "scopiazzan": "scopiazzare",
    "scopiazzando": "scopiazzare",
    "scopiazzano": "scopiazzare",
    "scopiazzante": "scopiazzare",
    "scopiazzanti": "scopiazzare",
    "scopiazzar": "scopiazzare",
    "scopiazzaron": "scopiazzare",
    "scopiazzarono": "scopiazzare",
    "scopiazzasse": "scopiazzare",
    "scopiazzasser": "scopiazzare",
    "scopiazzassero": "scopiazzare",
    "scopiazzassi": "scopiazzare",
    "scopiazzassimo": "scopiazzare",
    "scopiazzaste": "scopiazzare",
    "scopiazzasti": "scopiazzare",
    "scopiazzata": "scopiazzare",
    "scopiazzate": "scopiazzare",
    "scopiazzati": "scopiazzare",
    "scopiazzato": "scopiazzare",
    "scopiazzava": "scopiazzare",
    "scopiazzavamo": "scopiazzare",
    "scopiazzavan": "scopiazzare",
    "scopiazzavano": "scopiazzare",
    "scopiazzavate": "scopiazzare",
    "scopiazzavi": "scopiazzare",
    "scopiazzavo": "scopiazzare",
    "scopiazzerai": "scopiazzare",
    "scopiazzeran": "scopiazzare",
    "scopiazzeranno": "scopiazzare",
    "scopiazzerebbe": "scopiazzare",
    "scopiazzerebber": "scopiazzare",
    "scopiazzerebbero": "scopiazzare",
    "scopiazzerei": "scopiazzare",
    "scopiazzeremmo": "scopiazzare",
    "scopiazzeremo": "scopiazzare",
    "scopiazzereste": "scopiazzare",
    "scopiazzeresti": "scopiazzare",
    "scopiazzerete": "scopiazzare",
    "scopiazzerà": "scopiazzare",
    "scopiazzerò": "scopiazzare",
    "scopiazzi": "scopiazzare",
    "scopiazziamo": "scopiazzare",
    "scopiazziate": "scopiazzare",
    "scopiazzin": "scopiazzare",
    "scopiazzino": "scopiazzare",
    "scopiazzo": "scopiazzare",
    "scopiazzò": "scopiazzare",
    "scopin": "scopare",
    "scopino": "scopare",
    "scopo": "scopare",
    "scoppi": "scoppio",
    "scoppia": "scoppiare",
    "scoppiai": "scoppiare",
    "scoppiammo": "scoppiare",
    "scoppiamo": "scoppiare",
    "scoppian": "scoppiare",
    "scoppiando": "scoppiare",
    "scoppiano": "scoppiare",
    "scoppiante": "scoppiare",
    "scoppianti": "scoppiare",
    "scoppiar": "scoppiare",
    "scoppiaron": "scoppiare",
    "scoppiarono": "scoppiare",
    "scoppiasse": "scoppiare",
    "scoppiasser": "scoppiare",
    "scoppiassero": "scoppiare",
    "scoppiassi": "scoppiare",
    "scoppiassimo": "scoppiare",
    "scoppiaste": "scoppiare",
    "scoppiasti": "scoppiare",
    "scoppiata": "scoppiare",
    "scoppiate": "scoppiare",
    "scoppiati": "scoppiare",
    "scoppiato": "scoppiare",
    "scoppiature": "scoppiatura",
    "scoppiava": "scoppiare",
    "scoppiavamo": "scoppiare",
    "scoppiavan": "scoppiare",
    "scoppiavano": "scoppiare",
    "scoppiavate": "scoppiare",
    "scoppiavi": "scoppiare",
    "scoppiavo": "scoppiare",
    "scoppierai": "scoppiare",
    "scoppieran": "scoppiare",
    "scoppieranno": "scoppiare",
    "scoppierebbe": "scoppiare",
    "scoppierebber": "scoppiare",
    "scoppierebbero": "scoppiare",
    "scoppierei": "scoppiare",
    "scoppieremmo": "scoppiare",
    "scoppieremo": "scoppiare",
    "scoppiereste": "scoppiare",
    "scoppieresti": "scoppiare",
    "scoppierete": "scoppiare",
    "scoppierà": "scoppiare",
    "scoppierò": "scoppiare",
    "scoppietta": "scoppiettare",
    "scoppiettai": "scoppiettare",
    "scoppiettammo": "scoppiettare",
    "scoppiettan": "scoppiettare",
    "scoppiettando": "scoppiettare",
    "scoppiettano": "scoppiettare",
    "scoppiettante": "scoppiettare",
    "scoppiettanti": "scoppiettare",
    "scoppiettar": "scoppiettare",
    "scoppiettaron": "scoppiettare",
    "scoppiettarono": "scoppiettare",
    "scoppiettasse": "scoppiettare",
    "scoppiettasser": "scoppiettare",
    "scoppiettassero": "scoppiettare",
    "scoppiettassi": "scoppiettare",
    "scoppiettassimo": "scoppiettare",
    "scoppiettaste": "scoppiettare",
    "scoppiettasti": "scoppiettare",
    "scoppiettata": "scoppiettare",
    "scoppiettate": "scoppiettare",
    "scoppiettati": "scoppiettare",
    "scoppiettato": "scoppiettare",
    "scoppiettava": "scoppiettare",
    "scoppiettavamo": "scoppiettare",
    "scoppiettavan": "scoppiettare",
    "scoppiettavano": "scoppiettare",
    "scoppiettavate": "scoppiettare",
    "scoppiettavi": "scoppiettare",
    "scoppiettavo": "scoppiettare",
    "scoppietterai": "scoppiettare",
    "scoppietteran": "scoppiettare",
    "scoppietteranno": "scoppiettare",
    "scoppietterebbe": "scoppiettare",
    "scoppietterebber": "scoppiettare",
    "scoppietterebbero": "scoppiettare",
    "scoppietterei": "scoppiettare",
    "scoppietteremmo": "scoppiettare",
    "scoppietteremo": "scoppiettare",
    "scoppiettereste": "scoppiettare",
    "scoppietteresti": "scoppiettare",
    "scoppietterete": "scoppiettare",
    "scoppietterà": "scoppiettare",
    "scoppietterò": "scoppiettare",
    "scoppietti": "scoppiettare",
    "scoppiettiamo": "scoppiettare",
    "scoppiettiate": "scoppiettare",
    "scoppiettii": "scoppiettio",
    "scoppiettin": "scoppiettare",
    "scoppiettino": "scoppiettare",
    "scoppietto": "scoppiettare",
    "scoppiettò": "scoppiettare",
    "scoppin": "scoppiare",
    "scoppino": "scoppiare",
    "scoppio": "scoppiare",
    "scoppiò": "scoppiare",
    "scoppole": "scoppola",
    "scopra": "scoprire",
    "scopran": "scoprire",
    "scoprano": "scoprire",
    "scopre": "scoprire",
    "scoprendo": "scoprire",
    "scoprente": "scoprire",
    "scoprenti": "scoprire",
    "scopri": "scoprire",
    "scopriamo": "scoprire",
    "scopriate": "scoprire",
    "scoprii": "scoprire",
    "scoprimmo": "scoprire",
    "scoprir": "scoprire",
    "scoprirai": "scoprire",
    "scopriran": "scoprire",
    "scopriranno": "scoprire",
    "scoprirebbe": "scoprire",
    "scoprirebber": "scoprire",
    "scoprirebbero": "scoprire",
    "scoprirei": "scoprire",
    "scopriremmo": "scoprire",
    "scopriremo": "scoprire",
    "scoprireste": "scoprire",
    "scopriresti": "scoprire",
    "scoprirete": "scoprire",
    "scopriron": "scoprire",
    "scoprirono": "scoprire",
    "scoprirà": "scoprire",
    "scoprirò": "scoprire",
    "scoprisse": "scoprire",
    "scoprisser": "scoprire",
    "scoprissero": "scoprire",
    "scoprissi": "scoprire",
    "scoprissimo": "scoprire",
    "scopriste": "scoprire",
    "scopristi": "scoprire",
    "scoprite": "scoprire",
    "scopritori": "scopritore",
    "scopriva": "scoprire",
    "scoprivamo": "scoprire",
    "scoprivan": "scoprire",
    "scoprivano": "scoprire",
    "scoprivate": "scoprire",
    "scoprivi": "scoprire",
    "scoprivo": "scoprire",
    "scopro": "scoprire",
    "scopron": "scoprire",
    "scoprono": "scoprire",
    "scoprì": "scoprire",
    "scopò": "scopare",
    "scora": "scorare",
    "scoraggerai": "scoraggiare",
    "scoraggeran": "scoraggiare",
    "scoraggeranno": "scoraggiare",
    "scoraggerebbe": "scoraggiare",
    "scoraggerebber": "scoraggiare",
    "scoraggerebbero": "scoraggiare",
    "scoraggerei": "scoraggiare",
    "scoraggeremmo": "scoraggiare",
    "scoraggeremo": "scoraggiare",
    "scoraggereste": "scoraggiare",
    "scoraggeresti": "scoraggiare",
    "scoraggerete": "scoraggiare",
    "scoraggerà": "scoraggiare",
    "scoraggerò": "scoraggiare",
    "scoraggi": "scoraggiare",
    "scoraggia": "scoraggiare",
    "scoraggiai": "scoraggiare",
    "scoraggiamenti": "scoraggiamento",
    "scoraggiammo": "scoraggiare",
    "scoraggiamo": "scoraggiare",
    "scoraggian": "scoraggiare",
    "scoraggiando": "scoraggiare",
    "scoraggiano": "scoraggiare",
    "scoraggiante": "scoraggiare",
    "scoraggianti": "scoraggiare",
    "scoraggiar": "scoraggiare",
    "scoraggiaron": "scoraggiare",
    "scoraggiarono": "scoraggiare",
    "scoraggiasse": "scoraggiare",
    "scoraggiasser": "scoraggiare",
    "scoraggiassero": "scoraggiare",
    "scoraggiassi": "scoraggiare",
    "scoraggiassimo": "scoraggiare",
    "scoraggiaste": "scoraggiare",
    "scoraggiasti": "scoraggiare",
    "scoraggiata": "scoraggiare",
    "scoraggiate": "scoraggiare",
    "scoraggiati": "scoraggiare",
    "scoraggiato": "scoraggiare",
    "scoraggiava": "scoraggiare",
    "scoraggiavamo": "scoraggiare",
    "scoraggiavan": "scoraggiare",
    "scoraggiavano": "scoraggiare",
    "scoraggiavate": "scoraggiare",
    "scoraggiavi": "scoraggiare",
    "scoraggiavo": "scoraggiare",
    "scoraggin": "scoraggiare",
    "scoraggino": "scoraggiare",
    "scoraggio": "scoraggiare",
    "scoraggiò": "scoraggiare",
    "scorai": "scorare",
    "scoramenti": "scoramento",
    "scorammo": "scorare",
    "scoran": "scorare",
    "scorando": "scorare",
    "scorano": "scorare",
    "scorante": "scorare",
    "scoranti": "scorare",
    "scorar": "scorare",
    "scoraron": "scorare",
    "scorarono": "scorare",
    "scorasse": "scorare",
    "scorasser": "scorare",
    "scorassero": "scorare",
    "scorassi": "scorare",
    "scorassimo": "scorare",
    "scoraste": "scorare",
    "scorasti": "scorare",
    "scorata": "scorare",
    "scorate": "scorare",
    "scorati": "scorare",
    "scorato": "scorare",
    "scorava": "scorare",
    "scoravamo": "scorare",
    "scoravan": "scorare",
    "scoravano": "scorare",
    "scoravate": "scorare",
    "scoravi": "scorare",
    "scoravo": "scorare",
    "scorbutica": "scorbutico",
    "scorbutiche": "scorbutico",
    "scorbutici": "scorbutico",
    "scorcerai": "scorciare",
    "scorceran": "scorciare",
    "scorceranno": "scorciare",
    "scorcerebbe": "scorciare",
    "scorcerebber": "scorciare",
    "scorcerebbero": "scorciare",
    "scorcerei": "scorciare",
    "scorceremmo": "scorciare",
    "scorceremo": "scorciare",
    "scorcereste": "scorciare",
    "scorceresti": "scorciare",
    "scorcerete": "scorciare",
    "scorcerà": "scorciare",
    "scorcerò": "scorciare",
    "scorci": "scorcio",
    "scorcia": "scorciare",
    "scorciai": "scorciare",
    "scorciammo": "scorciare",
    "scorciamo": "scorciare",
    "scorcian": "scorciare",
    "scorciando": "scorciare",
    "scorciano": "scorciare",
    "scorciante": "scorciare",
    "scorcianti": "scorciare",
    "scorciar": "scorciare",
    "scorciaron": "scorciare",
    "scorciarono": "scorciare",
    "scorciasse": "scorciare",
    "scorciasser": "scorciare",
    "scorciassero": "scorciare",
    "scorciassi": "scorciare",
    "scorciassimo": "scorciare",
    "scorciaste": "scorciare",
    "scorciasti": "scorciare",
    "scorciata": "scorciare",
    "scorciate": "scorciare",
    "scorciati": "scorciare",
    "scorciato": "scorciare",
    "scorciatoie": "scorciatoia",
    "scorciava": "scorciare",
    "scorciavamo": "scorciare",
    "scorciavan": "scorciare",
    "scorciavano": "scorciare",
    "scorciavate": "scorciare",
    "scorciavi": "scorciare",
    "scorciavo": "scorciare",
    "scorcin": "scorciare",
    "scorcino": "scorciare",
    "scorcio": "scorciare",
    "scorciò": "scorciare",
    "scorda": "scordare",
    "scordai": "scordare",
    "scordammo": "scordare",
    "scordan": "scordare",
    "scordando": "scordare",
    "scordano": "scordare",
    "scordante": "scordare",
    "scordanti": "scordare",
    "scordar": "scordare",
    "scordaron": "scordare",
    "scordarono": "scordare",
    "scordasse": "scordare",
    "scordasser": "scordare",
    "scordassero": "scordare",
    "scordassi": "scordare",
    "scordassimo": "scordare",
    "scordaste": "scordare",
    "scordasti": "scordare",
    "scordata": "scordare",
    "scordate": "scordare",
    "scordati": "scordare",
    "scordato": "scordare",
    "scordava": "scordare",
    "scordavamo": "scordare",
    "scordavan": "scordare",
    "scordavano": "scordare",
    "scordavate": "scordare",
    "scordavi": "scordare",
    "scordavo": "scordare",
    "scorderai": "scordare",
    "scorderan": "scordare",
    "scorderanno": "scordare",
    "scorderebbe": "scordare",
    "scorderebber": "scordare",
    "scorderebbero": "scordare",
    "scorderei": "scordare",
    "scorderemmo": "scordare",
    "scorderemo": "scordare",
    "scordereste": "scordare",
    "scorderesti": "scordare",
    "scorderete": "scordare",
    "scorderà": "scordare",
    "scorderò": "scordare",
    "scordi": "scordare",
    "scordiamo": "scordare",
    "scordiate": "scordare",
    "scordin": "scordare",
    "scordino": "scordare",
    "scordo": "scordare",
    "scordò": "scordare",
    "scoreggerai": "scoreggiare",
    "scoreggeran": "scoreggiare",
    "scoreggeranno": "scoreggiare",
    "scoreggerebbe": "scoreggiare",
    "scoreggerebber": "scoreggiare",
    "scoreggerebbero": "scoreggiare",
    "scoreggerei": "scoreggiare",
    "scoreggeremmo": "scoreggiare",
    "scoreggeremo": "scoreggiare",
    "scoreggereste": "scoreggiare",
    "scoreggeresti": "scoreggiare",
    "scoreggerete": "scoreggiare",
    "scoreggerà": "scoreggiare",
    "scoreggerò": "scoreggiare",
    "scoreggi": "scoreggiare",
    "scoreggia": "scoreggiare",
    "scoreggiai": "scoreggiare",
    "scoreggiammo": "scoreggiare",
    "scoreggiamo": "scoreggiare",
    "scoreggian": "scoreggiare",
    "scoreggiando": "scoreggiare",
    "scoreggiano": "scoreggiare",
    "scoreggiante": "scoreggiare",
    "scoreggianti": "scoreggiare",
    "scoreggiar": "scoreggiare",
    "scoreggiaron": "scoreggiare",
    "scoreggiarono": "scoreggiare",
    "scoreggiasse": "scoreggiare",
    "scoreggiasser": "scoreggiare",
    "scoreggiassero": "scoreggiare",
    "scoreggiassi": "scoreggiare",
    "scoreggiassimo": "scoreggiare",
    "scoreggiaste": "scoreggiare",
    "scoreggiasti": "scoreggiare",
    "scoreggiata": "scoreggiare",
    "scoreggiate": "scoreggiare",
    "scoreggiati": "scoreggiare",
    "scoreggiato": "scoreggiare",
    "scoreggiava": "scoreggiare",
    "scoreggiavamo": "scoreggiare",
    "scoreggiavan": "scoreggiare",
    "scoreggiavano": "scoreggiare",
    "scoreggiavate": "scoreggiare",
    "scoreggiavi": "scoreggiare",
    "scoreggiavo": "scoreggiare",
    "scoreggin": "scoreggiare",
    "scoreggino": "scoreggiare",
    "scoreggio": "scoreggiare",
    "scoreggiò": "scoreggiare",
    "scorerai": "scorare",
    "scoreran": "scorare",
    "scoreranno": "scorare",
    "scorerebbe": "scorare",
    "scorerebber": "scorare",
    "scorerebbero": "scorare",
    "scorerei": "scorare",
    "scoreremmo": "scorare",
    "scoreremo": "scorare",
    "scorereste": "scorare",
    "scoreresti": "scorare",
    "scorerete": "scorare",
    "scorerà": "scorare",
    "scorerò": "scorare",
    "scores": "score",
    "scorga": "scorgere",
    "scorgan": "scorgere",
    "scorgano": "scorgere",
    "scorge": "scorgere",
    "scorgemmo": "scorgere",
    "scorgendo": "scorgere",
    "scorgente": "scorgere",
    "scorgenti": "scorgere",
    "scorger": "scorgere",
    "scorgerai": "scorgere",
    "scorgeran": "scorgere",
    "scorgeranno": "scorgere",
    "scorgerebbe": "scorgere",
    "scorgerebber": "scorgere",
    "scorgerebbero": "scorgere",
    "scorgerei": "scorgere",
    "scorgeremmo": "scorgere",
    "scorgeremo": "scorgere",
    "scorgereste": "scorgere",
    "scorgeresti": "scorgere",
    "scorgerete": "scorgere",
    "scorgerà": "scorgere",
    "scorgerò": "scorgere",
    "scorgesse": "scorgere",
    "scorgesser": "scorgere",
    "scorgessero": "scorgere",
    "scorgessi": "scorgere",
    "scorgessimo": "scorgere",
    "scorgeste": "scorgere",
    "scorgesti": "scorgere",
    "scorgete": "scorgere",
    "scorgeva": "scorgere",
    "scorgevamo": "scorgere",
    "scorgevan": "scorgere",
    "scorgevano": "scorgere",
    "scorgevate": "scorgere",
    "scorgevi": "scorgere",
    "scorgevo": "scorgere",
    "scorgi": "scorgere",
    "scorgiamo": "scorgere",
    "scorgiate": "scorgere",
    "scorgo": "scorgere",
    "scorgon": "scorgere",
    "scorgono": "scorgere",
    "scori": "scorare",
    "scoriamo": "scorare",
    "scoriate": "scorare",
    "scorie": "scoria",
    "scorin": "scorare",
    "scorino": "scorare",
    "scorna": "scornare",
    "scornai": "scornare",
    "scornammo": "scornare",
    "scornan": "scornare",
    "scornando": "scornare",
    "scornano": "scornare",
    "scornante": "scornare",
    "scornanti": "scornare",
    "scornar": "scornare",
    "scornaron": "scornare",
    "scornarono": "scornare",
    "scornasse": "scornare",
    "scornasser": "scornare",
    "scornassero": "scornare",
    "scornassi": "scornare",
    "scornassimo": "scornare",
    "scornaste": "scornare",
    "scornasti": "scornare",
    "scornata": "scornare",
    "scornate": "scornare",
    "scornati": "scornare",
    "scornato": "scornare",
    "scornava": "scornare",
    "scornavamo": "scornare",
    "scornavan": "scornare",
    "scornavano": "scornare",
    "scornavate": "scornare",
    "scornavi": "scornare",
    "scornavo": "scornare",
    "scornerai": "scornare",
    "scorneran": "scornare",
    "scorneranno": "scornare",
    "scornerebbe": "scornare",
    "scornerebber": "scornare",
    "scornerebbero": "scornare",
    "scornerei": "scornare",
    "scorneremmo": "scornare",
    "scorneremo": "scornare",
    "scornereste": "scornare",
    "scorneresti": "scornare",
    "scornerete": "scornare",
    "scornerà": "scornare",
    "scornerò": "scornare",
    "scorni": "scornare",
    "scorniamo": "scornare",
    "scorniate": "scornare",
    "scornin": "scornare",
    "scornino": "scornare",
    "scorno": "scornare",
    "scornò": "scornare",
    "scoro": "scorare",
    "scorpacciate": "scorpacciata",
    "scorpioni": "scorpione",
    "scorpora": "scorporare",
    "scorporai": "scorporare",
    "scorporammo": "scorporare",
    "scorporan": "scorporare",
    "scorporando": "scorporare",
    "scorporano": "scorporare",
    "scorporante": "scorporare",
    "scorporanti": "scorporare",
    "scorporar": "scorporare",
    "scorporaron": "scorporare",
    "scorporarono": "scorporare",
    "scorporasse": "scorporare",
    "scorporasser": "scorporare",
    "scorporassero": "scorporare",
    "scorporassi": "scorporare",
    "scorporassimo": "scorporare",
    "scorporaste": "scorporare",
    "scorporasti": "scorporare",
    "scorporata": "scorporare",
    "scorporate": "scorporare",
    "scorporati": "scorporare",
    "scorporato": "scorporare",
    "scorporava": "scorporare",
    "scorporavamo": "scorporare",
    "scorporavan": "scorporare",
    "scorporavano": "scorporare",
    "scorporavate": "scorporare",
    "scorporavi": "scorporare",
    "scorporavo": "scorporare",
    "scorporerai": "scorporare",
    "scorporeran": "scorporare",
    "scorporeranno": "scorporare",
    "scorporerebbe": "scorporare",
    "scorporerebber": "scorporare",
    "scorporerebbero": "scorporare",
    "scorporerei": "scorporare",
    "scorporeremmo": "scorporare",
    "scorporeremo": "scorporare",
    "scorporereste": "scorporare",
    "scorporeresti": "scorporare",
    "scorporerete": "scorporare",
    "scorporerà": "scorporare",
    "scorporerò": "scorporare",
    "scorpori": "scorporo",
    "scorporiamo": "scorporare",
    "scorporiate": "scorporare",
    "scorporin": "scorporare",
    "scorporino": "scorporare",
    "scorporo": "scorporare",
    "scorporò": "scorporare",
    "scorra": "scorrere",
    "scorran": "scorrere",
    "scorrano": "scorrere",
    "scorrazza": "scorrazzare",
    "scorrazzai": "scorrazzare",
    "scorrazzammo": "scorrazzare",
    "scorrazzan": "scorrazzare",
    "scorrazzando": "scorrazzare",
    "scorrazzano": "scorrazzare",
    "scorrazzante": "scorrazzare",
    "scorrazzanti": "scorrazzare",
    "scorrazzar": "scorrazzare",
    "scorrazzaron": "scorrazzare",
    "scorrazzarono": "scorrazzare",
    "scorrazzasse": "scorrazzare",
    "scorrazzasser": "scorrazzare",
    "scorrazzassero": "scorrazzare",
    "scorrazzassi": "scorrazzare",
    "scorrazzassimo": "scorrazzare",
    "scorrazzaste": "scorrazzare",
    "scorrazzasti": "scorrazzare",
    "scorrazzata": "scorrazzare",
    "scorrazzate": "scorrazzare",
    "scorrazzati": "scorrazzare",
    "scorrazzato": "scorrazzare",
    "scorrazzava": "scorrazzare",
    "scorrazzavamo": "scorrazzare",
    "scorrazzavan": "scorrazzare",
    "scorrazzavano": "scorrazzare",
    "scorrazzavate": "scorrazzare",
    "scorrazzavi": "scorrazzare",
    "scorrazzavo": "scorrazzare",
    "scorrazzerai": "scorrazzare",
    "scorrazzeran": "scorrazzare",
    "scorrazzeranno": "scorrazzare",
    "scorrazzerebbe": "scorrazzare",
    "scorrazzerebber": "scorrazzare",
    "scorrazzerebbero": "scorrazzare",
    "scorrazzerei": "scorrazzare",
    "scorrazzeremmo": "scorrazzare",
    "scorrazzeremo": "scorrazzare",
    "scorrazzereste": "scorrazzare",
    "scorrazzeresti": "scorrazzare",
    "scorrazzerete": "scorrazzare",
    "scorrazzerà": "scorrazzare",
    "scorrazzerò": "scorrazzare",
    "scorrazzi": "scorrazzare",
    "scorrazziamo": "scorrazzare",
    "scorrazziate": "scorrazzare",
    "scorrazzin": "scorrazzare",
    "scorrazzino": "scorrazzare",
    "scorrazzo": "scorrazzare",
    "scorrazzò": "scorrazzare",
    "scorre": "scorrere",
    "scorremmo": "scorrere",
    "scorrendo": "scorrere",
    "scorrente": "scorrere",
    "scorrenti": "scorrere",
    "scorrer": "scorrere",
    "scorrerai": "scorrere",
    "scorreran": "scorrere",
    "scorreranno": "scorrere",
    "scorrerebbe": "scorrere",
    "scorrerebber": "scorrere",
    "scorrerebbero": "scorrere",
    "scorrerei": "scorrere",
    "scorreremmo": "scorrere",
    "scorreremo": "scorrere",
    "scorrereste": "scorrere",
    "scorreresti": "scorrere",
    "scorrerete": "scorrere",
    "scorrerie": "scorreria",
    "scorrerà": "scorrere",
    "scorrerò": "scorrere",
    "scorresse": "scorrere",
    "scorresser": "scorrere",
    "scorressero": "scorrere",
    "scorressi": "scorrere",
    "scorressimo": "scorrere",
    "scorreste": "scorrere",
    "scorresti": "scorrere",
    "scorrete": "scorrere",
    "scorretta": "scorretto",
    "scorrette": "scorretto",
    "scorrettezze": "scorrettezza",
    "scorretti": "scorretto",
    "scorreva": "scorrere",
    "scorrevamo": "scorrere",
    "scorrevan": "scorrere",
    "scorrevano": "scorrere",
    "scorrevate": "scorrere",
    "scorrevi": "scorrere",
    "scorrevo": "scorrere",
    "scorrevolezze": "scorrevolezza",
    "scorrevoli": "scorrevole",
    "scorri": "scorrere",
    "scorriamo": "scorrere",
    "scorriate": "scorrere",
    "scorribande": "scorribanda",
    "scorrimenti": "scorrimento",
    "scorro": "scorrere",
    "scorron": "scorrere",
    "scorrono": "scorrere",
    "scorsa": "scorso",
    "scorse": "scorso",
    "scorser": "scorrere",
    "scorsero": "scorrere",
    "scorsi": "scorso",
    "scorso": "scorrere",
    "scorsoi": "scorsoio",
    "scorsoia": "scorsoio",
    "scorsoie": "scorsoio",
    "scorta": "scortare",
    "scortai": "scortare",
    "scortammo": "scortare",
    "scortan": "scortare",
    "scortando": "scortare",
    "scortano": "scortare",
    "scortante": "scortare",
    "scortanti": "scortare",
    "scortar": "scortare",
    "scortaron": "scortare",
    "scortarono": "scortare",
    "scortasse": "scortare",
    "scortasser": "scortare",
    "scortassero": "scortare",
    "scortassi": "scortare",
    "scortassimo": "scortare",
    "scortaste": "scortare",
    "scortasti": "scortare",
    "scortata": "scortare",
    "scortate": "scortare",
    "scortati": "scortare",
    "scortato": "scortare",
    "scortava": "scortare",
    "scortavamo": "scortare",
    "scortavan": "scortare",
    "scortavano": "scortare",
    "scortavate": "scortare",
    "scortavi": "scortare",
    "scortavo": "scortare",
    "scorte": "scorta",
    "scorteccerai": "scortecciare",
    "scortecceran": "scortecciare",
    "scortecceranno": "scortecciare",
    "scorteccerebbe": "scortecciare",
    "scorteccerebber": "scortecciare",
    "scorteccerebbero": "scortecciare",
    "scorteccerei": "scortecciare",
    "scortecceremmo": "scortecciare",
    "scortecceremo": "scortecciare",
    "scorteccereste": "scortecciare",
    "scortecceresti": "scortecciare",
    "scorteccerete": "scortecciare",
    "scorteccerà": "scortecciare",
    "scorteccerò": "scortecciare",
    "scortecci": "scortecciare",
    "scorteccia": "scortecciare",
    "scortecciai": "scortecciare",
    "scortecciammo": "scortecciare",
    "scortecciamo": "scortecciare",
    "scorteccian": "scortecciare",
    "scortecciando": "scortecciare",
    "scortecciano": "scortecciare",
    "scortecciante": "scortecciare",
    "scorteccianti": "scortecciare",
    "scortecciar": "scortecciare",
    "scortecciaron": "scortecciare",
    "scortecciarono": "scortecciare",
    "scortecciasse": "scortecciare",
    "scortecciasser": "scortecciare",
    "scortecciassero": "scortecciare",
    "scortecciassi": "scortecciare",
    "scortecciassimo": "scortecciare",
    "scortecciaste": "scortecciare",
    "scortecciasti": "scortecciare",
    "scortecciata": "scortecciare",
    "scortecciate": "scortecciare",
    "scortecciati": "scortecciare",
    "scortecciato": "scortecciare",
    "scortecciava": "scortecciare",
    "scortecciavamo": "scortecciare",
    "scortecciavan": "scortecciare",
    "scortecciavano": "scortecciare",
    "scortecciavate": "scortecciare",
    "scortecciavi": "scortecciare",
    "scortecciavo": "scortecciare",
    "scorteccin": "scortecciare",
    "scorteccino": "scortecciare",
    "scorteccio": "scortecciare",
    "scortecciò": "scortecciare",
    "scorterai": "scortare",
    "scorteran": "scortare",
    "scorteranno": "scortare",
    "scorterebbe": "scortare",
    "scorterebber": "scortare",
    "scorterebbero": "scortare",
    "scorterei": "scortare",
    "scorteremmo": "scortare",
    "scorteremo": "scortare",
    "scortereste": "scortare",
    "scorteresti": "scortare",
    "scorterete": "scortare",
    "scorterà": "scortare",
    "scorterò": "scortare",
    "scortesi": "scortese",
    "scortesie": "scortesia",
    "scorti": "scortare",
    "scortiamo": "scortare",
    "scortiate": "scortare",
    "scortica": "scorticare",
    "scorticai": "scorticare",
    "scorticammo": "scorticare",
    "scortican": "scorticare",
    "scorticando": "scorticare",
    "scorticano": "scorticare",
    "scorticante": "scorticare",
    "scorticanti": "scorticare",
    "scorticar": "scorticare",
    "scorticaron": "scorticare",
    "scorticarono": "scorticare",
    "scorticasse": "scorticare",
    "scorticasser": "scorticare",
    "scorticassero": "scorticare",
    "scorticassi": "scorticare",
    "scorticassimo": "scorticare",
    "scorticaste": "scorticare",
    "scorticasti": "scorticare",
    "scorticata": "scorticare",
    "scorticate": "scorticare",
    "scorticati": "scorticare",
    "scorticato": "scorticare",
    "scorticava": "scorticare",
    "scorticavamo": "scorticare",
    "scorticavan": "scorticare",
    "scorticavano": "scorticare",
    "scorticavate": "scorticare",
    "scorticavi": "scorticare",
    "scorticavo": "scorticare",
    "scorticherai": "scorticare",
    "scorticheran": "scorticare",
    "scorticheranno": "scorticare",
    "scorticherebbe": "scorticare",
    "scorticherebber": "scorticare",
    "scorticherebbero": "scorticare",
    "scorticherei": "scorticare",
    "scorticheremmo": "scorticare",
    "scorticheremo": "scorticare",
    "scortichereste": "scorticare",
    "scorticheresti": "scorticare",
    "scorticherete": "scorticare",
    "scorticherà": "scorticare",
    "scorticherò": "scorticare",
    "scortichi": "scorticare",
    "scortichiamo": "scorticare",
    "scortichiate": "scorticare",
    "scortichin": "scorticare",
    "scortichino": "scorticare",
    "scortico": "scorticare",
    "scorticò": "scorticare",
    "scortin": "scortare",
    "scortino": "scortare",
    "scorto": "scortare",
    "scortò": "scortare",
    "scorò": "scorare",
    "scoscenda": "scoscendere",
    "scoscendan": "scoscendere",
    "scoscendano": "scoscendere",
    "scoscende": "scoscendere",
    "scoscendemmo": "scoscendere",
    "scoscendendo": "scoscendere",
    "scoscendente": "scoscendere",
    "scoscendenti": "scoscendere",
    "scoscender": "scoscendere",
    "scoscenderai": "scoscendere",
    "scoscenderan": "scoscendere",
    "scoscenderanno": "scoscendere",
    "scoscenderebbe": "scoscendere",
    "scoscenderebber": "scoscendere",
    "scoscenderebbero": "scoscendere",
    "scoscenderei": "scoscendere",
    "scoscenderemmo": "scoscendere",
    "scoscenderemo": "scoscendere",
    "scoscendereste": "scoscendere",
    "scoscenderesti": "scoscendere",
    "scoscenderete": "scoscendere",
    "scoscenderà": "scoscendere",
    "scoscenderò": "scoscendere",
    "scoscendesse": "scoscendere",
    "scoscendesser": "scoscendere",
    "scoscendessero": "scoscendere",
    "scoscendessi": "scoscendere",
    "scoscendessimo": "scoscendere",
    "scoscendeste": "scoscendere",
    "scoscendesti": "scoscendere",
    "scoscendete": "scoscendere",
    "scoscendeva": "scoscendere",
    "scoscendevamo": "scoscendere",
    "scoscendevan": "scoscendere",
    "scoscendevano": "scoscendere",
    "scoscendevate": "scoscendere",
    "scoscendevi": "scoscendere",
    "scoscendevo": "scoscendere",
    "scoscendi": "scoscendere",
    "scoscendiamo": "scoscendere",
    "scoscendiate": "scoscendere",
    "scoscendo": "scoscendere",
    "scoscendon": "scoscendere",
    "scoscendono": "scoscendere",
    "scoscerai": "scosciare",
    "scosceran": "scosciare",
    "scosceranno": "scosciare",
    "scoscerebbe": "scosciare",
    "scoscerebber": "scosciare",
    "scoscerebbero": "scosciare",
    "scoscerei": "scosciare",
    "scosceremmo": "scosciare",
    "scosceremo": "scosciare",
    "scoscereste": "scosciare",
    "scosceresti": "scosciare",
    "scoscerete": "scosciare",
    "scoscerà": "scosciare",
    "scoscerò": "scosciare",
    "scoscesa": "scosceso",
    "scoscese": "scosceso",
    "scosceser": "scoscendere",
    "scoscesero": "scoscendere",
    "scoscesi": "scosceso",
    "scosceso": "scoscendere",
    "scoscesè": "scoscendere",
    "scosci": "scosciare",
    "scoscia": "scosciare",
    "scosciai": "scosciare",
    "scosciammo": "scosciare",
    "scosciamo": "scosciare",
    "scoscian": "scosciare",
    "scosciando": "scosciare",
    "scosciano": "scosciare",
    "scosciante": "scosciare",
    "scoscianti": "scosciare",
    "scosciar": "scosciare",
    "scosciaron": "scosciare",
    "scosciarono": "scosciare",
    "scosciasse": "scosciare",
    "scosciasser": "scosciare",
    "scosciassero": "scosciare",
    "scosciassi": "scosciare",
    "scosciassimo": "scosciare",
    "scosciaste": "scosciare",
    "scosciasti": "scosciare",
    "scosciata": "scosciare",
    "scosciate": "scosciare",
    "scosciati": "scosciare",
    "scosciato": "scosciare",
    "scosciava": "scosciare",
    "scosciavamo": "scosciare",
    "scosciavan": "scosciare",
    "scosciavano": "scosciare",
    "scosciavate": "scosciare",
    "scosciavi": "scosciare",
    "scosciavo": "scosciare",
    "scoscin": "scosciare",
    "scoscino": "scosciare",
    "scoscio": "scosciare",
    "scosciò": "scosciare",
    "scossa": "scuotere",
    "scosse": "scuotere",
    "scosser": "scuotere",
    "scossero": "scuotere",
    "scossi": "scuotere",
    "scosso": "scuotere",
    "scossoni": "scossone",
    "scosta": "scostare",
    "scostai": "scostare",
    "scostamenti": "scostamento",
    "scostammo": "scostare",
    "scostan": "scostare",
    "scostando": "scostare",
    "scostano": "scostare",
    "scostante": "scostare",
    "scostanti": "scostare",
    "scostar": "scostare",
    "scostaron": "scostare",
    "scostarono": "scostare",
    "scostasse": "scostare",
    "scostasser": "scostare",
    "scostassero": "scostare",
    "scostassi": "scostare",
    "scostassimo": "scostare",
    "scostaste": "scostare",
    "scostasti": "scostare",
    "scostata": "scostare",
    "scostate": "scostare",
    "scostati": "scostare",
    "scostato": "scostare",
    "scostava": "scostare",
    "scostavamo": "scostare",
    "scostavan": "scostare",
    "scostavano": "scostare",
    "scostavate": "scostare",
    "scostavi": "scostare",
    "scostavo": "scostare",
    "scosterai": "scostare",
    "scosteran": "scostare",
    "scosteranno": "scostare",
    "scosterebbe": "scostare",
    "scosterebber": "scostare",
    "scosterebbero": "scostare",
    "scosterei": "scostare",
    "scosteremmo": "scostare",
    "scosteremo": "scostare",
    "scostereste": "scostare",
    "scosteresti": "scostare",
    "scosterete": "scostare",
    "scosterà": "scostare",
    "scosterò": "scostare",
    "scosti": "scostare",
    "scostiamo": "scostare",
    "scostiate": "scostare",
    "scostin": "scostare",
    "scostino": "scostare",
    "scosto": "scostare",
    "scostumata": "scostumato",
    "scostumate": "scostumato",
    "scostumati": "scostumato",
    "scostò": "scostare",
    "scotenna": "scotennare",
    "scotennai": "scotennare",
    "scotennammo": "scotennare",
    "scotennan": "scotennare",
    "scotennando": "scotennare",
    "scotennano": "scotennare",
    "scotennante": "scotennare",
    "scotennanti": "scotennare",
    "scotennar": "scotennare",
    "scotennaron": "scotennare",
    "scotennarono": "scotennare",
    "scotennasse": "scotennare",
    "scotennasser": "scotennare",
    "scotennassero": "scotennare",
    "scotennassi": "scotennare",
    "scotennassimo": "scotennare",
    "scotennaste": "scotennare",
    "scotennasti": "scotennare",
    "scotennata": "scotennare",
    "scotennate": "scotennare",
    "scotennati": "scotennare",
    "scotennato": "scotennare",
    "scotennava": "scotennare",
    "scotennavamo": "scotennare",
    "scotennavan": "scotennare",
    "scotennavano": "scotennare",
    "scotennavate": "scotennare",
    "scotennavi": "scotennare",
    "scotennavo": "scotennare",
    "scotennerai": "scotennare",
    "scotenneran": "scotennare",
    "scotenneranno": "scotennare",
    "scotennerebbe": "scotennare",
    "scotennerebber": "scotennare",
    "scotennerebbero": "scotennare",
    "scotennerei": "scotennare",
    "scotenneremmo": "scotennare",
    "scotenneremo": "scotennare",
    "scotennereste": "scotennare",
    "scotenneresti": "scotennare",
    "scotennerete": "scotennare",
    "scotennerà": "scotennare",
    "scotennerò": "scotennare",
    "scotenni": "scotennare",
    "scotenniamo": "scotennare",
    "scotenniate": "scotennare",
    "scotennin": "scotennare",
    "scotennino": "scotennare",
    "scotenno": "scotennare",
    "scotennò": "scotennare",
    "scotta": "scottare",
    "scottai": "scottare",
    "scottammo": "scottare",
    "scottan": "scottare",
    "scottando": "scottare",
    "scottano": "scottare",
    "scottante": "scottare",
    "scottanti": "scottare",
    "scottar": "scottare",
    "scottaron": "scottare",
    "scottarono": "scottare",
    "scottasse": "scottare",
    "scottasser": "scottare",
    "scottassero": "scottare",
    "scottassi": "scottare",
    "scottassimo": "scottare",
    "scottaste": "scottare",
    "scottasti": "scottare",
    "scottata": "scottare",
    "scottate": "scottare",
    "scottati": "scottare",
    "scottato": "scottare",
    "scottature": "scottatura",
    "scottava": "scottare",
    "scottavamo": "scottare",
    "scottavan": "scottare",
    "scottavano": "scottare",
    "scottavate": "scottare",
    "scottavi": "scottare",
    "scottavo": "scottare",
    "scotterai": "scottare",
    "scotteran": "scottare",
    "scotteranno": "scottare",
    "scotterebbe": "scottare",
    "scotterebber": "scottare",
    "scotterebbero": "scottare",
    "scotterei": "scottare",
    "scotteremmo": "scottare",
    "scotteremo": "scottare",
    "scottereste": "scottare",
    "scotteresti": "scottare",
    "scotterete": "scottare",
    "scotterà": "scottare",
    "scotterò": "scottare",
    "scotti": "scottare",
    "scottiamo": "scottare",
    "scottiate": "scottare",
    "scottin": "scottare",
    "scottino": "scottare",
    "scotto": "scottare",
    "scottò": "scottare",
    "scova": "scovare",
    "scovai": "scovare",
    "scovammo": "scovare",
    "scovan": "scovare",
    "scovando": "scovare",
    "scovano": "scovare",
    "scovante": "scovare",
    "scovanti": "scovare",
    "scovar": "scovare",
    "scovaron": "scovare",
    "scovarono": "scovare",
    "scovasse": "scovare",
    "scovasser": "scovare",
    "scovassero": "scovare",
    "scovassi": "scovare",
    "scovassimo": "scovare",
    "scovaste": "scovare",
    "scovasti": "scovare",
    "scovata": "scovare",
    "scovate": "scovare",
    "scovati": "scovare",
    "scovato": "scovare",
    "scovava": "scovare",
    "scovavamo": "scovare",
    "scovavan": "scovare",
    "scovavano": "scovare",
    "scovavate": "scovare",
    "scovavi": "scovare",
    "scovavo": "scovare",
    "scoverai": "scovare",
    "scoveran": "scovare",
    "scoveranno": "scovare",
    "scoverebbe": "scovare",
    "scoverebber": "scovare",
    "scoverebbero": "scovare",
    "scoverei": "scovare",
    "scoveremmo": "scovare",
    "scoveremo": "scovare",
    "scovereste": "scovare",
    "scoveresti": "scovare",
    "scoverete": "scovare",
    "scoverà": "scovare",
    "scoverò": "scovare",
    "scovi": "scovare",
    "scoviamo": "scovare",
    "scoviate": "scovare",
    "scovin": "scovare",
    "scovino": "scovare",
    "scovo": "scovare",
    "scovò": "scovare",
    "scozzesi": "scozzese",
    "scozzona": "scozzonare",
    "scozzonai": "scozzonare",
    "scozzonammo": "scozzonare",
    "scozzonan": "scozzonare",
    "scozzonando": "scozzonare",
    "scozzonano": "scozzonare",
    "scozzonante": "scozzonare",
    "scozzonanti": "scozzonare",
    "scozzonar": "scozzonare",
    "scozzonaron": "scozzonare",
    "scozzonarono": "scozzonare",
    "scozzonasse": "scozzonare",
    "scozzonasser": "scozzonare",
    "scozzonassero": "scozzonare",
    "scozzonassi": "scozzonare",
    "scozzonassimo": "scozzonare",
    "scozzonaste": "scozzonare",
    "scozzonasti": "scozzonare",
    "scozzonata": "scozzonare",
    "scozzonate": "scozzonare",
    "scozzonati": "scozzonare",
    "scozzonato": "scozzonare",
    "scozzonava": "scozzonare",
    "scozzonavamo": "scozzonare",
    "scozzonavan": "scozzonare",
    "scozzonavano": "scozzonare",
    "scozzonavate": "scozzonare",
    "scozzonavi": "scozzonare",
    "scozzonavo": "scozzonare",
    "scozzonerai": "scozzonare",
    "scozzoneran": "scozzonare",
    "scozzoneranno": "scozzonare",
    "scozzonerebbe": "scozzonare",
    "scozzonerebber": "scozzonare",
    "scozzonerebbero": "scozzonare",
    "scozzonerei": "scozzonare",
    "scozzoneremmo": "scozzonare",
    "scozzoneremo": "scozzonare",
    "scozzonereste": "scozzonare",
    "scozzoneresti": "scozzonare",
    "scozzonerete": "scozzonare",
    "scozzonerà": "scozzonare",
    "scozzonerò": "scozzonare",
    "scozzoni": "scozzonare",
    "scozzoniamo": "scozzonare",
    "scozzoniate": "scozzonare",
    "scozzonin": "scozzonare",
    "scozzonino": "scozzonare",
    "scozzono": "scozzonare",
    "scozzonò": "scozzonare",
    "scranni": "scranno",
    "scredita": "screditare",
    "screditai": "screditare",
    "screditammo": "screditare",
    "screditan": "screditare",
    "screditando": "screditare",
    "screditano": "screditare",
    "screditante": "screditare",
    "screditanti": "screditare",
    "screditar": "screditare",
    "screditaron": "screditare",
    "screditarono": "screditare",
    "screditasse": "screditare",
    "screditasser": "screditare",
    "screditassero": "screditare",
    "screditassi": "screditare",
    "screditassimo": "screditare",
    "screditaste": "screditare",
    "screditasti": "screditare",
    "screditata": "screditare",
    "screditate": "screditare",
    "screditati": "screditare",
    "screditato": "screditare",
    "screditava": "screditare",
    "screditavamo": "screditare",
    "screditavan": "screditare",
    "screditavano": "screditare",
    "screditavate": "screditare",
    "screditavi": "screditare",
    "screditavo": "screditare",
    "screditerai": "screditare",
    "screditeran": "screditare",
    "screditeranno": "screditare",
    "screditerebbe": "screditare",
    "screditerebber": "screditare",
    "screditerebbero": "screditare",
    "screditerei": "screditare",
    "screditeremmo": "screditare",
    "screditeremo": "screditare",
    "screditereste": "screditare",
    "screditeresti": "screditare",
    "screditerete": "screditare",
    "screditerà": "screditare",
    "screditerò": "screditare",
    "screditi": "screditare",
    "screditiamo": "screditare",
    "screditiate": "screditare",
    "screditin": "screditare",
    "screditino": "screditare",
    "scredito": "screditare",
    "screditò": "screditare",
    "screma": "scremare",
    "scremai": "scremare",
    "scremammo": "scremare",
    "screman": "scremare",
    "scremando": "scremare",
    "scremano": "scremare",
    "scremante": "scremare",
    "scremanti": "scremare",
    "scremar": "scremare",
    "scremaron": "scremare",
    "scremarono": "scremare",
    "scremasse": "scremare",
    "scremasser": "scremare",
    "scremassero": "scremare",
    "scremassi": "scremare",
    "scremassimo": "scremare",
    "scremaste": "scremare",
    "scremasti": "scremare",
    "scremata": "scremare",
    "scremate": "scremare",
    "scremati": "scremare",
    "scremato": "scremare",
    "scremature": "scrematura",
    "scremava": "scremare",
    "scremavamo": "scremare",
    "scremavan": "scremare",
    "scremavano": "scremare",
    "scremavate": "scremare",
    "scremavi": "scremare",
    "scremavo": "scremare",
    "scremerai": "scremare",
    "scremeran": "scremare",
    "scremeranno": "scremare",
    "scremerebbe": "scremare",
    "scremerebber": "scremare",
    "scremerebbero": "scremare",
    "scremerei": "scremare",
    "scremeremmo": "scremare",
    "scremeremo": "scremare",
    "scremereste": "scremare",
    "scremeresti": "scremare",
    "scremerete": "scremare",
    "scremerà": "scremare",
    "scremerò": "scremare",
    "scremi": "scremare",
    "scremiamo": "scremare",
    "scremiate": "scremare",
    "scremin": "scremare",
    "scremino": "scremare",
    "scremo": "scremare",
    "scremò": "scremare",
    "screpola": "screpolare",
    "screpolai": "screpolare",
    "screpolammo": "screpolare",
    "screpolan": "screpolare",
    "screpolando": "screpolare",
    "screpolano": "screpolare",
    "screpolante": "screpolare",
    "screpolanti": "screpolare",
    "screpolar": "screpolare",
    "screpolaron": "screpolare",
    "screpolarono": "screpolare",
    "screpolasse": "screpolare",
    "screpolasser": "screpolare",
    "screpolassero": "screpolare",
    "screpolassi": "screpolare",
    "screpolassimo": "screpolare",
    "screpolaste": "screpolare",
    "screpolasti": "screpolare",
    "screpolata": "screpolare",
    "screpolate": "screpolare",
    "screpolati": "screpolare",
    "screpolato": "screpolare",
    "screpolature": "screpolatura",
    "screpolava": "screpolare",
    "screpolavamo": "screpolare",
    "screpolavan": "screpolare",
    "screpolavano": "screpolare",
    "screpolavate": "screpolare",
    "screpolavi": "screpolare",
    "screpolavo": "screpolare",
    "screpolerai": "screpolare",
    "screpoleran": "screpolare",
    "screpoleranno": "screpolare",
    "screpolerebbe": "screpolare",
    "screpolerebber": "screpolare",
    "screpolerebbero": "screpolare",
    "screpolerei": "screpolare",
    "screpoleremmo": "screpolare",
    "screpoleremo": "screpolare",
    "screpolereste": "screpolare",
    "screpoleresti": "screpolare",
    "screpolerete": "screpolare",
    "screpolerà": "screpolare",
    "screpolerò": "screpolare",
    "screpoli": "screpolare",
    "screpoliamo": "screpolare",
    "screpoliate": "screpolare",
    "screpolin": "screpolare",
    "screpolino": "screpolare",
    "screpolo": "screpolare",
    "screpolò": "screpolare",
    "screzi": "screzio",
    "screzia": "screziare",
    "screziai": "screziare",
    "screziammo": "screziare",
    "screziamo": "screziare",
    "screzian": "screziare",
    "screziando": "screziare",
    "screziano": "screziare",
    "screziante": "screziare",
    "screzianti": "screziare",
    "screziar": "screziare",
    "screziaron": "screziare",
    "screziarono": "screziare",
    "screziasse": "screziare",
    "screziasser": "screziare",
    "screziassero": "screziare",
    "screziassi": "screziare",
    "screziassimo": "screziare",
    "screziaste": "screziare",
    "screziasti": "screziare",
    "screziata": "screziare",
    "screziate": "screziare",
    "screziati": "screziare",
    "screziato": "screziare",
    "screziava": "screziare",
    "screziavamo": "screziare",
    "screziavan": "screziare",
    "screziavano": "screziare",
    "screziavate": "screziare",
    "screziavi": "screziare",
    "screziavo": "screziare",
    "screzierai": "screziare",
    "screzieran": "screziare",
    "screzieranno": "screziare",
    "screzierebbe": "screziare",
    "screzierebber": "screziare",
    "screzierebbero": "screziare",
    "screzierei": "screziare",
    "screzieremmo": "screziare",
    "screzieremo": "screziare",
    "screziereste": "screziare",
    "screzieresti": "screziare",
    "screzierete": "screziare",
    "screzierà": "screziare",
    "screzierò": "screziare",
    "screzin": "screziare",
    "screzino": "screziare",
    "screzio": "screziare",
    "screziò": "screziare",
    "scribacchi": "scribacchiare",
    "scribacchia": "scribacchiare",
    "scribacchiai": "scribacchiare",
    "scribacchiammo": "scribacchiare",
    "scribacchiamo": "scribacchiare",
    "scribacchian": "scribacchiare",
    "scribacchiando": "scribacchiare",
    "scribacchiano": "scribacchiare",
    "scribacchiante": "scribacchiare",
    "scribacchianti": "scribacchiare",
    "scribacchiar": "scribacchiare",
    "scribacchiaron": "scribacchiare",
    "scribacchiarono": "scribacchiare",
    "scribacchiasse": "scribacchiare",
    "scribacchiasser": "scribacchiare",
    "scribacchiassero": "scribacchiare",
    "scribacchiassi": "scribacchiare",
    "scribacchiassimo": "scribacchiare",
    "scribacchiaste": "scribacchiare",
    "scribacchiasti": "scribacchiare",
    "scribacchiata": "scribacchiare",
    "scribacchiate": "scribacchiare",
    "scribacchiati": "scribacchiare",
    "scribacchiato": "scribacchiare",
    "scribacchiava": "scribacchiare",
    "scribacchiavamo": "scribacchiare",
    "scribacchiavan": "scribacchiare",
    "scribacchiavano": "scribacchiare",
    "scribacchiavate": "scribacchiare",
    "scribacchiavi": "scribacchiare",
    "scribacchiavo": "scribacchiare",
    "scribacchierai": "scribacchiare",
    "scribacchieran": "scribacchiare",
    "scribacchieranno": "scribacchiare",
    "scribacchierebbe": "scribacchiare",
    "scribacchierebber": "scribacchiare",
    "scribacchierebbero": "scribacchiare",
    "scribacchierei": "scribacchiare",
    "scribacchieremmo": "scribacchiare",
    "scribacchieremo": "scribacchiare",
    "scribacchiereste": "scribacchiare",
    "scribacchieresti": "scribacchiare",
    "scribacchierete": "scribacchiare",
    "scribacchierà": "scribacchiare",
    "scribacchierò": "scribacchiare",
    "scribacchin": "scribacchiare",
    "scribacchino": "scribacchiare",
    "scribacchio": "scribacchiare",
    "scribacchiò": "scribacchiare",
    "scribi": "scriba",
    "scricchiola": "scricchiolare",
    "scricchiolai": "scricchiolare",
    "scricchiolammo": "scricchiolare",
    "scricchiolan": "scricchiolare",
    "scricchiolando": "scricchiolare",
    "scricchiolano": "scricchiolare",
    "scricchiolante": "scricchiolare",
    "scricchiolanti": "scricchiolare",
    "scricchiolar": "scricchiolare",
    "scricchiolaron": "scricchiolare",
    "scricchiolarono": "scricchiolare",
    "scricchiolasse": "scricchiolare",
    "scricchiolasser": "scricchiolare",
    "scricchiolassero": "scricchiolare",
    "scricchiolassi": "scricchiolare",
    "scricchiolassimo": "scricchiolare",
    "scricchiolaste": "scricchiolare",
    "scricchiolasti": "scricchiolare",
    "scricchiolata": "scricchiolare",
    "scricchiolate": "scricchiolare",
    "scricchiolati": "scricchiolare",
    "scricchiolato": "scricchiolare",
    "scricchiolava": "scricchiolare",
    "scricchiolavamo": "scricchiolare",
    "scricchiolavan": "scricchiolare",
    "scricchiolavano": "scricchiolare",
    "scricchiolavate": "scricchiolare",
    "scricchiolavi": "scricchiolare",
    "scricchiolavo": "scricchiolare",
    "scricchiolerai": "scricchiolare",
    "scricchioleran": "scricchiolare",
    "scricchioleranno": "scricchiolare",
    "scricchiolerebbe": "scricchiolare",
    "scricchiolerebber": "scricchiolare",
    "scricchiolerebbero": "scricchiolare",
    "scricchiolerei": "scricchiolare",
    "scricchioleremmo": "scricchiolare",
    "scricchioleremo": "scricchiolare",
    "scricchiolereste": "scricchiolare",
    "scricchioleresti": "scricchiolare",
    "scricchiolerete": "scricchiolare",
    "scricchiolerà": "scricchiolare",
    "scricchiolerò": "scricchiolare",
    "scricchioli": "scricchiolare",
    "scricchioliamo": "scricchiolare",
    "scricchioliate": "scricchiolare",
    "scricchiolii": "scricchiolio",
    "scricchiolin": "scricchiolare",
    "scricchiolino": "scricchiolare",
    "scricchiolo": "scricchiolare",
    "scricchiolò": "scricchiolare",
    "scrigni": "scrigno",
    "scrisse": "scrivere",
    "scrisser": "scrivere",
    "scrissero": "scrivere",
    "scrissi": "scrivere",
    "scristianizza": "scristianizzare",
    "scristianizzai": "scristianizzare",
    "scristianizzammo": "scristianizzare",
    "scristianizzan": "scristianizzare",
    "scristianizzando": "scristianizzare",
    "scristianizzano": "scristianizzare",
    "scristianizzante": "scristianizzare",
    "scristianizzanti": "scristianizzare",
    "scristianizzar": "scristianizzare",
    "scristianizzaron": "scristianizzare",
    "scristianizzarono": "scristianizzare",
    "scristianizzasse": "scristianizzare",
    "scristianizzasser": "scristianizzare",
    "scristianizzassero": "scristianizzare",
    "scristianizzassi": "scristianizzare",
    "scristianizzassimo": "scristianizzare",
    "scristianizzaste": "scristianizzare",
    "scristianizzasti": "scristianizzare",
    "scristianizzata": "scristianizzare",
    "scristianizzate": "scristianizzare",
    "scristianizzati": "scristianizzare",
    "scristianizzato": "scristianizzare",
    "scristianizzava": "scristianizzare",
    "scristianizzavamo": "scristianizzare",
    "scristianizzavan": "scristianizzare",
    "scristianizzavano": "scristianizzare",
    "scristianizzavate": "scristianizzare",
    "scristianizzavi": "scristianizzare",
    "scristianizzavo": "scristianizzare",
    "scristianizzazioni": "scristianizzazione",
    "scristianizzerai": "scristianizzare",
    "scristianizzeran": "scristianizzare",
    "scristianizzeranno": "scristianizzare",
    "scristianizzerebbe": "scristianizzare",
    "scristianizzerebber": "scristianizzare",
    "scristianizzerebbero": "scristianizzare",
    "scristianizzerei": "scristianizzare",
    "scristianizzeremmo": "scristianizzare",
    "scristianizzeremo": "scristianizzare",
    "scristianizzereste": "scristianizzare",
    "scristianizzeresti": "scristianizzare",
    "scristianizzerete": "scristianizzare",
    "scristianizzerà": "scristianizzare",
    "scristianizzerò": "scristianizzare",
    "scristianizzi": "scristianizzare",
    "scristianizziamo": "scristianizzare",
    "scristianizziate": "scristianizzare",
    "scristianizzin": "scristianizzare",
    "scristianizzino": "scristianizzare",
    "scristianizzo": "scristianizzare",
    "scristianizzò": "scristianizzare",
    "scriteriata": "scriteriato",
    "scriteriate": "scriteriato",
    "scriteriati": "scriteriato",
    "scritta": "scrivere",
    "scritte": "scrivere",
    "scritti": "scrivere",
    "scritto": "scrivere",
    "scrittoi": "scrittoio",
    "scrittori": "scrittorio",
    "scrittoria": "scrittorio",
    "scrittorie": "scrittorio",
    "scrittrice": "scrittore",
    "scrittrici": "scrittrice",
    "scrittura": "scritturare",
    "scritturai": "scritturare",
    "scritturammo": "scritturare",
    "scritturan": "scritturare",
    "scritturando": "scritturare",
    "scritturano": "scritturare",
    "scritturante": "scritturare",
    "scritturanti": "scritturare",
    "scritturar": "scritturare",
    "scritturaron": "scritturare",
    "scritturarono": "scritturare",
    "scritturasse": "scritturare",
    "scritturasser": "scritturare",
    "scritturassero": "scritturare",
    "scritturassi": "scritturare",
    "scritturassimo": "scritturare",
    "scritturaste": "scritturare",
    "scritturasti": "scritturare",
    "scritturata": "scritturare",
    "scritturate": "scritturare",
    "scritturati": "scritturare",
    "scritturato": "scritturare",
    "scritturava": "scritturare",
    "scritturavamo": "scritturare",
    "scritturavan": "scritturare",
    "scritturavano": "scritturare",
    "scritturavate": "scritturare",
    "scritturavi": "scritturare",
    "scritturavo": "scritturare",
    "scritture": "scrittura",
    "scritturerai": "scritturare",
    "scrittureran": "scritturare",
    "scrittureranno": "scritturare",
    "scritturerebbe": "scritturare",
    "scritturerebber": "scritturare",
    "scritturerebbero": "scritturare",
    "scritturerei": "scritturare",
    "scrittureremmo": "scritturare",
    "scrittureremo": "scritturare",
    "scritturereste": "scritturare",
    "scrittureresti": "scritturare",
    "scritturerete": "scritturare",
    "scritturerà": "scritturare",
    "scritturerò": "scritturare",
    "scritturi": "scritturare",
    "scritturiamo": "scritturare",
    "scritturiate": "scritturare",
    "scritturin": "scritturare",
    "scritturino": "scritturare",
    "scritturo": "scritturare",
    "scritturò": "scritturare",
    "scriva": "scrivere",
    "scrivan": "scrivere",
    "scrivani": "scrivano",
    "scrivanie": "scrivania",
    "scrivano": "scrivere",
    "scrive": "scrivere",
    "scrivemmo": "scrivere",
    "scrivendo": "scrivere",
    "scrivente": "scrivere",
    "scriventi": "scrivere",
    "scriver": "scrivere",
    "scriverai": "scrivere",
    "scriveran": "scrivere",
    "scriveranno": "scrivere",
    "scriverebbe": "scrivere",
    "scriverebber": "scrivere",
    "scriverebbero": "scrivere",
    "scriverei": "scrivere",
    "scriveremmo": "scrivere",
    "scriveremo": "scrivere",
    "scrivereste": "scrivere",
    "scriveresti": "scrivere",
    "scriverete": "scrivere",
    "scriverà": "scrivere",
    "scriverò": "scrivere",
    "scrivesse": "scrivere",
    "scrivesser": "scrivere",
    "scrivessero": "scrivere",
    "scrivessi": "scrivere",
    "scrivessimo": "scrivere",
    "scriveste": "scrivere",
    "scrivesti": "scrivere",
    "scrivete": "scrivere",
    "scriveva": "scrivere",
    "scrivevamo": "scrivere",
    "scrivevan": "scrivere",
    "scrivevano": "scrivere",
    "scrivevate": "scrivere",
    "scrivevi": "scrivere",
    "scrivevo": "scrivere",
    "scrivi": "scrivere",
    "scriviamo": "scrivere",
    "scriviate": "scrivere",
    "scrivo": "scrivere",
    "scrivon": "scrivere",
    "scrivono": "scrivere",
    "scrocca": "scroccare",
    "scroccai": "scroccare",
    "scroccammo": "scroccare",
    "scroccan": "scroccare",
    "scroccando": "scroccare",
    "scroccano": "scroccare",
    "scroccante": "scroccare",
    "scroccanti": "scroccare",
    "scroccar": "scroccare",
    "scroccaron": "scroccare",
    "scroccarono": "scroccare",
    "scroccasse": "scroccare",
    "scroccasser": "scroccare",
    "scroccassero": "scroccare",
    "scroccassi": "scroccare",
    "scroccassimo": "scroccare",
    "scroccaste": "scroccare",
    "scroccasti": "scroccare",
    "scroccata": "scroccare",
    "scroccate": "scroccare",
    "scroccati": "scroccare",
    "scroccato": "scroccare",
    "scroccava": "scroccare",
    "scroccavamo": "scroccare",
    "scroccavan": "scroccare",
    "scroccavano": "scroccare",
    "scroccavate": "scroccare",
    "scroccavi": "scroccare",
    "scroccavo": "scroccare",
    "scroccherai": "scroccare",
    "scroccheran": "scroccare",
    "scroccheranno": "scroccare",
    "scroccherebbe": "scroccare",
    "scroccherebber": "scroccare",
    "scroccherebbero": "scroccare",
    "scroccherei": "scroccare",
    "scroccheremmo": "scroccare",
    "scroccheremo": "scroccare",
    "scrocchereste": "scroccare",
    "scroccheresti": "scroccare",
    "scroccherete": "scroccare",
    "scroccherà": "scroccare",
    "scroccherò": "scroccare",
    "scrocchi": "scroccare",
    "scrocchiamo": "scroccare",
    "scrocchiate": "scroccare",
    "scrocchin": "scroccare",
    "scrocchino": "scroccare",
    "scrocco": "scroccare",
    "scroccò": "scroccare",
    "scrolla": "scrollare",
    "scrollai": "scrollare",
    "scrollammo": "scrollare",
    "scrollan": "scrollare",
    "scrollando": "scrollare",
    "scrollano": "scrollare",
    "scrollante": "scrollare",
    "scrollanti": "scrollare",
    "scrollar": "scrollare",
    "scrollaron": "scrollare",
    "scrollarono": "scrollare",
    "scrollasse": "scrollare",
    "scrollasser": "scrollare",
    "scrollassero": "scrollare",
    "scrollassi": "scrollare",
    "scrollassimo": "scrollare",
    "scrollaste": "scrollare",
    "scrollasti": "scrollare",
    "scrollata": "scrollare",
    "scrollate": "scrollata",
    "scrollati": "scrollare",
    "scrollato": "scrollare",
    "scrollava": "scrollare",
    "scrollavamo": "scrollare",
    "scrollavan": "scrollare",
    "scrollavano": "scrollare",
    "scrollavate": "scrollare",
    "scrollavi": "scrollare",
    "scrollavo": "scrollare",
    "scrollerai": "scrollare",
    "scrolleran": "scrollare",
    "scrolleranno": "scrollare",
    "scrollerebbe": "scrollare",
    "scrollerebber": "scrollare",
    "scrollerebbero": "scrollare",
    "scrollerei": "scrollare",
    "scrolleremmo": "scrollare",
    "scrolleremo": "scrollare",
    "scrollereste": "scrollare",
    "scrolleresti": "scrollare",
    "scrollerete": "scrollare",
    "scrollerà": "scrollare",
    "scrollerò": "scrollare",
    "scrolli": "scrollare",
    "scrolliamo": "scrollare",
    "scrolliate": "scrollare",
    "scrollin": "scrollare",
    "scrollino": "scrollare",
    "scrollo": "scrollare",
    "scrolloni": "scrollone",
    "scrollò": "scrollare",
    "scroscerai": "scrosciare",
    "scrosceran": "scrosciare",
    "scrosceranno": "scrosciare",
    "scroscerebbe": "scrosciare",
    "scroscerebber": "scrosciare",
    "scroscerebbero": "scrosciare",
    "scroscerei": "scrosciare",
    "scrosceremmo": "scrosciare",
    "scrosceremo": "scrosciare",
    "scroscereste": "scrosciare",
    "scrosceresti": "scrosciare",
    "scroscerete": "scrosciare",
    "scroscerà": "scrosciare",
    "scroscerò": "scrosciare",
    "scrosci": "scroscio",
    "scroscia": "scrosciare",
    "scrosciai": "scrosciare",
    "scrosciammo": "scrosciare",
    "scrosciamo": "scrosciare",
    "scroscian": "scrosciare",
    "scrosciando": "scrosciare",
    "scrosciano": "scrosciare",
    "scrosciante": "scrosciare",
    "scroscianti": "scrosciare",
    "scrosciar": "scrosciare",
    "scrosciaron": "scrosciare",
    "scrosciarono": "scrosciare",
    "scrosciasse": "scrosciare",
    "scrosciasser": "scrosciare",
    "scrosciassero": "scrosciare",
    "scrosciassi": "scrosciare",
    "scrosciassimo": "scrosciare",
    "scrosciaste": "scrosciare",
    "scrosciasti": "scrosciare",
    "scrosciata": "scrosciare",
    "scrosciate": "scrosciare",
    "scrosciati": "scrosciare",
    "scrosciato": "scrosciare",
    "scrosciava": "scrosciare",
    "scrosciavamo": "scrosciare",
    "scrosciavan": "scrosciare",
    "scrosciavano": "scrosciare",
    "scrosciavate": "scrosciare",
    "scrosciavi": "scrosciare",
    "scrosciavo": "scrosciare",
    "scroscin": "scrosciare",
    "scroscino": "scrosciare",
    "scroscio": "scrosciare",
    "scrosciò": "scrosciare",
    "scrosta": "scrostare",
    "scrostai": "scrostare",
    "scrostammo": "scrostare",
    "scrostan": "scrostare",
    "scrostando": "scrostare",
    "scrostano": "scrostare",
    "scrostante": "scrostare",
    "scrostanti": "scrostare",
    "scrostar": "scrostare",
    "scrostaron": "scrostare",
    "scrostarono": "scrostare",
    "scrostasse": "scrostare",
    "scrostasser": "scrostare",
    "scrostassero": "scrostare",
    "scrostassi": "scrostare",
    "scrostassimo": "scrostare",
    "scrostaste": "scrostare",
    "scrostasti": "scrostare",
    "scrostata": "scrostare",
    "scrostate": "scrostare",
    "scrostati": "scrostare",
    "scrostato": "scrostare",
    "scrostava": "scrostare",
    "scrostavamo": "scrostare",
    "scrostavan": "scrostare",
    "scrostavano": "scrostare",
    "scrostavate": "scrostare",
    "scrostavi": "scrostare",
    "scrostavo": "scrostare",
    "scrosterai": "scrostare",
    "scrosteran": "scrostare",
    "scrosteranno": "scrostare",
    "scrosterebbe": "scrostare",
    "scrosterebber": "scrostare",
    "scrosterebbero": "scrostare",
    "scrosterei": "scrostare",
    "scrosteremmo": "scrostare",
    "scrosteremo": "scrostare",
    "scrostereste": "scrostare",
    "scrosteresti": "scrostare",
    "scrosterete": "scrostare",
    "scrosterà": "scrostare",
    "scrosterò": "scrostare",
    "scrosti": "scrostare",
    "scrostiamo": "scrostare",
    "scrostiate": "scrostare",
    "scrostin": "scrostare",
    "scrostino": "scrostare",
    "scrosto": "scrostare",
    "scrostò": "scrostare",
    "scrupoli": "scrupolo",
    "scrupolosa": "scrupoloso",
    "scrupolose": "scrupoloso",
    "scrupolosi": "scrupoloso",
    "scruta": "scrutare",
    "scrutai": "scrutare",
    "scrutammo": "scrutare",
    "scrutan": "scrutare",
    "scrutando": "scrutare",
    "scrutano": "scrutare",
    "scrutante": "scrutare",
    "scrutanti": "scrutare",
    "scrutar": "scrutare",
    "scrutaron": "scrutare",
    "scrutarono": "scrutare",
    "scrutasse": "scrutare",
    "scrutasser": "scrutare",
    "scrutassero": "scrutare",
    "scrutassi": "scrutare",
    "scrutassimo": "scrutare",
    "scrutaste": "scrutare",
    "scrutasti": "scrutare",
    "scrutata": "scrutare",
    "scrutate": "scrutare",
    "scrutati": "scrutare",
    "scrutato": "scrutare",
    "scrutatori": "scrutatore",
    "scrutava": "scrutare",
    "scrutavamo": "scrutare",
    "scrutavan": "scrutare",
    "scrutavano": "scrutare",
    "scrutavate": "scrutare",
    "scrutavi": "scrutare",
    "scrutavo": "scrutare",
    "scruterai": "scrutare",
    "scruteran": "scrutare",
    "scruteranno": "scrutare",
    "scruterebbe": "scrutare",
    "scruterebber": "scrutare",
    "scruterebbero": "scrutare",
    "scruterei": "scrutare",
    "scruteremmo": "scrutare",
    "scruteremo": "scrutare",
    "scrutereste": "scrutare",
    "scruteresti": "scrutare",
    "scruterete": "scrutare",
    "scruterà": "scrutare",
    "scruterò": "scrutare",
    "scruti": "scrutare",
    "scrutiamo": "scrutare",
    "scrutiate": "scrutare",
    "scrutin": "scrutare",
    "scrutina": "scrutinare",
    "scrutinai": "scrutinare",
    "scrutinammo": "scrutinare",
    "scrutinan": "scrutinare",
    "scrutinando": "scrutinare",
    "scrutinano": "scrutinare",
    "scrutinante": "scrutinare",
    "scrutinanti": "scrutinare",
    "scrutinar": "scrutinare",
    "scrutinaron": "scrutinare",
    "scrutinarono": "scrutinare",
    "scrutinasse": "scrutinare",
    "scrutinasser": "scrutinare",
    "scrutinassero": "scrutinare",
    "scrutinassi": "scrutinare",
    "scrutinassimo": "scrutinare",
    "scrutinaste": "scrutinare",
    "scrutinasti": "scrutinare",
    "scrutinata": "scrutinare",
    "scrutinate": "scrutinare",
    "scrutinati": "scrutinare",
    "scrutinato": "scrutinare",
    "scrutinava": "scrutinare",
    "scrutinavamo": "scrutinare",
    "scrutinavan": "scrutinare",
    "scrutinavano": "scrutinare",
    "scrutinavate": "scrutinare",
    "scrutinavi": "scrutinare",
    "scrutinavo": "scrutinare",
    "scrutinerai": "scrutinare",
    "scrutineran": "scrutinare",
    "scrutineranno": "scrutinare",
    "scrutinerebbe": "scrutinare",
    "scrutinerebber": "scrutinare",
    "scrutinerebbero": "scrutinare",
    "scrutinerei": "scrutinare",
    "scrutineremmo": "scrutinare",
    "scrutineremo": "scrutinare",
    "scrutinereste": "scrutinare",
    "scrutineresti": "scrutinare",
    "scrutinerete": "scrutinare",
    "scrutinerà": "scrutinare",
    "scrutinerò": "scrutinare",
    "scrutini": "scrutinio",
    "scrutiniamo": "scrutinare",
    "scrutiniate": "scrutinare",
    "scrutinii": "scrutinio",
    "scrutinin": "scrutinare",
    "scrutinino": "scrutinare",
    "scrutino": "scrutinare",
    "scrutinò": "scrutinare",
    "scruto": "scrutare",
    "scrutò": "scrutare",
    "scuca": "scucire",
    "scucan": "scucire",
    "scucano": "scucire",
    "scuce": "scucire",
    "scucendo": "scucire",
    "scucente": "scucire",
    "scucenti": "scucire",
    "scuci": "scucire",
    "scuciamo": "scucire",
    "scuciate": "scucire",
    "scucii": "scucire",
    "scucimmo": "scucire",
    "scucir": "scucire",
    "scucirai": "scucire",
    "scuciran": "scucire",
    "scuciranno": "scucire",
    "scucirebbe": "scucire",
    "scucirebber": "scucire",
    "scucirebbero": "scucire",
    "scucirei": "scucire",
    "scuciremmo": "scucire",
    "scuciremo": "scucire",
    "scucireste": "scucire",
    "scuciresti": "scucire",
    "scucirete": "scucire",
    "scuciron": "scucire",
    "scucirono": "scucire",
    "scucirà": "scucire",
    "scucirò": "scucire",
    "scucisse": "scucire",
    "scucisser": "scucire",
    "scucissero": "scucire",
    "scucissi": "scucire",
    "scucissimo": "scucire",
    "scuciste": "scucire",
    "scucisti": "scucire",
    "scucita": "scucire",
    "scucite": "scucire",
    "scuciti": "scucire",
    "scucito": "scucire",
    "scuciva": "scucire",
    "scucivamo": "scucire",
    "scucivan": "scucire",
    "scucivano": "scucire",
    "scucivate": "scucire",
    "scucivi": "scucire",
    "scucivo": "scucire",
    "scuco": "scucire",
    "scucon": "scucire",
    "scucono": "scucire",
    "scucì": "scucire",
    "scuderie": "scuderia",
    "scudetti": "scudetto",
    "scudi": "scudo",
    "scudicrociati": "scudocrociato",
    "scudieri": "scudiero",
    "scudiscerai": "scudisciare",
    "scudisceran": "scudisciare",
    "scudisceranno": "scudisciare",
    "scudiscerebbe": "scudisciare",
    "scudiscerebber": "scudisciare",
    "scudiscerebbero": "scudisciare",
    "scudiscerei": "scudisciare",
    "scudisceremmo": "scudisciare",
    "scudisceremo": "scudisciare",
    "scudiscereste": "scudisciare",
    "scudisceresti": "scudisciare",
    "scudiscerete": "scudisciare",
    "scudiscerà": "scudisciare",
    "scudiscerò": "scudisciare",
    "scudisci": "scudisciare",
    "scudiscia": "scudisciare",
    "scudisciai": "scudisciare",
    "scudisciammo": "scudisciare",
    "scudisciamo": "scudisciare",
    "scudiscian": "scudisciare",
    "scudisciando": "scudisciare",
    "scudisciano": "scudisciare",
    "scudisciante": "scudisciare",
    "scudiscianti": "scudisciare",
    "scudisciar": "scudisciare",
    "scudisciaron": "scudisciare",
    "scudisciarono": "scudisciare",
    "scudisciasse": "scudisciare",
    "scudisciasser": "scudisciare",
    "scudisciassero": "scudisciare",
    "scudisciassi": "scudisciare",
    "scudisciassimo": "scudisciare",
    "scudisciaste": "scudisciare",
    "scudisciasti": "scudisciare",
    "scudisciata": "scudisciare",
    "scudisciate": "scudisciare",
    "scudisciati": "scudisciare",
    "scudisciato": "scudisciare",
    "scudisciava": "scudisciare",
    "scudisciavamo": "scudisciare",
    "scudisciavan": "scudisciare",
    "scudisciavano": "scudisciare",
    "scudisciavate": "scudisciare",
    "scudisciavi": "scudisciare",
    "scudisciavo": "scudisciare",
    "scudiscin": "scudisciare",
    "scudiscino": "scudisciare",
    "scudiscio": "scudisciare",
    "scudisciò": "scudisciare",
    "scugnizzi": "scugnizzo",
    "sculaccerai": "sculacciare",
    "sculacceran": "sculacciare",
    "sculacceranno": "sculacciare",
    "sculaccerebbe": "sculacciare",
    "sculaccerebber": "sculacciare",
    "sculaccerebbero": "sculacciare",
    "sculaccerei": "sculacciare",
    "sculacceremmo": "sculacciare",
    "sculacceremo": "sculacciare",
    "sculaccereste": "sculacciare",
    "sculacceresti": "sculacciare",
    "sculaccerete": "sculacciare",
    "sculaccerà": "sculacciare",
    "sculaccerò": "sculacciare",
    "sculacci": "sculacciare",
    "sculaccia": "sculacciare",
    "sculacciai": "sculacciare",
    "sculacciammo": "sculacciare",
    "sculacciamo": "sculacciare",
    "sculaccian": "sculacciare",
    "sculacciando": "sculacciare",
    "sculacciano": "sculacciare",
    "sculacciante": "sculacciare",
    "sculaccianti": "sculacciare",
    "sculacciar": "sculacciare",
    "sculacciaron": "sculacciare",
    "sculacciarono": "sculacciare",
    "sculacciasse": "sculacciare",
    "sculacciasser": "sculacciare",
    "sculacciassero": "sculacciare",
    "sculacciassi": "sculacciare",
    "sculacciassimo": "sculacciare",
    "sculacciaste": "sculacciare",
    "sculacciasti": "sculacciare",
    "sculacciata": "sculacciare",
    "sculacciate": "sculacciata",
    "sculacciati": "sculacciare",
    "sculacciato": "sculacciare",
    "sculacciava": "sculacciare",
    "sculacciavamo": "sculacciare",
    "sculacciavan": "sculacciare",
    "sculacciavano": "sculacciare",
    "sculacciavate": "sculacciare",
    "sculacciavi": "sculacciare",
    "sculacciavo": "sculacciare",
    "sculaccin": "sculacciare",
    "sculaccino": "sculacciare",
    "sculaccio": "sculacciare",
    "sculacciò": "sculacciare",
    "sculetta": "sculettare",
    "sculettai": "sculettare",
    "sculettammo": "sculettare",
    "sculettan": "sculettare",
    "sculettando": "sculettare",
    "sculettano": "sculettare",
    "sculettante": "sculettare",
    "sculettanti": "sculettare",
    "sculettar": "sculettare",
    "sculettaron": "sculettare",
    "sculettarono": "sculettare",
    "sculettasse": "sculettare",
    "sculettasser": "sculettare",
    "sculettassero": "sculettare",
    "sculettassi": "sculettare",
    "sculettassimo": "sculettare",
    "sculettaste": "sculettare",
    "sculettasti": "sculettare",
    "sculettata": "sculettare",
    "sculettate": "sculettare",
    "sculettati": "sculettare",
    "sculettato": "sculettare",
    "sculettava": "sculettare",
    "sculettavamo": "sculettare",
    "sculettavan": "sculettare",
    "sculettavano": "sculettare",
    "sculettavate": "sculettare",
    "sculettavi": "sculettare",
    "sculettavo": "sculettare",
    "sculetterai": "sculettare",
    "sculetteran": "sculettare",
    "sculetteranno": "sculettare",
    "sculetterebbe": "sculettare",
    "sculetterebber": "sculettare",
    "sculetterebbero": "sculettare",
    "sculetterei": "sculettare",
    "sculetteremmo": "sculettare",
    "sculetteremo": "sculettare",
    "sculettereste": "sculettare",
    "sculetteresti": "sculettare",
    "sculetterete": "sculettare",
    "sculetterà": "sculettare",
    "sculetterò": "sculettare",
    "sculetti": "sculettare",
    "sculettiamo": "sculettare",
    "sculettiate": "sculettare",
    "sculettin": "sculettare",
    "sculettino": "sculettare",
    "sculetto": "sculettare",
    "sculettò": "sculettare",
    "scultorea": "scultoreo",
    "scultoree": "scultoreo",
    "scultorei": "scultoreo",
    "scultori": "scultorio",
    "scultoria": "scultorio",
    "scultorie": "scultorio",
    "scultrice": "scultore",
    "scultrici": "scultrice",
    "sculture": "scultura",
    "scuoca": "scuocere",
    "scuocan": "scuocere",
    "scuocano": "scuocere",
    "scuoce": "scuocere",
    "scuocei": "scuocere",
    "scuocemmo": "scuocere",
    "scuocendo": "scuocere",
    "scuocente": "scuocere",
    "scuocenti": "scuocere",
    "scuocer": "scuocere",
    "scuocerai": "scuocere",
    "scuoceran": "scuocere",
    "scuoceranno": "scuocere",
    "scuocerebbe": "scuocere",
    "scuocerebber": "scuocere",
    "scuocerebbero": "scuocere",
    "scuocerei": "scuocere",
    "scuoceremmo": "scuocere",
    "scuoceremo": "scuocere",
    "scuocereste": "scuocere",
    "scuoceresti": "scuocere",
    "scuocerete": "scuocere",
    "scuoceron": "scuocere",
    "scuocerono": "scuocere",
    "scuocerà": "scuocere",
    "scuocerò": "scuocere",
    "scuocesse": "scuocere",
    "scuocesser": "scuocere",
    "scuocessero": "scuocere",
    "scuocessi": "scuocere",
    "scuocessimo": "scuocere",
    "scuoceste": "scuocere",
    "scuocesti": "scuocere",
    "scuocete": "scuocere",
    "scuoceva": "scuocere",
    "scuocevamo": "scuocere",
    "scuocevan": "scuocere",
    "scuocevano": "scuocere",
    "scuocevate": "scuocere",
    "scuocevi": "scuocere",
    "scuocevo": "scuocere",
    "scuoci": "scuocere",
    "scuociamo": "scuocere",
    "scuociate": "scuocere",
    "scuociuta": "scuocere",
    "scuociute": "scuocere",
    "scuociuti": "scuocere",
    "scuociuto": "scuocere",
    "scuoco": "scuocere",
    "scuocon": "scuocere",
    "scuocono": "scuocere",
    "scuocè": "scuocere",
    "scuoi": "scuoiare",
    "scuoia": "scuoiare",
    "scuoiai": "scuoiare",
    "scuoiammo": "scuoiare",
    "scuoiamo": "scuoiare",
    "scuoian": "scuoiare",
    "scuoiando": "scuoiare",
    "scuoiano": "scuoiare",
    "scuoiante": "scuoiare",
    "scuoianti": "scuoiare",
    "scuoiar": "scuoiare",
    "scuoiaron": "scuoiare",
    "scuoiarono": "scuoiare",
    "scuoiasse": "scuoiare",
    "scuoiasser": "scuoiare",
    "scuoiassero": "scuoiare",
    "scuoiassi": "scuoiare",
    "scuoiassimo": "scuoiare",
    "scuoiaste": "scuoiare",
    "scuoiasti": "scuoiare",
    "scuoiata": "scuoiare",
    "scuoiate": "scuoiare",
    "scuoiati": "scuoiare",
    "scuoiato": "scuoiare",
    "scuoiava": "scuoiare",
    "scuoiavamo": "scuoiare",
    "scuoiavan": "scuoiare",
    "scuoiavano": "scuoiare",
    "scuoiavate": "scuoiare",
    "scuoiavi": "scuoiare",
    "scuoiavo": "scuoiare",
    "scuoierai": "scuoiare",
    "scuoieran": "scuoiare",
    "scuoieranno": "scuoiare",
    "scuoierebbe": "scuoiare",
    "scuoierebber": "scuoiare",
    "scuoierebbero": "scuoiare",
    "scuoierei": "scuoiare",
    "scuoieremmo": "scuoiare",
    "scuoieremo": "scuoiare",
    "scuoiereste": "scuoiare",
    "scuoieresti": "scuoiare",
    "scuoierete": "scuoiare",
    "scuoierà": "scuoiare",
    "scuoierò": "scuoiare",
    "scuoin": "scuoiare",
    "scuoino": "scuoiare",
    "scuoio": "scuoiare",
    "scuoiò": "scuoiare",
    "scuole": "scuola",
    "scuota": "scuotere",
    "scuotan": "scuotere",
    "scuotano": "scuotere",
    "scuote": "scuotere",
    "scuotemmo": "scuotere",
    "scuoter": "scuotere",
    "scuoterai": "scuotere",
    "scuoteran": "scuotere",
    "scuoteranno": "scuotere",
    "scuoterebbe": "scuotere",
    "scuoterebber": "scuotere",
    "scuoterebbero": "scuotere",
    "scuoterei": "scuotere",
    "scuoteremmo": "scuotere",
    "scuoteremo": "scuotere",
    "scuotereste": "scuotere",
    "scuoteresti": "scuotere",
    "scuoterete": "scuotere",
    "scuoterà": "scuotere",
    "scuoterò": "scuotere",
    "scuotesse": "scuotere",
    "scuotessero": "scuotere",
    "scuotessi": "scuotere",
    "scuotessimo": "scuotere",
    "scuoteste": "scuotere",
    "scuotesti": "scuotere",
    "scuoteva": "scuotere",
    "scuotevamo": "scuotere",
    "scuotevano": "scuotere",
    "scuotevate": "scuotere",
    "scuotevi": "scuotere",
    "scuotevo": "scuotere",
    "scuoti": "scuotere",
    "scuotiamo": "scuotere",
    "scuotiate": "scuotere",
    "scuotimenti": "scuotimento",
    "scuoto": "scuotere",
    "scuoton": "scuotere",
    "scuotono": "scuotere",
    "scura": "scuro",
    "scuran": "scurire",
    "scurano": "scurire",
    "scure": "scuro",
    "scurendo": "scurire",
    "scurente": "scurire",
    "scurenti": "scurire",
    "scuri": "scuro",
    "scuriamo": "scurire",
    "scuriate": "scurire",
    "scurii": "scurire",
    "scurimmo": "scurire",
    "scurir": "scurire",
    "scurirai": "scurire",
    "scuriran": "scurire",
    "scuriranno": "scurire",
    "scurirebbe": "scurire",
    "scurirebber": "scurire",
    "scurirebbero": "scurire",
    "scurirei": "scurire",
    "scuriremmo": "scurire",
    "scuriremo": "scurire",
    "scurireste": "scurire",
    "scuriresti": "scurire",
    "scurirete": "scurire",
    "scuriron": "scurire",
    "scurirono": "scurire",
    "scurirà": "scurire",
    "scurirò": "scurire",
    "scurisse": "scurire",
    "scurisser": "scurire",
    "scurissero": "scurire",
    "scurissi": "scurire",
    "scurissimo": "scurire",
    "scuriste": "scurire",
    "scuristi": "scurire",
    "scurita": "scurire",
    "scurite": "scurire",
    "scuriti": "scurire",
    "scurito": "scurire",
    "scuriva": "scurire",
    "scurivamo": "scurire",
    "scurivan": "scurire",
    "scurivano": "scurire",
    "scurivate": "scurire",
    "scurivi": "scurire",
    "scurivo": "scurire",
    "scuro": "scurire",
    "scuron": "scurire",
    "scurono": "scurire",
    "scurrili": "scurrile",
    "scurì": "scurire",
    "scusa": "scusare",
    "scusabili": "scusabile",
    "scusai": "scusare",
    "scusammo": "scusare",
    "scusan": "scusare",
    "scusando": "scusare",
    "scusano": "scusare",
    "scusante": "scusare",
    "scusanti": "scusare",
    "scusar": "scusare",
    "scusaron": "scusare",
    "scusarono": "scusare",
    "scusasse": "scusare",
    "scusasser": "scusare",
    "scusassero": "scusare",
    "scusassi": "scusare",
    "scusassimo": "scusare",
    "scusaste": "scusare",
    "scusasti": "scusare",
    "scusata": "scusare",
    "scusate": "scusare",
    "scusati": "scusare",
    "scusato": "scusare",
    "scusava": "scusare",
    "scusavamo": "scusare",
    "scusavan": "scusare",
    "scusavano": "scusare",
    "scusavate": "scusare",
    "scusavi": "scusare",
    "scusavo": "scusare",
    "scuse": "scusa",
    "scuserai": "scusare",
    "scuseran": "scusare",
    "scuseranno": "scusare",
    "scuserebbe": "scusare",
    "scuserebber": "scusare",
    "scuserebbero": "scusare",
    "scuserei": "scusare",
    "scuseremmo": "scusare",
    "scuseremo": "scusare",
    "scusereste": "scusare",
    "scuseresti": "scusare",
    "scuserete": "scusare",
    "scuserà": "scusare",
    "scuserò": "scusare",
    "scusi": "scusare",
    "scusiamo": "scusare",
    "scusiate": "scusare",
    "scusin": "scusare",
    "scusino": "scusare",
    "scuso": "scusare",
    "scusò": "scusare",
    "sdebita": "sdebitare",
    "sdebitai": "sdebitare",
    "sdebitammo": "sdebitare",
    "sdebitan": "sdebitare",
    "sdebitando": "sdebitare",
    "sdebitano": "sdebitare",
    "sdebitante": "sdebitare",
    "sdebitanti": "sdebitare",
    "sdebitar": "sdebitare",
    "sdebitaron": "sdebitare",
    "sdebitarono": "sdebitare",
    "sdebitasse": "sdebitare",
    "sdebitasser": "sdebitare",
    "sdebitassero": "sdebitare",
    "sdebitassi": "sdebitare",
    "sdebitassimo": "sdebitare",
    "sdebitaste": "sdebitare",
    "sdebitasti": "sdebitare",
    "sdebitata": "sdebitare",
    "sdebitate": "sdebitare",
    "sdebitati": "sdebitare",
    "sdebitato": "sdebitare",
    "sdebitava": "sdebitare",
    "sdebitavamo": "sdebitare",
    "sdebitavan": "sdebitare",
    "sdebitavano": "sdebitare",
    "sdebitavate": "sdebitare",
    "sdebitavi": "sdebitare",
    "sdebitavo": "sdebitare",
    "sdebiterai": "sdebitare",
    "sdebiteran": "sdebitare",
    "sdebiteranno": "sdebitare",
    "sdebiterebbe": "sdebitare",
    "sdebiterebber": "sdebitare",
    "sdebiterebbero": "sdebitare",
    "sdebiterei": "sdebitare",
    "sdebiteremmo": "sdebitare",
    "sdebiteremo": "sdebitare",
    "sdebitereste": "sdebitare",
    "sdebiteresti": "sdebitare",
    "sdebiterete": "sdebitare",
    "sdebiterà": "sdebitare",
    "sdebiterò": "sdebitare",
    "sdebiti": "sdebitare",
    "sdebitiamo": "sdebitare",
    "sdebitiate": "sdebitare",
    "sdebitin": "sdebitare",
    "sdebitino": "sdebitare",
    "sdebito": "sdebitare",
    "sdebitò": "sdebitare",
    "sdegna": "sdegnare",
    "sdegnai": "sdegnare",
    "sdegnammo": "sdegnare",
    "sdegnan": "sdegnare",
    "sdegnando": "sdegnare",
    "sdegnano": "sdegnare",
    "sdegnante": "sdegnare",
    "sdegnanti": "sdegnare",
    "sdegnar": "sdegnare",
    "sdegnaron": "sdegnare",
    "sdegnarono": "sdegnare",
    "sdegnasse": "sdegnare",
    "sdegnasser": "sdegnare",
    "sdegnassero": "sdegnare",
    "sdegnassi": "sdegnare",
    "sdegnassimo": "sdegnare",
    "sdegnaste": "sdegnare",
    "sdegnasti": "sdegnare",
    "sdegnata": "sdegnare",
    "sdegnate": "sdegnare",
    "sdegnati": "sdegnare",
    "sdegnato": "sdegnare",
    "sdegnava": "sdegnare",
    "sdegnavamo": "sdegnare",
    "sdegnavan": "sdegnare",
    "sdegnavano": "sdegnare",
    "sdegnavate": "sdegnare",
    "sdegnavi": "sdegnare",
    "sdegnavo": "sdegnare",
    "sdegnerai": "sdegnare",
    "sdegneran": "sdegnare",
    "sdegneranno": "sdegnare",
    "sdegnerebbe": "sdegnare",
    "sdegnerebber": "sdegnare",
    "sdegnerebbero": "sdegnare",
    "sdegnerei": "sdegnare",
    "sdegneremmo": "sdegnare",
    "sdegneremo": "sdegnare",
    "sdegnereste": "sdegnare",
    "sdegneresti": "sdegnare",
    "sdegnerete": "sdegnare",
    "sdegnerà": "sdegnare",
    "sdegnerò": "sdegnare",
    "sdegni": "sdegno",
    "sdegniamo": "sdegnare",
    "sdegniate": "sdegnare",
    "sdegnin": "sdegnare",
    "sdegnino": "sdegnare",
    "sdegno": "sdegnare",
    "sdegnosa": "sdegnoso",
    "sdegnose": "sdegnoso",
    "sdegnosi": "sdegnoso",
    "sdegnò": "sdegnare",
    "sdenta": "sdentare",
    "sdentai": "sdentare",
    "sdentammo": "sdentare",
    "sdentan": "sdentare",
    "sdentando": "sdentare",
    "sdentano": "sdentare",
    "sdentante": "sdentare",
    "sdentanti": "sdentare",
    "sdentar": "sdentare",
    "sdentaron": "sdentare",
    "sdentarono": "sdentare",
    "sdentasse": "sdentare",
    "sdentasser": "sdentare",
    "sdentassero": "sdentare",
    "sdentassi": "sdentare",
    "sdentassimo": "sdentare",
    "sdentaste": "sdentare",
    "sdentasti": "sdentare",
    "sdentata": "sdentato",
    "sdentate": "sdentato",
    "sdentati": "sdentato",
    "sdentato": "sdentare",
    "sdentava": "sdentare",
    "sdentavamo": "sdentare",
    "sdentavan": "sdentare",
    "sdentavano": "sdentare",
    "sdentavate": "sdentare",
    "sdentavi": "sdentare",
    "sdentavo": "sdentare",
    "sdenterai": "sdentare",
    "sdenteran": "sdentare",
    "sdenteranno": "sdentare",
    "sdenterebbe": "sdentare",
    "sdenterebber": "sdentare",
    "sdenterebbero": "sdentare",
    "sdenterei": "sdentare",
    "sdenteremmo": "sdentare",
    "sdenteremo": "sdentare",
    "sdentereste": "sdentare",
    "sdenteresti": "sdentare",
    "sdenterete": "sdentare",
    "sdenterà": "sdentare",
    "sdenterò": "sdentare",
    "sdenti": "sdentare",
    "sdentiamo": "sdentare",
    "sdentiate": "sdentare",
    "sdentin": "sdentare",
    "sdentino": "sdentare",
    "sdento": "sdentare",
    "sdentò": "sdentare",
    "sdilinqua": "sdilinquire",
    "sdilinquan": "sdilinquire",
    "sdilinquano": "sdilinquire",
    "sdilinque": "sdilinquire",
    "sdilinquendo": "sdilinquire",
    "sdilinquente": "sdilinquire",
    "sdilinquenti": "sdilinquire",
    "sdilinqui": "sdilinquire",
    "sdilinquiamo": "sdilinquire",
    "sdilinquiate": "sdilinquire",
    "sdilinquii": "sdilinquire",
    "sdilinquimmo": "sdilinquire",
    "sdilinquir": "sdilinquire",
    "sdilinquirai": "sdilinquire",
    "sdilinquiran": "sdilinquire",
    "sdilinquiranno": "sdilinquire",
    "sdilinquirebbe": "sdilinquire",
    "sdilinquirebber": "sdilinquire",
    "sdilinquirebbero": "sdilinquire",
    "sdilinquirei": "sdilinquire",
    "sdilinquiremmo": "sdilinquire",
    "sdilinquiremo": "sdilinquire",
    "sdilinquireste": "sdilinquire",
    "sdilinquiresti": "sdilinquire",
    "sdilinquirete": "sdilinquire",
    "sdilinquiron": "sdilinquire",
    "sdilinquirono": "sdilinquire",
    "sdilinquirà": "sdilinquire",
    "sdilinquirò": "sdilinquire",
    "sdilinquisse": "sdilinquire",
    "sdilinquisser": "sdilinquire",
    "sdilinquissero": "sdilinquire",
    "sdilinquissi": "sdilinquire",
    "sdilinquissimo": "sdilinquire",
    "sdilinquiste": "sdilinquire",
    "sdilinquisti": "sdilinquire",
    "sdilinquita": "sdilinquire",
    "sdilinquite": "sdilinquire",
    "sdilinquiti": "sdilinquire",
    "sdilinquito": "sdilinquire",
    "sdilinquiva": "sdilinquire",
    "sdilinquivamo": "sdilinquire",
    "sdilinquivan": "sdilinquire",
    "sdilinquivano": "sdilinquire",
    "sdilinquivate": "sdilinquire",
    "sdilinquivi": "sdilinquire",
    "sdilinquivo": "sdilinquire",
    "sdilinquo": "sdilinquire",
    "sdilinquon": "sdilinquire",
    "sdilinquono": "sdilinquire",
    "sdilinquì": "sdilinquire",
    "sdogana": "sdoganare",
    "sdoganai": "sdoganare",
    "sdoganamenti": "sdoganamento",
    "sdoganammo": "sdoganare",
    "sdoganan": "sdoganare",
    "sdoganando": "sdoganare",
    "sdoganano": "sdoganare",
    "sdoganante": "sdoganare",
    "sdogananti": "sdoganare",
    "sdoganar": "sdoganare",
    "sdoganaron": "sdoganare",
    "sdoganarono": "sdoganare",
    "sdoganasse": "sdoganare",
    "sdoganasser": "sdoganare",
    "sdoganassero": "sdoganare",
    "sdoganassi": "sdoganare",
    "sdoganassimo": "sdoganare",
    "sdoganaste": "sdoganare",
    "sdoganasti": "sdoganare",
    "sdoganata": "sdoganare",
    "sdoganate": "sdoganare",
    "sdoganati": "sdoganare",
    "sdoganato": "sdoganare",
    "sdoganava": "sdoganare",
    "sdoganavamo": "sdoganare",
    "sdoganavan": "sdoganare",
    "sdoganavano": "sdoganare",
    "sdoganavate": "sdoganare",
    "sdoganavi": "sdoganare",
    "sdoganavo": "sdoganare",
    "sdoganerai": "sdoganare",
    "sdoganeran": "sdoganare",
    "sdoganeranno": "sdoganare",
    "sdoganerebbe": "sdoganare",
    "sdoganerebber": "sdoganare",
    "sdoganerebbero": "sdoganare",
    "sdoganerei": "sdoganare",
    "sdoganeremmo": "sdoganare",
    "sdoganeremo": "sdoganare",
    "sdoganereste": "sdoganare",
    "sdoganeresti": "sdoganare",
    "sdoganerete": "sdoganare",
    "sdoganerà": "sdoganare",
    "sdoganerò": "sdoganare",
    "sdogani": "sdoganare",
    "sdoganiamo": "sdoganare",
    "sdoganiate": "sdoganare",
    "sdoganin": "sdoganare",
    "sdoganino": "sdoganare",
    "sdogano": "sdoganare",
    "sdoganò": "sdoganare",
    "sdolcinata": "sdolcinato",
    "sdolcinate": "sdolcinato",
    "sdolcinati": "sdolcinato",
    "sdoppi": "sdoppiare",
    "sdoppia": "sdoppiare",
    "sdoppiai": "sdoppiare",
    "sdoppiamenti": "sdoppiamento",
    "sdoppiammo": "sdoppiare",
    "sdoppiamo": "sdoppiare",
    "sdoppian": "sdoppiare",
    "sdoppiando": "sdoppiare",
    "sdoppiano": "sdoppiare",
    "sdoppiante": "sdoppiare",
    "sdoppianti": "sdoppiare",
    "sdoppiar": "sdoppiare",
    "sdoppiaron": "sdoppiare",
    "sdoppiarono": "sdoppiare",
    "sdoppiasse": "sdoppiare",
    "sdoppiasser": "sdoppiare",
    "sdoppiassero": "sdoppiare",
    "sdoppiassi": "sdoppiare",
    "sdoppiassimo": "sdoppiare",
    "sdoppiaste": "sdoppiare",
    "sdoppiasti": "sdoppiare",
    "sdoppiata": "sdoppiare",
    "sdoppiate": "sdoppiare",
    "sdoppiati": "sdoppiare",
    "sdoppiato": "sdoppiare",
    "sdoppiava": "sdoppiare",
    "sdoppiavamo": "sdoppiare",
    "sdoppiavan": "sdoppiare",
    "sdoppiavano": "sdoppiare",
    "sdoppiavate": "sdoppiare",
    "sdoppiavi": "sdoppiare",
    "sdoppiavo": "sdoppiare",
    "sdoppierai": "sdoppiare",
    "sdoppieran": "sdoppiare",
    "sdoppieranno": "sdoppiare",
    "sdoppierebbe": "sdoppiare",
    "sdoppierebber": "sdoppiare",
    "sdoppierebbero": "sdoppiare",
    "sdoppierei": "sdoppiare",
    "sdoppieremmo": "sdoppiare",
    "sdoppieremo": "sdoppiare",
    "sdoppiereste": "sdoppiare",
    "sdoppieresti": "sdoppiare",
    "sdoppierete": "sdoppiare",
    "sdoppierà": "sdoppiare",
    "sdoppierò": "sdoppiare",
    "sdoppin": "sdoppiare",
    "sdoppino": "sdoppiare",
    "sdoppio": "sdoppiare",
    "sdoppiò": "sdoppiare",
    "sdottoreggerai": "sdottoreggiare",
    "sdottoreggeran": "sdottoreggiare",
    "sdottoreggeranno": "sdottoreggiare",
    "sdottoreggerebbe": "sdottoreggiare",
    "sdottoreggerebber": "sdottoreggiare",
    "sdottoreggerebbero": "sdottoreggiare",
    "sdottoreggerei": "sdottoreggiare",
    "sdottoreggeremmo": "sdottoreggiare",
    "sdottoreggeremo": "sdottoreggiare",
    "sdottoreggereste": "sdottoreggiare",
    "sdottoreggeresti": "sdottoreggiare",
    "sdottoreggerete": "sdottoreggiare",
    "sdottoreggerà": "sdottoreggiare",
    "sdottoreggerò": "sdottoreggiare",
    "sdottoreggi": "sdottoreggiare",
    "sdottoreggia": "sdottoreggiare",
    "sdottoreggiai": "sdottoreggiare",
    "sdottoreggiammo": "sdottoreggiare",
    "sdottoreggiamo": "sdottoreggiare",
    "sdottoreggian": "sdottoreggiare",
    "sdottoreggiando": "sdottoreggiare",
    "sdottoreggiano": "sdottoreggiare",
    "sdottoreggiante": "sdottoreggiare",
    "sdottoreggianti": "sdottoreggiare",
    "sdottoreggiar": "sdottoreggiare",
    "sdottoreggiaron": "sdottoreggiare",
    "sdottoreggiarono": "sdottoreggiare",
    "sdottoreggiasse": "sdottoreggiare",
    "sdottoreggiasser": "sdottoreggiare",
    "sdottoreggiassero": "sdottoreggiare",
    "sdottoreggiassi": "sdottoreggiare",
    "sdottoreggiassimo": "sdottoreggiare",
    "sdottoreggiaste": "sdottoreggiare",
    "sdottoreggiasti": "sdottoreggiare",
    "sdottoreggiata": "sdottoreggiare",
    "sdottoreggiate": "sdottoreggiare",
    "sdottoreggiati": "sdottoreggiare",
    "sdottoreggiato": "sdottoreggiare",
    "sdottoreggiava": "sdottoreggiare",
    "sdottoreggiavamo": "sdottoreggiare",
    "sdottoreggiavan": "sdottoreggiare",
    "sdottoreggiavano": "sdottoreggiare",
    "sdottoreggiavate": "sdottoreggiare",
    "sdottoreggiavi": "sdottoreggiare",
    "sdottoreggiavo": "sdottoreggiare",
    "sdottoreggin": "sdottoreggiare",
    "sdottoreggino": "sdottoreggiare",
    "sdottoreggio": "sdottoreggiare",
    "sdottoreggiò": "sdottoreggiare",
    "sdrai": "sdraiare",
    "sdraia": "sdraiare",
    "sdraiai": "sdraiare",
    "sdraiammo": "sdraiare",
    "sdraiamo": "sdraiare",
    "sdraian": "sdraiare",
    "sdraiando": "sdraiare",
    "sdraiano": "sdraiare",
    "sdraiante": "sdraiare",
    "sdraianti": "sdraiare",
    "sdraiar": "sdraiare",
    "sdraiaron": "sdraiare",
    "sdraiarono": "sdraiare",
    "sdraiasse": "sdraiare",
    "sdraiasser": "sdraiare",
    "sdraiassero": "sdraiare",
    "sdraiassi": "sdraiare",
    "sdraiassimo": "sdraiare",
    "sdraiaste": "sdraiare",
    "sdraiasti": "sdraiare",
    "sdraiata": "sdraiato",
    "sdraiate": "sdraiato",
    "sdraiati": "sdraiato",
    "sdraiato": "sdraiare",
    "sdraiava": "sdraiare",
    "sdraiavamo": "sdraiare",
    "sdraiavan": "sdraiare",
    "sdraiavano": "sdraiare",
    "sdraiavate": "sdraiare",
    "sdraiavi": "sdraiare",
    "sdraiavo": "sdraiare",
    "sdraierai": "sdraiare",
    "sdraieran": "sdraiare",
    "sdraieranno": "sdraiare",
    "sdraierebbe": "sdraiare",
    "sdraierebber": "sdraiare",
    "sdraierebbero": "sdraiare",
    "sdraierei": "sdraiare",
    "sdraieremmo": "sdraiare",
    "sdraieremo": "sdraiare",
    "sdraiereste": "sdraiare",
    "sdraieresti": "sdraiare",
    "sdraierete": "sdraiare",
    "sdraierà": "sdraiare",
    "sdraierò": "sdraiare",
    "sdrain": "sdraiare",
    "sdraino": "sdraiare",
    "sdraio": "sdraiare",
    "sdraiò": "sdraiare",
    "sdrammatizza": "sdrammatizzare",
    "sdrammatizzai": "sdrammatizzare",
    "sdrammatizzammo": "sdrammatizzare",
    "sdrammatizzan": "sdrammatizzare",
    "sdrammatizzando": "sdrammatizzare",
    "sdrammatizzano": "sdrammatizzare",
    "sdrammatizzante": "sdrammatizzare",
    "sdrammatizzanti": "sdrammatizzare",
    "sdrammatizzar": "sdrammatizzare",
    "sdrammatizzaron": "sdrammatizzare",
    "sdrammatizzarono": "sdrammatizzare",
    "sdrammatizzasse": "sdrammatizzare",
    "sdrammatizzasser": "sdrammatizzare",
    "sdrammatizzassero": "sdrammatizzare",
    "sdrammatizzassi": "sdrammatizzare",
    "sdrammatizzassimo": "sdrammatizzare",
    "sdrammatizzaste": "sdrammatizzare",
    "sdrammatizzasti": "sdrammatizzare",
    "sdrammatizzata": "sdrammatizzare",
    "sdrammatizzate": "sdrammatizzare",
    "sdrammatizzati": "sdrammatizzare",
    "sdrammatizzato": "sdrammatizzare",
    "sdrammatizzava": "sdrammatizzare",
    "sdrammatizzavamo": "sdrammatizzare",
    "sdrammatizzavan": "sdrammatizzare",
    "sdrammatizzavano": "sdrammatizzare",
    "sdrammatizzavate": "sdrammatizzare",
    "sdrammatizzavi": "sdrammatizzare",
    "sdrammatizzavo": "sdrammatizzare",
    "sdrammatizzazioni": "sdrammatizzazione",
    "sdrammatizzerai": "sdrammatizzare",
    "sdrammatizzeran": "sdrammatizzare",
    "sdrammatizzeranno": "sdrammatizzare",
    "sdrammatizzerebbe": "sdrammatizzare",
    "sdrammatizzerebber": "sdrammatizzare",
    "sdrammatizzerebbero": "sdrammatizzare",
    "sdrammatizzerei": "sdrammatizzare",
    "sdrammatizzeremmo": "sdrammatizzare",
    "sdrammatizzeremo": "sdrammatizzare",
    "sdrammatizzereste": "sdrammatizzare",
    "sdrammatizzeresti": "sdrammatizzare",
    "sdrammatizzerete": "sdrammatizzare",
    "sdrammatizzerà": "sdrammatizzare",
    "sdrammatizzerò": "sdrammatizzare",
    "sdrammatizzi": "sdrammatizzare",
    "sdrammatizziamo": "sdrammatizzare",
    "sdrammatizziate": "sdrammatizzare",
    "sdrammatizzin": "sdrammatizzare",
    "sdrammatizzino": "sdrammatizzare",
    "sdrammatizzo": "sdrammatizzare",
    "sdrammatizzò": "sdrammatizzare",
    "sdruca": "sdrucire",
    "sdrucan": "sdrucire",
    "sdrucano": "sdrucire",
    "sdrucciola": "sdrucciolare",
    "sdrucciolai": "sdrucciolare",
    "sdrucciolammo": "sdrucciolare",
    "sdrucciolan": "sdrucciolare",
    "sdrucciolando": "sdrucciolare",
    "sdrucciolano": "sdrucciolare",
    "sdrucciolante": "sdrucciolare",
    "sdrucciolanti": "sdrucciolare",
    "sdrucciolar": "sdrucciolare",
    "sdrucciolaron": "sdrucciolare",
    "sdrucciolarono": "sdrucciolare",
    "sdrucciolasse": "sdrucciolare",
    "sdrucciolasser": "sdrucciolare",
    "sdrucciolassero": "sdrucciolare",
    "sdrucciolassi": "sdrucciolare",
    "sdrucciolassimo": "sdrucciolare",
    "sdrucciolaste": "sdrucciolare",
    "sdrucciolasti": "sdrucciolare",
    "sdrucciolata": "sdrucciolare",
    "sdrucciolate": "sdrucciolare",
    "sdrucciolati": "sdrucciolare",
    "sdrucciolato": "sdrucciolare",
    "sdrucciolava": "sdrucciolare",
    "sdrucciolavamo": "sdrucciolare",
    "sdrucciolavan": "sdrucciolare",
    "sdrucciolavano": "sdrucciolare",
    "sdrucciolavate": "sdrucciolare",
    "sdrucciolavi": "sdrucciolare",
    "sdrucciolavo": "sdrucciolare",
    "sdrucciolerai": "sdrucciolare",
    "sdruccioleran": "sdrucciolare",
    "sdruccioleranno": "sdrucciolare",
    "sdrucciolerebbe": "sdrucciolare",
    "sdrucciolerebber": "sdrucciolare",
    "sdrucciolerebbero": "sdrucciolare",
    "sdrucciolerei": "sdrucciolare",
    "sdruccioleremmo": "sdrucciolare",
    "sdruccioleremo": "sdrucciolare",
    "sdrucciolereste": "sdrucciolare",
    "sdruccioleresti": "sdrucciolare",
    "sdrucciolerete": "sdrucciolare",
    "sdrucciolerà": "sdrucciolare",
    "sdrucciolerò": "sdrucciolare",
    "sdrucciolevoli": "sdrucciolevole",
    "sdruccioli": "sdrucciolare",
    "sdruccioliamo": "sdrucciolare",
    "sdruccioliate": "sdrucciolare",
    "sdrucciolin": "sdrucciolare",
    "sdrucciolino": "sdrucciolare",
    "sdrucciolo": "sdrucciolare",
    "sdrucciolò": "sdrucciolare",
    "sdruce": "sdrucire",
    "sdrucendo": "sdrucire",
    "sdrucente": "sdrucire",
    "sdrucenti": "sdrucire",
    "sdruci": "sdrucire",
    "sdruciamo": "sdrucire",
    "sdruciate": "sdrucire",
    "sdrucii": "sdrucire",
    "sdrucimmo": "sdrucire",
    "sdrucir": "sdrucire",
    "sdrucirai": "sdrucire",
    "sdruciran": "sdrucire",
    "sdruciranno": "sdrucire",
    "sdrucirebbe": "sdrucire",
    "sdrucirebber": "sdrucire",
    "sdrucirebbero": "sdrucire",
    "sdrucirei": "sdrucire",
    "sdruciremmo": "sdrucire",
    "sdruciremo": "sdrucire",
    "sdrucireste": "sdrucire",
    "sdruciresti": "sdrucire",
    "sdrucirete": "sdrucire",
    "sdruciron": "sdrucire",
    "sdrucirono": "sdrucire",
    "sdrucirà": "sdrucire",
    "sdrucirò": "sdrucire",
    "sdrucisse": "sdrucire",
    "sdrucisser": "sdrucire",
    "sdrucissero": "sdrucire",
    "sdrucissi": "sdrucire",
    "sdrucissimo": "sdrucire",
    "sdruciste": "sdrucire",
    "sdrucisti": "sdrucire",
    "sdrucita": "sdrucire",
    "sdrucite": "sdrucire",
    "sdruciti": "sdrucire",
    "sdrucito": "sdrucire",
    "sdruciva": "sdrucire",
    "sdrucivamo": "sdrucire",
    "sdrucivan": "sdrucire",
    "sdrucivano": "sdrucire",
    "sdrucivate": "sdrucire",
    "sdrucivi": "sdrucire",
    "sdrucivo": "sdrucire",
    "sdruco": "sdrucire",
    "sdrucon": "sdrucire",
    "sdrucono": "sdrucire",
    "sdrucì": "sdrucire",
    "secca": "secco",
    "seccai": "seccare",
    "seccammo": "seccare",
    "seccan": "seccare",
    "seccando": "seccare",
    "seccano": "seccare",
    "seccante": "seccare",
    "seccanti": "seccare",
    "seccar": "seccare",
    "seccaron": "seccare",
    "seccarono": "seccare",
    "seccasse": "seccare",
    "seccasser": "seccare",
    "seccassero": "seccare",
    "seccassi": "seccare",
    "seccassimo": "seccare",
    "seccaste": "seccare",
    "seccasti": "seccare",
    "seccata": "seccato",
    "seccate": "seccato",
    "seccati": "seccato",
    "seccato": "seccare",
    "seccatori": "seccatore",
    "seccature": "seccatura",
    "seccava": "seccare",
    "seccavamo": "seccare",
    "seccavan": "seccare",
    "seccavano": "seccare",
    "seccavate": "seccare",
    "seccavi": "seccare",
    "seccavo": "seccare",
    "secche": "secco",
    "seccherai": "seccare",
    "seccheran": "seccare",
    "seccheranno": "seccare",
    "seccherebbe": "seccare",
    "seccherebber": "seccare",
    "seccherebbero": "seccare",
    "seccherei": "seccare",
    "seccheremmo": "seccare",
    "seccheremo": "seccare",
    "secchereste": "seccare",
    "seccheresti": "seccare",
    "seccherete": "seccare",
    "seccherà": "seccare",
    "seccherò": "seccare",
    "secchezze": "secchezza",
    "secchi": "secco",
    "secchiamo": "seccare",
    "secchiate": "secchiata",
    "secchielli": "secchiello",
    "secchin": "seccare",
    "secchino": "seccare",
    "secco": "seccare",
    "seccò": "seccare",
    "secentesca": "secentesco",
    "secentesche": "secentesco",
    "secenteschi": "secentesco",
    "secerna": "secernere",
    "secernan": "secernere",
    "secernano": "secernere",
    "secerne": "secernere",
    "secernei": "secernere",
    "secernemmo": "secernere",
    "secernendo": "secernere",
    "secernente": "secernere",
    "secernenti": "secernere",
    "secerner": "secernere",
    "secernerai": "secernere",
    "secerneran": "secernere",
    "secerneranno": "secernere",
    "secernerebbe": "secernere",
    "secernerebber": "secernere",
    "secernerebbero": "secernere",
    "secernerei": "secernere",
    "secerneremmo": "secernere",
    "secerneremo": "secernere",
    "secernereste": "secernere",
    "secerneresti": "secernere",
    "secernerete": "secernere",
    "secerneron": "secernere",
    "secernerono": "secernere",
    "secernerà": "secernere",
    "secernerò": "secernere",
    "secernesse": "secernere",
    "secernesser": "secernere",
    "secernessero": "secernere",
    "secernessi": "secernere",
    "secernessimo": "secernere",
    "secerneste": "secernere",
    "secernesti": "secernere",
    "secernete": "secernere",
    "secerneva": "secernere",
    "secernevamo": "secernere",
    "secernevan": "secernere",
    "secernevano": "secernere",
    "secernevate": "secernere",
    "secernevi": "secernere",
    "secernevo": "secernere",
    "secerni": "secernere",
    "secerniamo": "secernere",
    "secerniate": "secernere",
    "secerno": "secernere",
    "secernon": "secernere",
    "secernono": "secernere",
    "secernè": "secernere",
    "secessioni": "secessione",
    "secessionismi": "secessionismo",
    "secessioniste": "secessionista",
    "secessionisti": "secessionista",
    "secolari": "secolare",
    "secolarismi": "secolarismo",
    "secolarizza": "secolarizzare",
    "secolarizzai": "secolarizzare",
    "secolarizzammo": "secolarizzare",
    "secolarizzan": "secolarizzare",
    "secolarizzando": "secolarizzare",
    "secolarizzano": "secolarizzare",
    "secolarizzante": "secolarizzare",
    "secolarizzanti": "secolarizzare",
    "secolarizzar": "secolarizzare",
    "secolarizzaron": "secolarizzare",
    "secolarizzarono": "secolarizzare",
    "secolarizzasse": "secolarizzare",
    "secolarizzasser": "secolarizzare",
    "secolarizzassero": "secolarizzare",
    "secolarizzassi": "secolarizzare",
    "secolarizzassimo": "secolarizzare",
    "secolarizzaste": "secolarizzare",
    "secolarizzasti": "secolarizzare",
    "secolarizzata": "secolarizzare",
    "secolarizzate": "secolarizzare",
    "secolarizzati": "secolarizzare",
    "secolarizzato": "secolarizzare",
    "secolarizzava": "secolarizzare",
    "secolarizzavamo": "secolarizzare",
    "secolarizzavan": "secolarizzare",
    "secolarizzavano": "secolarizzare",
    "secolarizzavate": "secolarizzare",
    "secolarizzavi": "secolarizzare",
    "secolarizzavo": "secolarizzare",
    "secolarizzazioni": "secolarizzazione",
    "secolarizzerai": "secolarizzare",
    "secolarizzeran": "secolarizzare",
    "secolarizzeranno": "secolarizzare",
    "secolarizzerebbe": "secolarizzare",
    "secolarizzerebber": "secolarizzare",
    "secolarizzerebbero": "secolarizzare",
    "secolarizzerei": "secolarizzare",
    "secolarizzeremmo": "secolarizzare",
    "secolarizzeremo": "secolarizzare",
    "secolarizzereste": "secolarizzare",
    "secolarizzeresti": "secolarizzare",
    "secolarizzerete": "secolarizzare",
    "secolarizzerà": "secolarizzare",
    "secolarizzerò": "secolarizzare",
    "secolarizzi": "secolarizzare",
    "secolarizziamo": "secolarizzare",
    "secolarizziate": "secolarizzare",
    "secolarizzin": "secolarizzare",
    "secolarizzino": "secolarizzare",
    "secolarizzo": "secolarizzare",
    "secolarizzò": "secolarizzare",
    "secoli": "secolo",
    "seconda": "secondo",
    "secondai": "secondare",
    "secondammo": "secondare",
    "secondan": "secondare",
    "secondando": "secondare",
    "secondano": "secondare",
    "secondante": "secondare",
    "secondanti": "secondare",
    "secondar": "secondare",
    "secondari": "secondario",
    "secondaria": "secondario",
    "secondarie": "secondario",
    "secondaron": "secondare",
    "secondarono": "secondare",
    "secondasse": "secondare",
    "secondasser": "secondare",
    "secondassero": "secondare",
    "secondassi": "secondare",
    "secondassimo": "secondare",
    "secondaste": "secondare",
    "secondasti": "secondare",
    "secondata": "secondare",
    "secondate": "secondare",
    "secondati": "secondare",
    "secondato": "secondare",
    "secondava": "secondare",
    "secondavamo": "secondare",
    "secondavan": "secondare",
    "secondavano": "secondare",
    "secondavate": "secondare",
    "secondavi": "secondare",
    "secondavo": "secondare",
    "seconde": "secondo",
    "seconderai": "secondare",
    "seconderan": "secondare",
    "seconderanno": "secondare",
    "seconderebbe": "secondare",
    "seconderebber": "secondare",
    "seconderebbero": "secondare",
    "seconderei": "secondare",
    "seconderemmo": "secondare",
    "seconderemo": "secondare",
    "secondereste": "secondare",
    "seconderesti": "secondare",
    "seconderete": "secondare",
    "seconderà": "secondare",
    "seconderò": "secondare",
    "secondi": "secondo",
    "secondiamo": "secondare",
    "secondiate": "secondare",
    "secondin": "secondare",
    "secondini": "secondino",
    "secondino": "secondare",
    "secondo": "secondare",
    "secondogenita": "secondogenito",
    "secondogenite": "secondogenito",
    "secondogeniti": "secondogenito",
    "secondò": "secondare",
    "secreta": "secretare",
    "secretai": "secretare",
    "secretammo": "secretare",
    "secretan": "secretare",
    "secretando": "secretare",
    "secretano": "secretare",
    "secretante": "secretare",
    "secretanti": "secretare",
    "secretar": "secretare",
    "secretaron": "secretare",
    "secretarono": "secretare",
    "secretasse": "secretare",
    "secretasser": "secretare",
    "secretassero": "secretare",
    "secretassi": "secretare",
    "secretassimo": "secretare",
    "secretaste": "secretare",
    "secretasti": "secretare",
    "secretata": "secretare",
    "secretate": "secretare",
    "secretati": "secretare",
    "secretato": "secretare",
    "secretava": "secretare",
    "secretavamo": "secretare",
    "secretavan": "secretare",
    "secretavano": "secretare",
    "secretavate": "secretare",
    "secretavi": "secretare",
    "secretavo": "secretare",
    "secrete": "secernere",
    "secreterai": "secretare",
    "secreteran": "secretare",
    "secreteranno": "secretare",
    "secreterebbe": "secretare",
    "secreterebber": "secretare",
    "secreterebbero": "secretare",
    "secreterei": "secretare",
    "secreteremmo": "secretare",
    "secreteremo": "secretare",
    "secretereste": "secretare",
    "secreteresti": "secretare",
    "secreterete": "secretare",
    "secreterà": "secretare",
    "secreterò": "secretare",
    "secreti": "secretare",
    "secretiamo": "secretare",
    "secretiate": "secretare",
    "secretin": "secretare",
    "secretino": "secretare",
    "secreto": "secretare",
    "secretò": "secretare",
    "secrezioni": "secrezione",
    "seda": "sedare",
    "sedai": "sedare",
    "sedammo": "sedare",
    "sedan": "sedare",
    "sedando": "sedare",
    "sedano": "sedere",
    "sedante": "sedare",
    "sedanti": "sedare",
    "sedar": "sedare",
    "sedaron": "sedare",
    "sedarono": "sedare",
    "sedasse": "sedare",
    "sedasser": "sedare",
    "sedassero": "sedare",
    "sedassi": "sedare",
    "sedassimo": "sedare",
    "sedaste": "sedare",
    "sedasti": "sedare",
    "sedata": "sedare",
    "sedate": "sedare",
    "sedati": "sedare",
    "sedativa": "sedativo",
    "sedative": "sedativo",
    "sedativi": "sedativo",
    "sedato": "sedare",
    "sedava": "sedare",
    "sedavamo": "sedare",
    "sedavan": "sedare",
    "sedavano": "sedare",
    "sedavate": "sedare",
    "sedavi": "sedare",
    "sedavo": "sedare",
    "sedei": "sedere",
    "sedemmo": "sedere",
    "sedentari": "sedentario",
    "sedentaria": "sedentario",
    "sedentarie": "sedentario",
    "seder": "sedere",
    "sederai": "sedere",
    "sederan": "sedare",
    "sederanno": "sedere",
    "sederebbe": "sedere",
    "sederebber": "sedare",
    "sederebbero": "sedere",
    "sederei": "sedere",
    "sederemmo": "sedere",
    "sederemo": "sedere",
    "sedereste": "sedere",
    "sederesti": "sedere",
    "sederete": "sedere",
    "sederi": "sedere",
    "sederini": "sederino",
    "sederon": "sedere",
    "sederono": "sedere",
    "sederà": "sedere",
    "sederò": "sedere",
    "sedesse": "sedere",
    "sedesser": "sedere",
    "sedessero": "sedere",
    "sedessi": "sedere",
    "sedessimo": "sedere",
    "sedeste": "sedere",
    "sedesti": "sedere",
    "sedete": "sedere",
    "sedeva": "sedere",
    "sedevamo": "sedere",
    "sedevano": "sedere",
    "sedevate": "sedere",
    "sedevi": "sedere",
    "sedevo": "sedere",
    "sedi": "sede",
    "sediamo": "sedere",
    "sediate": "sedere",
    "sedicenni": "sedicenne",
    "sedicenti": "sedicente",
    "sedicesima": "sedicesimo",
    "sedicesime": "sedicesimo",
    "sedicesimi": "sedicesimo",
    "sedie": "sedia",
    "sedili": "sedile",
    "sedimenta": "sedimentare",
    "sedimentai": "sedimentare",
    "sedimentammo": "sedimentare",
    "sedimentan": "sedimentare",
    "sedimentando": "sedimentare",
    "sedimentano": "sedimentare",
    "sedimentante": "sedimentare",
    "sedimentanti": "sedimentare",
    "sedimentar": "sedimentare",
    "sedimentaron": "sedimentare",
    "sedimentarono": "sedimentare",
    "sedimentasse": "sedimentare",
    "sedimentasser": "sedimentare",
    "sedimentassero": "sedimentare",
    "sedimentassi": "sedimentare",
    "sedimentassimo": "sedimentare",
    "sedimentaste": "sedimentare",
    "sedimentasti": "sedimentare",
    "sedimentata": "sedimentare",
    "sedimentate": "sedimentare",
    "sedimentati": "sedimentare",
    "sedimentato": "sedimentare",
    "sedimentava": "sedimentare",
    "sedimentavamo": "sedimentare",
    "sedimentavan": "sedimentare",
    "sedimentavano": "sedimentare",
    "sedimentavate": "sedimentare",
    "sedimentavi": "sedimentare",
    "sedimentavo": "sedimentare",
    "sedimentazioni": "sedimentazione",
    "sedimenterai": "sedimentare",
    "sedimenteran": "sedimentare",
    "sedimenteranno": "sedimentare",
    "sedimenterebbe": "sedimentare",
    "sedimenterebber": "sedimentare",
    "sedimenterebbero": "sedimentare",
    "sedimenterei": "sedimentare",
    "sedimenteremmo": "sedimentare",
    "sedimenteremo": "sedimentare",
    "sedimentereste": "sedimentare",
    "sedimenteresti": "sedimentare",
    "sedimenterete": "sedimentare",
    "sedimenterà": "sedimentare",
    "sedimenterò": "sedimentare",
    "sedimenti": "sedimento",
    "sedimentiamo": "sedimentare",
    "sedimentiate": "sedimentare",
    "sedimentin": "sedimentare",
    "sedimentino": "sedimentare",
    "sedimento": "sedimentare",
    "sedimentò": "sedimentare",
    "sedin": "sedare",
    "sedino": "sedare",
    "sedioline": "sediolina",
    "sedizioni": "sedizione",
    "sediziosa": "sedizioso",
    "sediziose": "sedizioso",
    "sediziosi": "sedizioso",
    "sedo": "sedare",
    "sedotta": "sedurre",
    "sedotte": "sedurre",
    "sedotti": "sedurre",
    "sedotto": "sedurre",
    "seduca": "sedurre",
    "seducan": "sedurre",
    "seducano": "sedurre",
    "seduce": "sedurre",
    "seducemmo": "sedurre",
    "seducendo": "sedurre",
    "seducente": "sedurre",
    "seducenti": "sedurre",
    "seducesse": "sedurre",
    "seducesser": "sedurre",
    "seducessero": "sedurre",
    "seducessi": "sedurre",
    "seducessimo": "sedurre",
    "seduceste": "sedurre",
    "seducesti": "sedurre",
    "seducete": "sedurre",
    "seduceva": "sedurre",
    "seducevamo": "sedurre",
    "seducevan": "sedurre",
    "seducevano": "sedurre",
    "seducevate": "sedurre",
    "seducevi": "sedurre",
    "seducevo": "sedurre",
    "seduci": "sedurre",
    "seduciamo": "sedurre",
    "seduciate": "sedurre",
    "seduco": "sedurre",
    "seducon": "sedurre",
    "seducono": "sedurre",
    "sedurr": "sedurre",
    "sedurrai": "sedurre",
    "sedurran": "sedurre",
    "sedurranno": "sedurre",
    "sedurrebbe": "sedurre",
    "sedurrebber": "sedurre",
    "sedurrebbero": "sedurre",
    "sedurrei": "sedurre",
    "sedurremmo": "sedurre",
    "sedurremo": "sedurre",
    "sedurreste": "sedurre",
    "sedurresti": "sedurre",
    "sedurrete": "sedurre",
    "sedurrà": "sedurre",
    "sedurrò": "sedurre",
    "sedusse": "sedurre",
    "sedusser": "sedurre",
    "sedussero": "sedurre",
    "sedussi": "sedurre",
    "seduta": "sedere",
    "sedute": "seduta",
    "seduti": "sedere",
    "seduto": "sedere",
    "seduttori": "seduttore",
    "seduttrice": "seduttore",
    "seduttrici": "seduttrice",
    "seduzioni": "seduzione",
    "sedè": "sedere",
    "sedò": "sedare",
    "sega": "segare",
    "segai": "segare",
    "segaligna": "segaligno",
    "segaligne": "segaligno",
    "segaligni": "segaligno",
    "segammo": "segare",
    "segan": "segare",
    "segando": "segare",
    "segano": "segare",
    "segante": "segare",
    "seganti": "segare",
    "segar": "segare",
    "segaron": "segare",
    "segarono": "segare",
    "segasse": "segare",
    "segasser": "segare",
    "segassero": "segare",
    "segassi": "segare",
    "segassimo": "segare",
    "segaste": "segare",
    "segasti": "segare",
    "segata": "segare",
    "segate": "segare",
    "segati": "segare",
    "segato": "segare",
    "segature": "segatura",
    "segava": "segare",
    "segavamo": "segare",
    "segavan": "segare",
    "segavano": "segare",
    "segavate": "segare",
    "segavi": "segare",
    "segavo": "segare",
    "seggi": "seggio",
    "seggiole": "seggiola",
    "seggioline": "seggiolina",
    "seggiolini": "seggiolino",
    "seggioloni": "seggiolone",
    "seggiovie": "seggiovia",
    "seghe": "sega",
    "segherai": "segare",
    "segheran": "segare",
    "segheranno": "segare",
    "segherebbe": "segare",
    "segherebber": "segare",
    "segherebbero": "segare",
    "segherei": "segare",
    "segheremmo": "segare",
    "segheremo": "segare",
    "seghereste": "segare",
    "segheresti": "segare",
    "segherete": "segare",
    "segherie": "segheria",
    "segherà": "segare",
    "segherò": "segare",
    "seghetta": "seghettare",
    "seghettai": "seghettare",
    "seghettammo": "seghettare",
    "seghettan": "seghettare",
    "seghettando": "seghettare",
    "seghettano": "seghettare",
    "seghettante": "seghettare",
    "seghettanti": "seghettare",
    "seghettar": "seghettare",
    "seghettaron": "seghettare",
    "seghettarono": "seghettare",
    "seghettasse": "seghettare",
    "seghettasser": "seghettare",
    "seghettassero": "seghettare",
    "seghettassi": "seghettare",
    "seghettassimo": "seghettare",
    "seghettaste": "seghettare",
    "seghettasti": "seghettare",
    "seghettata": "seghettare",
    "seghettate": "seghettare",
    "seghettati": "seghettare",
    "seghettato": "seghettare",
    "seghettava": "seghettare",
    "seghettavamo": "seghettare",
    "seghettavan": "seghettare",
    "seghettavano": "seghettare",
    "seghettavate": "seghettare",
    "seghettavi": "seghettare",
    "seghettavo": "seghettare",
    "seghetterai": "seghettare",
    "seghetteran": "seghettare",
    "seghetteranno": "seghettare",
    "seghetterebbe": "seghettare",
    "seghetterebber": "seghettare",
    "seghetterebbero": "seghettare",
    "seghetterei": "seghettare",
    "seghetteremmo": "seghettare",
    "seghetteremo": "seghettare",
    "seghettereste": "seghettare",
    "seghetteresti": "seghettare",
    "seghetterete": "seghettare",
    "seghetterà": "seghettare",
    "seghetterò": "seghettare",
    "seghetti": "seghettare",
    "seghettiamo": "seghettare",
    "seghettiate": "seghettare",
    "seghettin": "seghettare",
    "seghettino": "seghettare",
    "seghetto": "seghettare",
    "seghettò": "seghettare",
    "seghi": "segare",
    "seghiamo": "segare",
    "seghiate": "segare",
    "seghin": "segare",
    "seghino": "segare",
    "segmenta": "segmentare",
    "segmentai": "segmentare",
    "segmentammo": "segmentare",
    "segmentan": "segmentare",
    "segmentando": "segmentare",
    "segmentano": "segmentare",
    "segmentante": "segmentare",
    "segmentanti": "segmentare",
    "segmentar": "segmentare",
    "segmentaron": "segmentare",
    "segmentarono": "segmentare",
    "segmentasse": "segmentare",
    "segmentasser": "segmentare",
    "segmentassero": "segmentare",
    "segmentassi": "segmentare",
    "segmentassimo": "segmentare",
    "segmentaste": "segmentare",
    "segmentasti": "segmentare",
    "segmentata": "segmentare",
    "segmentate": "segmentare",
    "segmentati": "segmentare",
    "segmentato": "segmentare",
    "segmentava": "segmentare",
    "segmentavamo": "segmentare",
    "segmentavan": "segmentare",
    "segmentavano": "segmentare",
    "segmentavate": "segmentare",
    "segmentavi": "segmentare",
    "segmentavo": "segmentare",
    "segmentazioni": "segmentazione",
    "segmenterai": "segmentare",
    "segmenteran": "segmentare",
    "segmenteranno": "segmentare",
    "segmenterebbe": "segmentare",
    "segmenterebber": "segmentare",
    "segmenterebbero": "segmentare",
    "segmenterei": "segmentare",
    "segmenteremmo": "segmentare",
    "segmenteremo": "segmentare",
    "segmentereste": "segmentare",
    "segmenteresti": "segmentare",
    "segmenterete": "segmentare",
    "segmenterà": "segmentare",
    "segmenterò": "segmentare",
    "segmenti": "segmento",
    "segmentiamo": "segmentare",
    "segmentiate": "segmentare",
    "segmentin": "segmentare",
    "segmentino": "segmentare",
    "segmento": "segmentare",
    "segmentò": "segmentare",
    "segna": "segnare",
    "segnai": "segnare",
    "segnala": "segnalare",
    "segnalai": "segnalare",
    "segnalamenti": "segnalamento",
    "segnalammo": "segnalare",
    "segnalan": "segnalare",
    "segnalando": "segnalare",
    "segnalano": "segnalare",
    "segnalante": "segnalare",
    "segnalanti": "segnalare",
    "segnalar": "segnalare",
    "segnalaron": "segnalare",
    "segnalarono": "segnalare",
    "segnalasse": "segnalare",
    "segnalasser": "segnalare",
    "segnalassero": "segnalare",
    "segnalassi": "segnalare",
    "segnalassimo": "segnalare",
    "segnalaste": "segnalare",
    "segnalasti": "segnalare",
    "segnalata": "segnalato",
    "segnalate": "segnalato",
    "segnalati": "segnalato",
    "segnalato": "segnalare",
    "segnalatori": "segnalatore",
    "segnalava": "segnalare",
    "segnalavamo": "segnalare",
    "segnalavan": "segnalare",
    "segnalavano": "segnalare",
    "segnalavate": "segnalare",
    "segnalavi": "segnalare",
    "segnalavo": "segnalare",
    "segnalazioni": "segnalazione",
    "segnalerai": "segnalare",
    "segnaleran": "segnalare",
    "segnaleranno": "segnalare",
    "segnalerebbe": "segnalare",
    "segnalerebber": "segnalare",
    "segnalerebbero": "segnalare",
    "segnalerei": "segnalare",
    "segnaleremmo": "segnalare",
    "segnaleremo": "segnalare",
    "segnalereste": "segnalare",
    "segnaleresti": "segnalare",
    "segnalerete": "segnalare",
    "segnalerà": "segnalare",
    "segnalerò": "segnalare",
    "segnaletica": "segnaletico",
    "segnaletiche": "segnaletico",
    "segnaletici": "segnaletico",
    "segnali": "segnale",
    "segnaliamo": "segnalare",
    "segnaliate": "segnalare",
    "segnalin": "segnalare",
    "segnalino": "segnalare",
    "segnalo": "segnalare",
    "segnalò": "segnalare",
    "segnammo": "segnare",
    "segnan": "segnare",
    "segnando": "segnare",
    "segnano": "segnare",
    "segnante": "segnare",
    "segnanti": "segnare",
    "segnar": "segnare",
    "segnaron": "segnare",
    "segnarono": "segnare",
    "segnasse": "segnare",
    "segnasser": "segnare",
    "segnassero": "segnare",
    "segnassi": "segnare",
    "segnassimo": "segnare",
    "segnaste": "segnare",
    "segnasti": "segnare",
    "segnata": "segnato",
    "segnate": "segnato",
    "segnati": "segnato",
    "segnato": "segnare",
    "segnature": "segnatura",
    "segnava": "segnare",
    "segnavamo": "segnare",
    "segnavan": "segnare",
    "segnavano": "segnare",
    "segnavate": "segnare",
    "segnavi": "segnare",
    "segnavo": "segnare",
    "segnerai": "segnare",
    "segneran": "segnare",
    "segneranno": "segnare",
    "segnerebbe": "segnare",
    "segnerebber": "segnare",
    "segnerebbero": "segnare",
    "segnerei": "segnare",
    "segneremmo": "segnare",
    "segneremo": "segnare",
    "segnereste": "segnare",
    "segneresti": "segnare",
    "segnerete": "segnare",
    "segnerà": "segnare",
    "segnerò": "segnare",
    "segni": "segno",
    "segniamo": "segnare",
    "segniate": "segnare",
    "segnica": "segnico",
    "segniche": "segnico",
    "segnici": "segnico",
    "segnin": "segnare",
    "segnino": "segnare",
    "segno": "segnare",
    "segnò": "segnare",
    "sego": "segare",
    "segrega": "segregare",
    "segregai": "segregare",
    "segregammo": "segregare",
    "segregan": "segregare",
    "segregando": "segregare",
    "segregano": "segregare",
    "segregante": "segregare",
    "segreganti": "segregare",
    "segregar": "segregare",
    "segregaron": "segregare",
    "segregarono": "segregare",
    "segregasse": "segregare",
    "segregasser": "segregare",
    "segregassero": "segregare",
    "segregassi": "segregare",
    "segregassimo": "segregare",
    "segregaste": "segregare",
    "segregasti": "segregare",
    "segregata": "segregato",
    "segregate": "segregato",
    "segregati": "segregato",
    "segregato": "segregare",
    "segregava": "segregare",
    "segregavamo": "segregare",
    "segregavan": "segregare",
    "segregavano": "segregare",
    "segregavate": "segregare",
    "segregavi": "segregare",
    "segregavo": "segregare",
    "segregazioni": "segregazione",
    "segregazioniste": "segregazionista",
    "segregazionisti": "segregazionista",
    "segregherai": "segregare",
    "segregheran": "segregare",
    "segregheranno": "segregare",
    "segregherebbe": "segregare",
    "segregherebber": "segregare",
    "segregherebbero": "segregare",
    "segregherei": "segregare",
    "segregheremmo": "segregare",
    "segregheremo": "segregare",
    "segreghereste": "segregare",
    "segregheresti": "segregare",
    "segregherete": "segregare",
    "segregherà": "segregare",
    "segregherò": "segregare",
    "segreghi": "segregare",
    "segreghiamo": "segregare",
    "segreghiate": "segregare",
    "segreghin": "segregare",
    "segreghino": "segregare",
    "segrego": "segregare",
    "segregò": "segregare",
    "segreta": "segreto",
    "segretari": "segretaro",
    "segretari-presidenti": "segretario-presidente",
    "segretariati": "segretariato",
    "segretarie": "segretaria",
    "segrete": "segreto",
    "segreterie": "segreteria",
    "segretezze": "segretezza",
    "segreti": "segreto",
    "segua": "seguire",
    "seguaci": "seguace",
    "seguan": "seguire",
    "seguano": "seguire",
    "segue": "seguire",
    "seguendo": "seguire",
    "seguente": "seguire",
    "seguenti": "seguire",
    "segugi": "segugio",
    "segui": "seguire",
    "seguiamo": "seguire",
    "seguiate": "seguire",
    "seguii": "seguire",
    "seguimmo": "seguire",
    "seguir": "seguire",
    "seguirai": "seguire",
    "seguiran": "seguire",
    "seguiranno": "seguire",
    "seguirebbe": "seguire",
    "seguirebber": "seguire",
    "seguirebbero": "seguire",
    "seguirei": "seguire",
    "seguiremmo": "seguire",
    "seguiremo": "seguire",
    "seguireste": "seguire",
    "seguiresti": "seguire",
    "seguirete": "seguire",
    "seguiron": "seguire",
    "seguirono": "seguire",
    "seguirà": "seguire",
    "seguirò": "seguire",
    "seguisse": "seguire",
    "seguisser": "seguire",
    "seguissero": "seguire",
    "seguissi": "seguire",
    "seguissimo": "seguire",
    "seguiste": "seguire",
    "seguisti": "seguire",
    "seguita": "seguito",
    "seguitai": "seguitare",
    "seguitammo": "seguitare",
    "seguitan": "seguitare",
    "seguitando": "seguitare",
    "seguitano": "seguitare",
    "seguitante": "seguitare",
    "seguitanti": "seguitare",
    "seguitar": "seguitare",
    "seguitaron": "seguitare",
    "seguitarono": "seguitare",
    "seguitasse": "seguitare",
    "seguitasser": "seguitare",
    "seguitassero": "seguitare",
    "seguitassi": "seguitare",
    "seguitassimo": "seguitare",
    "seguitaste": "seguitare",
    "seguitasti": "seguitare",
    "seguitata": "seguitare",
    "seguitate": "seguitare",
    "seguitati": "seguitare",
    "seguitato": "seguitare",
    "seguitava": "seguitare",
    "seguitavamo": "seguitare",
    "seguitavan": "seguitare",
    "seguitavano": "seguitare",
    "seguitavate": "seguitare",
    "seguitavi": "seguitare",
    "seguitavo": "seguitare",
    "seguite": "seguito",
    "seguiterai": "seguitare",
    "seguiteran": "seguitare",
    "seguiteranno": "seguitare",
    "seguiterebbe": "seguitare",
    "seguiterebber": "seguitare",
    "seguiterebbero": "seguitare",
    "seguiterei": "seguitare",
    "seguiteremmo": "seguitare",
    "seguiteremo": "seguitare",
    "seguitereste": "seguitare",
    "seguiteresti": "seguitare",
    "seguiterete": "seguitare",
    "seguiterà": "seguitare",
    "seguiterò": "seguitare",
    "seguiti": "seguito",
    "seguitiamo": "seguitare",
    "seguitiate": "seguitare",
    "seguitin": "seguitare",
    "seguitino": "seguitare",
    "seguito": "seguitare",
    "seguitò": "seguitare",
    "seguiva": "seguire",
    "seguivamo": "seguire",
    "seguivan": "seguire",
    "seguivano": "seguire",
    "seguivate": "seguire",
    "seguivi": "seguire",
    "seguivo": "seguire",
    "seguo": "seguire",
    "seguon": "seguire",
    "seguono": "seguire",
    "seguì": "seguire",
    "segò": "segare",
    "sei": "essere",
    "seicentesca": "seicentesco",
    "seicentesche": "seicentesco",
    "seicenteschi": "seicentesco",
    "seicentesima": "seicentesimo",
    "seicentesime": "seicentesimo",
    "seicentesimi": "seicentesimo",
    "seimillesima": "seimillesimo",
    "seimillesime": "seimillesimo",
    "seimillesimi": "seimillesimo",
    "selcerai": "selciare",
    "selceran": "selciare",
    "selceranno": "selciare",
    "selcerebbe": "selciare",
    "selcerebber": "selciare",
    "selcerebbero": "selciare",
    "selcerei": "selciare",
    "selceremmo": "selciare",
    "selceremo": "selciare",
    "selcereste": "selciare",
    "selceresti": "selciare",
    "selcerete": "selciare",
    "selcerà": "selciare",
    "selcerò": "selciare",
    "selci": "selciare",
    "selcia": "selciare",
    "selciai": "selciare",
    "selciammo": "selciare",
    "selciamo": "selciare",
    "selcian": "selciare",
    "selciando": "selciare",
    "selciano": "selciare",
    "selciante": "selciare",
    "selcianti": "selciare",
    "selciar": "selciare",
    "selciaron": "selciare",
    "selciarono": "selciare",
    "selciasse": "selciare",
    "selciasser": "selciare",
    "selciassero": "selciare",
    "selciassi": "selciare",
    "selciassimo": "selciare",
    "selciaste": "selciare",
    "selciasti": "selciare",
    "selciata": "selciato",
    "selciate": "selciato",
    "selciati": "selciato",
    "selciato": "selciare",
    "selciava": "selciare",
    "selciavamo": "selciare",
    "selciavan": "selciare",
    "selciavano": "selciare",
    "selciavate": "selciare",
    "selciavi": "selciare",
    "selciavo": "selciare",
    "selcin": "selciare",
    "selcino": "selciare",
    "selcio": "selciare",
    "selciò": "selciare",
    "selettiva": "selettivo",
    "selettive": "selettivo",
    "selettivi": "selettivo",
    "selettori": "selettore",
    "seleziona": "selezionare",
    "selezionai": "selezionare",
    "selezionammo": "selezionare",
    "selezionan": "selezionare",
    "selezionando": "selezionare",
    "selezionano": "selezionare",
    "selezionante": "selezionare",
    "selezionanti": "selezionare",
    "selezionar": "selezionare",
    "selezionaron": "selezionare",
    "selezionarono": "selezionare",
    "selezionasse": "selezionare",
    "selezionasser": "selezionare",
    "selezionassero": "selezionare",
    "selezionassi": "selezionare",
    "selezionassimo": "selezionare",
    "selezionaste": "selezionare",
    "selezionasti": "selezionare",
    "selezionata": "selezionato",
    "selezionate": "selezionato",
    "selezionati": "selezionato",
    "selezionato": "selezionare",
    "selezionatori": "selezionatore",
    "selezionatrice": "selezionatore",
    "selezionatrici": "selezionatore",
    "selezionava": "selezionare",
    "selezionavamo": "selezionare",
    "selezionavan": "selezionare",
    "selezionavano": "selezionare",
    "selezionavate": "selezionare",
    "selezionavi": "selezionare",
    "selezionavo": "selezionare",
    "selezionerai": "selezionare",
    "selezioneran": "selezionare",
    "selezioneranno": "selezionare",
    "selezionerebbe": "selezionare",
    "selezionerebber": "selezionare",
    "selezionerebbero": "selezionare",
    "selezionerei": "selezionare",
    "selezioneremmo": "selezionare",
    "selezioneremo": "selezionare",
    "selezionereste": "selezionare",
    "selezioneresti": "selezionare",
    "selezionerete": "selezionare",
    "selezionerà": "selezionare",
    "selezionerò": "selezionare",
    "selezioni": "selezione",
    "selezioniamo": "selezionare",
    "selezioniate": "selezionare",
    "selezionin": "selezionare",
    "selezionino": "selezionare",
    "seleziono": "selezionare",
    "selezionò": "selezionare",
    "sella": "sellare",
    "sellai": "sellare",
    "sellammo": "sellare",
    "sellan": "sellare",
    "sellando": "sellare",
    "sellano": "sellare",
    "sellante": "sellare",
    "sellanti": "sellare",
    "sellar": "sellare",
    "sellaron": "sellare",
    "sellarono": "sellare",
    "sellasse": "sellare",
    "sellasser": "sellare",
    "sellassero": "sellare",
    "sellassi": "sellare",
    "sellassimo": "sellare",
    "sellaste": "sellare",
    "sellasti": "sellare",
    "sellata": "sellare",
    "sellate": "sellare",
    "sellati": "sellare",
    "sellato": "sellare",
    "sellava": "sellare",
    "sellavamo": "sellare",
    "sellavan": "sellare",
    "sellavano": "sellare",
    "sellavate": "sellare",
    "sellavi": "sellare",
    "sellavo": "sellare",
    "selle": "sella",
    "sellerai": "sellare",
    "selleran": "sellare",
    "selleranno": "sellare",
    "sellerebbe": "sellare",
    "sellerebber": "sellare",
    "sellerebbero": "sellare",
    "sellerei": "sellare",
    "selleremmo": "sellare",
    "selleremo": "sellare",
    "sellereste": "sellare",
    "selleresti": "sellare",
    "sellerete": "sellare",
    "sellerà": "sellare",
    "sellerò": "sellare",
    "selli": "sellare",
    "selliamo": "sellare",
    "selliate": "sellare",
    "sellin": "sellare",
    "sellini": "sellino",
    "sellino": "sellare",
    "sello": "sellare",
    "sellò": "sellare",
    "selvagge": "selvaggio",
    "selvaggi": "selvaggio",
    "selvaggia": "selvaggio",
    "selvaggine": "selvaggina",
    "selvatica": "selvatico",
    "selvatiche": "selvatico",
    "selvatici": "selvatico",
    "selve": "selva",
    "selvosa": "selvoso",
    "selvose": "selvoso",
    "selvosi": "selvoso",
    "semafori": "semaforo",
    "semaforica": "semaforico",
    "semaforiche": "semaforico",
    "semaforici": "semaforico",
    "semantica": "semantico",
    "semantiche": "semantico",
    "semantici": "semantico",
    "sembianze": "sembianza",
    "sembra": "sembrare",
    "sembrai": "sembrare",
    "sembrammo": "sembrare",
    "sembran": "sembrare",
    "sembrando": "sembrare",
    "sembrano": "sembrare",
    "sembrante": "sembrare",
    "sembranti": "sembrare",
    "sembrar": "sembrare",
    "sembraron": "sembrare",
    "sembrarono": "sembrare",
    "sembrasse": "sembrare",
    "sembrasser": "sembrare",
    "sembrassero": "sembrare",
    "sembrassi": "sembrare",
    "sembrassimo": "sembrare",
    "sembraste": "sembrare",
    "sembrasti": "sembrare",
    "sembrata": "sembrare",
    "sembrate": "sembrare",
    "sembrati": "sembrare",
    "sembrato": "sembrare",
    "sembrava": "sembrare",
    "sembravamo": "sembrare",
    "sembravan": "sembrare",
    "sembravano": "sembrare",
    "sembravate": "sembrare",
    "sembravi": "sembrare",
    "sembravo": "sembrare",
    "sembrerai": "sembrare",
    "sembreran": "sembrare",
    "sembreranno": "sembrare",
    "sembrerebbe": "sembrare",
    "sembrerebber": "sembrare",
    "sembrerebbero": "sembrare",
    "sembrerei": "sembrare",
    "sembreremmo": "sembrare",
    "sembreremo": "sembrare",
    "sembrereste": "sembrare",
    "sembreresti": "sembrare",
    "sembrerete": "sembrare",
    "sembrerà": "sembrare",
    "sembrerò": "sembrare",
    "sembri": "sembrare",
    "sembriamo": "sembrare",
    "sembriate": "sembrare",
    "sembrin": "sembrare",
    "sembrino": "sembrare",
    "sembro": "sembrare",
    "sembrò": "sembrare",
    "sementa": "sementare",
    "sementai": "sementare",
    "sementammo": "sementare",
    "sementan": "sementare",
    "sementando": "sementare",
    "sementano": "sementare",
    "sementante": "sementare",
    "sementanti": "sementare",
    "sementar": "sementare",
    "sementaron": "sementare",
    "sementarono": "sementare",
    "sementasse": "sementare",
    "sementasser": "sementare",
    "sementassero": "sementare",
    "sementassi": "sementare",
    "sementassimo": "sementare",
    "sementaste": "sementare",
    "sementasti": "sementare",
    "sementata": "sementare",
    "sementate": "sementare",
    "sementati": "sementare",
    "sementato": "sementare",
    "sementava": "sementare",
    "sementavamo": "sementare",
    "sementavan": "sementare",
    "sementavano": "sementare",
    "sementavate": "sementare",
    "sementavi": "sementare",
    "sementavo": "sementare",
    "sementerai": "sementare",
    "sementeran": "sementare",
    "sementeranno": "sementare",
    "sementerebbe": "sementare",
    "sementerebber": "sementare",
    "sementerebbero": "sementare",
    "sementerei": "sementare",
    "sementeremmo": "sementare",
    "sementeremo": "sementare",
    "sementereste": "sementare",
    "sementeresti": "sementare",
    "sementerete": "sementare",
    "sementerà": "sementare",
    "sementerò": "sementare",
    "sementi": "sementare",
    "sementiamo": "sementare",
    "sementiate": "sementare",
    "sementin": "sementare",
    "sementino": "sementare",
    "semento": "sementare",
    "sementò": "sementare",
    "semestrali": "semestrale",
    "semestralizzazioni": "semestralizzazione",
    "semestri": "semestre",
    "semi": "seme",
    "semianalfabete": "semianalfabeta",
    "semianalfabeti": "semianalfabeta",
    "semiaperta": "semiaperto",
    "semiaperte": "semiaperto",
    "semiaperti": "semiaperto",
    "semiassiderata": "semiassiderato",
    "semiassiderate": "semiassiderato",
    "semiassiderati": "semiassiderato",
    "semiautomatica": "semiautomatico",
    "semiautomatiche": "semiautomatico",
    "semiautomatici": "semiautomatico",
    "semicerchi": "semicerchio",
    "semichiusa": "semichiuso",
    "semichiuse": "semichiuso",
    "semichiusi": "semichiuso",
    "semicircola": "semicircolare",
    "semicircolai": "semicircolare",
    "semicircolammo": "semicircolare",
    "semicircolan": "semicircolare",
    "semicircolando": "semicircolare",
    "semicircolano": "semicircolare",
    "semicircolante": "semicircolare",
    "semicircolanti": "semicircolare",
    "semicircolar": "semicircolare",
    "semicircolari": "semicircolare",
    "semicircolaron": "semicircolare",
    "semicircolarono": "semicircolare",
    "semicircolasse": "semicircolare",
    "semicircolasser": "semicircolare",
    "semicircolassero": "semicircolare",
    "semicircolassi": "semicircolare",
    "semicircolassimo": "semicircolare",
    "semicircolaste": "semicircolare",
    "semicircolasti": "semicircolare",
    "semicircolata": "semicircolare",
    "semicircolate": "semicircolare",
    "semicircolati": "semicircolare",
    "semicircolato": "semicircolare",
    "semicircolava": "semicircolare",
    "semicircolavamo": "semicircolare",
    "semicircolavan": "semicircolare",
    "semicircolavano": "semicircolare",
    "semicircolavate": "semicircolare",
    "semicircolavi": "semicircolare",
    "semicircolavo": "semicircolare",
    "semicircolerai": "semicircolare",
    "semicircoleran": "semicircolare",
    "semicircoleranno": "semicircolare",
    "semicircolerebbe": "semicircolare",
    "semicircolerebber": "semicircolare",
    "semicircolerebbero": "semicircolare",
    "semicircolerei": "semicircolare",
    "semicircoleremmo": "semicircolare",
    "semicircoleremo": "semicircolare",
    "semicircolereste": "semicircolare",
    "semicircoleresti": "semicircolare",
    "semicircolerete": "semicircolare",
    "semicircolerà": "semicircolare",
    "semicircolerò": "semicircolare",
    "semicircoli": "semicircolare",
    "semicircoliamo": "semicircolare",
    "semicircoliate": "semicircolare",
    "semicircolin": "semicircolare",
    "semicircolino": "semicircolare",
    "semicircolo": "semicircolare",
    "semicircolò": "semicircolare",
    "semiconduttori": "semiconduttore",
    "semidei": "semidio",
    "semideserta": "semideserto",
    "semideserte": "semideserto",
    "semideserti": "semideserto",
    "semifinali": "semifinale",
    "semifinaliste": "semifinalista",
    "semilavorata": "semilavorato",
    "semilavorate": "semilavorato",
    "semilavorati": "semilavorato",
    "semiliberi": "semilibero",
    "semiluna": "semilunare",
    "semilunai": "semilunare",
    "semilunammo": "semilunare",
    "semilunan": "semilunare",
    "semilunando": "semilunare",
    "semilunano": "semilunare",
    "semilunante": "semilunare",
    "semilunanti": "semilunare",
    "semilunar": "semilunare",
    "semilunaron": "semilunare",
    "semilunarono": "semilunare",
    "semilunasse": "semilunare",
    "semilunasser": "semilunare",
    "semilunassero": "semilunare",
    "semilunassi": "semilunare",
    "semilunassimo": "semilunare",
    "semilunaste": "semilunare",
    "semilunasti": "semilunare",
    "semilunata": "semilunare",
    "semilunate": "semilunare",
    "semilunati": "semilunare",
    "semilunato": "semilunare",
    "semilunava": "semilunare",
    "semilunavamo": "semilunare",
    "semilunavan": "semilunare",
    "semilunavano": "semilunare",
    "semilunavate": "semilunare",
    "semilunavi": "semilunare",
    "semilunavo": "semilunare",
    "semilunerai": "semilunare",
    "semiluneran": "semilunare",
    "semiluneranno": "semilunare",
    "semilunerebbe": "semilunare",
    "semilunerebber": "semilunare",
    "semilunerebbero": "semilunare",
    "semilunerei": "semilunare",
    "semiluneremmo": "semilunare",
    "semiluneremo": "semilunare",
    "semilunereste": "semilunare",
    "semiluneresti": "semilunare",
    "semilunerete": "semilunare",
    "semilunerà": "semilunare",
    "semilunerò": "semilunare",
    "semiluni": "semilunare",
    "semiluniamo": "semilunare",
    "semiluniate": "semilunare",
    "semilunin": "semilunare",
    "semilunino": "semilunare",
    "semiluno": "semilunare",
    "semilunò": "semilunare",
    "semina": "seminare",
    "seminai": "seminare",
    "seminali": "seminale",
    "seminammo": "seminare",
    "seminan": "seminare",
    "seminando": "seminare",
    "seminano": "seminare",
    "seminante": "seminare",
    "seminanti": "seminare",
    "seminar": "seminare",
    "seminari": "seminario",
    "seminaristi": "seminarista",
    "seminaron": "seminare",
    "seminarono": "seminare",
    "seminasse": "seminare",
    "seminasser": "seminare",
    "seminassero": "seminare",
    "seminassi": "seminare",
    "seminassimo": "seminare",
    "seminaste": "seminare",
    "seminasti": "seminare",
    "seminata": "seminato",
    "seminate": "seminato",
    "seminati": "seminato",
    "seminato": "seminare",
    "seminatori": "seminatore",
    "seminava": "seminare",
    "seminavamo": "seminare",
    "seminavan": "seminare",
    "seminavano": "seminare",
    "seminavate": "seminare",
    "seminavi": "seminare",
    "seminavo": "seminare",
    "semine": "semina",
    "seminerai": "seminare",
    "semineran": "seminare",
    "semineranno": "seminare",
    "seminerebbe": "seminare",
    "seminerebber": "seminare",
    "seminerebbero": "seminare",
    "seminerei": "seminare",
    "semineremmo": "seminare",
    "semineremo": "seminare",
    "seminereste": "seminare",
    "semineresti": "seminare",
    "seminerete": "seminare",
    "seminerà": "seminare",
    "seminerò": "seminare",
    "seminferma": "seminfermo",
    "seminferme": "seminfermo",
    "seminfermi": "seminfermo",
    "semini": "seminare",
    "seminiamo": "seminare",
    "seminiate": "seminare",
    "seminin": "seminare",
    "seminino": "seminare",
    "semino": "seminare",
    "seminterrati": "seminterrato",
    "seminuda": "seminudo",
    "seminude": "seminudo",
    "seminudi": "seminudo",
    "seminò": "seminare",
    "semiologi": "semiologo",
    "semiologie": "semiologia",
    "semipresidenziali": "semipresidenziale",
    "semipresidenzialismi": "semipresidenzialismo",
    "semiseri": "semiserio",
    "semiseria": "semiserio",
    "semiserie": "semiserio",
    "semispontanea": "semispontaneo",
    "semispontanee": "semispontaneo",
    "semispontanei": "semispontaneo",
    "semite": "semita",
    "semiti": "semita",
    "semitica": "semitico",
    "semitiche": "semitico",
    "semitici": "semitico",
    "semitoni": "semitono",
    "semitrasparenti": "semitrasparente",
    "semivuota": "semivuoto",
    "semivuote": "semivuoto",
    "semivuoti": "semivuoto",
    "semoventi": "semovente",
    "sempiterna": "sempiterno",
    "sempiterne": "sempiterno",
    "sempiterni": "sempiterno",
    "semplici": "semplice",
    "sempliciotta": "sempliciotto",
    "sempliciotte": "sempliciotto",
    "sempliciotti": "sempliciotto",
    "semplicismi": "semplicismo",
    "sempliciste": "semplicista",
    "semplicisti": "semplicista",
    "semplicistica": "semplicistico",
    "semplicistiche": "semplicistico",
    "semplicistici": "semplicistico",
    "semplifica": "semplificare",
    "semplificai": "semplificare",
    "semplificammo": "semplificare",
    "semplifican": "semplificare",
    "semplificando": "semplificare",
    "semplificano": "semplificare",
    "semplificante": "semplificare",
    "semplificanti": "semplificare",
    "semplificar": "semplificare",
    "semplificaron": "semplificare",
    "semplificarono": "semplificare",
    "semplificasse": "semplificare",
    "semplificasser": "semplificare",
    "semplificassero": "semplificare",
    "semplificassi": "semplificare",
    "semplificassimo": "semplificare",
    "semplificaste": "semplificare",
    "semplificasti": "semplificare",
    "semplificata": "semplificare",
    "semplificate": "semplificare",
    "semplificati": "semplificare",
    "semplificato": "semplificare",
    "semplificava": "semplificare",
    "semplificavamo": "semplificare",
    "semplificavan": "semplificare",
    "semplificavano": "semplificare",
    "semplificavate": "semplificare",
    "semplificavi": "semplificare",
    "semplificavo": "semplificare",
    "semplificazioni": "semplificazione",
    "semplificherai": "semplificare",
    "semplificheran": "semplificare",
    "semplificheranno": "semplificare",
    "semplificherebbe": "semplificare",
    "semplificherebber": "semplificare",
    "semplificherebbero": "semplificare",
    "semplificherei": "semplificare",
    "semplificheremmo": "semplificare",
    "semplificheremo": "semplificare",
    "semplifichereste": "semplificare",
    "semplificheresti": "semplificare",
    "semplificherete": "semplificare",
    "semplificherà": "semplificare",
    "semplificherò": "semplificare",
    "semplifichi": "semplificare",
    "semplifichiamo": "semplificare",
    "semplifichiate": "semplificare",
    "semplifichin": "semplificare",
    "semplifichino": "semplificare",
    "semplifico": "semplificare",
    "semplificò": "semplificare",
    "sempreverdi": "sempreverde",
    "senati": "senato",
    "senatori": "senatorio",
    "senatoria": "senatorio",
    "senatoriali": "senatoriale",
    "senatorie": "senatorio",
    "senatrici": "senatrice",
    "senegalesi": "senegalese",
    "senescenti": "senescente",
    "senescenze": "senescenza",
    "senesi": "senese",
    "seni": "seno",
    "senili": "senile",
    "senni": "senno",
    "sensali": "sensale",
    "sensata": "sensato",
    "sensate": "sensato",
    "sensati": "sensato",
    "sensazionali": "sensazionale",
    "sensazionalismi": "sensazionalismo",
    "sensazioni": "sensazione",
    "sensi": "senso",
    "sensibili": "sensibile",
    "sensibilizza": "sensibilizzare",
    "sensibilizzai": "sensibilizzare",
    "sensibilizzammo": "sensibilizzare",
    "sensibilizzan": "sensibilizzare",
    "sensibilizzando": "sensibilizzare",
    "sensibilizzano": "sensibilizzare",
    "sensibilizzante": "sensibilizzare",
    "sensibilizzanti": "sensibilizzare",
    "sensibilizzar": "sensibilizzare",
    "sensibilizzaron": "sensibilizzare",
    "sensibilizzarono": "sensibilizzare",
    "sensibilizzasse": "sensibilizzare",
    "sensibilizzasser": "sensibilizzare",
    "sensibilizzassero": "sensibilizzare",
    "sensibilizzassi": "sensibilizzare",
    "sensibilizzassimo": "sensibilizzare",
    "sensibilizzaste": "sensibilizzare",
    "sensibilizzasti": "sensibilizzare",
    "sensibilizzata": "sensibilizzare",
    "sensibilizzate": "sensibilizzare",
    "sensibilizzati": "sensibilizzare",
    "sensibilizzato": "sensibilizzare",
    "sensibilizzava": "sensibilizzare",
    "sensibilizzavamo": "sensibilizzare",
    "sensibilizzavan": "sensibilizzare",
    "sensibilizzavano": "sensibilizzare",
    "sensibilizzavate": "sensibilizzare",
    "sensibilizzavi": "sensibilizzare",
    "sensibilizzavo": "sensibilizzare",
    "sensibilizzazioni": "sensibilizzazione",
    "sensibilizzerai": "sensibilizzare",
    "sensibilizzeran": "sensibilizzare",
    "sensibilizzeranno": "sensibilizzare",
    "sensibilizzerebbe": "sensibilizzare",
    "sensibilizzerebber": "sensibilizzare",
    "sensibilizzerebbero": "sensibilizzare",
    "sensibilizzerei": "sensibilizzare",
    "sensibilizzeremmo": "sensibilizzare",
    "sensibilizzeremo": "sensibilizzare",
    "sensibilizzereste": "sensibilizzare",
    "sensibilizzeresti": "sensibilizzare",
    "sensibilizzerete": "sensibilizzare",
    "sensibilizzerà": "sensibilizzare",
    "sensibilizzerò": "sensibilizzare",
    "sensibilizzi": "sensibilizzare",
    "sensibilizziamo": "sensibilizzare",
    "sensibilizziate": "sensibilizzare",
    "sensibilizzin": "sensibilizzare",
    "sensibilizzino": "sensibilizzare",
    "sensibilizzo": "sensibilizzare",
    "sensibilizzò": "sensibilizzare",
    "sensitiva": "sensitivo",
    "sensitive": "sensitivo",
    "sensitivi": "sensitivo",
    "sensori": "sensorio",
    "sensoria": "sensorio",
    "sensoriali": "sensoriale",
    "sensorie": "sensorio",
    "sensuali": "sensuale",
    "senta": "sentire",
    "sentan": "sentire",
    "sentano": "sentire",
    "sente": "sentire",
    "sentendo": "sentire",
    "sentenze": "sentenza",
    "sentenze-ordinanze": "sentenza-ordinanza",
    "sentenzi": "sentenziare",
    "sentenzia": "sentenziare",
    "sentenziai": "sentenziare",
    "sentenziammo": "sentenziare",
    "sentenziamo": "sentenziare",
    "sentenzian": "sentenziare",
    "sentenziando": "sentenziare",
    "sentenziano": "sentenziare",
    "sentenziante": "sentenziare",
    "sentenzianti": "sentenziare",
    "sentenziar": "sentenziare",
    "sentenziaron": "sentenziare",
    "sentenziarono": "sentenziare",
    "sentenziasse": "sentenziare",
    "sentenziasser": "sentenziare",
    "sentenziassero": "sentenziare",
    "sentenziassi": "sentenziare",
    "sentenziassimo": "sentenziare",
    "sentenziaste": "sentenziare",
    "sentenziasti": "sentenziare",
    "sentenziata": "sentenziare",
    "sentenziate": "sentenziare",
    "sentenziati": "sentenziare",
    "sentenziato": "sentenziare",
    "sentenziava": "sentenziare",
    "sentenziavamo": "sentenziare",
    "sentenziavan": "sentenziare",
    "sentenziavano": "sentenziare",
    "sentenziavate": "sentenziare",
    "sentenziavi": "sentenziare",
    "sentenziavo": "sentenziare",
    "sentenzierai": "sentenziare",
    "sentenzieran": "sentenziare",
    "sentenzieranno": "sentenziare",
    "sentenzierebbe": "sentenziare",
    "sentenzierebber": "sentenziare",
    "sentenzierebbero": "sentenziare",
    "sentenzierei": "sentenziare",
    "sentenzieremmo": "sentenziare",
    "sentenzieremo": "sentenziare",
    "sentenziereste": "sentenziare",
    "sentenzieresti": "sentenziare",
    "sentenzierete": "sentenziare",
    "sentenzierà": "sentenziare",
    "sentenzierò": "sentenziare",
    "sentenzin": "sentenziare",
    "sentenzino": "sentenziare",
    "sentenzio": "sentenziare",
    "sentenziò": "sentenziare",
    "senti": "sentire",
    "sentiamo": "sentire",
    "sentiate": "sentire",
    "sentieri": "sentiero",
    "sentii": "sentire",
    "sentimentali": "sentimentale",
    "sentimentalismi": "sentimentalismo",
    "sentimenti": "sentimento",
    "sentimmo": "sentire",
    "sentine": "sentina",
    "sentinelle": "sentinella",
    "sentir": "sentire",
    "sentirai": "sentire",
    "sentiran": "sentire",
    "sentiranno": "sentire",
    "sentirebbe": "sentire",
    "sentirebber": "sentire",
    "sentirebbero": "sentire",
    "sentirei": "sentire",
    "sentiremmo": "sentire",
    "sentiremo": "sentire",
    "sentireste": "sentire",
    "sentiresti": "sentire",
    "sentirete": "sentire",
    "sentiron": "sentire",
    "sentirono": "sentire",
    "sentirà": "sentire",
    "sentirò": "sentire",
    "sentisse": "sentire",
    "sentisser": "sentire",
    "sentissero": "sentire",
    "sentissi": "sentire",
    "sentissimo": "sentire",
    "sentiste": "sentire",
    "sentisti": "sentire",
    "sentita": "sentito",
    "sentite": "sentito",
    "sentiti": "sentito",
    "sentito": "sentire",
    "sentiva": "sentire",
    "sentivamo": "sentire",
    "sentivan": "sentire",
    "sentivano": "sentire",
    "sentivate": "sentire",
    "sentivi": "sentire",
    "sentivo": "sentire",
    "sento": "sentire",
    "senton": "sentire",
    "sentono": "sentire",
    "sentori": "sentore",
    "sentì": "sentire",
    "senz'": "senza",
    "senziente": "sentire",
    "senzienti": "sentire",
    "separa": "separare",
    "separai": "separare",
    "separammo": "separare",
    "separan": "separare",
    "separando": "separare",
    "separano": "separare",
    "separante": "separare",
    "separanti": "separare",
    "separar": "separare",
    "separaron": "separare",
    "separarono": "separare",
    "separasse": "separare",
    "separasser": "separare",
    "separassero": "separare",
    "separassi": "separare",
    "separassimo": "separare",
    "separaste": "separare",
    "separasti": "separare",
    "separata": "separato",
    "separate": "separato",
    "separatezze": "separatezza",
    "separati": "separato",
    "separatismi": "separatismo",
    "separatisti": "separatista",
    "separatistica": "separatistico",
    "separatistiche": "separatistico",
    "separatistici": "separatistico",
    "separato": "separare",
    "separava": "separare",
    "separavamo": "separare",
    "separavan": "separare",
    "separavano": "separare",
    "separavate": "separare",
    "separavi": "separare",
    "separavo": "separare",
    "separazioni": "separazione",
    "separerai": "separare",
    "separeran": "separare",
    "separeranno": "separare",
    "separerebbe": "separare",
    "separerebber": "separare",
    "separerebbero": "separare",
    "separerei": "separare",
    "separeremmo": "separare",
    "separeremo": "separare",
    "separereste": "separare",
    "separeresti": "separare",
    "separerete": "separare",
    "separerà": "separare",
    "separerò": "separare",
    "separi": "separare",
    "separiamo": "separare",
    "separiate": "separare",
    "separin": "separare",
    "separino": "separare",
    "separo": "separare",
    "separò": "separare",
    "sepolcrali": "sepolcrale",
    "sepolcri": "sepolcro",
    "sepolta": "sepolto",
    "sepolte": "sepolto",
    "sepolti": "sepolto",
    "sepolture": "sepoltura",
    "seppe": "sapere",
    "seppellendo": "seppellire",
    "seppellente": "seppellire",
    "seppellenti": "seppellire",
    "seppelliamo": "seppellire",
    "seppelliate": "seppellire",
    "seppellii": "seppellire",
    "seppellimenti": "seppellimento",
    "seppellimmo": "seppellire",
    "seppellir": "seppellire",
    "seppellirai": "seppellire",
    "seppelliran": "seppellire",
    "seppelliranno": "seppellire",
    "seppellirebbe": "seppellire",
    "seppellirebber": "seppellire",
    "seppellirebbero": "seppellire",
    "seppellirei": "seppellire",
    "seppelliremmo": "seppellire",
    "seppelliremo": "seppellire",
    "seppellireste": "seppellire",
    "seppelliresti": "seppellire",
    "seppellirete": "seppellire",
    "seppelliron": "seppellire",
    "seppellirono": "seppellire",
    "seppellirà": "seppellire",
    "seppellirò": "seppellire",
    "seppellisca": "seppellire",
    "seppelliscan": "seppellire",
    "seppelliscano": "seppellire",
    "seppellisce": "seppellire",
    "seppellisci": "seppellire",
    "seppellisco": "seppellire",
    "seppelliscon": "seppellire",
    "seppelliscono": "seppellire",
    "seppellisse": "seppellire",
    "seppellisser": "seppellire",
    "seppellissero": "seppellire",
    "seppellissi": "seppellire",
    "seppellissimo": "seppellire",
    "seppelliste": "seppellire",
    "seppellisti": "seppellire",
    "seppellita": "seppellito",
    "seppellite": "seppellito",
    "seppelliti": "seppellito",
    "seppellito": "seppellire",
    "seppelliva": "seppellire",
    "seppellivamo": "seppellire",
    "seppellivan": "seppellire",
    "seppellivano": "seppellire",
    "seppellivate": "seppellire",
    "seppellivi": "seppellire",
    "seppellivo": "seppellire",
    "seppellì": "seppellire",
    "sepper": "sapere",
    "seppero": "sapere",
    "seppi": "sapere",
    "seppie": "seppia",
    "sequele": "sequela",
    "sequenze": "sequenza",
    "sequestra": "sequestrare",
    "sequestrai": "sequestrare",
    "sequestrammo": "sequestrare",
    "sequestran": "sequestrare",
    "sequestrando": "sequestrare",
    "sequestrano": "sequestrare",
    "sequestrante": "sequestrare",
    "sequestranti": "sequestrare",
    "sequestrar": "sequestrare",
    "sequestraron": "sequestrare",
    "sequestrarono": "sequestrare",
    "sequestrasse": "sequestrare",
    "sequestrasser": "sequestrare",
    "sequestrassero": "sequestrare",
    "sequestrassi": "sequestrare",
    "sequestrassimo": "sequestrare",
    "sequestraste": "sequestrare",
    "sequestrasti": "sequestrare",
    "sequestrata": "sequestrato",
    "sequestrate": "sequestrato",
    "sequestrati": "sequestrato",
    "sequestrato": "sequestrare",
    "sequestratori": "sequestratore",
    "sequestrava": "sequestrare",
    "sequestravamo": "sequestrare",
    "sequestravan": "sequestrare",
    "sequestravano": "sequestrare",
    "sequestravate": "sequestrare",
    "sequestravi": "sequestrare",
    "sequestravo": "sequestrare",
    "sequestrerai": "sequestrare",
    "sequestreran": "sequestrare",
    "sequestreranno": "sequestrare",
    "sequestrerebbe": "sequestrare",
    "sequestrerebber": "sequestrare",
    "sequestrerebbero": "sequestrare",
    "sequestrerei": "sequestrare",
    "sequestreremmo": "sequestrare",
    "sequestreremo": "sequestrare",
    "sequestrereste": "sequestrare",
    "sequestreresti": "sequestrare",
    "sequestrerete": "sequestrare",
    "sequestrerà": "sequestrare",
    "sequestrerò": "sequestrare",
    "sequestri": "sequestro",
    "sequestriamo": "sequestrare",
    "sequestriate": "sequestrare",
    "sequestrin": "sequestrare",
    "sequestrino": "sequestrare",
    "sequestro": "sequestrare",
    "sequestrò": "sequestrare",
    "sequoie": "sequoia",
    "seracchi": "seracco",
    "serafica": "serafico",
    "serafiche": "serafico",
    "serafici": "serafico",
    "serali": "serale",
    "serate": "serata",
    "serba": "serbare",
    "serbai": "serbare",
    "serbammo": "serbare",
    "serban": "serbare",
    "serbando": "serbare",
    "serbano": "serbare",
    "serbante": "serbare",
    "serbanti": "serbare",
    "serbar": "serbare",
    "serbaron": "serbare",
    "serbarono": "serbare",
    "serbasse": "serbare",
    "serbasser": "serbare",
    "serbassero": "serbare",
    "serbassi": "serbare",
    "serbassimo": "serbare",
    "serbaste": "serbare",
    "serbasti": "serbare",
    "serbata": "serbare",
    "serbate": "serbare",
    "serbati": "serbare",
    "serbato": "serbare",
    "serbatoi": "serbatoio",
    "serbava": "serbare",
    "serbavamo": "serbare",
    "serbavan": "serbare",
    "serbavano": "serbare",
    "serbavate": "serbare",
    "serbavi": "serbare",
    "serbavo": "serbare",
    "serbe": "serba",
    "serberai": "serbare",
    "serberan": "serbare",
    "serberanno": "serbare",
    "serberebbe": "serbare",
    "serberebber": "serbare",
    "serberebbero": "serbare",
    "serberei": "serbare",
    "serberemmo": "serbare",
    "serberemo": "serbare",
    "serbereste": "serbare",
    "serberesti": "serbare",
    "serberete": "serbare",
    "serberà": "serbare",
    "serberò": "serbare",
    "serbi": "serbo",
    "serbiamo": "serbare",
    "serbiate": "serbare",
    "serbin": "serbare",
    "serbino": "serbare",
    "serbo": "serbare",
    "serbo-albanesi": "serbo-albanese",
    "serbo-bosniaca": "serbo-bosniaco",
    "serbo-bosniache": "serbo-bosniaco",
    "serbo-bosniaci": "serbo-bosniaco",
    "serbo-croati": "serbo-croato",
    "serbo-kosovara": "serbo-kosovaro",
    "serbo-kosovare": "serbo-kosovaro",
    "serbo-kosovari": "serbo-kosovaro",
    "serbò": "serbare",
    "sere": "sera",
    "serena": "sereno",
    "serenai": "serenare",
    "serenammo": "serenare",
    "serenan": "serenare",
    "serenando": "serenare",
    "serenano": "serenare",
    "serenante": "serenare",
    "serenanti": "serenare",
    "serenar": "serenare",
    "serenaron": "serenare",
    "serenarono": "serenare",
    "serenasse": "serenare",
    "serenasser": "serenare",
    "serenassero": "serenare",
    "serenassi": "serenare",
    "serenassimo": "serenare",
    "serenaste": "serenare",
    "serenasti": "serenare",
    "serenata": "serenare",
    "serenate": "serenata",
    "serenati": "serenare",
    "serenato": "serenare",
    "serenava": "serenare",
    "serenavamo": "serenare",
    "serenavan": "serenare",
    "serenavano": "serenare",
    "serenavate": "serenare",
    "serenavi": "serenare",
    "serenavo": "serenare",
    "serene": "sereno",
    "serenerai": "serenare",
    "sereneran": "serenare",
    "sereneranno": "serenare",
    "serenerebbe": "serenare",
    "serenerebber": "serenare",
    "serenerebbero": "serenare",
    "serenerei": "serenare",
    "sereneremmo": "serenare",
    "sereneremo": "serenare",
    "serenereste": "serenare",
    "sereneresti": "serenare",
    "serenerete": "serenare",
    "serenerà": "serenare",
    "serenerò": "serenare",
    "sereni": "sereno",
    "sereniamo": "serenare",
    "sereniate": "serenare",
    "serenin": "serenare",
    "serenino": "serenare",
    "sereno": "serenare",
    "serenò": "serenare",
    "sergenti": "sergente",
    "seri": "serio",
    "seria": "serio",
    "seriai": "seriare",
    "seriali": "seriale",
    "seriammo": "seriare",
    "seriamo": "seriare",
    "serian": "seriare",
    "seriando": "seriare",
    "seriano": "seriare",
    "seriante": "seriare",
    "serianti": "seriare",
    "seriar": "seriare",
    "seriaron": "seriare",
    "seriarono": "seriare",
    "seriasse": "seriare",
    "seriasser": "seriare",
    "seriassero": "seriare",
    "seriassi": "seriare",
    "seriassimo": "seriare",
    "seriaste": "seriare",
    "seriasti": "seriare",
    "seriata": "seriare",
    "seriate": "seriare",
    "seriati": "seriare",
    "seriato": "seriare",
    "seriava": "seriare",
    "seriavamo": "seriare",
    "seriavan": "seriare",
    "seriavano": "seriare",
    "seriavate": "seriare",
    "seriavi": "seriare",
    "seriavo": "seriare",
    "serica": "serico",
    "seriche": "serico",
    "serici": "serico",
    "serie": "serio",
    "serierai": "seriare",
    "serieran": "seriare",
    "serieranno": "seriare",
    "serierebbe": "seriare",
    "serierebber": "seriare",
    "serierebbero": "seriare",
    "serierei": "seriare",
    "serieremmo": "seriare",
    "serieremo": "seriare",
    "seriereste": "seriare",
    "serieresti": "seriare",
    "serierete": "seriare",
    "serierà": "seriare",
    "serierò": "seriare",
    "serigrafie": "serigrafia",
    "serin": "seriare",
    "serino": "seriare",
    "serio": "seriare",
    "seriosa": "serioso",
    "seriose": "serioso",
    "seriosi": "serioso",
    "seriò": "seriare",
    "sermoneggerai": "sermoneggiare",
    "sermoneggeran": "sermoneggiare",
    "sermoneggeranno": "sermoneggiare",
    "sermoneggerebbe": "sermoneggiare",
    "sermoneggerebber": "sermoneggiare",
    "sermoneggerebbero": "sermoneggiare",
    "sermoneggerei": "sermoneggiare",
    "sermoneggeremmo": "sermoneggiare",
    "sermoneggeremo": "sermoneggiare",
    "sermoneggereste": "sermoneggiare",
    "sermoneggeresti": "sermoneggiare",
    "sermoneggerete": "sermoneggiare",
    "sermoneggerà": "sermoneggiare",
    "sermoneggerò": "sermoneggiare",
    "sermoneggi": "sermoneggiare",
    "sermoneggia": "sermoneggiare",
    "sermoneggiai": "sermoneggiare",
    "sermoneggiammo": "sermoneggiare",
    "sermoneggiamo": "sermoneggiare",
    "sermoneggian": "sermoneggiare",
    "sermoneggiando": "sermoneggiare",
    "sermoneggiano": "sermoneggiare",
    "sermoneggiante": "sermoneggiare",
    "sermoneggianti": "sermoneggiare",
    "sermoneggiar": "sermoneggiare",
    "sermoneggiaron": "sermoneggiare",
    "sermoneggiarono": "sermoneggiare",
    "sermoneggiasse": "sermoneggiare",
    "sermoneggiasser": "sermoneggiare",
    "sermoneggiassero": "sermoneggiare",
    "sermoneggiassi": "sermoneggiare",
    "sermoneggiassimo": "sermoneggiare",
    "sermoneggiaste": "sermoneggiare",
    "sermoneggiasti": "sermoneggiare",
    "sermoneggiata": "sermoneggiare",
    "sermoneggiate": "sermoneggiare",
    "sermoneggiati": "sermoneggiare",
    "sermoneggiato": "sermoneggiare",
    "sermoneggiava": "sermoneggiare",
    "sermoneggiavamo": "sermoneggiare",
    "sermoneggiavan": "sermoneggiare",
    "sermoneggiavano": "sermoneggiare",
    "sermoneggiavate": "sermoneggiare",
    "sermoneggiavi": "sermoneggiare",
    "sermoneggiavo": "sermoneggiare",
    "sermoneggin": "sermoneggiare",
    "sermoneggino": "sermoneggiare",
    "sermoneggio": "sermoneggiare",
    "sermoneggiò": "sermoneggiare",
    "sermoni": "sermone",
    "serotonine": "serotonina",
    "serpa": "serpere",
    "serpan": "serpere",
    "serpano": "serpere",
    "serpe": "serpere",
    "serpeggerai": "serpeggiare",
    "serpeggeran": "serpeggiare",
    "serpeggeranno": "serpeggiare",
    "serpeggerebbe": "serpeggiare",
    "serpeggerebber": "serpeggiare",
    "serpeggerebbero": "serpeggiare",
    "serpeggerei": "serpeggiare",
    "serpeggeremmo": "serpeggiare",
    "serpeggeremo": "serpeggiare",
    "serpeggereste": "serpeggiare",
    "serpeggeresti": "serpeggiare",
    "serpeggerete": "serpeggiare",
    "serpeggerà": "serpeggiare",
    "serpeggerò": "serpeggiare",
    "serpeggi": "serpeggiare",
    "serpeggia": "serpeggiare",
    "serpeggiai": "serpeggiare",
    "serpeggiammo": "serpeggiare",
    "serpeggiamo": "serpeggiare",
    "serpeggian": "serpeggiare",
    "serpeggiando": "serpeggiare",
    "serpeggiano": "serpeggiare",
    "serpeggiante": "serpeggiare",
    "serpeggianti": "serpeggiare",
    "serpeggiar": "serpeggiare",
    "serpeggiaron": "serpeggiare",
    "serpeggiarono": "serpeggiare",
    "serpeggiasse": "serpeggiare",
    "serpeggiasser": "serpeggiare",
    "serpeggiassero": "serpeggiare",
    "serpeggiassi": "serpeggiare",
    "serpeggiassimo": "serpeggiare",
    "serpeggiaste": "serpeggiare",
    "serpeggiasti": "serpeggiare",
    "serpeggiata": "serpeggiare",
    "serpeggiate": "serpeggiare",
    "serpeggiati": "serpeggiare",
    "serpeggiato": "serpeggiare",
    "serpeggiava": "serpeggiare",
    "serpeggiavamo": "serpeggiare",
    "serpeggiavan": "serpeggiare",
    "serpeggiavano": "serpeggiare",
    "serpeggiavate": "serpeggiare",
    "serpeggiavi": "serpeggiare",
    "serpeggiavo": "serpeggiare",
    "serpeggin": "serpeggiare",
    "serpeggino": "serpeggiare",
    "serpeggio": "serpeggiare",
    "serpeggiò": "serpeggiare",
    "serpei": "serpere",
    "serpemmo": "serpere",
    "serpendo": "serpere",
    "serpente": "serpere",
    "serpenti": "serpere",
    "serpentina": "serpentino",
    "serpentine": "serpentino",
    "serpentini": "serpentino",
    "serpentoni": "serpentone",
    "serper": "serpere",
    "serperai": "serpere",
    "serperan": "serpere",
    "serperanno": "serpere",
    "serperebbe": "serpere",
    "serperebber": "serpere",
    "serperebbero": "serpere",
    "serperei": "serpere",
    "serperemmo": "serpere",
    "serperemo": "serpere",
    "serpereste": "serpere",
    "serperesti": "serpere",
    "serperete": "serpere",
    "serperon": "serpere",
    "serperono": "serpere",
    "serperà": "serpere",
    "serperò": "serpere",
    "serpesse": "serpere",
    "serpesser": "serpere",
    "serpessero": "serpere",
    "serpessi": "serpere",
    "serpessimo": "serpere",
    "serpeste": "serpere",
    "serpesti": "serpere",
    "serpete": "serpere",
    "serpeva": "serpere",
    "serpevamo": "serpere",
    "serpevan": "serpere",
    "serpevano": "serpere",
    "serpevate": "serpere",
    "serpevi": "serpere",
    "serpevo": "serpere",
    "serpi": "serpere",
    "serpiamo": "serpere",
    "serpiate": "serpere",
    "serpo": "serpere",
    "serpon": "serpere",
    "serpono": "serpere",
    "serputa": "serpere",
    "serpute": "serpere",
    "serputi": "serpere",
    "serputo": "serpere",
    "serpè": "serpere",
    "serra": "serrare",
    "serragli": "serraglio",
    "serrai": "serrare",
    "serrammo": "serrare",
    "serran": "serrare",
    "serrande": "serranda",
    "serrando": "serrare",
    "serrano": "serrare",
    "serrante": "serrare",
    "serranti": "serrare",
    "serrar": "serrare",
    "serraron": "serrare",
    "serrarono": "serrare",
    "serrasse": "serrare",
    "serrasser": "serrare",
    "serrassero": "serrare",
    "serrassi": "serrare",
    "serrassimo": "serrare",
    "serraste": "serrare",
    "serrasti": "serrare",
    "serrata": "serrato",
    "serrate": "serrato",
    "serrati": "serrato",
    "serrato": "serrare",
    "serrature": "serratura",
    "serrava": "serrare",
    "serravamo": "serrare",
    "serravan": "serrare",
    "serravano": "serrare",
    "serravate": "serrare",
    "serravi": "serrare",
    "serravo": "serrare",
    "serre": "serra",
    "serrerai": "serrare",
    "serreran": "serrare",
    "serreranno": "serrare",
    "serrerebbe": "serrare",
    "serrerebber": "serrare",
    "serrerebbero": "serrare",
    "serrerei": "serrare",
    "serreremmo": "serrare",
    "serreremo": "serrare",
    "serrereste": "serrare",
    "serreresti": "serrare",
    "serrerete": "serrare",
    "serrerà": "serrare",
    "serrerò": "serrare",
    "serri": "serrare",
    "serriamo": "serrare",
    "serriate": "serrare",
    "serrin": "serrare",
    "serrino": "serrare",
    "serro": "serrare",
    "serrò": "serrare",
    "serva": "servire",
    "servan": "servire",
    "servano": "servire",
    "serve": "servire",
    "servendo": "servire",
    "servente": "servire",
    "serventi": "servire",
    "servette": "servetta",
    "servi": "servo",
    "serviamo": "servire",
    "serviate": "servire",
    "servigi": "servigio",
    "servii": "servire",
    "servili": "servile",
    "servilismi": "servilismo",
    "servimmo": "servire",
    "servir": "servire",
    "servirai": "servire",
    "serviran": "servire",
    "serviranno": "servire",
    "servirebbe": "servire",
    "servirebber": "servire",
    "servirebbero": "servire",
    "servirei": "servire",
    "serviremmo": "servire",
    "serviremo": "servire",
    "servireste": "servire",
    "serviresti": "servire",
    "servirete": "servire",
    "serviron": "servire",
    "servirono": "servire",
    "servirà": "servire",
    "servirò": "servire",
    "servisse": "servire",
    "servisser": "servire",
    "servissero": "servire",
    "servissi": "servire",
    "servissimo": "servire",
    "serviste": "servire",
    "servisti": "servire",
    "servita": "servire",
    "servite": "servire",
    "serviti": "servire",
    "servito": "servire",
    "servitori": "servitore",
    "serviva": "servire",
    "servivamo": "servire",
    "servivan": "servire",
    "servivano": "servire",
    "servivate": "servire",
    "servivi": "servire",
    "servivo": "servire",
    "servizi": "servizo",
    "servizietti": "servizietto",
    "servizievoli": "servizievole",
    "servo": "servire",
    "servon": "servire",
    "servono": "servire",
    "servosterzi": "servosterzo",
    "servì": "servire",
    "sesquipedali": "sesquipedale",
    "sessantacinquesima": "sessantacinquesimo",
    "sessantacinquesime": "sessantacinquesimo",
    "sessantacinquesimi": "sessantacinquesimo",
    "sessantaduesima": "sessantaduesimo",
    "sessantaduesime": "sessantaduesimo",
    "sessantaduesimi": "sessantaduesimo",
    "sessantanovesima": "sessantanovesimo",
    "sessantanovesime": "sessantanovesimo",
    "sessantanovesimi": "sessantanovesimo",
    "sessantaquattresima": "sessantaquattresimo",
    "sessantaquattresime": "sessantaquattresimo",
    "sessantaquattresimi": "sessantaquattresimo",
    "sessantaseiesima": "sessantaseiesimo",
    "sessantaseiesime": "sessantaseiesimo",
    "sessantaseiesimi": "sessantaseiesimo",
    "sessantasettesima": "sessantasettesimo",
    "sessantasettesime": "sessantasettesimo",
    "sessantasettesimi": "sessantasettesimo",
    "sessantatreesima": "sessantatreesimo",
    "sessantatreesime": "sessantatreesimo",
    "sessantatreesimi": "sessantatreesimo",
    "sessantenni": "sessantenne",
    "sessantesima": "sessantesimo",
    "sessantesime": "sessantesimo",
    "sessantesimi": "sessantesimo",
    "sessantine": "sessantina",
    "sessantotta": "sessantotto",
    "sessantotte": "sessantotto",
    "sessantottesca": "sessantottesco",
    "sessantottesche": "sessantottesco",
    "sessantotteschi": "sessantottesco",
    "sessantottesima": "sessantottesimo",
    "sessantottesime": "sessantottesimo",
    "sessantottesimi": "sessantottesimo",
    "sessantotti": "sessantotto",
    "sessantottini": "sessantottino",
    "sessantunesima": "sessantunesimo",
    "sessantunesime": "sessantunesimo",
    "sessantunesimi": "sessantunesimo",
    "sessi": "sesso",
    "sessioni": "sessione",
    "sessiste": "sessista",
    "sessisti": "sessista",
    "sessuali": "sessuale",
    "sessuata": "sessuato",
    "sessuate": "sessuato",
    "sessuati": "sessuato",
    "sessuofobi": "sessuofobo",
    "sessuologhe": "sessuologa",
    "sessuologi": "sessuologo",
    "sesta": "sesto",
    "seste": "sesto",
    "sestetti": "sestetto",
    "sesti": "sesto",
    "sestieri": "sestiere",
    "setaccerai": "setacciare",
    "setacceran": "setacciare",
    "setacceranno": "setacciare",
    "setaccerebbe": "setacciare",
    "setaccerebber": "setacciare",
    "setaccerebbero": "setacciare",
    "setaccerei": "setacciare",
    "setacceremmo": "setacciare",
    "setacceremo": "setacciare",
    "setaccereste": "setacciare",
    "setacceresti": "setacciare",
    "setaccerete": "setacciare",
    "setaccerà": "setacciare",
    "setaccerò": "setacciare",
    "setacci": "setaccio",
    "setaccia": "setacciare",
    "setacciai": "setacciare",
    "setacciammo": "setacciare",
    "setacciamo": "setacciare",
    "setaccian": "setacciare",
    "setacciando": "setacciare",
    "setacciano": "setacciare",
    "setacciante": "setacciare",
    "setaccianti": "setacciare",
    "setacciar": "setacciare",
    "setacciaron": "setacciare",
    "setacciarono": "setacciare",
    "setacciasse": "setacciare",
    "setacciasser": "setacciare",
    "setacciassero": "setacciare",
    "setacciassi": "setacciare",
    "setacciassimo": "setacciare",
    "setacciaste": "setacciare",
    "setacciasti": "setacciare",
    "setacciata": "setacciare",
    "setacciate": "setacciare",
    "setacciati": "setacciare",
    "setacciato": "setacciare",
    "setacciava": "setacciare",
    "setacciavamo": "setacciare",
    "setacciavan": "setacciare",
    "setacciavano": "setacciare",
    "setacciavate": "setacciare",
    "setacciavi": "setacciare",
    "setacciavo": "setacciare",
    "setaccin": "setacciare",
    "setaccino": "setacciare",
    "setaccio": "setacciare",
    "setacciò": "setacciare",
    "sete": "seta",
    "seti": "sete",
    "settantacinquesima": "settantacinquesimo",
    "settantacinquesime": "settantacinquesimo",
    "settantacinquesimi": "settantacinquesimo",
    "settantaduesima": "settantaduesimo",
    "settantaduesime": "settantaduesimo",
    "settantaduesimi": "settantaduesimo",
    "settantanovesima": "settantanovesimo",
    "settantanovesime": "settantanovesimo",
    "settantanovesimi": "settantanovesimo",
    "settantaquattresima": "settantaquattresimo",
    "settantaquattresime": "settantaquattresimo",
    "settantaquattresimi": "settantaquattresimo",
    "settantaseiesima": "settantaseiesimo",
    "settantaseiesime": "settantaseiesimo",
    "settantaseiesimi": "settantaseiesimo",
    "settantasettesima": "settantasettesimo",
    "settantasettesime": "settantasettesimo",
    "settantasettesimi": "settantasettesimo",
    "settantatreesima": "settantatreesimo",
    "settantatreesime": "settantatreesimo",
    "settantatreesimi": "settantatreesimo",
    "settantenni": "settantennio",
    "settantesima": "settantesimo",
    "settantesime": "settantesimo",
    "settantesimi": "settantesimo",
    "settantine": "settantina",
    "settantottesima": "settantottesimo",
    "settantottesime": "settantottesimo",
    "settantottesimi": "settantottesimo",
    "settantunesima": "settantunesimo",
    "settantunesime": "settantunesimo",
    "settantunesimi": "settantunesimo",
    "settari": "settario",
    "settaria": "settario",
    "settarie": "settario",
    "settarismi": "settarismo",
    "sette": "setta",
    "settecentesca": "settecentesco",
    "settecentesche": "settecentesco",
    "settecenteschi": "settecentesco",
    "settecentesima": "settecentesimo",
    "settecentesime": "settecentesimo",
    "settecentesimi": "settecentesimo",
    "settembri": "settembre",
    "settembrina": "settembrino",
    "settembrine": "settembrino",
    "settembrini": "settembrino",
    "settemillesima": "settemillesimo",
    "settemillesime": "settemillesimo",
    "settemillesimi": "settemillesimo",
    "settennali": "settennale",
    "settennati": "settennato",
    "settennii": "settennio",
    "settentrionali": "settentrionale",
    "settentrioni": "settentrione",
    "setti": "setto",
    "settima": "settimo",
    "settimanali": "settimanale",
    "settimane": "settimana",
    "settime": "settimo",
    "settimi": "settimo",
    "settimina": "settimino",
    "settimine": "settimino",
    "settimini": "settimino",
    "settori": "settore",
    "settoriali": "settoriale",
    "severa": "severo",
    "severe": "severo",
    "severi": "severo",
    "sevizi": "seviziare",
    "sevizia": "seviziare",
    "seviziai": "seviziare",
    "seviziammo": "seviziare",
    "seviziamo": "seviziare",
    "sevizian": "seviziare",
    "seviziando": "seviziare",
    "seviziano": "seviziare",
    "seviziante": "seviziare",
    "sevizianti": "seviziare",
    "seviziar": "seviziare",
    "seviziaron": "seviziare",
    "seviziarono": "seviziare",
    "seviziasse": "seviziare",
    "seviziasser": "seviziare",
    "seviziassero": "seviziare",
    "seviziassi": "seviziare",
    "seviziassimo": "seviziare",
    "seviziaste": "seviziare",
    "seviziasti": "seviziare",
    "seviziata": "seviziare",
    "seviziate": "seviziare",
    "seviziati": "seviziare",
    "seviziato": "seviziare",
    "seviziatori": "seviziatore",
    "seviziava": "seviziare",
    "seviziavamo": "seviziare",
    "seviziavan": "seviziare",
    "seviziavano": "seviziare",
    "seviziavate": "seviziare",
    "seviziavi": "seviziare",
    "seviziavo": "seviziare",
    "sevizie": "sevizia",
    "sevizierai": "seviziare",
    "sevizieran": "seviziare",
    "sevizieranno": "seviziare",
    "sevizierebbe": "seviziare",
    "sevizierebber": "seviziare",
    "sevizierebbero": "seviziare",
    "sevizierei": "seviziare",
    "sevizieremmo": "seviziare",
    "sevizieremo": "seviziare",
    "seviziereste": "seviziare",
    "sevizieresti": "seviziare",
    "sevizierete": "seviziare",
    "sevizierà": "seviziare",
    "sevizierò": "seviziare",
    "sevizin": "seviziare",
    "sevizino": "seviziare",
    "sevizio": "seviziare",
    "seviziò": "seviziare",
    "seziona": "sezionare",
    "sezionai": "sezionare",
    "sezionammo": "sezionare",
    "sezionan": "sezionare",
    "sezionando": "sezionare",
    "sezionano": "sezionare",
    "sezionante": "sezionare",
    "sezionanti": "sezionare",
    "sezionar": "sezionare",
    "sezionaron": "sezionare",
    "sezionarono": "sezionare",
    "sezionasse": "sezionare",
    "sezionasser": "sezionare",
    "sezionassero": "sezionare",
    "sezionassi": "sezionare",
    "sezionassimo": "sezionare",
    "sezionaste": "sezionare",
    "sezionasti": "sezionare",
    "sezionata": "sezionare",
    "sezionate": "sezionare",
    "sezionati": "sezionare",
    "sezionato": "sezionare",
    "sezionava": "sezionare",
    "sezionavamo": "sezionare",
    "sezionavan": "sezionare",
    "sezionavano": "sezionare",
    "sezionavate": "sezionare",
    "sezionavi": "sezionare",
    "sezionavo": "sezionare",
    "sezionerai": "sezionare",
    "sezioneran": "sezionare",
    "sezioneranno": "sezionare",
    "sezionerebbe": "sezionare",
    "sezionerebber": "sezionare",
    "sezionerebbero": "sezionare",
    "sezionerei": "sezionare",
    "sezioneremmo": "sezionare",
    "sezioneremo": "sezionare",
    "sezionereste": "sezionare",
    "sezioneresti": "sezionare",
    "sezionerete": "sezionare",
    "sezionerà": "sezionare",
    "sezionerò": "sezionare",
    "sezioni": "sezione",
    "sezioniamo": "sezionare",
    "sezioniate": "sezionare",
    "sezionin": "sezionare",
    "sezionino": "sezionare",
    "seziono": "sezionare",
    "sezionò": "sezionare",
    "sfa": "sfare",
    "sfaccenda": "sfaccendare",
    "sfaccendai": "sfaccendare",
    "sfaccendammo": "sfaccendare",
    "sfaccendan": "sfaccendare",
    "sfaccendando": "sfaccendare",
    "sfaccendano": "sfaccendare",
    "sfaccendante": "sfaccendare",
    "sfaccendanti": "sfaccendare",
    "sfaccendar": "sfaccendare",
    "sfaccendaron": "sfaccendare",
    "sfaccendarono": "sfaccendare",
    "sfaccendasse": "sfaccendare",
    "sfaccendasser": "sfaccendare",
    "sfaccendassero": "sfaccendare",
    "sfaccendassi": "sfaccendare",
    "sfaccendassimo": "sfaccendare",
    "sfaccendaste": "sfaccendare",
    "sfaccendasti": "sfaccendare",
    "sfaccendata": "sfaccendato",
    "sfaccendate": "sfaccendato",
    "sfaccendati": "sfaccendato",
    "sfaccendato": "sfaccendare",
    "sfaccendava": "sfaccendare",
    "sfaccendavamo": "sfaccendare",
    "sfaccendavan": "sfaccendare",
    "sfaccendavano": "sfaccendare",
    "sfaccendavate": "sfaccendare",
    "sfaccendavi": "sfaccendare",
    "sfaccendavo": "sfaccendare",
    "sfaccenderai": "sfaccendare",
    "sfaccenderan": "sfaccendare",
    "sfaccenderanno": "sfaccendare",
    "sfaccenderebbe": "sfaccendare",
    "sfaccenderebber": "sfaccendare",
    "sfaccenderebbero": "sfaccendare",
    "sfaccenderei": "sfaccendare",
    "sfaccenderemmo": "sfaccendare",
    "sfaccenderemo": "sfaccendare",
    "sfaccendereste": "sfaccendare",
    "sfaccenderesti": "sfaccendare",
    "sfaccenderete": "sfaccendare",
    "sfaccenderà": "sfaccendare",
    "sfaccenderò": "sfaccendare",
    "sfaccendi": "sfaccendare",
    "sfaccendiamo": "sfaccendare",
    "sfaccendiate": "sfaccendare",
    "sfaccendin": "sfaccendare",
    "sfaccendino": "sfaccendare",
    "sfaccendo": "sfaccendare",
    "sfaccendò": "sfaccendare",
    "sfaccetta": "sfaccettare",
    "sfaccettai": "sfaccettare",
    "sfaccettammo": "sfaccettare",
    "sfaccettan": "sfaccettare",
    "sfaccettando": "sfaccettare",
    "sfaccettano": "sfaccettare",
    "sfaccettante": "sfaccettare",
    "sfaccettanti": "sfaccettare",
    "sfaccettar": "sfaccettare",
    "sfaccettaron": "sfaccettare",
    "sfaccettarono": "sfaccettare",
    "sfaccettasse": "sfaccettare",
    "sfaccettasser": "sfaccettare",
    "sfaccettassero": "sfaccettare",
    "sfaccettassi": "sfaccettare",
    "sfaccettassimo": "sfaccettare",
    "sfaccettaste": "sfaccettare",
    "sfaccettasti": "sfaccettare",
    "sfaccettata": "sfaccettare",
    "sfaccettate": "sfaccettare",
    "sfaccettati": "sfaccettare",
    "sfaccettato": "sfaccettare",
    "sfaccettature": "sfaccettatura",
    "sfaccettava": "sfaccettare",
    "sfaccettavamo": "sfaccettare",
    "sfaccettavan": "sfaccettare",
    "sfaccettavano": "sfaccettare",
    "sfaccettavate": "sfaccettare",
    "sfaccettavi": "sfaccettare",
    "sfaccettavo": "sfaccettare",
    "sfaccetterai": "sfaccettare",
    "sfaccetteran": "sfaccettare",
    "sfaccetteranno": "sfaccettare",
    "sfaccetterebbe": "sfaccettare",
    "sfaccetterebber": "sfaccettare",
    "sfaccetterebbero": "sfaccettare",
    "sfaccetterei": "sfaccettare",
    "sfaccetteremmo": "sfaccettare",
    "sfaccetteremo": "sfaccettare",
    "sfaccettereste": "sfaccettare",
    "sfaccetteresti": "sfaccettare",
    "sfaccetterete": "sfaccettare",
    "sfaccetterà": "sfaccettare",
    "sfaccetterò": "sfaccettare",
    "sfaccetti": "sfaccettare",
    "sfaccettiamo": "sfaccettare",
    "sfaccettiate": "sfaccettare",
    "sfaccettin": "sfaccettare",
    "sfaccettino": "sfaccettare",
    "sfaccetto": "sfaccettare",
    "sfaccettò": "sfaccettare",
    "sfacchina": "sfacchinare",
    "sfacchinai": "sfacchinare",
    "sfacchinammo": "sfacchinare",
    "sfacchinan": "sfacchinare",
    "sfacchinando": "sfacchinare",
    "sfacchinano": "sfacchinare",
    "sfacchinante": "sfacchinare",
    "sfacchinanti": "sfacchinare",
    "sfacchinar": "sfacchinare",
    "sfacchinaron": "sfacchinare",
    "sfacchinarono": "sfacchinare",
    "sfacchinasse": "sfacchinare",
    "sfacchinasser": "sfacchinare",
    "sfacchinassero": "sfacchinare",
    "sfacchinassi": "sfacchinare",
    "sfacchinassimo": "sfacchinare",
    "sfacchinaste": "sfacchinare",
    "sfacchinasti": "sfacchinare",
    "sfacchinata": "sfacchinare",
    "sfacchinate": "sfacchinare",
    "sfacchinati": "sfacchinare",
    "sfacchinato": "sfacchinare",
    "sfacchinava": "sfacchinare",
    "sfacchinavamo": "sfacchinare",
    "sfacchinavan": "sfacchinare",
    "sfacchinavano": "sfacchinare",
    "sfacchinavate": "sfacchinare",
    "sfacchinavi": "sfacchinare",
    "sfacchinavo": "sfacchinare",
    "sfacchinerai": "sfacchinare",
    "sfacchineran": "sfacchinare",
    "sfacchineranno": "sfacchinare",
    "sfacchinerebbe": "sfacchinare",
    "sfacchinerebber": "sfacchinare",
    "sfacchinerebbero": "sfacchinare",
    "sfacchinerei": "sfacchinare",
    "sfacchineremmo": "sfacchinare",
    "sfacchineremo": "sfacchinare",
    "sfacchinereste": "sfacchinare",
    "sfacchineresti": "sfacchinare",
    "sfacchinerete": "sfacchinare",
    "sfacchinerà": "sfacchinare",
    "sfacchinerò": "sfacchinare",
    "sfacchini": "sfacchinare",
    "sfacchiniamo": "sfacchinare",
    "sfacchiniate": "sfacchinare",
    "sfacchinin": "sfacchinare",
    "sfacchinino": "sfacchinare",
    "sfacchino": "sfacchinare",
    "sfacchinò": "sfacchinare",
    "sfacciata": "sfacciato",
    "sfacciataggini": "sfacciataggine",
    "sfacciate": "sfacciato",
    "sfacciati": "sfacciato",
    "sfaceli": "sfacelo",
    "sfai": "sfare",
    "sfalda": "sfaldare",
    "sfaldai": "sfaldare",
    "sfaldamenti": "sfaldamento",
    "sfaldammo": "sfaldare",
    "sfaldan": "sfaldare",
    "sfaldando": "sfaldare",
    "sfaldano": "sfaldare",
    "sfaldante": "sfaldare",
    "sfaldanti": "sfaldare",
    "sfaldar": "sfaldare",
    "sfaldaron": "sfaldare",
    "sfaldarono": "sfaldare",
    "sfaldasse": "sfaldare",
    "sfaldasser": "sfaldare",
    "sfaldassero": "sfaldare",
    "sfaldassi": "sfaldare",
    "sfaldassimo": "sfaldare",
    "sfaldaste": "sfaldare",
    "sfaldasti": "sfaldare",
    "sfaldata": "sfaldare",
    "sfaldate": "sfaldare",
    "sfaldati": "sfaldare",
    "sfaldato": "sfaldare",
    "sfaldava": "sfaldare",
    "sfaldavamo": "sfaldare",
    "sfaldavan": "sfaldare",
    "sfaldavano": "sfaldare",
    "sfaldavate": "sfaldare",
    "sfaldavi": "sfaldare",
    "sfaldavo": "sfaldare",
    "sfalderai": "sfaldare",
    "sfalderan": "sfaldare",
    "sfalderanno": "sfaldare",
    "sfalderebbe": "sfaldare",
    "sfalderebber": "sfaldare",
    "sfalderebbero": "sfaldare",
    "sfalderei": "sfaldare",
    "sfalderemmo": "sfaldare",
    "sfalderemo": "sfaldare",
    "sfaldereste": "sfaldare",
    "sfalderesti": "sfaldare",
    "sfalderete": "sfaldare",
    "sfalderà": "sfaldare",
    "sfalderò": "sfaldare",
    "sfaldi": "sfaldare",
    "sfaldiamo": "sfaldare",
    "sfaldiate": "sfaldare",
    "sfaldin": "sfaldare",
    "sfaldino": "sfaldare",
    "sfaldo": "sfaldare",
    "sfaldò": "sfaldare",
    "sfalsa": "sfalsare",
    "sfalsai": "sfalsare",
    "sfalsammo": "sfalsare",
    "sfalsan": "sfalsare",
    "sfalsando": "sfalsare",
    "sfalsano": "sfalsare",
    "sfalsante": "sfalsare",
    "sfalsanti": "sfalsare",
    "sfalsar": "sfalsare",
    "sfalsaron": "sfalsare",
    "sfalsarono": "sfalsare",
    "sfalsasse": "sfalsare",
    "sfalsasser": "sfalsare",
    "sfalsassero": "sfalsare",
    "sfalsassi": "sfalsare",
    "sfalsassimo": "sfalsare",
    "sfalsaste": "sfalsare",
    "sfalsasti": "sfalsare",
    "sfalsata": "sfalsare",
    "sfalsate": "sfalsare",
    "sfalsati": "sfalsare",
    "sfalsato": "sfalsare",
    "sfalsava": "sfalsare",
    "sfalsavamo": "sfalsare",
    "sfalsavan": "sfalsare",
    "sfalsavano": "sfalsare",
    "sfalsavate": "sfalsare",
    "sfalsavi": "sfalsare",
    "sfalsavo": "sfalsare",
    "sfalserai": "sfalsare",
    "sfalseran": "sfalsare",
    "sfalseranno": "sfalsare",
    "sfalserebbe": "sfalsare",
    "sfalserebber": "sfalsare",
    "sfalserebbero": "sfalsare",
    "sfalserei": "sfalsare",
    "sfalseremmo": "sfalsare",
    "sfalseremo": "sfalsare",
    "sfalsereste": "sfalsare",
    "sfalseresti": "sfalsare",
    "sfalserete": "sfalsare",
    "sfalserà": "sfalsare",
    "sfalserò": "sfalsare",
    "sfalsi": "sfalsare",
    "sfalsiamo": "sfalsare",
    "sfalsiate": "sfalsare",
    "sfalsin": "sfalsare",
    "sfalsino": "sfalsare",
    "sfalso": "sfalsare",
    "sfalsò": "sfalsare",
    "sfama": "sfamare",
    "sfamai": "sfamare",
    "sfamammo": "sfamare",
    "sfaman": "sfamare",
    "sfamando": "sfamare",
    "sfamano": "sfamare",
    "sfamante": "sfamare",
    "sfamanti": "sfamare",
    "sfamar": "sfamare",
    "sfamaron": "sfamare",
    "sfamarono": "sfamare",
    "sfamasse": "sfamare",
    "sfamasser": "sfamare",
    "sfamassero": "sfamare",
    "sfamassi": "sfamare",
    "sfamassimo": "sfamare",
    "sfamaste": "sfamare",
    "sfamasti": "sfamare",
    "sfamata": "sfamare",
    "sfamate": "sfamare",
    "sfamati": "sfamare",
    "sfamato": "sfamare",
    "sfamava": "sfamare",
    "sfamavamo": "sfamare",
    "sfamavan": "sfamare",
    "sfamavano": "sfamare",
    "sfamavate": "sfamare",
    "sfamavi": "sfamare",
    "sfamavo": "sfamare",
    "sfamerai": "sfamare",
    "sfameran": "sfamare",
    "sfameranno": "sfamare",
    "sfamerebbe": "sfamare",
    "sfamerebber": "sfamare",
    "sfamerebbero": "sfamare",
    "sfamerei": "sfamare",
    "sfameremmo": "sfamare",
    "sfameremo": "sfamare",
    "sfamereste": "sfamare",
    "sfameresti": "sfamare",
    "sfamerete": "sfamare",
    "sfamerà": "sfamare",
    "sfamerò": "sfamare",
    "sfami": "sfamare",
    "sfamiamo": "sfamare",
    "sfamiate": "sfamare",
    "sfamin": "sfamare",
    "sfamino": "sfamare",
    "sfammo": "sfare",
    "sfamo": "sfamare",
    "sfamò": "sfamare",
    "sfan": "sfare",
    "sfando": "sfare",
    "sfanga": "sfangare",
    "sfangai": "sfangare",
    "sfangammo": "sfangare",
    "sfangan": "sfangare",
    "sfangando": "sfangare",
    "sfangano": "sfangare",
    "sfangante": "sfangare",
    "sfanganti": "sfangare",
    "sfangar": "sfangare",
    "sfangaron": "sfangare",
    "sfangarono": "sfangare",
    "sfangasse": "sfangare",
    "sfangasser": "sfangare",
    "sfangassero": "sfangare",
    "sfangassi": "sfangare",
    "sfangassimo": "sfangare",
    "sfangaste": "sfangare",
    "sfangasti": "sfangare",
    "sfangata": "sfangare",
    "sfangate": "sfangare",
    "sfangati": "sfangare",
    "sfangato": "sfangare",
    "sfangava": "sfangare",
    "sfangavamo": "sfangare",
    "sfangavan": "sfangare",
    "sfangavano": "sfangare",
    "sfangavate": "sfangare",
    "sfangavi": "sfangare",
    "sfangavo": "sfangare",
    "sfangherai": "sfangare",
    "sfangheran": "sfangare",
    "sfangheranno": "sfangare",
    "sfangherebbe": "sfangare",
    "sfangherebber": "sfangare",
    "sfangherebbero": "sfangare",
    "sfangherei": "sfangare",
    "sfangheremmo": "sfangare",
    "sfangheremo": "sfangare",
    "sfanghereste": "sfangare",
    "sfangheresti": "sfangare",
    "sfangherete": "sfangare",
    "sfangherà": "sfangare",
    "sfangherò": "sfangare",
    "sfanghi": "sfangare",
    "sfanghiamo": "sfangare",
    "sfanghiate": "sfangare",
    "sfanghin": "sfangare",
    "sfanghino": "sfangare",
    "sfango": "sfangare",
    "sfangò": "sfangare",
    "sfano": "sfare",
    "sfante": "sfare",
    "sfanti": "sfare",
    "sfar": "sfare",
    "sfarfalla": "sfarfallare",
    "sfarfallai": "sfarfallare",
    "sfarfallammo": "sfarfallare",
    "sfarfallan": "sfarfallare",
    "sfarfallando": "sfarfallare",
    "sfarfallano": "sfarfallare",
    "sfarfallante": "sfarfallare",
    "sfarfallanti": "sfarfallare",
    "sfarfallar": "sfarfallare",
    "sfarfallaron": "sfarfallare",
    "sfarfallarono": "sfarfallare",
    "sfarfallasse": "sfarfallare",
    "sfarfallasser": "sfarfallare",
    "sfarfallassero": "sfarfallare",
    "sfarfallassi": "sfarfallare",
    "sfarfallassimo": "sfarfallare",
    "sfarfallaste": "sfarfallare",
    "sfarfallasti": "sfarfallare",
    "sfarfallata": "sfarfallare",
    "sfarfallate": "sfarfallare",
    "sfarfallati": "sfarfallare",
    "sfarfallato": "sfarfallare",
    "sfarfallava": "sfarfallare",
    "sfarfallavamo": "sfarfallare",
    "sfarfallavan": "sfarfallare",
    "sfarfallavano": "sfarfallare",
    "sfarfallavate": "sfarfallare",
    "sfarfallavi": "sfarfallare",
    "sfarfallavo": "sfarfallare",
    "sfarfallerai": "sfarfallare",
    "sfarfalleran": "sfarfallare",
    "sfarfalleranno": "sfarfallare",
    "sfarfallerebbe": "sfarfallare",
    "sfarfallerebber": "sfarfallare",
    "sfarfallerebbero": "sfarfallare",
    "sfarfallerei": "sfarfallare",
    "sfarfalleremmo": "sfarfallare",
    "sfarfalleremo": "sfarfallare",
    "sfarfallereste": "sfarfallare",
    "sfarfalleresti": "sfarfallare",
    "sfarfallerete": "sfarfallare",
    "sfarfallerà": "sfarfallare",
    "sfarfallerò": "sfarfallare",
    "sfarfalli": "sfarfallare",
    "sfarfalliamo": "sfarfallare",
    "sfarfalliate": "sfarfallare",
    "sfarfallii": "sfarfallio",
    "sfarfallin": "sfarfallare",
    "sfarfallino": "sfarfallare",
    "sfarfallo": "sfarfallare",
    "sfarfallò": "sfarfallare",
    "sfarina": "sfarinare",
    "sfarinai": "sfarinare",
    "sfarinammo": "sfarinare",
    "sfarinan": "sfarinare",
    "sfarinando": "sfarinare",
    "sfarinano": "sfarinare",
    "sfarinante": "sfarinare",
    "sfarinanti": "sfarinare",
    "sfarinar": "sfarinare",
    "sfarinaron": "sfarinare",
    "sfarinarono": "sfarinare",
    "sfarinasse": "sfarinare",
    "sfarinasser": "sfarinare",
    "sfarinassero": "sfarinare",
    "sfarinassi": "sfarinare",
    "sfarinassimo": "sfarinare",
    "sfarinaste": "sfarinare",
    "sfarinasti": "sfarinare",
    "sfarinata": "sfarinare",
    "sfarinate": "sfarinare",
    "sfarinati": "sfarinare",
    "sfarinato": "sfarinare",
    "sfarinava": "sfarinare",
    "sfarinavamo": "sfarinare",
    "sfarinavan": "sfarinare",
    "sfarinavano": "sfarinare",
    "sfarinavate": "sfarinare",
    "sfarinavi": "sfarinare",
    "sfarinavo": "sfarinare",
    "sfarinerai": "sfarinare",
    "sfarineran": "sfarinare",
    "sfarineranno": "sfarinare",
    "sfarinerebbe": "sfarinare",
    "sfarinerebber": "sfarinare",
    "sfarinerebbero": "sfarinare",
    "sfarinerei": "sfarinare",
    "sfarineremmo": "sfarinare",
    "sfarineremo": "sfarinare",
    "sfarinereste": "sfarinare",
    "sfarineresti": "sfarinare",
    "sfarinerete": "sfarinare",
    "sfarinerà": "sfarinare",
    "sfarinerò": "sfarinare",
    "sfarini": "sfarinare",
    "sfariniamo": "sfarinare",
    "sfariniate": "sfarinare",
    "sfarinin": "sfarinare",
    "sfarinino": "sfarinare",
    "sfarino": "sfarinare",
    "sfarinò": "sfarinare",
    "sfaron": "sfare",
    "sfarono": "sfare",
    "sfarzi": "sfarzo",
    "sfarzosa": "sfarzoso",
    "sfarzose": "sfarzoso",
    "sfarzosi": "sfarzoso",
    "sfasa": "sfasare",
    "sfasai": "sfasare",
    "sfasamenti": "sfasamento",
    "sfasammo": "sfasare",
    "sfasan": "sfasare",
    "sfasando": "sfasare",
    "sfasano": "sfasare",
    "sfasante": "sfasare",
    "sfasanti": "sfasare",
    "sfasar": "sfasare",
    "sfasaron": "sfasare",
    "sfasarono": "sfasare",
    "sfasasse": "sfasare",
    "sfasasser": "sfasare",
    "sfasassero": "sfasare",
    "sfasassi": "sfasare",
    "sfasassimo": "sfasare",
    "sfasaste": "sfasare",
    "sfasasti": "sfasare",
    "sfasata": "sfasato",
    "sfasate": "sfasato",
    "sfasati": "sfasato",
    "sfasato": "sfasare",
    "sfasature": "sfasatura",
    "sfasava": "sfasare",
    "sfasavamo": "sfasare",
    "sfasavan": "sfasare",
    "sfasavano": "sfasare",
    "sfasavate": "sfasare",
    "sfasavi": "sfasare",
    "sfasavo": "sfasare",
    "sfascerai": "sfasciare",
    "sfasceran": "sfasciare",
    "sfasceranno": "sfasciare",
    "sfascerebbe": "sfasciare",
    "sfascerebber": "sfasciare",
    "sfascerebbero": "sfasciare",
    "sfascerei": "sfasciare",
    "sfasceremmo": "sfasciare",
    "sfasceremo": "sfasciare",
    "sfascereste": "sfasciare",
    "sfasceresti": "sfasciare",
    "sfascerete": "sfasciare",
    "sfascerà": "sfasciare",
    "sfascerò": "sfasciare",
    "sfasci": "sfascio",
    "sfascia": "sfasciare",
    "sfasciai": "sfasciare",
    "sfasciammo": "sfasciare",
    "sfasciamo": "sfasciare",
    "sfascian": "sfasciare",
    "sfasciando": "sfasciare",
    "sfasciano": "sfasciare",
    "sfasciante": "sfasciare",
    "sfascianti": "sfasciare",
    "sfasciar": "sfasciare",
    "sfasciaron": "sfasciare",
    "sfasciarono": "sfasciare",
    "sfasciasse": "sfasciare",
    "sfasciasser": "sfasciare",
    "sfasciassero": "sfasciare",
    "sfasciassi": "sfasciare",
    "sfasciassimo": "sfasciare",
    "sfasciaste": "sfasciare",
    "sfasciasti": "sfasciare",
    "sfasciata": "sfasciare",
    "sfasciate": "sfasciare",
    "sfasciati": "sfasciare",
    "sfasciato": "sfasciare",
    "sfasciava": "sfasciare",
    "sfasciavamo": "sfasciare",
    "sfasciavan": "sfasciare",
    "sfasciavano": "sfasciare",
    "sfasciavate": "sfasciare",
    "sfasciavi": "sfasciare",
    "sfasciavo": "sfasciare",
    "sfascin": "sfasciare",
    "sfascino": "sfasciare",
    "sfascio": "sfasciare",
    "sfasciò": "sfasciare",
    "sfaserai": "sfasare",
    "sfaseran": "sfasare",
    "sfaseranno": "sfasare",
    "sfaserebbe": "sfasare",
    "sfaserebber": "sfasare",
    "sfaserebbero": "sfasare",
    "sfaserei": "sfasare",
    "sfaseremmo": "sfasare",
    "sfaseremo": "sfasare",
    "sfasereste": "sfasare",
    "sfaseresti": "sfasare",
    "sfaserete": "sfasare",
    "sfaserà": "sfasare",
    "sfaserò": "sfasare",
    "sfasi": "sfasare",
    "sfasiamo": "sfasare",
    "sfasiate": "sfasare",
    "sfasin": "sfasare",
    "sfasino": "sfasare",
    "sfaso": "sfasare",
    "sfasse": "sfare",
    "sfasser": "sfare",
    "sfassero": "sfare",
    "sfassi": "sfare",
    "sfassimo": "sfare",
    "sfaste": "sfare",
    "sfasti": "sfare",
    "sfasò": "sfasare",
    "sfata": "sfatare",
    "sfatai": "sfatare",
    "sfatammo": "sfatare",
    "sfatan": "sfatare",
    "sfatando": "sfatare",
    "sfatano": "sfatare",
    "sfatante": "sfatare",
    "sfatanti": "sfatare",
    "sfatar": "sfatare",
    "sfataron": "sfatare",
    "sfatarono": "sfatare",
    "sfatasse": "sfatare",
    "sfatasser": "sfatare",
    "sfatassero": "sfatare",
    "sfatassi": "sfatare",
    "sfatassimo": "sfatare",
    "sfataste": "sfatare",
    "sfatasti": "sfatare",
    "sfatata": "sfatare",
    "sfatate": "sfatare",
    "sfatati": "sfatare",
    "sfatato": "sfatare",
    "sfatava": "sfatare",
    "sfatavamo": "sfatare",
    "sfatavan": "sfatare",
    "sfatavano": "sfatare",
    "sfatavate": "sfatare",
    "sfatavi": "sfatare",
    "sfatavo": "sfatare",
    "sfate": "sfare",
    "sfaterai": "sfatare",
    "sfateran": "sfatare",
    "sfateranno": "sfatare",
    "sfaterebbe": "sfatare",
    "sfaterebber": "sfatare",
    "sfaterebbero": "sfatare",
    "sfaterei": "sfatare",
    "sfateremmo": "sfatare",
    "sfateremo": "sfatare",
    "sfatereste": "sfatare",
    "sfateresti": "sfatare",
    "sfaterete": "sfatare",
    "sfaterà": "sfatare",
    "sfaterò": "sfatare",
    "sfati": "sfatare",
    "sfatiamo": "sfatare",
    "sfatiate": "sfatare",
    "sfatin": "sfatare",
    "sfatino": "sfatare",
    "sfato": "sfatare",
    "sfatta": "sfatto",
    "sfatte": "sfatto",
    "sfatti": "sfatto",
    "sfatò": "sfatare",
    "sfava": "sfare",
    "sfavamo": "sfare",
    "sfavan": "sfare",
    "sfavano": "sfare",
    "sfavate": "sfare",
    "sfavi": "sfare",
    "sfavilla": "sfavillare",
    "sfavillai": "sfavillare",
    "sfavillammo": "sfavillare",
    "sfavillan": "sfavillare",
    "sfavillando": "sfavillare",
    "sfavillano": "sfavillare",
    "sfavillante": "sfavillare",
    "sfavillanti": "sfavillare",
    "sfavillar": "sfavillare",
    "sfavillaron": "sfavillare",
    "sfavillarono": "sfavillare",
    "sfavillasse": "sfavillare",
    "sfavillasser": "sfavillare",
    "sfavillassero": "sfavillare",
    "sfavillassi": "sfavillare",
    "sfavillassimo": "sfavillare",
    "sfavillaste": "sfavillare",
    "sfavillasti": "sfavillare",
    "sfavillata": "sfavillare",
    "sfavillate": "sfavillare",
    "sfavillati": "sfavillare",
    "sfavillato": "sfavillare",
    "sfavillava": "sfavillare",
    "sfavillavamo": "sfavillare",
    "sfavillavan": "sfavillare",
    "sfavillavano": "sfavillare",
    "sfavillavate": "sfavillare",
    "sfavillavi": "sfavillare",
    "sfavillavo": "sfavillare",
    "sfavillerai": "sfavillare",
    "sfavilleran": "sfavillare",
    "sfavilleranno": "sfavillare",
    "sfavillerebbe": "sfavillare",
    "sfavillerebber": "sfavillare",
    "sfavillerebbero": "sfavillare",
    "sfavillerei": "sfavillare",
    "sfavilleremmo": "sfavillare",
    "sfavilleremo": "sfavillare",
    "sfavillereste": "sfavillare",
    "sfavilleresti": "sfavillare",
    "sfavillerete": "sfavillare",
    "sfavillerà": "sfavillare",
    "sfavillerò": "sfavillare",
    "sfavilli": "sfavillare",
    "sfavilliamo": "sfavillare",
    "sfavilliate": "sfavillare",
    "sfavillii": "sfavillio",
    "sfavillin": "sfavillare",
    "sfavillino": "sfavillare",
    "sfavillo": "sfavillare",
    "sfavillò": "sfavillare",
    "sfavo": "sfare",
    "sfavora": "sfavorire",
    "sfavoran": "sfavorire",
    "sfavorano": "sfavorire",
    "sfavore": "sfavorire",
    "sfavorendo": "sfavorire",
    "sfavorente": "sfavorire",
    "sfavorenti": "sfavorire",
    "sfavorevoli": "sfavorevole",
    "sfavori": "sfavorire",
    "sfavoriamo": "sfavorire",
    "sfavoriate": "sfavorire",
    "sfavorii": "sfavorire",
    "sfavorimmo": "sfavorire",
    "sfavorir": "sfavorire",
    "sfavorirai": "sfavorire",
    "sfavoriran": "sfavorire",
    "sfavoriranno": "sfavorire",
    "sfavorirebbe": "sfavorire",
    "sfavorirebber": "sfavorire",
    "sfavorirebbero": "sfavorire",
    "sfavorirei": "sfavorire",
    "sfavoriremmo": "sfavorire",
    "sfavoriremo": "sfavorire",
    "sfavorireste": "sfavorire",
    "sfavoriresti": "sfavorire",
    "sfavorirete": "sfavorire",
    "sfavoriron": "sfavorire",
    "sfavorirono": "sfavorire",
    "sfavorirà": "sfavorire",
    "sfavorirò": "sfavorire",
    "sfavorisse": "sfavorire",
    "sfavorisser": "sfavorire",
    "sfavorissero": "sfavorire",
    "sfavorissi": "sfavorire",
    "sfavorissimo": "sfavorire",
    "sfavoriste": "sfavorire",
    "sfavoristi": "sfavorire",
    "sfavorita": "sfavorire",
    "sfavorite": "sfavorire",
    "sfavoriti": "sfavorire",
    "sfavorito": "sfavorire",
    "sfavoriva": "sfavorire",
    "sfavorivamo": "sfavorire",
    "sfavorivan": "sfavorire",
    "sfavorivano": "sfavorire",
    "sfavorivate": "sfavorire",
    "sfavorivi": "sfavorire",
    "sfavorivo": "sfavorire",
    "sfavoro": "sfavorire",
    "sfavoron": "sfavorire",
    "sfavorono": "sfavorire",
    "sfavorì": "sfavorire",
    "sfebbra": "sfebbrare",
    "sfebbrai": "sfebbrare",
    "sfebbrammo": "sfebbrare",
    "sfebbran": "sfebbrare",
    "sfebbrando": "sfebbrare",
    "sfebbrano": "sfebbrare",
    "sfebbrante": "sfebbrare",
    "sfebbranti": "sfebbrare",
    "sfebbrar": "sfebbrare",
    "sfebbraron": "sfebbrare",
    "sfebbrarono": "sfebbrare",
    "sfebbrasse": "sfebbrare",
    "sfebbrasser": "sfebbrare",
    "sfebbrassero": "sfebbrare",
    "sfebbrassi": "sfebbrare",
    "sfebbrassimo": "sfebbrare",
    "sfebbraste": "sfebbrare",
    "sfebbrasti": "sfebbrare",
    "sfebbrata": "sfebbrare",
    "sfebbrate": "sfebbrare",
    "sfebbrati": "sfebbrare",
    "sfebbrato": "sfebbrare",
    "sfebbrava": "sfebbrare",
    "sfebbravamo": "sfebbrare",
    "sfebbravan": "sfebbrare",
    "sfebbravano": "sfebbrare",
    "sfebbravate": "sfebbrare",
    "sfebbravi": "sfebbrare",
    "sfebbravo": "sfebbrare",
    "sfebbrerai": "sfebbrare",
    "sfebbreran": "sfebbrare",
    "sfebbreranno": "sfebbrare",
    "sfebbrerebbe": "sfebbrare",
    "sfebbrerebber": "sfebbrare",
    "sfebbrerebbero": "sfebbrare",
    "sfebbrerei": "sfebbrare",
    "sfebbreremmo": "sfebbrare",
    "sfebbreremo": "sfebbrare",
    "sfebbrereste": "sfebbrare",
    "sfebbreresti": "sfebbrare",
    "sfebbrerete": "sfebbrare",
    "sfebbrerà": "sfebbrare",
    "sfebbrerò": "sfebbrare",
    "sfebbri": "sfebbrare",
    "sfebbriamo": "sfebbrare",
    "sfebbriate": "sfebbrare",
    "sfebbrin": "sfebbrare",
    "sfebbrino": "sfebbrare",
    "sfebbro": "sfebbrare",
    "sfebbrò": "sfebbrare",
    "sfegata": "sfegatare",
    "sfegatai": "sfegatare",
    "sfegatammo": "sfegatare",
    "sfegatan": "sfegatare",
    "sfegatando": "sfegatare",
    "sfegatano": "sfegatare",
    "sfegatar": "sfegatare",
    "sfegataron": "sfegatare",
    "sfegatarono": "sfegatare",
    "sfegatasse": "sfegatare",
    "sfegatasser": "sfegatare",
    "sfegatassero": "sfegatare",
    "sfegatassi": "sfegatare",
    "sfegatassimo": "sfegatare",
    "sfegataste": "sfegatare",
    "sfegatasti": "sfegatare",
    "sfegatata": "sfegatato",
    "sfegatate": "sfegatato",
    "sfegatati": "sfegatato",
    "sfegatato": "sfegatare",
    "sfegatava": "sfegatare",
    "sfegatavamo": "sfegatare",
    "sfegatavan": "sfegatare",
    "sfegatavano": "sfegatare",
    "sfegatavate": "sfegatare",
    "sfegatavi": "sfegatare",
    "sfegatavo": "sfegatare",
    "sfegaterai": "sfegatare",
    "sfegateran": "sfegatare",
    "sfegateranno": "sfegatare",
    "sfegaterebbe": "sfegatare",
    "sfegaterebber": "sfegatare",
    "sfegaterebbero": "sfegatare",
    "sfegaterei": "sfegatare",
    "sfegateremmo": "sfegatare",
    "sfegateremo": "sfegatare",
    "sfegatereste": "sfegatare",
    "sfegateresti": "sfegatare",
    "sfegaterete": "sfegatare",
    "sfegaterà": "sfegatare",
    "sfegaterò": "sfegatare",
    "sfegati": "sfegatare",
    "sfegatiamo": "sfegatare",
    "sfegatiate": "sfegatare",
    "sfegatin": "sfegatare",
    "sfegatino": "sfegatare",
    "sfegato": "sfegatare",
    "sfegatò": "sfegatare",
    "sferai": "sfare",
    "sferan": "sfare",
    "sferanno": "sfare",
    "sfere": "sfera",
    "sferebbe": "sfare",
    "sferebber": "sfare",
    "sferebbero": "sfare",
    "sferei": "sfare",
    "sferemmo": "sfare",
    "sferemo": "sfare",
    "sfereste": "sfare",
    "sferesti": "sfare",
    "sferete": "sfare",
    "sferica": "sferico",
    "sferiche": "sferico",
    "sferici": "sferico",
    "sferoidali": "sferoidale",
    "sferra": "sferrare",
    "sferragli": "sferragliare",
    "sferraglia": "sferragliare",
    "sferragliai": "sferragliare",
    "sferragliammo": "sferragliare",
    "sferragliamo": "sferragliare",
    "sferraglian": "sferragliare",
    "sferragliando": "sferragliare",
    "sferragliano": "sferragliare",
    "sferragliante": "sferragliare",
    "sferraglianti": "sferragliare",
    "sferragliar": "sferragliare",
    "sferragliaron": "sferragliare",
    "sferragliarono": "sferragliare",
    "sferragliasse": "sferragliare",
    "sferragliasser": "sferragliare",
    "sferragliassero": "sferragliare",
    "sferragliassi": "sferragliare",
    "sferragliassimo": "sferragliare",
    "sferragliaste": "sferragliare",
    "sferragliasti": "sferragliare",
    "sferragliata": "sferragliare",
    "sferragliate": "sferragliare",
    "sferragliati": "sferragliare",
    "sferragliato": "sferragliare",
    "sferragliava": "sferragliare",
    "sferragliavamo": "sferragliare",
    "sferragliavan": "sferragliare",
    "sferragliavano": "sferragliare",
    "sferragliavate": "sferragliare",
    "sferragliavi": "sferragliare",
    "sferragliavo": "sferragliare",
    "sferraglierai": "sferragliare",
    "sferraglieran": "sferragliare",
    "sferraglieranno": "sferragliare",
    "sferraglierebbe": "sferragliare",
    "sferraglierebber": "sferragliare",
    "sferraglierebbero": "sferragliare",
    "sferraglierei": "sferragliare",
    "sferraglieremmo": "sferragliare",
    "sferraglieremo": "sferragliare",
    "sferragliereste": "sferragliare",
    "sferraglieresti": "sferragliare",
    "sferraglierete": "sferragliare",
    "sferraglierà": "sferragliare",
    "sferraglierò": "sferragliare",
    "sferraglin": "sferragliare",
    "sferraglino": "sferragliare",
    "sferraglio": "sferragliare",
    "sferragliò": "sferragliare",
    "sferrai": "sferrare",
    "sferrammo": "sferrare",
    "sferran": "sferrare",
    "sferrando": "sferrare",
    "sferrano": "sferrare",
    "sferrante": "sferrare",
    "sferranti": "sferrare",
    "sferrar": "sferrare",
    "sferraron": "sferrare",
    "sferrarono": "sferrare",
    "sferrasse": "sferrare",
    "sferrasser": "sferrare",
    "sferrassero": "sferrare",
    "sferrassi": "sferrare",
    "sferrassimo": "sferrare",
    "sferraste": "sferrare",
    "sferrasti": "sferrare",
    "sferrata": "sferrare",
    "sferrate": "sferrare",
    "sferrati": "sferrare",
    "sferrato": "sferrare",
    "sferrava": "sferrare",
    "sferravamo": "sferrare",
    "sferravan": "sferrare",
    "sferravano": "sferrare",
    "sferravate": "sferrare",
    "sferravi": "sferrare",
    "sferravo": "sferrare",
    "sferrerai": "sferrare",
    "sferreran": "sferrare",
    "sferreranno": "sferrare",
    "sferrerebbe": "sferrare",
    "sferrerebber": "sferrare",
    "sferrerebbero": "sferrare",
    "sferrerei": "sferrare",
    "sferreremmo": "sferrare",
    "sferreremo": "sferrare",
    "sferrereste": "sferrare",
    "sferreresti": "sferrare",
    "sferrerete": "sferrare",
    "sferrerà": "sferrare",
    "sferrerò": "sferrare",
    "sferri": "sferrare",
    "sferriamo": "sferrare",
    "sferriate": "sferrare",
    "sferrin": "sferrare",
    "sferrino": "sferrare",
    "sferro": "sferrare",
    "sferruzza": "sferruzzare",
    "sferruzzai": "sferruzzare",
    "sferruzzammo": "sferruzzare",
    "sferruzzan": "sferruzzare",
    "sferruzzando": "sferruzzare",
    "sferruzzano": "sferruzzare",
    "sferruzzante": "sferruzzare",
    "sferruzzanti": "sferruzzare",
    "sferruzzar": "sferruzzare",
    "sferruzzaron": "sferruzzare",
    "sferruzzarono": "sferruzzare",
    "sferruzzasse": "sferruzzare",
    "sferruzzasser": "sferruzzare",
    "sferruzzassero": "sferruzzare",
    "sferruzzassi": "sferruzzare",
    "sferruzzassimo": "sferruzzare",
    "sferruzzaste": "sferruzzare",
    "sferruzzasti": "sferruzzare",
    "sferruzzata": "sferruzzare",
    "sferruzzate": "sferruzzare",
    "sferruzzati": "sferruzzare",
    "sferruzzato": "sferruzzare",
    "sferruzzava": "sferruzzare",
    "sferruzzavamo": "sferruzzare",
    "sferruzzavan": "sferruzzare",
    "sferruzzavano": "sferruzzare",
    "sferruzzavate": "sferruzzare",
    "sferruzzavi": "sferruzzare",
    "sferruzzavo": "sferruzzare",
    "sferruzzerai": "sferruzzare",
    "sferruzzeran": "sferruzzare",
    "sferruzzeranno": "sferruzzare",
    "sferruzzerebbe": "sferruzzare",
    "sferruzzerebber": "sferruzzare",
    "sferruzzerebbero": "sferruzzare",
    "sferruzzerei": "sferruzzare",
    "sferruzzeremmo": "sferruzzare",
    "sferruzzeremo": "sferruzzare",
    "sferruzzereste": "sferruzzare",
    "sferruzzeresti": "sferruzzare",
    "sferruzzerete": "sferruzzare",
    "sferruzzerà": "sferruzzare",
    "sferruzzerò": "sferruzzare",
    "sferruzzi": "sferruzzare",
    "sferruzziamo": "sferruzzare",
    "sferruzziate": "sferruzzare",
    "sferruzzin": "sferruzzare",
    "sferruzzino": "sferruzzare",
    "sferruzzo": "sferruzzare",
    "sferruzzò": "sferruzzare",
    "sferrò": "sferrare",
    "sferza": "sferzare",
    "sferzai": "sferzare",
    "sferzammo": "sferzare",
    "sferzan": "sferzare",
    "sferzando": "sferzare",
    "sferzano": "sferzare",
    "sferzante": "sferzare",
    "sferzanti": "sferzare",
    "sferzar": "sferzare",
    "sferzaron": "sferzare",
    "sferzarono": "sferzare",
    "sferzasse": "sferzare",
    "sferzasser": "sferzare",
    "sferzassero": "sferzare",
    "sferzassi": "sferzare",
    "sferzassimo": "sferzare",
    "sferzaste": "sferzare",
    "sferzasti": "sferzare",
    "sferzata": "sferzare",
    "sferzate": "sferzata",
    "sferzati": "sferzare",
    "sferzato": "sferzare",
    "sferzava": "sferzare",
    "sferzavamo": "sferzare",
    "sferzavan": "sferzare",
    "sferzavano": "sferzare",
    "sferzavate": "sferzare",
    "sferzavi": "sferzare",
    "sferzavo": "sferzare",
    "sferze": "sferza",
    "sferzerai": "sferzare",
    "sferzeran": "sferzare",
    "sferzeranno": "sferzare",
    "sferzerebbe": "sferzare",
    "sferzerebber": "sferzare",
    "sferzerebbero": "sferzare",
    "sferzerei": "sferzare",
    "sferzeremmo": "sferzare",
    "sferzeremo": "sferzare",
    "sferzereste": "sferzare",
    "sferzeresti": "sferzare",
    "sferzerete": "sferzare",
    "sferzerà": "sferzare",
    "sferzerò": "sferzare",
    "sferzi": "sferzare",
    "sferziamo": "sferzare",
    "sferziate": "sferzare",
    "sferzin": "sferzare",
    "sferzino": "sferzare",
    "sferzo": "sferzare",
    "sferzò": "sferzare",
    "sferà": "sfare",
    "sferò": "sfare",
    "sfi": "sfare",
    "sfiamma": "sfiammare",
    "sfiammai": "sfiammare",
    "sfiammammo": "sfiammare",
    "sfiamman": "sfiammare",
    "sfiammando": "sfiammare",
    "sfiammano": "sfiammare",
    "sfiammante": "sfiammare",
    "sfiammanti": "sfiammare",
    "sfiammar": "sfiammare",
    "sfiammaron": "sfiammare",
    "sfiammarono": "sfiammare",
    "sfiammasse": "sfiammare",
    "sfiammasser": "sfiammare",
    "sfiammassero": "sfiammare",
    "sfiammassi": "sfiammare",
    "sfiammassimo": "sfiammare",
    "sfiammaste": "sfiammare",
    "sfiammasti": "sfiammare",
    "sfiammata": "sfiammare",
    "sfiammate": "sfiammare",
    "sfiammati": "sfiammare",
    "sfiammato": "sfiammare",
    "sfiammava": "sfiammare",
    "sfiammavamo": "sfiammare",
    "sfiammavan": "sfiammare",
    "sfiammavano": "sfiammare",
    "sfiammavate": "sfiammare",
    "sfiammavi": "sfiammare",
    "sfiammavo": "sfiammare",
    "sfiammerai": "sfiammare",
    "sfiammeran": "sfiammare",
    "sfiammeranno": "sfiammare",
    "sfiammerebbe": "sfiammare",
    "sfiammerebber": "sfiammare",
    "sfiammerebbero": "sfiammare",
    "sfiammerei": "sfiammare",
    "sfiammeremmo": "sfiammare",
    "sfiammeremo": "sfiammare",
    "sfiammereste": "sfiammare",
    "sfiammeresti": "sfiammare",
    "sfiammerete": "sfiammare",
    "sfiammerà": "sfiammare",
    "sfiammerò": "sfiammare",
    "sfiammi": "sfiammare",
    "sfiammiamo": "sfiammare",
    "sfiammiate": "sfiammare",
    "sfiammin": "sfiammare",
    "sfiammino": "sfiammare",
    "sfiammo": "sfiammare",
    "sfiammò": "sfiammare",
    "sfiamo": "sfare",
    "sfianca": "sfiancare",
    "sfiancai": "sfiancare",
    "sfiancammo": "sfiancare",
    "sfiancan": "sfiancare",
    "sfiancando": "sfiancare",
    "sfiancano": "sfiancare",
    "sfiancante": "sfiancare",
    "sfiancanti": "sfiancare",
    "sfiancar": "sfiancare",
    "sfiancaron": "sfiancare",
    "sfiancarono": "sfiancare",
    "sfiancasse": "sfiancare",
    "sfiancasser": "sfiancare",
    "sfiancassero": "sfiancare",
    "sfiancassi": "sfiancare",
    "sfiancassimo": "sfiancare",
    "sfiancaste": "sfiancare",
    "sfiancasti": "sfiancare",
    "sfiancata": "sfiancare",
    "sfiancate": "sfiancare",
    "sfiancati": "sfiancare",
    "sfiancato": "sfiancare",
    "sfiancava": "sfiancare",
    "sfiancavamo": "sfiancare",
    "sfiancavan": "sfiancare",
    "sfiancavano": "sfiancare",
    "sfiancavate": "sfiancare",
    "sfiancavi": "sfiancare",
    "sfiancavo": "sfiancare",
    "sfiancherai": "sfiancare",
    "sfiancheran": "sfiancare",
    "sfiancheranno": "sfiancare",
    "sfiancherebbe": "sfiancare",
    "sfiancherebber": "sfiancare",
    "sfiancherebbero": "sfiancare",
    "sfiancherei": "sfiancare",
    "sfiancheremmo": "sfiancare",
    "sfiancheremo": "sfiancare",
    "sfianchereste": "sfiancare",
    "sfiancheresti": "sfiancare",
    "sfiancherete": "sfiancare",
    "sfiancherà": "sfiancare",
    "sfiancherò": "sfiancare",
    "sfianchi": "sfiancare",
    "sfianchiamo": "sfiancare",
    "sfianchiate": "sfiancare",
    "sfianchin": "sfiancare",
    "sfianchino": "sfiancare",
    "sfianco": "sfiancare",
    "sfiancò": "sfiancare",
    "sfiata": "sfiatare",
    "sfiatai": "sfiatare",
    "sfiatammo": "sfiatare",
    "sfiatan": "sfiatare",
    "sfiatando": "sfiatare",
    "sfiatano": "sfiatare",
    "sfiatante": "sfiatare",
    "sfiatanti": "sfiatare",
    "sfiatar": "sfiatare",
    "sfiataron": "sfiatare",
    "sfiatarono": "sfiatare",
    "sfiatasse": "sfiatare",
    "sfiatasser": "sfiatare",
    "sfiatassero": "sfiatare",
    "sfiatassi": "sfiatare",
    "sfiatassimo": "sfiatare",
    "sfiataste": "sfiatare",
    "sfiatasti": "sfiatare",
    "sfiatata": "sfiatare",
    "sfiatate": "sfiatare",
    "sfiatati": "sfiatare",
    "sfiatato": "sfiatare",
    "sfiatava": "sfiatare",
    "sfiatavamo": "sfiatare",
    "sfiatavan": "sfiatare",
    "sfiatavano": "sfiatare",
    "sfiatavate": "sfiatare",
    "sfiatavi": "sfiatare",
    "sfiatavo": "sfiatare",
    "sfiate": "sfare",
    "sfiaterai": "sfiatare",
    "sfiateran": "sfiatare",
    "sfiateranno": "sfiatare",
    "sfiaterebbe": "sfiatare",
    "sfiaterebber": "sfiatare",
    "sfiaterebbero": "sfiatare",
    "sfiaterei": "sfiatare",
    "sfiateremmo": "sfiatare",
    "sfiateremo": "sfiatare",
    "sfiatereste": "sfiatare",
    "sfiateresti": "sfiatare",
    "sfiaterete": "sfiatare",
    "sfiaterà": "sfiatare",
    "sfiaterò": "sfiatare",
    "sfiati": "sfiatare",
    "sfiatiamo": "sfiatare",
    "sfiatiate": "sfiatare",
    "sfiatin": "sfiatare",
    "sfiatino": "sfiatare",
    "sfiato": "sfiatare",
    "sfiatò": "sfiatare",
    "sfibbi": "sfibbiare",
    "sfibbia": "sfibbiare",
    "sfibbiai": "sfibbiare",
    "sfibbiammo": "sfibbiare",
    "sfibbiamo": "sfibbiare",
    "sfibbian": "sfibbiare",
    "sfibbiando": "sfibbiare",
    "sfibbiano": "sfibbiare",
    "sfibbiante": "sfibbiare",
    "sfibbianti": "sfibbiare",
    "sfibbiar": "sfibbiare",
    "sfibbiaron": "sfibbiare",
    "sfibbiarono": "sfibbiare",
    "sfibbiasse": "sfibbiare",
    "sfibbiasser": "sfibbiare",
    "sfibbiassero": "sfibbiare",
    "sfibbiassi": "sfibbiare",
    "sfibbiassimo": "sfibbiare",
    "sfibbiaste": "sfibbiare",
    "sfibbiasti": "sfibbiare",
    "sfibbiata": "sfibbiare",
    "sfibbiate": "sfibbiare",
    "sfibbiati": "sfibbiare",
    "sfibbiato": "sfibbiare",
    "sfibbiava": "sfibbiare",
    "sfibbiavamo": "sfibbiare",
    "sfibbiavan": "sfibbiare",
    "sfibbiavano": "sfibbiare",
    "sfibbiavate": "sfibbiare",
    "sfibbiavi": "sfibbiare",
    "sfibbiavo": "sfibbiare",
    "sfibbierai": "sfibbiare",
    "sfibbieran": "sfibbiare",
    "sfibbieranno": "sfibbiare",
    "sfibbierebbe": "sfibbiare",
    "sfibbierebber": "sfibbiare",
    "sfibbierebbero": "sfibbiare",
    "sfibbierei": "sfibbiare",
    "sfibbieremmo": "sfibbiare",
    "sfibbieremo": "sfibbiare",
    "sfibbiereste": "sfibbiare",
    "sfibbieresti": "sfibbiare",
    "sfibbierete": "sfibbiare",
    "sfibbierà": "sfibbiare",
    "sfibbierò": "sfibbiare",
    "sfibbin": "sfibbiare",
    "sfibbino": "sfibbiare",
    "sfibbio": "sfibbiare",
    "sfibbiò": "sfibbiare",
    "sfibra": "sfibrare",
    "sfibrabili": "sfibrabile",
    "sfibrai": "sfibrare",
    "sfibrammo": "sfibrare",
    "sfibran": "sfibrare",
    "sfibrando": "sfibrare",
    "sfibrano": "sfibrare",
    "sfibrante": "sfibrare",
    "sfibranti": "sfibrare",
    "sfibrar": "sfibrare",
    "sfibraron": "sfibrare",
    "sfibrarono": "sfibrare",
    "sfibrasse": "sfibrare",
    "sfibrasser": "sfibrare",
    "sfibrassero": "sfibrare",
    "sfibrassi": "sfibrare",
    "sfibrassimo": "sfibrare",
    "sfibraste": "sfibrare",
    "sfibrasti": "sfibrare",
    "sfibrata": "sfibrato",
    "sfibrate": "sfibrato",
    "sfibrati": "sfibrato",
    "sfibrato": "sfibrare",
    "sfibrava": "sfibrare",
    "sfibravamo": "sfibrare",
    "sfibravan": "sfibrare",
    "sfibravano": "sfibrare",
    "sfibravate": "sfibrare",
    "sfibravi": "sfibrare",
    "sfibravo": "sfibrare",
    "sfibrerai": "sfibrare",
    "sfibreran": "sfibrare",
    "sfibreranno": "sfibrare",
    "sfibrerebbe": "sfibrare",
    "sfibrerebber": "sfibrare",
    "sfibrerebbero": "sfibrare",
    "sfibrerei": "sfibrare",
    "sfibreremmo": "sfibrare",
    "sfibreremo": "sfibrare",
    "sfibrereste": "sfibrare",
    "sfibreresti": "sfibrare",
    "sfibrerete": "sfibrare",
    "sfibrerà": "sfibrare",
    "sfibrerò": "sfibrare",
    "sfibri": "sfibrare",
    "sfibriamo": "sfibrare",
    "sfibriate": "sfibrare",
    "sfibrin": "sfibrare",
    "sfibrino": "sfibrare",
    "sfibro": "sfibrare",
    "sfibrò": "sfibrare",
    "sfida": "sfidare",
    "sfidai": "sfidare",
    "sfidammo": "sfidare",
    "sfidan": "sfidare",
    "sfidando": "sfidare",
    "sfidano": "sfidare",
    "sfidante": "sfidare",
    "sfidanti": "sfidare",
    "sfidar": "sfidare",
    "sfidaron": "sfidare",
    "sfidarono": "sfidare",
    "sfidasse": "sfidare",
    "sfidasser": "sfidare",
    "sfidassero": "sfidare",
    "sfidassi": "sfidare",
    "sfidassimo": "sfidare",
    "sfidaste": "sfidare",
    "sfidasti": "sfidare",
    "sfidata": "sfidare",
    "sfidate": "sfidare",
    "sfidati": "sfidare",
    "sfidato": "sfidare",
    "sfidava": "sfidare",
    "sfidavamo": "sfidare",
    "sfidavan": "sfidare",
    "sfidavano": "sfidare",
    "sfidavate": "sfidare",
    "sfidavi": "sfidare",
    "sfidavo": "sfidare",
    "sfide": "sfida",
    "sfiderai": "sfidare",
    "sfideran": "sfidare",
    "sfideranno": "sfidare",
    "sfiderebbe": "sfidare",
    "sfiderebber": "sfidare",
    "sfiderebbero": "sfidare",
    "sfiderei": "sfidare",
    "sfideremmo": "sfidare",
    "sfideremo": "sfidare",
    "sfidereste": "sfidare",
    "sfideresti": "sfidare",
    "sfiderete": "sfidare",
    "sfiderà": "sfidare",
    "sfiderò": "sfidare",
    "sfidi": "sfidare",
    "sfidiamo": "sfidare",
    "sfidiate": "sfidare",
    "sfidin": "sfidare",
    "sfidino": "sfidare",
    "sfido": "sfidare",
    "sfiduce": "sfiducia",
    "sfiducerai": "sfiduciare",
    "sfiduceran": "sfiduciare",
    "sfiduceranno": "sfiduciare",
    "sfiducerebbe": "sfiduciare",
    "sfiducerebber": "sfiduciare",
    "sfiducerebbero": "sfiduciare",
    "sfiducerei": "sfiduciare",
    "sfiduceremmo": "sfiduciare",
    "sfiduceremo": "sfiduciare",
    "sfiducereste": "sfiduciare",
    "sfiduceresti": "sfiduciare",
    "sfiducerete": "sfiduciare",
    "sfiducerà": "sfiduciare",
    "sfiducerò": "sfiduciare",
    "sfiduci": "sfiduciare",
    "sfiducia": "sfiduciare",
    "sfiduciai": "sfiduciare",
    "sfiduciammo": "sfiduciare",
    "sfiduciamo": "sfiduciare",
    "sfiducian": "sfiduciare",
    "sfiduciando": "sfiduciare",
    "sfiduciano": "sfiduciare",
    "sfiduciante": "sfiduciare",
    "sfiducianti": "sfiduciare",
    "sfiduciar": "sfiduciare",
    "sfiduciaron": "sfiduciare",
    "sfiduciarono": "sfiduciare",
    "sfiduciasse": "sfiduciare",
    "sfiduciasser": "sfiduciare",
    "sfiduciassero": "sfiduciare",
    "sfiduciassi": "sfiduciare",
    "sfiduciassimo": "sfiduciare",
    "sfiduciaste": "sfiduciare",
    "sfiduciasti": "sfiduciare",
    "sfiduciata": "sfiduciare",
    "sfiduciate": "sfiduciare",
    "sfiduciati": "sfiduciato",
    "sfiduciato": "sfiduciare",
    "sfiduciava": "sfiduciare",
    "sfiduciavamo": "sfiduciare",
    "sfiduciavan": "sfiduciare",
    "sfiduciavano": "sfiduciare",
    "sfiduciavate": "sfiduciare",
    "sfiduciavi": "sfiduciare",
    "sfiduciavo": "sfiduciare",
    "sfiducin": "sfiduciare",
    "sfiducino": "sfiduciare",
    "sfiducio": "sfiduciare",
    "sfiduciò": "sfiduciare",
    "sfidò": "sfidare",
    "sfigati": "sfigato",
    "sfighe": "sfiga",
    "sfigura": "sfigurare",
    "sfigurai": "sfigurare",
    "sfigurammo": "sfigurare",
    "sfiguran": "sfigurare",
    "sfigurando": "sfigurare",
    "sfigurano": "sfigurare",
    "sfigurante": "sfigurare",
    "sfiguranti": "sfigurare",
    "sfigurar": "sfigurare",
    "sfiguraron": "sfigurare",
    "sfigurarono": "sfigurare",
    "sfigurasse": "sfigurare",
    "sfigurasser": "sfigurare",
    "sfigurassero": "sfigurare",
    "sfigurassi": "sfigurare",
    "sfigurassimo": "sfigurare",
    "sfiguraste": "sfigurare",
    "sfigurasti": "sfigurare",
    "sfigurata": "sfigurare",
    "sfigurate": "sfigurare",
    "sfigurati": "sfigurare",
    "sfigurato": "sfigurare",
    "sfigurava": "sfigurare",
    "sfiguravamo": "sfigurare",
    "sfiguravan": "sfigurare",
    "sfiguravano": "sfigurare",
    "sfiguravate": "sfigurare",
    "sfiguravi": "sfigurare",
    "sfiguravo": "sfigurare",
    "sfigurerai": "sfigurare",
    "sfigureran": "sfigurare",
    "sfigureranno": "sfigurare",
    "sfigurerebbe": "sfigurare",
    "sfigurerebber": "sfigurare",
    "sfigurerebbero": "sfigurare",
    "sfigurerei": "sfigurare",
    "sfigureremmo": "sfigurare",
    "sfigureremo": "sfigurare",
    "sfigurereste": "sfigurare",
    "sfigureresti": "sfigurare",
    "sfigurerete": "sfigurare",
    "sfigurerà": "sfigurare",
    "sfigurerò": "sfigurare",
    "sfiguri": "sfigurare",
    "sfiguriamo": "sfigurare",
    "sfiguriate": "sfigurare",
    "sfigurin": "sfigurare",
    "sfigurino": "sfigurare",
    "sfiguro": "sfigurare",
    "sfigurò": "sfigurare",
    "sfila": "sfilare",
    "sfilaccerai": "sfilacciare",
    "sfilacceran": "sfilacciare",
    "sfilacceranno": "sfilacciare",
    "sfilaccerebbe": "sfilacciare",
    "sfilaccerebber": "sfilacciare",
    "sfilaccerebbero": "sfilacciare",
    "sfilaccerei": "sfilacciare",
    "sfilacceremmo": "sfilacciare",
    "sfilacceremo": "sfilacciare",
    "sfilaccereste": "sfilacciare",
    "sfilacceresti": "sfilacciare",
    "sfilaccerete": "sfilacciare",
    "sfilaccerà": "sfilacciare",
    "sfilaccerò": "sfilacciare",
    "sfilacci": "sfilacciare",
    "sfilaccia": "sfilacciare",
    "sfilacciai": "sfilacciare",
    "sfilacciamenti": "sfilacciamento",
    "sfilacciammo": "sfilacciare",
    "sfilacciamo": "sfilacciare",
    "sfilaccian": "sfilacciare",
    "sfilacciando": "sfilacciare",
    "sfilacciano": "sfilacciare",
    "sfilacciante": "sfilacciare",
    "sfilaccianti": "sfilacciare",
    "sfilacciar": "sfilacciare",
    "sfilacciaron": "sfilacciare",
    "sfilacciarono": "sfilacciare",
    "sfilacciasse": "sfilacciare",
    "sfilacciasser": "sfilacciare",
    "sfilacciassero": "sfilacciare",
    "sfilacciassi": "sfilacciare",
    "sfilacciassimo": "sfilacciare",
    "sfilacciaste": "sfilacciare",
    "sfilacciasti": "sfilacciare",
    "sfilacciata": "sfilacciato",
    "sfilacciate": "sfilacciato",
    "sfilacciati": "sfilacciato",
    "sfilacciato": "sfilacciare",
    "sfilacciava": "sfilacciare",
    "sfilacciavamo": "sfilacciare",
    "sfilacciavan": "sfilacciare",
    "sfilacciavano": "sfilacciare",
    "sfilacciavate": "sfilacciare",
    "sfilacciavi": "sfilacciare",
    "sfilacciavo": "sfilacciare",
    "sfilaccin": "sfilacciare",
    "sfilaccino": "sfilacciare",
    "sfilaccio": "sfilacciare",
    "sfilacciò": "sfilacciare",
    "sfilai": "sfilare",
    "sfilammo": "sfilare",
    "sfilan": "sfilare",
    "sfilando": "sfilare",
    "sfilano": "sfilare",
    "sfilante": "sfilare",
    "sfilanti": "sfilare",
    "sfilar": "sfilare",
    "sfilaron": "sfilare",
    "sfilarono": "sfilare",
    "sfilasse": "sfilare",
    "sfilasser": "sfilare",
    "sfilassero": "sfilare",
    "sfilassi": "sfilare",
    "sfilassimo": "sfilare",
    "sfilaste": "sfilare",
    "sfilasti": "sfilare",
    "sfilata": "sfilato",
    "sfilate": "sfilato",
    "sfilati": "sfilato",
    "sfilatini": "sfilatino",
    "sfilato": "sfilare",
    "sfilava": "sfilare",
    "sfilavamo": "sfilare",
    "sfilavan": "sfilare",
    "sfilavano": "sfilare",
    "sfilavate": "sfilare",
    "sfilavi": "sfilare",
    "sfilavo": "sfilare",
    "sfilerai": "sfilare",
    "sfileran": "sfilare",
    "sfileranno": "sfilare",
    "sfilerebbe": "sfilare",
    "sfilerebber": "sfilare",
    "sfilerebbero": "sfilare",
    "sfilerei": "sfilare",
    "sfileremmo": "sfilare",
    "sfileremo": "sfilare",
    "sfilereste": "sfilare",
    "sfileresti": "sfilare",
    "sfilerete": "sfilare",
    "sfilerà": "sfilare",
    "sfilerò": "sfilare",
    "sfili": "sfilare",
    "sfiliamo": "sfilare",
    "sfiliate": "sfilare",
    "sfilin": "sfilare",
    "sfilino": "sfilare",
    "sfilo": "sfilare",
    "sfilze": "sfilza",
    "sfilò": "sfilare",
    "sfin": "sfare",
    "sfinendo": "sfinire",
    "sfinente": "sfinire",
    "sfinenti": "sfinire",
    "sfiniamo": "sfinire",
    "sfiniate": "sfinire",
    "sfinii": "sfinire",
    "sfinimenti": "sfinimento",
    "sfinimmo": "sfinire",
    "sfinir": "sfinire",
    "sfinirai": "sfinire",
    "sfiniran": "sfinire",
    "sfiniranno": "sfinire",
    "sfinirebbe": "sfinire",
    "sfinirebber": "sfinire",
    "sfinirebbero": "sfinire",
    "sfinirei": "sfinire",
    "sfiniremmo": "sfinire",
    "sfiniremo": "sfinire",
    "sfinireste": "sfinire",
    "sfiniresti": "sfinire",
    "sfinirete": "sfinire",
    "sfiniron": "sfinire",
    "sfinirono": "sfinire",
    "sfinirà": "sfinire",
    "sfinirò": "sfinire",
    "sfinisca": "sfinire",
    "sfiniscan": "sfinire",
    "sfiniscano": "sfinire",
    "sfinisce": "sfinire",
    "sfinisci": "sfinire",
    "sfinisco": "sfinire",
    "sfiniscon": "sfinire",
    "sfiniscono": "sfinire",
    "sfinisse": "sfinire",
    "sfinisser": "sfinire",
    "sfinissero": "sfinire",
    "sfinissi": "sfinire",
    "sfinissimo": "sfinire",
    "sfiniste": "sfinire",
    "sfinisti": "sfinire",
    "sfinita": "sfinire",
    "sfinite": "sfinire",
    "sfiniti": "sfinire",
    "sfinito": "sfinire",
    "sfiniva": "sfinire",
    "sfinivamo": "sfinire",
    "sfinivan": "sfinire",
    "sfinivano": "sfinire",
    "sfinivate": "sfinire",
    "sfinivi": "sfinire",
    "sfinivo": "sfinire",
    "sfino": "sfare",
    "sfinteri": "sfintere",
    "sfinì": "sfinire",
    "sfiora": "sfiorare",
    "sfiorai": "sfiorare",
    "sfiorammo": "sfiorare",
    "sfioran": "sfiorare",
    "sfiorando": "sfiorare",
    "sfiorano": "sfiorare",
    "sfiorante": "sfiorare",
    "sfioranti": "sfiorare",
    "sfiorar": "sfiorare",
    "sfioraron": "sfiorare",
    "sfiorarono": "sfiorare",
    "sfiorasse": "sfiorare",
    "sfiorasser": "sfiorare",
    "sfiorassero": "sfiorare",
    "sfiorassi": "sfiorare",
    "sfiorassimo": "sfiorare",
    "sfioraste": "sfiorare",
    "sfiorasti": "sfiorare",
    "sfiorata": "sfiorare",
    "sfiorate": "sfiorare",
    "sfiorati": "sfiorare",
    "sfiorato": "sfiorare",
    "sfiorava": "sfiorare",
    "sfioravamo": "sfiorare",
    "sfioravan": "sfiorare",
    "sfioravano": "sfiorare",
    "sfioravate": "sfiorare",
    "sfioravi": "sfiorare",
    "sfioravo": "sfiorare",
    "sfiorendo": "sfiorire",
    "sfiorente": "sfiorire",
    "sfiorenti": "sfiorire",
    "sfiorerai": "sfiorare",
    "sfioreran": "sfiorare",
    "sfioreranno": "sfiorare",
    "sfiorerebbe": "sfiorare",
    "sfiorerebber": "sfiorare",
    "sfiorerebbero": "sfiorare",
    "sfiorerei": "sfiorare",
    "sfioreremmo": "sfiorare",
    "sfioreremo": "sfiorare",
    "sfiorereste": "sfiorare",
    "sfioreresti": "sfiorare",
    "sfiorerete": "sfiorare",
    "sfiorerà": "sfiorare",
    "sfiorerò": "sfiorare",
    "sfiori": "sfiorare",
    "sfioriamo": "sfiorire",
    "sfioriate": "sfiorire",
    "sfiorii": "sfiorire",
    "sfiorimmo": "sfiorire",
    "sfiorin": "sfiorare",
    "sfiorino": "sfiorare",
    "sfiorir": "sfiorire",
    "sfiorirai": "sfiorire",
    "sfioriran": "sfiorire",
    "sfioriranno": "sfiorire",
    "sfiorirebbe": "sfiorire",
    "sfiorirebber": "sfiorire",
    "sfiorirebbero": "sfiorire",
    "sfiorirei": "sfiorire",
    "sfioriremmo": "sfiorire",
    "sfioriremo": "sfiorire",
    "sfiorireste": "sfiorire",
    "sfioriresti": "sfiorire",
    "sfiorirete": "sfiorire",
    "sfioriron": "sfiorire",
    "sfiorirono": "sfiorire",
    "sfiorirà": "sfiorire",
    "sfiorirò": "sfiorire",
    "sfiorisca": "sfiorire",
    "sfioriscan": "sfiorire",
    "sfioriscano": "sfiorire",
    "sfiorisce": "sfiorire",
    "sfiorisci": "sfiorire",
    "sfiorisco": "sfiorire",
    "sfioriscon": "sfiorire",
    "sfioriscono": "sfiorire",
    "sfiorisse": "sfiorire",
    "sfiorisser": "sfiorire",
    "sfiorissero": "sfiorire",
    "sfiorissi": "sfiorire",
    "sfiorissimo": "sfiorire",
    "sfioriste": "sfiorire",
    "sfioristi": "sfiorire",
    "sfiorita": "sfiorire",
    "sfiorite": "sfiorire",
    "sfioriti": "sfiorire",
    "sfiorito": "sfiorire",
    "sfioriva": "sfiorire",
    "sfiorivamo": "sfiorire",
    "sfiorivan": "sfiorire",
    "sfiorivano": "sfiorire",
    "sfiorivate": "sfiorire",
    "sfiorivi": "sfiorire",
    "sfiorivo": "sfiorire",
    "sfioro": "sfiorare",
    "sfiorì": "sfiorire",
    "sfiorò": "sfiorare",
    "sfitta": "sfitto",
    "sfittai": "sfittare",
    "sfittammo": "sfittare",
    "sfittan": "sfittare",
    "sfittando": "sfittare",
    "sfittano": "sfittare",
    "sfittante": "sfittare",
    "sfittanti": "sfittare",
    "sfittar": "sfittare",
    "sfittaron": "sfittare",
    "sfittarono": "sfittare",
    "sfittasse": "sfittare",
    "sfittasser": "sfittare",
    "sfittassero": "sfittare",
    "sfittassi": "sfittare",
    "sfittassimo": "sfittare",
    "sfittaste": "sfittare",
    "sfittasti": "sfittare",
    "sfittata": "sfittare",
    "sfittate": "sfittare",
    "sfittati": "sfittare",
    "sfittato": "sfittare",
    "sfittava": "sfittare",
    "sfittavamo": "sfittare",
    "sfittavan": "sfittare",
    "sfittavano": "sfittare",
    "sfittavate": "sfittare",
    "sfittavi": "sfittare",
    "sfittavo": "sfittare",
    "sfitte": "sfitto",
    "sfitterai": "sfittare",
    "sfitteran": "sfittare",
    "sfitteranno": "sfittare",
    "sfitterebbe": "sfittare",
    "sfitterebber": "sfittare",
    "sfitterebbero": "sfittare",
    "sfitterei": "sfittare",
    "sfitteremmo": "sfittare",
    "sfitteremo": "sfittare",
    "sfittereste": "sfittare",
    "sfitteresti": "sfittare",
    "sfitterete": "sfittare",
    "sfitterà": "sfittare",
    "sfitterò": "sfittare",
    "sfitti": "sfitto",
    "sfittiamo": "sfittare",
    "sfittiate": "sfittare",
    "sfittin": "sfittare",
    "sfittino": "sfittare",
    "sfitto": "sfittare",
    "sfittò": "sfittare",
    "sfizi": "sfizio",
    "sfiziosa": "sfizioso",
    "sfiziose": "sfizioso",
    "sfiziosi": "sfizioso",
    "sfo": "sfare",
    "sfoca": "sfocare",
    "sfocai": "sfocare",
    "sfocammo": "sfocare",
    "sfocan": "sfocare",
    "sfocando": "sfocare",
    "sfocano": "sfocare",
    "sfocante": "sfocare",
    "sfocanti": "sfocare",
    "sfocar": "sfocare",
    "sfocaron": "sfocare",
    "sfocarono": "sfocare",
    "sfocasse": "sfocare",
    "sfocasser": "sfocare",
    "sfocassero": "sfocare",
    "sfocassi": "sfocare",
    "sfocassimo": "sfocare",
    "sfocaste": "sfocare",
    "sfocasti": "sfocare",
    "sfocata": "sfocato",
    "sfocate": "sfocato",
    "sfocati": "sfocato",
    "sfocato": "sfocare",
    "sfocava": "sfocare",
    "sfocavamo": "sfocare",
    "sfocavan": "sfocare",
    "sfocavano": "sfocare",
    "sfocavate": "sfocare",
    "sfocavi": "sfocare",
    "sfocavo": "sfocare",
    "sfocerai": "sfociare",
    "sfoceran": "sfociare",
    "sfoceranno": "sfociare",
    "sfocerebbe": "sfociare",
    "sfocerebber": "sfociare",
    "sfocerebbero": "sfociare",
    "sfocerei": "sfociare",
    "sfoceremmo": "sfociare",
    "sfoceremo": "sfociare",
    "sfocereste": "sfociare",
    "sfoceresti": "sfociare",
    "sfocerete": "sfociare",
    "sfocerà": "sfociare",
    "sfocerò": "sfociare",
    "sfocherai": "sfocare",
    "sfocheran": "sfocare",
    "sfocheranno": "sfocare",
    "sfocherebbe": "sfocare",
    "sfocherebber": "sfocare",
    "sfocherebbero": "sfocare",
    "sfocherei": "sfocare",
    "sfocheremmo": "sfocare",
    "sfocheremo": "sfocare",
    "sfochereste": "sfocare",
    "sfocheresti": "sfocare",
    "sfocherete": "sfocare",
    "sfocherà": "sfocare",
    "sfocherò": "sfocare",
    "sfochi": "sfocare",
    "sfochiamo": "sfocare",
    "sfochiate": "sfocare",
    "sfochin": "sfocare",
    "sfochino": "sfocare",
    "sfoci": "sfociare",
    "sfocia": "sfociare",
    "sfociai": "sfociare",
    "sfociammo": "sfociare",
    "sfociamo": "sfociare",
    "sfocian": "sfociare",
    "sfociando": "sfociare",
    "sfociano": "sfociare",
    "sfociante": "sfociare",
    "sfocianti": "sfociare",
    "sfociar": "sfociare",
    "sfociaron": "sfociare",
    "sfociarono": "sfociare",
    "sfociasse": "sfociare",
    "sfociasser": "sfociare",
    "sfociassero": "sfociare",
    "sfociassi": "sfociare",
    "sfociassimo": "sfociare",
    "sfociaste": "sfociare",
    "sfociasti": "sfociare",
    "sfociata": "sfociare",
    "sfociate": "sfociare",
    "sfociati": "sfociare",
    "sfociato": "sfociare",
    "sfociava": "sfociare",
    "sfociavamo": "sfociare",
    "sfociavan": "sfociare",
    "sfociavano": "sfociare",
    "sfociavate": "sfociare",
    "sfociavi": "sfociare",
    "sfociavo": "sfociare",
    "sfocin": "sfociare",
    "sfocino": "sfociare",
    "sfocio": "sfociare",
    "sfociò": "sfociare",
    "sfoco": "sfocare",
    "sfocò": "sfocare",
    "sfodera": "sfoderare",
    "sfoderai": "sfoderare",
    "sfoderammo": "sfoderare",
    "sfoderan": "sfoderare",
    "sfoderando": "sfoderare",
    "sfoderano": "sfoderare",
    "sfoderante": "sfoderare",
    "sfoderanti": "sfoderare",
    "sfoderar": "sfoderare",
    "sfoderaron": "sfoderare",
    "sfoderarono": "sfoderare",
    "sfoderasse": "sfoderare",
    "sfoderasser": "sfoderare",
    "sfoderassero": "sfoderare",
    "sfoderassi": "sfoderare",
    "sfoderassimo": "sfoderare",
    "sfoderaste": "sfoderare",
    "sfoderasti": "sfoderare",
    "sfoderata": "sfoderare",
    "sfoderate": "sfoderare",
    "sfoderati": "sfoderare",
    "sfoderato": "sfoderare",
    "sfoderava": "sfoderare",
    "sfoderavamo": "sfoderare",
    "sfoderavan": "sfoderare",
    "sfoderavano": "sfoderare",
    "sfoderavate": "sfoderare",
    "sfoderavi": "sfoderare",
    "sfoderavo": "sfoderare",
    "sfodererai": "sfoderare",
    "sfodereran": "sfoderare",
    "sfodereranno": "sfoderare",
    "sfodererebbe": "sfoderare",
    "sfodererebber": "sfoderare",
    "sfodererebbero": "sfoderare",
    "sfodererei": "sfoderare",
    "sfodereremmo": "sfoderare",
    "sfodereremo": "sfoderare",
    "sfoderereste": "sfoderare",
    "sfodereresti": "sfoderare",
    "sfodererete": "sfoderare",
    "sfodererà": "sfoderare",
    "sfodererò": "sfoderare",
    "sfoderi": "sfoderare",
    "sfoderiamo": "sfoderare",
    "sfoderiate": "sfoderare",
    "sfoderin": "sfoderare",
    "sfoderino": "sfoderare",
    "sfodero": "sfoderare",
    "sfoderò": "sfoderare",
    "sfoga": "sfogare",
    "sfogai": "sfogare",
    "sfogammo": "sfogare",
    "sfogan": "sfogare",
    "sfogando": "sfogare",
    "sfogano": "sfogare",
    "sfogante": "sfogare",
    "sfoganti": "sfogare",
    "sfogar": "sfogare",
    "sfogaron": "sfogare",
    "sfogarono": "sfogare",
    "sfogasse": "sfogare",
    "sfogasser": "sfogare",
    "sfogassero": "sfogare",
    "sfogassi": "sfogare",
    "sfogassimo": "sfogare",
    "sfogaste": "sfogare",
    "sfogasti": "sfogare",
    "sfogata": "sfogare",
    "sfogate": "sfogare",
    "sfogati": "sfogare",
    "sfogato": "sfogare",
    "sfogava": "sfogare",
    "sfogavamo": "sfogare",
    "sfogavan": "sfogare",
    "sfogavano": "sfogare",
    "sfogavate": "sfogare",
    "sfogavi": "sfogare",
    "sfogavo": "sfogare",
    "sfoggerai": "sfoggiare",
    "sfoggeran": "sfoggiare",
    "sfoggeranno": "sfoggiare",
    "sfoggerebbe": "sfoggiare",
    "sfoggerebber": "sfoggiare",
    "sfoggerebbero": "sfoggiare",
    "sfoggerei": "sfoggiare",
    "sfoggeremmo": "sfoggiare",
    "sfoggeremo": "sfoggiare",
    "sfoggereste": "sfoggiare",
    "sfoggeresti": "sfoggiare",
    "sfoggerete": "sfoggiare",
    "sfoggerà": "sfoggiare",
    "sfoggerò": "sfoggiare",
    "sfoggi": "sfoggio",
    "sfoggia": "sfoggiare",
    "sfoggiai": "sfoggiare",
    "sfoggiammo": "sfoggiare",
    "sfoggiamo": "sfoggiare",
    "sfoggian": "sfoggiare",
    "sfoggiando": "sfoggiare",
    "sfoggiano": "sfoggiare",
    "sfoggiante": "sfoggiare",
    "sfoggianti": "sfoggiare",
    "sfoggiar": "sfoggiare",
    "sfoggiaron": "sfoggiare",
    "sfoggiarono": "sfoggiare",
    "sfoggiasse": "sfoggiare",
    "sfoggiasser": "sfoggiare",
    "sfoggiassero": "sfoggiare",
    "sfoggiassi": "sfoggiare",
    "sfoggiassimo": "sfoggiare",
    "sfoggiaste": "sfoggiare",
    "sfoggiasti": "sfoggiare",
    "sfoggiata": "sfoggiare",
    "sfoggiate": "sfoggiare",
    "sfoggiati": "sfoggiare",
    "sfoggiato": "sfoggiare",
    "sfoggiava": "sfoggiare",
    "sfoggiavamo": "sfoggiare",
    "sfoggiavan": "sfoggiare",
    "sfoggiavano": "sfoggiare",
    "sfoggiavate": "sfoggiare",
    "sfoggiavi": "sfoggiare",
    "sfoggiavo": "sfoggiare",
    "sfoggin": "sfoggiare",
    "sfoggino": "sfoggiare",
    "sfoggio": "sfoggiare",
    "sfoggiò": "sfoggiare",
    "sfogherai": "sfogare",
    "sfogheran": "sfogare",
    "sfogheranno": "sfogare",
    "sfogherebbe": "sfogare",
    "sfogherebber": "sfogare",
    "sfogherebbero": "sfogare",
    "sfogherei": "sfogare",
    "sfogheremmo": "sfogare",
    "sfogheremo": "sfogare",
    "sfoghereste": "sfogare",
    "sfogheresti": "sfogare",
    "sfogherete": "sfogare",
    "sfogherà": "sfogare",
    "sfogherò": "sfogare",
    "sfoghi": "sfogo",
    "sfoghiamo": "sfogare",
    "sfoghiate": "sfogare",
    "sfoghin": "sfogare",
    "sfoghino": "sfogare",
    "sfogli": "sfogliare",
    "sfoglia": "sfogliare",
    "sfogliai": "sfogliare",
    "sfogliammo": "sfogliare",
    "sfogliamo": "sfogliare",
    "sfoglian": "sfogliare",
    "sfogliando": "sfogliare",
    "sfogliano": "sfogliare",
    "sfogliante": "sfogliare",
    "sfoglianti": "sfogliare",
    "sfogliar": "sfogliare",
    "sfogliaron": "sfogliare",
    "sfogliarono": "sfogliare",
    "sfogliasse": "sfogliare",
    "sfogliasser": "sfogliare",
    "sfogliassero": "sfogliare",
    "sfogliassi": "sfogliare",
    "sfogliassimo": "sfogliare",
    "sfogliaste": "sfogliare",
    "sfogliasti": "sfogliare",
    "sfogliata": "sfogliare",
    "sfogliate": "sfogliare",
    "sfogliatelle": "sfogliatella",
    "sfogliati": "sfogliare",
    "sfogliato": "sfogliare",
    "sfogliava": "sfogliare",
    "sfogliavamo": "sfogliare",
    "sfogliavan": "sfogliare",
    "sfogliavano": "sfogliare",
    "sfogliavate": "sfogliare",
    "sfogliavi": "sfogliare",
    "sfogliavo": "sfogliare",
    "sfoglie": "sfoglia",
    "sfoglierai": "sfogliare",
    "sfoglieran": "sfogliare",
    "sfoglieranno": "sfogliare",
    "sfoglierebbe": "sfogliare",
    "sfoglierebber": "sfogliare",
    "sfoglierebbero": "sfogliare",
    "sfoglierei": "sfogliare",
    "sfoglieremmo": "sfogliare",
    "sfoglieremo": "sfogliare",
    "sfogliereste": "sfogliare",
    "sfoglieresti": "sfogliare",
    "sfoglierete": "sfogliare",
    "sfoglierà": "sfogliare",
    "sfoglierò": "sfogliare",
    "sfoglin": "sfogliare",
    "sfoglino": "sfogliare",
    "sfoglio": "sfogliare",
    "sfogliò": "sfogliare",
    "sfogo": "sfogare",
    "sfogò": "sfogare",
    "sfolgora": "sfolgorare",
    "sfolgorai": "sfolgorare",
    "sfolgorammo": "sfolgorare",
    "sfolgoran": "sfolgorare",
    "sfolgorando": "sfolgorare",
    "sfolgorano": "sfolgorare",
    "sfolgorante": "sfolgorare",
    "sfolgoranti": "sfolgorare",
    "sfolgorar": "sfolgorare",
    "sfolgoraron": "sfolgorare",
    "sfolgorarono": "sfolgorare",
    "sfolgorasse": "sfolgorare",
    "sfolgorasser": "sfolgorare",
    "sfolgorassero": "sfolgorare",
    "sfolgorassi": "sfolgorare",
    "sfolgorassimo": "sfolgorare",
    "sfolgoraste": "sfolgorare",
    "sfolgorasti": "sfolgorare",
    "sfolgorata": "sfolgorare",
    "sfolgorate": "sfolgorare",
    "sfolgorati": "sfolgorare",
    "sfolgorato": "sfolgorare",
    "sfolgorava": "sfolgorare",
    "sfolgoravamo": "sfolgorare",
    "sfolgoravan": "sfolgorare",
    "sfolgoravano": "sfolgorare",
    "sfolgoravate": "sfolgorare",
    "sfolgoravi": "sfolgorare",
    "sfolgoravo": "sfolgorare",
    "sfolgorerai": "sfolgorare",
    "sfolgoreran": "sfolgorare",
    "sfolgoreranno": "sfolgorare",
    "sfolgorerebbe": "sfolgorare",
    "sfolgorerebber": "sfolgorare",
    "sfolgorerebbero": "sfolgorare",
    "sfolgorerei": "sfolgorare",
    "sfolgoreremmo": "sfolgorare",
    "sfolgoreremo": "sfolgorare",
    "sfolgorereste": "sfolgorare",
    "sfolgoreresti": "sfolgorare",
    "sfolgorerete": "sfolgorare",
    "sfolgorerà": "sfolgorare",
    "sfolgorerò": "sfolgorare",
    "sfolgori": "sfolgorare",
    "sfolgoriamo": "sfolgorare",
    "sfolgoriate": "sfolgorare",
    "sfolgorin": "sfolgorare",
    "sfolgorino": "sfolgorare",
    "sfolgoro": "sfolgorare",
    "sfolgorò": "sfolgorare",
    "sfolla": "sfollare",
    "sfollai": "sfollare",
    "sfollamenti": "sfollamento",
    "sfollammo": "sfollare",
    "sfollan": "sfollare",
    "sfollando": "sfollare",
    "sfollano": "sfollare",
    "sfollante": "sfollare",
    "sfollanti": "sfollare",
    "sfollar": "sfollare",
    "sfollaron": "sfollare",
    "sfollarono": "sfollare",
    "sfollasse": "sfollare",
    "sfollasser": "sfollare",
    "sfollassero": "sfollare",
    "sfollassi": "sfollare",
    "sfollassimo": "sfollare",
    "sfollaste": "sfollare",
    "sfollasti": "sfollare",
    "sfollata": "sfollato",
    "sfollate": "sfollato",
    "sfollati": "sfollato",
    "sfollato": "sfollare",
    "sfollava": "sfollare",
    "sfollavamo": "sfollare",
    "sfollavan": "sfollare",
    "sfollavano": "sfollare",
    "sfollavate": "sfollare",
    "sfollavi": "sfollare",
    "sfollavo": "sfollare",
    "sfollerai": "sfollare",
    "sfolleran": "sfollare",
    "sfolleranno": "sfollare",
    "sfollerebbe": "sfollare",
    "sfollerebber": "sfollare",
    "sfollerebbero": "sfollare",
    "sfollerei": "sfollare",
    "sfolleremmo": "sfollare",
    "sfolleremo": "sfollare",
    "sfollereste": "sfollare",
    "sfolleresti": "sfollare",
    "sfollerete": "sfollare",
    "sfollerà": "sfollare",
    "sfollerò": "sfollare",
    "sfolli": "sfollare",
    "sfolliamo": "sfollare",
    "sfolliate": "sfollare",
    "sfollin": "sfollare",
    "sfollino": "sfollare",
    "sfollo": "sfollare",
    "sfollò": "sfollare",
    "sfoltendo": "sfoltire",
    "sfoltente": "sfoltire",
    "sfoltenti": "sfoltire",
    "sfoltiamo": "sfoltire",
    "sfoltiate": "sfoltire",
    "sfoltii": "sfoltire",
    "sfoltimenti": "sfoltimento",
    "sfoltimmo": "sfoltire",
    "sfoltir": "sfoltire",
    "sfoltirai": "sfoltire",
    "sfoltiran": "sfoltire",
    "sfoltiranno": "sfoltire",
    "sfoltirebbe": "sfoltire",
    "sfoltirebber": "sfoltire",
    "sfoltirebbero": "sfoltire",
    "sfoltirei": "sfoltire",
    "sfoltiremmo": "sfoltire",
    "sfoltiremo": "sfoltire",
    "sfoltireste": "sfoltire",
    "sfoltiresti": "sfoltire",
    "sfoltirete": "sfoltire",
    "sfoltiron": "sfoltire",
    "sfoltirono": "sfoltire",
    "sfoltirà": "sfoltire",
    "sfoltirò": "sfoltire",
    "sfoltisca": "sfoltire",
    "sfoltiscan": "sfoltire",
    "sfoltiscano": "sfoltire",
    "sfoltisce": "sfoltire",
    "sfoltisci": "sfoltire",
    "sfoltisco": "sfoltire",
    "sfoltiscon": "sfoltire",
    "sfoltiscono": "sfoltire",
    "sfoltisse": "sfoltire",
    "sfoltisser": "sfoltire",
    "sfoltissero": "sfoltire",
    "sfoltissi": "sfoltire",
    "sfoltissimo": "sfoltire",
    "sfoltiste": "sfoltire",
    "sfoltisti": "sfoltire",
    "sfoltita": "sfoltire",
    "sfoltite": "sfoltire",
    "sfoltiti": "sfoltire",
    "sfoltito": "sfoltire",
    "sfoltiva": "sfoltire",
    "sfoltivamo": "sfoltire",
    "sfoltivan": "sfoltire",
    "sfoltivano": "sfoltire",
    "sfoltivate": "sfoltire",
    "sfoltivi": "sfoltire",
    "sfoltivo": "sfoltire",
    "sfoltì": "sfoltire",
    "sfonda": "sfondare",
    "sfondai": "sfondare",
    "sfondamenti": "sfondamento",
    "sfondammo": "sfondare",
    "sfondan": "sfondare",
    "sfondando": "sfondare",
    "sfondano": "sfondare",
    "sfondante": "sfondare",
    "sfondanti": "sfondare",
    "sfondar": "sfondare",
    "sfondaron": "sfondare",
    "sfondarono": "sfondare",
    "sfondasse": "sfondare",
    "sfondasser": "sfondare",
    "sfondassero": "sfondare",
    "sfondassi": "sfondare",
    "sfondassimo": "sfondare",
    "sfondaste": "sfondare",
    "sfondasti": "sfondare",
    "sfondata": "sfondato",
    "sfondate": "sfondato",
    "sfondati": "sfondato",
    "sfondato": "sfondare",
    "sfondava": "sfondare",
    "sfondavamo": "sfondare",
    "sfondavan": "sfondare",
    "sfondavano": "sfondare",
    "sfondavate": "sfondare",
    "sfondavi": "sfondare",
    "sfondavo": "sfondare",
    "sfonderai": "sfondare",
    "sfonderan": "sfondare",
    "sfonderanno": "sfondare",
    "sfonderebbe": "sfondare",
    "sfonderebber": "sfondare",
    "sfonderebbero": "sfondare",
    "sfonderei": "sfondare",
    "sfonderemmo": "sfondare",
    "sfonderemo": "sfondare",
    "sfondereste": "sfondare",
    "sfonderesti": "sfondare",
    "sfonderete": "sfondare",
    "sfonderà": "sfondare",
    "sfonderò": "sfondare",
    "sfondi": "sfondo",
    "sfondiamo": "sfondare",
    "sfondiate": "sfondare",
    "sfondin": "sfondare",
    "sfondino": "sfondare",
    "sfondo": "sfondare",
    "sfondò": "sfondare",
    "sforamenti": "sforamento",
    "sforbicerai": "sforbiciare",
    "sforbiceran": "sforbiciare",
    "sforbiceranno": "sforbiciare",
    "sforbicerebbe": "sforbiciare",
    "sforbicerebber": "sforbiciare",
    "sforbicerebbero": "sforbiciare",
    "sforbicerei": "sforbiciare",
    "sforbiceremmo": "sforbiciare",
    "sforbiceremo": "sforbiciare",
    "sforbicereste": "sforbiciare",
    "sforbiceresti": "sforbiciare",
    "sforbicerete": "sforbiciare",
    "sforbicerà": "sforbiciare",
    "sforbicerò": "sforbiciare",
    "sforbici": "sforbiciare",
    "sforbicia": "sforbiciare",
    "sforbiciai": "sforbiciare",
    "sforbiciammo": "sforbiciare",
    "sforbiciamo": "sforbiciare",
    "sforbician": "sforbiciare",
    "sforbiciando": "sforbiciare",
    "sforbiciano": "sforbiciare",
    "sforbiciante": "sforbiciare",
    "sforbicianti": "sforbiciare",
    "sforbiciar": "sforbiciare",
    "sforbiciaron": "sforbiciare",
    "sforbiciarono": "sforbiciare",
    "sforbiciasse": "sforbiciare",
    "sforbiciasser": "sforbiciare",
    "sforbiciassero": "sforbiciare",
    "sforbiciassi": "sforbiciare",
    "sforbiciassimo": "sforbiciare",
    "sforbiciaste": "sforbiciare",
    "sforbiciasti": "sforbiciare",
    "sforbiciata": "sforbiciare",
    "sforbiciate": "sforbiciata",
    "sforbiciati": "sforbiciare",
    "sforbiciato": "sforbiciare",
    "sforbiciava": "sforbiciare",
    "sforbiciavamo": "sforbiciare",
    "sforbiciavan": "sforbiciare",
    "sforbiciavano": "sforbiciare",
    "sforbiciavate": "sforbiciare",
    "sforbiciavi": "sforbiciare",
    "sforbiciavo": "sforbiciare",
    "sforbicin": "sforbiciare",
    "sforbicino": "sforbiciare",
    "sforbicio": "sforbiciare",
    "sforbiciò": "sforbiciare",
    "sforma": "sformare",
    "sformai": "sformare",
    "sformammo": "sformare",
    "sforman": "sformare",
    "sformando": "sformare",
    "sformano": "sformare",
    "sformante": "sformare",
    "sformanti": "sformare",
    "sformar": "sformare",
    "sformaron": "sformare",
    "sformarono": "sformare",
    "sformasse": "sformare",
    "sformasser": "sformare",
    "sformassero": "sformare",
    "sformassi": "sformare",
    "sformassimo": "sformare",
    "sformaste": "sformare",
    "sformasti": "sformare",
    "sformata": "sformato",
    "sformate": "sformato",
    "sformati": "sformato",
    "sformato": "sformare",
    "sformava": "sformare",
    "sformavamo": "sformare",
    "sformavan": "sformare",
    "sformavano": "sformare",
    "sformavate": "sformare",
    "sformavi": "sformare",
    "sformavo": "sformare",
    "sformerai": "sformare",
    "sformeran": "sformare",
    "sformeranno": "sformare",
    "sformerebbe": "sformare",
    "sformerebber": "sformare",
    "sformerebbero": "sformare",
    "sformerei": "sformare",
    "sformeremmo": "sformare",
    "sformeremo": "sformare",
    "sformereste": "sformare",
    "sformeresti": "sformare",
    "sformerete": "sformare",
    "sformerà": "sformare",
    "sformerò": "sformare",
    "sformi": "sformare",
    "sformiamo": "sformare",
    "sformiate": "sformare",
    "sformin": "sformare",
    "sformino": "sformare",
    "sformo": "sformare",
    "sformò": "sformare",
    "sforna": "sfornire",
    "sfornai": "sfornare",
    "sfornammo": "sfornare",
    "sfornan": "sfornire",
    "sfornando": "sfornare",
    "sfornano": "sfornire",
    "sfornante": "sfornare",
    "sfornanti": "sfornare",
    "sfornar": "sfornare",
    "sfornaron": "sfornare",
    "sfornarono": "sfornare",
    "sfornasse": "sfornare",
    "sfornasser": "sfornare",
    "sfornassero": "sfornare",
    "sfornassi": "sfornare",
    "sfornassimo": "sfornare",
    "sfornaste": "sfornare",
    "sfornasti": "sfornare",
    "sfornata": "sfornare",
    "sfornate": "sfornare",
    "sfornati": "sfornare",
    "sfornato": "sfornare",
    "sfornava": "sfornare",
    "sfornavamo": "sfornare",
    "sfornavan": "sfornare",
    "sfornavano": "sfornare",
    "sfornavate": "sfornare",
    "sfornavi": "sfornare",
    "sfornavo": "sfornare",
    "sforne": "sfornire",
    "sfornendo": "sfornire",
    "sfornente": "sfornire",
    "sfornenti": "sfornire",
    "sfornerai": "sfornare",
    "sforneran": "sfornare",
    "sforneranno": "sfornare",
    "sfornerebbe": "sfornare",
    "sfornerebber": "sfornare",
    "sfornerebbero": "sfornare",
    "sfornerei": "sfornare",
    "sforneremmo": "sfornare",
    "sforneremo": "sfornare",
    "sfornereste": "sfornare",
    "sforneresti": "sfornare",
    "sfornerete": "sfornare",
    "sfornerà": "sfornare",
    "sfornerò": "sfornare",
    "sforni": "sfornire",
    "sforniamo": "sfornire",
    "sforniate": "sfornire",
    "sfornii": "sfornire",
    "sfornimmo": "sfornire",
    "sfornin": "sfornare",
    "sfornino": "sfornare",
    "sfornir": "sfornire",
    "sfornirai": "sfornire",
    "sforniran": "sfornire",
    "sforniranno": "sfornire",
    "sfornirebbe": "sfornire",
    "sfornirebber": "sfornire",
    "sfornirebbero": "sfornire",
    "sfornirei": "sfornire",
    "sforniremmo": "sfornire",
    "sforniremo": "sfornire",
    "sfornireste": "sfornire",
    "sforniresti": "sfornire",
    "sfornirete": "sfornire",
    "sforniron": "sfornire",
    "sfornirono": "sfornire",
    "sfornirà": "sfornire",
    "sfornirò": "sfornire",
    "sfornisse": "sfornire",
    "sfornisser": "sfornire",
    "sfornissero": "sfornire",
    "sfornissi": "sfornire",
    "sfornissimo": "sfornire",
    "sforniste": "sfornire",
    "sfornisti": "sfornire",
    "sfornita": "sfornire",
    "sfornite": "sfornire",
    "sforniti": "sfornire",
    "sfornito": "sfornire",
    "sforniva": "sfornire",
    "sfornivamo": "sfornire",
    "sfornivan": "sfornire",
    "sfornivano": "sfornire",
    "sfornivate": "sfornire",
    "sfornivi": "sfornire",
    "sfornivo": "sfornire",
    "sforno": "sfornire",
    "sfornon": "sfornire",
    "sfornono": "sfornire",
    "sfornì": "sfornire",
    "sfornò": "sfornare",
    "sfortunata": "sfortunato",
    "sfortunate": "sfortunato",
    "sfortunati": "sfortunato",
    "sfortune": "sfortuna",
    "sforza": "sforzare",
    "sforzai": "sforzare",
    "sforzammo": "sforzare",
    "sforzan": "sforzare",
    "sforzando": "sforzare",
    "sforzano": "sforzare",
    "sforzante": "sforzare",
    "sforzanti": "sforzare",
    "sforzar": "sforzare",
    "sforzaron": "sforzare",
    "sforzarono": "sforzare",
    "sforzasse": "sforzare",
    "sforzasser": "sforzare",
    "sforzassero": "sforzare",
    "sforzassi": "sforzare",
    "sforzassimo": "sforzare",
    "sforzaste": "sforzare",
    "sforzasti": "sforzare",
    "sforzata": "sforzato",
    "sforzate": "sforzato",
    "sforzati": "sforzato",
    "sforzato": "sforzare",
    "sforzava": "sforzare",
    "sforzavamo": "sforzare",
    "sforzavan": "sforzare",
    "sforzavano": "sforzare",
    "sforzavate": "sforzare",
    "sforzavi": "sforzare",
    "sforzavo": "sforzare",
    "sforzerai": "sforzare",
    "sforzeran": "sforzare",
    "sforzeranno": "sforzare",
    "sforzerebbe": "sforzare",
    "sforzerebber": "sforzare",
    "sforzerebbero": "sforzare",
    "sforzerei": "sforzare",
    "sforzeremmo": "sforzare",
    "sforzeremo": "sforzare",
    "sforzereste": "sforzare",
    "sforzeresti": "sforzare",
    "sforzerete": "sforzare",
    "sforzerà": "sforzare",
    "sforzerò": "sforzare",
    "sforzi": "sforzo",
    "sforziamo": "sforzare",
    "sforziate": "sforzare",
    "sforzin": "sforzare",
    "sforzino": "sforzare",
    "sforzo": "sforzare",
    "sforzò": "sforzare",
    "sfotta": "sfottere",
    "sfottan": "sfottere",
    "sfottano": "sfottere",
    "sfotte": "sfottere",
    "sfottei": "sfottere",
    "sfottemmo": "sfottere",
    "sfottendo": "sfottere",
    "sfottente": "sfottere",
    "sfottenti": "sfottere",
    "sfotter": "sfottere",
    "sfotterai": "sfottere",
    "sfotteran": "sfottere",
    "sfotteranno": "sfottere",
    "sfotterebbe": "sfottere",
    "sfotterebber": "sfottere",
    "sfotterebbero": "sfottere",
    "sfotterei": "sfottere",
    "sfotteremmo": "sfottere",
    "sfotteremo": "sfottere",
    "sfottereste": "sfottere",
    "sfotteresti": "sfottere",
    "sfotterete": "sfottere",
    "sfotteron": "sfottere",
    "sfotterono": "sfottere",
    "sfotterà": "sfottere",
    "sfotterò": "sfottere",
    "sfottesse": "sfottere",
    "sfottesser": "sfottere",
    "sfottessero": "sfottere",
    "sfottessi": "sfottere",
    "sfottessimo": "sfottere",
    "sfotteste": "sfottere",
    "sfottesti": "sfottere",
    "sfottete": "sfottere",
    "sfotteva": "sfottere",
    "sfottevamo": "sfottere",
    "sfottevan": "sfottere",
    "sfottevano": "sfottere",
    "sfottevate": "sfottere",
    "sfottevi": "sfottere",
    "sfottevo": "sfottere",
    "sfotti": "sfottere",
    "sfottiamo": "sfottere",
    "sfottiate": "sfottere",
    "sfottitori": "sfottitorio",
    "sfottitoria": "sfottitorio",
    "sfottitorie": "sfottitorio",
    "sfotto": "sfottere",
    "sfotton": "sfottere",
    "sfottono": "sfottere",
    "sfottuta": "sfottere",
    "sfottute": "sfottere",
    "sfottuti": "sfottere",
    "sfottuto": "sfottere",
    "sfottè": "sfottere",
    "sfracella": "sfracellare",
    "sfracellai": "sfracellare",
    "sfracellammo": "sfracellare",
    "sfracellan": "sfracellare",
    "sfracellando": "sfracellare",
    "sfracellano": "sfracellare",
    "sfracellante": "sfracellare",
    "sfracellanti": "sfracellare",
    "sfracellar": "sfracellare",
    "sfracellaron": "sfracellare",
    "sfracellarono": "sfracellare",
    "sfracellasse": "sfracellare",
    "sfracellasser": "sfracellare",
    "sfracellassero": "sfracellare",
    "sfracellassi": "sfracellare",
    "sfracellassimo": "sfracellare",
    "sfracellaste": "sfracellare",
    "sfracellasti": "sfracellare",
    "sfracellata": "sfracellare",
    "sfracellate": "sfracellare",
    "sfracellati": "sfracellare",
    "sfracellato": "sfracellare",
    "sfracellava": "sfracellare",
    "sfracellavamo": "sfracellare",
    "sfracellavan": "sfracellare",
    "sfracellavano": "sfracellare",
    "sfracellavate": "sfracellare",
    "sfracellavi": "sfracellare",
    "sfracellavo": "sfracellare",
    "sfracellerai": "sfracellare",
    "sfracelleran": "sfracellare",
    "sfracelleranno": "sfracellare",
    "sfracellerebbe": "sfracellare",
    "sfracellerebber": "sfracellare",
    "sfracellerebbero": "sfracellare",
    "sfracellerei": "sfracellare",
    "sfracelleremmo": "sfracellare",
    "sfracelleremo": "sfracellare",
    "sfracellereste": "sfracellare",
    "sfracelleresti": "sfracellare",
    "sfracellerete": "sfracellare",
    "sfracellerà": "sfracellare",
    "sfracellerò": "sfracellare",
    "sfracelli": "sfracello",
    "sfracelliamo": "sfracellare",
    "sfracelliate": "sfracellare",
    "sfracellin": "sfracellare",
    "sfracellino": "sfracellare",
    "sfracello": "sfracellare",
    "sfracellò": "sfracellare",
    "sfrangerai": "sfrangiare",
    "sfrangeran": "sfrangiare",
    "sfrangeranno": "sfrangiare",
    "sfrangerebbe": "sfrangiare",
    "sfrangerebber": "sfrangiare",
    "sfrangerebbero": "sfrangiare",
    "sfrangerei": "sfrangiare",
    "sfrangeremmo": "sfrangiare",
    "sfrangeremo": "sfrangiare",
    "sfrangereste": "sfrangiare",
    "sfrangeresti": "sfrangiare",
    "sfrangerete": "sfrangiare",
    "sfrangerà": "sfrangiare",
    "sfrangerò": "sfrangiare",
    "sfrangi": "sfrangiare",
    "sfrangia": "sfrangiare",
    "sfrangiai": "sfrangiare",
    "sfrangiammo": "sfrangiare",
    "sfrangiamo": "sfrangiare",
    "sfrangian": "sfrangiare",
    "sfrangiando": "sfrangiare",
    "sfrangiano": "sfrangiare",
    "sfrangiante": "sfrangiare",
    "sfrangianti": "sfrangiare",
    "sfrangiar": "sfrangiare",
    "sfrangiaron": "sfrangiare",
    "sfrangiarono": "sfrangiare",
    "sfrangiasse": "sfrangiare",
    "sfrangiasser": "sfrangiare",
    "sfrangiassero": "sfrangiare",
    "sfrangiassi": "sfrangiare",
    "sfrangiassimo": "sfrangiare",
    "sfrangiaste": "sfrangiare",
    "sfrangiasti": "sfrangiare",
    "sfrangiata": "sfrangiare",
    "sfrangiate": "sfrangiare",
    "sfrangiati": "sfrangiare",
    "sfrangiato": "sfrangiare",
    "sfrangiava": "sfrangiare",
    "sfrangiavamo": "sfrangiare",
    "sfrangiavan": "sfrangiare",
    "sfrangiavano": "sfrangiare",
    "sfrangiavate": "sfrangiare",
    "sfrangiavi": "sfrangiare",
    "sfrangiavo": "sfrangiare",
    "sfrangin": "sfrangiare",
    "sfrangino": "sfrangiare",
    "sfrangio": "sfrangiare",
    "sfrangiò": "sfrangiare",
    "sfrata": "sfratare",
    "sfratai": "sfratare",
    "sfratammo": "sfratare",
    "sfratan": "sfratare",
    "sfratando": "sfratare",
    "sfratano": "sfratare",
    "sfratar": "sfratare",
    "sfrataron": "sfratare",
    "sfratarono": "sfratare",
    "sfratasse": "sfratare",
    "sfratasser": "sfratare",
    "sfratassero": "sfratare",
    "sfratassi": "sfratare",
    "sfratassimo": "sfratare",
    "sfrataste": "sfratare",
    "sfratasti": "sfratare",
    "sfratata": "sfratare",
    "sfratate": "sfratare",
    "sfratati": "sfratare",
    "sfratato": "sfratare",
    "sfratava": "sfratare",
    "sfratavamo": "sfratare",
    "sfratavan": "sfratare",
    "sfratavano": "sfratare",
    "sfratavate": "sfratare",
    "sfratavi": "sfratare",
    "sfratavo": "sfratare",
    "sfraterai": "sfratare",
    "sfrateran": "sfratare",
    "sfrateranno": "sfratare",
    "sfraterebbe": "sfratare",
    "sfraterebber": "sfratare",
    "sfraterebbero": "sfratare",
    "sfraterei": "sfratare",
    "sfrateremmo": "sfratare",
    "sfrateremo": "sfratare",
    "sfratereste": "sfratare",
    "sfrateresti": "sfratare",
    "sfraterete": "sfratare",
    "sfraterà": "sfratare",
    "sfraterò": "sfratare",
    "sfrati": "sfratare",
    "sfratiamo": "sfratare",
    "sfratiate": "sfratare",
    "sfratin": "sfratare",
    "sfratino": "sfratare",
    "sfrato": "sfratare",
    "sfratta": "sfrattare",
    "sfrattai": "sfrattare",
    "sfrattammo": "sfrattare",
    "sfrattan": "sfrattare",
    "sfrattando": "sfrattare",
    "sfrattano": "sfrattare",
    "sfrattante": "sfrattare",
    "sfrattanti": "sfrattare",
    "sfrattar": "sfrattare",
    "sfrattaron": "sfrattare",
    "sfrattarono": "sfrattare",
    "sfrattasse": "sfrattare",
    "sfrattasser": "sfrattare",
    "sfrattassero": "sfrattare",
    "sfrattassi": "sfrattare",
    "sfrattassimo": "sfrattare",
    "sfrattaste": "sfrattare",
    "sfrattasti": "sfrattare",
    "sfrattata": "sfrattato",
    "sfrattate": "sfrattato",
    "sfrattati": "sfrattato",
    "sfrattato": "sfrattare",
    "sfrattava": "sfrattare",
    "sfrattavamo": "sfrattare",
    "sfrattavan": "sfrattare",
    "sfrattavano": "sfrattare",
    "sfrattavate": "sfrattare",
    "sfrattavi": "sfrattare",
    "sfrattavo": "sfrattare",
    "sfratterai": "sfrattare",
    "sfratteran": "sfrattare",
    "sfratteranno": "sfrattare",
    "sfratterebbe": "sfrattare",
    "sfratterebber": "sfrattare",
    "sfratterebbero": "sfrattare",
    "sfratterei": "sfrattare",
    "sfratteremmo": "sfrattare",
    "sfratteremo": "sfrattare",
    "sfrattereste": "sfrattare",
    "sfratteresti": "sfrattare",
    "sfratterete": "sfrattare",
    "sfratterà": "sfrattare",
    "sfratterò": "sfrattare",
    "sfratti": "sfratto",
    "sfrattiamo": "sfrattare",
    "sfrattiate": "sfrattare",
    "sfrattin": "sfrattare",
    "sfrattino": "sfrattare",
    "sfratto": "sfrattare",
    "sfrattò": "sfrattare",
    "sfratò": "sfratare",
    "sfreccerai": "sfrecciare",
    "sfrecceran": "sfrecciare",
    "sfrecceranno": "sfrecciare",
    "sfreccerebbe": "sfrecciare",
    "sfreccerebber": "sfrecciare",
    "sfreccerebbero": "sfrecciare",
    "sfreccerei": "sfrecciare",
    "sfrecceremmo": "sfrecciare",
    "sfrecceremo": "sfrecciare",
    "sfreccereste": "sfrecciare",
    "sfrecceresti": "sfrecciare",
    "sfreccerete": "sfrecciare",
    "sfreccerà": "sfrecciare",
    "sfreccerò": "sfrecciare",
    "sfrecci": "sfrecciare",
    "sfreccia": "sfrecciare",
    "sfrecciai": "sfrecciare",
    "sfrecciammo": "sfrecciare",
    "sfrecciamo": "sfrecciare",
    "sfreccian": "sfrecciare",
    "sfrecciando": "sfrecciare",
    "sfrecciano": "sfrecciare",
    "sfrecciante": "sfrecciare",
    "sfreccianti": "sfrecciare",
    "sfrecciar": "sfrecciare",
    "sfrecciaron": "sfrecciare",
    "sfrecciarono": "sfrecciare",
    "sfrecciasse": "sfrecciare",
    "sfrecciasser": "sfrecciare",
    "sfrecciassero": "sfrecciare",
    "sfrecciassi": "sfrecciare",
    "sfrecciassimo": "sfrecciare",
    "sfrecciaste": "sfrecciare",
    "sfrecciasti": "sfrecciare",
    "sfrecciata": "sfrecciare",
    "sfrecciate": "sfrecciare",
    "sfrecciati": "sfrecciare",
    "sfrecciato": "sfrecciare",
    "sfrecciava": "sfrecciare",
    "sfrecciavamo": "sfrecciare",
    "sfrecciavan": "sfrecciare",
    "sfrecciavano": "sfrecciare",
    "sfrecciavate": "sfrecciare",
    "sfrecciavi": "sfrecciare",
    "sfrecciavo": "sfrecciare",
    "sfreccin": "sfrecciare",
    "sfreccino": "sfrecciare",
    "sfreccio": "sfrecciare",
    "sfrecciò": "sfrecciare",
    "sfrega": "sfregare",
    "sfregai": "sfregare",
    "sfregamenti": "sfregamento",
    "sfregammo": "sfregare",
    "sfregan": "sfregare",
    "sfregando": "sfregare",
    "sfregano": "sfregare",
    "sfregante": "sfregare",
    "sfreganti": "sfregare",
    "sfregar": "sfregare",
    "sfregaron": "sfregare",
    "sfregarono": "sfregare",
    "sfregasse": "sfregare",
    "sfregasser": "sfregare",
    "sfregassero": "sfregare",
    "sfregassi": "sfregare",
    "sfregassimo": "sfregare",
    "sfregaste": "sfregare",
    "sfregasti": "sfregare",
    "sfregata": "sfregare",
    "sfregate": "sfregare",
    "sfregati": "sfregare",
    "sfregato": "sfregare",
    "sfregava": "sfregare",
    "sfregavamo": "sfregare",
    "sfregavan": "sfregare",
    "sfregavano": "sfregare",
    "sfregavate": "sfregare",
    "sfregavi": "sfregare",
    "sfregavo": "sfregare",
    "sfregerai": "sfregiare",
    "sfregeran": "sfregiare",
    "sfregeranno": "sfregiare",
    "sfregerebbe": "sfregiare",
    "sfregerebber": "sfregiare",
    "sfregerebbero": "sfregiare",
    "sfregerei": "sfregiare",
    "sfregeremmo": "sfregiare",
    "sfregeremo": "sfregiare",
    "sfregereste": "sfregiare",
    "sfregeresti": "sfregiare",
    "sfregerete": "sfregiare",
    "sfregerà": "sfregiare",
    "sfregerò": "sfregiare",
    "sfregherai": "sfregare",
    "sfregheran": "sfregare",
    "sfregheranno": "sfregare",
    "sfregherebbe": "sfregare",
    "sfregherebber": "sfregare",
    "sfregherebbero": "sfregare",
    "sfregherei": "sfregare",
    "sfregheremmo": "sfregare",
    "sfregheremo": "sfregare",
    "sfreghereste": "sfregare",
    "sfregheresti": "sfregare",
    "sfregherete": "sfregare",
    "sfregherà": "sfregare",
    "sfregherò": "sfregare",
    "sfreghi": "sfregare",
    "sfreghiamo": "sfregare",
    "sfreghiate": "sfregare",
    "sfreghin": "sfregare",
    "sfreghino": "sfregare",
    "sfregi": "sfregio",
    "sfregia": "sfregiare",
    "sfregiai": "sfregiare",
    "sfregiammo": "sfregiare",
    "sfregiamo": "sfregiare",
    "sfregian": "sfregiare",
    "sfregiando": "sfregiare",
    "sfregiano": "sfregiare",
    "sfregiante": "sfregiare",
    "sfregianti": "sfregiare",
    "sfregiar": "sfregiare",
    "sfregiaron": "sfregiare",
    "sfregiarono": "sfregiare",
    "sfregiasse": "sfregiare",
    "sfregiasser": "sfregiare",
    "sfregiassero": "sfregiare",
    "sfregiassi": "sfregiare",
    "sfregiassimo": "sfregiare",
    "sfregiaste": "sfregiare",
    "sfregiasti": "sfregiare",
    "sfregiata": "sfregiare",
    "sfregiate": "sfregiare",
    "sfregiati": "sfregiare",
    "sfregiato": "sfregiare",
    "sfregiava": "sfregiare",
    "sfregiavamo": "sfregiare",
    "sfregiavan": "sfregiare",
    "sfregiavano": "sfregiare",
    "sfregiavate": "sfregiare",
    "sfregiavi": "sfregiare",
    "sfregiavo": "sfregiare",
    "sfregin": "sfregiare",
    "sfregino": "sfregiare",
    "sfregio": "sfregiare",
    "sfregiò": "sfregiare",
    "sfrego": "sfregare",
    "sfregò": "sfregare",
    "sfrena": "sfrenare",
    "sfrenai": "sfrenare",
    "sfrenammo": "sfrenare",
    "sfrenan": "sfrenare",
    "sfrenando": "sfrenare",
    "sfrenano": "sfrenare",
    "sfrenante": "sfrenare",
    "sfrenanti": "sfrenare",
    "sfrenar": "sfrenare",
    "sfrenaron": "sfrenare",
    "sfrenarono": "sfrenare",
    "sfrenasse": "sfrenare",
    "sfrenasser": "sfrenare",
    "sfrenassero": "sfrenare",
    "sfrenassi": "sfrenare",
    "sfrenassimo": "sfrenare",
    "sfrenaste": "sfrenare",
    "sfrenasti": "sfrenare",
    "sfrenata": "sfrenato",
    "sfrenate": "sfrenato",
    "sfrenatezze": "sfrenatezza",
    "sfrenati": "sfrenato",
    "sfrenato": "sfrenare",
    "sfrenava": "sfrenare",
    "sfrenavamo": "sfrenare",
    "sfrenavan": "sfrenare",
    "sfrenavano": "sfrenare",
    "sfrenavate": "sfrenare",
    "sfrenavi": "sfrenare",
    "sfrenavo": "sfrenare",
    "sfrenerai": "sfrenare",
    "sfreneran": "sfrenare",
    "sfreneranno": "sfrenare",
    "sfrenerebbe": "sfrenare",
    "sfrenerebber": "sfrenare",
    "sfrenerebbero": "sfrenare",
    "sfrenerei": "sfrenare",
    "sfreneremmo": "sfrenare",
    "sfreneremo": "sfrenare",
    "sfrenereste": "sfrenare",
    "sfreneresti": "sfrenare",
    "sfrenerete": "sfrenare",
    "sfrenerà": "sfrenare",
    "sfrenerò": "sfrenare",
    "sfreni": "sfrenare",
    "sfreniamo": "sfrenare",
    "sfreniate": "sfrenare",
    "sfrenin": "sfrenare",
    "sfrenino": "sfrenare",
    "sfreno": "sfrenare",
    "sfrenò": "sfrenare",
    "sfrigola": "sfrigolare",
    "sfrigolai": "sfrigolare",
    "sfrigolammo": "sfrigolare",
    "sfrigolan": "sfrigolare",
    "sfrigolando": "sfrigolare",
    "sfrigolano": "sfrigolare",
    "sfrigolante": "sfrigolare",
    "sfrigolanti": "sfrigolare",
    "sfrigolar": "sfrigolare",
    "sfrigolaron": "sfrigolare",
    "sfrigolarono": "sfrigolare",
    "sfrigolasse": "sfrigolare",
    "sfrigolasser": "sfrigolare",
    "sfrigolassero": "sfrigolare",
    "sfrigolassi": "sfrigolare",
    "sfrigolassimo": "sfrigolare",
    "sfrigolaste": "sfrigolare",
    "sfrigolasti": "sfrigolare",
    "sfrigolata": "sfrigolare",
    "sfrigolate": "sfrigolare",
    "sfrigolati": "sfrigolare",
    "sfrigolato": "sfrigolare",
    "sfrigolava": "sfrigolare",
    "sfrigolavamo": "sfrigolare",
    "sfrigolavan": "sfrigolare",
    "sfrigolavano": "sfrigolare",
    "sfrigolavate": "sfrigolare",
    "sfrigolavi": "sfrigolare",
    "sfrigolavo": "sfrigolare",
    "sfrigolerai": "sfrigolare",
    "sfrigoleran": "sfrigolare",
    "sfrigoleranno": "sfrigolare",
    "sfrigolerebbe": "sfrigolare",
    "sfrigolerebber": "sfrigolare",
    "sfrigolerebbero": "sfrigolare",
    "sfrigolerei": "sfrigolare",
    "sfrigoleremmo": "sfrigolare",
    "sfrigoleremo": "sfrigolare",
    "sfrigolereste": "sfrigolare",
    "sfrigoleresti": "sfrigolare",
    "sfrigolerete": "sfrigolare",
    "sfrigolerà": "sfrigolare",
    "sfrigolerò": "sfrigolare",
    "sfrigoli": "sfrigolare",
    "sfrigoliamo": "sfrigolare",
    "sfrigoliate": "sfrigolare",
    "sfrigolin": "sfrigolare",
    "sfrigolino": "sfrigolare",
    "sfrigolo": "sfrigolare",
    "sfrigolò": "sfrigolare",
    "sfronda": "sfrondare",
    "sfrondai": "sfrondare",
    "sfrondammo": "sfrondare",
    "sfrondan": "sfrondare",
    "sfrondando": "sfrondare",
    "sfrondano": "sfrondare",
    "sfrondante": "sfrondare",
    "sfrondanti": "sfrondare",
    "sfrondar": "sfrondare",
    "sfrondaron": "sfrondare",
    "sfrondarono": "sfrondare",
    "sfrondasse": "sfrondare",
    "sfrondasser": "sfrondare",
    "sfrondassero": "sfrondare",
    "sfrondassi": "sfrondare",
    "sfrondassimo": "sfrondare",
    "sfrondaste": "sfrondare",
    "sfrondasti": "sfrondare",
    "sfrondata": "sfrondare",
    "sfrondate": "sfrondare",
    "sfrondati": "sfrondare",
    "sfrondato": "sfrondare",
    "sfrondava": "sfrondare",
    "sfrondavamo": "sfrondare",
    "sfrondavan": "sfrondare",
    "sfrondavano": "sfrondare",
    "sfrondavate": "sfrondare",
    "sfrondavi": "sfrondare",
    "sfrondavo": "sfrondare",
    "sfronderai": "sfrondare",
    "sfronderan": "sfrondare",
    "sfronderanno": "sfrondare",
    "sfronderebbe": "sfrondare",
    "sfronderebber": "sfrondare",
    "sfronderebbero": "sfrondare",
    "sfronderei": "sfrondare",
    "sfronderemmo": "sfrondare",
    "sfronderemo": "sfrondare",
    "sfrondereste": "sfrondare",
    "sfronderesti": "sfrondare",
    "sfronderete": "sfrondare",
    "sfronderà": "sfrondare",
    "sfronderò": "sfrondare",
    "sfrondi": "sfrondare",
    "sfrondiamo": "sfrondare",
    "sfrondiate": "sfrondare",
    "sfrondin": "sfrondare",
    "sfrondino": "sfrondare",
    "sfrondo": "sfrondare",
    "sfrondò": "sfrondare",
    "sfrontata": "sfrontato",
    "sfrontate": "sfrontato",
    "sfrontatezze": "sfrontatezza",
    "sfrontati": "sfrontato",
    "sfrutta": "sfruttare",
    "sfruttai": "sfruttare",
    "sfruttamenti": "sfruttamento",
    "sfruttammo": "sfruttare",
    "sfruttan": "sfruttare",
    "sfruttando": "sfruttare",
    "sfruttano": "sfruttare",
    "sfruttante": "sfruttare",
    "sfruttanti": "sfruttare",
    "sfruttar": "sfruttare",
    "sfruttaron": "sfruttare",
    "sfruttarono": "sfruttare",
    "sfruttasse": "sfruttare",
    "sfruttasser": "sfruttare",
    "sfruttassero": "sfruttare",
    "sfruttassi": "sfruttare",
    "sfruttassimo": "sfruttare",
    "sfruttaste": "sfruttare",
    "sfruttasti": "sfruttare",
    "sfruttata": "sfruttato",
    "sfruttate": "sfruttato",
    "sfruttati": "sfruttato",
    "sfruttato": "sfruttare",
    "sfruttatori": "sfruttatore",
    "sfruttava": "sfruttare",
    "sfruttavamo": "sfruttare",
    "sfruttavan": "sfruttare",
    "sfruttavano": "sfruttare",
    "sfruttavate": "sfruttare",
    "sfruttavi": "sfruttare",
    "sfruttavo": "sfruttare",
    "sfrutterai": "sfruttare",
    "sfrutteran": "sfruttare",
    "sfrutteranno": "sfruttare",
    "sfrutterebbe": "sfruttare",
    "sfrutterebber": "sfruttare",
    "sfrutterebbero": "sfruttare",
    "sfrutterei": "sfruttare",
    "sfrutteremmo": "sfruttare",
    "sfrutteremo": "sfruttare",
    "sfruttereste": "sfruttare",
    "sfrutteresti": "sfruttare",
    "sfrutterete": "sfruttare",
    "sfrutterà": "sfruttare",
    "sfrutterò": "sfruttare",
    "sfrutti": "sfruttare",
    "sfruttiamo": "sfruttare",
    "sfruttiate": "sfruttare",
    "sfruttin": "sfruttare",
    "sfruttino": "sfruttare",
    "sfrutto": "sfruttare",
    "sfruttò": "sfruttare",
    "sfugga": "sfuggire",
    "sfuggan": "sfuggire",
    "sfuggano": "sfuggire",
    "sfugge": "sfuggire",
    "sfuggendo": "sfuggire",
    "sfuggente": "sfuggire",
    "sfuggenti": "sfuggire",
    "sfuggi": "sfuggire",
    "sfuggiamo": "sfuggire",
    "sfuggiate": "sfuggire",
    "sfuggii": "sfuggire",
    "sfuggimmo": "sfuggire",
    "sfuggir": "sfuggire",
    "sfuggirai": "sfuggire",
    "sfuggiran": "sfuggire",
    "sfuggiranno": "sfuggire",
    "sfuggirebbe": "sfuggire",
    "sfuggirebber": "sfuggire",
    "sfuggirebbero": "sfuggire",
    "sfuggirei": "sfuggire",
    "sfuggiremmo": "sfuggire",
    "sfuggiremo": "sfuggire",
    "sfuggireste": "sfuggire",
    "sfuggiresti": "sfuggire",
    "sfuggirete": "sfuggire",
    "sfuggiron": "sfuggire",
    "sfuggirono": "sfuggire",
    "sfuggirà": "sfuggire",
    "sfuggirò": "sfuggire",
    "sfuggisse": "sfuggire",
    "sfuggisser": "sfuggire",
    "sfuggissero": "sfuggire",
    "sfuggissi": "sfuggire",
    "sfuggissimo": "sfuggire",
    "sfuggiste": "sfuggire",
    "sfuggisti": "sfuggire",
    "sfuggita": "sfuggire",
    "sfuggite": "sfuggire",
    "sfuggiti": "sfuggire",
    "sfuggito": "sfuggire",
    "sfuggiva": "sfuggire",
    "sfuggivamo": "sfuggire",
    "sfuggivan": "sfuggire",
    "sfuggivano": "sfuggire",
    "sfuggivate": "sfuggire",
    "sfuggivi": "sfuggire",
    "sfuggivo": "sfuggire",
    "sfuggo": "sfuggire",
    "sfuggon": "sfuggire",
    "sfuggono": "sfuggire",
    "sfuggì": "sfuggire",
    "sfuma": "sfumare",
    "sfumai": "sfumare",
    "sfumammo": "sfumare",
    "sfuman": "sfumare",
    "sfumando": "sfumare",
    "sfumano": "sfumare",
    "sfumante": "sfumare",
    "sfumanti": "sfumare",
    "sfumar": "sfumare",
    "sfumaron": "sfumare",
    "sfumarono": "sfumare",
    "sfumasse": "sfumare",
    "sfumasser": "sfumare",
    "sfumassero": "sfumare",
    "sfumassi": "sfumare",
    "sfumassimo": "sfumare",
    "sfumaste": "sfumare",
    "sfumasti": "sfumare",
    "sfumata": "sfumato",
    "sfumate": "sfumato",
    "sfumati": "sfumato",
    "sfumato": "sfumare",
    "sfumature": "sfumatura",
    "sfumava": "sfumare",
    "sfumavamo": "sfumare",
    "sfumavan": "sfumare",
    "sfumavano": "sfumare",
    "sfumavate": "sfumare",
    "sfumavi": "sfumare",
    "sfumavo": "sfumare",
    "sfumerai": "sfumare",
    "sfumeran": "sfumare",
    "sfumeranno": "sfumare",
    "sfumerebbe": "sfumare",
    "sfumerebber": "sfumare",
    "sfumerebbero": "sfumare",
    "sfumerei": "sfumare",
    "sfumeremmo": "sfumare",
    "sfumeremo": "sfumare",
    "sfumereste": "sfumare",
    "sfumeresti": "sfumare",
    "sfumerete": "sfumare",
    "sfumerà": "sfumare",
    "sfumerò": "sfumare",
    "sfumi": "sfumare",
    "sfumiamo": "sfumare",
    "sfumiate": "sfumare",
    "sfumin": "sfumare",
    "sfumino": "sfumare",
    "sfumo": "sfumare",
    "sfumò": "sfumare",
    "sfuoca": "sfuocare",
    "sfuocai": "sfuocare",
    "sfuocammo": "sfuocare",
    "sfuocan": "sfuocare",
    "sfuocando": "sfuocare",
    "sfuocano": "sfuocare",
    "sfuocante": "sfuocare",
    "sfuocanti": "sfuocare",
    "sfuocar": "sfuocare",
    "sfuocaron": "sfuocare",
    "sfuocarono": "sfuocare",
    "sfuocasse": "sfuocare",
    "sfuocasser": "sfuocare",
    "sfuocassero": "sfuocare",
    "sfuocassi": "sfuocare",
    "sfuocassimo": "sfuocare",
    "sfuocaste": "sfuocare",
    "sfuocasti": "sfuocare",
    "sfuocata": "sfuocare",
    "sfuocate": "sfuocare",
    "sfuocati": "sfuocare",
    "sfuocato": "sfuocare",
    "sfuocava": "sfuocare",
    "sfuocavamo": "sfuocare",
    "sfuocavan": "sfuocare",
    "sfuocavano": "sfuocare",
    "sfuocavate": "sfuocare",
    "sfuocavi": "sfuocare",
    "sfuocavo": "sfuocare",
    "sfuocherai": "sfuocare",
    "sfuocheran": "sfuocare",
    "sfuocheranno": "sfuocare",
    "sfuocherebbe": "sfuocare",
    "sfuocherebber": "sfuocare",
    "sfuocherebbero": "sfuocare",
    "sfuocherei": "sfuocare",
    "sfuocheremmo": "sfuocare",
    "sfuocheremo": "sfuocare",
    "sfuochereste": "sfuocare",
    "sfuocheresti": "sfuocare",
    "sfuocherete": "sfuocare",
    "sfuocherà": "sfuocare",
    "sfuocherò": "sfuocare",
    "sfuochi": "sfuocare",
    "sfuochiamo": "sfuocare",
    "sfuochiate": "sfuocare",
    "sfuochin": "sfuocare",
    "sfuochino": "sfuocare",
    "sfuoco": "sfuocare",
    "sfuocò": "sfuocare",
    "sfuri": "sfuriare",
    "sfuria": "sfuriare",
    "sfuriai": "sfuriare",
    "sfuriammo": "sfuriare",
    "sfuriamo": "sfuriare",
    "sfurian": "sfuriare",
    "sfuriando": "sfuriare",
    "sfuriano": "sfuriare",
    "sfuriante": "sfuriare",
    "sfurianti": "sfuriare",
    "sfuriar": "sfuriare",
    "sfuriaron": "sfuriare",
    "sfuriarono": "sfuriare",
    "sfuriasse": "sfuriare",
    "sfuriasser": "sfuriare",
    "sfuriassero": "sfuriare",
    "sfuriassi": "sfuriare",
    "sfuriassimo": "sfuriare",
    "sfuriaste": "sfuriare",
    "sfuriasti": "sfuriare",
    "sfuriata": "sfuriare",
    "sfuriate": "sfuriata",
    "sfuriati": "sfuriare",
    "sfuriato": "sfuriare",
    "sfuriava": "sfuriare",
    "sfuriavamo": "sfuriare",
    "sfuriavan": "sfuriare",
    "sfuriavano": "sfuriare",
    "sfuriavate": "sfuriare",
    "sfuriavi": "sfuriare",
    "sfuriavo": "sfuriare",
    "sfurierai": "sfuriare",
    "sfurieran": "sfuriare",
    "sfurieranno": "sfuriare",
    "sfurierebbe": "sfuriare",
    "sfurierebber": "sfuriare",
    "sfurierebbero": "sfuriare",
    "sfurierei": "sfuriare",
    "sfurieremmo": "sfuriare",
    "sfurieremo": "sfuriare",
    "sfuriereste": "sfuriare",
    "sfurieresti": "sfuriare",
    "sfurierete": "sfuriare",
    "sfurierà": "sfuriare",
    "sfurierò": "sfuriare",
    "sfurin": "sfuriare",
    "sfurino": "sfuriare",
    "sfurio": "sfuriare",
    "sfuriò": "sfuriare",
    "sfusa": "sfuso",
    "sfuse": "sfuso",
    "sfusi": "sfuso",
    "sfò": "sfare",
    "sgabelli": "sgabello",
    "sgabuzzini": "sgabuzzino",
    "sgamba": "sgambare",
    "sgambai": "sgambare",
    "sgambammo": "sgambare",
    "sgamban": "sgambare",
    "sgambando": "sgambare",
    "sgambano": "sgambare",
    "sgambante": "sgambare",
    "sgambanti": "sgambare",
    "sgambar": "sgambare",
    "sgambaron": "sgambare",
    "sgambarono": "sgambare",
    "sgambasse": "sgambare",
    "sgambasser": "sgambare",
    "sgambassero": "sgambare",
    "sgambassi": "sgambare",
    "sgambassimo": "sgambare",
    "sgambaste": "sgambare",
    "sgambasti": "sgambare",
    "sgambata": "sgambare",
    "sgambate": "sgambare",
    "sgambati": "sgambare",
    "sgambato": "sgambare",
    "sgambature": "sgambatura",
    "sgambava": "sgambare",
    "sgambavamo": "sgambare",
    "sgambavan": "sgambare",
    "sgambavano": "sgambare",
    "sgambavate": "sgambare",
    "sgambavi": "sgambare",
    "sgambavo": "sgambare",
    "sgamberai": "sgambare",
    "sgamberan": "sgambare",
    "sgamberanno": "sgambare",
    "sgamberebbe": "sgambare",
    "sgamberebber": "sgambare",
    "sgamberebbero": "sgambare",
    "sgamberei": "sgambare",
    "sgamberemmo": "sgambare",
    "sgamberemo": "sgambare",
    "sgambereste": "sgambare",
    "sgamberesti": "sgambare",
    "sgamberete": "sgambare",
    "sgamberà": "sgambare",
    "sgamberò": "sgambare",
    "sgambetta": "sgambettare",
    "sgambettai": "sgambettare",
    "sgambettammo": "sgambettare",
    "sgambettan": "sgambettare",
    "sgambettando": "sgambettare",
    "sgambettano": "sgambettare",
    "sgambettante": "sgambettare",
    "sgambettanti": "sgambettare",
    "sgambettar": "sgambettare",
    "sgambettaron": "sgambettare",
    "sgambettarono": "sgambettare",
    "sgambettasse": "sgambettare",
    "sgambettasser": "sgambettare",
    "sgambettassero": "sgambettare",
    "sgambettassi": "sgambettare",
    "sgambettassimo": "sgambettare",
    "sgambettaste": "sgambettare",
    "sgambettasti": "sgambettare",
    "sgambettata": "sgambettare",
    "sgambettate": "sgambettare",
    "sgambettati": "sgambettare",
    "sgambettato": "sgambettare",
    "sgambettava": "sgambettare",
    "sgambettavamo": "sgambettare",
    "sgambettavan": "sgambettare",
    "sgambettavano": "sgambettare",
    "sgambettavate": "sgambettare",
    "sgambettavi": "sgambettare",
    "sgambettavo": "sgambettare",
    "sgambetterai": "sgambettare",
    "sgambetteran": "sgambettare",
    "sgambetteranno": "sgambettare",
    "sgambetterebbe": "sgambettare",
    "sgambetterebber": "sgambettare",
    "sgambetterebbero": "sgambettare",
    "sgambetterei": "sgambettare",
    "sgambetteremmo": "sgambettare",
    "sgambetteremo": "sgambettare",
    "sgambettereste": "sgambettare",
    "sgambetteresti": "sgambettare",
    "sgambetterete": "sgambettare",
    "sgambetterà": "sgambettare",
    "sgambetterò": "sgambettare",
    "sgambetti": "sgambetto",
    "sgambettiamo": "sgambettare",
    "sgambettiate": "sgambettare",
    "sgambettin": "sgambettare",
    "sgambettino": "sgambettare",
    "sgambetto": "sgambettare",
    "sgambettò": "sgambettare",
    "sgambi": "sgambare",
    "sgambiamo": "sgambare",
    "sgambiate": "sgambare",
    "sgambin": "sgambare",
    "sgambino": "sgambare",
    "sgambo": "sgambare",
    "sgambò": "sgambare",
    "sganascerai": "sganasciare",
    "sganasceran": "sganasciare",
    "sganasceranno": "sganasciare",
    "sganascerebbe": "sganasciare",
    "sganascerebber": "sganasciare",
    "sganascerebbero": "sganasciare",
    "sganascerei": "sganasciare",
    "sganasceremmo": "sganasciare",
    "sganasceremo": "sganasciare",
    "sganascereste": "sganasciare",
    "sganasceresti": "sganasciare",
    "sganascerete": "sganasciare",
    "sganascerà": "sganasciare",
    "sganascerò": "sganasciare",
    "sganasci": "sganasciare",
    "sganascia": "sganasciare",
    "sganasciai": "sganasciare",
    "sganasciammo": "sganasciare",
    "sganasciamo": "sganasciare",
    "sganascian": "sganasciare",
    "sganasciando": "sganasciare",
    "sganasciano": "sganasciare",
    "sganasciante": "sganasciare",
    "sganascianti": "sganasciare",
    "sganasciar": "sganasciare",
    "sganasciaron": "sganasciare",
    "sganasciarono": "sganasciare",
    "sganasciasse": "sganasciare",
    "sganasciasser": "sganasciare",
    "sganasciassero": "sganasciare",
    "sganasciassi": "sganasciare",
    "sganasciassimo": "sganasciare",
    "sganasciaste": "sganasciare",
    "sganasciasti": "sganasciare",
    "sganasciata": "sganasciare",
    "sganasciate": "sganasciare",
    "sganasciati": "sganasciare",
    "sganasciato": "sganasciare",
    "sganasciava": "sganasciare",
    "sganasciavamo": "sganasciare",
    "sganasciavan": "sganasciare",
    "sganasciavano": "sganasciare",
    "sganasciavate": "sganasciare",
    "sganasciavi": "sganasciare",
    "sganasciavo": "sganasciare",
    "sganascin": "sganasciare",
    "sganascino": "sganasciare",
    "sganascio": "sganasciare",
    "sganasciò": "sganasciare",
    "sgancerai": "sganciare",
    "sganceran": "sganciare",
    "sganceranno": "sganciare",
    "sgancerebbe": "sganciare",
    "sgancerebber": "sganciare",
    "sgancerebbero": "sganciare",
    "sgancerei": "sganciare",
    "sganceremmo": "sganciare",
    "sganceremo": "sganciare",
    "sgancereste": "sganciare",
    "sganceresti": "sganciare",
    "sgancerete": "sganciare",
    "sgancerà": "sganciare",
    "sgancerò": "sganciare",
    "sganci": "sganciare",
    "sgancia": "sganciare",
    "sganciai": "sganciare",
    "sganciamenti": "sganciamento",
    "sganciammo": "sganciare",
    "sganciamo": "sganciare",
    "sgancian": "sganciare",
    "sganciando": "sganciare",
    "sganciano": "sganciare",
    "sganciante": "sganciare",
    "sgancianti": "sganciare",
    "sganciar": "sganciare",
    "sganciaron": "sganciare",
    "sganciarono": "sganciare",
    "sganciasse": "sganciare",
    "sganciasser": "sganciare",
    "sganciassero": "sganciare",
    "sganciassi": "sganciare",
    "sganciassimo": "sganciare",
    "sganciaste": "sganciare",
    "sganciasti": "sganciare",
    "sganciata": "sganciare",
    "sganciate": "sganciare",
    "sganciati": "sganciare",
    "sganciato": "sganciare",
    "sganciava": "sganciare",
    "sganciavamo": "sganciare",
    "sganciavan": "sganciare",
    "sganciavano": "sganciare",
    "sganciavate": "sganciare",
    "sganciavi": "sganciare",
    "sganciavo": "sganciare",
    "sgancin": "sganciare",
    "sgancino": "sganciare",
    "sgancio": "sganciare",
    "sganciò": "sganciare",
    "sganghera": "sgangherare",
    "sgangherai": "sgangherare",
    "sgangherammo": "sgangherare",
    "sgangheran": "sgangherare",
    "sgangherando": "sgangherare",
    "sgangherano": "sgangherare",
    "sgangherante": "sgangherare",
    "sgangheranti": "sgangherare",
    "sgangherar": "sgangherare",
    "sgangheraron": "sgangherare",
    "sgangherarono": "sgangherare",
    "sgangherasse": "sgangherare",
    "sgangherasser": "sgangherare",
    "sgangherassero": "sgangherare",
    "sgangherassi": "sgangherare",
    "sgangherassimo": "sgangherare",
    "sgangheraste": "sgangherare",
    "sgangherasti": "sgangherare",
    "sgangherata": "sgangherato",
    "sgangherate": "sgangherato",
    "sgangheratezze": "sgangheratezza",
    "sgangherati": "sgangherato",
    "sgangherato": "sgangherare",
    "sgangherava": "sgangherare",
    "sgangheravamo": "sgangherare",
    "sgangheravan": "sgangherare",
    "sgangheravano": "sgangherare",
    "sgangheravate": "sgangherare",
    "sgangheravi": "sgangherare",
    "sgangheravo": "sgangherare",
    "sganghererai": "sgangherare",
    "sganghereran": "sgangherare",
    "sganghereranno": "sgangherare",
    "sganghererebbe": "sgangherare",
    "sganghererebber": "sgangherare",
    "sganghererebbero": "sgangherare",
    "sganghererei": "sgangherare",
    "sganghereremmo": "sgangherare",
    "sganghereremo": "sgangherare",
    "sgangherereste": "sgangherare",
    "sganghereresti": "sgangherare",
    "sganghererete": "sgangherare",
    "sganghererà": "sgangherare",
    "sganghererò": "sgangherare",
    "sgangheri": "sgangherare",
    "sgangheriamo": "sgangherare",
    "sgangheriate": "sgangherare",
    "sgangherin": "sgangherare",
    "sgangherino": "sgangherare",
    "sganghero": "sgangherare",
    "sgangherò": "sgangherare",
    "sgarbata": "sgarbato",
    "sgarbate": "sgarbato",
    "sgarbati": "sgarbato",
    "sgarbi": "sgarbo",
    "sgargianti": "sgargiante",
    "sgarra": "sgarrare",
    "sgarrai": "sgarrare",
    "sgarrammo": "sgarrare",
    "sgarran": "sgarrare",
    "sgarrando": "sgarrare",
    "sgarrano": "sgarrare",
    "sgarrante": "sgarrare",
    "sgarranti": "sgarrare",
    "sgarrar": "sgarrare",
    "sgarraron": "sgarrare",
    "sgarrarono": "sgarrare",
    "sgarrasse": "sgarrare",
    "sgarrasser": "sgarrare",
    "sgarrassero": "sgarrare",
    "sgarrassi": "sgarrare",
    "sgarrassimo": "sgarrare",
    "sgarraste": "sgarrare",
    "sgarrasti": "sgarrare",
    "sgarrata": "sgarrare",
    "sgarrate": "sgarrare",
    "sgarrati": "sgarrare",
    "sgarrato": "sgarrare",
    "sgarrava": "sgarrare",
    "sgarravamo": "sgarrare",
    "sgarravan": "sgarrare",
    "sgarravano": "sgarrare",
    "sgarravate": "sgarrare",
    "sgarravi": "sgarrare",
    "sgarravo": "sgarrare",
    "sgarrerai": "sgarrare",
    "sgarreran": "sgarrare",
    "sgarreranno": "sgarrare",
    "sgarrerebbe": "sgarrare",
    "sgarrerebber": "sgarrare",
    "sgarrerebbero": "sgarrare",
    "sgarrerei": "sgarrare",
    "sgarreremmo": "sgarrare",
    "sgarreremo": "sgarrare",
    "sgarrereste": "sgarrare",
    "sgarreresti": "sgarrare",
    "sgarrerete": "sgarrare",
    "sgarrerà": "sgarrare",
    "sgarrerò": "sgarrare",
    "sgarri": "sgarro",
    "sgarriamo": "sgarrare",
    "sgarriate": "sgarrare",
    "sgarrin": "sgarrare",
    "sgarrino": "sgarrare",
    "sgarro": "sgarrare",
    "sgarrupata": "sgarrupato",
    "sgarrupate": "sgarrupato",
    "sgarrupati": "sgarrupato",
    "sgarrò": "sgarrare",
    "sgattaiola": "sgattaiolare",
    "sgattaiolai": "sgattaiolare",
    "sgattaiolammo": "sgattaiolare",
    "sgattaiolan": "sgattaiolare",
    "sgattaiolando": "sgattaiolare",
    "sgattaiolano": "sgattaiolare",
    "sgattaiolante": "sgattaiolare",
    "sgattaiolanti": "sgattaiolare",
    "sgattaiolar": "sgattaiolare",
    "sgattaiolaron": "sgattaiolare",
    "sgattaiolarono": "sgattaiolare",
    "sgattaiolasse": "sgattaiolare",
    "sgattaiolasser": "sgattaiolare",
    "sgattaiolassero": "sgattaiolare",
    "sgattaiolassi": "sgattaiolare",
    "sgattaiolassimo": "sgattaiolare",
    "sgattaiolaste": "sgattaiolare",
    "sgattaiolasti": "sgattaiolare",
    "sgattaiolata": "sgattaiolare",
    "sgattaiolate": "sgattaiolare",
    "sgattaiolati": "sgattaiolare",
    "sgattaiolato": "sgattaiolare",
    "sgattaiolava": "sgattaiolare",
    "sgattaiolavamo": "sgattaiolare",
    "sgattaiolavan": "sgattaiolare",
    "sgattaiolavano": "sgattaiolare",
    "sgattaiolavate": "sgattaiolare",
    "sgattaiolavi": "sgattaiolare",
    "sgattaiolavo": "sgattaiolare",
    "sgattaiolerai": "sgattaiolare",
    "sgattaioleran": "sgattaiolare",
    "sgattaioleranno": "sgattaiolare",
    "sgattaiolerebbe": "sgattaiolare",
    "sgattaiolerebber": "sgattaiolare",
    "sgattaiolerebbero": "sgattaiolare",
    "sgattaiolerei": "sgattaiolare",
    "sgattaioleremmo": "sgattaiolare",
    "sgattaioleremo": "sgattaiolare",
    "sgattaiolereste": "sgattaiolare",
    "sgattaioleresti": "sgattaiolare",
    "sgattaiolerete": "sgattaiolare",
    "sgattaiolerà": "sgattaiolare",
    "sgattaiolerò": "sgattaiolare",
    "sgattaioli": "sgattaiolare",
    "sgattaioliamo": "sgattaiolare",
    "sgattaioliate": "sgattaiolare",
    "sgattaiolin": "sgattaiolare",
    "sgattaiolino": "sgattaiolare",
    "sgattaiolo": "sgattaiolare",
    "sgattaiolò": "sgattaiolare",
    "sgela": "sgelare",
    "sgelai": "sgelare",
    "sgelammo": "sgelare",
    "sgelan": "sgelare",
    "sgelando": "sgelare",
    "sgelano": "sgelare",
    "sgelante": "sgelare",
    "sgelanti": "sgelare",
    "sgelar": "sgelare",
    "sgelaron": "sgelare",
    "sgelarono": "sgelare",
    "sgelasse": "sgelare",
    "sgelasser": "sgelare",
    "sgelassero": "sgelare",
    "sgelassi": "sgelare",
    "sgelassimo": "sgelare",
    "sgelaste": "sgelare",
    "sgelasti": "sgelare",
    "sgelata": "sgelare",
    "sgelate": "sgelare",
    "sgelati": "sgelare",
    "sgelato": "sgelare",
    "sgelava": "sgelare",
    "sgelavamo": "sgelare",
    "sgelavan": "sgelare",
    "sgelavano": "sgelare",
    "sgelavate": "sgelare",
    "sgelavi": "sgelare",
    "sgelavo": "sgelare",
    "sgelerai": "sgelare",
    "sgeleran": "sgelare",
    "sgeleranno": "sgelare",
    "sgelerebbe": "sgelare",
    "sgelerebber": "sgelare",
    "sgelerebbero": "sgelare",
    "sgelerei": "sgelare",
    "sgeleremmo": "sgelare",
    "sgeleremo": "sgelare",
    "sgelereste": "sgelare",
    "sgeleresti": "sgelare",
    "sgelerete": "sgelare",
    "sgelerà": "sgelare",
    "sgelerò": "sgelare",
    "sgeli": "sgelare",
    "sgeliamo": "sgelare",
    "sgeliate": "sgelare",
    "sgelin": "sgelare",
    "sgelino": "sgelare",
    "sgelo": "sgelare",
    "sgelò": "sgelare",
    "sghemba": "sghembo",
    "sghembe": "sghembo",
    "sghembi": "sghembo",
    "sgherri": "sgherro",
    "sghiaccerai": "sghiacciare",
    "sghiacceran": "sghiacciare",
    "sghiacceranno": "sghiacciare",
    "sghiaccerebbe": "sghiacciare",
    "sghiaccerebber": "sghiacciare",
    "sghiaccerebbero": "sghiacciare",
    "sghiaccerei": "sghiacciare",
    "sghiacceremmo": "sghiacciare",
    "sghiacceremo": "sghiacciare",
    "sghiaccereste": "sghiacciare",
    "sghiacceresti": "sghiacciare",
    "sghiaccerete": "sghiacciare",
    "sghiaccerà": "sghiacciare",
    "sghiaccerò": "sghiacciare",
    "sghiacci": "sghiacciare",
    "sghiaccia": "sghiacciare",
    "sghiacciai": "sghiacciare",
    "sghiacciammo": "sghiacciare",
    "sghiacciamo": "sghiacciare",
    "sghiaccian": "sghiacciare",
    "sghiacciando": "sghiacciare",
    "sghiacciano": "sghiacciare",
    "sghiacciante": "sghiacciare",
    "sghiaccianti": "sghiacciare",
    "sghiacciar": "sghiacciare",
    "sghiacciaron": "sghiacciare",
    "sghiacciarono": "sghiacciare",
    "sghiacciasse": "sghiacciare",
    "sghiacciasser": "sghiacciare",
    "sghiacciassero": "sghiacciare",
    "sghiacciassi": "sghiacciare",
    "sghiacciassimo": "sghiacciare",
    "sghiacciaste": "sghiacciare",
    "sghiacciasti": "sghiacciare",
    "sghiacciata": "sghiacciare",
    "sghiacciate": "sghiacciare",
    "sghiacciati": "sghiacciare",
    "sghiacciato": "sghiacciare",
    "sghiacciava": "sghiacciare",
    "sghiacciavamo": "sghiacciare",
    "sghiacciavan": "sghiacciare",
    "sghiacciavano": "sghiacciare",
    "sghiacciavate": "sghiacciare",
    "sghiacciavi": "sghiacciare",
    "sghiacciavo": "sghiacciare",
    "sghiaccin": "sghiacciare",
    "sghiaccino": "sghiacciare",
    "sghiaccio": "sghiacciare",
    "sghiacciò": "sghiacciare",
    "sghignazza": "sghignazzare",
    "sghignazzai": "sghignazzare",
    "sghignazzammo": "sghignazzare",
    "sghignazzan": "sghignazzare",
    "sghignazzando": "sghignazzare",
    "sghignazzano": "sghignazzare",
    "sghignazzante": "sghignazzare",
    "sghignazzanti": "sghignazzare",
    "sghignazzar": "sghignazzare",
    "sghignazzaron": "sghignazzare",
    "sghignazzarono": "sghignazzare",
    "sghignazzasse": "sghignazzare",
    "sghignazzasser": "sghignazzare",
    "sghignazzassero": "sghignazzare",
    "sghignazzassi": "sghignazzare",
    "sghignazzassimo": "sghignazzare",
    "sghignazzaste": "sghignazzare",
    "sghignazzasti": "sghignazzare",
    "sghignazzata": "sghignazzare",
    "sghignazzate": "sghignazzare",
    "sghignazzati": "sghignazzare",
    "sghignazzato": "sghignazzare",
    "sghignazzava": "sghignazzare",
    "sghignazzavamo": "sghignazzare",
    "sghignazzavan": "sghignazzare",
    "sghignazzavano": "sghignazzare",
    "sghignazzavate": "sghignazzare",
    "sghignazzavi": "sghignazzare",
    "sghignazzavo": "sghignazzare",
    "sghignazzerai": "sghignazzare",
    "sghignazzeran": "sghignazzare",
    "sghignazzeranno": "sghignazzare",
    "sghignazzerebbe": "sghignazzare",
    "sghignazzerebber": "sghignazzare",
    "sghignazzerebbero": "sghignazzare",
    "sghignazzerei": "sghignazzare",
    "sghignazzeremmo": "sghignazzare",
    "sghignazzeremo": "sghignazzare",
    "sghignazzereste": "sghignazzare",
    "sghignazzeresti": "sghignazzare",
    "sghignazzerete": "sghignazzare",
    "sghignazzerà": "sghignazzare",
    "sghignazzerò": "sghignazzare",
    "sghignazzi": "sghignazzo",
    "sghignazziamo": "sghignazzare",
    "sghignazziate": "sghignazzare",
    "sghignazzin": "sghignazzare",
    "sghignazzino": "sghignazzare",
    "sghignazzo": "sghignazzare",
    "sghignazzò": "sghignazzare",
    "sghimbesce": "sghimbescio",
    "sghimbesci": "sghimbescio",
    "sghimbescia": "sghimbescio",
    "sgobba": "sgobbare",
    "sgobbai": "sgobbare",
    "sgobbammo": "sgobbare",
    "sgobban": "sgobbare",
    "sgobbando": "sgobbare",
    "sgobbano": "sgobbare",
    "sgobbante": "sgobbare",
    "sgobbanti": "sgobbare",
    "sgobbar": "sgobbare",
    "sgobbaron": "sgobbare",
    "sgobbarono": "sgobbare",
    "sgobbasse": "sgobbare",
    "sgobbasser": "sgobbare",
    "sgobbassero": "sgobbare",
    "sgobbassi": "sgobbare",
    "sgobbassimo": "sgobbare",
    "sgobbaste": "sgobbare",
    "sgobbasti": "sgobbare",
    "sgobbata": "sgobbare",
    "sgobbate": "sgobbare",
    "sgobbati": "sgobbare",
    "sgobbato": "sgobbare",
    "sgobbava": "sgobbare",
    "sgobbavamo": "sgobbare",
    "sgobbavan": "sgobbare",
    "sgobbavano": "sgobbare",
    "sgobbavate": "sgobbare",
    "sgobbavi": "sgobbare",
    "sgobbavo": "sgobbare",
    "sgobberai": "sgobbare",
    "sgobberan": "sgobbare",
    "sgobberanno": "sgobbare",
    "sgobberebbe": "sgobbare",
    "sgobberebber": "sgobbare",
    "sgobberebbero": "sgobbare",
    "sgobberei": "sgobbare",
    "sgobberemmo": "sgobbare",
    "sgobberemo": "sgobbare",
    "sgobbereste": "sgobbare",
    "sgobberesti": "sgobbare",
    "sgobberete": "sgobbare",
    "sgobberà": "sgobbare",
    "sgobberò": "sgobbare",
    "sgobbi": "sgobbare",
    "sgobbiamo": "sgobbare",
    "sgobbiate": "sgobbare",
    "sgobbin": "sgobbare",
    "sgobbino": "sgobbare",
    "sgobbo": "sgobbare",
    "sgobboni": "sgobbone",
    "sgobbò": "sgobbare",
    "sgocciola": "sgocciolare",
    "sgocciolai": "sgocciolare",
    "sgocciolammo": "sgocciolare",
    "sgocciolan": "sgocciolare",
    "sgocciolando": "sgocciolare",
    "sgocciolano": "sgocciolare",
    "sgocciolante": "sgocciolare",
    "sgocciolanti": "sgocciolare",
    "sgocciolar": "sgocciolare",
    "sgocciolaron": "sgocciolare",
    "sgocciolarono": "sgocciolare",
    "sgocciolasse": "sgocciolare",
    "sgocciolasser": "sgocciolare",
    "sgocciolassero": "sgocciolare",
    "sgocciolassi": "sgocciolare",
    "sgocciolassimo": "sgocciolare",
    "sgocciolaste": "sgocciolare",
    "sgocciolasti": "sgocciolare",
    "sgocciolata": "sgocciolare",
    "sgocciolate": "sgocciolare",
    "sgocciolati": "sgocciolare",
    "sgocciolato": "sgocciolare",
    "sgocciolava": "sgocciolare",
    "sgocciolavamo": "sgocciolare",
    "sgocciolavan": "sgocciolare",
    "sgocciolavano": "sgocciolare",
    "sgocciolavate": "sgocciolare",
    "sgocciolavi": "sgocciolare",
    "sgocciolavo": "sgocciolare",
    "sgocciolerai": "sgocciolare",
    "sgoccioleran": "sgocciolare",
    "sgoccioleranno": "sgocciolare",
    "sgocciolerebbe": "sgocciolare",
    "sgocciolerebber": "sgocciolare",
    "sgocciolerebbero": "sgocciolare",
    "sgocciolerei": "sgocciolare",
    "sgoccioleremmo": "sgocciolare",
    "sgoccioleremo": "sgocciolare",
    "sgocciolereste": "sgocciolare",
    "sgoccioleresti": "sgocciolare",
    "sgocciolerete": "sgocciolare",
    "sgocciolerà": "sgocciolare",
    "sgocciolerò": "sgocciolare",
    "sgoccioli": "sgocciolio",
    "sgoccioliamo": "sgocciolare",
    "sgoccioliate": "sgocciolare",
    "sgocciolin": "sgocciolare",
    "sgocciolino": "sgocciolare",
    "sgocciolo": "sgocciolare",
    "sgocciolò": "sgocciolare",
    "sgola": "sgolare",
    "sgolai": "sgolare",
    "sgolammo": "sgolare",
    "sgolan": "sgolare",
    "sgolando": "sgolare",
    "sgolano": "sgolare",
    "sgolar": "sgolare",
    "sgolaron": "sgolare",
    "sgolarono": "sgolare",
    "sgolasse": "sgolare",
    "sgolasser": "sgolare",
    "sgolassero": "sgolare",
    "sgolassi": "sgolare",
    "sgolassimo": "sgolare",
    "sgolaste": "sgolare",
    "sgolasti": "sgolare",
    "sgolata": "sgolare",
    "sgolate": "sgolare",
    "sgolati": "sgolare",
    "sgolato": "sgolare",
    "sgolava": "sgolare",
    "sgolavamo": "sgolare",
    "sgolavan": "sgolare",
    "sgolavano": "sgolare",
    "sgolavate": "sgolare",
    "sgolavi": "sgolare",
    "sgolavo": "sgolare",
    "sgolerai": "sgolare",
    "sgoleran": "sgolare",
    "sgoleranno": "sgolare",
    "sgolerebbe": "sgolare",
    "sgolerebber": "sgolare",
    "sgolerebbero": "sgolare",
    "sgolerei": "sgolare",
    "sgoleremmo": "sgolare",
    "sgoleremo": "sgolare",
    "sgolereste": "sgolare",
    "sgoleresti": "sgolare",
    "sgolerete": "sgolare",
    "sgolerà": "sgolare",
    "sgolerò": "sgolare",
    "sgoli": "sgolare",
    "sgoliamo": "sgolare",
    "sgoliate": "sgolare",
    "sgolin": "sgolare",
    "sgolino": "sgolare",
    "sgolo": "sgolare",
    "sgolò": "sgolare",
    "sgombera": "sgomberare",
    "sgomberai": "sgomberare",
    "sgomberammo": "sgomberare",
    "sgomberan": "sgomberare",
    "sgomberando": "sgomberare",
    "sgomberano": "sgomberare",
    "sgomberante": "sgomberare",
    "sgomberanti": "sgomberare",
    "sgomberar": "sgomberare",
    "sgomberaron": "sgomberare",
    "sgomberarono": "sgomberare",
    "sgomberasse": "sgomberare",
    "sgomberasser": "sgomberare",
    "sgomberassero": "sgomberare",
    "sgomberassi": "sgomberare",
    "sgomberassimo": "sgomberare",
    "sgomberaste": "sgomberare",
    "sgomberasti": "sgomberare",
    "sgomberata": "sgomberare",
    "sgomberate": "sgomberare",
    "sgomberati": "sgomberare",
    "sgomberato": "sgomberare",
    "sgomberava": "sgomberare",
    "sgomberavamo": "sgomberare",
    "sgomberavan": "sgomberare",
    "sgomberavano": "sgomberare",
    "sgomberavate": "sgomberare",
    "sgomberavi": "sgomberare",
    "sgomberavo": "sgomberare",
    "sgombererai": "sgomberare",
    "sgombereran": "sgomberare",
    "sgombereranno": "sgomberare",
    "sgombererebbe": "sgomberare",
    "sgombererebber": "sgomberare",
    "sgombererebbero": "sgomberare",
    "sgombererei": "sgomberare",
    "sgombereremmo": "sgomberare",
    "sgombereremo": "sgomberare",
    "sgomberereste": "sgomberare",
    "sgombereresti": "sgomberare",
    "sgombererete": "sgomberare",
    "sgombererà": "sgomberare",
    "sgombererò": "sgomberare",
    "sgomberi": "sgombero",
    "sgomberiamo": "sgomberare",
    "sgomberiate": "sgomberare",
    "sgomberin": "sgomberare",
    "sgomberino": "sgomberare",
    "sgombero": "sgomberare",
    "sgomberò": "sgomberare",
    "sgombra": "sgombro",
    "sgombrai": "sgombrare",
    "sgombrammo": "sgombrare",
    "sgombran": "sgombrare",
    "sgombrando": "sgombrare",
    "sgombrano": "sgombrare",
    "sgombrante": "sgombrare",
    "sgombranti": "sgombrare",
    "sgombrar": "sgombrare",
    "sgombraron": "sgombrare",
    "sgombrarono": "sgombrare",
    "sgombrasse": "sgombrare",
    "sgombrasser": "sgombrare",
    "sgombrassero": "sgombrare",
    "sgombrassi": "sgombrare",
    "sgombrassimo": "sgombrare",
    "sgombraste": "sgombrare",
    "sgombrasti": "sgombrare",
    "sgombrata": "sgombrare",
    "sgombrate": "sgombrare",
    "sgombrati": "sgombrare",
    "sgombrato": "sgombrare",
    "sgombrava": "sgombrare",
    "sgombravamo": "sgombrare",
    "sgombravan": "sgombrare",
    "sgombravano": "sgombrare",
    "sgombravate": "sgombrare",
    "sgombravi": "sgombrare",
    "sgombravo": "sgombrare",
    "sgombre": "sgombro",
    "sgombrerai": "sgombrare",
    "sgombreran": "sgombrare",
    "sgombreranno": "sgombrare",
    "sgombrerebbe": "sgombrare",
    "sgombrerebber": "sgombrare",
    "sgombrerebbero": "sgombrare",
    "sgombrerei": "sgombrare",
    "sgombreremmo": "sgombrare",
    "sgombreremo": "sgombrare",
    "sgombrereste": "sgombrare",
    "sgombreresti": "sgombrare",
    "sgombrerete": "sgombrare",
    "sgombrerà": "sgombrare",
    "sgombrerò": "sgombrare",
    "sgombri": "sgombro",
    "sgombriamo": "sgombrare",
    "sgombriate": "sgombrare",
    "sgombrin": "sgombrare",
    "sgombrino": "sgombrare",
    "sgombro": "sgombrare",
    "sgombrò": "sgombrare",
    "sgomenta": "sgomento",
    "sgomentai": "sgomentare",
    "sgomentammo": "sgomentare",
    "sgomentan": "sgomentare",
    "sgomentando": "sgomentare",
    "sgomentano": "sgomentare",
    "sgomentante": "sgomentare",
    "sgomentanti": "sgomentare",
    "sgomentar": "sgomentare",
    "sgomentaron": "sgomentare",
    "sgomentarono": "sgomentare",
    "sgomentasse": "sgomentare",
    "sgomentasser": "sgomentare",
    "sgomentassero": "sgomentare",
    "sgomentassi": "sgomentare",
    "sgomentassimo": "sgomentare",
    "sgomentaste": "sgomentare",
    "sgomentasti": "sgomentare",
    "sgomentata": "sgomentare",
    "sgomentate": "sgomentare",
    "sgomentati": "sgomentare",
    "sgomentato": "sgomentare",
    "sgomentava": "sgomentare",
    "sgomentavamo": "sgomentare",
    "sgomentavan": "sgomentare",
    "sgomentavano": "sgomentare",
    "sgomentavate": "sgomentare",
    "sgomentavi": "sgomentare",
    "sgomentavo": "sgomentare",
    "sgomente": "sgomento",
    "sgomenterai": "sgomentare",
    "sgomenteran": "sgomentare",
    "sgomenteranno": "sgomentare",
    "sgomenterebbe": "sgomentare",
    "sgomenterebber": "sgomentare",
    "sgomenterebbero": "sgomentare",
    "sgomenterei": "sgomentare",
    "sgomenteremmo": "sgomentare",
    "sgomenteremo": "sgomentare",
    "sgomentereste": "sgomentare",
    "sgomenteresti": "sgomentare",
    "sgomenterete": "sgomentare",
    "sgomenterà": "sgomentare",
    "sgomenterò": "sgomentare",
    "sgomenti": "sgomento",
    "sgomentiamo": "sgomentare",
    "sgomentiate": "sgomentare",
    "sgomentin": "sgomentare",
    "sgomentino": "sgomentare",
    "sgomento": "sgomentare",
    "sgomentò": "sgomentare",
    "sgomina": "sgominare",
    "sgominai": "sgominare",
    "sgominammo": "sgominare",
    "sgominan": "sgominare",
    "sgominando": "sgominare",
    "sgominano": "sgominare",
    "sgominante": "sgominare",
    "sgominanti": "sgominare",
    "sgominar": "sgominare",
    "sgominaron": "sgominare",
    "sgominarono": "sgominare",
    "sgominasse": "sgominare",
    "sgominasser": "sgominare",
    "sgominassero": "sgominare",
    "sgominassi": "sgominare",
    "sgominassimo": "sgominare",
    "sgominaste": "sgominare",
    "sgominasti": "sgominare",
    "sgominata": "sgominare",
    "sgominate": "sgominare",
    "sgominati": "sgominare",
    "sgominato": "sgominare",
    "sgominava": "sgominare",
    "sgominavamo": "sgominare",
    "sgominavan": "sgominare",
    "sgominavano": "sgominare",
    "sgominavate": "sgominare",
    "sgominavi": "sgominare",
    "sgominavo": "sgominare",
    "sgominerai": "sgominare",
    "sgomineran": "sgominare",
    "sgomineranno": "sgominare",
    "sgominerebbe": "sgominare",
    "sgominerebber": "sgominare",
    "sgominerebbero": "sgominare",
    "sgominerei": "sgominare",
    "sgomineremmo": "sgominare",
    "sgomineremo": "sgominare",
    "sgominereste": "sgominare",
    "sgomineresti": "sgominare",
    "sgominerete": "sgominare",
    "sgominerà": "sgominare",
    "sgominerò": "sgominare",
    "sgomini": "sgominare",
    "sgominiamo": "sgominare",
    "sgominiate": "sgominare",
    "sgominin": "sgominare",
    "sgominino": "sgominare",
    "sgomino": "sgominare",
    "sgominò": "sgominare",
    "sgomitola": "sgomitolare",
    "sgomitolai": "sgomitolare",
    "sgomitolammo": "sgomitolare",
    "sgomitolan": "sgomitolare",
    "sgomitolando": "sgomitolare",
    "sgomitolano": "sgomitolare",
    "sgomitolante": "sgomitolare",
    "sgomitolanti": "sgomitolare",
    "sgomitolar": "sgomitolare",
    "sgomitolaron": "sgomitolare",
    "sgomitolarono": "sgomitolare",
    "sgomitolasse": "sgomitolare",
    "sgomitolasser": "sgomitolare",
    "sgomitolassero": "sgomitolare",
    "sgomitolassi": "sgomitolare",
    "sgomitolassimo": "sgomitolare",
    "sgomitolaste": "sgomitolare",
    "sgomitolasti": "sgomitolare",
    "sgomitolata": "sgomitolare",
    "sgomitolate": "sgomitolare",
    "sgomitolati": "sgomitolare",
    "sgomitolato": "sgomitolare",
    "sgomitolava": "sgomitolare",
    "sgomitolavamo": "sgomitolare",
    "sgomitolavan": "sgomitolare",
    "sgomitolavano": "sgomitolare",
    "sgomitolavate": "sgomitolare",
    "sgomitolavi": "sgomitolare",
    "sgomitolavo": "sgomitolare",
    "sgomitolerai": "sgomitolare",
    "sgomitoleran": "sgomitolare",
    "sgomitoleranno": "sgomitolare",
    "sgomitolerebbe": "sgomitolare",
    "sgomitolerebber": "sgomitolare",
    "sgomitolerebbero": "sgomitolare",
    "sgomitolerei": "sgomitolare",
    "sgomitoleremmo": "sgomitolare",
    "sgomitoleremo": "sgomitolare",
    "sgomitolereste": "sgomitolare",
    "sgomitoleresti": "sgomitolare",
    "sgomitolerete": "sgomitolare",
    "sgomitolerà": "sgomitolare",
    "sgomitolerò": "sgomitolare",
    "sgomitoli": "sgomitolare",
    "sgomitoliamo": "sgomitolare",
    "sgomitoliate": "sgomitolare",
    "sgomitolin": "sgomitolare",
    "sgomitolino": "sgomitolare",
    "sgomitolo": "sgomitolare",
    "sgomitolò": "sgomitolare",
    "sgomma": "sgommare",
    "sgommai": "sgommare",
    "sgommammo": "sgommare",
    "sgomman": "sgommare",
    "sgommando": "sgommare",
    "sgommano": "sgommare",
    "sgommante": "sgommare",
    "sgommanti": "sgommare",
    "sgommar": "sgommare",
    "sgommaron": "sgommare",
    "sgommarono": "sgommare",
    "sgommasse": "sgommare",
    "sgommasser": "sgommare",
    "sgommassero": "sgommare",
    "sgommassi": "sgommare",
    "sgommassimo": "sgommare",
    "sgommaste": "sgommare",
    "sgommasti": "sgommare",
    "sgommata": "sgommare",
    "sgommate": "sgommare",
    "sgommati": "sgommare",
    "sgommato": "sgommare",
    "sgommava": "sgommare",
    "sgommavamo": "sgommare",
    "sgommavan": "sgommare",
    "sgommavano": "sgommare",
    "sgommavate": "sgommare",
    "sgommavi": "sgommare",
    "sgommavo": "sgommare",
    "sgommerai": "sgommare",
    "sgommeran": "sgommare",
    "sgommeranno": "sgommare",
    "sgommerebbe": "sgommare",
    "sgommerebber": "sgommare",
    "sgommerebbero": "sgommare",
    "sgommerei": "sgommare",
    "sgommeremmo": "sgommare",
    "sgommeremo": "sgommare",
    "sgommereste": "sgommare",
    "sgommeresti": "sgommare",
    "sgommerete": "sgommare",
    "sgommerà": "sgommare",
    "sgommerò": "sgommare",
    "sgommi": "sgommare",
    "sgommiamo": "sgommare",
    "sgommiate": "sgommare",
    "sgommin": "sgommare",
    "sgommino": "sgommare",
    "sgommo": "sgommare",
    "sgommò": "sgommare",
    "sgonfi": "sgonfio",
    "sgonfia": "sgonfio",
    "sgonfiai": "sgonfiare",
    "sgonfiammo": "sgonfiare",
    "sgonfiamo": "sgonfiare",
    "sgonfian": "sgonfiare",
    "sgonfiando": "sgonfiare",
    "sgonfiano": "sgonfiare",
    "sgonfiante": "sgonfiare",
    "sgonfianti": "sgonfiare",
    "sgonfiar": "sgonfiare",
    "sgonfiaron": "sgonfiare",
    "sgonfiarono": "sgonfiare",
    "sgonfiasse": "sgonfiare",
    "sgonfiasser": "sgonfiare",
    "sgonfiassero": "sgonfiare",
    "sgonfiassi": "sgonfiare",
    "sgonfiassimo": "sgonfiare",
    "sgonfiaste": "sgonfiare",
    "sgonfiasti": "sgonfiare",
    "sgonfiata": "sgonfiare",
    "sgonfiate": "sgonfiare",
    "sgonfiati": "sgonfiare",
    "sgonfiato": "sgonfiare",
    "sgonfiava": "sgonfiare",
    "sgonfiavamo": "sgonfiare",
    "sgonfiavan": "sgonfiare",
    "sgonfiavano": "sgonfiare",
    "sgonfiavate": "sgonfiare",
    "sgonfiavi": "sgonfiare",
    "sgonfiavo": "sgonfiare",
    "sgonfie": "sgonfio",
    "sgonfierai": "sgonfiare",
    "sgonfieran": "sgonfiare",
    "sgonfieranno": "sgonfiare",
    "sgonfierebbe": "sgonfiare",
    "sgonfierebber": "sgonfiare",
    "sgonfierebbero": "sgonfiare",
    "sgonfierei": "sgonfiare",
    "sgonfieremmo": "sgonfiare",
    "sgonfieremo": "sgonfiare",
    "sgonfiereste": "sgonfiare",
    "sgonfieresti": "sgonfiare",
    "sgonfierete": "sgonfiare",
    "sgonfierà": "sgonfiare",
    "sgonfierò": "sgonfiare",
    "sgonfin": "sgonfiare",
    "sgonfino": "sgonfiare",
    "sgonfio": "sgonfiare",
    "sgonfiò": "sgonfiare",
    "sgonnella": "sgonnellare",
    "sgonnellai": "sgonnellare",
    "sgonnellammo": "sgonnellare",
    "sgonnellan": "sgonnellare",
    "sgonnellando": "sgonnellare",
    "sgonnellano": "sgonnellare",
    "sgonnellante": "sgonnellare",
    "sgonnellanti": "sgonnellare",
    "sgonnellar": "sgonnellare",
    "sgonnellaron": "sgonnellare",
    "sgonnellarono": "sgonnellare",
    "sgonnellasse": "sgonnellare",
    "sgonnellasser": "sgonnellare",
    "sgonnellassero": "sgonnellare",
    "sgonnellassi": "sgonnellare",
    "sgonnellassimo": "sgonnellare",
    "sgonnellaste": "sgonnellare",
    "sgonnellasti": "sgonnellare",
    "sgonnellata": "sgonnellare",
    "sgonnellate": "sgonnellare",
    "sgonnellati": "sgonnellare",
    "sgonnellato": "sgonnellare",
    "sgonnellava": "sgonnellare",
    "sgonnellavamo": "sgonnellare",
    "sgonnellavan": "sgonnellare",
    "sgonnellavano": "sgonnellare",
    "sgonnellavate": "sgonnellare",
    "sgonnellavi": "sgonnellare",
    "sgonnellavo": "sgonnellare",
    "sgonnellerai": "sgonnellare",
    "sgonnelleran": "sgonnellare",
    "sgonnelleranno": "sgonnellare",
    "sgonnellerebbe": "sgonnellare",
    "sgonnellerebber": "sgonnellare",
    "sgonnellerebbero": "sgonnellare",
    "sgonnellerei": "sgonnellare",
    "sgonnelleremmo": "sgonnellare",
    "sgonnelleremo": "sgonnellare",
    "sgonnellereste": "sgonnellare",
    "sgonnelleresti": "sgonnellare",
    "sgonnellerete": "sgonnellare",
    "sgonnellerà": "sgonnellare",
    "sgonnellerò": "sgonnellare",
    "sgonnelli": "sgonnellare",
    "sgonnelliamo": "sgonnellare",
    "sgonnelliate": "sgonnellare",
    "sgonnellin": "sgonnellare",
    "sgonnellino": "sgonnellare",
    "sgonnello": "sgonnellare",
    "sgonnellò": "sgonnellare",
    "sgorbi": "sgorbiare",
    "sgorbia": "sgorbiare",
    "sgorbiai": "sgorbiare",
    "sgorbiammo": "sgorbiare",
    "sgorbiamo": "sgorbiare",
    "sgorbian": "sgorbiare",
    "sgorbiando": "sgorbiare",
    "sgorbiano": "sgorbiare",
    "sgorbiante": "sgorbiare",
    "sgorbianti": "sgorbiare",
    "sgorbiar": "sgorbiare",
    "sgorbiaron": "sgorbiare",
    "sgorbiarono": "sgorbiare",
    "sgorbiasse": "sgorbiare",
    "sgorbiasser": "sgorbiare",
    "sgorbiassero": "sgorbiare",
    "sgorbiassi": "sgorbiare",
    "sgorbiassimo": "sgorbiare",
    "sgorbiaste": "sgorbiare",
    "sgorbiasti": "sgorbiare",
    "sgorbiata": "sgorbiare",
    "sgorbiate": "sgorbiare",
    "sgorbiati": "sgorbiare",
    "sgorbiato": "sgorbiare",
    "sgorbiava": "sgorbiare",
    "sgorbiavamo": "sgorbiare",
    "sgorbiavan": "sgorbiare",
    "sgorbiavano": "sgorbiare",
    "sgorbiavate": "sgorbiare",
    "sgorbiavi": "sgorbiare",
    "sgorbiavo": "sgorbiare",
    "sgorbierai": "sgorbiare",
    "sgorbieran": "sgorbiare",
    "sgorbieranno": "sgorbiare",
    "sgorbierebbe": "sgorbiare",
    "sgorbierebber": "sgorbiare",
    "sgorbierebbero": "sgorbiare",
    "sgorbierei": "sgorbiare",
    "sgorbieremmo": "sgorbiare",
    "sgorbieremo": "sgorbiare",
    "sgorbiereste": "sgorbiare",
    "sgorbieresti": "sgorbiare",
    "sgorbierete": "sgorbiare",
    "sgorbierà": "sgorbiare",
    "sgorbierò": "sgorbiare",
    "sgorbin": "sgorbiare",
    "sgorbino": "sgorbiare",
    "sgorbio": "sgorbiare",
    "sgorbiò": "sgorbiare",
    "sgorga": "sgorgare",
    "sgorgai": "sgorgare",
    "sgorgammo": "sgorgare",
    "sgorgan": "sgorgare",
    "sgorgando": "sgorgare",
    "sgorgano": "sgorgare",
    "sgorgante": "sgorgare",
    "sgorganti": "sgorgare",
    "sgorgar": "sgorgare",
    "sgorgaron": "sgorgare",
    "sgorgarono": "sgorgare",
    "sgorgasse": "sgorgare",
    "sgorgasser": "sgorgare",
    "sgorgassero": "sgorgare",
    "sgorgassi": "sgorgare",
    "sgorgassimo": "sgorgare",
    "sgorgaste": "sgorgare",
    "sgorgasti": "sgorgare",
    "sgorgata": "sgorgare",
    "sgorgate": "sgorgare",
    "sgorgati": "sgorgare",
    "sgorgato": "sgorgare",
    "sgorgava": "sgorgare",
    "sgorgavamo": "sgorgare",
    "sgorgavan": "sgorgare",
    "sgorgavano": "sgorgare",
    "sgorgavate": "sgorgare",
    "sgorgavi": "sgorgare",
    "sgorgavo": "sgorgare",
    "sgorgherai": "sgorgare",
    "sgorgheran": "sgorgare",
    "sgorgheranno": "sgorgare",
    "sgorgherebbe": "sgorgare",
    "sgorgherebber": "sgorgare",
    "sgorgherebbero": "sgorgare",
    "sgorgherei": "sgorgare",
    "sgorgheremmo": "sgorgare",
    "sgorgheremo": "sgorgare",
    "sgorghereste": "sgorgare",
    "sgorgheresti": "sgorgare",
    "sgorgherete": "sgorgare",
    "sgorgherà": "sgorgare",
    "sgorgherò": "sgorgare",
    "sgorghi": "sgorgare",
    "sgorghiamo": "sgorgare",
    "sgorghiate": "sgorgare",
    "sgorghin": "sgorgare",
    "sgorghino": "sgorgare",
    "sgorgo": "sgorgare",
    "sgorgò": "sgorgare",
    "sgozza": "sgozzare",
    "sgozzai": "sgozzare",
    "sgozzamenti": "sgozzamento",
    "sgozzammo": "sgozzare",
    "sgozzan": "sgozzare",
    "sgozzando": "sgozzare",
    "sgozzano": "sgozzare",
    "sgozzante": "sgozzare",
    "sgozzanti": "sgozzare",
    "sgozzar": "sgozzare",
    "sgozzaron": "sgozzare",
    "sgozzarono": "sgozzare",
    "sgozzasse": "sgozzare",
    "sgozzasser": "sgozzare",
    "sgozzassero": "sgozzare",
    "sgozzassi": "sgozzare",
    "sgozzassimo": "sgozzare",
    "sgozzaste": "sgozzare",
    "sgozzasti": "sgozzare",
    "sgozzata": "sgozzare",
    "sgozzate": "sgozzare",
    "sgozzati": "sgozzare",
    "sgozzato": "sgozzare",
    "sgozzava": "sgozzare",
    "sgozzavamo": "sgozzare",
    "sgozzavan": "sgozzare",
    "sgozzavano": "sgozzare",
    "sgozzavate": "sgozzare",
    "sgozzavi": "sgozzare",
    "sgozzavo": "sgozzare",
    "sgozzerai": "sgozzare",
    "sgozzeran": "sgozzare",
    "sgozzeranno": "sgozzare",
    "sgozzerebbe": "sgozzare",
    "sgozzerebber": "sgozzare",
    "sgozzerebbero": "sgozzare",
    "sgozzerei": "sgozzare",
    "sgozzeremmo": "sgozzare",
    "sgozzeremo": "sgozzare",
    "sgozzereste": "sgozzare",
    "sgozzeresti": "sgozzare",
    "sgozzerete": "sgozzare",
    "sgozzerà": "sgozzare",
    "sgozzerò": "sgozzare",
    "sgozzi": "sgozzare",
    "sgozziamo": "sgozzare",
    "sgozziate": "sgozzare",
    "sgozzin": "sgozzare",
    "sgozzino": "sgozzare",
    "sgozzo": "sgozzare",
    "sgozzò": "sgozzare",
    "sgrada": "sgradire",
    "sgradan": "sgradire",
    "sgradano": "sgradire",
    "sgrade": "sgradire",
    "sgradendo": "sgradire",
    "sgradente": "sgradire",
    "sgradenti": "sgradire",
    "sgradevolezze": "sgradevolezza",
    "sgradevoli": "sgradevole",
    "sgradi": "sgradire",
    "sgradiamo": "sgradire",
    "sgradiate": "sgradire",
    "sgradii": "sgradire",
    "sgradimmo": "sgradire",
    "sgradir": "sgradire",
    "sgradirai": "sgradire",
    "sgradiran": "sgradire",
    "sgradiranno": "sgradire",
    "sgradirebbe": "sgradire",
    "sgradirebber": "sgradire",
    "sgradirebbero": "sgradire",
    "sgradirei": "sgradire",
    "sgradiremmo": "sgradire",
    "sgradiremo": "sgradire",
    "sgradireste": "sgradire",
    "sgradiresti": "sgradire",
    "sgradirete": "sgradire",
    "sgradiron": "sgradire",
    "sgradirono": "sgradire",
    "sgradirà": "sgradire",
    "sgradirò": "sgradire",
    "sgradisse": "sgradire",
    "sgradisser": "sgradire",
    "sgradissero": "sgradire",
    "sgradissi": "sgradire",
    "sgradissimo": "sgradire",
    "sgradiste": "sgradire",
    "sgradisti": "sgradire",
    "sgradita": "sgradito",
    "sgradite": "sgradito",
    "sgraditi": "sgradito",
    "sgradito": "sgradire",
    "sgradiva": "sgradire",
    "sgradivamo": "sgradire",
    "sgradivan": "sgradire",
    "sgradivano": "sgradire",
    "sgradivate": "sgradire",
    "sgradivi": "sgradire",
    "sgradivo": "sgradire",
    "sgrado": "sgradire",
    "sgradon": "sgradire",
    "sgradono": "sgradire",
    "sgradì": "sgradire",
    "sgraffigna": "sgraffignare",
    "sgraffignai": "sgraffignare",
    "sgraffignammo": "sgraffignare",
    "sgraffignan": "sgraffignare",
    "sgraffignando": "sgraffignare",
    "sgraffignano": "sgraffignare",
    "sgraffignante": "sgraffignare",
    "sgraffignanti": "sgraffignare",
    "sgraffignar": "sgraffignare",
    "sgraffignaron": "sgraffignare",
    "sgraffignarono": "sgraffignare",
    "sgraffignasse": "sgraffignare",
    "sgraffignasser": "sgraffignare",
    "sgraffignassero": "sgraffignare",
    "sgraffignassi": "sgraffignare",
    "sgraffignassimo": "sgraffignare",
    "sgraffignaste": "sgraffignare",
    "sgraffignasti": "sgraffignare",
    "sgraffignata": "sgraffignare",
    "sgraffignate": "sgraffignare",
    "sgraffignati": "sgraffignare",
    "sgraffignato": "sgraffignare",
    "sgraffignava": "sgraffignare",
    "sgraffignavamo": "sgraffignare",
    "sgraffignavan": "sgraffignare",
    "sgraffignavano": "sgraffignare",
    "sgraffignavate": "sgraffignare",
    "sgraffignavi": "sgraffignare",
    "sgraffignavo": "sgraffignare",
    "sgraffignerai": "sgraffignare",
    "sgraffigneran": "sgraffignare",
    "sgraffigneranno": "sgraffignare",
    "sgraffignerebbe": "sgraffignare",
    "sgraffignerebber": "sgraffignare",
    "sgraffignerebbero": "sgraffignare",
    "sgraffignerei": "sgraffignare",
    "sgraffigneremmo": "sgraffignare",
    "sgraffigneremo": "sgraffignare",
    "sgraffignereste": "sgraffignare",
    "sgraffigneresti": "sgraffignare",
    "sgraffignerete": "sgraffignare",
    "sgraffignerà": "sgraffignare",
    "sgraffignerò": "sgraffignare",
    "sgraffigni": "sgraffignare",
    "sgraffigniamo": "sgraffignare",
    "sgraffigniate": "sgraffignare",
    "sgraffignin": "sgraffignare",
    "sgraffignino": "sgraffignare",
    "sgraffigno": "sgraffignare",
    "sgraffignò": "sgraffignare",
    "sgrammatica": "sgrammaticare",
    "sgrammaticai": "sgrammaticare",
    "sgrammaticammo": "sgrammaticare",
    "sgrammatican": "sgrammaticare",
    "sgrammaticando": "sgrammaticare",
    "sgrammaticano": "sgrammaticare",
    "sgrammaticante": "sgrammaticare",
    "sgrammaticanti": "sgrammaticare",
    "sgrammaticar": "sgrammaticare",
    "sgrammaticaron": "sgrammaticare",
    "sgrammaticarono": "sgrammaticare",
    "sgrammaticasse": "sgrammaticare",
    "sgrammaticasser": "sgrammaticare",
    "sgrammaticassero": "sgrammaticare",
    "sgrammaticassi": "sgrammaticare",
    "sgrammaticassimo": "sgrammaticare",
    "sgrammaticaste": "sgrammaticare",
    "sgrammaticasti": "sgrammaticare",
    "sgrammaticata": "sgrammaticato",
    "sgrammaticate": "sgrammaticato",
    "sgrammaticati": "sgrammaticato",
    "sgrammaticato": "sgrammaticare",
    "sgrammaticature": "sgrammaticatura",
    "sgrammaticava": "sgrammaticare",
    "sgrammaticavamo": "sgrammaticare",
    "sgrammaticavan": "sgrammaticare",
    "sgrammaticavano": "sgrammaticare",
    "sgrammaticavate": "sgrammaticare",
    "sgrammaticavi": "sgrammaticare",
    "sgrammaticavo": "sgrammaticare",
    "sgrammaticherai": "sgrammaticare",
    "sgrammaticheran": "sgrammaticare",
    "sgrammaticheranno": "sgrammaticare",
    "sgrammaticherebbe": "sgrammaticare",
    "sgrammaticherebber": "sgrammaticare",
    "sgrammaticherebbero": "sgrammaticare",
    "sgrammaticherei": "sgrammaticare",
    "sgrammaticheremmo": "sgrammaticare",
    "sgrammaticheremo": "sgrammaticare",
    "sgrammatichereste": "sgrammaticare",
    "sgrammaticheresti": "sgrammaticare",
    "sgrammaticherete": "sgrammaticare",
    "sgrammaticherà": "sgrammaticare",
    "sgrammaticherò": "sgrammaticare",
    "sgrammatichi": "sgrammaticare",
    "sgrammatichiamo": "sgrammaticare",
    "sgrammatichiate": "sgrammaticare",
    "sgrammatichin": "sgrammaticare",
    "sgrammatichino": "sgrammaticare",
    "sgrammatico": "sgrammaticare",
    "sgrammaticò": "sgrammaticare",
    "sgrana": "sgranare",
    "sgranai": "sgranare",
    "sgranammo": "sgranare",
    "sgranan": "sgranare",
    "sgranando": "sgranare",
    "sgranano": "sgranare",
    "sgranante": "sgranare",
    "sgrananti": "sgranare",
    "sgranar": "sgranare",
    "sgranaron": "sgranare",
    "sgranarono": "sgranare",
    "sgranasse": "sgranare",
    "sgranasser": "sgranare",
    "sgranassero": "sgranare",
    "sgranassi": "sgranare",
    "sgranassimo": "sgranare",
    "sgranaste": "sgranare",
    "sgranasti": "sgranare",
    "sgranata": "sgranare",
    "sgranate": "sgranare",
    "sgranati": "sgranare",
    "sgranato": "sgranare",
    "sgranava": "sgranare",
    "sgranavamo": "sgranare",
    "sgranavan": "sgranare",
    "sgranavano": "sgranare",
    "sgranavate": "sgranare",
    "sgranavi": "sgranare",
    "sgranavo": "sgranare",
    "sgranchendo": "sgranchire",
    "sgranchente": "sgranchire",
    "sgranchenti": "sgranchire",
    "sgranchiamo": "sgranchire",
    "sgranchiate": "sgranchire",
    "sgranchii": "sgranchire",
    "sgranchimmo": "sgranchire",
    "sgranchir": "sgranchire",
    "sgranchirai": "sgranchire",
    "sgranchiran": "sgranchire",
    "sgranchiranno": "sgranchire",
    "sgranchirebbe": "sgranchire",
    "sgranchirebber": "sgranchire",
    "sgranchirebbero": "sgranchire",
    "sgranchirei": "sgranchire",
    "sgranchiremmo": "sgranchire",
    "sgranchiremo": "sgranchire",
    "sgranchireste": "sgranchire",
    "sgranchiresti": "sgranchire",
    "sgranchirete": "sgranchire",
    "sgranchiron": "sgranchire",
    "sgranchirono": "sgranchire",
    "sgranchirà": "sgranchire",
    "sgranchirò": "sgranchire",
    "sgranchisca": "sgranchire",
    "sgranchiscan": "sgranchire",
    "sgranchiscano": "sgranchire",
    "sgranchisce": "sgranchire",
    "sgranchisci": "sgranchire",
    "sgranchisco": "sgranchire",
    "sgranchiscon": "sgranchire",
    "sgranchiscono": "sgranchire",
    "sgranchisse": "sgranchire",
    "sgranchisser": "sgranchire",
    "sgranchissero": "sgranchire",
    "sgranchissi": "sgranchire",
    "sgranchissimo": "sgranchire",
    "sgranchiste": "sgranchire",
    "sgranchisti": "sgranchire",
    "sgranchita": "sgranchire",
    "sgranchite": "sgranchire",
    "sgranchiti": "sgranchire",
    "sgranchito": "sgranchire",
    "sgranchiva": "sgranchire",
    "sgranchivamo": "sgranchire",
    "sgranchivan": "sgranchire",
    "sgranchivano": "sgranchire",
    "sgranchivate": "sgranchire",
    "sgranchivi": "sgranchire",
    "sgranchivo": "sgranchire",
    "sgranchì": "sgranchire",
    "sgranerai": "sgranare",
    "sgraneran": "sgranare",
    "sgraneranno": "sgranare",
    "sgranerebbe": "sgranare",
    "sgranerebber": "sgranare",
    "sgranerebbero": "sgranare",
    "sgranerei": "sgranare",
    "sgraneremmo": "sgranare",
    "sgraneremo": "sgranare",
    "sgranereste": "sgranare",
    "sgraneresti": "sgranare",
    "sgranerete": "sgranare",
    "sgranerà": "sgranare",
    "sgranerò": "sgranare",
    "sgrani": "sgranare",
    "sgraniamo": "sgranare",
    "sgraniate": "sgranare",
    "sgranin": "sgranare",
    "sgranino": "sgranare",
    "sgrano": "sgranare",
    "sgranocchi": "sgranocchiare",
    "sgranocchia": "sgranocchiare",
    "sgranocchiai": "sgranocchiare",
    "sgranocchiammo": "sgranocchiare",
    "sgranocchiamo": "sgranocchiare",
    "sgranocchian": "sgranocchiare",
    "sgranocchiando": "sgranocchiare",
    "sgranocchiano": "sgranocchiare",
    "sgranocchiante": "sgranocchiare",
    "sgranocchianti": "sgranocchiare",
    "sgranocchiar": "sgranocchiare",
    "sgranocchiaron": "sgranocchiare",
    "sgranocchiarono": "sgranocchiare",
    "sgranocchiasse": "sgranocchiare",
    "sgranocchiasser": "sgranocchiare",
    "sgranocchiassero": "sgranocchiare",
    "sgranocchiassi": "sgranocchiare",
    "sgranocchiassimo": "sgranocchiare",
    "sgranocchiaste": "sgranocchiare",
    "sgranocchiasti": "sgranocchiare",
    "sgranocchiata": "sgranocchiare",
    "sgranocchiate": "sgranocchiare",
    "sgranocchiati": "sgranocchiare",
    "sgranocchiato": "sgranocchiare",
    "sgranocchiava": "sgranocchiare",
    "sgranocchiavamo": "sgranocchiare",
    "sgranocchiavan": "sgranocchiare",
    "sgranocchiavano": "sgranocchiare",
    "sgranocchiavate": "sgranocchiare",
    "sgranocchiavi": "sgranocchiare",
    "sgranocchiavo": "sgranocchiare",
    "sgranocchierai": "sgranocchiare",
    "sgranocchieran": "sgranocchiare",
    "sgranocchieranno": "sgranocchiare",
    "sgranocchierebbe": "sgranocchiare",
    "sgranocchierebber": "sgranocchiare",
    "sgranocchierebbero": "sgranocchiare",
    "sgranocchierei": "sgranocchiare",
    "sgranocchieremmo": "sgranocchiare",
    "sgranocchieremo": "sgranocchiare",
    "sgranocchiereste": "sgranocchiare",
    "sgranocchieresti": "sgranocchiare",
    "sgranocchierete": "sgranocchiare",
    "sgranocchierà": "sgranocchiare",
    "sgranocchierò": "sgranocchiare",
    "sgranocchin": "sgranocchiare",
    "sgranocchino": "sgranocchiare",
    "sgranocchio": "sgranocchiare",
    "sgranocchiò": "sgranocchiare",
    "sgranò": "sgranare",
    "sgrassa": "sgrassare",
    "sgrassai": "sgrassare",
    "sgrassammo": "sgrassare",
    "sgrassan": "sgrassare",
    "sgrassando": "sgrassare",
    "sgrassano": "sgrassare",
    "sgrassante": "sgrassare",
    "sgrassanti": "sgrassare",
    "sgrassar": "sgrassare",
    "sgrassaron": "sgrassare",
    "sgrassarono": "sgrassare",
    "sgrassasse": "sgrassare",
    "sgrassasser": "sgrassare",
    "sgrassassero": "sgrassare",
    "sgrassassi": "sgrassare",
    "sgrassassimo": "sgrassare",
    "sgrassaste": "sgrassare",
    "sgrassasti": "sgrassare",
    "sgrassata": "sgrassare",
    "sgrassate": "sgrassare",
    "sgrassati": "sgrassare",
    "sgrassato": "sgrassare",
    "sgrassava": "sgrassare",
    "sgrassavamo": "sgrassare",
    "sgrassavan": "sgrassare",
    "sgrassavano": "sgrassare",
    "sgrassavate": "sgrassare",
    "sgrassavi": "sgrassare",
    "sgrassavo": "sgrassare",
    "sgrasserai": "sgrassare",
    "sgrasseran": "sgrassare",
    "sgrasseranno": "sgrassare",
    "sgrasserebbe": "sgrassare",
    "sgrasserebber": "sgrassare",
    "sgrasserebbero": "sgrassare",
    "sgrasserei": "sgrassare",
    "sgrasseremmo": "sgrassare",
    "sgrasseremo": "sgrassare",
    "sgrassereste": "sgrassare",
    "sgrasseresti": "sgrassare",
    "sgrasserete": "sgrassare",
    "sgrasserà": "sgrassare",
    "sgrasserò": "sgrassare",
    "sgrassi": "sgrassare",
    "sgrassiamo": "sgrassare",
    "sgrassiate": "sgrassare",
    "sgrassin": "sgrassare",
    "sgrassino": "sgrassare",
    "sgrasso": "sgrassare",
    "sgrassò": "sgrassare",
    "sgrava": "sgravare",
    "sgravai": "sgravare",
    "sgravammo": "sgravare",
    "sgravan": "sgravare",
    "sgravando": "sgravare",
    "sgravano": "sgravare",
    "sgravante": "sgravare",
    "sgravanti": "sgravare",
    "sgravar": "sgravare",
    "sgravaron": "sgravare",
    "sgravarono": "sgravare",
    "sgravasse": "sgravare",
    "sgravasser": "sgravare",
    "sgravassero": "sgravare",
    "sgravassi": "sgravare",
    "sgravassimo": "sgravare",
    "sgravaste": "sgravare",
    "sgravasti": "sgravare",
    "sgravata": "sgravare",
    "sgravate": "sgravare",
    "sgravati": "sgravare",
    "sgravato": "sgravare",
    "sgravava": "sgravare",
    "sgravavamo": "sgravare",
    "sgravavan": "sgravare",
    "sgravavano": "sgravare",
    "sgravavate": "sgravare",
    "sgravavi": "sgravare",
    "sgravavo": "sgravare",
    "sgraverai": "sgravare",
    "sgraveran": "sgravare",
    "sgraveranno": "sgravare",
    "sgraverebbe": "sgravare",
    "sgraverebber": "sgravare",
    "sgraverebbero": "sgravare",
    "sgraverei": "sgravare",
    "sgraveremmo": "sgravare",
    "sgraveremo": "sgravare",
    "sgravereste": "sgravare",
    "sgraveresti": "sgravare",
    "sgraverete": "sgravare",
    "sgraverà": "sgravare",
    "sgraverò": "sgravare",
    "sgravi": "sgravio",
    "sgraviamo": "sgravare",
    "sgraviate": "sgravare",
    "sgravin": "sgravare",
    "sgravino": "sgravare",
    "sgravo": "sgravare",
    "sgravò": "sgravare",
    "sgraziata": "sgraziato",
    "sgraziate": "sgraziato",
    "sgraziati": "sgraziato",
    "sgretola": "sgretolare",
    "sgretolai": "sgretolare",
    "sgretolamenti": "sgretolamento",
    "sgretolammo": "sgretolare",
    "sgretolan": "sgretolare",
    "sgretolando": "sgretolare",
    "sgretolano": "sgretolare",
    "sgretolante": "sgretolare",
    "sgretolanti": "sgretolare",
    "sgretolar": "sgretolare",
    "sgretolaron": "sgretolare",
    "sgretolarono": "sgretolare",
    "sgretolasse": "sgretolare",
    "sgretolasser": "sgretolare",
    "sgretolassero": "sgretolare",
    "sgretolassi": "sgretolare",
    "sgretolassimo": "sgretolare",
    "sgretolaste": "sgretolare",
    "sgretolasti": "sgretolare",
    "sgretolata": "sgretolare",
    "sgretolate": "sgretolare",
    "sgretolati": "sgretolare",
    "sgretolato": "sgretolare",
    "sgretolava": "sgretolare",
    "sgretolavamo": "sgretolare",
    "sgretolavan": "sgretolare",
    "sgretolavano": "sgretolare",
    "sgretolavate": "sgretolare",
    "sgretolavi": "sgretolare",
    "sgretolavo": "sgretolare",
    "sgretolerai": "sgretolare",
    "sgretoleran": "sgretolare",
    "sgretoleranno": "sgretolare",
    "sgretolerebbe": "sgretolare",
    "sgretolerebber": "sgretolare",
    "sgretolerebbero": "sgretolare",
    "sgretolerei": "sgretolare",
    "sgretoleremmo": "sgretolare",
    "sgretoleremo": "sgretolare",
    "sgretolereste": "sgretolare",
    "sgretoleresti": "sgretolare",
    "sgretolerete": "sgretolare",
    "sgretolerà": "sgretolare",
    "sgretolerò": "sgretolare",
    "sgretoli": "sgretolare",
    "sgretoliamo": "sgretolare",
    "sgretoliate": "sgretolare",
    "sgretolin": "sgretolare",
    "sgretolino": "sgretolare",
    "sgretolo": "sgretolare",
    "sgretolò": "sgretolare",
    "sgrida": "sgridare",
    "sgridai": "sgridare",
    "sgridammo": "sgridare",
    "sgridan": "sgridare",
    "sgridando": "sgridare",
    "sgridano": "sgridare",
    "sgridante": "sgridare",
    "sgridanti": "sgridare",
    "sgridar": "sgridare",
    "sgridaron": "sgridare",
    "sgridarono": "sgridare",
    "sgridasse": "sgridare",
    "sgridasser": "sgridare",
    "sgridassero": "sgridare",
    "sgridassi": "sgridare",
    "sgridassimo": "sgridare",
    "sgridaste": "sgridare",
    "sgridasti": "sgridare",
    "sgridata": "sgridare",
    "sgridate": "sgridata",
    "sgridati": "sgridare",
    "sgridato": "sgridare",
    "sgridava": "sgridare",
    "sgridavamo": "sgridare",
    "sgridavan": "sgridare",
    "sgridavano": "sgridare",
    "sgridavate": "sgridare",
    "sgridavi": "sgridare",
    "sgridavo": "sgridare",
    "sgriderai": "sgridare",
    "sgrideran": "sgridare",
    "sgrideranno": "sgridare",
    "sgriderebbe": "sgridare",
    "sgriderebber": "sgridare",
    "sgriderebbero": "sgridare",
    "sgriderei": "sgridare",
    "sgrideremmo": "sgridare",
    "sgrideremo": "sgridare",
    "sgridereste": "sgridare",
    "sgrideresti": "sgridare",
    "sgriderete": "sgridare",
    "sgriderà": "sgridare",
    "sgriderò": "sgridare",
    "sgridi": "sgridare",
    "sgridiamo": "sgridare",
    "sgridiate": "sgridare",
    "sgridin": "sgridare",
    "sgridino": "sgridare",
    "sgrido": "sgridare",
    "sgridò": "sgridare",
    "sgrilletta": "sgrillettare",
    "sgrillettai": "sgrillettare",
    "sgrillettammo": "sgrillettare",
    "sgrillettan": "sgrillettare",
    "sgrillettando": "sgrillettare",
    "sgrillettano": "sgrillettare",
    "sgrillettante": "sgrillettare",
    "sgrillettanti": "sgrillettare",
    "sgrillettar": "sgrillettare",
    "sgrillettaron": "sgrillettare",
    "sgrillettarono": "sgrillettare",
    "sgrillettasse": "sgrillettare",
    "sgrillettasser": "sgrillettare",
    "sgrillettassero": "sgrillettare",
    "sgrillettassi": "sgrillettare",
    "sgrillettassimo": "sgrillettare",
    "sgrillettaste": "sgrillettare",
    "sgrillettasti": "sgrillettare",
    "sgrillettata": "sgrillettare",
    "sgrillettate": "sgrillettare",
    "sgrillettati": "sgrillettare",
    "sgrillettato": "sgrillettare",
    "sgrillettava": "sgrillettare",
    "sgrillettavamo": "sgrillettare",
    "sgrillettavan": "sgrillettare",
    "sgrillettavano": "sgrillettare",
    "sgrillettavate": "sgrillettare",
    "sgrillettavi": "sgrillettare",
    "sgrillettavo": "sgrillettare",
    "sgrilletterai": "sgrillettare",
    "sgrilletteran": "sgrillettare",
    "sgrilletteranno": "sgrillettare",
    "sgrilletterebbe": "sgrillettare",
    "sgrilletterebber": "sgrillettare",
    "sgrilletterebbero": "sgrillettare",
    "sgrilletterei": "sgrillettare",
    "sgrilletteremmo": "sgrillettare",
    "sgrilletteremo": "sgrillettare",
    "sgrillettereste": "sgrillettare",
    "sgrilletteresti": "sgrillettare",
    "sgrilletterete": "sgrillettare",
    "sgrilletterà": "sgrillettare",
    "sgrilletterò": "sgrillettare",
    "sgrilletti": "sgrillettare",
    "sgrillettiamo": "sgrillettare",
    "sgrillettiate": "sgrillettare",
    "sgrillettin": "sgrillettare",
    "sgrillettino": "sgrillettare",
    "sgrilletto": "sgrillettare",
    "sgrillettò": "sgrillettare",
    "sgronda": "sgrondare",
    "sgrondai": "sgrondare",
    "sgrondammo": "sgrondare",
    "sgrondan": "sgrondare",
    "sgrondando": "sgrondare",
    "sgrondano": "sgrondare",
    "sgrondante": "sgrondare",
    "sgrondanti": "sgrondare",
    "sgrondar": "sgrondare",
    "sgrondaron": "sgrondare",
    "sgrondarono": "sgrondare",
    "sgrondasse": "sgrondare",
    "sgrondasser": "sgrondare",
    "sgrondassero": "sgrondare",
    "sgrondassi": "sgrondare",
    "sgrondassimo": "sgrondare",
    "sgrondaste": "sgrondare",
    "sgrondasti": "sgrondare",
    "sgrondata": "sgrondare",
    "sgrondate": "sgrondare",
    "sgrondati": "sgrondare",
    "sgrondato": "sgrondare",
    "sgrondava": "sgrondare",
    "sgrondavamo": "sgrondare",
    "sgrondavan": "sgrondare",
    "sgrondavano": "sgrondare",
    "sgrondavate": "sgrondare",
    "sgrondavi": "sgrondare",
    "sgrondavo": "sgrondare",
    "sgronderai": "sgrondare",
    "sgronderan": "sgrondare",
    "sgronderanno": "sgrondare",
    "sgronderebbe": "sgrondare",
    "sgronderebber": "sgrondare",
    "sgronderebbero": "sgrondare",
    "sgronderei": "sgrondare",
    "sgronderemmo": "sgrondare",
    "sgronderemo": "sgrondare",
    "sgrondereste": "sgrondare",
    "sgronderesti": "sgrondare",
    "sgronderete": "sgrondare",
    "sgronderà": "sgrondare",
    "sgronderò": "sgrondare",
    "sgrondi": "sgrondare",
    "sgrondiamo": "sgrondare",
    "sgrondiate": "sgrondare",
    "sgrondin": "sgrondare",
    "sgrondino": "sgrondare",
    "sgrondo": "sgrondare",
    "sgrondò": "sgrondare",
    "sgroppa": "sgroppare",
    "sgroppai": "sgroppare",
    "sgroppammo": "sgroppare",
    "sgroppan": "sgroppare",
    "sgroppando": "sgroppare",
    "sgroppano": "sgroppare",
    "sgroppante": "sgroppare",
    "sgroppanti": "sgroppare",
    "sgroppar": "sgroppare",
    "sgropparon": "sgroppare",
    "sgropparono": "sgroppare",
    "sgroppasse": "sgroppare",
    "sgroppasser": "sgroppare",
    "sgroppassero": "sgroppare",
    "sgroppassi": "sgroppare",
    "sgroppassimo": "sgroppare",
    "sgroppaste": "sgroppare",
    "sgroppasti": "sgroppare",
    "sgroppata": "sgroppare",
    "sgroppate": "sgroppata",
    "sgroppati": "sgroppare",
    "sgroppato": "sgroppare",
    "sgroppava": "sgroppare",
    "sgroppavamo": "sgroppare",
    "sgroppavan": "sgroppare",
    "sgroppavano": "sgroppare",
    "sgroppavate": "sgroppare",
    "sgroppavi": "sgroppare",
    "sgroppavo": "sgroppare",
    "sgropperai": "sgroppare",
    "sgropperan": "sgroppare",
    "sgropperanno": "sgroppare",
    "sgropperebbe": "sgroppare",
    "sgropperebber": "sgroppare",
    "sgropperebbero": "sgroppare",
    "sgropperei": "sgroppare",
    "sgropperemmo": "sgroppare",
    "sgropperemo": "sgroppare",
    "sgroppereste": "sgroppare",
    "sgropperesti": "sgroppare",
    "sgropperete": "sgroppare",
    "sgropperà": "sgroppare",
    "sgropperò": "sgroppare",
    "sgroppi": "sgroppare",
    "sgroppiamo": "sgroppare",
    "sgroppiate": "sgroppare",
    "sgroppin": "sgroppare",
    "sgroppino": "sgroppare",
    "sgroppo": "sgroppare",
    "sgroppona": "sgropponare",
    "sgropponai": "sgropponare",
    "sgropponammo": "sgropponare",
    "sgropponan": "sgropponare",
    "sgropponando": "sgropponare",
    "sgropponano": "sgropponare",
    "sgropponante": "sgropponare",
    "sgropponanti": "sgropponare",
    "sgropponar": "sgropponare",
    "sgropponaron": "sgropponare",
    "sgropponarono": "sgropponare",
    "sgropponasse": "sgropponare",
    "sgropponasser": "sgropponare",
    "sgropponassero": "sgropponare",
    "sgropponassi": "sgropponare",
    "sgropponassimo": "sgropponare",
    "sgropponaste": "sgropponare",
    "sgropponasti": "sgropponare",
    "sgropponata": "sgropponare",
    "sgropponate": "sgropponare",
    "sgropponati": "sgropponare",
    "sgropponato": "sgropponare",
    "sgropponava": "sgropponare",
    "sgropponavamo": "sgropponare",
    "sgropponavan": "sgropponare",
    "sgropponavano": "sgropponare",
    "sgropponavate": "sgropponare",
    "sgropponavi": "sgropponare",
    "sgropponavo": "sgropponare",
    "sgropponerai": "sgropponare",
    "sgropponeran": "sgropponare",
    "sgropponeranno": "sgropponare",
    "sgropponerebbe": "sgropponare",
    "sgropponerebber": "sgropponare",
    "sgropponerebbero": "sgropponare",
    "sgropponerei": "sgropponare",
    "sgropponeremmo": "sgropponare",
    "sgropponeremo": "sgropponare",
    "sgropponereste": "sgropponare",
    "sgropponeresti": "sgropponare",
    "sgropponerete": "sgropponare",
    "sgropponerà": "sgropponare",
    "sgropponerò": "sgropponare",
    "sgropponi": "sgropponare",
    "sgropponiamo": "sgropponare",
    "sgropponiate": "sgropponare",
    "sgropponin": "sgropponare",
    "sgropponino": "sgropponare",
    "sgroppono": "sgropponare",
    "sgropponò": "sgropponare",
    "sgroppò": "sgroppare",
    "sgrossa": "sgrossare",
    "sgrossai": "sgrossare",
    "sgrossammo": "sgrossare",
    "sgrossan": "sgrossare",
    "sgrossando": "sgrossare",
    "sgrossano": "sgrossare",
    "sgrossante": "sgrossare",
    "sgrossanti": "sgrossare",
    "sgrossar": "sgrossare",
    "sgrossaron": "sgrossare",
    "sgrossarono": "sgrossare",
    "sgrossasse": "sgrossare",
    "sgrossasser": "sgrossare",
    "sgrossassero": "sgrossare",
    "sgrossassi": "sgrossare",
    "sgrossassimo": "sgrossare",
    "sgrossaste": "sgrossare",
    "sgrossasti": "sgrossare",
    "sgrossata": "sgrossare",
    "sgrossate": "sgrossare",
    "sgrossati": "sgrossare",
    "sgrossato": "sgrossare",
    "sgrossava": "sgrossare",
    "sgrossavamo": "sgrossare",
    "sgrossavan": "sgrossare",
    "sgrossavano": "sgrossare",
    "sgrossavate": "sgrossare",
    "sgrossavi": "sgrossare",
    "sgrossavo": "sgrossare",
    "sgrosserai": "sgrossare",
    "sgrosseran": "sgrossare",
    "sgrosseranno": "sgrossare",
    "sgrosserebbe": "sgrossare",
    "sgrosserebber": "sgrossare",
    "sgrosserebbero": "sgrossare",
    "sgrosserei": "sgrossare",
    "sgrosseremmo": "sgrossare",
    "sgrosseremo": "sgrossare",
    "sgrossereste": "sgrossare",
    "sgrosseresti": "sgrossare",
    "sgrosserete": "sgrossare",
    "sgrosserà": "sgrossare",
    "sgrosserò": "sgrossare",
    "sgrossi": "sgrossare",
    "sgrossiamo": "sgrossare",
    "sgrossiate": "sgrossare",
    "sgrossin": "sgrossare",
    "sgrossino": "sgrossare",
    "sgrosso": "sgrossare",
    "sgrossò": "sgrossare",
    "sgrovigli": "sgrovigliare",
    "sgroviglia": "sgrovigliare",
    "sgrovigliai": "sgrovigliare",
    "sgrovigliammo": "sgrovigliare",
    "sgrovigliamo": "sgrovigliare",
    "sgroviglian": "sgrovigliare",
    "sgrovigliando": "sgrovigliare",
    "sgrovigliano": "sgrovigliare",
    "sgrovigliante": "sgrovigliare",
    "sgroviglianti": "sgrovigliare",
    "sgrovigliar": "sgrovigliare",
    "sgrovigliaron": "sgrovigliare",
    "sgrovigliarono": "sgrovigliare",
    "sgrovigliasse": "sgrovigliare",
    "sgrovigliasser": "sgrovigliare",
    "sgrovigliassero": "sgrovigliare",
    "sgrovigliassi": "sgrovigliare",
    "sgrovigliassimo": "sgrovigliare",
    "sgrovigliaste": "sgrovigliare",
    "sgrovigliasti": "sgrovigliare",
    "sgrovigliata": "sgrovigliare",
    "sgrovigliate": "sgrovigliare",
    "sgrovigliati": "sgrovigliare",
    "sgrovigliato": "sgrovigliare",
    "sgrovigliava": "sgrovigliare",
    "sgrovigliavamo": "sgrovigliare",
    "sgrovigliavan": "sgrovigliare",
    "sgrovigliavano": "sgrovigliare",
    "sgrovigliavate": "sgrovigliare",
    "sgrovigliavi": "sgrovigliare",
    "sgrovigliavo": "sgrovigliare",
    "sgroviglierai": "sgrovigliare",
    "sgroviglieran": "sgrovigliare",
    "sgroviglieranno": "sgrovigliare",
    "sgroviglierebbe": "sgrovigliare",
    "sgroviglierebber": "sgrovigliare",
    "sgroviglierebbero": "sgrovigliare",
    "sgroviglierei": "sgrovigliare",
    "sgroviglieremmo": "sgrovigliare",
    "sgroviglieremo": "sgrovigliare",
    "sgrovigliereste": "sgrovigliare",
    "sgroviglieresti": "sgrovigliare",
    "sgroviglierete": "sgrovigliare",
    "sgroviglierà": "sgrovigliare",
    "sgroviglierò": "sgrovigliare",
    "sgroviglin": "sgrovigliare",
    "sgroviglino": "sgrovigliare",
    "sgroviglio": "sgrovigliare",
    "sgrovigliò": "sgrovigliare",
    "sguaiata": "sguaiato",
    "sguaiate": "sguaiato",
    "sguaiati": "sguaiato",
    "sguaina": "sguainare",
    "sguainai": "sguainare",
    "sguainammo": "sguainare",
    "sguainan": "sguainare",
    "sguainando": "sguainare",
    "sguainano": "sguainare",
    "sguainante": "sguainare",
    "sguainanti": "sguainare",
    "sguainar": "sguainare",
    "sguainaron": "sguainare",
    "sguainarono": "sguainare",
    "sguainasse": "sguainare",
    "sguainasser": "sguainare",
    "sguainassero": "sguainare",
    "sguainassi": "sguainare",
    "sguainassimo": "sguainare",
    "sguainaste": "sguainare",
    "sguainasti": "sguainare",
    "sguainata": "sguainare",
    "sguainate": "sguainare",
    "sguainati": "sguainare",
    "sguainato": "sguainare",
    "sguainava": "sguainare",
    "sguainavamo": "sguainare",
    "sguainavan": "sguainare",
    "sguainavano": "sguainare",
    "sguainavate": "sguainare",
    "sguainavi": "sguainare",
    "sguainavo": "sguainare",
    "sguainerai": "sguainare",
    "sguaineran": "sguainare",
    "sguaineranno": "sguainare",
    "sguainerebbe": "sguainare",
    "sguainerebber": "sguainare",
    "sguainerebbero": "sguainare",
    "sguainerei": "sguainare",
    "sguaineremmo": "sguainare",
    "sguaineremo": "sguainare",
    "sguainereste": "sguainare",
    "sguaineresti": "sguainare",
    "sguainerete": "sguainare",
    "sguainerà": "sguainare",
    "sguainerò": "sguainare",
    "sguaini": "sguainare",
    "sguainiamo": "sguainare",
    "sguainiate": "sguainare",
    "sguainin": "sguainare",
    "sguainino": "sguainare",
    "sguaino": "sguainare",
    "sguainò": "sguainare",
    "sgualca": "sgualcire",
    "sgualcan": "sgualcire",
    "sgualcano": "sgualcire",
    "sgualce": "sgualcire",
    "sgualcendo": "sgualcire",
    "sgualcente": "sgualcire",
    "sgualcenti": "sgualcire",
    "sgualci": "sgualcire",
    "sgualciamo": "sgualcire",
    "sgualciate": "sgualcire",
    "sgualcii": "sgualcire",
    "sgualcimmo": "sgualcire",
    "sgualcir": "sgualcire",
    "sgualcirai": "sgualcire",
    "sgualciran": "sgualcire",
    "sgualciranno": "sgualcire",
    "sgualcirebbe": "sgualcire",
    "sgualcirebber": "sgualcire",
    "sgualcirebbero": "sgualcire",
    "sgualcirei": "sgualcire",
    "sgualciremmo": "sgualcire",
    "sgualciremo": "sgualcire",
    "sgualcireste": "sgualcire",
    "sgualciresti": "sgualcire",
    "sgualcirete": "sgualcire",
    "sgualciron": "sgualcire",
    "sgualcirono": "sgualcire",
    "sgualcirà": "sgualcire",
    "sgualcirò": "sgualcire",
    "sgualcisse": "sgualcire",
    "sgualcisser": "sgualcire",
    "sgualcissero": "sgualcire",
    "sgualcissi": "sgualcire",
    "sgualcissimo": "sgualcire",
    "sgualciste": "sgualcire",
    "sgualcisti": "sgualcire",
    "sgualcita": "sgualcire",
    "sgualcite": "sgualcire",
    "sgualciti": "sgualcire",
    "sgualcito": "sgualcire",
    "sgualciva": "sgualcire",
    "sgualcivamo": "sgualcire",
    "sgualcivan": "sgualcire",
    "sgualcivano": "sgualcire",
    "sgualcivate": "sgualcire",
    "sgualcivi": "sgualcire",
    "sgualcivo": "sgualcire",
    "sgualco": "sgualcire",
    "sgualcon": "sgualcire",
    "sgualcono": "sgualcire",
    "sgualcì": "sgualcire",
    "sguardi": "sguardo",
    "sguarnendo": "sguarnire",
    "sguarnente": "sguarnire",
    "sguarnenti": "sguarnire",
    "sguarniamo": "sguarnire",
    "sguarniate": "sguarnire",
    "sguarnii": "sguarnire",
    "sguarnimmo": "sguarnire",
    "sguarnir": "sguarnire",
    "sguarnirai": "sguarnire",
    "sguarniran": "sguarnire",
    "sguarniranno": "sguarnire",
    "sguarnirebbe": "sguarnire",
    "sguarnirebber": "sguarnire",
    "sguarnirebbero": "sguarnire",
    "sguarnirei": "sguarnire",
    "sguarniremmo": "sguarnire",
    "sguarniremo": "sguarnire",
    "sguarnireste": "sguarnire",
    "sguarniresti": "sguarnire",
    "sguarnirete": "sguarnire",
    "sguarniron": "sguarnire",
    "sguarnirono": "sguarnire",
    "sguarnirà": "sguarnire",
    "sguarnirò": "sguarnire",
    "sguarnisca": "sguarnire",
    "sguarniscan": "sguarnire",
    "sguarniscano": "sguarnire",
    "sguarnisce": "sguarnire",
    "sguarnisci": "sguarnire",
    "sguarnisco": "sguarnire",
    "sguarniscon": "sguarnire",
    "sguarniscono": "sguarnire",
    "sguarnisse": "sguarnire",
    "sguarnisser": "sguarnire",
    "sguarnissero": "sguarnire",
    "sguarnissi": "sguarnire",
    "sguarnissimo": "sguarnire",
    "sguarniste": "sguarnire",
    "sguarnisti": "sguarnire",
    "sguarnita": "sguarnire",
    "sguarnite": "sguarnire",
    "sguarniti": "sguarnire",
    "sguarnito": "sguarnire",
    "sguarniva": "sguarnire",
    "sguarnivamo": "sguarnire",
    "sguarnivan": "sguarnire",
    "sguarnivano": "sguarnire",
    "sguarnivate": "sguarnire",
    "sguarnivi": "sguarnire",
    "sguarnivo": "sguarnire",
    "sguarnì": "sguarnire",
    "sguazza": "sguazzare",
    "sguazzai": "sguazzare",
    "sguazzammo": "sguazzare",
    "sguazzan": "sguazzare",
    "sguazzando": "sguazzare",
    "sguazzano": "sguazzare",
    "sguazzante": "sguazzare",
    "sguazzanti": "sguazzare",
    "sguazzar": "sguazzare",
    "sguazzaron": "sguazzare",
    "sguazzarono": "sguazzare",
    "sguazzasse": "sguazzare",
    "sguazzasser": "sguazzare",
    "sguazzassero": "sguazzare",
    "sguazzassi": "sguazzare",
    "sguazzassimo": "sguazzare",
    "sguazzaste": "sguazzare",
    "sguazzasti": "sguazzare",
    "sguazzata": "sguazzare",
    "sguazzate": "sguazzare",
    "sguazzati": "sguazzare",
    "sguazzato": "sguazzare",
    "sguazzava": "sguazzare",
    "sguazzavamo": "sguazzare",
    "sguazzavan": "sguazzare",
    "sguazzavano": "sguazzare",
    "sguazzavate": "sguazzare",
    "sguazzavi": "sguazzare",
    "sguazzavo": "sguazzare",
    "sguazzerai": "sguazzare",
    "sguazzeran": "sguazzare",
    "sguazzeranno": "sguazzare",
    "sguazzerebbe": "sguazzare",
    "sguazzerebber": "sguazzare",
    "sguazzerebbero": "sguazzare",
    "sguazzerei": "sguazzare",
    "sguazzeremmo": "sguazzare",
    "sguazzeremo": "sguazzare",
    "sguazzereste": "sguazzare",
    "sguazzeresti": "sguazzare",
    "sguazzerete": "sguazzare",
    "sguazzerà": "sguazzare",
    "sguazzerò": "sguazzare",
    "sguazzi": "sguazzare",
    "sguazziamo": "sguazzare",
    "sguazziate": "sguazzare",
    "sguazzin": "sguazzare",
    "sguazzino": "sguazzare",
    "sguazzo": "sguazzare",
    "sguazzò": "sguazzare",
    "sguinzagli": "sguinzagliare",
    "sguinzaglia": "sguinzagliare",
    "sguinzagliai": "sguinzagliare",
    "sguinzagliammo": "sguinzagliare",
    "sguinzagliamo": "sguinzagliare",
    "sguinzaglian": "sguinzagliare",
    "sguinzagliando": "sguinzagliare",
    "sguinzagliano": "sguinzagliare",
    "sguinzagliante": "sguinzagliare",
    "sguinzaglianti": "sguinzagliare",
    "sguinzagliar": "sguinzagliare",
    "sguinzagliaron": "sguinzagliare",
    "sguinzagliarono": "sguinzagliare",
    "sguinzagliasse": "sguinzagliare",
    "sguinzagliasser": "sguinzagliare",
    "sguinzagliassero": "sguinzagliare",
    "sguinzagliassi": "sguinzagliare",
    "sguinzagliassimo": "sguinzagliare",
    "sguinzagliaste": "sguinzagliare",
    "sguinzagliasti": "sguinzagliare",
    "sguinzagliata": "sguinzagliare",
    "sguinzagliate": "sguinzagliare",
    "sguinzagliati": "sguinzagliare",
    "sguinzagliato": "sguinzagliare",
    "sguinzagliava": "sguinzagliare",
    "sguinzagliavamo": "sguinzagliare",
    "sguinzagliavan": "sguinzagliare",
    "sguinzagliavano": "sguinzagliare",
    "sguinzagliavate": "sguinzagliare",
    "sguinzagliavi": "sguinzagliare",
    "sguinzagliavo": "sguinzagliare",
    "sguinzaglierai": "sguinzagliare",
    "sguinzaglieran": "sguinzagliare",
    "sguinzaglieranno": "sguinzagliare",
    "sguinzaglierebbe": "sguinzagliare",
    "sguinzaglierebber": "sguinzagliare",
    "sguinzaglierebbero": "sguinzagliare",
    "sguinzaglierei": "sguinzagliare",
    "sguinzaglieremmo": "sguinzagliare",
    "sguinzaglieremo": "sguinzagliare",
    "sguinzagliereste": "sguinzagliare",
    "sguinzaglieresti": "sguinzagliare",
    "sguinzaglierete": "sguinzagliare",
    "sguinzaglierà": "sguinzagliare",
    "sguinzaglierò": "sguinzagliare",
    "sguinzaglin": "sguinzagliare",
    "sguinzaglino": "sguinzagliare",
    "sguinzaglio": "sguinzagliare",
    "sguinzagliò": "sguinzagliare",
    "sguiscerai": "sguisciare",
    "sguisceran": "sguisciare",
    "sguisceranno": "sguisciare",
    "sguiscerebbe": "sguisciare",
    "sguiscerebber": "sguisciare",
    "sguiscerebbero": "sguisciare",
    "sguiscerei": "sguisciare",
    "sguisceremmo": "sguisciare",
    "sguisceremo": "sguisciare",
    "sguiscereste": "sguisciare",
    "sguisceresti": "sguisciare",
    "sguiscerete": "sguisciare",
    "sguiscerà": "sguisciare",
    "sguiscerò": "sguisciare",
    "sguisci": "sguisciare",
    "sguiscia": "sguisciare",
    "sguisciai": "sguisciare",
    "sguisciammo": "sguisciare",
    "sguisciamo": "sguisciare",
    "sguiscian": "sguisciare",
    "sguisciando": "sguisciare",
    "sguisciano": "sguisciare",
    "sguisciante": "sguisciare",
    "sguiscianti": "sguisciare",
    "sguisciar": "sguisciare",
    "sguisciaron": "sguisciare",
    "sguisciarono": "sguisciare",
    "sguisciasse": "sguisciare",
    "sguisciasser": "sguisciare",
    "sguisciassero": "sguisciare",
    "sguisciassi": "sguisciare",
    "sguisciassimo": "sguisciare",
    "sguisciaste": "sguisciare",
    "sguisciasti": "sguisciare",
    "sguisciata": "sguisciare",
    "sguisciate": "sguisciare",
    "sguisciati": "sguisciare",
    "sguisciato": "sguisciare",
    "sguisciava": "sguisciare",
    "sguisciavamo": "sguisciare",
    "sguisciavan": "sguisciare",
    "sguisciavano": "sguisciare",
    "sguisciavate": "sguisciare",
    "sguisciavi": "sguisciare",
    "sguisciavo": "sguisciare",
    "sguiscin": "sguisciare",
    "sguiscino": "sguisciare",
    "sguiscio": "sguisciare",
    "sguisciò": "sguisciare",
    "sguscerai": "sgusciare",
    "sgusceran": "sgusciare",
    "sgusceranno": "sgusciare",
    "sguscerebbe": "sgusciare",
    "sguscerebber": "sgusciare",
    "sguscerebbero": "sgusciare",
    "sguscerei": "sgusciare",
    "sgusceremmo": "sgusciare",
    "sgusceremo": "sgusciare",
    "sguscereste": "sgusciare",
    "sgusceresti": "sgusciare",
    "sguscerete": "sgusciare",
    "sguscerà": "sgusciare",
    "sguscerò": "sgusciare",
    "sgusci": "sgusciare",
    "sguscia": "sgusciare",
    "sgusciai": "sgusciare",
    "sgusciammo": "sgusciare",
    "sgusciamo": "sgusciare",
    "sguscian": "sgusciare",
    "sgusciando": "sgusciare",
    "sgusciano": "sgusciare",
    "sgusciante": "sgusciare",
    "sguscianti": "sgusciare",
    "sgusciar": "sgusciare",
    "sgusciaron": "sgusciare",
    "sgusciarono": "sgusciare",
    "sgusciasse": "sgusciare",
    "sgusciasser": "sgusciare",
    "sgusciassero": "sgusciare",
    "sgusciassi": "sgusciare",
    "sgusciassimo": "sgusciare",
    "sgusciaste": "sgusciare",
    "sgusciasti": "sgusciare",
    "sgusciata": "sgusciare",
    "sgusciate": "sgusciare",
    "sgusciati": "sgusciare",
    "sgusciato": "sgusciare",
    "sgusciava": "sgusciare",
    "sgusciavamo": "sgusciare",
    "sgusciavan": "sgusciare",
    "sgusciavano": "sgusciare",
    "sgusciavate": "sgusciare",
    "sgusciavi": "sgusciare",
    "sgusciavo": "sgusciare",
    "sguscin": "sgusciare",
    "sguscino": "sgusciare",
    "sguscio": "sgusciare",
    "sgusciò": "sgusciare",
    "sharie": "sharia",
    "shocca": "shoccare",
    "shoccai": "shoccare",
    "shoccammo": "shoccare",
    "shoccan": "shoccare",
    "shoccando": "shoccare",
    "shoccano": "shoccare",
    "shoccante": "shoccare",
    "shoccanti": "shoccare",
    "shoccar": "shoccare",
    "shoccaron": "shoccare",
    "shoccarono": "shoccare",
    "shoccasse": "shoccare",
    "shoccasser": "shoccare",
    "shoccassero": "shoccare",
    "shoccassi": "shoccare",
    "shoccassimo": "shoccare",
    "shoccaste": "shoccare",
    "shoccasti": "shoccare",
    "shoccata": "shoccare",
    "shoccate": "shoccare",
    "shoccati": "shoccare",
    "shoccato": "shoccare",
    "shoccava": "shoccare",
    "shoccavamo": "shoccare",
    "shoccavan": "shoccare",
    "shoccavano": "shoccare",
    "shoccavate": "shoccare",
    "shoccavi": "shoccare",
    "shoccavo": "shoccare",
    "shoccherai": "shoccare",
    "shoccheran": "shoccare",
    "shoccheranno": "shoccare",
    "shoccherebbe": "shoccare",
    "shoccherebber": "shoccare",
    "shoccherebbero": "shoccare",
    "shoccherei": "shoccare",
    "shoccheremmo": "shoccare",
    "shoccheremo": "shoccare",
    "shocchereste": "shoccare",
    "shoccheresti": "shoccare",
    "shoccherete": "shoccare",
    "shoccherà": "shoccare",
    "shoccherò": "shoccare",
    "shocchi": "shoccare",
    "shocchiamo": "shoccare",
    "shocchiate": "shoccare",
    "shocchin": "shoccare",
    "shocchino": "shoccare",
    "shocco": "shoccare",
    "shoccò": "shoccare",
    "shocka": "shockare",
    "shockai": "shockare",
    "shockammo": "shockare",
    "shockan": "shockare",
    "shockando": "shockare",
    "shockano": "shockare",
    "shockante": "shockare",
    "shockanti": "shockare",
    "shockar": "shockare",
    "shockaron": "shockare",
    "shockarono": "shockare",
    "shockasse": "shockare",
    "shockasser": "shockare",
    "shockassero": "shockare",
    "shockassi": "shockare",
    "shockassimo": "shockare",
    "shockaste": "shockare",
    "shockasti": "shockare",
    "shockata": "shockare",
    "shockate": "shockare",
    "shockati": "shockare",
    "shockato": "shockare",
    "shockava": "shockare",
    "shockavamo": "shockare",
    "shockavan": "shockare",
    "shockavano": "shockare",
    "shockavate": "shockare",
    "shockavi": "shockare",
    "shockavo": "shockare",
    "shockerai": "shockare",
    "shockeran": "shockare",
    "shockeranno": "shockare",
    "shockerebbe": "shockare",
    "shockerebber": "shockare",
    "shockerebbero": "shockare",
    "shockerei": "shockare",
    "shockeremmo": "shockare",
    "shockeremo": "shockare",
    "shockereste": "shockare",
    "shockeresti": "shockare",
    "shockerete": "shockare",
    "shockerà": "shockare",
    "shockerò": "shockare",
    "shocki": "shockare",
    "shockiamo": "shockare",
    "shockiate": "shockare",
    "shockin": "shockare",
    "shockino": "shockare",
    "shocko": "shockare",
    "shockò": "shockare",
    "showmen": "showman",
    "sia": "essere",
    "siamesi": "siamese",
    "siamo": "essere",
    "sian": "essere",
    "siano": "essere",
    "siate": "essere",
    "siberiana": "siberiano",
    "siberiane": "siberiano",
    "siberiani": "siberiano",
    "sibila": "sibilare",
    "sibilai": "sibilare",
    "sibilammo": "sibilare",
    "sibilan": "sibilare",
    "sibilando": "sibilare",
    "sibilano": "sibilare",
    "sibilante": "sibilare",
    "sibilanti": "sibilare",
    "sibilar": "sibilare",
    "sibilaron": "sibilare",
    "sibilarono": "sibilare",
    "sibilasse": "sibilare",
    "sibilasser": "sibilare",
    "sibilassero": "sibilare",
    "sibilassi": "sibilare",
    "sibilassimo": "sibilare",
    "sibilaste": "sibilare",
    "sibilasti": "sibilare",
    "sibilata": "sibilare",
    "sibilate": "sibilare",
    "sibilati": "sibilare",
    "sibilato": "sibilare",
    "sibilava": "sibilare",
    "sibilavamo": "sibilare",
    "sibilavan": "sibilare",
    "sibilavano": "sibilare",
    "sibilavate": "sibilare",
    "sibilavi": "sibilare",
    "sibilavo": "sibilare",
    "sibilerai": "sibilare",
    "sibileran": "sibilare",
    "sibileranno": "sibilare",
    "sibilerebbe": "sibilare",
    "sibilerebber": "sibilare",
    "sibilerebbero": "sibilare",
    "sibilerei": "sibilare",
    "sibileremmo": "sibilare",
    "sibileremo": "sibilare",
    "sibilereste": "sibilare",
    "sibileresti": "sibilare",
    "sibilerete": "sibilare",
    "sibilerà": "sibilare",
    "sibilerò": "sibilare",
    "sibili": "sibilo",
    "sibiliamo": "sibilare",
    "sibiliate": "sibilare",
    "sibilin": "sibilare",
    "sibilino": "sibilare",
    "sibillina": "sibillino",
    "sibilline": "sibillino",
    "sibillini": "sibillino",
    "sibilo": "sibilare",
    "sibilò": "sibilare",
    "sicari": "sicario",
    "siccitosa": "siccitoso",
    "siccitose": "siccitoso",
    "siccitosi": "siccitoso",
    "siciliana": "siciliano",
    "siciliane": "siciliano",
    "siciliani": "siciliano",
    "sicula": "siculo",
    "sicule": "siculo",
    "siculi": "siculo",
    "siculo-americana": "siculo-americano",
    "siculo-americane": "siculo-americano",
    "siculo-americani": "siculo-americano",
    "sicumere": "sicumera",
    "sicura": "sicuro",
    "sicure": "sicuro",
    "sicurezze": "sicurezza",
    "sicuri": "sicuro",
    "siderali": "siderale",
    "siderurgica": "siderurgico",
    "siderurgiche": "siderurgico",
    "siderurgici": "siderurgico",
    "siderurgie": "siderurgia",
    "sieda": "sedere",
    "siedano": "soprassedere",
    "siede": "sedere",
    "siederai": "soprassedere",
    "siederanno": "soprassedere",
    "siederebbe": "soprassedere",
    "siederebbero": "soprassedere",
    "siederei": "soprassedere",
    "siederemmo": "soprassedere",
    "siederemo": "soprassedere",
    "siedereste": "soprassedere",
    "siederesti": "soprassedere",
    "siederete": "soprassedere",
    "siederà": "soprassedere",
    "siederò": "soprassedere",
    "siedete": "soprassedere",
    "siedeva": "soprassedere",
    "siedevamo": "soprassedere",
    "siedevano": "soprassedere",
    "siedevate": "soprassedere",
    "siedevi": "soprassedere",
    "siedevo": "soprassedere",
    "siedi": "sedere",
    "siediamo": "soprassedere",
    "siediate": "soprassedere",
    "siedo": "sedere",
    "siedon": "sedere",
    "siedono": "sedere",
    "siepi": "siepe",
    "sieri": "siero",
    "sieropositiva": "sieropositivo",
    "sieropositive": "sieropositivo",
    "sieropositivi": "sieropositivo",
    "sieste": "siesta",
    "siete": "essere",
    "siffatta": "siffatto",
    "siffatte": "siffatto",
    "siffatti": "siffatto",
    "sifilitica": "sifilitico",
    "sifilitiche": "sifilitico",
    "sifilitici": "sifilitico",
    "sifoni": "sifone",
    "sigaraie": "sigaraia",
    "sigarette": "sigaretta",
    "sigari": "sigaro",
    "sigilla": "sigillare",
    "sigillai": "sigillare",
    "sigillammo": "sigillare",
    "sigillan": "sigillare",
    "sigillando": "sigillare",
    "sigillano": "sigillare",
    "sigillante": "sigillare",
    "sigillanti": "sigillare",
    "sigillar": "sigillare",
    "sigillaron": "sigillare",
    "sigillarono": "sigillare",
    "sigillasse": "sigillare",
    "sigillasser": "sigillare",
    "sigillassero": "sigillare",
    "sigillassi": "sigillare",
    "sigillassimo": "sigillare",
    "sigillaste": "sigillare",
    "sigillasti": "sigillare",
    "sigillata": "sigillare",
    "sigillate": "sigillare",
    "sigillati": "sigillare",
    "sigillato": "sigillare",
    "sigillava": "sigillare",
    "sigillavamo": "sigillare",
    "sigillavan": "sigillare",
    "sigillavano": "sigillare",
    "sigillavate": "sigillare",
    "sigillavi": "sigillare",
    "sigillavo": "sigillare",
    "sigillerai": "sigillare",
    "sigilleran": "sigillare",
    "sigilleranno": "sigillare",
    "sigillerebbe": "sigillare",
    "sigillerebber": "sigillare",
    "sigillerebbero": "sigillare",
    "sigillerei": "sigillare",
    "sigilleremmo": "sigillare",
    "sigilleremo": "sigillare",
    "sigillereste": "sigillare",
    "sigilleresti": "sigillare",
    "sigillerete": "sigillare",
    "sigillerà": "sigillare",
    "sigillerò": "sigillare",
    "sigilli": "sigillo",
    "sigilliamo": "sigillare",
    "sigilliate": "sigillare",
    "sigillin": "sigillare",
    "sigillino": "sigillare",
    "sigillo": "sigillare",
    "sigillò": "sigillare",
    "sigla": "siglare",
    "siglai": "siglare",
    "siglammo": "siglare",
    "siglan": "siglare",
    "siglando": "siglare",
    "siglano": "siglare",
    "siglante": "siglare",
    "siglanti": "siglare",
    "siglar": "siglare",
    "siglaron": "siglare",
    "siglarono": "siglare",
    "siglasse": "siglare",
    "siglasser": "siglare",
    "siglassero": "siglare",
    "siglassi": "siglare",
    "siglassimo": "siglare",
    "siglaste": "siglare",
    "siglasti": "siglare",
    "siglata": "siglare",
    "siglate": "siglare",
    "siglati": "siglare",
    "siglato": "siglare",
    "siglava": "siglare",
    "siglavamo": "siglare",
    "siglavan": "siglare",
    "siglavano": "siglare",
    "siglavate": "siglare",
    "siglavi": "siglare",
    "siglavo": "siglare",
    "sigle": "sigla",
    "siglerai": "siglare",
    "sigleran": "siglare",
    "sigleranno": "siglare",
    "siglerebbe": "siglare",
    "siglerebber": "siglare",
    "siglerebbero": "siglare",
    "siglerei": "siglare",
    "sigleremmo": "siglare",
    "sigleremo": "siglare",
    "siglereste": "siglare",
    "sigleresti": "siglare",
    "siglerete": "siglare",
    "siglerà": "siglare",
    "siglerò": "siglare",
    "sigli": "siglare",
    "sigliamo": "siglare",
    "sigliate": "siglare",
    "siglin": "siglare",
    "siglino": "siglare",
    "siglo": "siglare",
    "siglò": "siglare",
    "significa": "significare",
    "significai": "significare",
    "significammo": "significare",
    "significan": "significare",
    "significando": "significare",
    "significano": "significare",
    "significante": "significare",
    "significanti": "significare",
    "significar": "significare",
    "significaron": "significare",
    "significarono": "significare",
    "significasse": "significare",
    "significasser": "significare",
    "significassero": "significare",
    "significassi": "significare",
    "significassimo": "significare",
    "significaste": "significare",
    "significasti": "significare",
    "significata": "significare",
    "significate": "significare",
    "significati": "significato",
    "significativa": "significativo",
    "significative": "significativo",
    "significativi": "significativo",
    "significato": "significare",
    "significava": "significare",
    "significavamo": "significare",
    "significavan": "significare",
    "significavano": "significare",
    "significavate": "significare",
    "significavi": "significare",
    "significavo": "significare",
    "significazioni": "significazione",
    "significherai": "significare",
    "significheran": "significare",
    "significheranno": "significare",
    "significherebbe": "significare",
    "significherebber": "significare",
    "significherebbero": "significare",
    "significherei": "significare",
    "significheremmo": "significare",
    "significheremo": "significare",
    "significhereste": "significare",
    "significheresti": "significare",
    "significherete": "significare",
    "significherà": "significare",
    "significherò": "significare",
    "significhi": "significare",
    "significhiamo": "significare",
    "significhiate": "significare",
    "significhin": "significare",
    "significhino": "significare",
    "significo": "significare",
    "significò": "significare",
    "signor": "signore",
    "signore": "signora",
    "signoreggerai": "signoreggiare",
    "signoreggeran": "signoreggiare",
    "signoreggeranno": "signoreggiare",
    "signoreggerebbe": "signoreggiare",
    "signoreggerebber": "signoreggiare",
    "signoreggerebbero": "signoreggiare",
    "signoreggerei": "signoreggiare",
    "signoreggeremmo": "signoreggiare",
    "signoreggeremo": "signoreggiare",
    "signoreggereste": "signoreggiare",
    "signoreggeresti": "signoreggiare",
    "signoreggerete": "signoreggiare",
    "signoreggerà": "signoreggiare",
    "signoreggerò": "signoreggiare",
    "signoreggi": "signoreggiare",
    "signoreggia": "signoreggiare",
    "signoreggiai": "signoreggiare",
    "signoreggiammo": "signoreggiare",
    "signoreggiamo": "signoreggiare",
    "signoreggian": "signoreggiare",
    "signoreggiando": "signoreggiare",
    "signoreggiano": "signoreggiare",
    "signoreggiante": "signoreggiare",
    "signoreggianti": "signoreggiare",
    "signoreggiar": "signoreggiare",
    "signoreggiaron": "signoreggiare",
    "signoreggiarono": "signoreggiare",
    "signoreggiasse": "signoreggiare",
    "signoreggiasser": "signoreggiare",
    "signoreggiassero": "signoreggiare",
    "signoreggiassi": "signoreggiare",
    "signoreggiassimo": "signoreggiare",
    "signoreggiaste": "signoreggiare",
    "signoreggiasti": "signoreggiare",
    "signoreggiata": "signoreggiare",
    "signoreggiate": "signoreggiare",
    "signoreggiati": "signoreggiare",
    "signoreggiato": "signoreggiare",
    "signoreggiava": "signoreggiare",
    "signoreggiavamo": "signoreggiare",
    "signoreggiavan": "signoreggiare",
    "signoreggiavano": "signoreggiare",
    "signoreggiavate": "signoreggiare",
    "signoreggiavi": "signoreggiare",
    "signoreggiavo": "signoreggiare",
    "signoreggin": "signoreggiare",
    "signoreggino": "signoreggiare",
    "signoreggio": "signoreggiare",
    "signoreggiò": "signoreggiare",
    "signori": "signore",
    "signorie": "signoria",
    "signorili": "signorile",
    "signorine": "signorina",
    "signorini": "signorino",
    "signorotti": "signorotto",
    "sii": "essere",
    "silenti": "silente",
    "silenzi": "silenzio",
    "silenzi-assensi": "silenzio-assenso",
    "silenzi-stampa": "silenzio-stampa",
    "silenzia": "silenziare",
    "silenziai": "silenziare",
    "silenziammo": "silenziare",
    "silenziamo": "silenziare",
    "silenzian": "silenziare",
    "silenziando": "silenziare",
    "silenziano": "silenziare",
    "silenziante": "silenziare",
    "silenzianti": "silenziare",
    "silenziar": "silenziare",
    "silenziaron": "silenziare",
    "silenziarono": "silenziare",
    "silenziasse": "silenziare",
    "silenziasser": "silenziare",
    "silenziassero": "silenziare",
    "silenziassi": "silenziare",
    "silenziassimo": "silenziare",
    "silenziaste": "silenziare",
    "silenziasti": "silenziare",
    "silenziata": "silenziare",
    "silenziate": "silenziare",
    "silenziati": "silenziare",
    "silenziato": "silenziare",
    "silenziatori": "silenziatore",
    "silenziava": "silenziare",
    "silenziavamo": "silenziare",
    "silenziavan": "silenziare",
    "silenziavano": "silenziare",
    "silenziavate": "silenziare",
    "silenziavi": "silenziare",
    "silenziavo": "silenziare",
    "silenzierai": "silenziare",
    "silenzieran": "silenziare",
    "silenzieranno": "silenziare",
    "silenzierebbe": "silenziare",
    "silenzierebber": "silenziare",
    "silenzierebbero": "silenziare",
    "silenzierei": "silenziare",
    "silenzieremmo": "silenziare",
    "silenzieremo": "silenziare",
    "silenziereste": "silenziare",
    "silenzieresti": "silenziare",
    "silenzierete": "silenziare",
    "silenzierà": "silenziare",
    "silenzierò": "silenziare",
    "silenzin": "silenziare",
    "silenzino": "silenziare",
    "silenzio": "silenziare",
    "silenziosa": "silenzioso",
    "silenziose": "silenzioso",
    "silenziosi": "silenzioso",
    "silenziò": "silenziare",
    "silici": "silicio",
    "siliconi": "silicone",
    "sillaba": "sillabare",
    "sillabai": "sillabare",
    "sillabammo": "sillabare",
    "sillaban": "sillabare",
    "sillabando": "sillabare",
    "sillabano": "sillabare",
    "sillabante": "sillabare",
    "sillabanti": "sillabare",
    "sillabar": "sillabare",
    "sillabari": "sillabario",
    "sillabaron": "sillabare",
    "sillabarono": "sillabare",
    "sillabasse": "sillabare",
    "sillabasser": "sillabare",
    "sillabassero": "sillabare",
    "sillabassi": "sillabare",
    "sillabassimo": "sillabare",
    "sillabaste": "sillabare",
    "sillabasti": "sillabare",
    "sillabata": "sillabare",
    "sillabate": "sillabare",
    "sillabati": "sillabare",
    "sillabato": "sillabare",
    "sillabava": "sillabare",
    "sillabavamo": "sillabare",
    "sillabavan": "sillabare",
    "sillabavano": "sillabare",
    "sillabavate": "sillabare",
    "sillabavi": "sillabare",
    "sillabavo": "sillabare",
    "sillabe": "sillaba",
    "sillaberai": "sillabare",
    "sillaberan": "sillabare",
    "sillaberanno": "sillabare",
    "sillaberebbe": "sillabare",
    "sillaberebber": "sillabare",
    "sillaberebbero": "sillabare",
    "sillaberei": "sillabare",
    "sillaberemmo": "sillabare",
    "sillaberemo": "sillabare",
    "sillabereste": "sillabare",
    "sillaberesti": "sillabare",
    "sillaberete": "sillabare",
    "sillaberà": "sillabare",
    "sillaberò": "sillabare",
    "sillabi": "sillabare",
    "sillabiamo": "sillabare",
    "sillabiate": "sillabare",
    "sillabin": "sillabare",
    "sillabino": "sillabare",
    "sillabo": "sillabare",
    "sillabò": "sillabare",
    "sillogi": "silloge",
    "sillogismi": "sillogismo",
    "sillogistica": "sillogistico",
    "sillogistiche": "sillogistico",
    "sillogistici": "sillogistico",
    "sillogizza": "sillogizzare",
    "sillogizzai": "sillogizzare",
    "sillogizzammo": "sillogizzare",
    "sillogizzan": "sillogizzare",
    "sillogizzando": "sillogizzare",
    "sillogizzano": "sillogizzare",
    "sillogizzante": "sillogizzare",
    "sillogizzanti": "sillogizzare",
    "sillogizzar": "sillogizzare",
    "sillogizzaron": "sillogizzare",
    "sillogizzarono": "sillogizzare",
    "sillogizzasse": "sillogizzare",
    "sillogizzasser": "sillogizzare",
    "sillogizzassero": "sillogizzare",
    "sillogizzassi": "sillogizzare",
    "sillogizzassimo": "sillogizzare",
    "sillogizzaste": "sillogizzare",
    "sillogizzasti": "sillogizzare",
    "sillogizzata": "sillogizzare",
    "sillogizzate": "sillogizzare",
    "sillogizzati": "sillogizzare",
    "sillogizzato": "sillogizzare",
    "sillogizzava": "sillogizzare",
    "sillogizzavamo": "sillogizzare",
    "sillogizzavan": "sillogizzare",
    "sillogizzavano": "sillogizzare",
    "sillogizzavate": "sillogizzare",
    "sillogizzavi": "sillogizzare",
    "sillogizzavo": "sillogizzare",
    "sillogizzerai": "sillogizzare",
    "sillogizzeran": "sillogizzare",
    "sillogizzeranno": "sillogizzare",
    "sillogizzerebbe": "sillogizzare",
    "sillogizzerebber": "sillogizzare",
    "sillogizzerebbero": "sillogizzare",
    "sillogizzerei": "sillogizzare",
    "sillogizzeremmo": "sillogizzare",
    "sillogizzeremo": "sillogizzare",
    "sillogizzereste": "sillogizzare",
    "sillogizzeresti": "sillogizzare",
    "sillogizzerete": "sillogizzare",
    "sillogizzerà": "sillogizzare",
    "sillogizzerò": "sillogizzare",
    "sillogizzi": "sillogizzare",
    "sillogizziamo": "sillogizzare",
    "sillogizziate": "sillogizzare",
    "sillogizzin": "sillogizzare",
    "sillogizzino": "sillogizzare",
    "sillogizzo": "sillogizzare",
    "sillogizzò": "sillogizzare",
    "silura": "silurare",
    "silurai": "silurare",
    "siluramenti": "siluramento",
    "silurammo": "silurare",
    "siluran": "silurare",
    "silurando": "silurare",
    "silurano": "silurare",
    "silurante": "silurare",
    "siluranti": "silurare",
    "silurar": "silurare",
    "siluraron": "silurare",
    "silurarono": "silurare",
    "silurasse": "silurare",
    "silurasser": "silurare",
    "silurassero": "silurare",
    "silurassi": "silurare",
    "silurassimo": "silurare",
    "siluraste": "silurare",
    "silurasti": "silurare",
    "silurata": "silurare",
    "silurate": "silurare",
    "silurati": "silurare",
    "silurato": "silurare",
    "silurava": "silurare",
    "siluravamo": "silurare",
    "siluravan": "silurare",
    "siluravano": "silurare",
    "siluravate": "silurare",
    "siluravi": "silurare",
    "siluravo": "silurare",
    "silurerai": "silurare",
    "silureran": "silurare",
    "silureranno": "silurare",
    "silurerebbe": "silurare",
    "silurerebber": "silurare",
    "silurerebbero": "silurare",
    "silurerei": "silurare",
    "silureremmo": "silurare",
    "silureremo": "silurare",
    "silurereste": "silurare",
    "silureresti": "silurare",
    "silurerete": "silurare",
    "silurerà": "silurare",
    "silurerò": "silurare",
    "siluri": "silurare",
    "siluriamo": "silurare",
    "siluriate": "silurare",
    "silurin": "silurare",
    "silurino": "silurare",
    "siluro": "silurare",
    "silurò": "silurare",
    "silvana": "silvano",
    "silvane": "silvano",
    "silvani": "silvano",
    "silvestri": "silvestre",
    "simboleggerai": "simboleggiare",
    "simboleggeran": "simboleggiare",
    "simboleggeranno": "simboleggiare",
    "simboleggerebbe": "simboleggiare",
    "simboleggerebber": "simboleggiare",
    "simboleggerebbero": "simboleggiare",
    "simboleggerei": "simboleggiare",
    "simboleggeremmo": "simboleggiare",
    "simboleggeremo": "simboleggiare",
    "simboleggereste": "simboleggiare",
    "simboleggeresti": "simboleggiare",
    "simboleggerete": "simboleggiare",
    "simboleggerà": "simboleggiare",
    "simboleggerò": "simboleggiare",
    "simboleggi": "simboleggiare",
    "simboleggia": "simboleggiare",
    "simboleggiai": "simboleggiare",
    "simboleggiammo": "simboleggiare",
    "simboleggiamo": "simboleggiare",
    "simboleggian": "simboleggiare",
    "simboleggiando": "simboleggiare",
    "simboleggiano": "simboleggiare",
    "simboleggiante": "simboleggiare",
    "simboleggianti": "simboleggiare",
    "simboleggiar": "simboleggiare",
    "simboleggiaron": "simboleggiare",
    "simboleggiarono": "simboleggiare",
    "simboleggiasse": "simboleggiare",
    "simboleggiasser": "simboleggiare",
    "simboleggiassero": "simboleggiare",
    "simboleggiassi": "simboleggiare",
    "simboleggiassimo": "simboleggiare",
    "simboleggiaste": "simboleggiare",
    "simboleggiasti": "simboleggiare",
    "simboleggiata": "simboleggiare",
    "simboleggiate": "simboleggiare",
    "simboleggiati": "simboleggiare",
    "simboleggiato": "simboleggiare",
    "simboleggiava": "simboleggiare",
    "simboleggiavamo": "simboleggiare",
    "simboleggiavan": "simboleggiare",
    "simboleggiavano": "simboleggiare",
    "simboleggiavate": "simboleggiare",
    "simboleggiavi": "simboleggiare",
    "simboleggiavo": "simboleggiare",
    "simboleggin": "simboleggiare",
    "simboleggino": "simboleggiare",
    "simboleggio": "simboleggiare",
    "simboleggiò": "simboleggiare",
    "simboli": "simbolo",
    "simbolica": "simbolico",
    "simboliche": "simbolico",
    "simbolici": "simbolico",
    "simbolismi": "simbolismo",
    "simboliste": "simbolista",
    "simbolisti": "simbolista",
    "simbolistica": "simbolistico",
    "simbolistiche": "simbolistico",
    "simbolistici": "simbolistico",
    "simbolizza": "simbolizzare",
    "simbolizzai": "simbolizzare",
    "simbolizzammo": "simbolizzare",
    "simbolizzan": "simbolizzare",
    "simbolizzando": "simbolizzare",
    "simbolizzano": "simbolizzare",
    "simbolizzante": "simbolizzare",
    "simbolizzanti": "simbolizzare",
    "simbolizzar": "simbolizzare",
    "simbolizzaron": "simbolizzare",
    "simbolizzarono": "simbolizzare",
    "simbolizzasse": "simbolizzare",
    "simbolizzasser": "simbolizzare",
    "simbolizzassero": "simbolizzare",
    "simbolizzassi": "simbolizzare",
    "simbolizzassimo": "simbolizzare",
    "simbolizzaste": "simbolizzare",
    "simbolizzasti": "simbolizzare",
    "simbolizzata": "simbolizzare",
    "simbolizzate": "simbolizzare",
    "simbolizzati": "simbolizzare",
    "simbolizzato": "simbolizzare",
    "simbolizzava": "simbolizzare",
    "simbolizzavamo": "simbolizzare",
    "simbolizzavan": "simbolizzare",
    "simbolizzavano": "simbolizzare",
    "simbolizzavate": "simbolizzare",
    "simbolizzavi": "simbolizzare",
    "simbolizzavo": "simbolizzare",
    "simbolizzerai": "simbolizzare",
    "simbolizzeran": "simbolizzare",
    "simbolizzeranno": "simbolizzare",
    "simbolizzerebbe": "simbolizzare",
    "simbolizzerebber": "simbolizzare",
    "simbolizzerebbero": "simbolizzare",
    "simbolizzerei": "simbolizzare",
    "simbolizzeremmo": "simbolizzare",
    "simbolizzeremo": "simbolizzare",
    "simbolizzereste": "simbolizzare",
    "simbolizzeresti": "simbolizzare",
    "simbolizzerete": "simbolizzare",
    "simbolizzerà": "simbolizzare",
    "simbolizzerò": "simbolizzare",
    "simbolizzi": "simbolizzare",
    "simbolizziamo": "simbolizzare",
    "simbolizziate": "simbolizzare",
    "simbolizzin": "simbolizzare",
    "simbolizzino": "simbolizzare",
    "simbolizzo": "simbolizzare",
    "simbolizzò": "simbolizzare",
    "simbologie": "simbologia",
    "simila": "similare",
    "similai": "similare",
    "similammo": "similare",
    "similan": "similare",
    "similando": "similare",
    "similano": "similare",
    "similante": "similare",
    "similanti": "similare",
    "similar": "similare",
    "similari": "similare",
    "similaron": "similare",
    "similarono": "similare",
    "similasse": "similare",
    "similasser": "similare",
    "similassero": "similare",
    "similassi": "similare",
    "similassimo": "similare",
    "similaste": "similare",
    "similasti": "similare",
    "similata": "similare",
    "similate": "similare",
    "similati": "similare",
    "similato": "similare",
    "similava": "similare",
    "similavamo": "similare",
    "similavan": "similare",
    "similavano": "similare",
    "similavate": "similare",
    "similavi": "similare",
    "similavo": "similare",
    "similerai": "similare",
    "simileran": "similare",
    "simileranno": "similare",
    "similerebbe": "similare",
    "similerebber": "similare",
    "similerebbero": "similare",
    "similerei": "similare",
    "simileremmo": "similare",
    "simileremo": "similare",
    "similereste": "similare",
    "simileresti": "similare",
    "similerete": "similare",
    "similerà": "similare",
    "similerò": "similare",
    "simili": "simile",
    "similiamo": "similare",
    "similiate": "similare",
    "similin": "similare",
    "similino": "similare",
    "similitudini": "similitudine",
    "similo": "similare",
    "similò": "similare",
    "simmetrica": "simmetrico",
    "simmetriche": "simmetrico",
    "simmetrici": "simmetrico",
    "simmetrie": "simmetria",
    "simpatica": "simpatico",
    "simpatiche": "simpatico",
    "simpatici": "simpatico",
    "simpaticoni": "simpaticone",
    "simpatie": "simpatia",
    "simpatizza": "simpatizzare",
    "simpatizzai": "simpatizzare",
    "simpatizzammo": "simpatizzare",
    "simpatizzan": "simpatizzare",
    "simpatizzando": "simpatizzare",
    "simpatizzano": "simpatizzare",
    "simpatizzante": "simpatizzare",
    "simpatizzanti": "simpatizzare",
    "simpatizzar": "simpatizzare",
    "simpatizzaron": "simpatizzare",
    "simpatizzarono": "simpatizzare",
    "simpatizzasse": "simpatizzare",
    "simpatizzasser": "simpatizzare",
    "simpatizzassero": "simpatizzare",
    "simpatizzassi": "simpatizzare",
    "simpatizzassimo": "simpatizzare",
    "simpatizzaste": "simpatizzare",
    "simpatizzasti": "simpatizzare",
    "simpatizzata": "simpatizzare",
    "simpatizzate": "simpatizzare",
    "simpatizzati": "simpatizzare",
    "simpatizzato": "simpatizzare",
    "simpatizzava": "simpatizzare",
    "simpatizzavamo": "simpatizzare",
    "simpatizzavan": "simpatizzare",
    "simpatizzavano": "simpatizzare",
    "simpatizzavate": "simpatizzare",
    "simpatizzavi": "simpatizzare",
    "simpatizzavo": "simpatizzare",
    "simpatizzerai": "simpatizzare",
    "simpatizzeran": "simpatizzare",
    "simpatizzeranno": "simpatizzare",
    "simpatizzerebbe": "simpatizzare",
    "simpatizzerebber": "simpatizzare",
    "simpatizzerebbero": "simpatizzare",
    "simpatizzerei": "simpatizzare",
    "simpatizzeremmo": "simpatizzare",
    "simpatizzeremo": "simpatizzare",
    "simpatizzereste": "simpatizzare",
    "simpatizzeresti": "simpatizzare",
    "simpatizzerete": "simpatizzare",
    "simpatizzerà": "simpatizzare",
    "simpatizzerò": "simpatizzare",
    "simpatizzi": "simpatizzare",
    "simpatizziamo": "simpatizzare",
    "simpatizziate": "simpatizzare",
    "simpatizzin": "simpatizzare",
    "simpatizzino": "simpatizzare",
    "simpatizzo": "simpatizzare",
    "simpatizzò": "simpatizzare",
    "simposi": "simposio",
    "simula": "simulare",
    "simulacri": "simulacro",
    "simulai": "simulare",
    "simulammo": "simulare",
    "simulan": "simulare",
    "simulando": "simulare",
    "simulano": "simulare",
    "simulante": "simulare",
    "simulanti": "simulare",
    "simular": "simulare",
    "simularon": "simulare",
    "simularono": "simulare",
    "simulasse": "simulare",
    "simulasser": "simulare",
    "simulassero": "simulare",
    "simulassi": "simulare",
    "simulassimo": "simulare",
    "simulaste": "simulare",
    "simulasti": "simulare",
    "simulata": "simulare",
    "simulate": "simulare",
    "simulati": "simulare",
    "simulato": "simulare",
    "simulatori": "simulatore",
    "simulava": "simulare",
    "simulavamo": "simulare",
    "simulavan": "simulare",
    "simulavano": "simulare",
    "simulavate": "simulare",
    "simulavi": "simulare",
    "simulavo": "simulare",
    "simulazioni": "simulazione",
    "simulerai": "simulare",
    "simuleran": "simulare",
    "simuleranno": "simulare",
    "simulerebbe": "simulare",
    "simulerebber": "simulare",
    "simulerebbero": "simulare",
    "simulerei": "simulare",
    "simuleremmo": "simulare",
    "simuleremo": "simulare",
    "simulereste": "simulare",
    "simuleresti": "simulare",
    "simulerete": "simulare",
    "simulerà": "simulare",
    "simulerò": "simulare",
    "simuli": "simulare",
    "simuliamo": "simulare",
    "simuliate": "simulare",
    "simulin": "simulare",
    "simulino": "simulare",
    "simulo": "simulare",
    "simultanea": "simultaneo",
    "simultanee": "simultaneo",
    "simultanei": "simultaneo",
    "simulò": "simulare",
    "sinagoghe": "sinagoga",
    "sincera": "sincero",
    "sincerai": "sincerare",
    "sincerammo": "sincerare",
    "sinceran": "sincerare",
    "sincerando": "sincerare",
    "sincerano": "sincerare",
    "sincerante": "sincerare",
    "sinceranti": "sincerare",
    "sincerar": "sincerare",
    "sinceraron": "sincerare",
    "sincerarono": "sincerare",
    "sincerasse": "sincerare",
    "sincerasser": "sincerare",
    "sincerassero": "sincerare",
    "sincerassi": "sincerare",
    "sincerassimo": "sincerare",
    "sinceraste": "sincerare",
    "sincerasti": "sincerare",
    "sincerata": "sincerare",
    "sincerate": "sincerare",
    "sincerati": "sincerare",
    "sincerato": "sincerare",
    "sincerava": "sincerare",
    "sinceravamo": "sincerare",
    "sinceravan": "sincerare",
    "sinceravano": "sincerare",
    "sinceravate": "sincerare",
    "sinceravi": "sincerare",
    "sinceravo": "sincerare",
    "sincere": "sincero",
    "sincererai": "sincerare",
    "sincereran": "sincerare",
    "sincereranno": "sincerare",
    "sincererebbe": "sincerare",
    "sincererebber": "sincerare",
    "sincererebbero": "sincerare",
    "sincererei": "sincerare",
    "sincereremmo": "sincerare",
    "sincereremo": "sincerare",
    "sincerereste": "sincerare",
    "sincereresti": "sincerare",
    "sincererete": "sincerare",
    "sincererà": "sincerare",
    "sincererò": "sincerare",
    "sinceri": "sincero",
    "sinceriamo": "sincerare",
    "sinceriate": "sincerare",
    "sincerin": "sincerare",
    "sincerino": "sincerare",
    "sincero": "sincerare",
    "sincerò": "sincerare",
    "sincopa": "sincopare",
    "sincopai": "sincopare",
    "sincopammo": "sincopare",
    "sincopan": "sincopare",
    "sincopando": "sincopare",
    "sincopano": "sincopare",
    "sincopante": "sincopare",
    "sincopanti": "sincopare",
    "sincopar": "sincopare",
    "sincoparon": "sincopare",
    "sincoparono": "sincopare",
    "sincopasse": "sincopare",
    "sincopasser": "sincopare",
    "sincopassero": "sincopare",
    "sincopassi": "sincopare",
    "sincopassimo": "sincopare",
    "sincopaste": "sincopare",
    "sincopasti": "sincopare",
    "sincopata": "sincopato",
    "sincopate": "sincopato",
    "sincopati": "sincopato",
    "sincopato": "sincopare",
    "sincopava": "sincopare",
    "sincopavamo": "sincopare",
    "sincopavan": "sincopare",
    "sincopavano": "sincopare",
    "sincopavate": "sincopare",
    "sincopavi": "sincopare",
    "sincopavo": "sincopare",
    "sincoperai": "sincopare",
    "sincoperan": "sincopare",
    "sincoperanno": "sincopare",
    "sincoperebbe": "sincopare",
    "sincoperebber": "sincopare",
    "sincoperebbero": "sincopare",
    "sincoperei": "sincopare",
    "sincoperemmo": "sincopare",
    "sincoperemo": "sincopare",
    "sincopereste": "sincopare",
    "sincoperesti": "sincopare",
    "sincoperete": "sincopare",
    "sincoperà": "sincopare",
    "sincoperò": "sincopare",
    "sincopi": "sincopare",
    "sincopiamo": "sincopare",
    "sincopiate": "sincopare",
    "sincopin": "sincopare",
    "sincopino": "sincopare",
    "sincopo": "sincopare",
    "sincopò": "sincopare",
    "sincretismi": "sincretismo",
    "sincrona": "sincrono",
    "sincrone": "sincrono",
    "sincroni": "sincrono",
    "sincronie": "sincronia",
    "sincronismi": "sincronismo",
    "sincronizza": "sincronizzare",
    "sincronizzai": "sincronizzare",
    "sincronizzammo": "sincronizzare",
    "sincronizzan": "sincronizzare",
    "sincronizzando": "sincronizzare",
    "sincronizzano": "sincronizzare",
    "sincronizzante": "sincronizzare",
    "sincronizzanti": "sincronizzare",
    "sincronizzar": "sincronizzare",
    "sincronizzaron": "sincronizzare",
    "sincronizzarono": "sincronizzare",
    "sincronizzasse": "sincronizzare",
    "sincronizzasser": "sincronizzare",
    "sincronizzassero": "sincronizzare",
    "sincronizzassi": "sincronizzare",
    "sincronizzassimo": "sincronizzare",
    "sincronizzaste": "sincronizzare",
    "sincronizzasti": "sincronizzare",
    "sincronizzata": "sincronizzare",
    "sincronizzate": "sincronizzare",
    "sincronizzati": "sincronizzare",
    "sincronizzato": "sincronizzare",
    "sincronizzava": "sincronizzare",
    "sincronizzavamo": "sincronizzare",
    "sincronizzavan": "sincronizzare",
    "sincronizzavano": "sincronizzare",
    "sincronizzavate": "sincronizzare",
    "sincronizzavi": "sincronizzare",
    "sincronizzavo": "sincronizzare",
    "sincronizzerai": "sincronizzare",
    "sincronizzeran": "sincronizzare",
    "sincronizzeranno": "sincronizzare",
    "sincronizzerebbe": "sincronizzare",
    "sincronizzerebber": "sincronizzare",
    "sincronizzerebbero": "sincronizzare",
    "sincronizzerei": "sincronizzare",
    "sincronizzeremmo": "sincronizzare",
    "sincronizzeremo": "sincronizzare",
    "sincronizzereste": "sincronizzare",
    "sincronizzeresti": "sincronizzare",
    "sincronizzerete": "sincronizzare",
    "sincronizzerà": "sincronizzare",
    "sincronizzerò": "sincronizzare",
    "sincronizzi": "sincronizzare",
    "sincronizziamo": "sincronizzare",
    "sincronizziate": "sincronizzare",
    "sincronizzin": "sincronizzare",
    "sincronizzino": "sincronizzare",
    "sincronizzo": "sincronizzare",
    "sincronizzò": "sincronizzare",
    "sincrotroni": "sincrotrone",
    "sindaca": "sindacare",
    "sindacabili": "sindacabile",
    "sindacai": "sindacare",
    "sindacali": "sindacale",
    "sindacalismi": "sindacalismo",
    "sindacaliste": "sindacalista",
    "sindacalisti": "sindacalista",
    "sindacalizza": "sindacalizzare",
    "sindacalizzai": "sindacalizzare",
    "sindacalizzammo": "sindacalizzare",
    "sindacalizzan": "sindacalizzare",
    "sindacalizzando": "sindacalizzare",
    "sindacalizzano": "sindacalizzare",
    "sindacalizzante": "sindacalizzare",
    "sindacalizzanti": "sindacalizzare",
    "sindacalizzar": "sindacalizzare",
    "sindacalizzaron": "sindacalizzare",
    "sindacalizzarono": "sindacalizzare",
    "sindacalizzasse": "sindacalizzare",
    "sindacalizzasser": "sindacalizzare",
    "sindacalizzassero": "sindacalizzare",
    "sindacalizzassi": "sindacalizzare",
    "sindacalizzassimo": "sindacalizzare",
    "sindacalizzaste": "sindacalizzare",
    "sindacalizzasti": "sindacalizzare",
    "sindacalizzata": "sindacalizzare",
    "sindacalizzate": "sindacalizzare",
    "sindacalizzati": "sindacalizzare",
    "sindacalizzato": "sindacalizzare",
    "sindacalizzava": "sindacalizzare",
    "sindacalizzavamo": "sindacalizzare",
    "sindacalizzavan": "sindacalizzare",
    "sindacalizzavano": "sindacalizzare",
    "sindacalizzavate": "sindacalizzare",
    "sindacalizzavi": "sindacalizzare",
    "sindacalizzavo": "sindacalizzare",
    "sindacalizzazioni": "sindacalizzazione",
    "sindacalizzerai": "sindacalizzare",
    "sindacalizzeran": "sindacalizzare",
    "sindacalizzeranno": "sindacalizzare",
    "sindacalizzerebbe": "sindacalizzare",
    "sindacalizzerebber": "sindacalizzare",
    "sindacalizzerebbero": "sindacalizzare",
    "sindacalizzerei": "sindacalizzare",
    "sindacalizzeremmo": "sindacalizzare",
    "sindacalizzeremo": "sindacalizzare",
    "sindacalizzereste": "sindacalizzare",
    "sindacalizzeresti": "sindacalizzare",
    "sindacalizzerete": "sindacalizzare",
    "sindacalizzerà": "sindacalizzare",
    "sindacalizzerò": "sindacalizzare",
    "sindacalizzi": "sindacalizzare",
    "sindacalizziamo": "sindacalizzare",
    "sindacalizziate": "sindacalizzare",
    "sindacalizzin": "sindacalizzare",
    "sindacalizzino": "sindacalizzare",
    "sindacalizzo": "sindacalizzare",
    "sindacalizzò": "sindacalizzare",
    "sindacammo": "sindacare",
    "sindacan": "sindacare",
    "sindacando": "sindacare",
    "sindacano": "sindacare",
    "sindacante": "sindacare",
    "sindacanti": "sindacare",
    "sindacar": "sindacare",
    "sindacaron": "sindacare",
    "sindacarono": "sindacare",
    "sindacasse": "sindacare",
    "sindacasser": "sindacare",
    "sindacassero": "sindacare",
    "sindacassi": "sindacare",
    "sindacassimo": "sindacare",
    "sindacaste": "sindacare",
    "sindacasti": "sindacare",
    "sindacata": "sindacare",
    "sindacate": "sindacare",
    "sindacati": "sindacato",
    "sindacatini": "sindacatino",
    "sindacato": "sindacare",
    "sindacava": "sindacare",
    "sindacavamo": "sindacare",
    "sindacavan": "sindacare",
    "sindacavano": "sindacare",
    "sindacavate": "sindacare",
    "sindacavi": "sindacare",
    "sindacavo": "sindacare",
    "sindacherai": "sindacare",
    "sindacheran": "sindacare",
    "sindacheranno": "sindacare",
    "sindacherebbe": "sindacare",
    "sindacherebber": "sindacare",
    "sindacherebbero": "sindacare",
    "sindacherei": "sindacare",
    "sindacheremmo": "sindacare",
    "sindacheremo": "sindacare",
    "sindachereste": "sindacare",
    "sindacheresti": "sindacare",
    "sindacherete": "sindacare",
    "sindacherà": "sindacare",
    "sindacherò": "sindacare",
    "sindachi": "sindacare",
    "sindachiamo": "sindacare",
    "sindachiate": "sindacare",
    "sindachin": "sindacare",
    "sindachino": "sindacare",
    "sindaci": "sindaco",
    "sindaco": "sindacare",
    "sindacò": "sindacare",
    "sindromi": "sindrome",
    "sinecure": "sinecura",
    "sinergica": "sinergico",
    "sinergiche": "sinergico",
    "sinergici": "sinergico",
    "sinergie": "sinergia",
    "sinfonica": "sinfonico",
    "sinfoniche": "sinfonico",
    "sinfonici": "sinfonico",
    "sinfonie": "sinfonia",
    "sinfonismi": "sinfonismo",
    "singalesi": "singalese",
    "singhiozza": "singhiozzare",
    "singhiozzai": "singhiozzare",
    "singhiozzammo": "singhiozzare",
    "singhiozzan": "singhiozzare",
    "singhiozzando": "singhiozzare",
    "singhiozzano": "singhiozzare",
    "singhiozzante": "singhiozzare",
    "singhiozzanti": "singhiozzare",
    "singhiozzar": "singhiozzare",
    "singhiozzaron": "singhiozzare",
    "singhiozzarono": "singhiozzare",
    "singhiozzasse": "singhiozzare",
    "singhiozzasser": "singhiozzare",
    "singhiozzassero": "singhiozzare",
    "singhiozzassi": "singhiozzare",
    "singhiozzassimo": "singhiozzare",
    "singhiozzaste": "singhiozzare",
    "singhiozzasti": "singhiozzare",
    "singhiozzata": "singhiozzare",
    "singhiozzate": "singhiozzare",
    "singhiozzati": "singhiozzare",
    "singhiozzato": "singhiozzare",
    "singhiozzava": "singhiozzare",
    "singhiozzavamo": "singhiozzare",
    "singhiozzavan": "singhiozzare",
    "singhiozzavano": "singhiozzare",
    "singhiozzavate": "singhiozzare",
    "singhiozzavi": "singhiozzare",
    "singhiozzavo": "singhiozzare",
    "singhiozzerai": "singhiozzare",
    "singhiozzeran": "singhiozzare",
    "singhiozzeranno": "singhiozzare",
    "singhiozzerebbe": "singhiozzare",
    "singhiozzerebber": "singhiozzare",
    "singhiozzerebbero": "singhiozzare",
    "singhiozzerei": "singhiozzare",
    "singhiozzeremmo": "singhiozzare",
    "singhiozzeremo": "singhiozzare",
    "singhiozzereste": "singhiozzare",
    "singhiozzeresti": "singhiozzare",
    "singhiozzerete": "singhiozzare",
    "singhiozzerà": "singhiozzare",
    "singhiozzerò": "singhiozzare",
    "singhiozzi": "singhiozzo",
    "singhiozziamo": "singhiozzare",
    "singhiozziate": "singhiozzare",
    "singhiozzin": "singhiozzare",
    "singhiozzino": "singhiozzare",
    "singhiozzo": "singhiozzare",
    "singhiozzò": "singhiozzare",
    "singola": "singolo",
    "singolari": "singolare",
    "singolaristi": "singolarista",
    "singole": "singolo",
    "singoli": "singolo",
    "singulti": "singulto",
    "sinistra": "sinistro",
    "sinistrai": "sinistrare",
    "sinistrammo": "sinistrare",
    "sinistran": "sinistrare",
    "sinistrando": "sinistrare",
    "sinistrano": "sinistrare",
    "sinistrante": "sinistrare",
    "sinistranti": "sinistrare",
    "sinistrar": "sinistrare",
    "sinistraron": "sinistrare",
    "sinistrarono": "sinistrare",
    "sinistrasse": "sinistrare",
    "sinistrasser": "sinistrare",
    "sinistrassero": "sinistrare",
    "sinistrassi": "sinistrare",
    "sinistrassimo": "sinistrare",
    "sinistraste": "sinistrare",
    "sinistrasti": "sinistrare",
    "sinistrata": "sinistrato",
    "sinistrate": "sinistrato",
    "sinistrati": "sinistrato",
    "sinistrato": "sinistrare",
    "sinistrava": "sinistrare",
    "sinistravamo": "sinistrare",
    "sinistravan": "sinistrare",
    "sinistravano": "sinistrare",
    "sinistravate": "sinistrare",
    "sinistravi": "sinistrare",
    "sinistravo": "sinistrare",
    "sinistre": "sinistro",
    "sinistrerai": "sinistrare",
    "sinistreran": "sinistrare",
    "sinistreranno": "sinistrare",
    "sinistrerebbe": "sinistrare",
    "sinistrerebber": "sinistrare",
    "sinistrerebbero": "sinistrare",
    "sinistrerei": "sinistrare",
    "sinistreremmo": "sinistrare",
    "sinistreremo": "sinistrare",
    "sinistrereste": "sinistrare",
    "sinistreresti": "sinistrare",
    "sinistrerete": "sinistrare",
    "sinistrerà": "sinistrare",
    "sinistrerò": "sinistrare",
    "sinistri": "sinistro",
    "sinistriamo": "sinistrare",
    "sinistriate": "sinistrare",
    "sinistrin": "sinistrare",
    "sinistrino": "sinistrare",
    "sinistro": "sinistrare",
    "sinistrorsa": "sinistrorso",
    "sinistrorse": "sinistrorso",
    "sinistrorsi": "sinistrorso",
    "sinistrò": "sinistrare",
    "sinodali": "sinodale",
    "sinodi": "sinodo",
    "sinologi": "sinologo",
    "sinonimi": "sinonimo",
    "sinottica": "sinottico",
    "sinottiche": "sinottico",
    "sinottici": "sinottico",
    "sintattica": "sintattico",
    "sintattiche": "sintattico",
    "sintattici": "sintattico",
    "sinterizza": "sinterizzare",
    "sinterizzai": "sinterizzare",
    "sinterizzammo": "sinterizzare",
    "sinterizzan": "sinterizzare",
    "sinterizzando": "sinterizzare",
    "sinterizzano": "sinterizzare",
    "sinterizzante": "sinterizzare",
    "sinterizzanti": "sinterizzare",
    "sinterizzar": "sinterizzare",
    "sinterizzaron": "sinterizzare",
    "sinterizzarono": "sinterizzare",
    "sinterizzasse": "sinterizzare",
    "sinterizzasser": "sinterizzare",
    "sinterizzassero": "sinterizzare",
    "sinterizzassi": "sinterizzare",
    "sinterizzassimo": "sinterizzare",
    "sinterizzaste": "sinterizzare",
    "sinterizzasti": "sinterizzare",
    "sinterizzata": "sinterizzare",
    "sinterizzate": "sinterizzare",
    "sinterizzati": "sinterizzare",
    "sinterizzato": "sinterizzare",
    "sinterizzava": "sinterizzare",
    "sinterizzavamo": "sinterizzare",
    "sinterizzavan": "sinterizzare",
    "sinterizzavano": "sinterizzare",
    "sinterizzavate": "sinterizzare",
    "sinterizzavi": "sinterizzare",
    "sinterizzavo": "sinterizzare",
    "sinterizzerai": "sinterizzare",
    "sinterizzeran": "sinterizzare",
    "sinterizzeranno": "sinterizzare",
    "sinterizzerebbe": "sinterizzare",
    "sinterizzerebber": "sinterizzare",
    "sinterizzerebbero": "sinterizzare",
    "sinterizzerei": "sinterizzare",
    "sinterizzeremmo": "sinterizzare",
    "sinterizzeremo": "sinterizzare",
    "sinterizzereste": "sinterizzare",
    "sinterizzeresti": "sinterizzare",
    "sinterizzerete": "sinterizzare",
    "sinterizzerà": "sinterizzare",
    "sinterizzerò": "sinterizzare",
    "sinterizzi": "sinterizzare",
    "sinterizziamo": "sinterizzare",
    "sinterizziate": "sinterizzare",
    "sinterizzin": "sinterizzare",
    "sinterizzino": "sinterizzare",
    "sinterizzo": "sinterizzare",
    "sinterizzò": "sinterizzare",
    "sintetica": "sintetico",
    "sintetiche": "sintetico",
    "sintetici": "sintetico",
    "sintetizza": "sintetizzare",
    "sintetizzabili": "sintetizzabile",
    "sintetizzai": "sintetizzare",
    "sintetizzammo": "sintetizzare",
    "sintetizzan": "sintetizzare",
    "sintetizzando": "sintetizzare",
    "sintetizzano": "sintetizzare",
    "sintetizzante": "sintetizzare",
    "sintetizzanti": "sintetizzare",
    "sintetizzar": "sintetizzare",
    "sintetizzaron": "sintetizzare",
    "sintetizzarono": "sintetizzare",
    "sintetizzasse": "sintetizzare",
    "sintetizzasser": "sintetizzare",
    "sintetizzassero": "sintetizzare",
    "sintetizzassi": "sintetizzare",
    "sintetizzassimo": "sintetizzare",
    "sintetizzaste": "sintetizzare",
    "sintetizzasti": "sintetizzare",
    "sintetizzata": "sintetizzare",
    "sintetizzate": "sintetizzare",
    "sintetizzati": "sintetizzare",
    "sintetizzato": "sintetizzare",
    "sintetizzatori": "sintetizzatore",
    "sintetizzava": "sintetizzare",
    "sintetizzavamo": "sintetizzare",
    "sintetizzavan": "sintetizzare",
    "sintetizzavano": "sintetizzare",
    "sintetizzavate": "sintetizzare",
    "sintetizzavi": "sintetizzare",
    "sintetizzavo": "sintetizzare",
    "sintetizzerai": "sintetizzare",
    "sintetizzeran": "sintetizzare",
    "sintetizzeranno": "sintetizzare",
    "sintetizzerebbe": "sintetizzare",
    "sintetizzerebber": "sintetizzare",
    "sintetizzerebbero": "sintetizzare",
    "sintetizzerei": "sintetizzare",
    "sintetizzeremmo": "sintetizzare",
    "sintetizzeremo": "sintetizzare",
    "sintetizzereste": "sintetizzare",
    "sintetizzeresti": "sintetizzare",
    "sintetizzerete": "sintetizzare",
    "sintetizzerà": "sintetizzare",
    "sintetizzerò": "sintetizzare",
    "sintetizzi": "sintetizzare",
    "sintetizziamo": "sintetizzare",
    "sintetizziate": "sintetizzare",
    "sintetizzin": "sintetizzare",
    "sintetizzino": "sintetizzare",
    "sintetizzo": "sintetizzare",
    "sintetizzò": "sintetizzare",
    "sintomatica": "sintomatico",
    "sintomatiche": "sintomatico",
    "sintomatici": "sintomatico",
    "sintomatologie": "sintomatologia",
    "sintomi": "sintomo",
    "sintonie": "sintonia",
    "sintonizza": "sintonizzare",
    "sintonizzai": "sintonizzare",
    "sintonizzammo": "sintonizzare",
    "sintonizzan": "sintonizzare",
    "sintonizzando": "sintonizzare",
    "sintonizzano": "sintonizzare",
    "sintonizzante": "sintonizzare",
    "sintonizzanti": "sintonizzare",
    "sintonizzar": "sintonizzare",
    "sintonizzaron": "sintonizzare",
    "sintonizzarono": "sintonizzare",
    "sintonizzasse": "sintonizzare",
    "sintonizzasser": "sintonizzare",
    "sintonizzassero": "sintonizzare",
    "sintonizzassi": "sintonizzare",
    "sintonizzassimo": "sintonizzare",
    "sintonizzaste": "sintonizzare",
    "sintonizzasti": "sintonizzare",
    "sintonizzata": "sintonizzare",
    "sintonizzate": "sintonizzare",
    "sintonizzati": "sintonizzare",
    "sintonizzato": "sintonizzare",
    "sintonizzava": "sintonizzare",
    "sintonizzavamo": "sintonizzare",
    "sintonizzavan": "sintonizzare",
    "sintonizzavano": "sintonizzare",
    "sintonizzavate": "sintonizzare",
    "sintonizzavi": "sintonizzare",
    "sintonizzavo": "sintonizzare",
    "sintonizzerai": "sintonizzare",
    "sintonizzeran": "sintonizzare",
    "sintonizzeranno": "sintonizzare",
    "sintonizzerebbe": "sintonizzare",
    "sintonizzerebber": "sintonizzare",
    "sintonizzerebbero": "sintonizzare",
    "sintonizzerei": "sintonizzare",
    "sintonizzeremmo": "sintonizzare",
    "sintonizzeremo": "sintonizzare",
    "sintonizzereste": "sintonizzare",
    "sintonizzeresti": "sintonizzare",
    "sintonizzerete": "sintonizzare",
    "sintonizzerà": "sintonizzare",
    "sintonizzerò": "sintonizzare",
    "sintonizzi": "sintonizzare",
    "sintonizziamo": "sintonizzare",
    "sintonizziate": "sintonizzare",
    "sintonizzin": "sintonizzare",
    "sintonizzino": "sintonizzare",
    "sintonizzo": "sintonizzare",
    "sintonizzò": "sintonizzare",
    "sinuosa": "sinuoso",
    "sinuose": "sinuoso",
    "sinuosi": "sinuoso",
    "sinusiti": "sinusite",
    "sionismi": "sionismo",
    "sioniste": "sionista",
    "sionisti": "sionista",
    "sipari": "sipario",
    "siparietti": "siparietto",
    "siracusani": "siracusano",
    "sirene": "sirena",
    "sirenette": "sirenetta",
    "siriana": "siriano",
    "siriane": "siriano",
    "siriani": "siriano",
    "sirianizzata": "sirianizzato",
    "sirianizzate": "sirianizzato",
    "sirianizzati": "sirianizzato",
    "siringhe": "siringa",
    "sismi": "sisma",
    "sismica": "sismico",
    "sismiche": "sismico",
    "sismici": "sismico",
    "sismografi": "sismografo",
    "sismologi": "sismologo",
    "sistema": "sistemare",
    "sistemai": "sistemare",
    "sistemammo": "sistemare",
    "sisteman": "sistemare",
    "sistemando": "sistemare",
    "sistemano": "sistemare",
    "sistemante": "sistemare",
    "sistemanti": "sistemare",
    "sistemar": "sistemare",
    "sistemaron": "sistemare",
    "sistemarono": "sistemare",
    "sistemasse": "sistemare",
    "sistemasser": "sistemare",
    "sistemassero": "sistemare",
    "sistemassi": "sistemare",
    "sistemassimo": "sistemare",
    "sistemaste": "sistemare",
    "sistemasti": "sistemare",
    "sistemata": "sistemare",
    "sistemate": "sistemare",
    "sistemati": "sistemare",
    "sistematica": "sistematico",
    "sistematiche": "sistematico",
    "sistematici": "sistematico",
    "sistematizza": "sistematizzare",
    "sistematizzai": "sistematizzare",
    "sistematizzammo": "sistematizzare",
    "sistematizzan": "sistematizzare",
    "sistematizzando": "sistematizzare",
    "sistematizzano": "sistematizzare",
    "sistematizzante": "sistematizzare",
    "sistematizzanti": "sistematizzare",
    "sistematizzar": "sistematizzare",
    "sistematizzaron": "sistematizzare",
    "sistematizzarono": "sistematizzare",
    "sistematizzasse": "sistematizzare",
    "sistematizzasser": "sistematizzare",
    "sistematizzassero": "sistematizzare",
    "sistematizzassi": "sistematizzare",
    "sistematizzassimo": "sistematizzare",
    "sistematizzaste": "sistematizzare",
    "sistematizzasti": "sistematizzare",
    "sistematizzata": "sistematizzare",
    "sistematizzate": "sistematizzare",
    "sistematizzati": "sistematizzare",
    "sistematizzato": "sistematizzare",
    "sistematizzava": "sistematizzare",
    "sistematizzavamo": "sistematizzare",
    "sistematizzavan": "sistematizzare",
    "sistematizzavano": "sistematizzare",
    "sistematizzavate": "sistematizzare",
    "sistematizzavi": "sistematizzare",
    "sistematizzavo": "sistematizzare",
    "sistematizzerai": "sistematizzare",
    "sistematizzeran": "sistematizzare",
    "sistematizzeranno": "sistematizzare",
    "sistematizzerebbe": "sistematizzare",
    "sistematizzerebber": "sistematizzare",
    "sistematizzerebbero": "sistematizzare",
    "sistematizzerei": "sistematizzare",
    "sistematizzeremmo": "sistematizzare",
    "sistematizzeremo": "sistematizzare",
    "sistematizzereste": "sistematizzare",
    "sistematizzeresti": "sistematizzare",
    "sistematizzerete": "sistematizzare",
    "sistematizzerà": "sistematizzare",
    "sistematizzerò": "sistematizzare",
    "sistematizzi": "sistematizzare",
    "sistematizziamo": "sistematizzare",
    "sistematizziate": "sistematizzare",
    "sistematizzin": "sistematizzare",
    "sistematizzino": "sistematizzare",
    "sistematizzo": "sistematizzare",
    "sistematizzò": "sistematizzare",
    "sistemato": "sistemare",
    "sistemava": "sistemare",
    "sistemavamo": "sistemare",
    "sistemavan": "sistemare",
    "sistemavano": "sistemare",
    "sistemavate": "sistemare",
    "sistemavi": "sistemare",
    "sistemavo": "sistemare",
    "sistemazioni": "sistemazione",
    "sistemerai": "sistemare",
    "sistemeran": "sistemare",
    "sistemeranno": "sistemare",
    "sistemerebbe": "sistemare",
    "sistemerebber": "sistemare",
    "sistemerebbero": "sistemare",
    "sistemerei": "sistemare",
    "sistemeremmo": "sistemare",
    "sistemeremo": "sistemare",
    "sistemereste": "sistemare",
    "sistemeresti": "sistemare",
    "sistemerete": "sistemare",
    "sistemerà": "sistemare",
    "sistemerò": "sistemare",
    "sistemi": "sistemare",
    "sistemi-italia": "sistema-italia",
    "sistemi-paese": "sistema-paese",
    "sistemiamo": "sistemare",
    "sistemiate": "sistemare",
    "sistemica": "sistemico",
    "sistemiche": "sistemico",
    "sistemici": "sistemico",
    "sistemin": "sistemare",
    "sistemino": "sistemare",
    "sistemisti": "sistemista",
    "sistemo": "sistemare",
    "sistemò": "sistemare",
    "sistette": "esistere",
    "sistettero": "esistere",
    "sistetti": "esistere",
    "sita": "sito",
    "site": "sito",
    "siti": "sito",
    "situa": "situare",
    "situai": "situare",
    "situammo": "situare",
    "situan": "situare",
    "situando": "situare",
    "situano": "situare",
    "situante": "situare",
    "situanti": "situare",
    "situar": "situare",
    "situaron": "situare",
    "situarono": "situare",
    "situasse": "situare",
    "situasser": "situare",
    "situassero": "situare",
    "situassi": "situare",
    "situassimo": "situare",
    "situaste": "situare",
    "situasti": "situare",
    "situata": "situare",
    "situate": "situare",
    "situati": "situare",
    "situato": "situare",
    "situava": "situare",
    "situavamo": "situare",
    "situavan": "situare",
    "situavano": "situare",
    "situavate": "situare",
    "situavi": "situare",
    "situavo": "situare",
    "situazioni": "situazione",
    "situerai": "situare",
    "situeran": "situare",
    "situeranno": "situare",
    "situerebbe": "situare",
    "situerebber": "situare",
    "situerebbero": "situare",
    "situerei": "situare",
    "situeremmo": "situare",
    "situeremo": "situare",
    "situereste": "situare",
    "situeresti": "situare",
    "situerete": "situare",
    "situerà": "situare",
    "situerò": "situare",
    "situi": "situare",
    "situiamo": "situare",
    "situiate": "situare",
    "situin": "situare",
    "situino": "situare",
    "situo": "situare",
    "situò": "situare",
    "sketches": "sketch",
    "skinheads": "skinhead",
    "slabbra": "slabbrare",
    "slabbrai": "slabbrare",
    "slabbrammo": "slabbrare",
    "slabbran": "slabbrare",
    "slabbrando": "slabbrare",
    "slabbrano": "slabbrare",
    "slabbrante": "slabbrare",
    "slabbranti": "slabbrare",
    "slabbrar": "slabbrare",
    "slabbraron": "slabbrare",
    "slabbrarono": "slabbrare",
    "slabbrasse": "slabbrare",
    "slabbrasser": "slabbrare",
    "slabbrassero": "slabbrare",
    "slabbrassi": "slabbrare",
    "slabbrassimo": "slabbrare",
    "slabbraste": "slabbrare",
    "slabbrasti": "slabbrare",
    "slabbrata": "slabbrare",
    "slabbrate": "slabbrare",
    "slabbrati": "slabbrare",
    "slabbrato": "slabbrare",
    "slabbrava": "slabbrare",
    "slabbravamo": "slabbrare",
    "slabbravan": "slabbrare",
    "slabbravano": "slabbrare",
    "slabbravate": "slabbrare",
    "slabbravi": "slabbrare",
    "slabbravo": "slabbrare",
    "slabbrerai": "slabbrare",
    "slabbreran": "slabbrare",
    "slabbreranno": "slabbrare",
    "slabbrerebbe": "slabbrare",
    "slabbrerebber": "slabbrare",
    "slabbrerebbero": "slabbrare",
    "slabbrerei": "slabbrare",
    "slabbreremmo": "slabbrare",
    "slabbreremo": "slabbrare",
    "slabbrereste": "slabbrare",
    "slabbreresti": "slabbrare",
    "slabbrerete": "slabbrare",
    "slabbrerà": "slabbrare",
    "slabbrerò": "slabbrare",
    "slabbri": "slabbrare",
    "slabbriamo": "slabbrare",
    "slabbriate": "slabbrare",
    "slabbrin": "slabbrare",
    "slabbrino": "slabbrare",
    "slabbro": "slabbrare",
    "slabbrò": "slabbrare",
    "slaccerai": "slacciare",
    "slacceran": "slacciare",
    "slacceranno": "slacciare",
    "slaccerebbe": "slacciare",
    "slaccerebber": "slacciare",
    "slaccerebbero": "slacciare",
    "slaccerei": "slacciare",
    "slacceremmo": "slacciare",
    "slacceremo": "slacciare",
    "slaccereste": "slacciare",
    "slacceresti": "slacciare",
    "slaccerete": "slacciare",
    "slaccerà": "slacciare",
    "slaccerò": "slacciare",
    "slacci": "slacciare",
    "slaccia": "slacciare",
    "slacciai": "slacciare",
    "slacciammo": "slacciare",
    "slacciamo": "slacciare",
    "slaccian": "slacciare",
    "slacciando": "slacciare",
    "slacciano": "slacciare",
    "slacciante": "slacciare",
    "slaccianti": "slacciare",
    "slacciar": "slacciare",
    "slacciaron": "slacciare",
    "slacciarono": "slacciare",
    "slacciasse": "slacciare",
    "slacciasser": "slacciare",
    "slacciassero": "slacciare",
    "slacciassi": "slacciare",
    "slacciassimo": "slacciare",
    "slacciaste": "slacciare",
    "slacciasti": "slacciare",
    "slacciata": "slacciare",
    "slacciate": "slacciare",
    "slacciati": "slacciare",
    "slacciato": "slacciare",
    "slacciava": "slacciare",
    "slacciavamo": "slacciare",
    "slacciavan": "slacciare",
    "slacciavano": "slacciare",
    "slacciavate": "slacciare",
    "slacciavi": "slacciare",
    "slacciavo": "slacciare",
    "slaccin": "slacciare",
    "slaccino": "slacciare",
    "slaccio": "slacciare",
    "slacciò": "slacciare",
    "slalomiste": "slalomista",
    "slalomisti": "slalomista",
    "slancerai": "slanciare",
    "slanceran": "slanciare",
    "slanceranno": "slanciare",
    "slancerebbe": "slanciare",
    "slancerebber": "slanciare",
    "slancerebbero": "slanciare",
    "slancerei": "slanciare",
    "slanceremmo": "slanciare",
    "slanceremo": "slanciare",
    "slancereste": "slanciare",
    "slanceresti": "slanciare",
    "slancerete": "slanciare",
    "slancerà": "slanciare",
    "slancerò": "slanciare",
    "slanci": "slancio",
    "slancia": "slanciare",
    "slanciai": "slanciare",
    "slanciammo": "slanciare",
    "slanciamo": "slanciare",
    "slancian": "slanciare",
    "slanciando": "slanciare",
    "slanciano": "slanciare",
    "slanciante": "slanciare",
    "slancianti": "slanciare",
    "slanciar": "slanciare",
    "slanciaron": "slanciare",
    "slanciarono": "slanciare",
    "slanciasse": "slanciare",
    "slanciasser": "slanciare",
    "slanciassero": "slanciare",
    "slanciassi": "slanciare",
    "slanciassimo": "slanciare",
    "slanciaste": "slanciare",
    "slanciasti": "slanciare",
    "slanciata": "slanciato",
    "slanciate": "slanciato",
    "slanciati": "slanciato",
    "slanciato": "slanciare",
    "slanciava": "slanciare",
    "slanciavamo": "slanciare",
    "slanciavan": "slanciare",
    "slanciavano": "slanciare",
    "slanciavate": "slanciare",
    "slanciavi": "slanciare",
    "slanciavo": "slanciare",
    "slancin": "slanciare",
    "slancino": "slanciare",
    "slancio": "slanciare",
    "slanciò": "slanciare",
    "slarga": "slargare",
    "slargai": "slargare",
    "slargammo": "slargare",
    "slargan": "slargare",
    "slargando": "slargare",
    "slargano": "slargare",
    "slargante": "slargare",
    "slarganti": "slargare",
    "slargar": "slargare",
    "slargaron": "slargare",
    "slargarono": "slargare",
    "slargasse": "slargare",
    "slargasser": "slargare",
    "slargassero": "slargare",
    "slargassi": "slargare",
    "slargassimo": "slargare",
    "slargaste": "slargare",
    "slargasti": "slargare",
    "slargata": "slargare",
    "slargate": "slargare",
    "slargati": "slargare",
    "slargato": "slargare",
    "slargava": "slargare",
    "slargavamo": "slargare",
    "slargavan": "slargare",
    "slargavano": "slargare",
    "slargavate": "slargare",
    "slargavi": "slargare",
    "slargavo": "slargare",
    "slargherai": "slargare",
    "slargheran": "slargare",
    "slargheranno": "slargare",
    "slargherebbe": "slargare",
    "slargherebber": "slargare",
    "slargherebbero": "slargare",
    "slargherei": "slargare",
    "slargheremmo": "slargare",
    "slargheremo": "slargare",
    "slarghereste": "slargare",
    "slargheresti": "slargare",
    "slargherete": "slargare",
    "slargherà": "slargare",
    "slargherò": "slargare",
    "slarghi": "slargo",
    "slarghiamo": "slargare",
    "slarghiate": "slargare",
    "slarghin": "slargare",
    "slarghino": "slargare",
    "slargo": "slargare",
    "slargò": "slargare",
    "slatta": "slattare",
    "slattai": "slattare",
    "slattammo": "slattare",
    "slattan": "slattare",
    "slattando": "slattare",
    "slattano": "slattare",
    "slattante": "slattare",
    "slattanti": "slattare",
    "slattar": "slattare",
    "slattaron": "slattare",
    "slattarono": "slattare",
    "slattasse": "slattare",
    "slattasser": "slattare",
    "slattassero": "slattare",
    "slattassi": "slattare",
    "slattassimo": "slattare",
    "slattaste": "slattare",
    "slattasti": "slattare",
    "slattata": "slattare",
    "slattate": "slattare",
    "slattati": "slattare",
    "slattato": "slattare",
    "slattava": "slattare",
    "slattavamo": "slattare",
    "slattavan": "slattare",
    "slattavano": "slattare",
    "slattavate": "slattare",
    "slattavi": "slattare",
    "slattavo": "slattare",
    "slatterai": "slattare",
    "slatteran": "slattare",
    "slatteranno": "slattare",
    "slatterebbe": "slattare",
    "slatterebber": "slattare",
    "slatterebbero": "slattare",
    "slatterei": "slattare",
    "slatteremmo": "slattare",
    "slatteremo": "slattare",
    "slattereste": "slattare",
    "slatteresti": "slattare",
    "slatterete": "slattare",
    "slatterà": "slattare",
    "slatterò": "slattare",
    "slatti": "slattare",
    "slattiamo": "slattare",
    "slattiate": "slattare",
    "slattin": "slattare",
    "slattino": "slattare",
    "slatto": "slattare",
    "slattò": "slattare",
    "slava": "slavo",
    "slavata": "slavato",
    "slavate": "slavato",
    "slavati": "slavato",
    "slave": "slavo",
    "slavi": "slavo",
    "slavine": "slavina",
    "slavisti": "slavista",
    "sleali": "sleale",
    "slega": "slegare",
    "slegai": "slegare",
    "slegammo": "slegare",
    "slegan": "slegare",
    "slegando": "slegare",
    "slegano": "slegare",
    "slegante": "slegare",
    "sleganti": "slegare",
    "slegar": "slegare",
    "slegaron": "slegare",
    "slegarono": "slegare",
    "slegasse": "slegare",
    "slegasser": "slegare",
    "slegassero": "slegare",
    "slegassi": "slegare",
    "slegassimo": "slegare",
    "slegaste": "slegare",
    "slegasti": "slegare",
    "slegata": "slegato",
    "slegate": "slegato",
    "slegati": "slegato",
    "slegato": "slegare",
    "slegava": "slegare",
    "slegavamo": "slegare",
    "slegavan": "slegare",
    "slegavano": "slegare",
    "slegavate": "slegare",
    "slegavi": "slegare",
    "slegavo": "slegare",
    "slegherai": "slegare",
    "slegheran": "slegare",
    "slegheranno": "slegare",
    "slegherebbe": "slegare",
    "slegherebber": "slegare",
    "slegherebbero": "slegare",
    "slegherei": "slegare",
    "slegheremmo": "slegare",
    "slegheremo": "slegare",
    "sleghereste": "slegare",
    "slegheresti": "slegare",
    "slegherete": "slegare",
    "slegherà": "slegare",
    "slegherò": "slegare",
    "sleghi": "slegare",
    "sleghiamo": "slegare",
    "sleghiate": "slegare",
    "sleghin": "slegare",
    "sleghino": "slegare",
    "slego": "slegare",
    "slegò": "slegare",
    "slitta": "slittare",
    "slittai": "slittare",
    "slittamenti": "slittamento",
    "slittammo": "slittare",
    "slittan": "slittare",
    "slittando": "slittare",
    "slittano": "slittare",
    "slittante": "slittare",
    "slittanti": "slittare",
    "slittar": "slittare",
    "slittaron": "slittare",
    "slittarono": "slittare",
    "slittasse": "slittare",
    "slittasser": "slittare",
    "slittassero": "slittare",
    "slittassi": "slittare",
    "slittassimo": "slittare",
    "slittaste": "slittare",
    "slittasti": "slittare",
    "slittata": "slittare",
    "slittate": "slittare",
    "slittati": "slittare",
    "slittato": "slittare",
    "slittava": "slittare",
    "slittavamo": "slittare",
    "slittavan": "slittare",
    "slittavano": "slittare",
    "slittavate": "slittare",
    "slittavi": "slittare",
    "slittavo": "slittare",
    "slitte": "slitta",
    "slitterai": "slittare",
    "slitteran": "slittare",
    "slitteranno": "slittare",
    "slitterebbe": "slittare",
    "slitterebber": "slittare",
    "slitterebbero": "slittare",
    "slitterei": "slittare",
    "slitteremmo": "slittare",
    "slitteremo": "slittare",
    "slittereste": "slittare",
    "slitteresti": "slittare",
    "slitterete": "slittare",
    "slitterà": "slittare",
    "slitterò": "slittare",
    "slitti": "slittare",
    "slittiamo": "slittare",
    "slittiate": "slittare",
    "slittin": "slittare",
    "slittini": "slittino",
    "slittino": "slittare",
    "slitto": "slittare",
    "slittò": "slittare",
    "sloga": "slogare",
    "slogai": "slogare",
    "slogammo": "slogare",
    "slogan": "slogare",
    "slogando": "slogare",
    "slogano": "slogare",
    "slogans": "slogan",
    "slogante": "slogare",
    "sloganti": "slogare",
    "slogar": "slogare",
    "slogaron": "slogare",
    "slogarono": "slogare",
    "slogasse": "slogare",
    "slogasser": "slogare",
    "slogassero": "slogare",
    "slogassi": "slogare",
    "slogassimo": "slogare",
    "slogaste": "slogare",
    "slogasti": "slogare",
    "slogata": "slogare",
    "slogate": "slogare",
    "slogati": "slogare",
    "slogato": "slogare",
    "slogava": "slogare",
    "slogavamo": "slogare",
    "slogavan": "slogare",
    "slogavano": "slogare",
    "slogavate": "slogare",
    "slogavi": "slogare",
    "slogavo": "slogare",
    "sloggerai": "sloggiare",
    "sloggeran": "sloggiare",
    "sloggeranno": "sloggiare",
    "sloggerebbe": "sloggiare",
    "sloggerebber": "sloggiare",
    "sloggerebbero": "sloggiare",
    "sloggerei": "sloggiare",
    "sloggeremmo": "sloggiare",
    "sloggeremo": "sloggiare",
    "sloggereste": "sloggiare",
    "sloggeresti": "sloggiare",
    "sloggerete": "sloggiare",
    "sloggerà": "sloggiare",
    "sloggerò": "sloggiare",
    "sloggi": "sloggiare",
    "sloggia": "sloggiare",
    "sloggiai": "sloggiare",
    "sloggiammo": "sloggiare",
    "sloggiamo": "sloggiare",
    "sloggian": "sloggiare",
    "sloggiando": "sloggiare",
    "sloggiano": "sloggiare",
    "sloggiante": "sloggiare",
    "sloggianti": "sloggiare",
    "sloggiar": "sloggiare",
    "sloggiaron": "sloggiare",
    "sloggiarono": "sloggiare",
    "sloggiasse": "sloggiare",
    "sloggiasser": "sloggiare",
    "sloggiassero": "sloggiare",
    "sloggiassi": "sloggiare",
    "sloggiassimo": "sloggiare",
    "sloggiaste": "sloggiare",
    "sloggiasti": "sloggiare",
    "sloggiata": "sloggiare",
    "sloggiate": "sloggiare",
    "sloggiati": "sloggiare",
    "sloggiato": "sloggiare",
    "sloggiava": "sloggiare",
    "sloggiavamo": "sloggiare",
    "sloggiavan": "sloggiare",
    "sloggiavano": "sloggiare",
    "sloggiavate": "sloggiare",
    "sloggiavi": "sloggiare",
    "sloggiavo": "sloggiare",
    "sloggin": "sloggiare",
    "sloggino": "sloggiare",
    "sloggio": "sloggiare",
    "sloggiò": "sloggiare",
    "slogherai": "slogare",
    "slogheran": "slogare",
    "slogheranno": "slogare",
    "slogherebbe": "slogare",
    "slogherebber": "slogare",
    "slogherebbero": "slogare",
    "slogherei": "slogare",
    "slogheremmo": "slogare",
    "slogheremo": "slogare",
    "sloghereste": "slogare",
    "slogheresti": "slogare",
    "slogherete": "slogare",
    "slogherà": "slogare",
    "slogherò": "slogare",
    "sloghi": "slogare",
    "sloghiamo": "slogare",
    "sloghiate": "slogare",
    "sloghin": "slogare",
    "sloghino": "slogare",
    "slogo": "slogare",
    "slogò": "slogare",
    "slomba": "slombare",
    "slombai": "slombare",
    "slombammo": "slombare",
    "slomban": "slombare",
    "slombando": "slombare",
    "slombano": "slombare",
    "slombante": "slombare",
    "slombanti": "slombare",
    "slombar": "slombare",
    "slombaron": "slombare",
    "slombarono": "slombare",
    "slombasse": "slombare",
    "slombasser": "slombare",
    "slombassero": "slombare",
    "slombassi": "slombare",
    "slombassimo": "slombare",
    "slombaste": "slombare",
    "slombasti": "slombare",
    "slombata": "slombare",
    "slombate": "slombare",
    "slombati": "slombare",
    "slombato": "slombare",
    "slombava": "slombare",
    "slombavamo": "slombare",
    "slombavan": "slombare",
    "slombavano": "slombare",
    "slombavate": "slombare",
    "slombavi": "slombare",
    "slombavo": "slombare",
    "slomberai": "slombare",
    "slomberan": "slombare",
    "slomberanno": "slombare",
    "slomberebbe": "slombare",
    "slomberebber": "slombare",
    "slomberebbero": "slombare",
    "slomberei": "slombare",
    "slomberemmo": "slombare",
    "slomberemo": "slombare",
    "slombereste": "slombare",
    "slomberesti": "slombare",
    "slomberete": "slombare",
    "slomberà": "slombare",
    "slomberò": "slombare",
    "slombi": "slombare",
    "slombiamo": "slombare",
    "slombiate": "slombare",
    "slombin": "slombare",
    "slombino": "slombare",
    "slombo": "slombare",
    "slombò": "slombare",
    "slovacca": "slovacco",
    "slovacche": "slovacco",
    "slovacchi": "slovacco",
    "slovene": "slovena",
    "sloveni": "sloveno",
    "smaccata": "smaccato",
    "smaccate": "smaccato",
    "smaccati": "smaccato",
    "smacchi": "smacco",
    "smacchia": "smacchiare",
    "smacchiai": "smacchiare",
    "smacchiammo": "smacchiare",
    "smacchiamo": "smacchiare",
    "smacchian": "smacchiare",
    "smacchiando": "smacchiare",
    "smacchiano": "smacchiare",
    "smacchiante": "smacchiare",
    "smacchianti": "smacchiare",
    "smacchiar": "smacchiare",
    "smacchiaron": "smacchiare",
    "smacchiarono": "smacchiare",
    "smacchiasse": "smacchiare",
    "smacchiasser": "smacchiare",
    "smacchiassero": "smacchiare",
    "smacchiassi": "smacchiare",
    "smacchiassimo": "smacchiare",
    "smacchiaste": "smacchiare",
    "smacchiasti": "smacchiare",
    "smacchiata": "smacchiare",
    "smacchiate": "smacchiare",
    "smacchiati": "smacchiare",
    "smacchiato": "smacchiare",
    "smacchiava": "smacchiare",
    "smacchiavamo": "smacchiare",
    "smacchiavan": "smacchiare",
    "smacchiavano": "smacchiare",
    "smacchiavate": "smacchiare",
    "smacchiavi": "smacchiare",
    "smacchiavo": "smacchiare",
    "smacchierai": "smacchiare",
    "smacchieran": "smacchiare",
    "smacchieranno": "smacchiare",
    "smacchierebbe": "smacchiare",
    "smacchierebber": "smacchiare",
    "smacchierebbero": "smacchiare",
    "smacchierei": "smacchiare",
    "smacchieremmo": "smacchiare",
    "smacchieremo": "smacchiare",
    "smacchiereste": "smacchiare",
    "smacchieresti": "smacchiare",
    "smacchierete": "smacchiare",
    "smacchierà": "smacchiare",
    "smacchierò": "smacchiare",
    "smacchin": "smacchiare",
    "smacchino": "smacchiare",
    "smacchio": "smacchiare",
    "smacchiò": "smacchiare",
    "smagli": "smagliare",
    "smaglia": "smagliare",
    "smagliai": "smagliare",
    "smagliammo": "smagliare",
    "smagliamo": "smagliare",
    "smaglian": "smagliare",
    "smagliando": "smagliare",
    "smagliano": "smagliare",
    "smagliante": "smagliare",
    "smaglianti": "smagliare",
    "smagliar": "smagliare",
    "smagliaron": "smagliare",
    "smagliarono": "smagliare",
    "smagliasse": "smagliare",
    "smagliasser": "smagliare",
    "smagliassero": "smagliare",
    "smagliassi": "smagliare",
    "smagliassimo": "smagliare",
    "smagliaste": "smagliare",
    "smagliasti": "smagliare",
    "smagliata": "smagliare",
    "smagliate": "smagliare",
    "smagliati": "smagliare",
    "smagliato": "smagliare",
    "smagliature": "smagliatura",
    "smagliava": "smagliare",
    "smagliavamo": "smagliare",
    "smagliavan": "smagliare",
    "smagliavano": "smagliare",
    "smagliavate": "smagliare",
    "smagliavi": "smagliare",
    "smagliavo": "smagliare",
    "smaglierai": "smagliare",
    "smaglieran": "smagliare",
    "smaglieranno": "smagliare",
    "smaglierebbe": "smagliare",
    "smaglierebber": "smagliare",
    "smaglierebbero": "smagliare",
    "smaglierei": "smagliare",
    "smaglieremmo": "smagliare",
    "smaglieremo": "smagliare",
    "smagliereste": "smagliare",
    "smaglieresti": "smagliare",
    "smaglierete": "smagliare",
    "smaglierà": "smagliare",
    "smaglierò": "smagliare",
    "smaglin": "smagliare",
    "smaglino": "smagliare",
    "smaglio": "smagliare",
    "smagliò": "smagliare",
    "smagnetizza": "smagnetizzare",
    "smagnetizzai": "smagnetizzare",
    "smagnetizzammo": "smagnetizzare",
    "smagnetizzan": "smagnetizzare",
    "smagnetizzando": "smagnetizzare",
    "smagnetizzano": "smagnetizzare",
    "smagnetizzante": "smagnetizzare",
    "smagnetizzanti": "smagnetizzare",
    "smagnetizzar": "smagnetizzare",
    "smagnetizzaron": "smagnetizzare",
    "smagnetizzarono": "smagnetizzare",
    "smagnetizzasse": "smagnetizzare",
    "smagnetizzasser": "smagnetizzare",
    "smagnetizzassero": "smagnetizzare",
    "smagnetizzassi": "smagnetizzare",
    "smagnetizzassimo": "smagnetizzare",
    "smagnetizzaste": "smagnetizzare",
    "smagnetizzasti": "smagnetizzare",
    "smagnetizzata": "smagnetizzare",
    "smagnetizzate": "smagnetizzare",
    "smagnetizzati": "smagnetizzare",
    "smagnetizzato": "smagnetizzare",
    "smagnetizzava": "smagnetizzare",
    "smagnetizzavamo": "smagnetizzare",
    "smagnetizzavan": "smagnetizzare",
    "smagnetizzavano": "smagnetizzare",
    "smagnetizzavate": "smagnetizzare",
    "smagnetizzavi": "smagnetizzare",
    "smagnetizzavo": "smagnetizzare",
    "smagnetizzerai": "smagnetizzare",
    "smagnetizzeran": "smagnetizzare",
    "smagnetizzeranno": "smagnetizzare",
    "smagnetizzerebbe": "smagnetizzare",
    "smagnetizzerebber": "smagnetizzare",
    "smagnetizzerebbero": "smagnetizzare",
    "smagnetizzerei": "smagnetizzare",
    "smagnetizzeremmo": "smagnetizzare",
    "smagnetizzeremo": "smagnetizzare",
    "smagnetizzereste": "smagnetizzare",
    "smagnetizzeresti": "smagnetizzare",
    "smagnetizzerete": "smagnetizzare",
    "smagnetizzerà": "smagnetizzare",
    "smagnetizzerò": "smagnetizzare",
    "smagnetizzi": "smagnetizzare",
    "smagnetizziamo": "smagnetizzare",
    "smagnetizziate": "smagnetizzare",
    "smagnetizzin": "smagnetizzare",
    "smagnetizzino": "smagnetizzare",
    "smagnetizzo": "smagnetizzare",
    "smagnetizzò": "smagnetizzare",
    "smagra": "smagrire",
    "smagran": "smagrire",
    "smagrano": "smagrire",
    "smagre": "smagrire",
    "smagrendo": "smagrire",
    "smagrente": "smagrire",
    "smagrenti": "smagrire",
    "smagri": "smagrire",
    "smagriamo": "smagrire",
    "smagriate": "smagrire",
    "smagrii": "smagrire",
    "smagrimmo": "smagrire",
    "smagrir": "smagrire",
    "smagrirai": "smagrire",
    "smagriran": "smagrire",
    "smagriranno": "smagrire",
    "smagrirebbe": "smagrire",
    "smagrirebber": "smagrire",
    "smagrirebbero": "smagrire",
    "smagrirei": "smagrire",
    "smagriremmo": "smagrire",
    "smagriremo": "smagrire",
    "smagrireste": "smagrire",
    "smagriresti": "smagrire",
    "smagrirete": "smagrire",
    "smagriron": "smagrire",
    "smagrirono": "smagrire",
    "smagrirà": "smagrire",
    "smagrirò": "smagrire",
    "smagrisse": "smagrire",
    "smagrisser": "smagrire",
    "smagrissero": "smagrire",
    "smagrissi": "smagrire",
    "smagrissimo": "smagrire",
    "smagriste": "smagrire",
    "smagristi": "smagrire",
    "smagrita": "smagrire",
    "smagrite": "smagrire",
    "smagriti": "smagrire",
    "smagrito": "smagrire",
    "smagriva": "smagrire",
    "smagrivamo": "smagrire",
    "smagrivan": "smagrire",
    "smagrivano": "smagrire",
    "smagrivate": "smagrire",
    "smagrivi": "smagrire",
    "smagrivo": "smagrire",
    "smagro": "smagrire",
    "smagron": "smagrire",
    "smagrono": "smagrire",
    "smagrì": "smagrire",
    "smalizi": "smaliziare",
    "smalizia": "smaliziare",
    "smaliziai": "smaliziare",
    "smaliziammo": "smaliziare",
    "smaliziamo": "smaliziare",
    "smalizian": "smaliziare",
    "smaliziando": "smaliziare",
    "smaliziano": "smaliziare",
    "smaliziante": "smaliziare",
    "smalizianti": "smaliziare",
    "smaliziar": "smaliziare",
    "smaliziaron": "smaliziare",
    "smaliziarono": "smaliziare",
    "smaliziasse": "smaliziare",
    "smaliziasser": "smaliziare",
    "smaliziassero": "smaliziare",
    "smaliziassi": "smaliziare",
    "smaliziassimo": "smaliziare",
    "smaliziaste": "smaliziare",
    "smaliziasti": "smaliziare",
    "smaliziata": "smaliziare",
    "smaliziate": "smaliziare",
    "smaliziati": "smaliziato",
    "smaliziato": "smaliziare",
    "smaliziava": "smaliziare",
    "smaliziavamo": "smaliziare",
    "smaliziavan": "smaliziare",
    "smaliziavano": "smaliziare",
    "smaliziavate": "smaliziare",
    "smaliziavi": "smaliziare",
    "smaliziavo": "smaliziare",
    "smalizierai": "smaliziare",
    "smalizieran": "smaliziare",
    "smalizieranno": "smaliziare",
    "smalizierebbe": "smaliziare",
    "smalizierebber": "smaliziare",
    "smalizierebbero": "smaliziare",
    "smalizierei": "smaliziare",
    "smalizieremmo": "smaliziare",
    "smalizieremo": "smaliziare",
    "smaliziereste": "smaliziare",
    "smalizieresti": "smaliziare",
    "smalizierete": "smaliziare",
    "smalizierà": "smaliziare",
    "smalizierò": "smaliziare",
    "smalizin": "smaliziare",
    "smalizino": "smaliziare",
    "smalizio": "smaliziare",
    "smaliziò": "smaliziare",
    "smalta": "smaltare",
    "smaltai": "smaltare",
    "smaltammo": "smaltare",
    "smaltan": "smaltare",
    "smaltando": "smaltare",
    "smaltano": "smaltare",
    "smaltante": "smaltare",
    "smaltanti": "smaltare",
    "smaltar": "smaltare",
    "smaltaron": "smaltare",
    "smaltarono": "smaltare",
    "smaltasse": "smaltare",
    "smaltasser": "smaltare",
    "smaltassero": "smaltare",
    "smaltassi": "smaltare",
    "smaltassimo": "smaltare",
    "smaltaste": "smaltare",
    "smaltasti": "smaltare",
    "smaltata": "smaltare",
    "smaltate": "smaltare",
    "smaltati": "smaltare",
    "smaltato": "smaltare",
    "smaltava": "smaltare",
    "smaltavamo": "smaltare",
    "smaltavan": "smaltare",
    "smaltavano": "smaltare",
    "smaltavate": "smaltare",
    "smaltavi": "smaltare",
    "smaltavo": "smaltare",
    "smaltendo": "smaltire",
    "smaltente": "smaltire",
    "smaltenti": "smaltire",
    "smalterai": "smaltare",
    "smalteran": "smaltare",
    "smalteranno": "smaltare",
    "smalterebbe": "smaltare",
    "smalterebber": "smaltare",
    "smalterebbero": "smaltare",
    "smalterei": "smaltare",
    "smalteremmo": "smaltare",
    "smalteremo": "smaltare",
    "smaltereste": "smaltare",
    "smalteresti": "smaltare",
    "smalterete": "smaltare",
    "smalterà": "smaltare",
    "smalterò": "smaltare",
    "smalti": "smalto",
    "smaltiamo": "smaltire",
    "smaltiate": "smaltire",
    "smaltii": "smaltire",
    "smaltimenti": "smaltimento",
    "smaltimmo": "smaltire",
    "smaltin": "smaltare",
    "smaltino": "smaltare",
    "smaltir": "smaltire",
    "smaltirai": "smaltire",
    "smaltiran": "smaltire",
    "smaltiranno": "smaltire",
    "smaltirebbe": "smaltire",
    "smaltirebber": "smaltire",
    "smaltirebbero": "smaltire",
    "smaltirei": "smaltire",
    "smaltiremmo": "smaltire",
    "smaltiremo": "smaltire",
    "smaltireste": "smaltire",
    "smaltiresti": "smaltire",
    "smaltirete": "smaltire",
    "smaltiron": "smaltire",
    "smaltirono": "smaltire",
    "smaltirà": "smaltire",
    "smaltirò": "smaltire",
    "smaltisca": "smaltire",
    "smaltiscan": "smaltire",
    "smaltiscano": "smaltire",
    "smaltisce": "smaltire",
    "smaltisci": "smaltire",
    "smaltisco": "smaltire",
    "smaltiscon": "smaltire",
    "smaltiscono": "smaltire",
    "smaltisse": "smaltire",
    "smaltisser": "smaltire",
    "smaltissero": "smaltire",
    "smaltissi": "smaltire",
    "smaltissimo": "smaltire",
    "smaltiste": "smaltire",
    "smaltisti": "smaltire",
    "smaltita": "smaltire",
    "smaltite": "smaltire",
    "smaltiti": "smaltire",
    "smaltito": "smaltire",
    "smaltiva": "smaltire",
    "smaltivamo": "smaltire",
    "smaltivan": "smaltire",
    "smaltivano": "smaltire",
    "smaltivate": "smaltire",
    "smaltivi": "smaltire",
    "smaltivo": "smaltire",
    "smalto": "smaltare",
    "smaltì": "smaltire",
    "smaltò": "smaltare",
    "smamma": "smammare",
    "smammai": "smammare",
    "smammammo": "smammare",
    "smamman": "smammare",
    "smammando": "smammare",
    "smammano": "smammare",
    "smammante": "smammare",
    "smammanti": "smammare",
    "smammar": "smammare",
    "smammaron": "smammare",
    "smammarono": "smammare",
    "smammasse": "smammare",
    "smammasser": "smammare",
    "smammassero": "smammare",
    "smammassi": "smammare",
    "smammassimo": "smammare",
    "smammaste": "smammare",
    "smammasti": "smammare",
    "smammata": "smammare",
    "smammate": "smammare",
    "smammati": "smammare",
    "smammato": "smammare",
    "smammava": "smammare",
    "smammavamo": "smammare",
    "smammavan": "smammare",
    "smammavano": "smammare",
    "smammavate": "smammare",
    "smammavi": "smammare",
    "smammavo": "smammare",
    "smammerai": "smammare",
    "smammeran": "smammare",
    "smammeranno": "smammare",
    "smammerebbe": "smammare",
    "smammerebber": "smammare",
    "smammerebbero": "smammare",
    "smammerei": "smammare",
    "smammeremmo": "smammare",
    "smammeremo": "smammare",
    "smammereste": "smammare",
    "smammeresti": "smammare",
    "smammerete": "smammare",
    "smammerà": "smammare",
    "smammerò": "smammare",
    "smammi": "smammare",
    "smammiamo": "smammare",
    "smammiate": "smammare",
    "smammin": "smammare",
    "smammino": "smammare",
    "smammo": "smammare",
    "smammò": "smammare",
    "smancerosa": "smanceroso",
    "smancerose": "smanceroso",
    "smancerosi": "smanceroso",
    "smanetta": "smanettare",
    "smanettai": "smanettare",
    "smanettammo": "smanettare",
    "smanettan": "smanettare",
    "smanettando": "smanettare",
    "smanettano": "smanettare",
    "smanettante": "smanettare",
    "smanettanti": "smanettare",
    "smanettar": "smanettare",
    "smanettaron": "smanettare",
    "smanettarono": "smanettare",
    "smanettasse": "smanettare",
    "smanettasser": "smanettare",
    "smanettassero": "smanettare",
    "smanettassi": "smanettare",
    "smanettassimo": "smanettare",
    "smanettaste": "smanettare",
    "smanettasti": "smanettare",
    "smanettata": "smanettare",
    "smanettate": "smanettare",
    "smanettati": "smanettare",
    "smanettato": "smanettare",
    "smanettava": "smanettare",
    "smanettavamo": "smanettare",
    "smanettavan": "smanettare",
    "smanettavano": "smanettare",
    "smanettavate": "smanettare",
    "smanettavi": "smanettare",
    "smanettavo": "smanettare",
    "smanetterai": "smanettare",
    "smanetteran": "smanettare",
    "smanetteranno": "smanettare",
    "smanetterebbe": "smanettare",
    "smanetterebber": "smanettare",
    "smanetterebbero": "smanettare",
    "smanetterei": "smanettare",
    "smanetteremmo": "smanettare",
    "smanetteremo": "smanettare",
    "smanettereste": "smanettare",
    "smanetteresti": "smanettare",
    "smanetterete": "smanettare",
    "smanetterà": "smanettare",
    "smanetterò": "smanettare",
    "smanetti": "smanettare",
    "smanettiamo": "smanettare",
    "smanettiate": "smanettare",
    "smanettin": "smanettare",
    "smanettino": "smanettare",
    "smanetto": "smanettare",
    "smanettò": "smanettare",
    "smani": "smaniare",
    "smania": "smaniare",
    "smaniai": "smaniare",
    "smaniammo": "smaniare",
    "smaniamo": "smaniare",
    "smanian": "smaniare",
    "smaniando": "smaniare",
    "smaniano": "smaniare",
    "smaniante": "smaniare",
    "smanianti": "smaniare",
    "smaniar": "smaniare",
    "smaniaron": "smaniare",
    "smaniarono": "smaniare",
    "smaniasse": "smaniare",
    "smaniasser": "smaniare",
    "smaniassero": "smaniare",
    "smaniassi": "smaniare",
    "smaniassimo": "smaniare",
    "smaniaste": "smaniare",
    "smaniasti": "smaniare",
    "smaniata": "smaniare",
    "smaniate": "smaniare",
    "smaniati": "smaniare",
    "smaniato": "smaniare",
    "smaniava": "smaniare",
    "smaniavamo": "smaniare",
    "smaniavan": "smaniare",
    "smaniavano": "smaniare",
    "smaniavate": "smaniare",
    "smaniavi": "smaniare",
    "smaniavo": "smaniare",
    "smanie": "smania",
    "smanierai": "smaniare",
    "smanieran": "smaniare",
    "smanieranno": "smaniare",
    "smanierebbe": "smaniare",
    "smanierebber": "smaniare",
    "smanierebbero": "smaniare",
    "smanierei": "smaniare",
    "smanieremmo": "smaniare",
    "smanieremo": "smaniare",
    "smaniereste": "smaniare",
    "smanieresti": "smaniare",
    "smanierete": "smaniare",
    "smanierà": "smaniare",
    "smanierò": "smaniare",
    "smanin": "smaniare",
    "smanino": "smaniare",
    "smanio": "smaniare",
    "smaniosa": "smanioso",
    "smaniose": "smanioso",
    "smaniosi": "smanioso",
    "smaniò": "smaniare",
    "smantella": "smantellare",
    "smantellai": "smantellare",
    "smantellamenti": "smantellamento",
    "smantellammo": "smantellare",
    "smantellan": "smantellare",
    "smantellando": "smantellare",
    "smantellano": "smantellare",
    "smantellante": "smantellare",
    "smantellanti": "smantellare",
    "smantellar": "smantellare",
    "smantellaron": "smantellare",
    "smantellarono": "smantellare",
    "smantellasse": "smantellare",
    "smantellasser": "smantellare",
    "smantellassero": "smantellare",
    "smantellassi": "smantellare",
    "smantellassimo": "smantellare",
    "smantellaste": "smantellare",
    "smantellasti": "smantellare",
    "smantellata": "smantellare",
    "smantellate": "smantellare",
    "smantellati": "smantellare",
    "smantellato": "smantellare",
    "smantellava": "smantellare",
    "smantellavamo": "smantellare",
    "smantellavan": "smantellare",
    "smantellavano": "smantellare",
    "smantellavate": "smantellare",
    "smantellavi": "smantellare",
    "smantellavo": "smantellare",
    "smantellerai": "smantellare",
    "smantelleran": "smantellare",
    "smantelleranno": "smantellare",
    "smantellerebbe": "smantellare",
    "smantellerebber": "smantellare",
    "smantellerebbero": "smantellare",
    "smantellerei": "smantellare",
    "smantelleremmo": "smantellare",
    "smantelleremo": "smantellare",
    "smantellereste": "smantellare",
    "smantelleresti": "smantellare",
    "smantellerete": "smantellare",
    "smantellerà": "smantellare",
    "smantellerò": "smantellare",
    "smantelli": "smantellare",
    "smantelliamo": "smantellare",
    "smantelliate": "smantellare",
    "smantellin": "smantellare",
    "smantellino": "smantellare",
    "smantello": "smantellare",
    "smantellò": "smantellare",
    "smarca": "smarcare",
    "smarcai": "smarcare",
    "smarcammo": "smarcare",
    "smarcan": "smarcare",
    "smarcando": "smarcare",
    "smarcano": "smarcare",
    "smarcante": "smarcare",
    "smarcanti": "smarcare",
    "smarcar": "smarcare",
    "smarcaron": "smarcare",
    "smarcarono": "smarcare",
    "smarcasse": "smarcare",
    "smarcasser": "smarcare",
    "smarcassero": "smarcare",
    "smarcassi": "smarcare",
    "smarcassimo": "smarcare",
    "smarcaste": "smarcare",
    "smarcasti": "smarcare",
    "smarcata": "smarcare",
    "smarcate": "smarcare",
    "smarcati": "smarcare",
    "smarcato": "smarcare",
    "smarcava": "smarcare",
    "smarcavamo": "smarcare",
    "smarcavan": "smarcare",
    "smarcavano": "smarcare",
    "smarcavate": "smarcare",
    "smarcavi": "smarcare",
    "smarcavo": "smarcare",
    "smarcherai": "smarcare",
    "smarcheran": "smarcare",
    "smarcheranno": "smarcare",
    "smarcherebbe": "smarcare",
    "smarcherebber": "smarcare",
    "smarcherebbero": "smarcare",
    "smarcherei": "smarcare",
    "smarcheremmo": "smarcare",
    "smarcheremo": "smarcare",
    "smarchereste": "smarcare",
    "smarcheresti": "smarcare",
    "smarcherete": "smarcare",
    "smarcherà": "smarcare",
    "smarcherò": "smarcare",
    "smarchi": "smarcare",
    "smarchiamo": "smarcare",
    "smarchiate": "smarcare",
    "smarchin": "smarcare",
    "smarchino": "smarcare",
    "smarco": "smarcare",
    "smarcò": "smarcare",
    "smargiassate": "smargiassata",
    "smargina": "smarginare",
    "smarginai": "smarginare",
    "smarginammo": "smarginare",
    "smarginan": "smarginare",
    "smarginando": "smarginare",
    "smarginano": "smarginare",
    "smarginante": "smarginare",
    "smarginanti": "smarginare",
    "smarginar": "smarginare",
    "smarginaron": "smarginare",
    "smarginarono": "smarginare",
    "smarginasse": "smarginare",
    "smarginasser": "smarginare",
    "smarginassero": "smarginare",
    "smarginassi": "smarginare",
    "smarginassimo": "smarginare",
    "smarginaste": "smarginare",
    "smarginasti": "smarginare",
    "smarginata": "smarginare",
    "smarginate": "smarginare",
    "smarginati": "smarginare",
    "smarginato": "smarginare",
    "smarginava": "smarginare",
    "smarginavamo": "smarginare",
    "smarginavan": "smarginare",
    "smarginavano": "smarginare",
    "smarginavate": "smarginare",
    "smarginavi": "smarginare",
    "smarginavo": "smarginare",
    "smarginerai": "smarginare",
    "smargineran": "smarginare",
    "smargineranno": "smarginare",
    "smarginerebbe": "smarginare",
    "smarginerebber": "smarginare",
    "smarginerebbero": "smarginare",
    "smarginerei": "smarginare",
    "smargineremmo": "smarginare",
    "smargineremo": "smarginare",
    "smarginereste": "smarginare",
    "smargineresti": "smarginare",
    "smarginerete": "smarginare",
    "smarginerà": "smarginare",
    "smarginerò": "smarginare",
    "smargini": "smarginare",
    "smarginiamo": "smarginare",
    "smarginiate": "smarginare",
    "smarginin": "smarginare",
    "smarginino": "smarginare",
    "smargino": "smarginare",
    "smarginò": "smarginare",
    "smarrendo": "smarrire",
    "smarrente": "smarrire",
    "smarrenti": "smarrire",
    "smarriamo": "smarrire",
    "smarriate": "smarrire",
    "smarrii": "smarrire",
    "smarrimenti": "smarrimento",
    "smarrimmo": "smarrire",
    "smarrir": "smarrire",
    "smarrirai": "smarrire",
    "smarriran": "smarrire",
    "smarriranno": "smarrire",
    "smarrirebbe": "smarrire",
    "smarrirebber": "smarrire",
    "smarrirebbero": "smarrire",
    "smarrirei": "smarrire",
    "smarriremmo": "smarrire",
    "smarriremo": "smarrire",
    "smarrireste": "smarrire",
    "smarriresti": "smarrire",
    "smarrirete": "smarrire",
    "smarriron": "smarrire",
    "smarrirono": "smarrire",
    "smarrirà": "smarrire",
    "smarrirò": "smarrire",
    "smarrisca": "smarrire",
    "smarriscan": "smarrire",
    "smarriscano": "smarrire",
    "smarrisce": "smarrire",
    "smarrisci": "smarrire",
    "smarrisco": "smarrire",
    "smarriscon": "smarrire",
    "smarriscono": "smarrire",
    "smarrisse": "smarrire",
    "smarrisser": "smarrire",
    "smarrissero": "smarrire",
    "smarrissi": "smarrire",
    "smarrissimo": "smarrire",
    "smarriste": "smarrire",
    "smarristi": "smarrire",
    "smarrita": "smarrito",
    "smarrite": "smarrito",
    "smarriti": "smarrito",
    "smarrito": "smarrire",
    "smarriva": "smarrire",
    "smarrivamo": "smarrire",
    "smarrivan": "smarrire",
    "smarrivano": "smarrire",
    "smarrivate": "smarrire",
    "smarrivi": "smarrire",
    "smarrivo": "smarrire",
    "smarrì": "smarrire",
    "smascella": "smascellare",
    "smascellai": "smascellare",
    "smascellammo": "smascellare",
    "smascellan": "smascellare",
    "smascellando": "smascellare",
    "smascellano": "smascellare",
    "smascellante": "smascellare",
    "smascellanti": "smascellare",
    "smascellar": "smascellare",
    "smascellaron": "smascellare",
    "smascellarono": "smascellare",
    "smascellasse": "smascellare",
    "smascellasser": "smascellare",
    "smascellassero": "smascellare",
    "smascellassi": "smascellare",
    "smascellassimo": "smascellare",
    "smascellaste": "smascellare",
    "smascellasti": "smascellare",
    "smascellata": "smascellare",
    "smascellate": "smascellare",
    "smascellati": "smascellare",
    "smascellato": "smascellare",
    "smascellava": "smascellare",
    "smascellavamo": "smascellare",
    "smascellavan": "smascellare",
    "smascellavano": "smascellare",
    "smascellavate": "smascellare",
    "smascellavi": "smascellare",
    "smascellavo": "smascellare",
    "smascellerai": "smascellare",
    "smascelleran": "smascellare",
    "smascelleranno": "smascellare",
    "smascellerebbe": "smascellare",
    "smascellerebber": "smascellare",
    "smascellerebbero": "smascellare",
    "smascellerei": "smascellare",
    "smascelleremmo": "smascellare",
    "smascelleremo": "smascellare",
    "smascellereste": "smascellare",
    "smascelleresti": "smascellare",
    "smascellerete": "smascellare",
    "smascellerà": "smascellare",
    "smascellerò": "smascellare",
    "smascelli": "smascellare",
    "smascelliamo": "smascellare",
    "smascelliate": "smascellare",
    "smascellin": "smascellare",
    "smascellino": "smascellare",
    "smascello": "smascellare",
    "smascellò": "smascellare",
    "smaschera": "smascherare",
    "smascherai": "smascherare",
    "smascherammo": "smascherare",
    "smascheran": "smascherare",
    "smascherando": "smascherare",
    "smascherano": "smascherare",
    "smascherante": "smascherare",
    "smascheranti": "smascherare",
    "smascherar": "smascherare",
    "smascheraron": "smascherare",
    "smascherarono": "smascherare",
    "smascherasse": "smascherare",
    "smascherasser": "smascherare",
    "smascherassero": "smascherare",
    "smascherassi": "smascherare",
    "smascherassimo": "smascherare",
    "smascheraste": "smascherare",
    "smascherasti": "smascherare",
    "smascherata": "smascherare",
    "smascherate": "smascherare",
    "smascherati": "smascherare",
    "smascherato": "smascherare",
    "smascherava": "smascherare",
    "smascheravamo": "smascherare",
    "smascheravan": "smascherare",
    "smascheravano": "smascherare",
    "smascheravate": "smascherare",
    "smascheravi": "smascherare",
    "smascheravo": "smascherare",
    "smaschererai": "smascherare",
    "smaschereran": "smascherare",
    "smaschereranno": "smascherare",
    "smaschererebbe": "smascherare",
    "smaschererebber": "smascherare",
    "smaschererebbero": "smascherare",
    "smaschererei": "smascherare",
    "smaschereremmo": "smascherare",
    "smaschereremo": "smascherare",
    "smascherereste": "smascherare",
    "smaschereresti": "smascherare",
    "smaschererete": "smascherare",
    "smaschererà": "smascherare",
    "smaschererò": "smascherare",
    "smascheri": "smascherare",
    "smascheriamo": "smascherare",
    "smascheriate": "smascherare",
    "smascherin": "smascherare",
    "smascherino": "smascherare",
    "smaschero": "smascherare",
    "smascherò": "smascherare",
    "smaterializza": "smaterializzare",
    "smaterializzai": "smaterializzare",
    "smaterializzammo": "smaterializzare",
    "smaterializzan": "smaterializzare",
    "smaterializzando": "smaterializzare",
    "smaterializzano": "smaterializzare",
    "smaterializzante": "smaterializzare",
    "smaterializzanti": "smaterializzare",
    "smaterializzar": "smaterializzare",
    "smaterializzaron": "smaterializzare",
    "smaterializzarono": "smaterializzare",
    "smaterializzasse": "smaterializzare",
    "smaterializzasser": "smaterializzare",
    "smaterializzassero": "smaterializzare",
    "smaterializzassi": "smaterializzare",
    "smaterializzassimo": "smaterializzare",
    "smaterializzaste": "smaterializzare",
    "smaterializzasti": "smaterializzare",
    "smaterializzata": "smaterializzare",
    "smaterializzate": "smaterializzare",
    "smaterializzati": "smaterializzare",
    "smaterializzato": "smaterializzare",
    "smaterializzava": "smaterializzare",
    "smaterializzavamo": "smaterializzare",
    "smaterializzavan": "smaterializzare",
    "smaterializzavano": "smaterializzare",
    "smaterializzavate": "smaterializzare",
    "smaterializzavi": "smaterializzare",
    "smaterializzavo": "smaterializzare",
    "smaterializzerai": "smaterializzare",
    "smaterializzeran": "smaterializzare",
    "smaterializzeranno": "smaterializzare",
    "smaterializzerebbe": "smaterializzare",
    "smaterializzerebber": "smaterializzare",
    "smaterializzerebbero": "smaterializzare",
    "smaterializzerei": "smaterializzare",
    "smaterializzeremmo": "smaterializzare",
    "smaterializzeremo": "smaterializzare",
    "smaterializzereste": "smaterializzare",
    "smaterializzeresti": "smaterializzare",
    "smaterializzerete": "smaterializzare",
    "smaterializzerà": "smaterializzare",
    "smaterializzerò": "smaterializzare",
    "smaterializzi": "smaterializzare",
    "smaterializziamo": "smaterializzare",
    "smaterializziate": "smaterializzare",
    "smaterializzin": "smaterializzare",
    "smaterializzino": "smaterializzare",
    "smaterializzo": "smaterializzare",
    "smaterializzò": "smaterializzare",
    "smembra": "smembrare",
    "smembrai": "smembrare",
    "smembramenti": "smembramento",
    "smembrammo": "smembrare",
    "smembran": "smembrare",
    "smembrando": "smembrare",
    "smembrano": "smembrare",
    "smembrante": "smembrare",
    "smembranti": "smembrare",
    "smembrar": "smembrare",
    "smembraron": "smembrare",
    "smembrarono": "smembrare",
    "smembrasse": "smembrare",
    "smembrasser": "smembrare",
    "smembrassero": "smembrare",
    "smembrassi": "smembrare",
    "smembrassimo": "smembrare",
    "smembraste": "smembrare",
    "smembrasti": "smembrare",
    "smembrata": "smembrare",
    "smembrate": "smembrare",
    "smembrati": "smembrare",
    "smembrato": "smembrare",
    "smembrava": "smembrare",
    "smembravamo": "smembrare",
    "smembravan": "smembrare",
    "smembravano": "smembrare",
    "smembravate": "smembrare",
    "smembravi": "smembrare",
    "smembravo": "smembrare",
    "smembrerai": "smembrare",
    "smembreran": "smembrare",
    "smembreranno": "smembrare",
    "smembrerebbe": "smembrare",
    "smembrerebber": "smembrare",
    "smembrerebbero": "smembrare",
    "smembrerei": "smembrare",
    "smembreremmo": "smembrare",
    "smembreremo": "smembrare",
    "smembrereste": "smembrare",
    "smembreresti": "smembrare",
    "smembrerete": "smembrare",
    "smembrerà": "smembrare",
    "smembrerò": "smembrare",
    "smembri": "smembrare",
    "smembriamo": "smembrare",
    "smembriate": "smembrare",
    "smembrin": "smembrare",
    "smembrino": "smembrare",
    "smembro": "smembrare",
    "smembrò": "smembrare",
    "smemora": "smemorare",
    "smemorai": "smemorare",
    "smemorammo": "smemorare",
    "smemoran": "smemorare",
    "smemorando": "smemorare",
    "smemorano": "smemorare",
    "smemorante": "smemorare",
    "smemoranti": "smemorare",
    "smemorar": "smemorare",
    "smemoraron": "smemorare",
    "smemorarono": "smemorare",
    "smemorasse": "smemorare",
    "smemorasser": "smemorare",
    "smemorassero": "smemorare",
    "smemorassi": "smemorare",
    "smemorassimo": "smemorare",
    "smemoraste": "smemorare",
    "smemorasti": "smemorare",
    "smemorata": "smemorato",
    "smemorate": "smemorato",
    "smemoratezze": "smemoratezza",
    "smemorati": "smemorato",
    "smemorato": "smemorare",
    "smemorava": "smemorare",
    "smemoravamo": "smemorare",
    "smemoravan": "smemorare",
    "smemoravano": "smemorare",
    "smemoravate": "smemorare",
    "smemoravi": "smemorare",
    "smemoravo": "smemorare",
    "smemorerai": "smemorare",
    "smemoreran": "smemorare",
    "smemoreranno": "smemorare",
    "smemorerebbe": "smemorare",
    "smemorerebber": "smemorare",
    "smemorerebbero": "smemorare",
    "smemorerei": "smemorare",
    "smemoreremmo": "smemorare",
    "smemoreremo": "smemorare",
    "smemorereste": "smemorare",
    "smemoreresti": "smemorare",
    "smemorerete": "smemorare",
    "smemorerà": "smemorare",
    "smemorerò": "smemorare",
    "smemori": "smemorare",
    "smemoriamo": "smemorare",
    "smemoriate": "smemorare",
    "smemorin": "smemorare",
    "smemorino": "smemorare",
    "smemoro": "smemorare",
    "smemorò": "smemorare",
    "smentendo": "smentire",
    "smentente": "smentire",
    "smententi": "smentire",
    "smentiamo": "smentire",
    "smentiate": "smentire",
    "smentii": "smentire",
    "smentimmo": "smentire",
    "smentir": "smentire",
    "smentirai": "smentire",
    "smentiran": "smentire",
    "smentiranno": "smentire",
    "smentirebbe": "smentire",
    "smentirebber": "smentire",
    "smentirebbero": "smentire",
    "smentirei": "smentire",
    "smentiremmo": "smentire",
    "smentiremo": "smentire",
    "smentireste": "smentire",
    "smentiresti": "smentire",
    "smentirete": "smentire",
    "smentiron": "smentire",
    "smentirono": "smentire",
    "smentirà": "smentire",
    "smentirò": "smentire",
    "smentisca": "smentire",
    "smentiscan": "smentire",
    "smentiscano": "smentire",
    "smentisce": "smentire",
    "smentisci": "smentire",
    "smentisco": "smentire",
    "smentiscon": "smentire",
    "smentiscono": "smentire",
    "smentisse": "smentire",
    "smentisser": "smentire",
    "smentissero": "smentire",
    "smentissi": "smentire",
    "smentissimo": "smentire",
    "smentiste": "smentire",
    "smentisti": "smentire",
    "smentita": "smentire",
    "smentite": "smentita",
    "smentiti": "smentire",
    "smentito": "smentire",
    "smentiva": "smentire",
    "smentivamo": "smentire",
    "smentivan": "smentire",
    "smentivano": "smentire",
    "smentivate": "smentire",
    "smentivi": "smentire",
    "smentivo": "smentire",
    "smentì": "smentire",
    "smeraldina": "smeraldino",
    "smeraldine": "smeraldino",
    "smeraldini": "smeraldino",
    "smercerai": "smerciare",
    "smerceran": "smerciare",
    "smerceranno": "smerciare",
    "smercerebbe": "smerciare",
    "smercerebber": "smerciare",
    "smercerebbero": "smerciare",
    "smercerei": "smerciare",
    "smerceremmo": "smerciare",
    "smerceremo": "smerciare",
    "smercereste": "smerciare",
    "smerceresti": "smerciare",
    "smercerete": "smerciare",
    "smercerà": "smerciare",
    "smercerò": "smerciare",
    "smerci": "smercio",
    "smercia": "smerciare",
    "smerciai": "smerciare",
    "smerciammo": "smerciare",
    "smerciamo": "smerciare",
    "smercian": "smerciare",
    "smerciando": "smerciare",
    "smerciano": "smerciare",
    "smerciante": "smerciare",
    "smercianti": "smerciare",
    "smerciar": "smerciare",
    "smerciaron": "smerciare",
    "smerciarono": "smerciare",
    "smerciasse": "smerciare",
    "smerciasser": "smerciare",
    "smerciassero": "smerciare",
    "smerciassi": "smerciare",
    "smerciassimo": "smerciare",
    "smerciaste": "smerciare",
    "smerciasti": "smerciare",
    "smerciata": "smerciare",
    "smerciate": "smerciare",
    "smerciati": "smerciare",
    "smerciato": "smerciare",
    "smerciava": "smerciare",
    "smerciavamo": "smerciare",
    "smerciavan": "smerciare",
    "smerciavano": "smerciare",
    "smerciavate": "smerciare",
    "smerciavi": "smerciare",
    "smerciavo": "smerciare",
    "smercin": "smerciare",
    "smercino": "smerciare",
    "smercio": "smerciare",
    "smerciò": "smerciare",
    "smerigli": "smerigliare",
    "smeriglia": "smerigliare",
    "smerigliai": "smerigliare",
    "smerigliammo": "smerigliare",
    "smerigliamo": "smerigliare",
    "smeriglian": "smerigliare",
    "smerigliando": "smerigliare",
    "smerigliano": "smerigliare",
    "smerigliante": "smerigliare",
    "smeriglianti": "smerigliare",
    "smerigliar": "smerigliare",
    "smerigliaron": "smerigliare",
    "smerigliarono": "smerigliare",
    "smerigliasse": "smerigliare",
    "smerigliasser": "smerigliare",
    "smerigliassero": "smerigliare",
    "smerigliassi": "smerigliare",
    "smerigliassimo": "smerigliare",
    "smerigliaste": "smerigliare",
    "smerigliasti": "smerigliare",
    "smerigliata": "smerigliare",
    "smerigliate": "smerigliare",
    "smerigliati": "smerigliare",
    "smerigliato": "smerigliare",
    "smerigliava": "smerigliare",
    "smerigliavamo": "smerigliare",
    "smerigliavan": "smerigliare",
    "smerigliavano": "smerigliare",
    "smerigliavate": "smerigliare",
    "smerigliavi": "smerigliare",
    "smerigliavo": "smerigliare",
    "smeriglierai": "smerigliare",
    "smeriglieran": "smerigliare",
    "smeriglieranno": "smerigliare",
    "smeriglierebbe": "smerigliare",
    "smeriglierebber": "smerigliare",
    "smeriglierebbero": "smerigliare",
    "smeriglierei": "smerigliare",
    "smeriglieremmo": "smerigliare",
    "smeriglieremo": "smerigliare",
    "smerigliereste": "smerigliare",
    "smeriglieresti": "smerigliare",
    "smeriglierete": "smerigliare",
    "smeriglierà": "smerigliare",
    "smeriglierò": "smerigliare",
    "smeriglin": "smerigliare",
    "smeriglino": "smerigliare",
    "smeriglio": "smerigliare",
    "smerigliò": "smerigliare",
    "smerla": "smerlare",
    "smerlai": "smerlare",
    "smerlammo": "smerlare",
    "smerlan": "smerlare",
    "smerlando": "smerlare",
    "smerlano": "smerlare",
    "smerlante": "smerlare",
    "smerlanti": "smerlare",
    "smerlar": "smerlare",
    "smerlaron": "smerlare",
    "smerlarono": "smerlare",
    "smerlasse": "smerlare",
    "smerlasser": "smerlare",
    "smerlassero": "smerlare",
    "smerlassi": "smerlare",
    "smerlassimo": "smerlare",
    "smerlaste": "smerlare",
    "smerlasti": "smerlare",
    "smerlata": "smerlare",
    "smerlate": "smerlare",
    "smerlati": "smerlare",
    "smerlato": "smerlare",
    "smerlava": "smerlare",
    "smerlavamo": "smerlare",
    "smerlavan": "smerlare",
    "smerlavano": "smerlare",
    "smerlavate": "smerlare",
    "smerlavi": "smerlare",
    "smerlavo": "smerlare",
    "smerlerai": "smerlare",
    "smerleran": "smerlare",
    "smerleranno": "smerlare",
    "smerlerebbe": "smerlare",
    "smerlerebber": "smerlare",
    "smerlerebbero": "smerlare",
    "smerlerei": "smerlare",
    "smerleremmo": "smerlare",
    "smerleremo": "smerlare",
    "smerlereste": "smerlare",
    "smerleresti": "smerlare",
    "smerlerete": "smerlare",
    "smerlerà": "smerlare",
    "smerlerò": "smerlare",
    "smerli": "smerlare",
    "smerliamo": "smerlare",
    "smerliate": "smerlare",
    "smerlin": "smerlare",
    "smerlino": "smerlare",
    "smerlo": "smerlare",
    "smerlò": "smerlare",
    "smessa": "smettere",
    "smesse": "smettere",
    "smessi": "smettere",
    "smesso": "smettere",
    "smetta": "smettere",
    "smettan": "smettere",
    "smettano": "smettere",
    "smette": "smettere",
    "smettemmo": "smettere",
    "smettendo": "smettere",
    "smettente": "smettere",
    "smettenti": "smettere",
    "smetter": "smettere",
    "smetterai": "smettere",
    "smetteran": "smettere",
    "smetteranno": "smettere",
    "smetterebbe": "smettere",
    "smetterebber": "smettere",
    "smetterebbero": "smettere",
    "smetterei": "smettere",
    "smetteremmo": "smettere",
    "smetteremo": "smettere",
    "smettereste": "smettere",
    "smetteresti": "smettere",
    "smetterete": "smettere",
    "smetterà": "smettere",
    "smetterò": "smettere",
    "smettesse": "smettere",
    "smettesser": "smettere",
    "smettessero": "smettere",
    "smettessi": "smettere",
    "smettessimo": "smettere",
    "smetteste": "smettere",
    "smettesti": "smettere",
    "smettete": "smettere",
    "smetteva": "smettere",
    "smettevamo": "smettere",
    "smettevan": "smettere",
    "smettevano": "smettere",
    "smettevate": "smettere",
    "smettevi": "smettere",
    "smettevo": "smettere",
    "smetti": "smettere",
    "smettiamo": "smettere",
    "smettiate": "smettere",
    "smetto": "smettere",
    "smetton": "smettere",
    "smettono": "smettere",
    "smezza": "smezzare",
    "smezzai": "smezzare",
    "smezzammo": "smezzare",
    "smezzan": "smezzare",
    "smezzando": "smezzare",
    "smezzano": "smezzare",
    "smezzante": "smezzare",
    "smezzanti": "smezzare",
    "smezzar": "smezzare",
    "smezzaron": "smezzare",
    "smezzarono": "smezzare",
    "smezzasse": "smezzare",
    "smezzasser": "smezzare",
    "smezzassero": "smezzare",
    "smezzassi": "smezzare",
    "smezzassimo": "smezzare",
    "smezzaste": "smezzare",
    "smezzasti": "smezzare",
    "smezzata": "smezzare",
    "smezzate": "smezzare",
    "smezzati": "smezzare",
    "smezzato": "smezzare",
    "smezzava": "smezzare",
    "smezzavamo": "smezzare",
    "smezzavan": "smezzare",
    "smezzavano": "smezzare",
    "smezzavate": "smezzare",
    "smezzavi": "smezzare",
    "smezzavo": "smezzare",
    "smezzerai": "smezzare",
    "smezzeran": "smezzare",
    "smezzeranno": "smezzare",
    "smezzerebbe": "smezzare",
    "smezzerebber": "smezzare",
    "smezzerebbero": "smezzare",
    "smezzerei": "smezzare",
    "smezzeremmo": "smezzare",
    "smezzeremo": "smezzare",
    "smezzereste": "smezzare",
    "smezzeresti": "smezzare",
    "smezzerete": "smezzare",
    "smezzerà": "smezzare",
    "smezzerò": "smezzare",
    "smezzi": "smezzare",
    "smezziamo": "smezzare",
    "smezziate": "smezzare",
    "smezzin": "smezzare",
    "smezzino": "smezzare",
    "smezzo": "smezzare",
    "smezzò": "smezzare",
    "smidolla": "smidollare",
    "smidollai": "smidollare",
    "smidollammo": "smidollare",
    "smidollan": "smidollare",
    "smidollando": "smidollare",
    "smidollano": "smidollare",
    "smidollante": "smidollare",
    "smidollanti": "smidollare",
    "smidollar": "smidollare",
    "smidollaron": "smidollare",
    "smidollarono": "smidollare",
    "smidollasse": "smidollare",
    "smidollasser": "smidollare",
    "smidollassero": "smidollare",
    "smidollassi": "smidollare",
    "smidollassimo": "smidollare",
    "smidollaste": "smidollare",
    "smidollasti": "smidollare",
    "smidollata": "smidollato",
    "smidollate": "smidollato",
    "smidollati": "smidollato",
    "smidollato": "smidollare",
    "smidollava": "smidollare",
    "smidollavamo": "smidollare",
    "smidollavan": "smidollare",
    "smidollavano": "smidollare",
    "smidollavate": "smidollare",
    "smidollavi": "smidollare",
    "smidollavo": "smidollare",
    "smidollerai": "smidollare",
    "smidolleran": "smidollare",
    "smidolleranno": "smidollare",
    "smidollerebbe": "smidollare",
    "smidollerebber": "smidollare",
    "smidollerebbero": "smidollare",
    "smidollerei": "smidollare",
    "smidolleremmo": "smidollare",
    "smidolleremo": "smidollare",
    "smidollereste": "smidollare",
    "smidolleresti": "smidollare",
    "smidollerete": "smidollare",
    "smidollerà": "smidollare",
    "smidollerò": "smidollare",
    "smidolli": "smidollare",
    "smidolliamo": "smidollare",
    "smidolliate": "smidollare",
    "smidollin": "smidollare",
    "smidollino": "smidollare",
    "smidollo": "smidollare",
    "smidollò": "smidollare",
    "smiela": "smielare",
    "smielai": "smielare",
    "smielammo": "smielare",
    "smielan": "smielare",
    "smielando": "smielare",
    "smielano": "smielare",
    "smielante": "smielare",
    "smielanti": "smielare",
    "smielar": "smielare",
    "smielaron": "smielare",
    "smielarono": "smielare",
    "smielasse": "smielare",
    "smielasser": "smielare",
    "smielassero": "smielare",
    "smielassi": "smielare",
    "smielassimo": "smielare",
    "smielaste": "smielare",
    "smielasti": "smielare",
    "smielata": "smielare",
    "smielate": "smielare",
    "smielati": "smielare",
    "smielato": "smielare",
    "smielava": "smielare",
    "smielavamo": "smielare",
    "smielavan": "smielare",
    "smielavano": "smielare",
    "smielavate": "smielare",
    "smielavi": "smielare",
    "smielavo": "smielare",
    "smielerai": "smielare",
    "smieleran": "smielare",
    "smieleranno": "smielare",
    "smielerebbe": "smielare",
    "smielerebber": "smielare",
    "smielerebbero": "smielare",
    "smielerei": "smielare",
    "smieleremmo": "smielare",
    "smieleremo": "smielare",
    "smielereste": "smielare",
    "smieleresti": "smielare",
    "smielerete": "smielare",
    "smielerà": "smielare",
    "smielerò": "smielare",
    "smieli": "smielare",
    "smieliamo": "smielare",
    "smieliate": "smielare",
    "smielin": "smielare",
    "smielino": "smielare",
    "smielo": "smielare",
    "smielò": "smielare",
    "smilitarizza": "smilitarizzare",
    "smilitarizzai": "smilitarizzare",
    "smilitarizzammo": "smilitarizzare",
    "smilitarizzan": "smilitarizzare",
    "smilitarizzando": "smilitarizzare",
    "smilitarizzano": "smilitarizzare",
    "smilitarizzante": "smilitarizzare",
    "smilitarizzanti": "smilitarizzare",
    "smilitarizzar": "smilitarizzare",
    "smilitarizzaron": "smilitarizzare",
    "smilitarizzarono": "smilitarizzare",
    "smilitarizzasse": "smilitarizzare",
    "smilitarizzasser": "smilitarizzare",
    "smilitarizzassero": "smilitarizzare",
    "smilitarizzassi": "smilitarizzare",
    "smilitarizzassimo": "smilitarizzare",
    "smilitarizzaste": "smilitarizzare",
    "smilitarizzasti": "smilitarizzare",
    "smilitarizzata": "smilitarizzare",
    "smilitarizzate": "smilitarizzare",
    "smilitarizzati": "smilitarizzare",
    "smilitarizzato": "smilitarizzare",
    "smilitarizzava": "smilitarizzare",
    "smilitarizzavamo": "smilitarizzare",
    "smilitarizzavan": "smilitarizzare",
    "smilitarizzavano": "smilitarizzare",
    "smilitarizzavate": "smilitarizzare",
    "smilitarizzavi": "smilitarizzare",
    "smilitarizzavo": "smilitarizzare",
    "smilitarizzazioni": "smilitarizzazione",
    "smilitarizzerai": "smilitarizzare",
    "smilitarizzeran": "smilitarizzare",
    "smilitarizzeranno": "smilitarizzare",
    "smilitarizzerebbe": "smilitarizzare",
    "smilitarizzerebber": "smilitarizzare",
    "smilitarizzerebbero": "smilitarizzare",
    "smilitarizzerei": "smilitarizzare",
    "smilitarizzeremmo": "smilitarizzare",
    "smilitarizzeremo": "smilitarizzare",
    "smilitarizzereste": "smilitarizzare",
    "smilitarizzeresti": "smilitarizzare",
    "smilitarizzerete": "smilitarizzare",
    "smilitarizzerà": "smilitarizzare",
    "smilitarizzerò": "smilitarizzare",
    "smilitarizzi": "smilitarizzare",
    "smilitarizziamo": "smilitarizzare",
    "smilitarizziate": "smilitarizzare",
    "smilitarizzin": "smilitarizzare",
    "smilitarizzino": "smilitarizzare",
    "smilitarizzo": "smilitarizzare",
    "smilitarizzò": "smilitarizzare",
    "smilza": "smilzo",
    "smilze": "smilzo",
    "smilzi": "smilzo",
    "smina": "sminare",
    "sminai": "sminare",
    "sminammo": "sminare",
    "sminan": "sminare",
    "sminando": "sminare",
    "sminano": "sminare",
    "sminante": "sminare",
    "sminanti": "sminare",
    "sminar": "sminare",
    "sminaron": "sminare",
    "sminarono": "sminare",
    "sminasse": "sminare",
    "sminasser": "sminare",
    "sminassero": "sminare",
    "sminassi": "sminare",
    "sminassimo": "sminare",
    "sminaste": "sminare",
    "sminasti": "sminare",
    "sminata": "sminare",
    "sminate": "sminare",
    "sminati": "sminare",
    "sminato": "sminare",
    "sminava": "sminare",
    "sminavamo": "sminare",
    "sminavan": "sminare",
    "sminavano": "sminare",
    "sminavate": "sminare",
    "sminavi": "sminare",
    "sminavo": "sminare",
    "sminerai": "sminare",
    "smineran": "sminare",
    "smineranno": "sminare",
    "sminerebbe": "sminare",
    "sminerebber": "sminare",
    "sminerebbero": "sminare",
    "sminerei": "sminare",
    "smineremmo": "sminare",
    "smineremo": "sminare",
    "sminereste": "sminare",
    "smineresti": "sminare",
    "sminerete": "sminare",
    "sminerà": "sminare",
    "sminerò": "sminare",
    "smini": "sminare",
    "sminiamo": "sminare",
    "sminiate": "sminare",
    "sminin": "sminare",
    "sminino": "sminare",
    "smino": "sminare",
    "sminuendo": "sminuire",
    "sminuente": "sminuire",
    "sminuenti": "sminuire",
    "sminuiamo": "sminuire",
    "sminuiate": "sminuire",
    "sminuii": "sminuire",
    "sminuimmo": "sminuire",
    "sminuir": "sminuire",
    "sminuirai": "sminuire",
    "sminuiran": "sminuire",
    "sminuiranno": "sminuire",
    "sminuirebbe": "sminuire",
    "sminuirebber": "sminuire",
    "sminuirebbero": "sminuire",
    "sminuirei": "sminuire",
    "sminuiremmo": "sminuire",
    "sminuiremo": "sminuire",
    "sminuireste": "sminuire",
    "sminuiresti": "sminuire",
    "sminuirete": "sminuire",
    "sminuiron": "sminuire",
    "sminuirono": "sminuire",
    "sminuirà": "sminuire",
    "sminuirò": "sminuire",
    "sminuisca": "sminuire",
    "sminuiscan": "sminuire",
    "sminuiscano": "sminuire",
    "sminuisce": "sminuire",
    "sminuisci": "sminuire",
    "sminuisco": "sminuire",
    "sminuiscon": "sminuire",
    "sminuiscono": "sminuire",
    "sminuisse": "sminuire",
    "sminuisser": "sminuire",
    "sminuissero": "sminuire",
    "sminuissi": "sminuire",
    "sminuissimo": "sminuire",
    "sminuiste": "sminuire",
    "sminuisti": "sminuire",
    "sminuita": "sminuire",
    "sminuite": "sminuire",
    "sminuiti": "sminuire",
    "sminuito": "sminuire",
    "sminuiva": "sminuire",
    "sminuivamo": "sminuire",
    "sminuivan": "sminuire",
    "sminuivano": "sminuire",
    "sminuivate": "sminuire",
    "sminuivi": "sminuire",
    "sminuivo": "sminuire",
    "sminuzza": "sminuzzare",
    "sminuzzai": "sminuzzare",
    "sminuzzammo": "sminuzzare",
    "sminuzzan": "sminuzzare",
    "sminuzzando": "sminuzzare",
    "sminuzzano": "sminuzzare",
    "sminuzzante": "sminuzzare",
    "sminuzzanti": "sminuzzare",
    "sminuzzar": "sminuzzare",
    "sminuzzaron": "sminuzzare",
    "sminuzzarono": "sminuzzare",
    "sminuzzasse": "sminuzzare",
    "sminuzzasser": "sminuzzare",
    "sminuzzassero": "sminuzzare",
    "sminuzzassi": "sminuzzare",
    "sminuzzassimo": "sminuzzare",
    "sminuzzaste": "sminuzzare",
    "sminuzzasti": "sminuzzare",
    "sminuzzata": "sminuzzare",
    "sminuzzate": "sminuzzare",
    "sminuzzati": "sminuzzare",
    "sminuzzato": "sminuzzare",
    "sminuzzava": "sminuzzare",
    "sminuzzavamo": "sminuzzare",
    "sminuzzavan": "sminuzzare",
    "sminuzzavano": "sminuzzare",
    "sminuzzavate": "sminuzzare",
    "sminuzzavi": "sminuzzare",
    "sminuzzavo": "sminuzzare",
    "sminuzzerai": "sminuzzare",
    "sminuzzeran": "sminuzzare",
    "sminuzzeranno": "sminuzzare",
    "sminuzzerebbe": "sminuzzare",
    "sminuzzerebber": "sminuzzare",
    "sminuzzerebbero": "sminuzzare",
    "sminuzzerei": "sminuzzare",
    "sminuzzeremmo": "sminuzzare",
    "sminuzzeremo": "sminuzzare",
    "sminuzzereste": "sminuzzare",
    "sminuzzeresti": "sminuzzare",
    "sminuzzerete": "sminuzzare",
    "sminuzzerà": "sminuzzare",
    "sminuzzerò": "sminuzzare",
    "sminuzzi": "sminuzzare",
    "sminuzziamo": "sminuzzare",
    "sminuzziate": "sminuzzare",
    "sminuzzin": "sminuzzare",
    "sminuzzino": "sminuzzare",
    "sminuzzo": "sminuzzare",
    "sminuzzò": "sminuzzare",
    "sminuì": "sminuire",
    "sminò": "sminare",
    "smise": "smettere",
    "smiser": "smettere",
    "smisero": "smettere",
    "smisi": "smettere",
    "smista": "smistare",
    "smistai": "smistare",
    "smistamenti": "smistamento",
    "smistammo": "smistare",
    "smistan": "smistare",
    "smistando": "smistare",
    "smistano": "smistare",
    "smistante": "smistare",
    "smistanti": "smistare",
    "smistar": "smistare",
    "smistaron": "smistare",
    "smistarono": "smistare",
    "smistasse": "smistare",
    "smistasser": "smistare",
    "smistassero": "smistare",
    "smistassi": "smistare",
    "smistassimo": "smistare",
    "smistaste": "smistare",
    "smistasti": "smistare",
    "smistata": "smistare",
    "smistate": "smistare",
    "smistati": "smistare",
    "smistato": "smistare",
    "smistava": "smistare",
    "smistavamo": "smistare",
    "smistavan": "smistare",
    "smistavano": "smistare",
    "smistavate": "smistare",
    "smistavi": "smistare",
    "smistavo": "smistare",
    "smisterai": "smistare",
    "smisteran": "smistare",
    "smisteranno": "smistare",
    "smisterebbe": "smistare",
    "smisterebber": "smistare",
    "smisterebbero": "smistare",
    "smisterei": "smistare",
    "smisteremmo": "smistare",
    "smisteremo": "smistare",
    "smistereste": "smistare",
    "smisteresti": "smistare",
    "smisterete": "smistare",
    "smisterà": "smistare",
    "smisterò": "smistare",
    "smisti": "smistare",
    "smistiamo": "smistare",
    "smistiate": "smistare",
    "smistin": "smistare",
    "smistino": "smistare",
    "smisto": "smistare",
    "smistò": "smistare",
    "smisurata": "smisurato",
    "smisurate": "smisurato",
    "smisurati": "smisurato",
    "smitizza": "smitizzare",
    "smitizzai": "smitizzare",
    "smitizzammo": "smitizzare",
    "smitizzan": "smitizzare",
    "smitizzando": "smitizzare",
    "smitizzano": "smitizzare",
    "smitizzante": "smitizzare",
    "smitizzanti": "smitizzare",
    "smitizzar": "smitizzare",
    "smitizzaron": "smitizzare",
    "smitizzarono": "smitizzare",
    "smitizzasse": "smitizzare",
    "smitizzasser": "smitizzare",
    "smitizzassero": "smitizzare",
    "smitizzassi": "smitizzare",
    "smitizzassimo": "smitizzare",
    "smitizzaste": "smitizzare",
    "smitizzasti": "smitizzare",
    "smitizzata": "smitizzare",
    "smitizzate": "smitizzare",
    "smitizzati": "smitizzare",
    "smitizzato": "smitizzare",
    "smitizzava": "smitizzare",
    "smitizzavamo": "smitizzare",
    "smitizzavan": "smitizzare",
    "smitizzavano": "smitizzare",
    "smitizzavate": "smitizzare",
    "smitizzavi": "smitizzare",
    "smitizzavo": "smitizzare",
    "smitizzerai": "smitizzare",
    "smitizzeran": "smitizzare",
    "smitizzeranno": "smitizzare",
    "smitizzerebbe": "smitizzare",
    "smitizzerebber": "smitizzare",
    "smitizzerebbero": "smitizzare",
    "smitizzerei": "smitizzare",
    "smitizzeremmo": "smitizzare",
    "smitizzeremo": "smitizzare",
    "smitizzereste": "smitizzare",
    "smitizzeresti": "smitizzare",
    "smitizzerete": "smitizzare",
    "smitizzerà": "smitizzare",
    "smitizzerò": "smitizzare",
    "smitizzi": "smitizzare",
    "smitizziamo": "smitizzare",
    "smitizziate": "smitizzare",
    "smitizzin": "smitizzare",
    "smitizzino": "smitizzare",
    "smitizzo": "smitizzare",
    "smitizzò": "smitizzare",
    "smobilita": "smobilitare",
    "smobilitai": "smobilitare",
    "smobilitammo": "smobilitare",
    "smobilitan": "smobilitare",
    "smobilitando": "smobilitare",
    "smobilitano": "smobilitare",
    "smobilitante": "smobilitare",
    "smobilitanti": "smobilitare",
    "smobilitar": "smobilitare",
    "smobilitaron": "smobilitare",
    "smobilitarono": "smobilitare",
    "smobilitasse": "smobilitare",
    "smobilitasser": "smobilitare",
    "smobilitassero": "smobilitare",
    "smobilitassi": "smobilitare",
    "smobilitassimo": "smobilitare",
    "smobilitaste": "smobilitare",
    "smobilitasti": "smobilitare",
    "smobilitata": "smobilitare",
    "smobilitate": "smobilitare",
    "smobilitati": "smobilitare",
    "smobilitato": "smobilitare",
    "smobilitava": "smobilitare",
    "smobilitavamo": "smobilitare",
    "smobilitavan": "smobilitare",
    "smobilitavano": "smobilitare",
    "smobilitavate": "smobilitare",
    "smobilitavi": "smobilitare",
    "smobilitavo": "smobilitare",
    "smobilitazioni": "smobilitazione",
    "smobiliterai": "smobilitare",
    "smobiliteran": "smobilitare",
    "smobiliteranno": "smobilitare",
    "smobiliterebbe": "smobilitare",
    "smobiliterebber": "smobilitare",
    "smobiliterebbero": "smobilitare",
    "smobiliterei": "smobilitare",
    "smobiliteremmo": "smobilitare",
    "smobiliteremo": "smobilitare",
    "smobilitereste": "smobilitare",
    "smobiliteresti": "smobilitare",
    "smobiliterete": "smobilitare",
    "smobiliterà": "smobilitare",
    "smobiliterò": "smobilitare",
    "smobiliti": "smobilitare",
    "smobilitiamo": "smobilitare",
    "smobilitiate": "smobilitare",
    "smobilitin": "smobilitare",
    "smobilitino": "smobilitare",
    "smobilito": "smobilitare",
    "smobilitò": "smobilitare",
    "smobilizzi": "smobilizzo",
    "smoccola": "smoccolare",
    "smoccolai": "smoccolare",
    "smoccolammo": "smoccolare",
    "smoccolan": "smoccolare",
    "smoccolando": "smoccolare",
    "smoccolano": "smoccolare",
    "smoccolante": "smoccolare",
    "smoccolanti": "smoccolare",
    "smoccolar": "smoccolare",
    "smoccolaron": "smoccolare",
    "smoccolarono": "smoccolare",
    "smoccolasse": "smoccolare",
    "smoccolasser": "smoccolare",
    "smoccolassero": "smoccolare",
    "smoccolassi": "smoccolare",
    "smoccolassimo": "smoccolare",
    "smoccolaste": "smoccolare",
    "smoccolasti": "smoccolare",
    "smoccolata": "smoccolare",
    "smoccolate": "smoccolare",
    "smoccolati": "smoccolare",
    "smoccolato": "smoccolare",
    "smoccolava": "smoccolare",
    "smoccolavamo": "smoccolare",
    "smoccolavan": "smoccolare",
    "smoccolavano": "smoccolare",
    "smoccolavate": "smoccolare",
    "smoccolavi": "smoccolare",
    "smoccolavo": "smoccolare",
    "smoccolerai": "smoccolare",
    "smoccoleran": "smoccolare",
    "smoccoleranno": "smoccolare",
    "smoccolerebbe": "smoccolare",
    "smoccolerebber": "smoccolare",
    "smoccolerebbero": "smoccolare",
    "smoccolerei": "smoccolare",
    "smoccoleremmo": "smoccolare",
    "smoccoleremo": "smoccolare",
    "smoccolereste": "smoccolare",
    "smoccoleresti": "smoccolare",
    "smoccolerete": "smoccolare",
    "smoccolerà": "smoccolare",
    "smoccolerò": "smoccolare",
    "smoccoli": "smoccolare",
    "smoccoliamo": "smoccolare",
    "smoccoliate": "smoccolare",
    "smoccolin": "smoccolare",
    "smoccolino": "smoccolare",
    "smoccolo": "smoccolare",
    "smoccolò": "smoccolare",
    "smodata": "smodato",
    "smodate": "smodato",
    "smodati": "smodato",
    "smonaca": "smonacare",
    "smonacai": "smonacare",
    "smonacammo": "smonacare",
    "smonacan": "smonacare",
    "smonacando": "smonacare",
    "smonacano": "smonacare",
    "smonacante": "smonacare",
    "smonacanti": "smonacare",
    "smonacar": "smonacare",
    "smonacaron": "smonacare",
    "smonacarono": "smonacare",
    "smonacasse": "smonacare",
    "smonacasser": "smonacare",
    "smonacassero": "smonacare",
    "smonacassi": "smonacare",
    "smonacassimo": "smonacare",
    "smonacaste": "smonacare",
    "smonacasti": "smonacare",
    "smonacata": "smonacare",
    "smonacate": "smonacare",
    "smonacati": "smonacare",
    "smonacato": "smonacare",
    "smonacava": "smonacare",
    "smonacavamo": "smonacare",
    "smonacavan": "smonacare",
    "smonacavano": "smonacare",
    "smonacavate": "smonacare",
    "smonacavi": "smonacare",
    "smonacavo": "smonacare",
    "smonacherai": "smonacare",
    "smonacheran": "smonacare",
    "smonacheranno": "smonacare",
    "smonacherebbe": "smonacare",
    "smonacherebber": "smonacare",
    "smonacherebbero": "smonacare",
    "smonacherei": "smonacare",
    "smonacheremmo": "smonacare",
    "smonacheremo": "smonacare",
    "smonachereste": "smonacare",
    "smonacheresti": "smonacare",
    "smonacherete": "smonacare",
    "smonacherà": "smonacare",
    "smonacherò": "smonacare",
    "smonachi": "smonacare",
    "smonachiamo": "smonacare",
    "smonachiate": "smonacare",
    "smonachin": "smonacare",
    "smonachino": "smonacare",
    "smonaco": "smonacare",
    "smonacò": "smonacare",
    "smonta": "smontare",
    "smontabili": "smontabile",
    "smontaggi": "smontaggio",
    "smontai": "smontare",
    "smontammo": "smontare",
    "smontan": "smontare",
    "smontando": "smontare",
    "smontano": "smontare",
    "smontante": "smontare",
    "smontanti": "smontare",
    "smontar": "smontare",
    "smontaron": "smontare",
    "smontarono": "smontare",
    "smontasse": "smontare",
    "smontasser": "smontare",
    "smontassero": "smontare",
    "smontassi": "smontare",
    "smontassimo": "smontare",
    "smontaste": "smontare",
    "smontasti": "smontare",
    "smontata": "smontare",
    "smontate": "smontare",
    "smontati": "smontare",
    "smontato": "smontare",
    "smontava": "smontare",
    "smontavamo": "smontare",
    "smontavan": "smontare",
    "smontavano": "smontare",
    "smontavate": "smontare",
    "smontavi": "smontare",
    "smontavo": "smontare",
    "smonterai": "smontare",
    "smonteran": "smontare",
    "smonteranno": "smontare",
    "smonterebbe": "smontare",
    "smonterebber": "smontare",
    "smonterebbero": "smontare",
    "smonterei": "smontare",
    "smonteremmo": "smontare",
    "smonteremo": "smontare",
    "smontereste": "smontare",
    "smonteresti": "smontare",
    "smonterete": "smontare",
    "smonterà": "smontare",
    "smonterò": "smontare",
    "smonti": "smontare",
    "smontiamo": "smontare",
    "smontiate": "smontare",
    "smontin": "smontare",
    "smontino": "smontare",
    "smonto": "smontare",
    "smontò": "smontare",
    "smorfie": "smorfia",
    "smorfiosa": "smorfioso",
    "smorfiose": "smorfioso",
    "smorfiosi": "smorfioso",
    "smorta": "smorto",
    "smorte": "smorto",
    "smorti": "smorto",
    "smorza": "smorzare",
    "smorzai": "smorzare",
    "smorzammo": "smorzare",
    "smorzan": "smorzare",
    "smorzando": "smorzare",
    "smorzano": "smorzare",
    "smorzante": "smorzare",
    "smorzanti": "smorzare",
    "smorzar": "smorzare",
    "smorzaron": "smorzare",
    "smorzarono": "smorzare",
    "smorzasse": "smorzare",
    "smorzasser": "smorzare",
    "smorzassero": "smorzare",
    "smorzassi": "smorzare",
    "smorzassimo": "smorzare",
    "smorzaste": "smorzare",
    "smorzasti": "smorzare",
    "smorzata": "smorzare",
    "smorzate": "smorzata",
    "smorzati": "smorzare",
    "smorzato": "smorzare",
    "smorzava": "smorzare",
    "smorzavamo": "smorzare",
    "smorzavan": "smorzare",
    "smorzavano": "smorzare",
    "smorzavate": "smorzare",
    "smorzavi": "smorzare",
    "smorzavo": "smorzare",
    "smorzerai": "smorzare",
    "smorzeran": "smorzare",
    "smorzeranno": "smorzare",
    "smorzerebbe": "smorzare",
    "smorzerebber": "smorzare",
    "smorzerebbero": "smorzare",
    "smorzerei": "smorzare",
    "smorzeremmo": "smorzare",
    "smorzeremo": "smorzare",
    "smorzereste": "smorzare",
    "smorzeresti": "smorzare",
    "smorzerete": "smorzare",
    "smorzerà": "smorzare",
    "smorzerò": "smorzare",
    "smorzi": "smorzare",
    "smorziamo": "smorzare",
    "smorziate": "smorzare",
    "smorzin": "smorzare",
    "smorzino": "smorzare",
    "smorzo": "smorzare",
    "smorzò": "smorzare",
    "smossa": "smuovere",
    "smosse": "smuovere",
    "smosser": "smuovere",
    "smossero": "smuovere",
    "smossi": "smuovere",
    "smosso": "smuovere",
    "smotta": "smottare",
    "smottai": "smottare",
    "smottamenti": "smottamento",
    "smottammo": "smottare",
    "smottan": "smottare",
    "smottando": "smottare",
    "smottano": "smottare",
    "smottante": "smottare",
    "smottanti": "smottare",
    "smottar": "smottare",
    "smottaron": "smottare",
    "smottarono": "smottare",
    "smottasse": "smottare",
    "smottasser": "smottare",
    "smottassero": "smottare",
    "smottassi": "smottare",
    "smottassimo": "smottare",
    "smottaste": "smottare",
    "smottasti": "smottare",
    "smottata": "smottare",
    "smottate": "smottare",
    "smottati": "smottare",
    "smottato": "smottare",
    "smottava": "smottare",
    "smottavamo": "smottare",
    "smottavan": "smottare",
    "smottavano": "smottare",
    "smottavate": "smottare",
    "smottavi": "smottare",
    "smottavo": "smottare",
    "smotterai": "smottare",
    "smotteran": "smottare",
    "smotteranno": "smottare",
    "smotterebbe": "smottare",
    "smotterebber": "smottare",
    "smotterebbero": "smottare",
    "smotterei": "smottare",
    "smotteremmo": "smottare",
    "smotteremo": "smottare",
    "smottereste": "smottare",
    "smotteresti": "smottare",
    "smotterete": "smottare",
    "smotterà": "smottare",
    "smotterò": "smottare",
    "smotti": "smottare",
    "smottiamo": "smottare",
    "smottiate": "smottare",
    "smottin": "smottare",
    "smottino": "smottare",
    "smotto": "smottare",
    "smottò": "smottare",
    "smozzica": "smozzicare",
    "smozzicai": "smozzicare",
    "smozzicammo": "smozzicare",
    "smozzican": "smozzicare",
    "smozzicando": "smozzicare",
    "smozzicano": "smozzicare",
    "smozzicante": "smozzicare",
    "smozzicanti": "smozzicare",
    "smozzicar": "smozzicare",
    "smozzicaron": "smozzicare",
    "smozzicarono": "smozzicare",
    "smozzicasse": "smozzicare",
    "smozzicasser": "smozzicare",
    "smozzicassero": "smozzicare",
    "smozzicassi": "smozzicare",
    "smozzicassimo": "smozzicare",
    "smozzicaste": "smozzicare",
    "smozzicasti": "smozzicare",
    "smozzicata": "smozzicare",
    "smozzicate": "smozzicare",
    "smozzicati": "smozzicare",
    "smozzicato": "smozzicare",
    "smozzicava": "smozzicare",
    "smozzicavamo": "smozzicare",
    "smozzicavan": "smozzicare",
    "smozzicavano": "smozzicare",
    "smozzicavate": "smozzicare",
    "smozzicavi": "smozzicare",
    "smozzicavo": "smozzicare",
    "smozzicherai": "smozzicare",
    "smozzicheran": "smozzicare",
    "smozzicheranno": "smozzicare",
    "smozzicherebbe": "smozzicare",
    "smozzicherebber": "smozzicare",
    "smozzicherebbero": "smozzicare",
    "smozzicherei": "smozzicare",
    "smozzicheremmo": "smozzicare",
    "smozzicheremo": "smozzicare",
    "smozzichereste": "smozzicare",
    "smozzicheresti": "smozzicare",
    "smozzicherete": "smozzicare",
    "smozzicherà": "smozzicare",
    "smozzicherò": "smozzicare",
    "smozzichi": "smozzicare",
    "smozzichiamo": "smozzicare",
    "smozzichiate": "smozzicare",
    "smozzichin": "smozzicare",
    "smozzichino": "smozzicare",
    "smozzico": "smozzicare",
    "smozzicò": "smozzicare",
    "smunga": "smungere",
    "smungan": "smungere",
    "smungano": "smungere",
    "smunge": "smungere",
    "smungemmo": "smungere",
    "smungendo": "smungere",
    "smungente": "smungere",
    "smungenti": "smungere",
    "smunger": "smungere",
    "smungerai": "smungere",
    "smungeran": "smungere",
    "smungeranno": "smungere",
    "smungerebbe": "smungere",
    "smungerebber": "smungere",
    "smungerebbero": "smungere",
    "smungerei": "smungere",
    "smungeremmo": "smungere",
    "smungeremo": "smungere",
    "smungereste": "smungere",
    "smungeresti": "smungere",
    "smungerete": "smungere",
    "smungerà": "smungere",
    "smungerò": "smungere",
    "smungesse": "smungere",
    "smungesser": "smungere",
    "smungessero": "smungere",
    "smungessi": "smungere",
    "smungessimo": "smungere",
    "smungeste": "smungere",
    "smungesti": "smungere",
    "smungete": "smungere",
    "smungeva": "smungere",
    "smungevamo": "smungere",
    "smungevan": "smungere",
    "smungevano": "smungere",
    "smungevate": "smungere",
    "smungevi": "smungere",
    "smungevo": "smungere",
    "smungi": "smungere",
    "smungiamo": "smungere",
    "smungiate": "smungere",
    "smungo": "smungere",
    "smungon": "smungere",
    "smungono": "smungere",
    "smunser": "smungere",
    "smunsero": "smungere",
    "smunsi": "smungere",
    "smunsè": "smungere",
    "smunta": "smunto",
    "smunte": "smunto",
    "smunti": "smunto",
    "smunto": "smungere",
    "smuova": "smuovere",
    "smuovan": "smuovere",
    "smuovano": "smuovere",
    "smuove": "smuovere",
    "smuovemmo": "smuovere",
    "smuovendo": "smuovere",
    "smuovente": "smuovere",
    "smuoventi": "smuovere",
    "smuover": "smuovere",
    "smuoverai": "smuovere",
    "smuoveran": "smuovere",
    "smuoveranno": "smuovere",
    "smuoverebbe": "smuovere",
    "smuoverebber": "smuovere",
    "smuoverebbero": "smuovere",
    "smuoverei": "smuovere",
    "smuoveremmo": "smuovere",
    "smuoveremo": "smuovere",
    "smuovereste": "smuovere",
    "smuoveresti": "smuovere",
    "smuoverete": "smuovere",
    "smuoverà": "smuovere",
    "smuoverò": "smuovere",
    "smuovesse": "smuovere",
    "smuovesser": "smuovere",
    "smuovessero": "smuovere",
    "smuovessi": "smuovere",
    "smuovessimo": "smuovere",
    "smuoveste": "smuovere",
    "smuovesti": "smuovere",
    "smuovete": "smuovere",
    "smuoveva": "smuovere",
    "smuovevamo": "smuovere",
    "smuovevan": "smuovere",
    "smuovevano": "smuovere",
    "smuovevate": "smuovere",
    "smuovevi": "smuovere",
    "smuovevo": "smuovere",
    "smuovi": "smuovere",
    "smuoviamo": "smuovere",
    "smuoviate": "smuovere",
    "smuovo": "smuovere",
    "smuovon": "smuovere",
    "smuovono": "smuovere",
    "smura": "smurare",
    "smurai": "smurare",
    "smurammo": "smurare",
    "smuran": "smurare",
    "smurando": "smurare",
    "smurano": "smurare",
    "smurante": "smurare",
    "smuranti": "smurare",
    "smurar": "smurare",
    "smuraron": "smurare",
    "smurarono": "smurare",
    "smurasse": "smurare",
    "smurasser": "smurare",
    "smurassero": "smurare",
    "smurassi": "smurare",
    "smurassimo": "smurare",
    "smuraste": "smurare",
    "smurasti": "smurare",
    "smurata": "smurare",
    "smurate": "smurare",
    "smurati": "smurare",
    "smurato": "smurare",
    "smurava": "smurare",
    "smuravamo": "smurare",
    "smuravan": "smurare",
    "smuravano": "smurare",
    "smuravate": "smurare",
    "smuravi": "smurare",
    "smuravo": "smurare",
    "smurerai": "smurare",
    "smureran": "smurare",
    "smureranno": "smurare",
    "smurerebbe": "smurare",
    "smurerebber": "smurare",
    "smurerebbero": "smurare",
    "smurerei": "smurare",
    "smureremmo": "smurare",
    "smureremo": "smurare",
    "smurereste": "smurare",
    "smureresti": "smurare",
    "smurerete": "smurare",
    "smurerà": "smurare",
    "smurerò": "smurare",
    "smuri": "smurare",
    "smuriamo": "smurare",
    "smuriate": "smurare",
    "smurin": "smurare",
    "smurino": "smurare",
    "smuro": "smurare",
    "smurò": "smurare",
    "smussa": "smussare",
    "smussai": "smussare",
    "smussammo": "smussare",
    "smussan": "smussare",
    "smussando": "smussare",
    "smussano": "smussare",
    "smussante": "smussare",
    "smussanti": "smussare",
    "smussar": "smussare",
    "smussaron": "smussare",
    "smussarono": "smussare",
    "smussasse": "smussare",
    "smussasser": "smussare",
    "smussassero": "smussare",
    "smussassi": "smussare",
    "smussassimo": "smussare",
    "smussaste": "smussare",
    "smussasti": "smussare",
    "smussata": "smussare",
    "smussate": "smussare",
    "smussati": "smussare",
    "smussato": "smussare",
    "smussava": "smussare",
    "smussavamo": "smussare",
    "smussavan": "smussare",
    "smussavano": "smussare",
    "smussavate": "smussare",
    "smussavi": "smussare",
    "smussavo": "smussare",
    "smusserai": "smussare",
    "smusseran": "smussare",
    "smusseranno": "smussare",
    "smusserebbe": "smussare",
    "smusserebber": "smussare",
    "smusserebbero": "smussare",
    "smusserei": "smussare",
    "smusseremmo": "smussare",
    "smusseremo": "smussare",
    "smussereste": "smussare",
    "smusseresti": "smussare",
    "smusserete": "smussare",
    "smusserà": "smussare",
    "smusserò": "smussare",
    "smussi": "smussare",
    "smussiamo": "smussare",
    "smussiate": "smussare",
    "smussin": "smussare",
    "smussino": "smussare",
    "smusso": "smussare",
    "smussò": "smussare",
    "snatura": "snaturare",
    "snaturai": "snaturare",
    "snaturamenti": "snaturamento",
    "snaturammo": "snaturare",
    "snaturan": "snaturare",
    "snaturando": "snaturare",
    "snaturano": "snaturare",
    "snaturante": "snaturare",
    "snaturanti": "snaturare",
    "snaturar": "snaturare",
    "snaturaron": "snaturare",
    "snaturarono": "snaturare",
    "snaturasse": "snaturare",
    "snaturasser": "snaturare",
    "snaturassero": "snaturare",
    "snaturassi": "snaturare",
    "snaturassimo": "snaturare",
    "snaturaste": "snaturare",
    "snaturasti": "snaturare",
    "snaturata": "snaturato",
    "snaturate": "snaturato",
    "snaturati": "snaturato",
    "snaturato": "snaturare",
    "snaturava": "snaturare",
    "snaturavamo": "snaturare",
    "snaturavan": "snaturare",
    "snaturavano": "snaturare",
    "snaturavate": "snaturare",
    "snaturavi": "snaturare",
    "snaturavo": "snaturare",
    "snaturerai": "snaturare",
    "snatureran": "snaturare",
    "snatureranno": "snaturare",
    "snaturerebbe": "snaturare",
    "snaturerebber": "snaturare",
    "snaturerebbero": "snaturare",
    "snaturerei": "snaturare",
    "snatureremmo": "snaturare",
    "snatureremo": "snaturare",
    "snaturereste": "snaturare",
    "snatureresti": "snaturare",
    "snaturerete": "snaturare",
    "snaturerà": "snaturare",
    "snaturerò": "snaturare",
    "snaturi": "snaturare",
    "snaturiamo": "snaturare",
    "snaturiate": "snaturare",
    "snaturin": "snaturare",
    "snaturino": "snaturare",
    "snaturo": "snaturare",
    "snaturò": "snaturare",
    "snazionalizza": "snazionalizzare",
    "snazionalizzai": "snazionalizzare",
    "snazionalizzammo": "snazionalizzare",
    "snazionalizzan": "snazionalizzare",
    "snazionalizzando": "snazionalizzare",
    "snazionalizzano": "snazionalizzare",
    "snazionalizzante": "snazionalizzare",
    "snazionalizzanti": "snazionalizzare",
    "snazionalizzar": "snazionalizzare",
    "snazionalizzaron": "snazionalizzare",
    "snazionalizzarono": "snazionalizzare",
    "snazionalizzasse": "snazionalizzare",
    "snazionalizzasser": "snazionalizzare",
    "snazionalizzassero": "snazionalizzare",
    "snazionalizzassi": "snazionalizzare",
    "snazionalizzassimo": "snazionalizzare",
    "snazionalizzaste": "snazionalizzare",
    "snazionalizzasti": "snazionalizzare",
    "snazionalizzata": "snazionalizzare",
    "snazionalizzate": "snazionalizzare",
    "snazionalizzati": "snazionalizzare",
    "snazionalizzato": "snazionalizzare",
    "snazionalizzava": "snazionalizzare",
    "snazionalizzavamo": "snazionalizzare",
    "snazionalizzavan": "snazionalizzare",
    "snazionalizzavano": "snazionalizzare",
    "snazionalizzavate": "snazionalizzare",
    "snazionalizzavi": "snazionalizzare",
    "snazionalizzavo": "snazionalizzare",
    "snazionalizzerai": "snazionalizzare",
    "snazionalizzeran": "snazionalizzare",
    "snazionalizzeranno": "snazionalizzare",
    "snazionalizzerebbe": "snazionalizzare",
    "snazionalizzerebber": "snazionalizzare",
    "snazionalizzerebbero": "snazionalizzare",
    "snazionalizzerei": "snazionalizzare",
    "snazionalizzeremmo": "snazionalizzare",
    "snazionalizzeremo": "snazionalizzare",
    "snazionalizzereste": "snazionalizzare",
    "snazionalizzeresti": "snazionalizzare",
    "snazionalizzerete": "snazionalizzare",
    "snazionalizzerà": "snazionalizzare",
    "snazionalizzerò": "snazionalizzare",
    "snazionalizzi": "snazionalizzare",
    "snazionalizziamo": "snazionalizzare",
    "snazionalizziate": "snazionalizzare",
    "snazionalizzin": "snazionalizzare",
    "snazionalizzino": "snazionalizzare",
    "snazionalizzo": "snazionalizzare",
    "snazionalizzò": "snazionalizzare",
    "snebbi": "snebbiare",
    "snebbia": "snebbiare",
    "snebbiai": "snebbiare",
    "snebbiammo": "snebbiare",
    "snebbiamo": "snebbiare",
    "snebbian": "snebbiare",
    "snebbiando": "snebbiare",
    "snebbiano": "snebbiare",
    "snebbiante": "snebbiare",
    "snebbianti": "snebbiare",
    "snebbiar": "snebbiare",
    "snebbiaron": "snebbiare",
    "snebbiarono": "snebbiare",
    "snebbiasse": "snebbiare",
    "snebbiasser": "snebbiare",
    "snebbiassero": "snebbiare",
    "snebbiassi": "snebbiare",
    "snebbiassimo": "snebbiare",
    "snebbiaste": "snebbiare",
    "snebbiasti": "snebbiare",
    "snebbiata": "snebbiare",
    "snebbiate": "snebbiare",
    "snebbiati": "snebbiare",
    "snebbiato": "snebbiare",
    "snebbiava": "snebbiare",
    "snebbiavamo": "snebbiare",
    "snebbiavan": "snebbiare",
    "snebbiavano": "snebbiare",
    "snebbiavate": "snebbiare",
    "snebbiavi": "snebbiare",
    "snebbiavo": "snebbiare",
    "snebbierai": "snebbiare",
    "snebbieran": "snebbiare",
    "snebbieranno": "snebbiare",
    "snebbierebbe": "snebbiare",
    "snebbierebber": "snebbiare",
    "snebbierebbero": "snebbiare",
    "snebbierei": "snebbiare",
    "snebbieremmo": "snebbiare",
    "snebbieremo": "snebbiare",
    "snebbiereste": "snebbiare",
    "snebbieresti": "snebbiare",
    "snebbierete": "snebbiare",
    "snebbierà": "snebbiare",
    "snebbierò": "snebbiare",
    "snebbin": "snebbiare",
    "snebbino": "snebbiare",
    "snebbio": "snebbiare",
    "snebbiò": "snebbiare",
    "snella": "snello",
    "snelle": "snello",
    "snellendo": "snellire",
    "snellente": "snellire",
    "snellenti": "snellire",
    "snellezze": "snellezza",
    "snelli": "snello",
    "snelliamo": "snellire",
    "snelliate": "snellire",
    "snellii": "snellire",
    "snellimenti": "snellimento",
    "snellimmo": "snellire",
    "snellir": "snellire",
    "snellirai": "snellire",
    "snelliran": "snellire",
    "snelliranno": "snellire",
    "snellirebbe": "snellire",
    "snellirebber": "snellire",
    "snellirebbero": "snellire",
    "snellirei": "snellire",
    "snelliremmo": "snellire",
    "snelliremo": "snellire",
    "snellireste": "snellire",
    "snelliresti": "snellire",
    "snellirete": "snellire",
    "snelliron": "snellire",
    "snellirono": "snellire",
    "snellirà": "snellire",
    "snellirò": "snellire",
    "snellisca": "snellire",
    "snelliscan": "snellire",
    "snelliscano": "snellire",
    "snellisce": "snellire",
    "snellisci": "snellire",
    "snellisco": "snellire",
    "snelliscon": "snellire",
    "snelliscono": "snellire",
    "snellisse": "snellire",
    "snellisser": "snellire",
    "snellissero": "snellire",
    "snellissi": "snellire",
    "snellissimo": "snellire",
    "snelliste": "snellire",
    "snellisti": "snellire",
    "snellita": "snellire",
    "snellite": "snellire",
    "snelliti": "snellire",
    "snellito": "snellire",
    "snelliva": "snellire",
    "snellivamo": "snellire",
    "snellivan": "snellire",
    "snellivano": "snellire",
    "snellivate": "snellire",
    "snellivi": "snellire",
    "snellivo": "snellire",
    "snellì": "snellire",
    "snerva": "snervare",
    "snervai": "snervare",
    "snervammo": "snervare",
    "snervan": "snervare",
    "snervando": "snervare",
    "snervano": "snervare",
    "snervante": "snervare",
    "snervanti": "snervare",
    "snervar": "snervare",
    "snervaron": "snervare",
    "snervarono": "snervare",
    "snervasse": "snervare",
    "snervasser": "snervare",
    "snervassero": "snervare",
    "snervassi": "snervare",
    "snervassimo": "snervare",
    "snervaste": "snervare",
    "snervasti": "snervare",
    "snervata": "snervato",
    "snervate": "snervato",
    "snervati": "snervato",
    "snervato": "snervare",
    "snervava": "snervare",
    "snervavamo": "snervare",
    "snervavan": "snervare",
    "snervavano": "snervare",
    "snervavate": "snervare",
    "snervavi": "snervare",
    "snervavo": "snervare",
    "snerverai": "snervare",
    "snerveran": "snervare",
    "snerveranno": "snervare",
    "snerverebbe": "snervare",
    "snerverebber": "snervare",
    "snerverebbero": "snervare",
    "snerverei": "snervare",
    "snerveremmo": "snervare",
    "snerveremo": "snervare",
    "snervereste": "snervare",
    "snerveresti": "snervare",
    "snerverete": "snervare",
    "snerverà": "snervare",
    "snerverò": "snervare",
    "snervi": "snervare",
    "snerviamo": "snervare",
    "snerviate": "snervare",
    "snervin": "snervare",
    "snervino": "snervare",
    "snervo": "snervare",
    "snervò": "snervare",
    "snida": "snidare",
    "snidai": "snidare",
    "snidammo": "snidare",
    "snidan": "snidare",
    "snidando": "snidare",
    "snidano": "snidare",
    "snidante": "snidare",
    "snidanti": "snidare",
    "snidar": "snidare",
    "snidaron": "snidare",
    "snidarono": "snidare",
    "snidasse": "snidare",
    "snidasser": "snidare",
    "snidassero": "snidare",
    "snidassi": "snidare",
    "snidassimo": "snidare",
    "snidaste": "snidare",
    "snidasti": "snidare",
    "snidata": "snidare",
    "snidate": "snidare",
    "snidati": "snidare",
    "snidato": "snidare",
    "snidava": "snidare",
    "snidavamo": "snidare",
    "snidavan": "snidare",
    "snidavano": "snidare",
    "snidavate": "snidare",
    "snidavi": "snidare",
    "snidavo": "snidare",
    "sniderai": "snidare",
    "snideran": "snidare",
    "snideranno": "snidare",
    "sniderebbe": "snidare",
    "sniderebber": "snidare",
    "sniderebbero": "snidare",
    "sniderei": "snidare",
    "snideremmo": "snidare",
    "snideremo": "snidare",
    "snidereste": "snidare",
    "snideresti": "snidare",
    "sniderete": "snidare",
    "sniderà": "snidare",
    "sniderò": "snidare",
    "snidi": "snidare",
    "snidiamo": "snidare",
    "snidiate": "snidare",
    "snidin": "snidare",
    "snidino": "snidare",
    "snido": "snidare",
    "snidò": "snidare",
    "snobba": "snobbare",
    "snobbai": "snobbare",
    "snobbammo": "snobbare",
    "snobban": "snobbare",
    "snobbando": "snobbare",
    "snobbano": "snobbare",
    "snobbante": "snobbare",
    "snobbanti": "snobbare",
    "snobbar": "snobbare",
    "snobbaron": "snobbare",
    "snobbarono": "snobbare",
    "snobbasse": "snobbare",
    "snobbasser": "snobbare",
    "snobbassero": "snobbare",
    "snobbassi": "snobbare",
    "snobbassimo": "snobbare",
    "snobbaste": "snobbare",
    "snobbasti": "snobbare",
    "snobbata": "snobbare",
    "snobbate": "snobbare",
    "snobbati": "snobbare",
    "snobbato": "snobbare",
    "snobbava": "snobbare",
    "snobbavamo": "snobbare",
    "snobbavan": "snobbare",
    "snobbavano": "snobbare",
    "snobbavate": "snobbare",
    "snobbavi": "snobbare",
    "snobbavo": "snobbare",
    "snobberai": "snobbare",
    "snobberan": "snobbare",
    "snobberanno": "snobbare",
    "snobberebbe": "snobbare",
    "snobberebber": "snobbare",
    "snobberebbero": "snobbare",
    "snobberei": "snobbare",
    "snobberemmo": "snobbare",
    "snobberemo": "snobbare",
    "snobbereste": "snobbare",
    "snobberesti": "snobbare",
    "snobberete": "snobbare",
    "snobberà": "snobbare",
    "snobberò": "snobbare",
    "snobbi": "snobbare",
    "snobbiamo": "snobbare",
    "snobbiate": "snobbare",
    "snobbin": "snobbare",
    "snobbino": "snobbare",
    "snobbo": "snobbare",
    "snobbò": "snobbare",
    "snobismi": "snobismo",
    "snobistica": "snobistico",
    "snobistiche": "snobistico",
    "snobistici": "snobistico",
    "snocciola": "snocciolare",
    "snocciolai": "snocciolare",
    "snocciolammo": "snocciolare",
    "snocciolan": "snocciolare",
    "snocciolando": "snocciolare",
    "snocciolano": "snocciolare",
    "snocciolante": "snocciolare",
    "snocciolanti": "snocciolare",
    "snocciolar": "snocciolare",
    "snocciolaron": "snocciolare",
    "snocciolarono": "snocciolare",
    "snocciolasse": "snocciolare",
    "snocciolasser": "snocciolare",
    "snocciolassero": "snocciolare",
    "snocciolassi": "snocciolare",
    "snocciolassimo": "snocciolare",
    "snocciolaste": "snocciolare",
    "snocciolasti": "snocciolare",
    "snocciolata": "snocciolare",
    "snocciolate": "snocciolare",
    "snocciolati": "snocciolare",
    "snocciolato": "snocciolare",
    "snocciolava": "snocciolare",
    "snocciolavamo": "snocciolare",
    "snocciolavan": "snocciolare",
    "snocciolavano": "snocciolare",
    "snocciolavate": "snocciolare",
    "snocciolavi": "snocciolare",
    "snocciolavo": "snocciolare",
    "snocciolerai": "snocciolare",
    "snoccioleran": "snocciolare",
    "snoccioleranno": "snocciolare",
    "snocciolerebbe": "snocciolare",
    "snocciolerebber": "snocciolare",
    "snocciolerebbero": "snocciolare",
    "snocciolerei": "snocciolare",
    "snoccioleremmo": "snocciolare",
    "snoccioleremo": "snocciolare",
    "snocciolereste": "snocciolare",
    "snoccioleresti": "snocciolare",
    "snocciolerete": "snocciolare",
    "snocciolerà": "snocciolare",
    "snocciolerò": "snocciolare",
    "snoccioli": "snocciolare",
    "snoccioliamo": "snocciolare",
    "snoccioliate": "snocciolare",
    "snocciolin": "snocciolare",
    "snocciolino": "snocciolare",
    "snocciolo": "snocciolare",
    "snocciolò": "snocciolare",
    "snoda": "snodare",
    "snodabili": "snodabile",
    "snodai": "snodare",
    "snodammo": "snodare",
    "snodan": "snodare",
    "snodando": "snodare",
    "snodano": "snodare",
    "snodante": "snodare",
    "snodanti": "snodare",
    "snodar": "snodare",
    "snodaron": "snodare",
    "snodarono": "snodare",
    "snodasse": "snodare",
    "snodasser": "snodare",
    "snodassero": "snodare",
    "snodassi": "snodare",
    "snodassimo": "snodare",
    "snodaste": "snodare",
    "snodasti": "snodare",
    "snodata": "snodare",
    "snodate": "snodare",
    "snodati": "snodare",
    "snodato": "snodare",
    "snodava": "snodare",
    "snodavamo": "snodare",
    "snodavan": "snodare",
    "snodavano": "snodare",
    "snodavate": "snodare",
    "snodavi": "snodare",
    "snodavo": "snodare",
    "snoderai": "snodare",
    "snoderan": "snodare",
    "snoderanno": "snodare",
    "snoderebbe": "snodare",
    "snoderebber": "snodare",
    "snoderebbero": "snodare",
    "snoderei": "snodare",
    "snoderemmo": "snodare",
    "snoderemo": "snodare",
    "snodereste": "snodare",
    "snoderesti": "snodare",
    "snoderete": "snodare",
    "snoderà": "snodare",
    "snoderò": "snodare",
    "snodi": "snodo",
    "snodiamo": "snodare",
    "snodiate": "snodare",
    "snodin": "snodare",
    "snodino": "snodare",
    "snodo": "snodare",
    "snodò": "snodare",
    "snuda": "snudare",
    "snudai": "snudare",
    "snudammo": "snudare",
    "snudan": "snudare",
    "snudando": "snudare",
    "snudano": "snudare",
    "snudante": "snudare",
    "snudanti": "snudare",
    "snudar": "snudare",
    "snudaron": "snudare",
    "snudarono": "snudare",
    "snudasse": "snudare",
    "snudasser": "snudare",
    "snudassero": "snudare",
    "snudassi": "snudare",
    "snudassimo": "snudare",
    "snudaste": "snudare",
    "snudasti": "snudare",
    "snudata": "snudare",
    "snudate": "snudare",
    "snudati": "snudare",
    "snudato": "snudare",
    "snudava": "snudare",
    "snudavamo": "snudare",
    "snudavan": "snudare",
    "snudavano": "snudare",
    "snudavate": "snudare",
    "snudavi": "snudare",
    "snudavo": "snudare",
    "snuderai": "snudare",
    "snuderan": "snudare",
    "snuderanno": "snudare",
    "snuderebbe": "snudare",
    "snuderebber": "snudare",
    "snuderebbero": "snudare",
    "snuderei": "snudare",
    "snuderemmo": "snudare",
    "snuderemo": "snudare",
    "snudereste": "snudare",
    "snuderesti": "snudare",
    "snuderete": "snudare",
    "snuderà": "snudare",
    "snuderò": "snudare",
    "snudi": "snudare",
    "snudiamo": "snudare",
    "snudiate": "snudare",
    "snudin": "snudare",
    "snudino": "snudare",
    "snudo": "snudare",
    "snudò": "snudare",
    "so": "sapere",
    "soavi": "soave",
    "sobbalza": "sobbalzare",
    "sobbalzai": "sobbalzare",
    "sobbalzammo": "sobbalzare",
    "sobbalzan": "sobbalzare",
    "sobbalzando": "sobbalzare",
    "sobbalzano": "sobbalzare",
    "sobbalzante": "sobbalzare",
    "sobbalzanti": "sobbalzare",
    "sobbalzar": "sobbalzare",
    "sobbalzaron": "sobbalzare",
    "sobbalzarono": "sobbalzare",
    "sobbalzasse": "sobbalzare",
    "sobbalzasser": "sobbalzare",
    "sobbalzassero": "sobbalzare",
    "sobbalzassi": "sobbalzare",
    "sobbalzassimo": "sobbalzare",
    "sobbalzaste": "sobbalzare",
    "sobbalzasti": "sobbalzare",
    "sobbalzata": "sobbalzare",
    "sobbalzate": "sobbalzare",
    "sobbalzati": "sobbalzare",
    "sobbalzato": "sobbalzare",
    "sobbalzava": "sobbalzare",
    "sobbalzavamo": "sobbalzare",
    "sobbalzavan": "sobbalzare",
    "sobbalzavano": "sobbalzare",
    "sobbalzavate": "sobbalzare",
    "sobbalzavi": "sobbalzare",
    "sobbalzavo": "sobbalzare",
    "sobbalzerai": "sobbalzare",
    "sobbalzeran": "sobbalzare",
    "sobbalzeranno": "sobbalzare",
    "sobbalzerebbe": "sobbalzare",
    "sobbalzerebber": "sobbalzare",
    "sobbalzerebbero": "sobbalzare",
    "sobbalzerei": "sobbalzare",
    "sobbalzeremmo": "sobbalzare",
    "sobbalzeremo": "sobbalzare",
    "sobbalzereste": "sobbalzare",
    "sobbalzeresti": "sobbalzare",
    "sobbalzerete": "sobbalzare",
    "sobbalzerà": "sobbalzare",
    "sobbalzerò": "sobbalzare",
    "sobbalzi": "sobbalzo",
    "sobbalziamo": "sobbalzare",
    "sobbalziate": "sobbalzare",
    "sobbalzin": "sobbalzare",
    "sobbalzino": "sobbalzare",
    "sobbalzo": "sobbalzare",
    "sobbalzò": "sobbalzare",
    "sobbarca": "sobbarcare",
    "sobbarcai": "sobbarcare",
    "sobbarcammo": "sobbarcare",
    "sobbarcan": "sobbarcare",
    "sobbarcando": "sobbarcare",
    "sobbarcano": "sobbarcare",
    "sobbarcante": "sobbarcare",
    "sobbarcanti": "sobbarcare",
    "sobbarcar": "sobbarcare",
    "sobbarcaron": "sobbarcare",
    "sobbarcarono": "sobbarcare",
    "sobbarcasse": "sobbarcare",
    "sobbarcasser": "sobbarcare",
    "sobbarcassero": "sobbarcare",
    "sobbarcassi": "sobbarcare",
    "sobbarcassimo": "sobbarcare",
    "sobbarcaste": "sobbarcare",
    "sobbarcasti": "sobbarcare",
    "sobbarcata": "sobbarcare",
    "sobbarcate": "sobbarcare",
    "sobbarcati": "sobbarcare",
    "sobbarcato": "sobbarcare",
    "sobbarcava": "sobbarcare",
    "sobbarcavamo": "sobbarcare",
    "sobbarcavan": "sobbarcare",
    "sobbarcavano": "sobbarcare",
    "sobbarcavate": "sobbarcare",
    "sobbarcavi": "sobbarcare",
    "sobbarcavo": "sobbarcare",
    "sobbarcherai": "sobbarcare",
    "sobbarcheran": "sobbarcare",
    "sobbarcheranno": "sobbarcare",
    "sobbarcherebbe": "sobbarcare",
    "sobbarcherebber": "sobbarcare",
    "sobbarcherebbero": "sobbarcare",
    "sobbarcherei": "sobbarcare",
    "sobbarcheremmo": "sobbarcare",
    "sobbarcheremo": "sobbarcare",
    "sobbarchereste": "sobbarcare",
    "sobbarcheresti": "sobbarcare",
    "sobbarcherete": "sobbarcare",
    "sobbarcherà": "sobbarcare",
    "sobbarcherò": "sobbarcare",
    "sobbarchi": "sobbarcare",
    "sobbarchiamo": "sobbarcare",
    "sobbarchiate": "sobbarcare",
    "sobbarchin": "sobbarcare",
    "sobbarchino": "sobbarcare",
    "sobbarco": "sobbarcare",
    "sobbarcò": "sobbarcare",
    "sobbolla": "sobbollire",
    "sobbollan": "sobbollire",
    "sobbollano": "sobbollire",
    "sobbolle": "sobbollire",
    "sobbollendo": "sobbollire",
    "sobbollente": "sobbollire",
    "sobbollenti": "sobbollire",
    "sobbolli": "sobbollire",
    "sobbolliamo": "sobbollire",
    "sobbolliate": "sobbollire",
    "sobbollii": "sobbollire",
    "sobbollimmo": "sobbollire",
    "sobbollir": "sobbollire",
    "sobbollirai": "sobbollire",
    "sobbolliran": "sobbollire",
    "sobbolliranno": "sobbollire",
    "sobbollirebbe": "sobbollire",
    "sobbollirebber": "sobbollire",
    "sobbollirebbero": "sobbollire",
    "sobbollirei": "sobbollire",
    "sobbolliremmo": "sobbollire",
    "sobbolliremo": "sobbollire",
    "sobbollireste": "sobbollire",
    "sobbolliresti": "sobbollire",
    "sobbollirete": "sobbollire",
    "sobbolliron": "sobbollire",
    "sobbollirono": "sobbollire",
    "sobbollirà": "sobbollire",
    "sobbollirò": "sobbollire",
    "sobbollisse": "sobbollire",
    "sobbollisser": "sobbollire",
    "sobbollissero": "sobbollire",
    "sobbollissi": "sobbollire",
    "sobbollissimo": "sobbollire",
    "sobbolliste": "sobbollire",
    "sobbollisti": "sobbollire",
    "sobbollita": "sobbollire",
    "sobbollite": "sobbollire",
    "sobbolliti": "sobbollire",
    "sobbollito": "sobbollire",
    "sobbolliva": "sobbollire",
    "sobbollivamo": "sobbollire",
    "sobbollivan": "sobbollire",
    "sobbollivano": "sobbollire",
    "sobbollivate": "sobbollire",
    "sobbollivi": "sobbollire",
    "sobbollivo": "sobbollire",
    "sobbollo": "sobbollire",
    "sobbollon": "sobbollire",
    "sobbollono": "sobbollire",
    "sobbollì": "sobbollire",
    "sobborghi": "sobborgo",
    "sobilla": "sobillare",
    "sobillai": "sobillare",
    "sobillammo": "sobillare",
    "sobillan": "sobillare",
    "sobillando": "sobillare",
    "sobillano": "sobillare",
    "sobillante": "sobillare",
    "sobillanti": "sobillare",
    "sobillar": "sobillare",
    "sobillaron": "sobillare",
    "sobillarono": "sobillare",
    "sobillasse": "sobillare",
    "sobillasser": "sobillare",
    "sobillassero": "sobillare",
    "sobillassi": "sobillare",
    "sobillassimo": "sobillare",
    "sobillaste": "sobillare",
    "sobillasti": "sobillare",
    "sobillata": "sobillare",
    "sobillate": "sobillare",
    "sobillati": "sobillare",
    "sobillato": "sobillare",
    "sobillatori": "sobillatore",
    "sobillatrice": "sobillatore",
    "sobillatrici": "sobillatore",
    "sobillava": "sobillare",
    "sobillavamo": "sobillare",
    "sobillavan": "sobillare",
    "sobillavano": "sobillare",
    "sobillavate": "sobillare",
    "sobillavi": "sobillare",
    "sobillavo": "sobillare",
    "sobillerai": "sobillare",
    "sobilleran": "sobillare",
    "sobilleranno": "sobillare",
    "sobillerebbe": "sobillare",
    "sobillerebber": "sobillare",
    "sobillerebbero": "sobillare",
    "sobillerei": "sobillare",
    "sobilleremmo": "sobillare",
    "sobilleremo": "sobillare",
    "sobillereste": "sobillare",
    "sobilleresti": "sobillare",
    "sobillerete": "sobillare",
    "sobillerà": "sobillare",
    "sobillerò": "sobillare",
    "sobilli": "sobillare",
    "sobilliamo": "sobillare",
    "sobilliate": "sobillare",
    "sobillin": "sobillare",
    "sobillino": "sobillare",
    "sobillo": "sobillare",
    "sobillò": "sobillare",
    "sobri": "sobrio",
    "sobria": "sobrio",
    "sobrie": "sobrio",
    "socchiuda": "socchiudere",
    "socchiudan": "socchiudere",
    "socchiudano": "socchiudere",
    "socchiude": "socchiudere",
    "socchiudemmo": "socchiudere",
    "socchiudendo": "socchiudere",
    "socchiudente": "socchiudere",
    "socchiudenti": "socchiudere",
    "socchiuder": "socchiudere",
    "socchiuderai": "socchiudere",
    "socchiuderan": "socchiudere",
    "socchiuderanno": "socchiudere",
    "socchiuderebbe": "socchiudere",
    "socchiuderebber": "socchiudere",
    "socchiuderebbero": "socchiudere",
    "socchiuderei": "socchiudere",
    "socchiuderemmo": "socchiudere",
    "socchiuderemo": "socchiudere",
    "socchiudereste": "socchiudere",
    "socchiuderesti": "socchiudere",
    "socchiuderete": "socchiudere",
    "socchiuderà": "socchiudere",
    "socchiuderò": "socchiudere",
    "socchiudesse": "socchiudere",
    "socchiudesser": "socchiudere",
    "socchiudessero": "socchiudere",
    "socchiudessi": "socchiudere",
    "socchiudessimo": "socchiudere",
    "socchiudeste": "socchiudere",
    "socchiudesti": "socchiudere",
    "socchiudete": "socchiudere",
    "socchiudeva": "socchiudere",
    "socchiudevamo": "socchiudere",
    "socchiudevan": "socchiudere",
    "socchiudevano": "socchiudere",
    "socchiudevate": "socchiudere",
    "socchiudevi": "socchiudere",
    "socchiudevo": "socchiudere",
    "socchiudi": "socchiudere",
    "socchiudiamo": "socchiudere",
    "socchiudiate": "socchiudere",
    "socchiudo": "socchiudere",
    "socchiudon": "socchiudere",
    "socchiudono": "socchiudere",
    "socchiusa": "socchiudere",
    "socchiuse": "socchiudere",
    "socchiuser": "socchiudere",
    "socchiusero": "socchiudere",
    "socchiusi": "socchiudere",
    "socchiuso": "socchiudere",
    "soccomba": "soccombere",
    "soccomban": "soccombere",
    "soccombano": "soccombere",
    "soccombe": "soccombere",
    "soccombei": "soccombere",
    "soccombemmo": "soccombere",
    "soccombendo": "soccombere",
    "soccombente": "soccombere",
    "soccombenti": "soccombere",
    "soccomber": "soccombere",
    "soccomberai": "soccombere",
    "soccomberan": "soccombere",
    "soccomberanno": "soccombere",
    "soccomberebbe": "soccombere",
    "soccomberebber": "soccombere",
    "soccomberebbero": "soccombere",
    "soccomberei": "soccombere",
    "soccomberemmo": "soccombere",
    "soccomberemo": "soccombere",
    "soccombereste": "soccombere",
    "soccomberesti": "soccombere",
    "soccomberete": "soccombere",
    "soccomberon": "soccombere",
    "soccomberono": "soccombere",
    "soccomberà": "soccombere",
    "soccomberò": "soccombere",
    "soccombesse": "soccombere",
    "soccombesser": "soccombere",
    "soccombessero": "soccombere",
    "soccombessi": "soccombere",
    "soccombessimo": "soccombere",
    "soccombeste": "soccombere",
    "soccombesti": "soccombere",
    "soccombete": "soccombere",
    "soccombeva": "soccombere",
    "soccombevamo": "soccombere",
    "soccombevan": "soccombere",
    "soccombevano": "soccombere",
    "soccombevate": "soccombere",
    "soccombevi": "soccombere",
    "soccombevo": "soccombere",
    "soccombi": "soccombere",
    "soccombiamo": "soccombere",
    "soccombiate": "soccombere",
    "soccombo": "soccombere",
    "soccombon": "soccombere",
    "soccombono": "soccombere",
    "soccombuta": "soccombere",
    "soccombute": "soccombere",
    "soccombuti": "soccombere",
    "soccombuto": "soccombere",
    "soccombè": "soccombere",
    "soccorra": "soccorrere",
    "soccorran": "soccorrere",
    "soccorrano": "soccorrere",
    "soccorre": "soccorrere",
    "soccorrei": "soccorrere",
    "soccorremmo": "soccorrere",
    "soccorrendo": "soccorrere",
    "soccorrente": "soccorrere",
    "soccorrenti": "soccorrere",
    "soccorrer": "soccorrere",
    "soccorrerai": "soccorrere",
    "soccorreran": "soccorrere",
    "soccorreranno": "soccorrere",
    "soccorrerebbe": "soccorrere",
    "soccorrerebber": "soccorrere",
    "soccorrerebbero": "soccorrere",
    "soccorrerei": "soccorrere",
    "soccorreremmo": "soccorrere",
    "soccorreremo": "soccorrere",
    "soccorrereste": "soccorrere",
    "soccorreresti": "soccorrere",
    "soccorrerete": "soccorrere",
    "soccorreron": "soccorrere",
    "soccorrerono": "soccorrere",
    "soccorrerà": "soccorrere",
    "soccorrerò": "soccorrere",
    "soccorresse": "soccorrere",
    "soccorresser": "soccorrere",
    "soccorressero": "soccorrere",
    "soccorressi": "soccorrere",
    "soccorressimo": "soccorrere",
    "soccorreste": "soccorrere",
    "soccorresti": "soccorrere",
    "soccorrete": "soccorrere",
    "soccorreva": "soccorrere",
    "soccorrevamo": "soccorrere",
    "soccorrevan": "soccorrere",
    "soccorrevano": "soccorrere",
    "soccorrevate": "soccorrere",
    "soccorrevi": "soccorrere",
    "soccorrevo": "soccorrere",
    "soccorri": "soccorrere",
    "soccorriamo": "soccorrere",
    "soccorriate": "soccorrere",
    "soccorritori": "soccorritore",
    "soccorritrice": "soccorritore",
    "soccorritrici": "soccorritore",
    "soccorro": "soccorrere",
    "soccorron": "soccorrere",
    "soccorrono": "soccorrere",
    "soccorruta": "soccorrere",
    "soccorrute": "soccorrere",
    "soccorruti": "soccorrere",
    "soccorruto": "soccorrere",
    "soccorrè": "soccorrere",
    "soccorsi": "soccorso",
    "soci": "socio",
    "social-comuniste": "social-comunista",
    "social-comunisti": "social-comunista",
    "socialdemocratica": "socialdemocratico",
    "socialdemocratiche": "socialdemocratico",
    "socialdemocratici": "socialdemocratico",
    "socialdemocrazie": "socialdemocrazia",
    "sociali": "sociale",
    "socialismi": "socialismo",
    "socialista": "socialisto",
    "socialiste": "socialisto",
    "socialisti": "socialisto",
    "socialistica": "socialistico",
    "socialistiche": "socialistico",
    "socialistici": "socialistico",
    "socializza": "socializzare",
    "socializzai": "socializzare",
    "socializzammo": "socializzare",
    "socializzan": "socializzare",
    "socializzando": "socializzare",
    "socializzano": "socializzare",
    "socializzante": "socializzare",
    "socializzanti": "socializzare",
    "socializzar": "socializzare",
    "socializzaron": "socializzare",
    "socializzarono": "socializzare",
    "socializzasse": "socializzare",
    "socializzasser": "socializzare",
    "socializzassero": "socializzare",
    "socializzassi": "socializzare",
    "socializzassimo": "socializzare",
    "socializzaste": "socializzare",
    "socializzasti": "socializzare",
    "socializzata": "socializzare",
    "socializzate": "socializzare",
    "socializzati": "socializzare",
    "socializzato": "socializzare",
    "socializzava": "socializzare",
    "socializzavamo": "socializzare",
    "socializzavan": "socializzare",
    "socializzavano": "socializzare",
    "socializzavate": "socializzare",
    "socializzavi": "socializzare",
    "socializzavo": "socializzare",
    "socializzazioni": "socializzazione",
    "socializzerai": "socializzare",
    "socializzeran": "socializzare",
    "socializzeranno": "socializzare",
    "socializzerebbe": "socializzare",
    "socializzerebber": "socializzare",
    "socializzerebbero": "socializzare",
    "socializzerei": "socializzare",
    "socializzeremmo": "socializzare",
    "socializzeremo": "socializzare",
    "socializzereste": "socializzare",
    "socializzeresti": "socializzare",
    "socializzerete": "socializzare",
    "socializzerà": "socializzare",
    "socializzerò": "socializzare",
    "socializzi": "socializzare",
    "socializziamo": "socializzare",
    "socializziate": "socializzare",
    "socializzin": "socializzare",
    "socializzino": "socializzare",
    "socializzo": "socializzare",
    "socializzò": "socializzare",
    "socie": "socia",
    "societari": "societario",
    "societaria": "societario",
    "societarie": "societario",
    "socievoli": "socievole",
    "socio-culturali": "socio-culturale",
    "socio-economica": "socio-economico",
    "socio-economiche": "socio-economico",
    "socio-economici": "socio-economico",
    "socio-politica": "socio-politico",
    "socio-politiche": "socio-politico",
    "socio-politici": "socio-politico",
    "sociobiologi": "sociobiologo",
    "socioculturali": "socioculturale",
    "socioeconomica": "socioeconomico",
    "socioeconomiche": "socioeconomico",
    "socioeconomici": "socioeconomico",
    "sociologhe": "sociologa",
    "sociologhi": "sociologo",
    "sociologi": "sociologo",
    "sociologica": "sociologico",
    "sociologiche": "sociologico",
    "sociologici": "sociologico",
    "sociologie": "sociologia",
    "sociologismi": "sociologismo",
    "socratica": "socratico",
    "socratiche": "socratico",
    "socratici": "socratico",
    "soda": "sodo",
    "sodai": "sodare",
    "sodali": "sodale",
    "sodalizi": "sodalizio",
    "sodammo": "sodare",
    "sodan": "sodare",
    "sodando": "sodare",
    "sodano": "sodare",
    "sodante": "sodare",
    "sodanti": "sodare",
    "sodar": "sodare",
    "sodaron": "sodare",
    "sodarono": "sodare",
    "sodasse": "sodare",
    "sodasser": "sodare",
    "sodassero": "sodare",
    "sodassi": "sodare",
    "sodassimo": "sodare",
    "sodaste": "sodare",
    "sodasti": "sodare",
    "sodata": "sodare",
    "sodate": "sodare",
    "sodati": "sodare",
    "sodato": "sodare",
    "sodava": "sodare",
    "sodavamo": "sodare",
    "sodavan": "sodare",
    "sodavano": "sodare",
    "sodavate": "sodare",
    "sodavi": "sodare",
    "sodavo": "sodare",
    "soddisfa": "soddisfare",
    "soddisfa'": "soddisfare",
    "soddisfaccia": "soddisfare",
    "soddisfacciamo": "soddisfare",
    "soddisfaccian": "soddisfare",
    "soddisfacciano": "soddisfare",
    "soddisfacciate": "soddisfare",
    "soddisfaccio": "soddisfare",
    "soddisfacemmo": "soddisfare",
    "soddisfacendo": "soddisfare",
    "soddisfacente": "soddisfare",
    "soddisfacenti": "soddisfare",
    "soddisfacesse": "soddisfare",
    "soddisfacesser": "soddisfare",
    "soddisfacessero": "soddisfare",
    "soddisfacessi": "soddisfare",
    "soddisfacessimo": "soddisfare",
    "soddisfaceste": "soddisfare",
    "soddisfacesti": "soddisfare",
    "soddisfaceva": "soddisfare",
    "soddisfacevamo": "soddisfare",
    "soddisfacevan": "soddisfare",
    "soddisfacevano": "soddisfare",
    "soddisfacevate": "soddisfare",
    "soddisfacevi": "soddisfare",
    "soddisfacevo": "soddisfare",
    "soddisfacimenti": "soddisfacimento",
    "soddisfai": "soddisfare",
    "soddisfammo": "soddisfare",
    "soddisfan": "soddisfare",
    "soddisfando": "soddisfare",
    "soddisfanno": "soddisfare",
    "soddisfano": "soddisfare",
    "soddisfante": "soddisfare",
    "soddisfanti": "soddisfare",
    "soddisfar": "soddisfare",
    "soddisfarai": "soddisfare",
    "soddisfaran": "soddisfare",
    "soddisfaranno": "soddisfare",
    "soddisfarebbe": "soddisfare",
    "soddisfarebber": "soddisfare",
    "soddisfarebbero": "soddisfare",
    "soddisfarei": "soddisfare",
    "soddisfaremmo": "soddisfare",
    "soddisfaremo": "soddisfare",
    "soddisfareste": "soddisfare",
    "soddisfaresti": "soddisfare",
    "soddisfarete": "soddisfare",
    "soddisfaron": "soddisfare",
    "soddisfarono": "soddisfare",
    "soddisfarà": "soddisfare",
    "soddisfarò": "soddisfare",
    "soddisfasse": "soddisfare",
    "soddisfasser": "soddisfare",
    "soddisfassero": "soddisfare",
    "soddisfassi": "soddisfare",
    "soddisfassimo": "soddisfare",
    "soddisfaste": "soddisfare",
    "soddisfasti": "soddisfare",
    "soddisfata": "soddisfare",
    "soddisfate": "soddisfare",
    "soddisfati": "soddisfare",
    "soddisfato": "soddisfare",
    "soddisfatta": "soddisfatto",
    "soddisfatte": "soddisfatto",
    "soddisfatti": "soddisfatto",
    "soddisfatto": "soddisfare",
    "soddisfava": "soddisfare",
    "soddisfavamo": "soddisfare",
    "soddisfavan": "soddisfare",
    "soddisfavano": "soddisfare",
    "soddisfavate": "soddisfare",
    "soddisfavi": "soddisfare",
    "soddisfavo": "soddisfare",
    "soddisfazioni": "soddisfazione",
    "soddisfece": "soddisfare",
    "soddisfecer": "soddisfare",
    "soddisfecero": "soddisfare",
    "soddisfeci": "soddisfare",
    "soddisferai": "soddisfare",
    "soddisferan": "soddisfare",
    "soddisferanno": "soddisfare",
    "soddisferebbe": "soddisfare",
    "soddisferebber": "soddisfare",
    "soddisferebbero": "soddisfare",
    "soddisferei": "soddisfare",
    "soddisferemmo": "soddisfare",
    "soddisferemo": "soddisfare",
    "soddisfereste": "soddisfare",
    "soddisferesti": "soddisfare",
    "soddisferete": "soddisfare",
    "soddisferà": "soddisfare",
    "soddisferò": "soddisfare",
    "soddisfi": "soddisfare",
    "soddisfiamo": "soddisfare",
    "soddisfiate": "soddisfare",
    "soddisfin": "soddisfare",
    "soddisfino": "soddisfare",
    "soddisfo": "soddisfare",
    "soddisfò": "soddisfare",
    "sode": "sodo",
    "soderai": "sodare",
    "soderan": "sodare",
    "soderanno": "sodare",
    "soderebbe": "sodare",
    "soderebber": "sodare",
    "soderebbero": "sodare",
    "soderei": "sodare",
    "soderemmo": "sodare",
    "soderemo": "sodare",
    "sodereste": "sodare",
    "soderesti": "sodare",
    "soderete": "sodare",
    "soderà": "sodare",
    "soderò": "sodare",
    "sodi": "sodo",
    "sodiamo": "sodare",
    "sodiate": "sodare",
    "sodica": "sodico",
    "sodiche": "sodico",
    "sodici": "sodico",
    "sodii": "sodio",
    "sodin": "sodare",
    "sodino": "sodare",
    "sodo": "sodare",
    "sodomie": "sodomia",
    "sodò": "sodare",
    "sofferenti": "sofferente",
    "sofferenze": "sofferenza",
    "sofferma": "soffermare",
    "soffermai": "soffermare",
    "soffermammo": "soffermare",
    "sofferman": "soffermare",
    "soffermando": "soffermare",
    "soffermano": "soffermare",
    "soffermante": "soffermare",
    "soffermanti": "soffermare",
    "soffermar": "soffermare",
    "soffermaron": "soffermare",
    "soffermarono": "soffermare",
    "soffermasse": "soffermare",
    "soffermasser": "soffermare",
    "soffermassero": "soffermare",
    "soffermassi": "soffermare",
    "soffermassimo": "soffermare",
    "soffermaste": "soffermare",
    "soffermasti": "soffermare",
    "soffermata": "soffermare",
    "soffermate": "soffermare",
    "soffermati": "soffermare",
    "soffermato": "soffermare",
    "soffermava": "soffermare",
    "soffermavamo": "soffermare",
    "soffermavan": "soffermare",
    "soffermavano": "soffermare",
    "soffermavate": "soffermare",
    "soffermavi": "soffermare",
    "soffermavo": "soffermare",
    "soffermerai": "soffermare",
    "soffermeran": "soffermare",
    "soffermeranno": "soffermare",
    "soffermerebbe": "soffermare",
    "soffermerebber": "soffermare",
    "soffermerebbero": "soffermare",
    "soffermerei": "soffermare",
    "soffermeremmo": "soffermare",
    "soffermeremo": "soffermare",
    "soffermereste": "soffermare",
    "soffermeresti": "soffermare",
    "soffermerete": "soffermare",
    "soffermerà": "soffermare",
    "soffermerò": "soffermare",
    "soffermi": "soffermare",
    "soffermiamo": "soffermare",
    "soffermiate": "soffermare",
    "soffermin": "soffermare",
    "soffermino": "soffermare",
    "soffermo": "soffermare",
    "soffermò": "soffermare",
    "sofferta": "soffrire",
    "sofferte": "soffrire",
    "sofferti": "soffrire",
    "sofferto": "soffrire",
    "soffi": "soffio",
    "soffia": "soffiare",
    "soffiai": "soffiare",
    "soffiammo": "soffiare",
    "soffiamo": "soffiare",
    "soffian": "soffiare",
    "soffiando": "soffiare",
    "soffiano": "soffiare",
    "soffiante": "soffiare",
    "soffianti": "soffiare",
    "soffiar": "soffiare",
    "soffiaron": "soffiare",
    "soffiarono": "soffiare",
    "soffiasse": "soffiare",
    "soffiasser": "soffiare",
    "soffiassero": "soffiare",
    "soffiassi": "soffiare",
    "soffiassimo": "soffiare",
    "soffiaste": "soffiare",
    "soffiasti": "soffiare",
    "soffiata": "soffiare",
    "soffiate": "soffiata",
    "soffiati": "soffiare",
    "soffiato": "soffiare",
    "soffiava": "soffiare",
    "soffiavamo": "soffiare",
    "soffiavan": "soffiare",
    "soffiavano": "soffiare",
    "soffiavate": "soffiare",
    "soffiavi": "soffiare",
    "soffiavo": "soffiare",
    "soffici": "soffice",
    "soffierai": "soffiare",
    "soffieran": "soffiare",
    "soffieranno": "soffiare",
    "soffierebbe": "soffiare",
    "soffierebber": "soffiare",
    "soffierebbero": "soffiare",
    "soffierei": "soffiare",
    "soffieremmo": "soffiare",
    "soffieremo": "soffiare",
    "soffiereste": "soffiare",
    "soffieresti": "soffiare",
    "soffierete": "soffiare",
    "soffierà": "soffiare",
    "soffierò": "soffiare",
    "soffietti": "soffietto",
    "soffin": "soffiare",
    "soffino": "soffiare",
    "soffio": "soffiare",
    "soffitta": "soffittare",
    "soffittai": "soffittare",
    "soffittammo": "soffittare",
    "soffittan": "soffittare",
    "soffittando": "soffittare",
    "soffittano": "soffittare",
    "soffittante": "soffittare",
    "soffittanti": "soffittare",
    "soffittar": "soffittare",
    "soffittaron": "soffittare",
    "soffittarono": "soffittare",
    "soffittasse": "soffittare",
    "soffittasser": "soffittare",
    "soffittassero": "soffittare",
    "soffittassi": "soffittare",
    "soffittassimo": "soffittare",
    "soffittaste": "soffittare",
    "soffittasti": "soffittare",
    "soffittata": "soffittare",
    "soffittate": "soffittare",
    "soffittati": "soffittare",
    "soffittato": "soffittare",
    "soffittava": "soffittare",
    "soffittavamo": "soffittare",
    "soffittavan": "soffittare",
    "soffittavano": "soffittare",
    "soffittavate": "soffittare",
    "soffittavi": "soffittare",
    "soffittavo": "soffittare",
    "soffitte": "soffitta",
    "soffitterai": "soffittare",
    "soffitteran": "soffittare",
    "soffitteranno": "soffittare",
    "soffitterebbe": "soffittare",
    "soffitterebber": "soffittare",
    "soffitterebbero": "soffittare",
    "soffitterei": "soffittare",
    "soffitteremmo": "soffittare",
    "soffitteremo": "soffittare",
    "soffittereste": "soffittare",
    "soffitteresti": "soffittare",
    "soffitterete": "soffittare",
    "soffitterà": "soffittare",
    "soffitterò": "soffittare",
    "soffitti": "soffitto",
    "soffittiamo": "soffittare",
    "soffittiate": "soffittare",
    "soffittin": "soffittare",
    "soffittino": "soffittare",
    "soffitto": "soffittare",
    "soffittò": "soffittare",
    "soffiò": "soffiare",
    "soffoca": "soffocare",
    "soffocai": "soffocare",
    "soffocamenti": "soffocamento",
    "soffocammo": "soffocare",
    "soffocan": "soffocare",
    "soffocando": "soffocare",
    "soffocano": "soffocare",
    "soffocante": "soffocare",
    "soffocanti": "soffocare",
    "soffocar": "soffocare",
    "soffocaron": "soffocare",
    "soffocarono": "soffocare",
    "soffocasse": "soffocare",
    "soffocasser": "soffocare",
    "soffocassero": "soffocare",
    "soffocassi": "soffocare",
    "soffocassimo": "soffocare",
    "soffocaste": "soffocare",
    "soffocasti": "soffocare",
    "soffocata": "soffocato",
    "soffocate": "soffocato",
    "soffocati": "soffocato",
    "soffocato": "soffocare",
    "soffocava": "soffocare",
    "soffocavamo": "soffocare",
    "soffocavan": "soffocare",
    "soffocavano": "soffocare",
    "soffocavate": "soffocare",
    "soffocavi": "soffocare",
    "soffocavo": "soffocare",
    "soffocherai": "soffocare",
    "soffocheran": "soffocare",
    "soffocheranno": "soffocare",
    "soffocherebbe": "soffocare",
    "soffocherebber": "soffocare",
    "soffocherebbero": "soffocare",
    "soffocherei": "soffocare",
    "soffocheremmo": "soffocare",
    "soffocheremo": "soffocare",
    "soffochereste": "soffocare",
    "soffocheresti": "soffocare",
    "soffocherete": "soffocare",
    "soffocherà": "soffocare",
    "soffocherò": "soffocare",
    "soffochi": "soffocare",
    "soffochiamo": "soffocare",
    "soffochiate": "soffocare",
    "soffochin": "soffocare",
    "soffochino": "soffocare",
    "soffoco": "soffocare",
    "soffocò": "soffocare",
    "soffonda": "soffondere",
    "soffondan": "soffondere",
    "soffondano": "soffondere",
    "soffonde": "soffondere",
    "soffondemmo": "soffondere",
    "soffondendo": "soffondere",
    "soffondente": "soffondere",
    "soffondenti": "soffondere",
    "soffonder": "soffondere",
    "soffonderai": "soffondere",
    "soffonderan": "soffondere",
    "soffonderanno": "soffondere",
    "soffonderebbe": "soffondere",
    "soffonderebber": "soffondere",
    "soffonderebbero": "soffondere",
    "soffonderei": "soffondere",
    "soffonderemmo": "soffondere",
    "soffonderemo": "soffondere",
    "soffondereste": "soffondere",
    "soffonderesti": "soffondere",
    "soffonderete": "soffondere",
    "soffonderà": "soffondere",
    "soffonderò": "soffondere",
    "soffondesse": "soffondere",
    "soffondesser": "soffondere",
    "soffondessero": "soffondere",
    "soffondessi": "soffondere",
    "soffondessimo": "soffondere",
    "soffondeste": "soffondere",
    "soffondesti": "soffondere",
    "soffondete": "soffondere",
    "soffondeva": "soffondere",
    "soffondevamo": "soffondere",
    "soffondevan": "soffondere",
    "soffondevano": "soffondere",
    "soffondevate": "soffondere",
    "soffondevi": "soffondere",
    "soffondevo": "soffondere",
    "soffondi": "soffondere",
    "soffondiamo": "soffondere",
    "soffondiate": "soffondere",
    "soffondo": "soffondere",
    "soffondon": "soffondere",
    "soffondono": "soffondere",
    "soffra": "soffrire",
    "soffran": "soffrire",
    "soffrano": "soffrire",
    "soffre": "soffrire",
    "soffrendo": "soffrire",
    "soffrente": "soffrire",
    "soffrenti": "soffrire",
    "soffri": "soffrire",
    "soffriamo": "soffrire",
    "soffriate": "soffrire",
    "soffrigga": "soffriggere",
    "soffriggan": "soffriggere",
    "soffriggano": "soffriggere",
    "soffrigge": "soffriggere",
    "soffriggemmo": "soffriggere",
    "soffriggendo": "soffriggere",
    "soffriggente": "soffriggere",
    "soffriggenti": "soffriggere",
    "soffrigger": "soffriggere",
    "soffriggerai": "soffriggere",
    "soffriggeran": "soffriggere",
    "soffriggeranno": "soffriggere",
    "soffriggerebbe": "soffriggere",
    "soffriggerebber": "soffriggere",
    "soffriggerebbero": "soffriggere",
    "soffriggerei": "soffriggere",
    "soffriggeremmo": "soffriggere",
    "soffriggeremo": "soffriggere",
    "soffriggereste": "soffriggere",
    "soffriggeresti": "soffriggere",
    "soffriggerete": "soffriggere",
    "soffriggerà": "soffriggere",
    "soffriggerò": "soffriggere",
    "soffriggesse": "soffriggere",
    "soffriggesser": "soffriggere",
    "soffriggessero": "soffriggere",
    "soffriggessi": "soffriggere",
    "soffriggessimo": "soffriggere",
    "soffriggeste": "soffriggere",
    "soffriggesti": "soffriggere",
    "soffriggete": "soffriggere",
    "soffriggeva": "soffriggere",
    "soffriggevamo": "soffriggere",
    "soffriggevan": "soffriggere",
    "soffriggevano": "soffriggere",
    "soffriggevate": "soffriggere",
    "soffriggevi": "soffriggere",
    "soffriggevo": "soffriggere",
    "soffriggi": "soffriggere",
    "soffriggiamo": "soffriggere",
    "soffriggiate": "soffriggere",
    "soffriggo": "soffriggere",
    "soffriggon": "soffriggere",
    "soffriggono": "soffriggere",
    "soffrii": "soffrire",
    "soffrimmo": "soffrire",
    "soffrir": "soffrire",
    "soffrirai": "soffrire",
    "soffriran": "soffrire",
    "soffriranno": "soffrire",
    "soffrirebbe": "soffrire",
    "soffrirebber": "soffrire",
    "soffrirebbero": "soffrire",
    "soffrirei": "soffrire",
    "soffriremmo": "soffrire",
    "soffriremo": "soffrire",
    "soffrireste": "soffrire",
    "soffriresti": "soffrire",
    "soffrirete": "soffrire",
    "soffriron": "soffrire",
    "soffrirono": "soffrire",
    "soffrirà": "soffrire",
    "soffrirò": "soffrire",
    "soffrisse": "soffrire",
    "soffrisser": "soffrire",
    "soffrissero": "soffrire",
    "soffrissi": "soffrire",
    "soffrissimo": "soffrire",
    "soffrissè": "soffriggere",
    "soffriste": "soffrire",
    "soffristi": "soffrire",
    "soffrite": "soffrire",
    "soffritta": "soffriggere",
    "soffritte": "soffriggere",
    "soffritti": "soffriggere",
    "soffritto": "soffriggere",
    "soffriva": "soffrire",
    "soffrivamo": "soffrire",
    "soffrivan": "soffrire",
    "soffrivano": "soffrire",
    "soffrivate": "soffrire",
    "soffrivi": "soffrire",
    "soffrivo": "soffrire",
    "soffro": "soffrire",
    "soffron": "soffrire",
    "soffrono": "soffrire",
    "soffrì": "soffrire",
    "soffusa": "soffuso",
    "soffuse": "soffuso",
    "soffuser": "soffondere",
    "soffusero": "soffondere",
    "soffusi": "soffuso",
    "soffuso": "soffondere",
    "sofismi": "sofisma",
    "sofisti": "sofista",
    "sofistica": "sofistico",
    "sofisticai": "sofisticare",
    "sofisticammo": "sofisticare",
    "sofistican": "sofisticare",
    "sofisticando": "sofisticare",
    "sofisticano": "sofisticare",
    "sofisticante": "sofisticare",
    "sofisticanti": "sofisticare",
    "sofisticar": "sofisticare",
    "sofisticaron": "sofisticare",
    "sofisticarono": "sofisticare",
    "sofisticasse": "sofisticare",
    "sofisticasser": "sofisticare",
    "sofisticassero": "sofisticare",
    "sofisticassi": "sofisticare",
    "sofisticassimo": "sofisticare",
    "sofisticaste": "sofisticare",
    "sofisticasti": "sofisticare",
    "sofisticata": "sofisticato",
    "sofisticate": "sofisticato",
    "sofisticati": "sofisticato",
    "sofisticato": "sofisticare",
    "sofisticava": "sofisticare",
    "sofisticavamo": "sofisticare",
    "sofisticavan": "sofisticare",
    "sofisticavano": "sofisticare",
    "sofisticavate": "sofisticare",
    "sofisticavi": "sofisticare",
    "sofisticavo": "sofisticare",
    "sofisticazioni": "sofisticazione",
    "sofistiche": "sofistico",
    "sofisticherai": "sofisticare",
    "sofisticheran": "sofisticare",
    "sofisticheranno": "sofisticare",
    "sofisticherebbe": "sofisticare",
    "sofisticherebber": "sofisticare",
    "sofisticherebbero": "sofisticare",
    "sofisticherei": "sofisticare",
    "sofisticheremmo": "sofisticare",
    "sofisticheremo": "sofisticare",
    "sofistichereste": "sofisticare",
    "sofisticheresti": "sofisticare",
    "sofisticherete": "sofisticare",
    "sofisticherie": "sofisticheria",
    "sofisticherà": "sofisticare",
    "sofisticherò": "sofisticare",
    "sofistichi": "sofisticare",
    "sofistichiamo": "sofisticare",
    "sofistichiate": "sofisticare",
    "sofistichin": "sofisticare",
    "sofistichino": "sofisticare",
    "sofistici": "sofistico",
    "sofistico": "sofisticare",
    "sofisticò": "sofisticare",
    "soggetta": "soggetto",
    "soggette": "soggetto",
    "soggetti": "soggetto",
    "soggettisti": "soggettista",
    "soggettiva": "soggettivo",
    "soggettivai": "soggettivare",
    "soggettivammo": "soggettivare",
    "soggettivan": "soggettivare",
    "soggettivando": "soggettivare",
    "soggettivano": "soggettivare",
    "soggettivante": "soggettivare",
    "soggettivanti": "soggettivare",
    "soggettivar": "soggettivare",
    "soggettivaron": "soggettivare",
    "soggettivarono": "soggettivare",
    "soggettivasse": "soggettivare",
    "soggettivasser": "soggettivare",
    "soggettivassero": "soggettivare",
    "soggettivassi": "soggettivare",
    "soggettivassimo": "soggettivare",
    "soggettivaste": "soggettivare",
    "soggettivasti": "soggettivare",
    "soggettivata": "soggettivare",
    "soggettivate": "soggettivare",
    "soggettivati": "soggettivare",
    "soggettivato": "soggettivare",
    "soggettivava": "soggettivare",
    "soggettivavamo": "soggettivare",
    "soggettivavan": "soggettivare",
    "soggettivavano": "soggettivare",
    "soggettivavate": "soggettivare",
    "soggettivavi": "soggettivare",
    "soggettivavo": "soggettivare",
    "soggettive": "soggettivo",
    "soggettiverai": "soggettivare",
    "soggettiveran": "soggettivare",
    "soggettiveranno": "soggettivare",
    "soggettiverebbe": "soggettivare",
    "soggettiverebber": "soggettivare",
    "soggettiverebbero": "soggettivare",
    "soggettiverei": "soggettivare",
    "soggettiveremmo": "soggettivare",
    "soggettiveremo": "soggettivare",
    "soggettivereste": "soggettivare",
    "soggettiveresti": "soggettivare",
    "soggettiverete": "soggettivare",
    "soggettiverà": "soggettivare",
    "soggettiverò": "soggettivare",
    "soggettivi": "soggettivo",
    "soggettiviamo": "soggettivare",
    "soggettiviate": "soggettivare",
    "soggettivin": "soggettivare",
    "soggettivino": "soggettivare",
    "soggettivo": "soggettivare",
    "soggettivò": "soggettivare",
    "soggezioni": "soggezione",
    "sogghigna": "sogghignare",
    "sogghignai": "sogghignare",
    "sogghignammo": "sogghignare",
    "sogghignan": "sogghignare",
    "sogghignando": "sogghignare",
    "sogghignano": "sogghignare",
    "sogghignante": "sogghignare",
    "sogghignanti": "sogghignare",
    "sogghignar": "sogghignare",
    "sogghignaron": "sogghignare",
    "sogghignarono": "sogghignare",
    "sogghignasse": "sogghignare",
    "sogghignasser": "sogghignare",
    "sogghignassero": "sogghignare",
    "sogghignassi": "sogghignare",
    "sogghignassimo": "sogghignare",
    "sogghignaste": "sogghignare",
    "sogghignasti": "sogghignare",
    "sogghignata": "sogghignare",
    "sogghignate": "sogghignare",
    "sogghignati": "sogghignare",
    "sogghignato": "sogghignare",
    "sogghignava": "sogghignare",
    "sogghignavamo": "sogghignare",
    "sogghignavan": "sogghignare",
    "sogghignavano": "sogghignare",
    "sogghignavate": "sogghignare",
    "sogghignavi": "sogghignare",
    "sogghignavo": "sogghignare",
    "sogghignerai": "sogghignare",
    "sogghigneran": "sogghignare",
    "sogghigneranno": "sogghignare",
    "sogghignerebbe": "sogghignare",
    "sogghignerebber": "sogghignare",
    "sogghignerebbero": "sogghignare",
    "sogghignerei": "sogghignare",
    "sogghigneremmo": "sogghignare",
    "sogghigneremo": "sogghignare",
    "sogghignereste": "sogghignare",
    "sogghigneresti": "sogghignare",
    "sogghignerete": "sogghignare",
    "sogghignerà": "sogghignare",
    "sogghignerò": "sogghignare",
    "sogghigni": "sogghigno",
    "sogghigniamo": "sogghignare",
    "sogghigniate": "sogghignare",
    "sogghignin": "sogghignare",
    "sogghignino": "sogghignare",
    "sogghigno": "sogghignare",
    "sogghignò": "sogghignare",
    "soggiaccia": "soggiacere",
    "soggiaccian": "soggiacere",
    "soggiacciano": "soggiacere",
    "soggiaccio": "soggiacere",
    "soggiaccion": "soggiacere",
    "soggiacciono": "soggiacere",
    "soggiace": "soggiacere",
    "soggiacemmo": "soggiacere",
    "soggiacendo": "soggiacere",
    "soggiacente": "soggiacere",
    "soggiacenti": "soggiacere",
    "soggiacer": "soggiacere",
    "soggiacerai": "soggiacere",
    "soggiaceran": "soggiacere",
    "soggiaceranno": "soggiacere",
    "soggiacerebbe": "soggiacere",
    "soggiacerebber": "soggiacere",
    "soggiacerebbero": "soggiacere",
    "soggiacerei": "soggiacere",
    "soggiaceremmo": "soggiacere",
    "soggiaceremo": "soggiacere",
    "soggiacereste": "soggiacere",
    "soggiaceresti": "soggiacere",
    "soggiacerete": "soggiacere",
    "soggiacerà": "soggiacere",
    "soggiacerò": "soggiacere",
    "soggiacesse": "soggiacere",
    "soggiacesser": "soggiacere",
    "soggiacessero": "soggiacere",
    "soggiacessi": "soggiacere",
    "soggiacessimo": "soggiacere",
    "soggiaceste": "soggiacere",
    "soggiacesti": "soggiacere",
    "soggiacete": "soggiacere",
    "soggiaceva": "soggiacere",
    "soggiacevamo": "soggiacere",
    "soggiacevan": "soggiacere",
    "soggiacevano": "soggiacere",
    "soggiacevate": "soggiacere",
    "soggiacevi": "soggiacere",
    "soggiacevo": "soggiacere",
    "soggiaci": "soggiacere",
    "soggiaciamo": "soggiacere",
    "soggiaciate": "soggiacere",
    "soggiaciuta": "soggiacere",
    "soggiaciute": "soggiacere",
    "soggiaciuti": "soggiacere",
    "soggiaciuto": "soggiacere",
    "soggiacque": "soggiacere",
    "soggiacquer": "soggiacere",
    "soggiacquero": "soggiacere",
    "soggiacqui": "soggiacere",
    "soggioga": "soggiogare",
    "soggiogai": "soggiogare",
    "soggiogammo": "soggiogare",
    "soggiogan": "soggiogare",
    "soggiogando": "soggiogare",
    "soggiogano": "soggiogare",
    "soggiogante": "soggiogare",
    "soggioganti": "soggiogare",
    "soggiogar": "soggiogare",
    "soggiogaron": "soggiogare",
    "soggiogarono": "soggiogare",
    "soggiogasse": "soggiogare",
    "soggiogasser": "soggiogare",
    "soggiogassero": "soggiogare",
    "soggiogassi": "soggiogare",
    "soggiogassimo": "soggiogare",
    "soggiogaste": "soggiogare",
    "soggiogasti": "soggiogare",
    "soggiogata": "soggiogare",
    "soggiogate": "soggiogare",
    "soggiogati": "soggiogare",
    "soggiogato": "soggiogare",
    "soggiogava": "soggiogare",
    "soggiogavamo": "soggiogare",
    "soggiogavan": "soggiogare",
    "soggiogavano": "soggiogare",
    "soggiogavate": "soggiogare",
    "soggiogavi": "soggiogare",
    "soggiogavo": "soggiogare",
    "soggiogherai": "soggiogare",
    "soggiogheran": "soggiogare",
    "soggiogheranno": "soggiogare",
    "soggiogherebbe": "soggiogare",
    "soggiogherebber": "soggiogare",
    "soggiogherebbero": "soggiogare",
    "soggiogherei": "soggiogare",
    "soggiogheremmo": "soggiogare",
    "soggiogheremo": "soggiogare",
    "soggioghereste": "soggiogare",
    "soggiogheresti": "soggiogare",
    "soggiogherete": "soggiogare",
    "soggiogherà": "soggiogare",
    "soggiogherò": "soggiogare",
    "soggioghi": "soggiogare",
    "soggioghiamo": "soggiogare",
    "soggioghiate": "soggiogare",
    "soggioghin": "soggiogare",
    "soggioghino": "soggiogare",
    "soggiogo": "soggiogare",
    "soggiogò": "soggiogare",
    "soggiorna": "soggiornare",
    "soggiornai": "soggiornare",
    "soggiornammo": "soggiornare",
    "soggiornan": "soggiornare",
    "soggiornando": "soggiornare",
    "soggiornano": "soggiornare",
    "soggiornante": "soggiornare",
    "soggiornanti": "soggiornare",
    "soggiornar": "soggiornare",
    "soggiornaron": "soggiornare",
    "soggiornarono": "soggiornare",
    "soggiornasse": "soggiornare",
    "soggiornasser": "soggiornare",
    "soggiornassero": "soggiornare",
    "soggiornassi": "soggiornare",
    "soggiornassimo": "soggiornare",
    "soggiornaste": "soggiornare",
    "soggiornasti": "soggiornare",
    "soggiornata": "soggiornare",
    "soggiornate": "soggiornare",
    "soggiornati": "soggiornare",
    "soggiornato": "soggiornare",
    "soggiornava": "soggiornare",
    "soggiornavamo": "soggiornare",
    "soggiornavan": "soggiornare",
    "soggiornavano": "soggiornare",
    "soggiornavate": "soggiornare",
    "soggiornavi": "soggiornare",
    "soggiornavo": "soggiornare",
    "soggiornerai": "soggiornare",
    "soggiorneran": "soggiornare",
    "soggiorneranno": "soggiornare",
    "soggiornerebbe": "soggiornare",
    "soggiornerebber": "soggiornare",
    "soggiornerebbero": "soggiornare",
    "soggiornerei": "soggiornare",
    "soggiorneremmo": "soggiornare",
    "soggiorneremo": "soggiornare",
    "soggiornereste": "soggiornare",
    "soggiorneresti": "soggiornare",
    "soggiornerete": "soggiornare",
    "soggiornerà": "soggiornare",
    "soggiornerò": "soggiornare",
    "soggiorni": "soggiorno",
    "soggiorniamo": "soggiornare",
    "soggiorniate": "soggiornare",
    "soggiornin": "soggiornare",
    "soggiornino": "soggiornare",
    "soggiorno": "soggiornare",
    "soggiornò": "soggiornare",
    "soggiunga": "soggiungere",
    "soggiungan": "soggiungere",
    "soggiungano": "soggiungere",
    "soggiunge": "soggiungere",
    "soggiungemmo": "soggiungere",
    "soggiungendo": "soggiungere",
    "soggiungente": "soggiungere",
    "soggiungenti": "soggiungere",
    "soggiunger": "soggiungere",
    "soggiungerai": "soggiungere",
    "soggiungeran": "soggiungere",
    "soggiungeranno": "soggiungere",
    "soggiungerebbe": "soggiungere",
    "soggiungerebber": "soggiungere",
    "soggiungerebbero": "soggiungere",
    "soggiungerei": "soggiungere",
    "soggiungeremmo": "soggiungere",
    "soggiungeremo": "soggiungere",
    "soggiungereste": "soggiungere",
    "soggiungeresti": "soggiungere",
    "soggiungerete": "soggiungere",
    "soggiungerà": "soggiungere",
    "soggiungerò": "soggiungere",
    "soggiungesse": "soggiungere",
    "soggiungesser": "soggiungere",
    "soggiungessero": "soggiungere",
    "soggiungessi": "soggiungere",
    "soggiungessimo": "soggiungere",
    "soggiungeste": "soggiungere",
    "soggiungesti": "soggiungere",
    "soggiungete": "soggiungere",
    "soggiungeva": "soggiungere",
    "soggiungevamo": "soggiungere",
    "soggiungevan": "soggiungere",
    "soggiungevano": "soggiungere",
    "soggiungevate": "soggiungere",
    "soggiungevi": "soggiungere",
    "soggiungevo": "soggiungere",
    "soggiungi": "soggiungere",
    "soggiungiamo": "soggiungere",
    "soggiungiate": "soggiungere",
    "soggiungo": "soggiungere",
    "soggiungon": "soggiungere",
    "soggiungono": "soggiungere",
    "soggiunse": "soggiungere",
    "soggiunser": "soggiungere",
    "soggiunsero": "soggiungere",
    "soggiunsi": "soggiungere",
    "soggiunta": "soggiungere",
    "soggiunte": "soggiungere",
    "soggiunti": "soggiungere",
    "soggiunto": "soggiungere",
    "soglie": "soglia",
    "sogliole": "sogliola",
    "sogna": "sognare",
    "sognai": "sognare",
    "sognammo": "sognare",
    "sognan": "sognare",
    "sognando": "sognare",
    "sognano": "sognare",
    "sognante": "sognare",
    "sognanti": "sognare",
    "sognar": "sognare",
    "sognaron": "sognare",
    "sognarono": "sognare",
    "sognasse": "sognare",
    "sognasser": "sognare",
    "sognassero": "sognare",
    "sognassi": "sognare",
    "sognassimo": "sognare",
    "sognaste": "sognare",
    "sognasti": "sognare",
    "sognata": "sognare",
    "sognate": "sognare",
    "sognati": "sognare",
    "sognato": "sognare",
    "sognatori": "sognatore",
    "sognatrice": "sognatore",
    "sognatrici": "sognatore",
    "sognava": "sognare",
    "sognavamo": "sognare",
    "sognavan": "sognare",
    "sognavano": "sognare",
    "sognavate": "sognare",
    "sognavi": "sognare",
    "sognavo": "sognare",
    "sognerai": "sognare",
    "sogneran": "sognare",
    "sogneranno": "sognare",
    "sognerebbe": "sognare",
    "sognerebber": "sognare",
    "sognerebbero": "sognare",
    "sognerei": "sognare",
    "sogneremmo": "sognare",
    "sogneremo": "sognare",
    "sognereste": "sognare",
    "sogneresti": "sognare",
    "sognerete": "sognare",
    "sognerà": "sognare",
    "sognerò": "sognare",
    "sogni": "sogno",
    "sogniamo": "sognare",
    "sogniate": "sognare",
    "sognin": "sognare",
    "sognino": "sognare",
    "sogno": "sognare",
    "sognò": "sognare",
    "soie": "soia",
    "soirées": "soirée",
    "sol": "sole",
    "sola": "solo",
    "solai": "solare",
    "solammo": "solare",
    "solan": "solere",
    "solando": "solare",
    "solano": "solere",
    "solante": "solare",
    "solanti": "solare",
    "solar": "solare",
    "solari": "solare",
    "solaron": "solare",
    "solarono": "solare",
    "solasse": "solare",
    "solasser": "solare",
    "solassero": "solare",
    "solassi": "solare",
    "solassimo": "solare",
    "solaste": "solare",
    "solasti": "solare",
    "solata": "solato",
    "solate": "solato",
    "solati": "solato",
    "solatia": "solatio",
    "solatie": "solatio",
    "solato": "solare",
    "solava": "solare",
    "solavamo": "solare",
    "solavan": "solare",
    "solavano": "solare",
    "solavate": "solare",
    "solavi": "solare",
    "solavo": "solare",
    "solca": "solcare",
    "solcai": "solcare",
    "solcammo": "solcare",
    "solcan": "solcare",
    "solcando": "solcare",
    "solcano": "solcare",
    "solcante": "solcare",
    "solcanti": "solcare",
    "solcar": "solcare",
    "solcaron": "solcare",
    "solcarono": "solcare",
    "solcasse": "solcare",
    "solcasser": "solcare",
    "solcassero": "solcare",
    "solcassi": "solcare",
    "solcassimo": "solcare",
    "solcaste": "solcare",
    "solcasti": "solcare",
    "solcata": "solcare",
    "solcate": "solcare",
    "solcati": "solcare",
    "solcato": "solcare",
    "solcava": "solcare",
    "solcavamo": "solcare",
    "solcavan": "solcare",
    "solcavano": "solcare",
    "solcavate": "solcare",
    "solcavi": "solcare",
    "solcavo": "solcare",
    "solcherai": "solcare",
    "solcheran": "solcare",
    "solcheranno": "solcare",
    "solcherebbe": "solcare",
    "solcherebber": "solcare",
    "solcherebbero": "solcare",
    "solcherei": "solcare",
    "solcheremmo": "solcare",
    "solcheremo": "solcare",
    "solchereste": "solcare",
    "solcheresti": "solcare",
    "solcherete": "solcare",
    "solcherà": "solcare",
    "solcherò": "solcare",
    "solchi": "solco",
    "solchiamo": "solcare",
    "solchiate": "solcare",
    "solchin": "solcare",
    "solchino": "solcare",
    "solco": "solcare",
    "solcò": "solcare",
    "soldatacci": "soldataccio",
    "soldataglie": "soldataglia",
    "soldatesse": "soldatessa",
    "soldati": "soldato",
    "soldatini": "soldatino",
    "soldi": "soldo",
    "soldini": "soldino",
    "sole": "solo",
    "soleggerai": "soleggiare",
    "soleggeran": "soleggiare",
    "soleggeranno": "soleggiare",
    "soleggerebbe": "soleggiare",
    "soleggerebber": "soleggiare",
    "soleggerebbero": "soleggiare",
    "soleggerei": "soleggiare",
    "soleggeremmo": "soleggiare",
    "soleggeremo": "soleggiare",
    "soleggereste": "soleggiare",
    "soleggeresti": "soleggiare",
    "soleggerete": "soleggiare",
    "soleggerà": "soleggiare",
    "soleggerò": "soleggiare",
    "soleggi": "soleggiare",
    "soleggia": "soleggiare",
    "soleggiai": "soleggiare",
    "soleggiammo": "soleggiare",
    "soleggiamo": "soleggiare",
    "soleggian": "soleggiare",
    "soleggiando": "soleggiare",
    "soleggiano": "soleggiare",
    "soleggiante": "soleggiare",
    "soleggianti": "soleggiare",
    "soleggiar": "soleggiare",
    "soleggiaron": "soleggiare",
    "soleggiarono": "soleggiare",
    "soleggiasse": "soleggiare",
    "soleggiasser": "soleggiare",
    "soleggiassero": "soleggiare",
    "soleggiassi": "soleggiare",
    "soleggiassimo": "soleggiare",
    "soleggiaste": "soleggiare",
    "soleggiasti": "soleggiare",
    "soleggiata": "soleggiato",
    "soleggiate": "soleggiato",
    "soleggiati": "soleggiato",
    "soleggiato": "soleggiare",
    "soleggiava": "soleggiare",
    "soleggiavamo": "soleggiare",
    "soleggiavan": "soleggiare",
    "soleggiavano": "soleggiare",
    "soleggiavate": "soleggiare",
    "soleggiavi": "soleggiare",
    "soleggiavo": "soleggiare",
    "soleggin": "soleggiare",
    "soleggino": "soleggiare",
    "soleggio": "soleggiare",
    "soleggiò": "soleggiare",
    "solei": "solere",
    "solemmo": "solere",
    "solendo": "solere",
    "solenni": "solenne",
    "solennizza": "solennizzare",
    "solennizzai": "solennizzare",
    "solennizzammo": "solennizzare",
    "solennizzan": "solennizzare",
    "solennizzando": "solennizzare",
    "solennizzano": "solennizzare",
    "solennizzante": "solennizzare",
    "solennizzanti": "solennizzare",
    "solennizzar": "solennizzare",
    "solennizzaron": "solennizzare",
    "solennizzarono": "solennizzare",
    "solennizzasse": "solennizzare",
    "solennizzasser": "solennizzare",
    "solennizzassero": "solennizzare",
    "solennizzassi": "solennizzare",
    "solennizzassimo": "solennizzare",
    "solennizzaste": "solennizzare",
    "solennizzasti": "solennizzare",
    "solennizzata": "solennizzare",
    "solennizzate": "solennizzare",
    "solennizzati": "solennizzare",
    "solennizzato": "solennizzare",
    "solennizzava": "solennizzare",
    "solennizzavamo": "solennizzare",
    "solennizzavan": "solennizzare",
    "solennizzavano": "solennizzare",
    "solennizzavate": "solennizzare",
    "solennizzavi": "solennizzare",
    "solennizzavo": "solennizzare",
    "solennizzerai": "solennizzare",
    "solennizzeran": "solennizzare",
    "solennizzeranno": "solennizzare",
    "solennizzerebbe": "solennizzare",
    "solennizzerebber": "solennizzare",
    "solennizzerebbero": "solennizzare",
    "solennizzerei": "solennizzare",
    "solennizzeremmo": "solennizzare",
    "solennizzeremo": "solennizzare",
    "solennizzereste": "solennizzare",
    "solennizzeresti": "solennizzare",
    "solennizzerete": "solennizzare",
    "solennizzerà": "solennizzare",
    "solennizzerò": "solennizzare",
    "solennizzi": "solennizzare",
    "solennizziamo": "solennizzare",
    "solennizziate": "solennizzare",
    "solennizzin": "solennizzare",
    "solennizzino": "solennizzare",
    "solennizzo": "solennizzare",
    "solennizzò": "solennizzare",
    "solente": "solere",
    "solenti": "solere",
    "soler": "solere",
    "solerai": "solere",
    "soleran": "solere",
    "soleranno": "solere",
    "solerebbe": "solere",
    "solerebber": "solere",
    "solerebbero": "solere",
    "solerei": "solere",
    "soleremmo": "solere",
    "soleremo": "solere",
    "solereste": "solere",
    "soleresti": "solere",
    "solerete": "solere",
    "soleron": "solere",
    "solerono": "solere",
    "solerti": "solerte",
    "solerzie": "solerzia",
    "solerà": "solere",
    "solerò": "solere",
    "solesse": "solere",
    "solesser": "solere",
    "solessero": "solere",
    "solessi": "solere",
    "solessimo": "solere",
    "soleste": "solere",
    "solesti": "solere",
    "solete": "solere",
    "solette": "soletta",
    "soleva": "solere",
    "solevamo": "solere",
    "solevan": "solere",
    "solevano": "solere",
    "solevate": "solere",
    "solevi": "solere",
    "solevo": "solere",
    "solfe": "solfa",
    "solfeggerai": "solfeggiare",
    "solfeggeran": "solfeggiare",
    "solfeggeranno": "solfeggiare",
    "solfeggerebbe": "solfeggiare",
    "solfeggerebber": "solfeggiare",
    "solfeggerebbero": "solfeggiare",
    "solfeggerei": "solfeggiare",
    "solfeggeremmo": "solfeggiare",
    "solfeggeremo": "solfeggiare",
    "solfeggereste": "solfeggiare",
    "solfeggeresti": "solfeggiare",
    "solfeggerete": "solfeggiare",
    "solfeggerà": "solfeggiare",
    "solfeggerò": "solfeggiare",
    "solfeggi": "solfeggiare",
    "solfeggia": "solfeggiare",
    "solfeggiai": "solfeggiare",
    "solfeggiammo": "solfeggiare",
    "solfeggiamo": "solfeggiare",
    "solfeggian": "solfeggiare",
    "solfeggiando": "solfeggiare",
    "solfeggiano": "solfeggiare",
    "solfeggiante": "solfeggiare",
    "solfeggianti": "solfeggiare",
    "solfeggiar": "solfeggiare",
    "solfeggiaron": "solfeggiare",
    "solfeggiarono": "solfeggiare",
    "solfeggiasse": "solfeggiare",
    "solfeggiasser": "solfeggiare",
    "solfeggiassero": "solfeggiare",
    "solfeggiassi": "solfeggiare",
    "solfeggiassimo": "solfeggiare",
    "solfeggiaste": "solfeggiare",
    "solfeggiasti": "solfeggiare",
    "solfeggiata": "solfeggiare",
    "solfeggiate": "solfeggiare",
    "solfeggiati": "solfeggiare",
    "solfeggiato": "solfeggiare",
    "solfeggiava": "solfeggiare",
    "solfeggiavamo": "solfeggiare",
    "solfeggiavan": "solfeggiare",
    "solfeggiavano": "solfeggiare",
    "solfeggiavate": "solfeggiare",
    "solfeggiavi": "solfeggiare",
    "solfeggiavo": "solfeggiare",
    "solfeggin": "solfeggiare",
    "solfeggino": "solfeggiare",
    "solfeggio": "solfeggiare",
    "solfeggiò": "solfeggiare",
    "solfora": "solforare",
    "solforai": "solforare",
    "solforammo": "solforare",
    "solforan": "solforare",
    "solforando": "solforare",
    "solforano": "solforare",
    "solforante": "solforare",
    "solforanti": "solforare",
    "solforar": "solforare",
    "solforaron": "solforare",
    "solforarono": "solforare",
    "solforasse": "solforare",
    "solforasser": "solforare",
    "solforassero": "solforare",
    "solforassi": "solforare",
    "solforassimo": "solforare",
    "solforaste": "solforare",
    "solforasti": "solforare",
    "solforata": "solforato",
    "solforate": "solforato",
    "solforati": "solforato",
    "solforato": "solforare",
    "solforava": "solforare",
    "solforavamo": "solforare",
    "solforavan": "solforare",
    "solforavano": "solforare",
    "solforavate": "solforare",
    "solforavi": "solforare",
    "solforavo": "solforare",
    "solforerai": "solforare",
    "solforeran": "solforare",
    "solforeranno": "solforare",
    "solforerebbe": "solforare",
    "solforerebber": "solforare",
    "solforerebbero": "solforare",
    "solforerei": "solforare",
    "solforeremmo": "solforare",
    "solforeremo": "solforare",
    "solforereste": "solforare",
    "solforeresti": "solforare",
    "solforerete": "solforare",
    "solforerà": "solforare",
    "solforerò": "solforare",
    "solfori": "solforare",
    "solforiamo": "solforare",
    "solforiate": "solforare",
    "solforica": "solforico",
    "solforiche": "solforico",
    "solforici": "solforico",
    "solforin": "solforare",
    "solforino": "solforare",
    "solforo": "solforare",
    "solforosa": "solforoso",
    "solforose": "solforoso",
    "solforosi": "solforoso",
    "solforò": "solforare",
    "soli": "solo",
    "soliamo": "solere",
    "soliate": "solere",
    "solida": "solido",
    "solidali": "solidale",
    "solidarismi": "solidarismo",
    "solidarizza": "solidarizzare",
    "solidarizzai": "solidarizzare",
    "solidarizzammo": "solidarizzare",
    "solidarizzan": "solidarizzare",
    "solidarizzando": "solidarizzare",
    "solidarizzano": "solidarizzare",
    "solidarizzante": "solidarizzare",
    "solidarizzanti": "solidarizzare",
    "solidarizzar": "solidarizzare",
    "solidarizzaron": "solidarizzare",
    "solidarizzarono": "solidarizzare",
    "solidarizzasse": "solidarizzare",
    "solidarizzasser": "solidarizzare",
    "solidarizzassero": "solidarizzare",
    "solidarizzassi": "solidarizzare",
    "solidarizzassimo": "solidarizzare",
    "solidarizzaste": "solidarizzare",
    "solidarizzasti": "solidarizzare",
    "solidarizzata": "solidarizzare",
    "solidarizzate": "solidarizzare",
    "solidarizzati": "solidarizzare",
    "solidarizzato": "solidarizzare",
    "solidarizzava": "solidarizzare",
    "solidarizzavamo": "solidarizzare",
    "solidarizzavan": "solidarizzare",
    "solidarizzavano": "solidarizzare",
    "solidarizzavate": "solidarizzare",
    "solidarizzavi": "solidarizzare",
    "solidarizzavo": "solidarizzare",
    "solidarizzerai": "solidarizzare",
    "solidarizzeran": "solidarizzare",
    "solidarizzeranno": "solidarizzare",
    "solidarizzerebbe": "solidarizzare",
    "solidarizzerebber": "solidarizzare",
    "solidarizzerebbero": "solidarizzare",
    "solidarizzerei": "solidarizzare",
    "solidarizzeremmo": "solidarizzare",
    "solidarizzeremo": "solidarizzare",
    "solidarizzereste": "solidarizzare",
    "solidarizzeresti": "solidarizzare",
    "solidarizzerete": "solidarizzare",
    "solidarizzerà": "solidarizzare",
    "solidarizzerò": "solidarizzare",
    "solidarizzi": "solidarizzare",
    "solidarizziamo": "solidarizzare",
    "solidarizziate": "solidarizzare",
    "solidarizzin": "solidarizzare",
    "solidarizzino": "solidarizzare",
    "solidarizzo": "solidarizzare",
    "solidarizzò": "solidarizzare",
    "solide": "solido",
    "solidi": "solido",
    "solidifica": "solidificare",
    "solidificai": "solidificare",
    "solidificammo": "solidificare",
    "solidifican": "solidificare",
    "solidificando": "solidificare",
    "solidificano": "solidificare",
    "solidificante": "solidificare",
    "solidificanti": "solidificare",
    "solidificar": "solidificare",
    "solidificaron": "solidificare",
    "solidificarono": "solidificare",
    "solidificasse": "solidificare",
    "solidificasser": "solidificare",
    "solidificassero": "solidificare",
    "solidificassi": "solidificare",
    "solidificassimo": "solidificare",
    "solidificaste": "solidificare",
    "solidificasti": "solidificare",
    "solidificata": "solidificare",
    "solidificate": "solidificare",
    "solidificati": "solidificare",
    "solidificato": "solidificare",
    "solidificava": "solidificare",
    "solidificavamo": "solidificare",
    "solidificavan": "solidificare",
    "solidificavano": "solidificare",
    "solidificavate": "solidificare",
    "solidificavi": "solidificare",
    "solidificavo": "solidificare",
    "solidificherai": "solidificare",
    "solidificheran": "solidificare",
    "solidificheranno": "solidificare",
    "solidificherebbe": "solidificare",
    "solidificherebber": "solidificare",
    "solidificherebbero": "solidificare",
    "solidificherei": "solidificare",
    "solidificheremmo": "solidificare",
    "solidificheremo": "solidificare",
    "solidifichereste": "solidificare",
    "solidificheresti": "solidificare",
    "solidificherete": "solidificare",
    "solidificherà": "solidificare",
    "solidificherò": "solidificare",
    "solidifichi": "solidificare",
    "solidifichiamo": "solidificare",
    "solidifichiate": "solidificare",
    "solidifichin": "solidificare",
    "solidifichino": "solidificare",
    "solidifico": "solidificare",
    "solidificò": "solidificare",
    "soliloqui": "soliloquio",
    "solin": "solare",
    "solino": "solare",
    "soliste": "solista",
    "solisti": "solista",
    "solistica": "solistico",
    "solistiche": "solistico",
    "solistici": "solistico",
    "solita": "solito",
    "solitari": "solitario",
    "solitaria": "solitario",
    "solitarie": "solitario",
    "solite": "solito",
    "soliti": "solito",
    "solitudini": "solitudine",
    "sollazza": "sollazzare",
    "sollazzai": "sollazzare",
    "sollazzammo": "sollazzare",
    "sollazzan": "sollazzare",
    "sollazzando": "sollazzare",
    "sollazzano": "sollazzare",
    "sollazzante": "sollazzare",
    "sollazzanti": "sollazzare",
    "sollazzar": "sollazzare",
    "sollazzaron": "sollazzare",
    "sollazzarono": "sollazzare",
    "sollazzasse": "sollazzare",
    "sollazzasser": "sollazzare",
    "sollazzassero": "sollazzare",
    "sollazzassi": "sollazzare",
    "sollazzassimo": "sollazzare",
    "sollazzaste": "sollazzare",
    "sollazzasti": "sollazzare",
    "sollazzata": "sollazzare",
    "sollazzate": "sollazzare",
    "sollazzati": "sollazzare",
    "sollazzato": "sollazzare",
    "sollazzava": "sollazzare",
    "sollazzavamo": "sollazzare",
    "sollazzavan": "sollazzare",
    "sollazzavano": "sollazzare",
    "sollazzavate": "sollazzare",
    "sollazzavi": "sollazzare",
    "sollazzavo": "sollazzare",
    "sollazzerai": "sollazzare",
    "sollazzeran": "sollazzare",
    "sollazzeranno": "sollazzare",
    "sollazzerebbe": "sollazzare",
    "sollazzerebber": "sollazzare",
    "sollazzerebbero": "sollazzare",
    "sollazzerei": "sollazzare",
    "sollazzeremmo": "sollazzare",
    "sollazzeremo": "sollazzare",
    "sollazzereste": "sollazzare",
    "sollazzeresti": "sollazzare",
    "sollazzerete": "sollazzare",
    "sollazzerà": "sollazzare",
    "sollazzerò": "sollazzare",
    "sollazzi": "sollazzo",
    "sollazziamo": "sollazzare",
    "sollazziate": "sollazzare",
    "sollazzin": "sollazzare",
    "sollazzino": "sollazzare",
    "sollazzo": "sollazzare",
    "sollazzò": "sollazzare",
    "sollecita": "sollecito",
    "sollecitai": "sollecitare",
    "sollecitammo": "sollecitare",
    "sollecitan": "sollecitare",
    "sollecitando": "sollecitare",
    "sollecitano": "sollecitare",
    "sollecitante": "sollecitare",
    "sollecitanti": "sollecitare",
    "sollecitar": "sollecitare",
    "sollecitaron": "sollecitare",
    "sollecitarono": "sollecitare",
    "sollecitasse": "sollecitare",
    "sollecitasser": "sollecitare",
    "sollecitassero": "sollecitare",
    "sollecitassi": "sollecitare",
    "sollecitassimo": "sollecitare",
    "sollecitaste": "sollecitare",
    "sollecitasti": "sollecitare",
    "sollecitata": "sollecitare",
    "sollecitate": "sollecitare",
    "sollecitati": "sollecitare",
    "sollecitato": "sollecitare",
    "sollecitava": "sollecitare",
    "sollecitavamo": "sollecitare",
    "sollecitavan": "sollecitare",
    "sollecitavano": "sollecitare",
    "sollecitavate": "sollecitare",
    "sollecitavi": "sollecitare",
    "sollecitavo": "sollecitare",
    "sollecitazioni": "sollecitazione",
    "sollecite": "sollecito",
    "solleciterai": "sollecitare",
    "solleciteran": "sollecitare",
    "solleciteranno": "sollecitare",
    "solleciterebbe": "sollecitare",
    "solleciterebber": "sollecitare",
    "solleciterebbero": "sollecitare",
    "solleciterei": "sollecitare",
    "solleciteremmo": "sollecitare",
    "solleciteremo": "sollecitare",
    "sollecitereste": "sollecitare",
    "solleciteresti": "sollecitare",
    "solleciterete": "sollecitare",
    "solleciterà": "sollecitare",
    "solleciterò": "sollecitare",
    "solleciti": "sollecito",
    "sollecitiamo": "sollecitare",
    "sollecitiate": "sollecitare",
    "sollecitin": "sollecitare",
    "sollecitino": "sollecitare",
    "sollecito": "sollecitare",
    "sollecitudini": "sollecitudine",
    "sollecitò": "sollecitare",
    "solleoni": "solleone",
    "solletica": "solleticare",
    "solleticai": "solleticare",
    "solleticammo": "solleticare",
    "solletican": "solleticare",
    "solleticando": "solleticare",
    "solleticano": "solleticare",
    "solleticante": "solleticare",
    "solleticanti": "solleticare",
    "solleticar": "solleticare",
    "solleticaron": "solleticare",
    "solleticarono": "solleticare",
    "solleticasse": "solleticare",
    "solleticasser": "solleticare",
    "solleticassero": "solleticare",
    "solleticassi": "solleticare",
    "solleticassimo": "solleticare",
    "solleticaste": "solleticare",
    "solleticasti": "solleticare",
    "solleticata": "solleticare",
    "solleticate": "solleticare",
    "solleticati": "solleticare",
    "solleticato": "solleticare",
    "solleticava": "solleticare",
    "solleticavamo": "solleticare",
    "solleticavan": "solleticare",
    "solleticavano": "solleticare",
    "solleticavate": "solleticare",
    "solleticavi": "solleticare",
    "solleticavo": "solleticare",
    "solleticherai": "solleticare",
    "solleticheran": "solleticare",
    "solleticheranno": "solleticare",
    "solleticherebbe": "solleticare",
    "solleticherebber": "solleticare",
    "solleticherebbero": "solleticare",
    "solleticherei": "solleticare",
    "solleticheremmo": "solleticare",
    "solleticheremo": "solleticare",
    "solletichereste": "solleticare",
    "solleticheresti": "solleticare",
    "solleticherete": "solleticare",
    "solleticherà": "solleticare",
    "solleticherò": "solleticare",
    "solletichi": "solletico",
    "solletichiamo": "solleticare",
    "solletichiate": "solleticare",
    "solletichin": "solleticare",
    "solletichino": "solleticare",
    "solletico": "solleticare",
    "solleticò": "solleticare",
    "solleva": "sollevare",
    "sollevai": "sollevare",
    "sollevamenti": "sollevamento",
    "sollevammo": "sollevare",
    "sollevan": "sollevare",
    "sollevando": "sollevare",
    "sollevano": "sollevare",
    "sollevante": "sollevare",
    "sollevanti": "sollevare",
    "sollevar": "sollevare",
    "sollevaron": "sollevare",
    "sollevarono": "sollevare",
    "sollevasse": "sollevare",
    "sollevasser": "sollevare",
    "sollevassero": "sollevare",
    "sollevassi": "sollevare",
    "sollevassimo": "sollevare",
    "sollevaste": "sollevare",
    "sollevasti": "sollevare",
    "sollevata": "sollevato",
    "sollevate": "sollevato",
    "sollevati": "sollevato",
    "sollevato": "sollevare",
    "sollevatori": "sollevatore",
    "sollevatrice": "sollevatore",
    "sollevatrici": "sollevatore",
    "sollevava": "sollevare",
    "sollevavamo": "sollevare",
    "sollevavan": "sollevare",
    "sollevavano": "sollevare",
    "sollevavate": "sollevare",
    "sollevavi": "sollevare",
    "sollevavo": "sollevare",
    "sollevazioni": "sollevazione",
    "solleverai": "sollevare",
    "solleveran": "sollevare",
    "solleveranno": "sollevare",
    "solleverebbe": "sollevare",
    "solleverebber": "sollevare",
    "solleverebbero": "sollevare",
    "solleverei": "sollevare",
    "solleveremmo": "sollevare",
    "solleveremo": "sollevare",
    "sollevereste": "sollevare",
    "solleveresti": "sollevare",
    "solleverete": "sollevare",
    "solleverà": "sollevare",
    "solleverò": "sollevare",
    "sollevi": "sollevare",
    "solleviamo": "sollevare",
    "solleviate": "sollevare",
    "sollevin": "sollevare",
    "sollevino": "sollevare",
    "sollevo": "sollevare",
    "sollevò": "sollevare",
    "sollievi": "sollievo",
    "solo": "solere",
    "solon": "solere",
    "soloni": "solone",
    "solono": "solere",
    "solstizi": "solstizio",
    "solubili": "solubile",
    "solubilizza": "solubilizzare",
    "solubilizzai": "solubilizzare",
    "solubilizzammo": "solubilizzare",
    "solubilizzan": "solubilizzare",
    "solubilizzando": "solubilizzare",
    "solubilizzano": "solubilizzare",
    "solubilizzante": "solubilizzare",
    "solubilizzanti": "solubilizzare",
    "solubilizzar": "solubilizzare",
    "solubilizzaron": "solubilizzare",
    "solubilizzarono": "solubilizzare",
    "solubilizzasse": "solubilizzare",
    "solubilizzasser": "solubilizzare",
    "solubilizzassero": "solubilizzare",
    "solubilizzassi": "solubilizzare",
    "solubilizzassimo": "solubilizzare",
    "solubilizzaste": "solubilizzare",
    "solubilizzasti": "solubilizzare",
    "solubilizzata": "solubilizzare",
    "solubilizzate": "solubilizzare",
    "solubilizzati": "solubilizzare",
    "solubilizzato": "solubilizzare",
    "solubilizzava": "solubilizzare",
    "solubilizzavamo": "solubilizzare",
    "solubilizzavan": "solubilizzare",
    "solubilizzavano": "solubilizzare",
    "solubilizzavate": "solubilizzare",
    "solubilizzavi": "solubilizzare",
    "solubilizzavo": "solubilizzare",
    "solubilizzerai": "solubilizzare",
    "solubilizzeran": "solubilizzare",
    "solubilizzeranno": "solubilizzare",
    "solubilizzerebbe": "solubilizzare",
    "solubilizzerebber": "solubilizzare",
    "solubilizzerebbero": "solubilizzare",
    "solubilizzerei": "solubilizzare",
    "solubilizzeremmo": "solubilizzare",
    "solubilizzeremo": "solubilizzare",
    "solubilizzereste": "solubilizzare",
    "solubilizzeresti": "solubilizzare",
    "solubilizzerete": "solubilizzare",
    "solubilizzerà": "solubilizzare",
    "solubilizzerò": "solubilizzare",
    "solubilizzi": "solubilizzare",
    "solubilizziamo": "solubilizzare",
    "solubilizziate": "solubilizzare",
    "solubilizzin": "solubilizzare",
    "solubilizzino": "solubilizzare",
    "solubilizzo": "solubilizzare",
    "solubilizzò": "solubilizzare",
    "soluta": "solere",
    "solute": "solere",
    "soluti": "solere",
    "soluto": "solere",
    "soluzioni": "soluzione",
    "solventi": "solvente",
    "solvibili": "solvibile",
    "solè": "solere",
    "solò": "solare",
    "somala": "somalo",
    "somale": "somalo",
    "somali": "somalo",
    "somara": "somaro",
    "somare": "somaro",
    "somari": "somaro",
    "somatica": "somatico",
    "somatiche": "somatico",
    "somatici": "somatico",
    "somatizza": "somatizzare",
    "somatizzai": "somatizzare",
    "somatizzammo": "somatizzare",
    "somatizzan": "somatizzare",
    "somatizzando": "somatizzare",
    "somatizzano": "somatizzare",
    "somatizzante": "somatizzare",
    "somatizzanti": "somatizzare",
    "somatizzar": "somatizzare",
    "somatizzaron": "somatizzare",
    "somatizzarono": "somatizzare",
    "somatizzasse": "somatizzare",
    "somatizzasser": "somatizzare",
    "somatizzassero": "somatizzare",
    "somatizzassi": "somatizzare",
    "somatizzassimo": "somatizzare",
    "somatizzaste": "somatizzare",
    "somatizzasti": "somatizzare",
    "somatizzata": "somatizzare",
    "somatizzate": "somatizzare",
    "somatizzati": "somatizzare",
    "somatizzato": "somatizzare",
    "somatizzava": "somatizzare",
    "somatizzavamo": "somatizzare",
    "somatizzavan": "somatizzare",
    "somatizzavano": "somatizzare",
    "somatizzavate": "somatizzare",
    "somatizzavi": "somatizzare",
    "somatizzavo": "somatizzare",
    "somatizzazioni": "somatizzazione",
    "somatizzerai": "somatizzare",
    "somatizzeran": "somatizzare",
    "somatizzeranno": "somatizzare",
    "somatizzerebbe": "somatizzare",
    "somatizzerebber": "somatizzare",
    "somatizzerebbero": "somatizzare",
    "somatizzerei": "somatizzare",
    "somatizzeremmo": "somatizzare",
    "somatizzeremo": "somatizzare",
    "somatizzereste": "somatizzare",
    "somatizzeresti": "somatizzare",
    "somatizzerete": "somatizzare",
    "somatizzerà": "somatizzare",
    "somatizzerò": "somatizzare",
    "somatizzi": "somatizzare",
    "somatizziamo": "somatizzare",
    "somatizziate": "somatizzare",
    "somatizzin": "somatizzare",
    "somatizzino": "somatizzare",
    "somatizzo": "somatizzare",
    "somatizzò": "somatizzare",
    "somatostatine": "somatostatina",
    "somigli": "somigliare",
    "somiglia": "somigliare",
    "somigliai": "somigliare",
    "somigliammo": "somigliare",
    "somigliamo": "somigliare",
    "somiglian": "somigliare",
    "somigliando": "somigliare",
    "somigliano": "somigliare",
    "somigliante": "somigliare",
    "somiglianti": "somigliare",
    "somiglianze": "somiglianza",
    "somigliar": "somigliare",
    "somigliaron": "somigliare",
    "somigliarono": "somigliare",
    "somigliasse": "somigliare",
    "somigliasser": "somigliare",
    "somigliassero": "somigliare",
    "somigliassi": "somigliare",
    "somigliassimo": "somigliare",
    "somigliaste": "somigliare",
    "somigliasti": "somigliare",
    "somigliata": "somigliare",
    "somigliate": "somigliare",
    "somigliati": "somigliare",
    "somigliato": "somigliare",
    "somigliava": "somigliare",
    "somigliavamo": "somigliare",
    "somigliavan": "somigliare",
    "somigliavano": "somigliare",
    "somigliavate": "somigliare",
    "somigliavi": "somigliare",
    "somigliavo": "somigliare",
    "somiglierai": "somigliare",
    "somiglieran": "somigliare",
    "somiglieranno": "somigliare",
    "somiglierebbe": "somigliare",
    "somiglierebber": "somigliare",
    "somiglierebbero": "somigliare",
    "somiglierei": "somigliare",
    "somiglieremmo": "somigliare",
    "somiglieremo": "somigliare",
    "somigliereste": "somigliare",
    "somiglieresti": "somigliare",
    "somiglierete": "somigliare",
    "somiglierà": "somigliare",
    "somiglierò": "somigliare",
    "somiglin": "somigliare",
    "somiglino": "somigliare",
    "somiglio": "somigliare",
    "somigliò": "somigliare",
    "somma": "sommo",
    "sommai": "sommare",
    "sommammo": "sommare",
    "somman": "sommare",
    "sommando": "sommare",
    "sommano": "sommare",
    "sommante": "sommare",
    "sommanti": "sommare",
    "sommar": "sommare",
    "sommari": "sommario",
    "sommaria": "sommario",
    "sommarie": "sommario",
    "sommaron": "sommare",
    "sommarono": "sommare",
    "sommasse": "sommare",
    "sommasser": "sommare",
    "sommassero": "sommare",
    "sommassi": "sommare",
    "sommassimo": "sommare",
    "sommaste": "sommare",
    "sommasti": "sommare",
    "sommata": "sommare",
    "sommate": "sommare",
    "sommati": "sommare",
    "sommato": "sommare",
    "sommatorie": "sommatoria",
    "sommava": "sommare",
    "sommavamo": "sommare",
    "sommavan": "sommare",
    "sommavano": "sommare",
    "sommavate": "sommare",
    "sommavi": "sommare",
    "sommavo": "sommare",
    "somme": "sommo",
    "sommerai": "sommare",
    "sommeran": "sommare",
    "sommeranno": "sommare",
    "sommerebbe": "sommare",
    "sommerebber": "sommare",
    "sommerebbero": "sommare",
    "sommerei": "sommare",
    "sommeremmo": "sommare",
    "sommeremo": "sommare",
    "sommereste": "sommare",
    "sommeresti": "sommare",
    "sommerete": "sommare",
    "sommerga": "sommergere",
    "sommergan": "sommergere",
    "sommergano": "sommergere",
    "sommerge": "sommergere",
    "sommergemmo": "sommergere",
    "sommergendo": "sommergere",
    "sommergente": "sommergere",
    "sommergenti": "sommergere",
    "sommerger": "sommergere",
    "sommergerai": "sommergere",
    "sommergeran": "sommergere",
    "sommergeranno": "sommergere",
    "sommergerebbe": "sommergere",
    "sommergerebber": "sommergere",
    "sommergerebbero": "sommergere",
    "sommergerei": "sommergere",
    "sommergeremmo": "sommergere",
    "sommergeremo": "sommergere",
    "sommergereste": "sommergere",
    "sommergeresti": "sommergere",
    "sommergerete": "sommergere",
    "sommergerà": "sommergere",
    "sommergerò": "sommergere",
    "sommergesse": "sommergere",
    "sommergesser": "sommergere",
    "sommergessero": "sommergere",
    "sommergessi": "sommergere",
    "sommergessimo": "sommergere",
    "sommergeste": "sommergere",
    "sommergesti": "sommergere",
    "sommergete": "sommergere",
    "sommergeva": "sommergere",
    "sommergevamo": "sommergere",
    "sommergevan": "sommergere",
    "sommergevano": "sommergere",
    "sommergevate": "sommergere",
    "sommergevi": "sommergere",
    "sommergevo": "sommergere",
    "sommergi": "sommergere",
    "sommergiamo": "sommergere",
    "sommergiate": "sommergere",
    "sommergibili": "sommergibile",
    "sommergo": "sommergere",
    "sommergon": "sommergere",
    "sommergono": "sommergere",
    "sommersa": "sommerso",
    "sommerse": "sommerso",
    "sommerser": "sommergere",
    "sommersero": "sommergere",
    "sommersi": "sommerso",
    "sommerso": "sommergere",
    "sommerà": "sommare",
    "sommerò": "sommare",
    "sommessa": "sommesso",
    "sommesse": "sommesso",
    "sommessi": "sommesso",
    "sommi": "sommo",
    "sommiamo": "sommare",
    "sommiate": "sommare",
    "sommin": "sommare",
    "somministra": "somministrare",
    "somministrai": "somministrare",
    "somministrammo": "somministrare",
    "somministran": "somministrare",
    "somministrando": "somministrare",
    "somministrano": "somministrare",
    "somministrante": "somministrare",
    "somministranti": "somministrare",
    "somministrar": "somministrare",
    "somministraron": "somministrare",
    "somministrarono": "somministrare",
    "somministrasse": "somministrare",
    "somministrasser": "somministrare",
    "somministrassero": "somministrare",
    "somministrassi": "somministrare",
    "somministrassimo": "somministrare",
    "somministraste": "somministrare",
    "somministrasti": "somministrare",
    "somministrata": "somministrare",
    "somministrate": "somministrare",
    "somministrati": "somministrare",
    "somministrato": "somministrare",
    "somministrava": "somministrare",
    "somministravamo": "somministrare",
    "somministravan": "somministrare",
    "somministravano": "somministrare",
    "somministravate": "somministrare",
    "somministravi": "somministrare",
    "somministravo": "somministrare",
    "somministrazioni": "somministrazione",
    "somministrerai": "somministrare",
    "somministreran": "somministrare",
    "somministreranno": "somministrare",
    "somministrerebbe": "somministrare",
    "somministrerebber": "somministrare",
    "somministrerebbero": "somministrare",
    "somministrerei": "somministrare",
    "somministreremmo": "somministrare",
    "somministreremo": "somministrare",
    "somministrereste": "somministrare",
    "somministreresti": "somministrare",
    "somministrerete": "somministrare",
    "somministrerà": "somministrare",
    "somministrerò": "somministrare",
    "somministri": "somministrare",
    "somministriamo": "somministrare",
    "somministriate": "somministrare",
    "somministrin": "somministrare",
    "somministrino": "somministrare",
    "somministro": "somministrare",
    "somministrò": "somministrare",
    "sommino": "sommare",
    "sommo": "sommare",
    "sommosse": "sommossa",
    "sommovimenti": "sommovimento",
    "sommozzatori": "sommozzatore",
    "sommuova": "sommuovere",
    "sommuovan": "sommuovere",
    "sommuovano": "sommuovere",
    "sommuove": "sommuovere",
    "sommuovei": "sommuovere",
    "sommuovemmo": "sommuovere",
    "sommuovendo": "sommuovere",
    "sommuovente": "sommuovere",
    "sommuoventi": "sommuovere",
    "sommuover": "sommuovere",
    "sommuoverai": "sommuovere",
    "sommuoveran": "sommuovere",
    "sommuoveranno": "sommuovere",
    "sommuoverebbe": "sommuovere",
    "sommuoverebber": "sommuovere",
    "sommuoverebbero": "sommuovere",
    "sommuoverei": "sommuovere",
    "sommuoveremmo": "sommuovere",
    "sommuoveremo": "sommuovere",
    "sommuovereste": "sommuovere",
    "sommuoveresti": "sommuovere",
    "sommuoverete": "sommuovere",
    "sommuoveron": "sommuovere",
    "sommuoverono": "sommuovere",
    "sommuoverà": "sommuovere",
    "sommuoverò": "sommuovere",
    "sommuovesse": "sommuovere",
    "sommuovesser": "sommuovere",
    "sommuovessero": "sommuovere",
    "sommuovessi": "sommuovere",
    "sommuovessimo": "sommuovere",
    "sommuoveste": "sommuovere",
    "sommuovesti": "sommuovere",
    "sommuovete": "sommuovere",
    "sommuoveva": "sommuovere",
    "sommuovevamo": "sommuovere",
    "sommuovevan": "sommuovere",
    "sommuovevano": "sommuovere",
    "sommuovevate": "sommuovere",
    "sommuovevi": "sommuovere",
    "sommuovevo": "sommuovere",
    "sommuovi": "sommuovere",
    "sommuoviamo": "sommuovere",
    "sommuoviate": "sommuovere",
    "sommuovo": "sommuovere",
    "sommuovon": "sommuovere",
    "sommuovono": "sommuovere",
    "sommuovuta": "sommuovere",
    "sommuovute": "sommuovere",
    "sommuovuti": "sommuovere",
    "sommuovuto": "sommuovere",
    "sommuovè": "sommuovere",
    "sommò": "sommare",
    "son": "essere",
    "sona": "sonare",
    "sonagli": "sonaglio",
    "sonai": "sonare",
    "sonammo": "sonare",
    "sonan": "sonare",
    "sonando": "sonare",
    "sonano": "sonare",
    "sonante": "sonare",
    "sonanti": "sonare",
    "sonar": "sonare",
    "sonaron": "sonare",
    "sonarono": "sonare",
    "sonasse": "sonare",
    "sonasser": "sonare",
    "sonassero": "sonare",
    "sonassi": "sonare",
    "sonassimo": "sonare",
    "sonaste": "sonare",
    "sonasti": "sonare",
    "sonata": "sonato",
    "sonate": "sonato",
    "sonati": "sonato",
    "sonato": "sonare",
    "sonava": "sonare",
    "sonavamo": "sonare",
    "sonavan": "sonare",
    "sonavano": "sonare",
    "sonavate": "sonare",
    "sonavi": "sonare",
    "sonavo": "sonare",
    "sonda": "sondare",
    "sondabili": "sondabile",
    "sondaggi": "sondaggio",
    "sondaggisti": "sondaggista",
    "sondaggistica": "sondaggistico",
    "sondaggistiche": "sondaggistico",
    "sondaggistici": "sondaggistico",
    "sondai": "sondare",
    "sondammo": "sondare",
    "sondan": "sondare",
    "sondando": "sondare",
    "sondano": "sondare",
    "sondante": "sondare",
    "sondanti": "sondare",
    "sondar": "sondare",
    "sondaron": "sondare",
    "sondarono": "sondare",
    "sondasse": "sondare",
    "sondasser": "sondare",
    "sondassero": "sondare",
    "sondassi": "sondare",
    "sondassimo": "sondare",
    "sondaste": "sondare",
    "sondasti": "sondare",
    "sondata": "sondare",
    "sondate": "sondare",
    "sondati": "sondare",
    "sondato": "sondare",
    "sondava": "sondare",
    "sondavamo": "sondare",
    "sondavan": "sondare",
    "sondavano": "sondare",
    "sondavate": "sondare",
    "sondavi": "sondare",
    "sondavo": "sondare",
    "sonde": "sonda",
    "sonderai": "sondare",
    "sonderan": "sondare",
    "sonderanno": "sondare",
    "sonderebbe": "sondare",
    "sonderebber": "sondare",
    "sonderebbero": "sondare",
    "sonderei": "sondare",
    "sonderemmo": "sondare",
    "sonderemo": "sondare",
    "sondereste": "sondare",
    "sonderesti": "sondare",
    "sonderete": "sondare",
    "sonderà": "sondare",
    "sonderò": "sondare",
    "sondi": "sondare",
    "sondiamo": "sondare",
    "sondiate": "sondare",
    "sondin": "sondare",
    "sondino": "sondare",
    "sondo": "sondare",
    "sondò": "sondare",
    "sonerai": "sonare",
    "soneran": "sonare",
    "soneranno": "sonare",
    "sonerebbe": "sonare",
    "sonerebber": "sonare",
    "sonerebbero": "sonare",
    "sonerei": "sonare",
    "soneremmo": "sonare",
    "soneremo": "sonare",
    "sonereste": "sonare",
    "soneresti": "sonare",
    "sonerete": "sonare",
    "sonerà": "sonare",
    "sonerò": "sonare",
    "sonetti": "sonetto",
    "soni": "sonare",
    "soniamo": "sonare",
    "soniate": "sonare",
    "sonica": "sonico",
    "soniche": "sonico",
    "sonici": "sonico",
    "sonin": "sonare",
    "sonino": "sonare",
    "sonnacchiosa": "sonnacchioso",
    "sonnacchiose": "sonnacchioso",
    "sonnacchiosi": "sonnacchioso",
    "sonnambula": "sonnambulo",
    "sonnambule": "sonnambulo",
    "sonnambuli": "sonnambulo",
    "sonnecchi": "sonnecchiare",
    "sonnecchia": "sonnecchiare",
    "sonnecchiai": "sonnecchiare",
    "sonnecchiammo": "sonnecchiare",
    "sonnecchiamo": "sonnecchiare",
    "sonnecchian": "sonnecchiare",
    "sonnecchiando": "sonnecchiare",
    "sonnecchiano": "sonnecchiare",
    "sonnecchiante": "sonnecchiare",
    "sonnecchianti": "sonnecchiare",
    "sonnecchiar": "sonnecchiare",
    "sonnecchiaron": "sonnecchiare",
    "sonnecchiarono": "sonnecchiare",
    "sonnecchiasse": "sonnecchiare",
    "sonnecchiasser": "sonnecchiare",
    "sonnecchiassero": "sonnecchiare",
    "sonnecchiassi": "sonnecchiare",
    "sonnecchiassimo": "sonnecchiare",
    "sonnecchiaste": "sonnecchiare",
    "sonnecchiasti": "sonnecchiare",
    "sonnecchiata": "sonnecchiare",
    "sonnecchiate": "sonnecchiare",
    "sonnecchiati": "sonnecchiare",
    "sonnecchiato": "sonnecchiare",
    "sonnecchiava": "sonnecchiare",
    "sonnecchiavamo": "sonnecchiare",
    "sonnecchiavan": "sonnecchiare",
    "sonnecchiavano": "sonnecchiare",
    "sonnecchiavate": "sonnecchiare",
    "sonnecchiavi": "sonnecchiare",
    "sonnecchiavo": "sonnecchiare",
    "sonnecchierai": "sonnecchiare",
    "sonnecchieran": "sonnecchiare",
    "sonnecchieranno": "sonnecchiare",
    "sonnecchierebbe": "sonnecchiare",
    "sonnecchierebber": "sonnecchiare",
    "sonnecchierebbero": "sonnecchiare",
    "sonnecchierei": "sonnecchiare",
    "sonnecchieremmo": "sonnecchiare",
    "sonnecchieremo": "sonnecchiare",
    "sonnecchiereste": "sonnecchiare",
    "sonnecchieresti": "sonnecchiare",
    "sonnecchierete": "sonnecchiare",
    "sonnecchierà": "sonnecchiare",
    "sonnecchierò": "sonnecchiare",
    "sonnecchin": "sonnecchiare",
    "sonnecchino": "sonnecchiare",
    "sonnecchio": "sonnecchiare",
    "sonnecchiò": "sonnecchiare",
    "sonnellini": "sonnellino",
    "sonni": "sonno",
    "sonnifera": "sonnifero",
    "sonnifere": "sonnifero",
    "sonniferi": "sonnifero",
    "sonnolenta": "sonnolento",
    "sonnolente": "sonnolento",
    "sonnolenti": "sonnolento",
    "sonnolenze": "sonnolenza",
    "sonora": "sonoro",
    "sonore": "sonoro",
    "sonori": "sonoro",
    "sonorizza": "sonorizzare",
    "sonorizzai": "sonorizzare",
    "sonorizzammo": "sonorizzare",
    "sonorizzan": "sonorizzare",
    "sonorizzando": "sonorizzare",
    "sonorizzano": "sonorizzare",
    "sonorizzante": "sonorizzare",
    "sonorizzanti": "sonorizzare",
    "sonorizzar": "sonorizzare",
    "sonorizzaron": "sonorizzare",
    "sonorizzarono": "sonorizzare",
    "sonorizzasse": "sonorizzare",
    "sonorizzasser": "sonorizzare",
    "sonorizzassero": "sonorizzare",
    "sonorizzassi": "sonorizzare",
    "sonorizzassimo": "sonorizzare",
    "sonorizzaste": "sonorizzare",
    "sonorizzasti": "sonorizzare",
    "sonorizzata": "sonorizzare",
    "sonorizzate": "sonorizzare",
    "sonorizzati": "sonorizzare",
    "sonorizzato": "sonorizzare",
    "sonorizzava": "sonorizzare",
    "sonorizzavamo": "sonorizzare",
    "sonorizzavan": "sonorizzare",
    "sonorizzavano": "sonorizzare",
    "sonorizzavate": "sonorizzare",
    "sonorizzavi": "sonorizzare",
    "sonorizzavo": "sonorizzare",
    "sonorizzerai": "sonorizzare",
    "sonorizzeran": "sonorizzare",
    "sonorizzeranno": "sonorizzare",
    "sonorizzerebbe": "sonorizzare",
    "sonorizzerebber": "sonorizzare",
    "sonorizzerebbero": "sonorizzare",
    "sonorizzerei": "sonorizzare",
    "sonorizzeremmo": "sonorizzare",
    "sonorizzeremo": "sonorizzare",
    "sonorizzereste": "sonorizzare",
    "sonorizzeresti": "sonorizzare",
    "sonorizzerete": "sonorizzare",
    "sonorizzerà": "sonorizzare",
    "sonorizzerò": "sonorizzare",
    "sonorizzi": "sonorizzare",
    "sonorizziamo": "sonorizzare",
    "sonorizziate": "sonorizzare",
    "sonorizzin": "sonorizzare",
    "sonorizzino": "sonorizzare",
    "sonorizzo": "sonorizzare",
    "sonorizzò": "sonorizzare",
    "sontuosa": "sontuoso",
    "sontuose": "sontuoso",
    "sontuosi": "sontuoso",
    "sonò": "sonare",
    "sopa": "sopire",
    "sopan": "sopire",
    "sopano": "sopire",
    "sope": "sopire",
    "sopendo": "sopire",
    "sopente": "sopire",
    "sopenti": "sopire",
    "soperchierie": "soperchieria",
    "sopi": "sopire",
    "sopiamo": "sopire",
    "sopiate": "sopire",
    "sopii": "sopire",
    "sopimmo": "sopire",
    "sopir": "sopire",
    "sopirai": "sopire",
    "sopiran": "sopire",
    "sopiranno": "sopire",
    "sopirebbe": "sopire",
    "sopirebber": "sopire",
    "sopirebbero": "sopire",
    "sopirei": "sopire",
    "sopiremmo": "sopire",
    "sopiremo": "sopire",
    "sopireste": "sopire",
    "sopiresti": "sopire",
    "sopirete": "sopire",
    "sopiron": "sopire",
    "sopirono": "sopire",
    "sopirà": "sopire",
    "sopirò": "sopire",
    "sopisse": "sopire",
    "sopisser": "sopire",
    "sopissero": "sopire",
    "sopissi": "sopire",
    "sopissimo": "sopire",
    "sopiste": "sopire",
    "sopisti": "sopire",
    "sopita": "sopire",
    "sopite": "sopire",
    "sopiti": "sopire",
    "sopito": "sopire",
    "sopiva": "sopire",
    "sopivamo": "sopire",
    "sopivan": "sopire",
    "sopivano": "sopire",
    "sopivate": "sopire",
    "sopivi": "sopire",
    "sopivo": "sopire",
    "sopo": "sopire",
    "sopon": "sopire",
    "sopono": "sopire",
    "soporifera": "soporifero",
    "soporifere": "soporifero",
    "soporiferi": "soporifero",
    "soppalchi": "soppalco",
    "sopperendo": "sopperire",
    "sopperente": "sopperire",
    "sopperenti": "sopperire",
    "sopperiamo": "sopperire",
    "sopperiate": "sopperire",
    "sopperii": "sopperire",
    "sopperimmo": "sopperire",
    "sopperir": "sopperire",
    "sopperirai": "sopperire",
    "sopperiran": "sopperire",
    "sopperiranno": "sopperire",
    "sopperirebbe": "sopperire",
    "sopperirebber": "sopperire",
    "sopperirebbero": "sopperire",
    "sopperirei": "sopperire",
    "sopperiremmo": "sopperire",
    "sopperiremo": "sopperire",
    "sopperireste": "sopperire",
    "sopperiresti": "sopperire",
    "sopperirete": "sopperire",
    "sopperiron": "sopperire",
    "sopperirono": "sopperire",
    "sopperirà": "sopperire",
    "sopperirò": "sopperire",
    "sopperisca": "sopperire",
    "sopperiscan": "sopperire",
    "sopperiscano": "sopperire",
    "sopperisce": "sopperire",
    "sopperisci": "sopperire",
    "sopperisco": "sopperire",
    "sopperiscon": "sopperire",
    "sopperiscono": "sopperire",
    "sopperisse": "sopperire",
    "sopperisser": "sopperire",
    "sopperissero": "sopperire",
    "sopperissi": "sopperire",
    "sopperissimo": "sopperire",
    "sopperiste": "sopperire",
    "sopperisti": "sopperire",
    "sopperita": "sopperire",
    "sopperite": "sopperire",
    "sopperiti": "sopperire",
    "sopperito": "sopperire",
    "sopperiva": "sopperire",
    "sopperivamo": "sopperire",
    "sopperivan": "sopperire",
    "sopperivano": "sopperire",
    "sopperivate": "sopperire",
    "sopperivi": "sopperire",
    "sopperivo": "sopperire",
    "sopperì": "sopperire",
    "soppesa": "soppesare",
    "soppesai": "soppesare",
    "soppesammo": "soppesare",
    "soppesan": "soppesare",
    "soppesando": "soppesare",
    "soppesano": "soppesare",
    "soppesante": "soppesare",
    "soppesanti": "soppesare",
    "soppesar": "soppesare",
    "soppesaron": "soppesare",
    "soppesarono": "soppesare",
    "soppesasse": "soppesare",
    "soppesasser": "soppesare",
    "soppesassero": "soppesare",
    "soppesassi": "soppesare",
    "soppesassimo": "soppesare",
    "soppesaste": "soppesare",
    "soppesasti": "soppesare",
    "soppesata": "soppesare",
    "soppesate": "soppesare",
    "soppesati": "soppesare",
    "soppesato": "soppesare",
    "soppesava": "soppesare",
    "soppesavamo": "soppesare",
    "soppesavan": "soppesare",
    "soppesavano": "soppesare",
    "soppesavate": "soppesare",
    "soppesavi": "soppesare",
    "soppesavo": "soppesare",
    "soppeserai": "soppesare",
    "soppeseran": "soppesare",
    "soppeseranno": "soppesare",
    "soppeserebbe": "soppesare",
    "soppeserebber": "soppesare",
    "soppeserebbero": "soppesare",
    "soppeserei": "soppesare",
    "soppeseremmo": "soppesare",
    "soppeseremo": "soppesare",
    "soppesereste": "soppesare",
    "soppeseresti": "soppesare",
    "soppeserete": "soppesare",
    "soppeserà": "soppesare",
    "soppeserò": "soppesare",
    "soppesi": "soppesare",
    "soppesiamo": "soppesare",
    "soppesiate": "soppesare",
    "soppesin": "soppesare",
    "soppesino": "soppesare",
    "soppeso": "soppesare",
    "soppesò": "soppesare",
    "soppianta": "soppiantare",
    "soppiantai": "soppiantare",
    "soppiantammo": "soppiantare",
    "soppiantan": "soppiantare",
    "soppiantando": "soppiantare",
    "soppiantano": "soppiantare",
    "soppiantante": "soppiantare",
    "soppiantanti": "soppiantare",
    "soppiantar": "soppiantare",
    "soppiantaron": "soppiantare",
    "soppiantarono": "soppiantare",
    "soppiantasse": "soppiantare",
    "soppiantasser": "soppiantare",
    "soppiantassero": "soppiantare",
    "soppiantassi": "soppiantare",
    "soppiantassimo": "soppiantare",
    "soppiantaste": "soppiantare",
    "soppiantasti": "soppiantare",
    "soppiantata": "soppiantare",
    "soppiantate": "soppiantare",
    "soppiantati": "soppiantare",
    "soppiantato": "soppiantare",
    "soppiantava": "soppiantare",
    "soppiantavamo": "soppiantare",
    "soppiantavan": "soppiantare",
    "soppiantavano": "soppiantare",
    "soppiantavate": "soppiantare",
    "soppiantavi": "soppiantare",
    "soppiantavo": "soppiantare",
    "soppianterai": "soppiantare",
    "soppianteran": "soppiantare",
    "soppianteranno": "soppiantare",
    "soppianterebbe": "soppiantare",
    "soppianterebber": "soppiantare",
    "soppianterebbero": "soppiantare",
    "soppianterei": "soppiantare",
    "soppianteremmo": "soppiantare",
    "soppianteremo": "soppiantare",
    "soppiantereste": "soppiantare",
    "soppianteresti": "soppiantare",
    "soppianterete": "soppiantare",
    "soppianterà": "soppiantare",
    "soppianterò": "soppiantare",
    "soppianti": "soppiantare",
    "soppiantiamo": "soppiantare",
    "soppiantiate": "soppiantare",
    "soppiantin": "soppiantare",
    "soppiantino": "soppiantare",
    "soppianto": "soppiantare",
    "soppiantò": "soppiantare",
    "sopporta": "sopportare",
    "sopportabili": "sopportabile",
    "sopportai": "sopportare",
    "sopportammo": "sopportare",
    "sopportan": "sopportare",
    "sopportando": "sopportare",
    "sopportano": "sopportare",
    "sopportante": "sopportare",
    "sopportanti": "sopportare",
    "sopportar": "sopportare",
    "sopportaron": "sopportare",
    "sopportarono": "sopportare",
    "sopportasse": "sopportare",
    "sopportasser": "sopportare",
    "sopportassero": "sopportare",
    "sopportassi": "sopportare",
    "sopportassimo": "sopportare",
    "sopportaste": "sopportare",
    "sopportasti": "sopportare",
    "sopportata": "sopportare",
    "sopportate": "sopportare",
    "sopportati": "sopportare",
    "sopportato": "sopportare",
    "sopportava": "sopportare",
    "sopportavamo": "sopportare",
    "sopportavan": "sopportare",
    "sopportavano": "sopportare",
    "sopportavate": "sopportare",
    "sopportavi": "sopportare",
    "sopportavo": "sopportare",
    "sopportazioni": "sopportazione",
    "sopporterai": "sopportare",
    "sopporteran": "sopportare",
    "sopporteranno": "sopportare",
    "sopporterebbe": "sopportare",
    "sopporterebber": "sopportare",
    "sopporterebbero": "sopportare",
    "sopporterei": "sopportare",
    "sopporteremmo": "sopportare",
    "sopporteremo": "sopportare",
    "sopportereste": "sopportare",
    "sopporteresti": "sopportare",
    "sopporterete": "sopportare",
    "sopporterà": "sopportare",
    "sopporterò": "sopportare",
    "sopporti": "sopportare",
    "sopportiamo": "sopportare",
    "sopportiate": "sopportare",
    "sopportin": "sopportare",
    "sopportino": "sopportare",
    "sopporto": "sopportare",
    "sopportò": "sopportare",
    "soppressa": "sopprimere",
    "soppresse": "sopprimere",
    "soppresser": "sopprimere",
    "soppressero": "sopprimere",
    "soppressi": "sopprimere",
    "soppressioni": "soppressione",
    "soppresso": "sopprimere",
    "sopprima": "sopprimere",
    "soppriman": "sopprimere",
    "sopprimano": "sopprimere",
    "sopprime": "sopprimere",
    "sopprimemmo": "sopprimere",
    "sopprimendo": "sopprimere",
    "sopprimente": "sopprimere",
    "sopprimenti": "sopprimere",
    "sopprimer": "sopprimere",
    "sopprimerai": "sopprimere",
    "sopprimeran": "sopprimere",
    "sopprimeranno": "sopprimere",
    "sopprimerebbe": "sopprimere",
    "sopprimerebber": "sopprimere",
    "sopprimerebbero": "sopprimere",
    "sopprimerei": "sopprimere",
    "sopprimeremmo": "sopprimere",
    "sopprimeremo": "sopprimere",
    "sopprimereste": "sopprimere",
    "sopprimeresti": "sopprimere",
    "sopprimerete": "sopprimere",
    "sopprimerà": "sopprimere",
    "sopprimerò": "sopprimere",
    "sopprimesse": "sopprimere",
    "sopprimesser": "sopprimere",
    "sopprimessero": "sopprimere",
    "sopprimessi": "sopprimere",
    "sopprimessimo": "sopprimere",
    "sopprimeste": "sopprimere",
    "sopprimesti": "sopprimere",
    "sopprimete": "sopprimere",
    "sopprimeva": "sopprimere",
    "sopprimevamo": "sopprimere",
    "sopprimevan": "sopprimere",
    "sopprimevano": "sopprimere",
    "sopprimevate": "sopprimere",
    "sopprimevi": "sopprimere",
    "sopprimevo": "sopprimere",
    "sopprimi": "sopprimere",
    "sopprimiamo": "sopprimere",
    "sopprimiate": "sopprimere",
    "sopprimo": "sopprimere",
    "sopprimon": "sopprimere",
    "sopprimono": "sopprimere",
    "soprabiti": "soprabito",
    "sopraccigli": "sopracciglio",
    "sopracciglia": "sopracciglio",
    "sopraccigliai": "sopraccigliare",
    "sopraccigliammo": "sopraccigliare",
    "sopraccigliamo": "sopraccigliare",
    "sopracciglian": "sopraccigliare",
    "sopraccigliando": "sopraccigliare",
    "sopraccigliano": "sopraccigliare",
    "sopraccigliante": "sopraccigliare",
    "sopracciglianti": "sopraccigliare",
    "sopraccigliar": "sopraccigliare",
    "sopraccigliaron": "sopraccigliare",
    "sopraccigliarono": "sopraccigliare",
    "sopraccigliasse": "sopraccigliare",
    "sopraccigliasser": "sopraccigliare",
    "sopraccigliassero": "sopraccigliare",
    "sopraccigliassi": "sopraccigliare",
    "sopraccigliassimo": "sopraccigliare",
    "sopraccigliaste": "sopraccigliare",
    "sopraccigliasti": "sopraccigliare",
    "sopraccigliata": "sopraccigliare",
    "sopraccigliate": "sopraccigliare",
    "sopraccigliati": "sopraccigliare",
    "sopraccigliato": "sopraccigliare",
    "sopraccigliava": "sopraccigliare",
    "sopraccigliavamo": "sopraccigliare",
    "sopraccigliavan": "sopraccigliare",
    "sopraccigliavano": "sopraccigliare",
    "sopraccigliavate": "sopraccigliare",
    "sopraccigliavi": "sopraccigliare",
    "sopraccigliavo": "sopraccigliare",
    "sopracciglierai": "sopraccigliare",
    "sopracciglieran": "sopraccigliare",
    "sopracciglieranno": "sopraccigliare",
    "sopracciglierebbe": "sopraccigliare",
    "sopracciglierebber": "sopraccigliare",
    "sopracciglierebbero": "sopraccigliare",
    "sopracciglierei": "sopraccigliare",
    "sopracciglieremmo": "sopraccigliare",
    "sopracciglieremo": "sopraccigliare",
    "sopraccigliereste": "sopraccigliare",
    "sopracciglieresti": "sopraccigliare",
    "sopracciglierete": "sopraccigliare",
    "sopracciglierà": "sopraccigliare",
    "sopracciglierò": "sopraccigliare",
    "sopracciglin": "sopraccigliare",
    "sopracciglino": "sopraccigliare",
    "sopracciglio": "sopraccigliare",
    "sopraccigliò": "sopraccigliare",
    "sopracita": "sopracitare",
    "sopracitai": "sopracitare",
    "sopracitammo": "sopracitare",
    "sopracitan": "sopracitare",
    "sopracitando": "sopracitare",
    "sopracitano": "sopracitare",
    "sopracitante": "sopracitare",
    "sopracitanti": "sopracitare",
    "sopracitar": "sopracitare",
    "sopracitaron": "sopracitare",
    "sopracitarono": "sopracitare",
    "sopracitasse": "sopracitare",
    "sopracitasser": "sopracitare",
    "sopracitassero": "sopracitare",
    "sopracitassi": "sopracitare",
    "sopracitassimo": "sopracitare",
    "sopracitaste": "sopracitare",
    "sopracitasti": "sopracitare",
    "sopracitata": "sopracitare",
    "sopracitate": "sopracitare",
    "sopracitati": "sopracitare",
    "sopracitato": "sopracitare",
    "sopracitava": "sopracitare",
    "sopracitavamo": "sopracitare",
    "sopracitavan": "sopracitare",
    "sopracitavano": "sopracitare",
    "sopracitavate": "sopracitare",
    "sopracitavi": "sopracitare",
    "sopracitavo": "sopracitare",
    "sopraciterai": "sopracitare",
    "sopraciteran": "sopracitare",
    "sopraciteranno": "sopracitare",
    "sopraciterebbe": "sopracitare",
    "sopraciterebber": "sopracitare",
    "sopraciterebbero": "sopracitare",
    "sopraciterei": "sopracitare",
    "sopraciteremmo": "sopracitare",
    "sopraciteremo": "sopracitare",
    "sopracitereste": "sopracitare",
    "sopraciteresti": "sopracitare",
    "sopraciterete": "sopracitare",
    "sopraciterà": "sopracitare",
    "sopraciterò": "sopracitare",
    "sopraciti": "sopracitare",
    "sopracitiamo": "sopracitare",
    "sopracitiate": "sopracitare",
    "sopracitin": "sopracitare",
    "sopracitino": "sopracitare",
    "sopracito": "sopracitare",
    "sopracitò": "sopracitare",
    "sopraddetta": "sopraddetto",
    "sopraddette": "sopraddetto",
    "sopraddetti": "sopraddetto",
    "sopradescriva": "sopradescrivere",
    "sopradescrivan": "sopradescrivere",
    "sopradescrivano": "sopradescrivere",
    "sopradescrive": "sopradescrivere",
    "sopradescrivei": "sopradescrivere",
    "sopradescrivemmo": "sopradescrivere",
    "sopradescrivendo": "sopradescrivere",
    "sopradescrivente": "sopradescrivere",
    "sopradescriventi": "sopradescrivere",
    "sopradescriver": "sopradescrivere",
    "sopradescriverai": "sopradescrivere",
    "sopradescriveran": "sopradescrivere",
    "sopradescriveranno": "sopradescrivere",
    "sopradescriverebbe": "sopradescrivere",
    "sopradescriverebber": "sopradescrivere",
    "sopradescriverebbero": "sopradescrivere",
    "sopradescriverei": "sopradescrivere",
    "sopradescriveremmo": "sopradescrivere",
    "sopradescriveremo": "sopradescrivere",
    "sopradescrivereste": "sopradescrivere",
    "sopradescriveresti": "sopradescrivere",
    "sopradescriverete": "sopradescrivere",
    "sopradescriveron": "sopradescrivere",
    "sopradescriverono": "sopradescrivere",
    "sopradescriverà": "sopradescrivere",
    "sopradescriverò": "sopradescrivere",
    "sopradescrivesse": "sopradescrivere",
    "sopradescrivesser": "sopradescrivere",
    "sopradescrivessero": "sopradescrivere",
    "sopradescrivessi": "sopradescrivere",
    "sopradescrivessimo": "sopradescrivere",
    "sopradescriveste": "sopradescrivere",
    "sopradescrivesti": "sopradescrivere",
    "sopradescrivete": "sopradescrivere",
    "sopradescriveva": "sopradescrivere",
    "sopradescrivevamo": "sopradescrivere",
    "sopradescrivevan": "sopradescrivere",
    "sopradescrivevano": "sopradescrivere",
    "sopradescrivevate": "sopradescrivere",
    "sopradescrivevi": "sopradescrivere",
    "sopradescrivevo": "sopradescrivere",
    "sopradescrivi": "sopradescrivere",
    "sopradescriviamo": "sopradescrivere",
    "sopradescriviate": "sopradescrivere",
    "sopradescrivo": "sopradescrivere",
    "sopradescrivon": "sopradescrivere",
    "sopradescrivono": "sopradescrivere",
    "sopradescrivuta": "sopradescrivere",
    "sopradescrivute": "sopradescrivere",
    "sopradescrivuti": "sopradescrivere",
    "sopradescrivuto": "sopradescrivere",
    "sopradescrivè": "sopradescrivere",
    "sopraelenca": "sopraelencare",
    "sopraelencai": "sopraelencare",
    "sopraelencammo": "sopraelencare",
    "sopraelencan": "sopraelencare",
    "sopraelencando": "sopraelencare",
    "sopraelencano": "sopraelencare",
    "sopraelencante": "sopraelencare",
    "sopraelencanti": "sopraelencare",
    "sopraelencar": "sopraelencare",
    "sopraelencaron": "sopraelencare",
    "sopraelencarono": "sopraelencare",
    "sopraelencasse": "sopraelencare",
    "sopraelencasser": "sopraelencare",
    "sopraelencassero": "sopraelencare",
    "sopraelencassi": "sopraelencare",
    "sopraelencassimo": "sopraelencare",
    "sopraelencaste": "sopraelencare",
    "sopraelencasti": "sopraelencare",
    "sopraelencata": "sopraelencare",
    "sopraelencate": "sopraelencare",
    "sopraelencati": "sopraelencare",
    "sopraelencato": "sopraelencare",
    "sopraelencava": "sopraelencare",
    "sopraelencavamo": "sopraelencare",
    "sopraelencavan": "sopraelencare",
    "sopraelencavano": "sopraelencare",
    "sopraelencavate": "sopraelencare",
    "sopraelencavi": "sopraelencare",
    "sopraelencavo": "sopraelencare",
    "sopraelencherai": "sopraelencare",
    "sopraelencheran": "sopraelencare",
    "sopraelencheranno": "sopraelencare",
    "sopraelencherebbe": "sopraelencare",
    "sopraelencherebber": "sopraelencare",
    "sopraelencherebbero": "sopraelencare",
    "sopraelencherei": "sopraelencare",
    "sopraelencheremmo": "sopraelencare",
    "sopraelencheremo": "sopraelencare",
    "sopraelenchereste": "sopraelencare",
    "sopraelencheresti": "sopraelencare",
    "sopraelencherete": "sopraelencare",
    "sopraelencherà": "sopraelencare",
    "sopraelencherò": "sopraelencare",
    "sopraelenchi": "sopraelencare",
    "sopraelenchiamo": "sopraelencare",
    "sopraelenchiate": "sopraelencare",
    "sopraelenchin": "sopraelencare",
    "sopraelenchino": "sopraelencare",
    "sopraelenco": "sopraelencare",
    "sopraelencò": "sopraelencare",
    "sopraeleva": "sopraelevare",
    "sopraelevai": "sopraelevare",
    "sopraelevammo": "sopraelevare",
    "sopraelevan": "sopraelevare",
    "sopraelevando": "sopraelevare",
    "sopraelevano": "sopraelevare",
    "sopraelevante": "sopraelevare",
    "sopraelevanti": "sopraelevare",
    "sopraelevar": "sopraelevare",
    "sopraelevaron": "sopraelevare",
    "sopraelevarono": "sopraelevare",
    "sopraelevasse": "sopraelevare",
    "sopraelevasser": "sopraelevare",
    "sopraelevassero": "sopraelevare",
    "sopraelevassi": "sopraelevare",
    "sopraelevassimo": "sopraelevare",
    "sopraelevaste": "sopraelevare",
    "sopraelevasti": "sopraelevare",
    "sopraelevata": "sopraelevare",
    "sopraelevate": "sopraelevare",
    "sopraelevati": "sopraelevare",
    "sopraelevato": "sopraelevare",
    "sopraelevava": "sopraelevare",
    "sopraelevavamo": "sopraelevare",
    "sopraelevavan": "sopraelevare",
    "sopraelevavano": "sopraelevare",
    "sopraelevavate": "sopraelevare",
    "sopraelevavi": "sopraelevare",
    "sopraelevavo": "sopraelevare",
    "sopraeleverai": "sopraelevare",
    "sopraeleveran": "sopraelevare",
    "sopraeleveranno": "sopraelevare",
    "sopraeleverebbe": "sopraelevare",
    "sopraeleverebber": "sopraelevare",
    "sopraeleverebbero": "sopraelevare",
    "sopraeleverei": "sopraelevare",
    "sopraeleveremmo": "sopraelevare",
    "sopraeleveremo": "sopraelevare",
    "sopraelevereste": "sopraelevare",
    "sopraeleveresti": "sopraelevare",
    "sopraeleverete": "sopraelevare",
    "sopraeleverà": "sopraelevare",
    "sopraeleverò": "sopraelevare",
    "sopraelevi": "sopraelevare",
    "sopraeleviamo": "sopraelevare",
    "sopraeleviate": "sopraelevare",
    "sopraelevin": "sopraelevare",
    "sopraelevino": "sopraelevare",
    "sopraelevo": "sopraelevare",
    "sopraelevò": "sopraelevare",
    "sopraffa": "sopraffare",
    "sopraffa'": "sopraffare",
    "sopraffaccia": "sopraffare",
    "sopraffacciamo": "sopraffare",
    "sopraffaccian": "sopraffare",
    "sopraffacciano": "sopraffare",
    "sopraffacciate": "sopraffare",
    "sopraffaccio": "sopraffare",
    "sopraffacemmo": "sopraffare",
    "sopraffacendo": "sopraffare",
    "sopraffacente": "sopraffare",
    "sopraffacenti": "sopraffare",
    "sopraffacesse": "sopraffare",
    "sopraffacesser": "sopraffare",
    "sopraffacessero": "sopraffare",
    "sopraffacessi": "sopraffare",
    "sopraffacessimo": "sopraffare",
    "sopraffaceste": "sopraffare",
    "sopraffacesti": "sopraffare",
    "sopraffaceva": "sopraffare",
    "sopraffacevamo": "sopraffare",
    "sopraffacevan": "sopraffare",
    "sopraffacevano": "sopraffare",
    "sopraffacevate": "sopraffare",
    "sopraffacevi": "sopraffare",
    "sopraffacevo": "sopraffare",
    "sopraffai": "sopraffare",
    "sopraffan": "sopraffare",
    "sopraffanno": "sopraffare",
    "sopraffar": "sopraffare",
    "sopraffarai": "sopraffare",
    "sopraffaran": "sopraffare",
    "sopraffaranno": "sopraffare",
    "sopraffarebbe": "sopraffare",
    "sopraffarebber": "sopraffare",
    "sopraffarebbero": "sopraffare",
    "sopraffarei": "sopraffare",
    "sopraffaremmo": "sopraffare",
    "sopraffaremo": "sopraffare",
    "sopraffareste": "sopraffare",
    "sopraffaresti": "sopraffare",
    "sopraffarete": "sopraffare",
    "sopraffarà": "sopraffare",
    "sopraffarò": "sopraffare",
    "sopraffate": "sopraffare",
    "sopraffatta": "sopraffare",
    "sopraffatte": "sopraffare",
    "sopraffatti": "sopraffare",
    "sopraffatto": "sopraffare",
    "sopraffattori": "sopraffattore",
    "sopraffattrice": "sopraffattore",
    "sopraffattrici": "sopraffattore",
    "sopraffazioni": "sopraffazione",
    "sopraffece": "sopraffare",
    "sopraffecer": "sopraffare",
    "sopraffecero": "sopraffare",
    "sopraffeci": "sopraffare",
    "sopraffina": "sopraffino",
    "sopraffine": "sopraffino",
    "sopraffini": "sopraffino",
    "sopraggiunga": "sopraggiungere",
    "sopraggiungan": "sopraggiungere",
    "sopraggiungano": "sopraggiungere",
    "sopraggiunge": "sopraggiungere",
    "sopraggiungemmo": "sopraggiungere",
    "sopraggiungendo": "sopraggiungere",
    "sopraggiungente": "sopraggiungere",
    "sopraggiungenti": "sopraggiungere",
    "sopraggiunger": "sopraggiungere",
    "sopraggiungerai": "sopraggiungere",
    "sopraggiungeran": "sopraggiungere",
    "sopraggiungeranno": "sopraggiungere",
    "sopraggiungerebbe": "sopraggiungere",
    "sopraggiungerebber": "sopraggiungere",
    "sopraggiungerebbero": "sopraggiungere",
    "sopraggiungerei": "sopraggiungere",
    "sopraggiungeremmo": "sopraggiungere",
    "sopraggiungeremo": "sopraggiungere",
    "sopraggiungereste": "sopraggiungere",
    "sopraggiungeresti": "sopraggiungere",
    "sopraggiungerete": "sopraggiungere",
    "sopraggiungerà": "sopraggiungere",
    "sopraggiungerò": "sopraggiungere",
    "sopraggiungesse": "sopraggiungere",
    "sopraggiungesser": "sopraggiungere",
    "sopraggiungessero": "sopraggiungere",
    "sopraggiungessi": "sopraggiungere",
    "sopraggiungessimo": "sopraggiungere",
    "sopraggiungeste": "sopraggiungere",
    "sopraggiungesti": "sopraggiungere",
    "sopraggiungete": "sopraggiungere",
    "sopraggiungeva": "sopraggiungere",
    "sopraggiungevamo": "sopraggiungere",
    "sopraggiungevan": "sopraggiungere",
    "sopraggiungevano": "sopraggiungere",
    "sopraggiungevate": "sopraggiungere",
    "sopraggiungevi": "sopraggiungere",
    "sopraggiungevo": "sopraggiungere",
    "sopraggiungi": "sopraggiungere",
    "sopraggiungiamo": "sopraggiungere",
    "sopraggiungiate": "sopraggiungere",
    "sopraggiungo": "sopraggiungere",
    "sopraggiungon": "sopraggiungere",
    "sopraggiungono": "sopraggiungere",
    "sopraggiunse": "sopraggiungere",
    "sopraggiunser": "sopraggiungere",
    "sopraggiunsero": "sopraggiungere",
    "sopraggiunsi": "sopraggiungere",
    "sopraggiunta": "sopraggiungere",
    "sopraggiunte": "sopraggiungere",
    "sopraggiunti": "sopraggiungere",
    "sopraggiunto": "sopraggiungere",
    "sopralluoghi": "sopralluogo",
    "soprammetta": "soprammettere",
    "soprammettan": "soprammettere",
    "soprammettano": "soprammettere",
    "soprammette": "soprammettere",
    "soprammettei": "soprammettere",
    "soprammettemmo": "soprammettere",
    "soprammettendo": "soprammettere",
    "soprammettente": "soprammettere",
    "soprammettenti": "soprammettere",
    "soprammetter": "soprammettere",
    "soprammetterai": "soprammettere",
    "soprammetteran": "soprammettere",
    "soprammetteranno": "soprammettere",
    "soprammetterebbe": "soprammettere",
    "soprammetterebber": "soprammettere",
    "soprammetterebbero": "soprammettere",
    "soprammetterei": "soprammettere",
    "soprammetteremmo": "soprammettere",
    "soprammetteremo": "soprammettere",
    "soprammettereste": "soprammettere",
    "soprammetteresti": "soprammettere",
    "soprammetterete": "soprammettere",
    "soprammetteron": "soprammettere",
    "soprammetterono": "soprammettere",
    "soprammetterà": "soprammettere",
    "soprammetterò": "soprammettere",
    "soprammettesse": "soprammettere",
    "soprammettesser": "soprammettere",
    "soprammettessero": "soprammettere",
    "soprammettessi": "soprammettere",
    "soprammettessimo": "soprammettere",
    "soprammetteste": "soprammettere",
    "soprammettesti": "soprammettere",
    "soprammettete": "soprammettere",
    "soprammetteva": "soprammettere",
    "soprammettevamo": "soprammettere",
    "soprammettevan": "soprammettere",
    "soprammettevano": "soprammettere",
    "soprammettevate": "soprammettere",
    "soprammettevi": "soprammettere",
    "soprammettevo": "soprammettere",
    "soprammetti": "soprammettere",
    "soprammettiamo": "soprammettere",
    "soprammettiate": "soprammettere",
    "soprammetto": "soprammettere",
    "soprammetton": "soprammettere",
    "soprammettono": "soprammettere",
    "soprammettuta": "soprammettere",
    "soprammettute": "soprammettere",
    "soprammettuti": "soprammettere",
    "soprammettuto": "soprammettere",
    "soprammettè": "soprammettere",
    "soprana": "soprano",
    "sopranazionali": "sopranazionale",
    "soprane": "soprano",
    "soprani": "soprano",
    "soprannaturali": "soprannaturale",
    "soprannomi": "soprannome",
    "soprannomina": "soprannominare",
    "soprannominai": "soprannominare",
    "soprannominammo": "soprannominare",
    "soprannominan": "soprannominare",
    "soprannominando": "soprannominare",
    "soprannominano": "soprannominare",
    "soprannominante": "soprannominare",
    "soprannominanti": "soprannominare",
    "soprannominar": "soprannominare",
    "soprannominaron": "soprannominare",
    "soprannominarono": "soprannominare",
    "soprannominasse": "soprannominare",
    "soprannominasser": "soprannominare",
    "soprannominassero": "soprannominare",
    "soprannominassi": "soprannominare",
    "soprannominassimo": "soprannominare",
    "soprannominaste": "soprannominare",
    "soprannominasti": "soprannominare",
    "soprannominata": "soprannominato",
    "soprannominate": "soprannominato",
    "soprannominati": "soprannominato",
    "soprannominato": "soprannominare",
    "soprannominava": "soprannominare",
    "soprannominavamo": "soprannominare",
    "soprannominavan": "soprannominare",
    "soprannominavano": "soprannominare",
    "soprannominavate": "soprannominare",
    "soprannominavi": "soprannominare",
    "soprannominavo": "soprannominare",
    "soprannominerai": "soprannominare",
    "soprannomineran": "soprannominare",
    "soprannomineranno": "soprannominare",
    "soprannominerebbe": "soprannominare",
    "soprannominerebber": "soprannominare",
    "soprannominerebbero": "soprannominare",
    "soprannominerei": "soprannominare",
    "soprannomineremmo": "soprannominare",
    "soprannomineremo": "soprannominare",
    "soprannominereste": "soprannominare",
    "soprannomineresti": "soprannominare",
    "soprannominerete": "soprannominare",
    "soprannominerà": "soprannominare",
    "soprannominerò": "soprannominare",
    "soprannomini": "soprannominare",
    "soprannominiamo": "soprannominare",
    "soprannominiate": "soprannominare",
    "soprannominin": "soprannominare",
    "soprannominino": "soprannominare",
    "soprannomino": "soprannominare",
    "soprannominò": "soprannominare",
    "soprannumera": "soprannumero",
    "soprannumere": "soprannumero",
    "soprannumeri": "soprannumero",
    "soprassalti": "soprassalto",
    "soprassedano": "soprassedere",
    "soprassedei": "soprassedere",
    "soprassedemmo": "soprassedere",
    "soprasseder": "soprassedere",
    "soprassederai": "soprassedere",
    "soprassederanno": "soprassedere",
    "soprassederebbe": "soprassedere",
    "soprassederebbero": "soprassedere",
    "soprassederei": "soprassedere",
    "soprassederemmo": "soprassedere",
    "soprassederemo": "soprassedere",
    "soprassedereste": "soprassedere",
    "soprassederesti": "soprassedere",
    "soprassederete": "soprassedere",
    "soprassederon": "soprassedere",
    "soprassederono": "soprassedere",
    "soprassederà": "soprassedere",
    "soprassederò": "soprassedere",
    "soprassedesse": "soprassedere",
    "soprassedesser": "soprassedere",
    "soprassedessero": "soprassedere",
    "soprassedessi": "soprassedere",
    "soprassedessimo": "soprassedere",
    "soprassedeste": "soprassedere",
    "soprassedesti": "soprassedere",
    "soprassedete": "soprassedere",
    "soprassedeva": "soprassedere",
    "soprassedevamo": "soprassedere",
    "soprassedevano": "soprassedere",
    "soprassedevate": "soprassedere",
    "soprassedevi": "soprassedere",
    "soprassedevo": "soprassedere",
    "soprassediamo": "soprassedere",
    "soprassediate": "soprassedere",
    "soprasseduta": "soprassedere",
    "soprassedute": "soprassedere",
    "soprasseduti": "soprassedere",
    "soprasseduto": "soprassedere",
    "soprassedè": "soprassedere",
    "soprassieda": "soprassedere",
    "soprassiede": "soprassedere",
    "soprassiedi": "soprassedere",
    "soprassiedo": "soprassedere",
    "soprassiedon": "soprassedere",
    "soprassiedono": "soprassedere",
    "soprasta": "soprastare",
    "soprastai": "soprastare",
    "soprastammo": "soprastare",
    "soprastan": "soprastare",
    "soprastando": "soprastare",
    "soprastano": "soprastare",
    "soprastante": "soprastare",
    "soprastanti": "soprastare",
    "soprastar": "soprastare",
    "soprastaron": "soprastare",
    "soprastarono": "soprastare",
    "soprastasse": "soprastare",
    "soprastasser": "soprastare",
    "soprastassero": "soprastare",
    "soprastassi": "soprastare",
    "soprastassimo": "soprastare",
    "soprastaste": "soprastare",
    "soprastasti": "soprastare",
    "soprastata": "soprastare",
    "soprastate": "soprastare",
    "soprastati": "soprastare",
    "soprastato": "soprastare",
    "soprastava": "soprastare",
    "soprastavamo": "soprastare",
    "soprastavan": "soprastare",
    "soprastavano": "soprastare",
    "soprastavate": "soprastare",
    "soprastavi": "soprastare",
    "soprastavo": "soprastare",
    "soprasterai": "soprastare",
    "soprasteran": "soprastare",
    "soprasteranno": "soprastare",
    "soprasterebbe": "soprastare",
    "soprasterebber": "soprastare",
    "soprasterebbero": "soprastare",
    "soprasterei": "soprastare",
    "soprasteremmo": "soprastare",
    "soprasteremo": "soprastare",
    "soprastereste": "soprastare",
    "soprasteresti": "soprastare",
    "soprasterete": "soprastare",
    "soprasterà": "soprastare",
    "soprasterò": "soprastare",
    "soprasti": "soprastare",
    "soprastiamo": "soprastare",
    "soprastiate": "soprastare",
    "soprastin": "soprastare",
    "soprastino": "soprastare",
    "soprasto": "soprastare",
    "soprastò": "soprastare",
    "soprattasse": "soprattassa",
    "sopravaluta": "sopravalutare",
    "sopravalutai": "sopravalutare",
    "sopravalutammo": "sopravalutare",
    "sopravalutan": "sopravalutare",
    "sopravalutando": "sopravalutare",
    "sopravalutano": "sopravalutare",
    "sopravalutante": "sopravalutare",
    "sopravalutanti": "sopravalutare",
    "sopravalutar": "sopravalutare",
    "sopravalutaron": "sopravalutare",
    "sopravalutarono": "sopravalutare",
    "sopravalutasse": "sopravalutare",
    "sopravalutasser": "sopravalutare",
    "sopravalutassero": "sopravalutare",
    "sopravalutassi": "sopravalutare",
    "sopravalutassimo": "sopravalutare",
    "sopravalutaste": "sopravalutare",
    "sopravalutasti": "sopravalutare",
    "sopravalutata": "sopravalutare",
    "sopravalutate": "sopravalutare",
    "sopravalutati": "sopravalutare",
    "sopravalutato": "sopravalutare",
    "sopravalutava": "sopravalutare",
    "sopravalutavamo": "sopravalutare",
    "sopravalutavan": "sopravalutare",
    "sopravalutavano": "sopravalutare",
    "sopravalutavate": "sopravalutare",
    "sopravalutavi": "sopravalutare",
    "sopravalutavo": "sopravalutare",
    "sopravaluterai": "sopravalutare",
    "sopravaluteran": "sopravalutare",
    "sopravaluteranno": "sopravalutare",
    "sopravaluterebbe": "sopravalutare",
    "sopravaluterebber": "sopravalutare",
    "sopravaluterebbero": "sopravalutare",
    "sopravaluterei": "sopravalutare",
    "sopravaluteremmo": "sopravalutare",
    "sopravaluteremo": "sopravalutare",
    "sopravalutereste": "sopravalutare",
    "sopravaluteresti": "sopravalutare",
    "sopravaluterete": "sopravalutare",
    "sopravaluterà": "sopravalutare",
    "sopravaluterò": "sopravalutare",
    "sopravaluti": "sopravalutare",
    "sopravalutiamo": "sopravalutare",
    "sopravalutiate": "sopravalutare",
    "sopravalutin": "sopravalutare",
    "sopravalutino": "sopravalutare",
    "sopravaluto": "sopravalutare",
    "sopravalutò": "sopravalutare",
    "sopravanza": "sopravanzare",
    "sopravanzai": "sopravanzare",
    "sopravanzammo": "sopravanzare",
    "sopravanzan": "sopravanzare",
    "sopravanzando": "sopravanzare",
    "sopravanzano": "sopravanzare",
    "sopravanzante": "sopravanzare",
    "sopravanzanti": "sopravanzare",
    "sopravanzar": "sopravanzare",
    "sopravanzaron": "sopravanzare",
    "sopravanzarono": "sopravanzare",
    "sopravanzasse": "sopravanzare",
    "sopravanzasser": "sopravanzare",
    "sopravanzassero": "sopravanzare",
    "sopravanzassi": "sopravanzare",
    "sopravanzassimo": "sopravanzare",
    "sopravanzaste": "sopravanzare",
    "sopravanzasti": "sopravanzare",
    "sopravanzata": "sopravanzare",
    "sopravanzate": "sopravanzare",
    "sopravanzati": "sopravanzare",
    "sopravanzato": "sopravanzare",
    "sopravanzava": "sopravanzare",
    "sopravanzavamo": "sopravanzare",
    "sopravanzavan": "sopravanzare",
    "sopravanzavano": "sopravanzare",
    "sopravanzavate": "sopravanzare",
    "sopravanzavi": "sopravanzare",
    "sopravanzavo": "sopravanzare",
    "sopravanzerai": "sopravanzare",
    "sopravanzeran": "sopravanzare",
    "sopravanzeranno": "sopravanzare",
    "sopravanzerebbe": "sopravanzare",
    "sopravanzerebber": "sopravanzare",
    "sopravanzerebbero": "sopravanzare",
    "sopravanzerei": "sopravanzare",
    "sopravanzeremmo": "sopravanzare",
    "sopravanzeremo": "sopravanzare",
    "sopravanzereste": "sopravanzare",
    "sopravanzeresti": "sopravanzare",
    "sopravanzerete": "sopravanzare",
    "sopravanzerà": "sopravanzare",
    "sopravanzerò": "sopravanzare",
    "sopravanzi": "sopravanzare",
    "sopravanziamo": "sopravanzare",
    "sopravanziate": "sopravanzare",
    "sopravanzin": "sopravanzare",
    "sopravanzino": "sopravanzare",
    "sopravanzo": "sopravanzare",
    "sopravanzò": "sopravanzare",
    "sopravissuti": "sopravissuto",
    "sopravvaluta": "sopravvalutare",
    "sopravvalutai": "sopravvalutare",
    "sopravvalutammo": "sopravvalutare",
    "sopravvalutan": "sopravvalutare",
    "sopravvalutando": "sopravvalutare",
    "sopravvalutano": "sopravvalutare",
    "sopravvalutante": "sopravvalutare",
    "sopravvalutanti": "sopravvalutare",
    "sopravvalutar": "sopravvalutare",
    "sopravvalutaron": "sopravvalutare",
    "sopravvalutarono": "sopravvalutare",
    "sopravvalutasse": "sopravvalutare",
    "sopravvalutasser": "sopravvalutare",
    "sopravvalutassero": "sopravvalutare",
    "sopravvalutassi": "sopravvalutare",
    "sopravvalutassimo": "sopravvalutare",
    "sopravvalutaste": "sopravvalutare",
    "sopravvalutasti": "sopravvalutare",
    "sopravvalutata": "sopravvalutare",
    "sopravvalutate": "sopravvalutare",
    "sopravvalutati": "sopravvalutare",
    "sopravvalutato": "sopravvalutare",
    "sopravvalutava": "sopravvalutare",
    "sopravvalutavamo": "sopravvalutare",
    "sopravvalutavan": "sopravvalutare",
    "sopravvalutavano": "sopravvalutare",
    "sopravvalutavate": "sopravvalutare",
    "sopravvalutavi": "sopravvalutare",
    "sopravvalutavo": "sopravvalutare",
    "sopravvalutazioni": "sopravvalutazione",
    "sopravvaluterai": "sopravvalutare",
    "sopravvaluteran": "sopravvalutare",
    "sopravvaluteranno": "sopravvalutare",
    "sopravvaluterebbe": "sopravvalutare",
    "sopravvaluterebber": "sopravvalutare",
    "sopravvaluterebbero": "sopravvalutare",
    "sopravvaluterei": "sopravvalutare",
    "sopravvaluteremmo": "sopravvalutare",
    "sopravvaluteremo": "sopravvalutare",
    "sopravvalutereste": "sopravvalutare",
    "sopravvaluteresti": "sopravvalutare",
    "sopravvaluterete": "sopravvalutare",
    "sopravvaluterà": "sopravvalutare",
    "sopravvaluterò": "sopravvalutare",
    "sopravvaluti": "sopravvalutare",
    "sopravvalutiamo": "sopravvalutare",
    "sopravvalutiate": "sopravvalutare",
    "sopravvalutin": "sopravvalutare",
    "sopravvalutino": "sopravvalutare",
    "sopravvaluto": "sopravvalutare",
    "sopravvalutò": "sopravvalutare",
    "sopravvenendo": "sopravvenire",
    "sopravvenente": "sopravvenire",
    "sopravvenenti": "sopravvenire",
    "sopravvenga": "sopravvenire",
    "sopravvengan": "sopravvenire",
    "sopravvengano": "sopravvenire",
    "sopravvengo": "sopravvenire",
    "sopravvengon": "sopravvenire",
    "sopravvengono": "sopravvenire",
    "sopravveniamo": "sopravvenire",
    "sopravveniate": "sopravvenire",
    "sopravvenienze": "sopravvenienza",
    "sopravvenimmo": "sopravvenire",
    "sopravvenir": "sopravvenire",
    "sopravvenisse": "sopravvenire",
    "sopravvenisser": "sopravvenire",
    "sopravvenissero": "sopravvenire",
    "sopravvenissi": "sopravvenire",
    "sopravvenissimo": "sopravvenire",
    "sopravveniste": "sopravvenire",
    "sopravvenisti": "sopravvenire",
    "sopravvenite": "sopravvenire",
    "sopravveniva": "sopravvenire",
    "sopravvenivamo": "sopravvenire",
    "sopravvenivan": "sopravvenire",
    "sopravvenivano": "sopravvenire",
    "sopravvenivate": "sopravvenire",
    "sopravvenivi": "sopravvenire",
    "sopravvenivo": "sopravvenire",
    "sopravvenne": "sopravvenire",
    "sopravvenner": "sopravvenire",
    "sopravvennero": "sopravvenire",
    "sopravvenni": "sopravvenire",
    "sopravventi": "sopravvento",
    "sopravvenuta": "sopravvenire",
    "sopravvenute": "sopravvenire",
    "sopravvenuti": "sopravvenuto",
    "sopravvenuto": "sopravvenire",
    "sopravverrai": "sopravvenire",
    "sopravverran": "sopravvenire",
    "sopravverranno": "sopravvenire",
    "sopravverrebbe": "sopravvenire",
    "sopravverrebber": "sopravvenire",
    "sopravverrebbero": "sopravvenire",
    "sopravverrei": "sopravvenire",
    "sopravverremmo": "sopravvenire",
    "sopravverremo": "sopravvenire",
    "sopravverreste": "sopravvenire",
    "sopravverresti": "sopravvenire",
    "sopravverrete": "sopravvenire",
    "sopravverrà": "sopravvenire",
    "sopravverrò": "sopravvenire",
    "sopravviene": "sopravvenire",
    "sopravvieni": "sopravvenire",
    "sopravvisse": "sopravvivere",
    "sopravvisser": "sopravvivere",
    "sopravvissero": "sopravvivere",
    "sopravvissi": "sopravvivere",
    "sopravvissuta": "sopravvivere",
    "sopravvissute": "sopravvivere",
    "sopravvissuti": "sopravvivere",
    "sopravvissuto": "sopravvivere",
    "sopravviva": "sopravvivere",
    "sopravvivan": "sopravvivere",
    "sopravvivano": "sopravvivere",
    "sopravvive": "sopravvivere",
    "sopravvivemmo": "sopravvivere",
    "sopravvivendo": "sopravvivere",
    "sopravvivente": "sopravvivere",
    "sopravviventi": "sopravvivere",
    "sopravvivenze": "sopravvivenza",
    "sopravviver": "sopravvivere",
    "sopravvivesse": "sopravvivere",
    "sopravvivesser": "sopravvivere",
    "sopravvivessero": "sopravvivere",
    "sopravvivessi": "sopravvivere",
    "sopravvivessimo": "sopravvivere",
    "sopravviveste": "sopravvivere",
    "sopravvivesti": "sopravvivere",
    "sopravvivete": "sopravvivere",
    "sopravviveva": "sopravvivere",
    "sopravvivevamo": "sopravvivere",
    "sopravvivevan": "sopravvivere",
    "sopravvivevano": "sopravvivere",
    "sopravvivevate": "sopravvivere",
    "sopravvivevi": "sopravvivere",
    "sopravvivevo": "sopravvivere",
    "sopravvivi": "sopravvivere",
    "sopravviviamo": "sopravvivere",
    "sopravviviate": "sopravvivere",
    "sopravvivo": "sopravvivere",
    "sopravvivon": "sopravvivere",
    "sopravvivono": "sopravvivere",
    "sopravvivrai": "sopravvivere",
    "sopravvivran": "sopravvivere",
    "sopravvivranno": "sopravvivere",
    "sopravvivrebbe": "sopravvivere",
    "sopravvivrebber": "sopravvivere",
    "sopravvivrebbero": "sopravvivere",
    "sopravvivrei": "sopravvivere",
    "sopravvivremmo": "sopravvivere",
    "sopravvivremo": "sopravvivere",
    "sopravvivreste": "sopravvivere",
    "sopravvivresti": "sopravvivere",
    "sopravvivrete": "sopravvivere",
    "sopravvivrà": "sopravvivere",
    "sopravvivrò": "sopravvivere",
    "sopreleva": "soprelevare",
    "soprelevai": "soprelevare",
    "soprelevammo": "soprelevare",
    "soprelevan": "soprelevare",
    "soprelevando": "soprelevare",
    "soprelevano": "soprelevare",
    "soprelevante": "soprelevare",
    "soprelevanti": "soprelevare",
    "soprelevar": "soprelevare",
    "soprelevaron": "soprelevare",
    "soprelevarono": "soprelevare",
    "soprelevasse": "soprelevare",
    "soprelevasser": "soprelevare",
    "soprelevassero": "soprelevare",
    "soprelevassi": "soprelevare",
    "soprelevassimo": "soprelevare",
    "soprelevaste": "soprelevare",
    "soprelevasti": "soprelevare",
    "soprelevata": "soprelevare",
    "soprelevate": "soprelevare",
    "soprelevati": "soprelevare",
    "soprelevato": "soprelevare",
    "soprelevava": "soprelevare",
    "soprelevavamo": "soprelevare",
    "soprelevavan": "soprelevare",
    "soprelevavano": "soprelevare",
    "soprelevavate": "soprelevare",
    "soprelevavi": "soprelevare",
    "soprelevavo": "soprelevare",
    "sopreleverai": "soprelevare",
    "sopreleveran": "soprelevare",
    "sopreleveranno": "soprelevare",
    "sopreleverebbe": "soprelevare",
    "sopreleverebber": "soprelevare",
    "sopreleverebbero": "soprelevare",
    "sopreleverei": "soprelevare",
    "sopreleveremmo": "soprelevare",
    "sopreleveremo": "soprelevare",
    "soprelevereste": "soprelevare",
    "sopreleveresti": "soprelevare",
    "sopreleverete": "soprelevare",
    "sopreleverà": "soprelevare",
    "sopreleverò": "soprelevare",
    "soprelevi": "soprelevare",
    "sopreleviamo": "soprelevare",
    "sopreleviate": "soprelevare",
    "soprelevin": "soprelevare",
    "soprelevino": "soprelevare",
    "soprelevo": "soprelevare",
    "soprelevò": "soprelevare",
    "soprese": "sopresa",
    "soprintenda": "soprintendere",
    "soprintendan": "soprintendere",
    "soprintendano": "soprintendere",
    "soprintende": "soprintendere",
    "soprintendemmo": "soprintendere",
    "soprintendendo": "soprintendere",
    "soprintendente": "soprintendere",
    "soprintendenti": "soprintendere",
    "soprintendenze": "soprintendenza",
    "soprintender": "soprintendere",
    "soprintenderai": "soprintendere",
    "soprintenderan": "soprintendere",
    "soprintenderanno": "soprintendere",
    "soprintenderebbe": "soprintendere",
    "soprintenderebber": "soprintendere",
    "soprintenderebbero": "soprintendere",
    "soprintenderei": "soprintendere",
    "soprintenderemmo": "soprintendere",
    "soprintenderemo": "soprintendere",
    "soprintendereste": "soprintendere",
    "soprintenderesti": "soprintendere",
    "soprintenderete": "soprintendere",
    "soprintenderà": "soprintendere",
    "soprintenderò": "soprintendere",
    "soprintendesse": "soprintendere",
    "soprintendesser": "soprintendere",
    "soprintendessero": "soprintendere",
    "soprintendessi": "soprintendere",
    "soprintendessimo": "soprintendere",
    "soprintendeste": "soprintendere",
    "soprintendesti": "soprintendere",
    "soprintendete": "soprintendere",
    "soprintendeva": "soprintendere",
    "soprintendevamo": "soprintendere",
    "soprintendevan": "soprintendere",
    "soprintendevano": "soprintendere",
    "soprintendevate": "soprintendere",
    "soprintendevi": "soprintendere",
    "soprintendevo": "soprintendere",
    "soprintendi": "soprintendere",
    "soprintendiamo": "soprintendere",
    "soprintendiate": "soprintendere",
    "soprintendo": "soprintendere",
    "soprintendon": "soprintendere",
    "soprintendono": "soprintendere",
    "soprintesa": "soprintendere",
    "soprintese": "soprintendere",
    "soprinteser": "soprintendere",
    "soprintesero": "soprintendere",
    "soprintesi": "soprintendere",
    "soprinteso": "soprintendere",
    "soprintesè": "soprintendere",
    "soprusi": "sopruso",
    "sopì": "sopire",
    "sorba": "sorbire",
    "sorban": "sorbire",
    "sorbano": "sorbire",
    "sorbe": "sorbire",
    "sorbendo": "sorbire",
    "sorbente": "sorbire",
    "sorbenti": "sorbire",
    "sorbetta": "sorbettare",
    "sorbettai": "sorbettare",
    "sorbettammo": "sorbettare",
    "sorbettan": "sorbettare",
    "sorbettando": "sorbettare",
    "sorbettano": "sorbettare",
    "sorbettante": "sorbettare",
    "sorbettanti": "sorbettare",
    "sorbettar": "sorbettare",
    "sorbettaron": "sorbettare",
    "sorbettarono": "sorbettare",
    "sorbettasse": "sorbettare",
    "sorbettasser": "sorbettare",
    "sorbettassero": "sorbettare",
    "sorbettassi": "sorbettare",
    "sorbettassimo": "sorbettare",
    "sorbettaste": "sorbettare",
    "sorbettasti": "sorbettare",
    "sorbettata": "sorbettare",
    "sorbettate": "sorbettare",
    "sorbettati": "sorbettare",
    "sorbettato": "sorbettare",
    "sorbettava": "sorbettare",
    "sorbettavamo": "sorbettare",
    "sorbettavan": "sorbettare",
    "sorbettavano": "sorbettare",
    "sorbettavate": "sorbettare",
    "sorbettavi": "sorbettare",
    "sorbettavo": "sorbettare",
    "sorbetterai": "sorbettare",
    "sorbetteran": "sorbettare",
    "sorbetteranno": "sorbettare",
    "sorbetterebbe": "sorbettare",
    "sorbetterebber": "sorbettare",
    "sorbetterebbero": "sorbettare",
    "sorbetterei": "sorbettare",
    "sorbetteremmo": "sorbettare",
    "sorbetteremo": "sorbettare",
    "sorbettereste": "sorbettare",
    "sorbetteresti": "sorbettare",
    "sorbetterete": "sorbettare",
    "sorbetterà": "sorbettare",
    "sorbetterò": "sorbettare",
    "sorbetti": "sorbetto",
    "sorbettiamo": "sorbettare",
    "sorbettiate": "sorbettare",
    "sorbettin": "sorbettare",
    "sorbettino": "sorbettare",
    "sorbetto": "sorbettare",
    "sorbettò": "sorbettare",
    "sorbi": "sorbire",
    "sorbiamo": "sorbire",
    "sorbiate": "sorbire",
    "sorbii": "sorbire",
    "sorbimmo": "sorbire",
    "sorbir": "sorbire",
    "sorbirai": "sorbire",
    "sorbiran": "sorbire",
    "sorbiranno": "sorbire",
    "sorbirebbe": "sorbire",
    "sorbirebber": "sorbire",
    "sorbirebbero": "sorbire",
    "sorbirei": "sorbire",
    "sorbiremmo": "sorbire",
    "sorbiremo": "sorbire",
    "sorbireste": "sorbire",
    "sorbiresti": "sorbire",
    "sorbirete": "sorbire",
    "sorbiron": "sorbire",
    "sorbirono": "sorbire",
    "sorbirà": "sorbire",
    "sorbirò": "sorbire",
    "sorbisse": "sorbire",
    "sorbisser": "sorbire",
    "sorbissero": "sorbire",
    "sorbissi": "sorbire",
    "sorbissimo": "sorbire",
    "sorbiste": "sorbire",
    "sorbisti": "sorbire",
    "sorbita": "sorbire",
    "sorbite": "sorbire",
    "sorbiti": "sorbire",
    "sorbito": "sorbire",
    "sorbiva": "sorbire",
    "sorbivamo": "sorbire",
    "sorbivan": "sorbire",
    "sorbivano": "sorbire",
    "sorbivate": "sorbire",
    "sorbivi": "sorbire",
    "sorbivo": "sorbire",
    "sorbo": "sorbire",
    "sorbon": "sorbire",
    "sorbono": "sorbire",
    "sorbì": "sorbire",
    "sorci": "sorcio",
    "sorda": "sordo",
    "sorde": "sordo",
    "sordi": "sordo",
    "sordida": "sordido",
    "sordide": "sordido",
    "sordidi": "sordido",
    "sordine": "sordina",
    "sordomuta": "sordomuto",
    "sordomute": "sordomuto",
    "sordomuti": "sordomuto",
    "sore": "sora",
    "sorellastre": "sorellastra",
    "sorelle": "sorella",
    "sorelline": "sorellina",
    "sorga": "sorgere",
    "sorgan": "sorgere",
    "sorgano": "sorgere",
    "sorge": "sorgere",
    "sorgemmo": "sorgere",
    "sorgendo": "sorgere",
    "sorgente": "sorgere",
    "sorgenti": "sorgere",
    "sorger": "sorgere",
    "sorgerai": "sorgere",
    "sorgeran": "sorgere",
    "sorgeranno": "sorgere",
    "sorgerebbe": "sorgere",
    "sorgerebber": "sorgere",
    "sorgerebbero": "sorgere",
    "sorgerei": "sorgere",
    "sorgeremmo": "sorgere",
    "sorgeremo": "sorgere",
    "sorgereste": "sorgere",
    "sorgeresti": "sorgere",
    "sorgerete": "sorgere",
    "sorgerà": "sorgere",
    "sorgerò": "sorgere",
    "sorgesse": "sorgere",
    "sorgesser": "sorgere",
    "sorgessero": "sorgere",
    "sorgessi": "sorgere",
    "sorgessimo": "sorgere",
    "sorgeste": "sorgere",
    "sorgesti": "sorgere",
    "sorgete": "sorgere",
    "sorgeva": "sorgere",
    "sorgevamo": "sorgere",
    "sorgevan": "sorgere",
    "sorgevano": "sorgere",
    "sorgevate": "sorgere",
    "sorgevi": "sorgere",
    "sorgevo": "sorgere",
    "sorgi": "sorgere",
    "sorgiamo": "sorgere",
    "sorgiate": "sorgere",
    "sorgiva": "sorgivo",
    "sorgive": "sorgivo",
    "sorgivi": "sorgivo",
    "sorgo": "sorgere",
    "sorgon": "sorgere",
    "sorgono": "sorgere",
    "soriana": "soriano",
    "soriane": "soriano",
    "soriani": "soriano",
    "sormonta": "sormontare",
    "sormontai": "sormontare",
    "sormontammo": "sormontare",
    "sormontan": "sormontare",
    "sormontando": "sormontare",
    "sormontano": "sormontare",
    "sormontante": "sormontare",
    "sormontanti": "sormontare",
    "sormontar": "sormontare",
    "sormontaron": "sormontare",
    "sormontarono": "sormontare",
    "sormontasse": "sormontare",
    "sormontasser": "sormontare",
    "sormontassero": "sormontare",
    "sormontassi": "sormontare",
    "sormontassimo": "sormontare",
    "sormontaste": "sormontare",
    "sormontasti": "sormontare",
    "sormontata": "sormontare",
    "sormontate": "sormontare",
    "sormontati": "sormontare",
    "sormontato": "sormontare",
    "sormontava": "sormontare",
    "sormontavamo": "sormontare",
    "sormontavan": "sormontare",
    "sormontavano": "sormontare",
    "sormontavate": "sormontare",
    "sormontavi": "sormontare",
    "sormontavo": "sormontare",
    "sormonterai": "sormontare",
    "sormonteran": "sormontare",
    "sormonteranno": "sormontare",
    "sormonterebbe": "sormontare",
    "sormonterebber": "sormontare",
    "sormonterebbero": "sormontare",
    "sormonterei": "sormontare",
    "sormonteremmo": "sormontare",
    "sormonteremo": "sormontare",
    "sormontereste": "sormontare",
    "sormonteresti": "sormontare",
    "sormonterete": "sormontare",
    "sormonterà": "sormontare",
    "sormonterò": "sormontare",
    "sormonti": "sormontare",
    "sormontiamo": "sormontare",
    "sormontiate": "sormontare",
    "sormontin": "sormontare",
    "sormontino": "sormontare",
    "sormonto": "sormontare",
    "sormontò": "sormontare",
    "sornioni": "sornione",
    "sorpassa": "sorpassare",
    "sorpassai": "sorpassare",
    "sorpassammo": "sorpassare",
    "sorpassan": "sorpassare",
    "sorpassando": "sorpassare",
    "sorpassano": "sorpassare",
    "sorpassante": "sorpassare",
    "sorpassanti": "sorpassare",
    "sorpassar": "sorpassare",
    "sorpassaron": "sorpassare",
    "sorpassarono": "sorpassare",
    "sorpassasse": "sorpassare",
    "sorpassasser": "sorpassare",
    "sorpassassero": "sorpassare",
    "sorpassassi": "sorpassare",
    "sorpassassimo": "sorpassare",
    "sorpassaste": "sorpassare",
    "sorpassasti": "sorpassare",
    "sorpassata": "sorpassato",
    "sorpassate": "sorpassato",
    "sorpassati": "sorpassato",
    "sorpassato": "sorpassare",
    "sorpassava": "sorpassare",
    "sorpassavamo": "sorpassare",
    "sorpassavan": "sorpassare",
    "sorpassavano": "sorpassare",
    "sorpassavate": "sorpassare",
    "sorpassavi": "sorpassare",
    "sorpassavo": "sorpassare",
    "sorpasserai": "sorpassare",
    "sorpasseran": "sorpassare",
    "sorpasseranno": "sorpassare",
    "sorpasserebbe": "sorpassare",
    "sorpasserebber": "sorpassare",
    "sorpasserebbero": "sorpassare",
    "sorpasserei": "sorpassare",
    "sorpasseremmo": "sorpassare",
    "sorpasseremo": "sorpassare",
    "sorpassereste": "sorpassare",
    "sorpasseresti": "sorpassare",
    "sorpasserete": "sorpassare",
    "sorpasserà": "sorpassare",
    "sorpasserò": "sorpassare",
    "sorpassi": "sorpasso",
    "sorpassiamo": "sorpassare",
    "sorpassiate": "sorpassare",
    "sorpassin": "sorpassare",
    "sorpassino": "sorpassare",
    "sorpasso": "sorpassare",
    "sorpassò": "sorpassare",
    "sorprenda": "sorprendere",
    "sorprendan": "sorprendere",
    "sorprendano": "sorprendere",
    "sorprende": "sorprendere",
    "sorprendemmo": "sorprendere",
    "sorprendendo": "sorprendere",
    "sorprendente": "sorprendere",
    "sorprendenti": "sorprendere",
    "sorprender": "sorprendere",
    "sorprenderai": "sorprendere",
    "sorprenderan": "sorprendere",
    "sorprenderanno": "sorprendere",
    "sorprenderebbe": "sorprendere",
    "sorprenderebber": "sorprendere",
    "sorprenderebbero": "sorprendere",
    "sorprenderei": "sorprendere",
    "sorprenderemmo": "sorprendere",
    "sorprenderemo": "sorprendere",
    "sorprendereste": "sorprendere",
    "sorprenderesti": "sorprendere",
    "sorprenderete": "sorprendere",
    "sorprenderà": "sorprendere",
    "sorprenderò": "sorprendere",
    "sorprendesse": "sorprendere",
    "sorprendesser": "sorprendere",
    "sorprendessero": "sorprendere",
    "sorprendessi": "sorprendere",
    "sorprendessimo": "sorprendere",
    "sorprendeste": "sorprendere",
    "sorprendesti": "sorprendere",
    "sorprendete": "sorprendere",
    "sorprendeva": "sorprendere",
    "sorprendevamo": "sorprendere",
    "sorprendevan": "sorprendere",
    "sorprendevano": "sorprendere",
    "sorprendevate": "sorprendere",
    "sorprendevi": "sorprendere",
    "sorprendevo": "sorprendere",
    "sorprendi": "sorprendere",
    "sorprendiamo": "sorprendere",
    "sorprendiate": "sorprendere",
    "sorprendo": "sorprendere",
    "sorprendon": "sorprendere",
    "sorprendono": "sorprendere",
    "sorpresa": "sorpreso",
    "sorprese": "sorpreso",
    "sorpreser": "sorprendere",
    "sorpresero": "sorprendere",
    "sorpresi": "sorpreso",
    "sorpresine": "sorpresina",
    "sorpreso": "sorprendere",
    "sorpresè": "sorprendere",
    "sorregga": "sorreggere",
    "sorreggan": "sorreggere",
    "sorreggano": "sorreggere",
    "sorregge": "sorreggere",
    "sorreggemmo": "sorreggere",
    "sorreggendo": "sorreggere",
    "sorreggente": "sorreggere",
    "sorreggenti": "sorreggere",
    "sorregger": "sorreggere",
    "sorreggerai": "sorreggere",
    "sorreggeran": "sorreggere",
    "sorreggeranno": "sorreggere",
    "sorreggerebbe": "sorreggere",
    "sorreggerebber": "sorreggere",
    "sorreggerebbero": "sorreggere",
    "sorreggerei": "sorreggere",
    "sorreggeremmo": "sorreggere",
    "sorreggeremo": "sorreggere",
    "sorreggereste": "sorreggere",
    "sorreggeresti": "sorreggere",
    "sorreggerete": "sorreggere",
    "sorreggerà": "sorreggere",
    "sorreggerò": "sorreggere",
    "sorreggesse": "sorreggere",
    "sorreggesser": "sorreggere",
    "sorreggessero": "sorreggere",
    "sorreggessi": "sorreggere",
    "sorreggessimo": "sorreggere",
    "sorreggeste": "sorreggere",
    "sorreggesti": "sorreggere",
    "sorreggete": "sorreggere",
    "sorreggeva": "sorreggere",
    "sorreggevamo": "sorreggere",
    "sorreggevan": "sorreggere",
    "sorreggevano": "sorreggere",
    "sorreggevate": "sorreggere",
    "sorreggevi": "sorreggere",
    "sorreggevo": "sorreggere",
    "sorreggi": "sorreggere",
    "sorreggiamo": "sorreggere",
    "sorreggiate": "sorreggere",
    "sorreggo": "sorreggere",
    "sorreggon": "sorreggere",
    "sorreggono": "sorreggere",
    "sorresser": "sorreggere",
    "sorressero": "sorreggere",
    "sorressi": "sorreggere",
    "sorressè": "sorreggere",
    "sorretta": "sorreggere",
    "sorrette": "sorreggere",
    "sorretti": "sorreggere",
    "sorretto": "sorreggere",
    "sorrida": "sorridere",
    "sorridan": "sorridere",
    "sorridano": "sorridere",
    "sorride": "sorridere",
    "sorridemmo": "sorridere",
    "sorridendo": "sorridere",
    "sorridente": "sorridere",
    "sorridenti": "sorridere",
    "sorrider": "sorridere",
    "sorriderai": "sorridere",
    "sorrideran": "sorridere",
    "sorrideranno": "sorridere",
    "sorriderebbe": "sorridere",
    "sorriderebber": "sorridere",
    "sorriderebbero": "sorridere",
    "sorriderei": "sorridere",
    "sorrideremmo": "sorridere",
    "sorrideremo": "sorridere",
    "sorridereste": "sorridere",
    "sorrideresti": "sorridere",
    "sorriderete": "sorridere",
    "sorriderà": "sorridere",
    "sorriderò": "sorridere",
    "sorridesse": "sorridere",
    "sorridesser": "sorridere",
    "sorridessero": "sorridere",
    "sorridessi": "sorridere",
    "sorridessimo": "sorridere",
    "sorrideste": "sorridere",
    "sorridesti": "sorridere",
    "sorridete": "sorridere",
    "sorrideva": "sorridere",
    "sorridevamo": "sorridere",
    "sorridevan": "sorridere",
    "sorridevano": "sorridere",
    "sorridevate": "sorridere",
    "sorridevi": "sorridere",
    "sorridevo": "sorridere",
    "sorridi": "sorridere",
    "sorridiamo": "sorridere",
    "sorridiate": "sorridere",
    "sorrido": "sorridere",
    "sorridon": "sorridere",
    "sorridono": "sorridere",
    "sorrisa": "sorridere",
    "sorrise": "sorridere",
    "sorriser": "sorridere",
    "sorrisero": "sorridere",
    "sorrisetti": "sorrisetto",
    "sorrisi": "sorriso",
    "sorrisini": "sorrisino",
    "sorriso": "sorridere",
    "sorrisoni": "sorrisone",
    "sorse": "sorgere",
    "sorseggerai": "sorseggiare",
    "sorseggeran": "sorseggiare",
    "sorseggeranno": "sorseggiare",
    "sorseggerebbe": "sorseggiare",
    "sorseggerebber": "sorseggiare",
    "sorseggerebbero": "sorseggiare",
    "sorseggerei": "sorseggiare",
    "sorseggeremmo": "sorseggiare",
    "sorseggeremo": "sorseggiare",
    "sorseggereste": "sorseggiare",
    "sorseggeresti": "sorseggiare",
    "sorseggerete": "sorseggiare",
    "sorseggerà": "sorseggiare",
    "sorseggerò": "sorseggiare",
    "sorseggi": "sorseggiare",
    "sorseggia": "sorseggiare",
    "sorseggiai": "sorseggiare",
    "sorseggiammo": "sorseggiare",
    "sorseggiamo": "sorseggiare",
    "sorseggian": "sorseggiare",
    "sorseggiando": "sorseggiare",
    "sorseggiano": "sorseggiare",
    "sorseggiante": "sorseggiare",
    "sorseggianti": "sorseggiare",
    "sorseggiar": "sorseggiare",
    "sorseggiaron": "sorseggiare",
    "sorseggiarono": "sorseggiare",
    "sorseggiasse": "sorseggiare",
    "sorseggiasser": "sorseggiare",
    "sorseggiassero": "sorseggiare",
    "sorseggiassi": "sorseggiare",
    "sorseggiassimo": "sorseggiare",
    "sorseggiaste": "sorseggiare",
    "sorseggiasti": "sorseggiare",
    "sorseggiata": "sorseggiare",
    "sorseggiate": "sorseggiare",
    "sorseggiati": "sorseggiare",
    "sorseggiato": "sorseggiare",
    "sorseggiava": "sorseggiare",
    "sorseggiavamo": "sorseggiare",
    "sorseggiavan": "sorseggiare",
    "sorseggiavano": "sorseggiare",
    "sorseggiavate": "sorseggiare",
    "sorseggiavi": "sorseggiare",
    "sorseggiavo": "sorseggiare",
    "sorseggin": "sorseggiare",
    "sorseggino": "sorseggiare",
    "sorseggio": "sorseggiare",
    "sorseggiò": "sorseggiare",
    "sorser": "sorgere",
    "sorsero": "sorgere",
    "sorsi": "sorso",
    "sorta": "sorto",
    "sorte": "sorto",
    "sorteggerai": "sorteggiare",
    "sorteggeran": "sorteggiare",
    "sorteggeranno": "sorteggiare",
    "sorteggerebbe": "sorteggiare",
    "sorteggerebber": "sorteggiare",
    "sorteggerebbero": "sorteggiare",
    "sorteggerei": "sorteggiare",
    "sorteggeremmo": "sorteggiare",
    "sorteggeremo": "sorteggiare",
    "sorteggereste": "sorteggiare",
    "sorteggeresti": "sorteggiare",
    "sorteggerete": "sorteggiare",
    "sorteggerà": "sorteggiare",
    "sorteggerò": "sorteggiare",
    "sorteggi": "sorteggio",
    "sorteggia": "sorteggiare",
    "sorteggiai": "sorteggiare",
    "sorteggiammo": "sorteggiare",
    "sorteggiamo": "sorteggiare",
    "sorteggian": "sorteggiare",
    "sorteggiando": "sorteggiare",
    "sorteggiano": "sorteggiare",
    "sorteggiante": "sorteggiare",
    "sorteggianti": "sorteggiare",
    "sorteggiar": "sorteggiare",
    "sorteggiaron": "sorteggiare",
    "sorteggiarono": "sorteggiare",
    "sorteggiasse": "sorteggiare",
    "sorteggiasser": "sorteggiare",
    "sorteggiassero": "sorteggiare",
    "sorteggiassi": "sorteggiare",
    "sorteggiassimo": "sorteggiare",
    "sorteggiaste": "sorteggiare",
    "sorteggiasti": "sorteggiare",
    "sorteggiata": "sorteggiare",
    "sorteggiate": "sorteggiare",
    "sorteggiati": "sorteggiare",
    "sorteggiato": "sorteggiare",
    "sorteggiava": "sorteggiare",
    "sorteggiavamo": "sorteggiare",
    "sorteggiavan": "sorteggiare",
    "sorteggiavano": "sorteggiare",
    "sorteggiavate": "sorteggiare",
    "sorteggiavi": "sorteggiare",
    "sorteggiavo": "sorteggiare",
    "sorteggin": "sorteggiare",
    "sorteggino": "sorteggiare",
    "sorteggio": "sorteggiare",
    "sorteggiò": "sorteggiare",
    "sortendo": "sortire",
    "sortente": "sortire",
    "sortenti": "sortire",
    "sorti": "sorto",
    "sortiamo": "sortire",
    "sortiate": "sortire",
    "sortii": "sortire",
    "sortilegi": "sortilegio",
    "sortimmo": "sortire",
    "sortir": "sortire",
    "sortirai": "sortire",
    "sortiran": "sortire",
    "sortiranno": "sortire",
    "sortirebbe": "sortire",
    "sortirebber": "sortire",
    "sortirebbero": "sortire",
    "sortirei": "sortire",
    "sortiremmo": "sortire",
    "sortiremo": "sortire",
    "sortireste": "sortire",
    "sortiresti": "sortire",
    "sortirete": "sortire",
    "sortiron": "sortire",
    "sortirono": "sortire",
    "sortirà": "sortire",
    "sortirò": "sortire",
    "sortisca": "sortire",
    "sortiscan": "sortire",
    "sortiscano": "sortire",
    "sortisce": "sortire",
    "sortisci": "sortire",
    "sortisco": "sortire",
    "sortiscon": "sortire",
    "sortiscono": "sortire",
    "sortisse": "sortire",
    "sortisser": "sortire",
    "sortissero": "sortire",
    "sortissi": "sortire",
    "sortissimo": "sortire",
    "sortiste": "sortire",
    "sortisti": "sortire",
    "sortita": "sortire",
    "sortite": "sortita",
    "sortiti": "sortire",
    "sortito": "sortire",
    "sortiva": "sortire",
    "sortivamo": "sortire",
    "sortivan": "sortire",
    "sortivano": "sortire",
    "sortivate": "sortire",
    "sortivi": "sortire",
    "sortivo": "sortire",
    "sorto": "sorgere",
    "sortì": "sortire",
    "sorvegli": "sorvegliare",
    "sorveglia": "sorvegliare",
    "sorvegliai": "sorvegliare",
    "sorvegliammo": "sorvegliare",
    "sorvegliamo": "sorvegliare",
    "sorveglian": "sorvegliare",
    "sorvegliando": "sorvegliare",
    "sorvegliano": "sorvegliare",
    "sorvegliante": "sorvegliare",
    "sorveglianti": "sorvegliare",
    "sorveglianze": "sorveglianza",
    "sorvegliar": "sorvegliare",
    "sorvegliaron": "sorvegliare",
    "sorvegliarono": "sorvegliare",
    "sorvegliasse": "sorvegliare",
    "sorvegliasser": "sorvegliare",
    "sorvegliassero": "sorvegliare",
    "sorvegliassi": "sorvegliare",
    "sorvegliassimo": "sorvegliare",
    "sorvegliaste": "sorvegliare",
    "sorvegliasti": "sorvegliare",
    "sorvegliata": "sorvegliare",
    "sorvegliate": "sorvegliare",
    "sorvegliati": "sorvegliare",
    "sorvegliato": "sorvegliare",
    "sorvegliava": "sorvegliare",
    "sorvegliavamo": "sorvegliare",
    "sorvegliavan": "sorvegliare",
    "sorvegliavano": "sorvegliare",
    "sorvegliavate": "sorvegliare",
    "sorvegliavi": "sorvegliare",
    "sorvegliavo": "sorvegliare",
    "sorveglierai": "sorvegliare",
    "sorveglieran": "sorvegliare",
    "sorveglieranno": "sorvegliare",
    "sorveglierebbe": "sorvegliare",
    "sorveglierebber": "sorvegliare",
    "sorveglierebbero": "sorvegliare",
    "sorveglierei": "sorvegliare",
    "sorveglieremmo": "sorvegliare",
    "sorveglieremo": "sorvegliare",
    "sorvegliereste": "sorvegliare",
    "sorveglieresti": "sorvegliare",
    "sorveglierete": "sorvegliare",
    "sorveglierà": "sorvegliare",
    "sorveglierò": "sorvegliare",
    "sorveglin": "sorvegliare",
    "sorveglino": "sorvegliare",
    "sorveglio": "sorvegliare",
    "sorvegliò": "sorvegliare",
    "sorvola": "sorvolare",
    "sorvolai": "sorvolare",
    "sorvolammo": "sorvolare",
    "sorvolan": "sorvolare",
    "sorvolando": "sorvolare",
    "sorvolano": "sorvolare",
    "sorvolante": "sorvolare",
    "sorvolanti": "sorvolare",
    "sorvolar": "sorvolare",
    "sorvolaron": "sorvolare",
    "sorvolarono": "sorvolare",
    "sorvolasse": "sorvolare",
    "sorvolasser": "sorvolare",
    "sorvolassero": "sorvolare",
    "sorvolassi": "sorvolare",
    "sorvolassimo": "sorvolare",
    "sorvolaste": "sorvolare",
    "sorvolasti": "sorvolare",
    "sorvolata": "sorvolare",
    "sorvolate": "sorvolare",
    "sorvolati": "sorvolare",
    "sorvolato": "sorvolare",
    "sorvolava": "sorvolare",
    "sorvolavamo": "sorvolare",
    "sorvolavan": "sorvolare",
    "sorvolavano": "sorvolare",
    "sorvolavate": "sorvolare",
    "sorvolavi": "sorvolare",
    "sorvolavo": "sorvolare",
    "sorvolerai": "sorvolare",
    "sorvoleran": "sorvolare",
    "sorvoleranno": "sorvolare",
    "sorvolerebbe": "sorvolare",
    "sorvolerebber": "sorvolare",
    "sorvolerebbero": "sorvolare",
    "sorvolerei": "sorvolare",
    "sorvoleremmo": "sorvolare",
    "sorvoleremo": "sorvolare",
    "sorvolereste": "sorvolare",
    "sorvoleresti": "sorvolare",
    "sorvolerete": "sorvolare",
    "sorvolerà": "sorvolare",
    "sorvolerò": "sorvolare",
    "sorvoli": "sorvolare",
    "sorvoliamo": "sorvolare",
    "sorvoliate": "sorvolare",
    "sorvolin": "sorvolare",
    "sorvolino": "sorvolare",
    "sorvolo": "sorvolare",
    "sorvolò": "sorvolare",
    "sosie": "sosia",
    "sospenda": "sospendere",
    "sospendan": "sospendere",
    "sospendano": "sospendere",
    "sospende": "sospendere",
    "sospendemmo": "sospendere",
    "sospendendo": "sospendere",
    "sospendente": "sospendere",
    "sospendenti": "sospendere",
    "sospender": "sospendere",
    "sospenderai": "sospendere",
    "sospenderan": "sospendere",
    "sospenderanno": "sospendere",
    "sospenderebbe": "sospendere",
    "sospenderebber": "sospendere",
    "sospenderebbero": "sospendere",
    "sospenderei": "sospendere",
    "sospenderemmo": "sospendere",
    "sospenderemo": "sospendere",
    "sospendereste": "sospendere",
    "sospenderesti": "sospendere",
    "sospenderete": "sospendere",
    "sospenderà": "sospendere",
    "sospenderò": "sospendere",
    "sospendesse": "sospendere",
    "sospendesser": "sospendere",
    "sospendessero": "sospendere",
    "sospendessi": "sospendere",
    "sospendessimo": "sospendere",
    "sospendeste": "sospendere",
    "sospendesti": "sospendere",
    "sospendete": "sospendere",
    "sospendeva": "sospendere",
    "sospendevamo": "sospendere",
    "sospendevan": "sospendere",
    "sospendevano": "sospendere",
    "sospendevate": "sospendere",
    "sospendevi": "sospendere",
    "sospendevo": "sospendere",
    "sospendi": "sospendere",
    "sospendiamo": "sospendere",
    "sospendiate": "sospendere",
    "sospendo": "sospendere",
    "sospendon": "sospendere",
    "sospendono": "sospendere",
    "sospensioni": "sospensione",
    "sospensiva": "sospensivo",
    "sospensive": "sospensivo",
    "sospensivi": "sospensivo",
    "sospesa": "sospeso",
    "sospese": "sospeso",
    "sospeser": "sospendere",
    "sospesero": "sospendere",
    "sospesi": "sospeso",
    "sospeso": "sospendere",
    "sospesè": "sospendere",
    "sospetta": "sospetto",
    "sospettabili": "sospettabile",
    "sospettai": "sospettare",
    "sospettammo": "sospettare",
    "sospettan": "sospettare",
    "sospettando": "sospettare",
    "sospettano": "sospettare",
    "sospettante": "sospettare",
    "sospettanti": "sospettare",
    "sospettar": "sospettare",
    "sospettaron": "sospettare",
    "sospettarono": "sospettare",
    "sospettasse": "sospettare",
    "sospettasser": "sospettare",
    "sospettassero": "sospettare",
    "sospettassi": "sospettare",
    "sospettassimo": "sospettare",
    "sospettaste": "sospettare",
    "sospettasti": "sospettare",
    "sospettata": "sospettare",
    "sospettate": "sospettare",
    "sospettati": "sospettato",
    "sospettato": "sospettare",
    "sospettava": "sospettare",
    "sospettavamo": "sospettare",
    "sospettavan": "sospettare",
    "sospettavano": "sospettare",
    "sospettavate": "sospettare",
    "sospettavi": "sospettare",
    "sospettavo": "sospettare",
    "sospette": "sospetto",
    "sospetterai": "sospettare",
    "sospetteran": "sospettare",
    "sospetteranno": "sospettare",
    "sospetterebbe": "sospettare",
    "sospetterebber": "sospettare",
    "sospetterebbero": "sospettare",
    "sospetterei": "sospettare",
    "sospetteremmo": "sospettare",
    "sospetteremo": "sospettare",
    "sospettereste": "sospettare",
    "sospetteresti": "sospettare",
    "sospetterete": "sospettare",
    "sospetterà": "sospettare",
    "sospetterò": "sospettare",
    "sospetti": "sospetto",
    "sospettiamo": "sospettare",
    "sospettiate": "sospettare",
    "sospettin": "sospettare",
    "sospettino": "sospettare",
    "sospetto": "sospettare",
    "sospettosa": "sospettoso",
    "sospettose": "sospettoso",
    "sospettosi": "sospettoso",
    "sospettò": "sospettare",
    "sospinga": "sospingere",
    "sospingan": "sospingere",
    "sospingano": "sospingere",
    "sospinge": "sospingere",
    "sospingemmo": "sospingere",
    "sospingendo": "sospingere",
    "sospingente": "sospingere",
    "sospingenti": "sospingere",
    "sospinger": "sospingere",
    "sospingerai": "sospingere",
    "sospingeran": "sospingere",
    "sospingeranno": "sospingere",
    "sospingerebbe": "sospingere",
    "sospingerebber": "sospingere",
    "sospingerebbero": "sospingere",
    "sospingerei": "sospingere",
    "sospingeremmo": "sospingere",
    "sospingeremo": "sospingere",
    "sospingereste": "sospingere",
    "sospingeresti": "sospingere",
    "sospingerete": "sospingere",
    "sospingerà": "sospingere",
    "sospingerò": "sospingere",
    "sospingesse": "sospingere",
    "sospingesser": "sospingere",
    "sospingessero": "sospingere",
    "sospingessi": "sospingere",
    "sospingessimo": "sospingere",
    "sospingeste": "sospingere",
    "sospingesti": "sospingere",
    "sospingete": "sospingere",
    "sospingeva": "sospingere",
    "sospingevamo": "sospingere",
    "sospingevan": "sospingere",
    "sospingevano": "sospingere",
    "sospingevate": "sospingere",
    "sospingevi": "sospingere",
    "sospingevo": "sospingere",
    "sospingi": "sospingere",
    "sospingiamo": "sospingere",
    "sospingiate": "sospingere",
    "sospingo": "sospingere",
    "sospingon": "sospingere",
    "sospingono": "sospingere",
    "sospinse": "sospingere",
    "sospinser": "sospingere",
    "sospinsero": "sospingere",
    "sospinsi": "sospingere",
    "sospinta": "sospingere",
    "sospinte": "sospingere",
    "sospinti": "sospingere",
    "sospinto": "sospingere",
    "sospira": "sospirare",
    "sospirai": "sospirare",
    "sospirammo": "sospirare",
    "sospiran": "sospirare",
    "sospirando": "sospirare",
    "sospirano": "sospirare",
    "sospirante": "sospirare",
    "sospiranti": "sospirare",
    "sospirar": "sospirare",
    "sospiraron": "sospirare",
    "sospirarono": "sospirare",
    "sospirasse": "sospirare",
    "sospirasser": "sospirare",
    "sospirassero": "sospirare",
    "sospirassi": "sospirare",
    "sospirassimo": "sospirare",
    "sospiraste": "sospirare",
    "sospirasti": "sospirare",
    "sospirata": "sospirare",
    "sospirate": "sospirare",
    "sospirati": "sospirato",
    "sospirato": "sospirare",
    "sospirava": "sospirare",
    "sospiravamo": "sospirare",
    "sospiravan": "sospirare",
    "sospiravano": "sospirare",
    "sospiravate": "sospirare",
    "sospiravi": "sospirare",
    "sospiravo": "sospirare",
    "sospirerai": "sospirare",
    "sospireran": "sospirare",
    "sospireranno": "sospirare",
    "sospirerebbe": "sospirare",
    "sospirerebber": "sospirare",
    "sospirerebbero": "sospirare",
    "sospirerei": "sospirare",
    "sospireremmo": "sospirare",
    "sospireremo": "sospirare",
    "sospirereste": "sospirare",
    "sospireresti": "sospirare",
    "sospirerete": "sospirare",
    "sospirerà": "sospirare",
    "sospirerò": "sospirare",
    "sospiri": "sospiro",
    "sospiriamo": "sospirare",
    "sospiriate": "sospirare",
    "sospirin": "sospirare",
    "sospirino": "sospirare",
    "sospiro": "sospirare",
    "sospirosa": "sospiroso",
    "sospirose": "sospiroso",
    "sospirosi": "sospiroso",
    "sospirò": "sospirare",
    "sosta": "sostare",
    "sostai": "sostare",
    "sostammo": "sostare",
    "sostan": "sostare",
    "sostando": "sostare",
    "sostano": "sostare",
    "sostante": "sostare",
    "sostanti": "sostare",
    "sostantiva": "sostantivare",
    "sostantivai": "sostantivare",
    "sostantivammo": "sostantivare",
    "sostantivan": "sostantivare",
    "sostantivando": "sostantivare",
    "sostantivano": "sostantivare",
    "sostantivante": "sostantivare",
    "sostantivanti": "sostantivare",
    "sostantivar": "sostantivare",
    "sostantivaron": "sostantivare",
    "sostantivarono": "sostantivare",
    "sostantivasse": "sostantivare",
    "sostantivasser": "sostantivare",
    "sostantivassero": "sostantivare",
    "sostantivassi": "sostantivare",
    "sostantivassimo": "sostantivare",
    "sostantivaste": "sostantivare",
    "sostantivasti": "sostantivare",
    "sostantivata": "sostantivare",
    "sostantivate": "sostantivare",
    "sostantivati": "sostantivare",
    "sostantivato": "sostantivare",
    "sostantivava": "sostantivare",
    "sostantivavamo": "sostantivare",
    "sostantivavan": "sostantivare",
    "sostantivavano": "sostantivare",
    "sostantivavate": "sostantivare",
    "sostantivavi": "sostantivare",
    "sostantivavo": "sostantivare",
    "sostantiverai": "sostantivare",
    "sostantiveran": "sostantivare",
    "sostantiveranno": "sostantivare",
    "sostantiverebbe": "sostantivare",
    "sostantiverebber": "sostantivare",
    "sostantiverebbero": "sostantivare",
    "sostantiverei": "sostantivare",
    "sostantiveremmo": "sostantivare",
    "sostantiveremo": "sostantivare",
    "sostantivereste": "sostantivare",
    "sostantiveresti": "sostantivare",
    "sostantiverete": "sostantivare",
    "sostantiverà": "sostantivare",
    "sostantiverò": "sostantivare",
    "sostantivi": "sostantivo",
    "sostantiviamo": "sostantivare",
    "sostantiviate": "sostantivare",
    "sostantivin": "sostantivare",
    "sostantivino": "sostantivare",
    "sostantivo": "sostantivare",
    "sostantivò": "sostantivare",
    "sostanze": "sostanza",
    "sostanzi": "sostanziare",
    "sostanzia": "sostanziare",
    "sostanziai": "sostanziare",
    "sostanziali": "sostanziale",
    "sostanziammo": "sostanziare",
    "sostanziamo": "sostanziare",
    "sostanzian": "sostanziare",
    "sostanziando": "sostanziare",
    "sostanziano": "sostanziare",
    "sostanziante": "sostanziare",
    "sostanzianti": "sostanziare",
    "sostanziar": "sostanziare",
    "sostanziaron": "sostanziare",
    "sostanziarono": "sostanziare",
    "sostanziasse": "sostanziare",
    "sostanziasser": "sostanziare",
    "sostanziassero": "sostanziare",
    "sostanziassi": "sostanziare",
    "sostanziassimo": "sostanziare",
    "sostanziaste": "sostanziare",
    "sostanziasti": "sostanziare",
    "sostanziata": "sostanziare",
    "sostanziate": "sostanziare",
    "sostanziati": "sostanziare",
    "sostanziato": "sostanziare",
    "sostanziava": "sostanziare",
    "sostanziavamo": "sostanziare",
    "sostanziavan": "sostanziare",
    "sostanziavano": "sostanziare",
    "sostanziavate": "sostanziare",
    "sostanziavi": "sostanziare",
    "sostanziavo": "sostanziare",
    "sostanzierai": "sostanziare",
    "sostanzieran": "sostanziare",
    "sostanzieranno": "sostanziare",
    "sostanzierebbe": "sostanziare",
    "sostanzierebber": "sostanziare",
    "sostanzierebbero": "sostanziare",
    "sostanzierei": "sostanziare",
    "sostanzieremmo": "sostanziare",
    "sostanzieremo": "sostanziare",
    "sostanziereste": "sostanziare",
    "sostanzieresti": "sostanziare",
    "sostanzierete": "sostanziare",
    "sostanzierà": "sostanziare",
    "sostanzierò": "sostanziare",
    "sostanzin": "sostanziare",
    "sostanzino": "sostanziare",
    "sostanzio": "sostanziare",
    "sostanziosa": "sostanzioso",
    "sostanziose": "sostanzioso",
    "sostanziosi": "sostanzioso",
    "sostanziò": "sostanziare",
    "sostar": "sostare",
    "sostaron": "sostare",
    "sostarono": "sostare",
    "sostasse": "sostare",
    "sostasser": "sostare",
    "sostassero": "sostare",
    "sostassi": "sostare",
    "sostassimo": "sostare",
    "sostaste": "sostare",
    "sostasti": "sostare",
    "sostata": "sostare",
    "sostate": "sostare",
    "sostati": "sostare",
    "sostato": "sostare",
    "sostava": "sostare",
    "sostavamo": "sostare",
    "sostavan": "sostare",
    "sostavano": "sostare",
    "sostavate": "sostare",
    "sostavi": "sostare",
    "sostavo": "sostare",
    "soste": "sosta",
    "sostegni": "sostegno",
    "sostenemmo": "sostenere",
    "sostenendo": "sostenere",
    "sostenente": "sostenere",
    "sostenenti": "sostenere",
    "sostener": "sostenere",
    "sostenesse": "sostenere",
    "sostenesser": "sostenere",
    "sostenessero": "sostenere",
    "sostenessi": "sostenere",
    "sostenessimo": "sostenere",
    "sosteneste": "sostenere",
    "sostenesti": "sostenere",
    "sostenete": "sostenere",
    "sosteneva": "sostenere",
    "sostenevamo": "sostenere",
    "sostenevan": "sostenere",
    "sostenevano": "sostenere",
    "sostenevate": "sostenere",
    "sostenevi": "sostenere",
    "sostenevo": "sostenere",
    "sostenga": "sostenere",
    "sostengan": "sostenere",
    "sostengano": "sostenere",
    "sostengo": "sostenere",
    "sostengon": "sostenere",
    "sostengono": "sostenere",
    "sosteniamo": "sostenere",
    "sosteniate": "sostenere",
    "sostenibili": "sostenibile",
    "sostenitori": "sostenitore",
    "sostenitrice": "sostenitore",
    "sostenitrici": "sostenitrice",
    "sostenne": "sostenere",
    "sostenner": "sostenere",
    "sostennero": "sostenere",
    "sostenni": "sostenere",
    "sostenta": "sostentare",
    "sostentai": "sostentare",
    "sostentamenti": "sostentamento",
    "sostentammo": "sostentare",
    "sostentan": "sostentare",
    "sostentando": "sostentare",
    "sostentano": "sostentare",
    "sostentante": "sostentare",
    "sostentanti": "sostentare",
    "sostentar": "sostentare",
    "sostentaron": "sostentare",
    "sostentarono": "sostentare",
    "sostentasse": "sostentare",
    "sostentasser": "sostentare",
    "sostentassero": "sostentare",
    "sostentassi": "sostentare",
    "sostentassimo": "sostentare",
    "sostentaste": "sostentare",
    "sostentasti": "sostentare",
    "sostentata": "sostentare",
    "sostentate": "sostentare",
    "sostentati": "sostentare",
    "sostentato": "sostentare",
    "sostentava": "sostentare",
    "sostentavamo": "sostentare",
    "sostentavan": "sostentare",
    "sostentavano": "sostentare",
    "sostentavate": "sostentare",
    "sostentavi": "sostentare",
    "sostentavo": "sostentare",
    "sostenterai": "sostentare",
    "sostenteran": "sostentare",
    "sostenteranno": "sostentare",
    "sostenterebbe": "sostentare",
    "sostenterebber": "sostentare",
    "sostenterebbero": "sostentare",
    "sostenterei": "sostentare",
    "sostenteremmo": "sostentare",
    "sostenteremo": "sostentare",
    "sostentereste": "sostentare",
    "sostenteresti": "sostentare",
    "sostenterete": "sostentare",
    "sostenterà": "sostentare",
    "sostenterò": "sostentare",
    "sostenti": "sostentare",
    "sostentiamo": "sostentare",
    "sostentiate": "sostentare",
    "sostentin": "sostentare",
    "sostentino": "sostentare",
    "sostento": "sostentare",
    "sostentò": "sostentare",
    "sostenuta": "sostenuto",
    "sostenute": "sostenuto",
    "sostenuti": "sostenuto",
    "sostenuto": "sostenere",
    "sosterai": "sostare",
    "sosteran": "sostare",
    "sosteranno": "sostare",
    "sosterebbe": "sostare",
    "sosterebber": "sostare",
    "sosterebbero": "sostare",
    "sosterei": "sostare",
    "sosteremmo": "sostare",
    "sosteremo": "sostare",
    "sostereste": "sostare",
    "sosteresti": "sostare",
    "sosterete": "sostare",
    "sosterrai": "sostenere",
    "sosterran": "sostenere",
    "sosterranno": "sostenere",
    "sosterrebbe": "sostenere",
    "sosterrebber": "sostenere",
    "sosterrebbero": "sostenere",
    "sosterrei": "sostenere",
    "sosterremmo": "sostenere",
    "sosterremo": "sostenere",
    "sosterreste": "sostenere",
    "sosterresti": "sostenere",
    "sosterrete": "sostenere",
    "sosterrà": "sostenere",
    "sosterrò": "sostenere",
    "sosterà": "sostare",
    "sosterò": "sostare",
    "sosti": "sostare",
    "sostiamo": "sostare",
    "sostiate": "sostare",
    "sostiene": "sostenere",
    "sostieni": "sostenere",
    "sostin": "sostare",
    "sostino": "sostare",
    "sostituendo": "sostituire",
    "sostituente": "sostituire",
    "sostituenti": "sostituire",
    "sostituiamo": "sostituire",
    "sostituiate": "sostituire",
    "sostituibili": "sostituibile",
    "sostituii": "sostituire",
    "sostituimmo": "sostituire",
    "sostituir": "sostituire",
    "sostituirai": "sostituire",
    "sostituiran": "sostituire",
    "sostituiranno": "sostituire",
    "sostituirebbe": "sostituire",
    "sostituirebber": "sostituire",
    "sostituirebbero": "sostituire",
    "sostituirei": "sostituire",
    "sostituiremmo": "sostituire",
    "sostituiremo": "sostituire",
    "sostituireste": "sostituire",
    "sostituiresti": "sostituire",
    "sostituirete": "sostituire",
    "sostituiron": "sostituire",
    "sostituirono": "sostituire",
    "sostituirà": "sostituire",
    "sostituirò": "sostituire",
    "sostituisca": "sostituire",
    "sostituiscan": "sostituire",
    "sostituiscano": "sostituire",
    "sostituisce": "sostituire",
    "sostituisci": "sostituire",
    "sostituisco": "sostituire",
    "sostituiscon": "sostituire",
    "sostituiscono": "sostituire",
    "sostituisse": "sostituire",
    "sostituisser": "sostituire",
    "sostituissero": "sostituire",
    "sostituissi": "sostituire",
    "sostituissimo": "sostituire",
    "sostituiste": "sostituire",
    "sostituisti": "sostituire",
    "sostituita": "sostituire",
    "sostituite": "sostituire",
    "sostituiti": "sostituire",
    "sostituito": "sostituire",
    "sostituiva": "sostituire",
    "sostituivamo": "sostituire",
    "sostituivan": "sostituire",
    "sostituivano": "sostituire",
    "sostituivate": "sostituire",
    "sostituivi": "sostituire",
    "sostituivo": "sostituire",
    "sostituti": "sostituto",
    "sostitutiva": "sostitutivo",
    "sostitutive": "sostitutivo",
    "sostitutivi": "sostitutivo",
    "sostituzioni": "sostituzione",
    "sostituì": "sostituire",
    "sosto": "sostare",
    "sostrati": "sostrato",
    "sostò": "sostare",
    "sott'": "sotto",
    "sottaccia": "sottacere",
    "sottacciano": "sottacere",
    "sottaccio": "sottacere",
    "sottacciono": "sottacere",
    "sottace": "sottacere",
    "sottacemmo": "sottacere",
    "sottacente": "sottacere",
    "sottacenti": "sottacere",
    "sottacerai": "sottacere",
    "sottaceranno": "sottacere",
    "sottacerebbe": "sottacere",
    "sottacerebbero": "sottacere",
    "sottacerei": "sottacere",
    "sottaceremmo": "sottacere",
    "sottaceremo": "sottacere",
    "sottacereste": "sottacere",
    "sottaceresti": "sottacere",
    "sottacerete": "sottacere",
    "sottacerà": "sottacere",
    "sottacerò": "sottacere",
    "sottacesse": "sottacere",
    "sottacessero": "sottacere",
    "sottacessi": "sottacere",
    "sottacessimo": "sottacere",
    "sottaceste": "sottacere",
    "sottacesti": "sottacere",
    "sottacete": "sottacere",
    "sottaceva": "sottacere",
    "sottacevamo": "sottacere",
    "sottacevano": "sottacere",
    "sottacevate": "sottacere",
    "sottacevi": "sottacere",
    "sottacevo": "sottacere",
    "sottaci": "sottacere",
    "sottaciamo": "sottacere",
    "sottaciate": "sottacere",
    "sottaciuta": "sottacere",
    "sottaciute": "sottacere",
    "sottaciuti": "sottacere",
    "sottaciuto": "sottacere",
    "sottacque": "sottacere",
    "sottacquero": "sottacere",
    "sottacqui": "sottacere",
    "sottana": "sottano",
    "sottane": "sottano",
    "sottani": "sottano",
    "sottenda": "sottendere",
    "sottendan": "sottendere",
    "sottendano": "sottendere",
    "sottende": "sottendere",
    "sottendemmo": "sottendere",
    "sottendendo": "sottendere",
    "sottendente": "sottendere",
    "sottendenti": "sottendere",
    "sottender": "sottendere",
    "sottenderai": "sottendere",
    "sottenderan": "sottendere",
    "sottenderanno": "sottendere",
    "sottenderebbe": "sottendere",
    "sottenderebber": "sottendere",
    "sottenderebbero": "sottendere",
    "sottenderei": "sottendere",
    "sottenderemmo": "sottendere",
    "sottenderemo": "sottendere",
    "sottendereste": "sottendere",
    "sottenderesti": "sottendere",
    "sottenderete": "sottendere",
    "sottenderà": "sottendere",
    "sottenderò": "sottendere",
    "sottendesse": "sottendere",
    "sottendesser": "sottendere",
    "sottendessero": "sottendere",
    "sottendessi": "sottendere",
    "sottendessimo": "sottendere",
    "sottendeste": "sottendere",
    "sottendesti": "sottendere",
    "sottendete": "sottendere",
    "sottendeva": "sottendere",
    "sottendevamo": "sottendere",
    "sottendevan": "sottendere",
    "sottendevano": "sottendere",
    "sottendevate": "sottendere",
    "sottendevi": "sottendere",
    "sottendevo": "sottendere",
    "sottendi": "sottendere",
    "sottendiamo": "sottendere",
    "sottendiate": "sottendere",
    "sottendo": "sottendere",
    "sottendon": "sottendere",
    "sottendono": "sottendere",
    "sottentra": "sottentrare",
    "sottentrai": "sottentrare",
    "sottentrammo": "sottentrare",
    "sottentran": "sottentrare",
    "sottentrando": "sottentrare",
    "sottentrano": "sottentrare",
    "sottentrante": "sottentrare",
    "sottentranti": "sottentrare",
    "sottentrar": "sottentrare",
    "sottentraron": "sottentrare",
    "sottentrarono": "sottentrare",
    "sottentrasse": "sottentrare",
    "sottentrasser": "sottentrare",
    "sottentrassero": "sottentrare",
    "sottentrassi": "sottentrare",
    "sottentrassimo": "sottentrare",
    "sottentraste": "sottentrare",
    "sottentrasti": "sottentrare",
    "sottentrata": "sottentrare",
    "sottentrate": "sottentrare",
    "sottentrati": "sottentrare",
    "sottentrato": "sottentrare",
    "sottentrava": "sottentrare",
    "sottentravamo": "sottentrare",
    "sottentravan": "sottentrare",
    "sottentravano": "sottentrare",
    "sottentravate": "sottentrare",
    "sottentravi": "sottentrare",
    "sottentravo": "sottentrare",
    "sottentrerai": "sottentrare",
    "sottentreran": "sottentrare",
    "sottentreranno": "sottentrare",
    "sottentrerebbe": "sottentrare",
    "sottentrerebber": "sottentrare",
    "sottentrerebbero": "sottentrare",
    "sottentrerei": "sottentrare",
    "sottentreremmo": "sottentrare",
    "sottentreremo": "sottentrare",
    "sottentrereste": "sottentrare",
    "sottentreresti": "sottentrare",
    "sottentrerete": "sottentrare",
    "sottentrerà": "sottentrare",
    "sottentrerò": "sottentrare",
    "sottentri": "sottentrare",
    "sottentriamo": "sottentrare",
    "sottentriate": "sottentrare",
    "sottentrin": "sottentrare",
    "sottentrino": "sottentrare",
    "sottentro": "sottentrare",
    "sottentrò": "sottentrare",
    "sotterfugi": "sotterfugio",
    "sotterra": "sotterrare",
    "sotterrai": "sotterrare",
    "sotterrammo": "sotterrare",
    "sotterran": "sotterrare",
    "sotterrando": "sotterrare",
    "sotterranea": "sotterraneo",
    "sotterranee": "sotterraneo",
    "sotterranei": "sotterraneo",
    "sotterrano": "sotterrare",
    "sotterrante": "sotterrare",
    "sotterranti": "sotterrare",
    "sotterrar": "sotterrare",
    "sotterraron": "sotterrare",
    "sotterrarono": "sotterrare",
    "sotterrasse": "sotterrare",
    "sotterrasser": "sotterrare",
    "sotterrassero": "sotterrare",
    "sotterrassi": "sotterrare",
    "sotterrassimo": "sotterrare",
    "sotterraste": "sotterrare",
    "sotterrasti": "sotterrare",
    "sotterrata": "sotterrare",
    "sotterrate": "sotterrare",
    "sotterrati": "sotterrare",
    "sotterrato": "sotterrare",
    "sotterrava": "sotterrare",
    "sotterravamo": "sotterrare",
    "sotterravan": "sotterrare",
    "sotterravano": "sotterrare",
    "sotterravate": "sotterrare",
    "sotterravi": "sotterrare",
    "sotterravo": "sotterrare",
    "sotterrerai": "sotterrare",
    "sotterreran": "sotterrare",
    "sotterreranno": "sotterrare",
    "sotterrerebbe": "sotterrare",
    "sotterrerebber": "sotterrare",
    "sotterrerebbero": "sotterrare",
    "sotterrerei": "sotterrare",
    "sotterreremmo": "sotterrare",
    "sotterreremo": "sotterrare",
    "sotterrereste": "sotterrare",
    "sotterreresti": "sotterrare",
    "sotterrerete": "sotterrare",
    "sotterrerà": "sotterrare",
    "sotterrerò": "sotterrare",
    "sotterri": "sotterrare",
    "sotterriamo": "sotterrare",
    "sotterriate": "sotterrare",
    "sotterrin": "sotterrare",
    "sotterrino": "sotterrare",
    "sotterro": "sotterrare",
    "sotterrò": "sotterrare",
    "sottesa": "sotteso",
    "sottese": "sotteso",
    "sotteser": "sottendere",
    "sottesero": "sottendere",
    "sottesi": "sotteso",
    "sotteso": "sottendere",
    "sottesè": "sottendere",
    "sottigliezze": "sottigliezza",
    "sottili": "sottile",
    "sottilizza": "sottilizzare",
    "sottilizzai": "sottilizzare",
    "sottilizzammo": "sottilizzare",
    "sottilizzan": "sottilizzare",
    "sottilizzando": "sottilizzare",
    "sottilizzano": "sottilizzare",
    "sottilizzante": "sottilizzare",
    "sottilizzanti": "sottilizzare",
    "sottilizzar": "sottilizzare",
    "sottilizzaron": "sottilizzare",
    "sottilizzarono": "sottilizzare",
    "sottilizzasse": "sottilizzare",
    "sottilizzasser": "sottilizzare",
    "sottilizzassero": "sottilizzare",
    "sottilizzassi": "sottilizzare",
    "sottilizzassimo": "sottilizzare",
    "sottilizzaste": "sottilizzare",
    "sottilizzasti": "sottilizzare",
    "sottilizzata": "sottilizzare",
    "sottilizzate": "sottilizzare",
    "sottilizzati": "sottilizzare",
    "sottilizzato": "sottilizzare",
    "sottilizzava": "sottilizzare",
    "sottilizzavamo": "sottilizzare",
    "sottilizzavan": "sottilizzare",
    "sottilizzavano": "sottilizzare",
    "sottilizzavate": "sottilizzare",
    "sottilizzavi": "sottilizzare",
    "sottilizzavo": "sottilizzare",
    "sottilizzerai": "sottilizzare",
    "sottilizzeran": "sottilizzare",
    "sottilizzeranno": "sottilizzare",
    "sottilizzerebbe": "sottilizzare",
    "sottilizzerebber": "sottilizzare",
    "sottilizzerebbero": "sottilizzare",
    "sottilizzerei": "sottilizzare",
    "sottilizzeremmo": "sottilizzare",
    "sottilizzeremo": "sottilizzare",
    "sottilizzereste": "sottilizzare",
    "sottilizzeresti": "sottilizzare",
    "sottilizzerete": "sottilizzare",
    "sottilizzerà": "sottilizzare",
    "sottilizzerò": "sottilizzare",
    "sottilizzi": "sottilizzare",
    "sottilizziamo": "sottilizzare",
    "sottilizziate": "sottilizzare",
    "sottilizzin": "sottilizzare",
    "sottilizzino": "sottilizzare",
    "sottilizzo": "sottilizzare",
    "sottilizzò": "sottilizzare",
    "sottintenda": "sottintendere",
    "sottintendan": "sottintendere",
    "sottintendano": "sottintendere",
    "sottintende": "sottintendere",
    "sottintendemmo": "sottintendere",
    "sottintendendo": "sottintendere",
    "sottintendente": "sottintendere",
    "sottintendenti": "sottintendere",
    "sottintender": "sottintendere",
    "sottintenderai": "sottintendere",
    "sottintenderan": "sottintendere",
    "sottintenderanno": "sottintendere",
    "sottintenderebbe": "sottintendere",
    "sottintenderebber": "sottintendere",
    "sottintenderebbero": "sottintendere",
    "sottintenderei": "sottintendere",
    "sottintenderemmo": "sottintendere",
    "sottintenderemo": "sottintendere",
    "sottintendereste": "sottintendere",
    "sottintenderesti": "sottintendere",
    "sottintenderete": "sottintendere",
    "sottintenderà": "sottintendere",
    "sottintenderò": "sottintendere",
    "sottintendesse": "sottintendere",
    "sottintendesser": "sottintendere",
    "sottintendessero": "sottintendere",
    "sottintendessi": "sottintendere",
    "sottintendessimo": "sottintendere",
    "sottintendeste": "sottintendere",
    "sottintendesti": "sottintendere",
    "sottintendete": "sottintendere",
    "sottintendeva": "sottintendere",
    "sottintendevamo": "sottintendere",
    "sottintendevan": "sottintendere",
    "sottintendevano": "sottintendere",
    "sottintendevate": "sottintendere",
    "sottintendevi": "sottintendere",
    "sottintendevo": "sottintendere",
    "sottintendi": "sottintendere",
    "sottintendiamo": "sottintendere",
    "sottintendiate": "sottintendere",
    "sottintendo": "sottintendere",
    "sottintendon": "sottintendere",
    "sottintendono": "sottintendere",
    "sottintesa": "sottinteso",
    "sottintese": "sottinteso",
    "sottinteser": "sottintendere",
    "sottintesero": "sottintendere",
    "sottintesi": "sottinteso",
    "sottinteso": "sottintendere",
    "sottintesè": "sottintendere",
    "sotto-capi": "sotto-capo",
    "sottoboschi": "sottobosco",
    "sottocapi": "sottocapo",
    "sottocapitalizzazioni": "sottocapitalizzazione",
    "sottocommissioni": "sottocommissione",
    "sottocorrenti": "sottocorrente",
    "sottocosta": "sottocosto",
    "sottocoste": "sottocosto",
    "sottocosti": "sottocosto",
    "sottoculture": "sottocultura",
    "sottocutanea": "sottocutaneo",
    "sottocutanee": "sottocutaneo",
    "sottocutanei": "sottocutaneo",
    "sottofondi": "sottofondo",
    "sottogeneri": "sottogenere",
    "sottogonne": "sottogonna",
    "sottogoverni": "sottogoverno",
    "sottolinea": "sottolineare",
    "sottolineai": "sottolineare",
    "sottolineammo": "sottolineare",
    "sottolinean": "sottolineare",
    "sottolineando": "sottolineare",
    "sottolineano": "sottolineare",
    "sottolineante": "sottolineare",
    "sottolineanti": "sottolineare",
    "sottolinear": "sottolineare",
    "sottolinearon": "sottolineare",
    "sottolinearono": "sottolineare",
    "sottolineasse": "sottolineare",
    "sottolineasser": "sottolineare",
    "sottolineassero": "sottolineare",
    "sottolineassi": "sottolineare",
    "sottolineassimo": "sottolineare",
    "sottolineaste": "sottolineare",
    "sottolineasti": "sottolineare",
    "sottolineata": "sottolineare",
    "sottolineate": "sottolineare",
    "sottolineati": "sottolineare",
    "sottolineato": "sottolineare",
    "sottolineature": "sottolineatura",
    "sottolineava": "sottolineare",
    "sottolineavamo": "sottolineare",
    "sottolineavan": "sottolineare",
    "sottolineavano": "sottolineare",
    "sottolineavate": "sottolineare",
    "sottolineavi": "sottolineare",
    "sottolineavo": "sottolineare",
    "sottolineerai": "sottolineare",
    "sottolineeran": "sottolineare",
    "sottolineeranno": "sottolineare",
    "sottolineerebbe": "sottolineare",
    "sottolineerebber": "sottolineare",
    "sottolineerebbero": "sottolineare",
    "sottolineerei": "sottolineare",
    "sottolineeremmo": "sottolineare",
    "sottolineeremo": "sottolineare",
    "sottolineereste": "sottolineare",
    "sottolineeresti": "sottolineare",
    "sottolineerete": "sottolineare",
    "sottolineerà": "sottolineare",
    "sottolineerò": "sottolineare",
    "sottolinei": "sottolineare",
    "sottolineiamo": "sottolineare",
    "sottolineiate": "sottolineare",
    "sottolinein": "sottolineare",
    "sottolineino": "sottolineare",
    "sottolineo": "sottolineare",
    "sottolineò": "sottolineare",
    "sottomarina": "sottomarino",
    "sottomarine": "sottomarino",
    "sottomarini": "sottomarino",
    "sottomessa": "sottomettere",
    "sottomesse": "sottomettere",
    "sottomessi": "sottomettere",
    "sottomesso": "sottomettere",
    "sottometta": "sottomettere",
    "sottomettan": "sottomettere",
    "sottomettano": "sottomettere",
    "sottomette": "sottomettere",
    "sottomettemmo": "sottomettere",
    "sottomettendo": "sottomettere",
    "sottomettente": "sottomettere",
    "sottomettenti": "sottomettere",
    "sottometter": "sottomettere",
    "sottometterai": "sottomettere",
    "sottometteran": "sottomettere",
    "sottometteranno": "sottomettere",
    "sottometterebbe": "sottomettere",
    "sottometterebber": "sottomettere",
    "sottometterebbero": "sottomettere",
    "sottometterei": "sottomettere",
    "sottometteremmo": "sottomettere",
    "sottometteremo": "sottomettere",
    "sottomettereste": "sottomettere",
    "sottometteresti": "sottomettere",
    "sottometterete": "sottomettere",
    "sottometterà": "sottomettere",
    "sottometterò": "sottomettere",
    "sottomettesse": "sottomettere",
    "sottomettesser": "sottomettere",
    "sottomettessero": "sottomettere",
    "sottomettessi": "sottomettere",
    "sottomettessimo": "sottomettere",
    "sottometteste": "sottomettere",
    "sottomettesti": "sottomettere",
    "sottomettete": "sottomettere",
    "sottometteva": "sottomettere",
    "sottomettevamo": "sottomettere",
    "sottomettevan": "sottomettere",
    "sottomettevano": "sottomettere",
    "sottomettevate": "sottomettere",
    "sottomettevi": "sottomettere",
    "sottomettevo": "sottomettere",
    "sottometti": "sottomettere",
    "sottomettiamo": "sottomettere",
    "sottomettiate": "sottomettere",
    "sottometto": "sottomettere",
    "sottometton": "sottomettere",
    "sottomettono": "sottomettere",
    "sottomise": "sottomettere",
    "sottomiser": "sottomettere",
    "sottomisero": "sottomettere",
    "sottomisi": "sottomettere",
    "sottomissioni": "sottomissione",
    "sottopaga": "sottopagare",
    "sottopagai": "sottopagare",
    "sottopagammo": "sottopagare",
    "sottopagan": "sottopagare",
    "sottopagando": "sottopagare",
    "sottopagano": "sottopagare",
    "sottopagante": "sottopagare",
    "sottopaganti": "sottopagare",
    "sottopagar": "sottopagare",
    "sottopagaron": "sottopagare",
    "sottopagarono": "sottopagare",
    "sottopagasse": "sottopagare",
    "sottopagasser": "sottopagare",
    "sottopagassero": "sottopagare",
    "sottopagassi": "sottopagare",
    "sottopagassimo": "sottopagare",
    "sottopagaste": "sottopagare",
    "sottopagasti": "sottopagare",
    "sottopagata": "sottopagare",
    "sottopagate": "sottopagare",
    "sottopagati": "sottopagare",
    "sottopagato": "sottopagare",
    "sottopagava": "sottopagare",
    "sottopagavamo": "sottopagare",
    "sottopagavan": "sottopagare",
    "sottopagavano": "sottopagare",
    "sottopagavate": "sottopagare",
    "sottopagavi": "sottopagare",
    "sottopagavo": "sottopagare",
    "sottopagherai": "sottopagare",
    "sottopagheran": "sottopagare",
    "sottopagheranno": "sottopagare",
    "sottopagherebbe": "sottopagare",
    "sottopagherebber": "sottopagare",
    "sottopagherebbero": "sottopagare",
    "sottopagherei": "sottopagare",
    "sottopagheremmo": "sottopagare",
    "sottopagheremo": "sottopagare",
    "sottopaghereste": "sottopagare",
    "sottopagheresti": "sottopagare",
    "sottopagherete": "sottopagare",
    "sottopagherà": "sottopagare",
    "sottopagherò": "sottopagare",
    "sottopaghi": "sottopagare",
    "sottopaghiamo": "sottopagare",
    "sottopaghiate": "sottopagare",
    "sottopaghin": "sottopagare",
    "sottopaghino": "sottopagare",
    "sottopago": "sottopagare",
    "sottopagò": "sottopagare",
    "sottopassaggi": "sottopassaggio",
    "sottopassi": "sottopasso",
    "sottopone": "sottoporre",
    "sottoponemmo": "sottoporre",
    "sottoponendo": "sottoporre",
    "sottoponente": "sottoporre",
    "sottoponenti": "sottoporre",
    "sottoponesse": "sottoporre",
    "sottoponesser": "sottoporre",
    "sottoponessero": "sottoporre",
    "sottoponessi": "sottoporre",
    "sottoponessimo": "sottoporre",
    "sottoponeste": "sottoporre",
    "sottoponesti": "sottoporre",
    "sottoponete": "sottoporre",
    "sottoponeva": "sottoporre",
    "sottoponevamo": "sottoporre",
    "sottoponevan": "sottoporre",
    "sottoponevano": "sottoporre",
    "sottoponevate": "sottoporre",
    "sottoponevi": "sottoporre",
    "sottoponevo": "sottoporre",
    "sottoponga": "sottoporre",
    "sottopongan": "sottoporre",
    "sottopongano": "sottoporre",
    "sottopongo": "sottoporre",
    "sottopongon": "sottoporre",
    "sottopongono": "sottoporre",
    "sottoponi": "sottoporre",
    "sottoponiamo": "sottoporre",
    "sottoponiate": "sottoporre",
    "sottoporr": "sottoporre",
    "sottoporrai": "sottoporre",
    "sottoporran": "sottoporre",
    "sottoporranno": "sottoporre",
    "sottoporrebbe": "sottoporre",
    "sottoporrebber": "sottoporre",
    "sottoporrebbero": "sottoporre",
    "sottoporrei": "sottoporre",
    "sottoporremmo": "sottoporre",
    "sottoporremo": "sottoporre",
    "sottoporreste": "sottoporre",
    "sottoporresti": "sottoporre",
    "sottoporrete": "sottoporre",
    "sottoporrà": "sottoporre",
    "sottoporrò": "sottoporre",
    "sottopose": "sottoporre",
    "sottoposer": "sottoporre",
    "sottoposero": "sottoporre",
    "sottoposi": "sottoporre",
    "sottoposta": "sottoposto",
    "sottoposte": "sottoposto",
    "sottoposti": "sottoposto",
    "sottoposto": "sottoporre",
    "sottoprodotti": "sottoprodotto",
    "sottoproletari": "sottoproletario",
    "sottoproletariati": "sottoproletariato",
    "sottorappresenta": "sottorappresentare",
    "sottorappresentai": "sottorappresentare",
    "sottorappresentammo": "sottorappresentare",
    "sottorappresentan": "sottorappresentare",
    "sottorappresentando": "sottorappresentare",
    "sottorappresentano": "sottorappresentare",
    "sottorappresentante": "sottorappresentare",
    "sottorappresentanti": "sottorappresentare",
    "sottorappresentar": "sottorappresentare",
    "sottorappresentaron": "sottorappresentare",
    "sottorappresentarono": "sottorappresentare",
    "sottorappresentasse": "sottorappresentare",
    "sottorappresentasser": "sottorappresentare",
    "sottorappresentassero": "sottorappresentare",
    "sottorappresentassi": "sottorappresentare",
    "sottorappresentassimo": "sottorappresentare",
    "sottorappresentaste": "sottorappresentare",
    "sottorappresentasti": "sottorappresentare",
    "sottorappresentata": "sottorappresentare",
    "sottorappresentate": "sottorappresentare",
    "sottorappresentati": "sottorappresentare",
    "sottorappresentato": "sottorappresentare",
    "sottorappresentava": "sottorappresentare",
    "sottorappresentavamo": "sottorappresentare",
    "sottorappresentavan": "sottorappresentare",
    "sottorappresentavano": "sottorappresentare",
    "sottorappresentavate": "sottorappresentare",
    "sottorappresentavi": "sottorappresentare",
    "sottorappresentavo": "sottorappresentare",
    "sottorappresenterai": "sottorappresentare",
    "sottorappresenteran": "sottorappresentare",
    "sottorappresenteranno": "sottorappresentare",
    "sottorappresenterebbe": "sottorappresentare",
    "sottorappresenterebber": "sottorappresentare",
    "sottorappresenterebbero": "sottorappresentare",
    "sottorappresenterei": "sottorappresentare",
    "sottorappresenteremmo": "sottorappresentare",
    "sottorappresenteremo": "sottorappresentare",
    "sottorappresentereste": "sottorappresentare",
    "sottorappresenteresti": "sottorappresentare",
    "sottorappresenterete": "sottorappresentare",
    "sottorappresenterà": "sottorappresentare",
    "sottorappresenterò": "sottorappresentare",
    "sottorappresenti": "sottorappresentare",
    "sottorappresentiamo": "sottorappresentare",
    "sottorappresentiate": "sottorappresentare",
    "sottorappresentin": "sottorappresentare",
    "sottorappresentino": "sottorappresentare",
    "sottorappresento": "sottorappresentare",
    "sottorappresentò": "sottorappresentare",
    "sottoscrisse": "sottoscrivere",
    "sottoscrisser": "sottoscrivere",
    "sottoscrissero": "sottoscrivere",
    "sottoscrissi": "sottoscrivere",
    "sottoscritta": "sottoscrivere",
    "sottoscritte": "sottoscrivere",
    "sottoscritti": "sottoscrivere",
    "sottoscritto": "sottoscrivere",
    "sottoscrittori": "sottoscrittore",
    "sottoscriva": "sottoscrivere",
    "sottoscrivan": "sottoscrivere",
    "sottoscrivano": "sottoscrivere",
    "sottoscrive": "sottoscrivere",
    "sottoscrivemmo": "sottoscrivere",
    "sottoscrivendo": "sottoscrivere",
    "sottoscrivente": "sottoscrivere",
    "sottoscriventi": "sottoscrivere",
    "sottoscriver": "sottoscrivere",
    "sottoscriverai": "sottoscrivere",
    "sottoscriveran": "sottoscrivere",
    "sottoscriveranno": "sottoscrivere",
    "sottoscriverebbe": "sottoscrivere",
    "sottoscriverebber": "sottoscrivere",
    "sottoscriverebbero": "sottoscrivere",
    "sottoscriverei": "sottoscrivere",
    "sottoscriveremmo": "sottoscrivere",
    "sottoscriveremo": "sottoscrivere",
    "sottoscrivereste": "sottoscrivere",
    "sottoscriveresti": "sottoscrivere",
    "sottoscriverete": "sottoscrivere",
    "sottoscriverà": "sottoscrivere",
    "sottoscriverò": "sottoscrivere",
    "sottoscrivesse": "sottoscrivere",
    "sottoscrivesser": "sottoscrivere",
    "sottoscrivessero": "sottoscrivere",
    "sottoscrivessi": "sottoscrivere",
    "sottoscrivessimo": "sottoscrivere",
    "sottoscriveste": "sottoscrivere",
    "sottoscrivesti": "sottoscrivere",
    "sottoscrivete": "sottoscrivere",
    "sottoscriveva": "sottoscrivere",
    "sottoscrivevamo": "sottoscrivere",
    "sottoscrivevan": "sottoscrivere",
    "sottoscrivevano": "sottoscrivere",
    "sottoscrivevate": "sottoscrivere",
    "sottoscrivevi": "sottoscrivere",
    "sottoscrivevo": "sottoscrivere",
    "sottoscrivi": "sottoscrivere",
    "sottoscriviamo": "sottoscrivere",
    "sottoscriviate": "sottoscrivere",
    "sottoscrivo": "sottoscrivere",
    "sottoscrivon": "sottoscrivere",
    "sottoscrivono": "sottoscrivere",
    "sottoscrizioni": "sottoscrizione",
    "sottosegretari": "sottosegretario",
    "sottosegretariati": "sottosegretariato",
    "sottosta": "sottostare",
    "sottosta'": "sottostare",
    "sottostai": "sottostare",
    "sottostammo": "sottostare",
    "sottostan": "sottostare",
    "sottostando": "sottostare",
    "sottostanno": "sottostare",
    "sottostante": "sottostare",
    "sottostanti": "sottostare",
    "sottostar": "sottostare",
    "sottostarai": "sottostare",
    "sottostaran": "sottostare",
    "sottostaranno": "sottostare",
    "sottostarebbe": "sottostare",
    "sottostarebber": "sottostare",
    "sottostarebbero": "sottostare",
    "sottostarei": "sottostare",
    "sottostaremmo": "sottostare",
    "sottostaremo": "sottostare",
    "sottostareste": "sottostare",
    "sottostaresti": "sottostare",
    "sottostarete": "sottostare",
    "sottostaron": "sottostare",
    "sottostarono": "sottostare",
    "sottostarà": "sottostare",
    "sottostarò": "sottostare",
    "sottostaste": "sottostare",
    "sottostata": "sottostare",
    "sottostate": "sottostare",
    "sottostati": "sottostare",
    "sottostato": "sottostare",
    "sottostava": "sottostare",
    "sottostavamo": "sottostare",
    "sottostavan": "sottostare",
    "sottostavano": "sottostare",
    "sottostavate": "sottostare",
    "sottostavi": "sottostare",
    "sottostavo": "sottostare",
    "sottostesse": "sottostare",
    "sottostesser": "sottostare",
    "sottostessero": "sottostare",
    "sottostessi": "sottostare",
    "sottostessimo": "sottostare",
    "sottosteste": "sottostare",
    "sottostesti": "sottostare",
    "sottostette": "sottostare",
    "sottostetti": "sottostare",
    "sottostia": "sottostare",
    "sottostiamo": "sottostare",
    "sottostian": "sottostare",
    "sottostiano": "sottostare",
    "sottostiate": "sottostare",
    "sottostima": "sottostimare",
    "sottostimai": "sottostimare",
    "sottostimammo": "sottostimare",
    "sottostiman": "sottostimare",
    "sottostimando": "sottostimare",
    "sottostimano": "sottostimare",
    "sottostimante": "sottostimare",
    "sottostimanti": "sottostimare",
    "sottostimar": "sottostimare",
    "sottostimaron": "sottostimare",
    "sottostimarono": "sottostimare",
    "sottostimasse": "sottostimare",
    "sottostimasser": "sottostimare",
    "sottostimassero": "sottostimare",
    "sottostimassi": "sottostimare",
    "sottostimassimo": "sottostimare",
    "sottostimaste": "sottostimare",
    "sottostimasti": "sottostimare",
    "sottostimata": "sottostimare",
    "sottostimate": "sottostimare",
    "sottostimati": "sottostimare",
    "sottostimato": "sottostimare",
    "sottostimava": "sottostimare",
    "sottostimavamo": "sottostimare",
    "sottostimavan": "sottostimare",
    "sottostimavano": "sottostimare",
    "sottostimavate": "sottostimare",
    "sottostimavi": "sottostimare",
    "sottostimavo": "sottostimare",
    "sottostimerai": "sottostimare",
    "sottostimeran": "sottostimare",
    "sottostimeranno": "sottostimare",
    "sottostimerebbe": "sottostimare",
    "sottostimerebber": "sottostimare",
    "sottostimerebbero": "sottostimare",
    "sottostimerei": "sottostimare",
    "sottostimeremmo": "sottostimare",
    "sottostimeremo": "sottostimare",
    "sottostimereste": "sottostimare",
    "sottostimeresti": "sottostimare",
    "sottostimerete": "sottostimare",
    "sottostimerà": "sottostimare",
    "sottostimerò": "sottostimare",
    "sottostimi": "sottostimare",
    "sottostimiamo": "sottostimare",
    "sottostimiate": "sottostimare",
    "sottostimin": "sottostimare",
    "sottostimino": "sottostimare",
    "sottostimo": "sottostimare",
    "sottostimò": "sottostimare",
    "sottosto": "sottostare",
    "sottosuoli": "sottosuolo",
    "sottosviluppata": "sottosviluppato",
    "sottosviluppate": "sottosviluppato",
    "sottosviluppati": "sottosviluppato",
    "sottosviluppi": "sottosviluppo",
    "sottotenenti": "sottotenente",
    "sottotetti": "sottotetto",
    "sottotipi": "sottotipo",
    "sottotitoli": "sottotitolo",
    "sottoufficiali": "sottoufficiale",
    "sottoutilizza": "sottoutilizzare",
    "sottoutilizzai": "sottoutilizzare",
    "sottoutilizzammo": "sottoutilizzare",
    "sottoutilizzan": "sottoutilizzare",
    "sottoutilizzando": "sottoutilizzare",
    "sottoutilizzano": "sottoutilizzare",
    "sottoutilizzante": "sottoutilizzare",
    "sottoutilizzanti": "sottoutilizzare",
    "sottoutilizzar": "sottoutilizzare",
    "sottoutilizzaron": "sottoutilizzare",
    "sottoutilizzarono": "sottoutilizzare",
    "sottoutilizzasse": "sottoutilizzare",
    "sottoutilizzasser": "sottoutilizzare",
    "sottoutilizzassero": "sottoutilizzare",
    "sottoutilizzassi": "sottoutilizzare",
    "sottoutilizzassimo": "sottoutilizzare",
    "sottoutilizzaste": "sottoutilizzare",
    "sottoutilizzasti": "sottoutilizzare",
    "sottoutilizzata": "sottoutilizzare",
    "sottoutilizzate": "sottoutilizzare",
    "sottoutilizzati": "sottoutilizzare",
    "sottoutilizzato": "sottoutilizzare",
    "sottoutilizzava": "sottoutilizzare",
    "sottoutilizzavamo": "sottoutilizzare",
    "sottoutilizzavan": "sottoutilizzare",
    "sottoutilizzavano": "sottoutilizzare",
    "sottoutilizzavate": "sottoutilizzare",
    "sottoutilizzavi": "sottoutilizzare",
    "sottoutilizzavo": "sottoutilizzare",
    "sottoutilizzerai": "sottoutilizzare",
    "sottoutilizzeran": "sottoutilizzare",
    "sottoutilizzeranno": "sottoutilizzare",
    "sottoutilizzerebbe": "sottoutilizzare",
    "sottoutilizzerebber": "sottoutilizzare",
    "sottoutilizzerebbero": "sottoutilizzare",
    "sottoutilizzerei": "sottoutilizzare",
    "sottoutilizzeremmo": "sottoutilizzare",
    "sottoutilizzeremo": "sottoutilizzare",
    "sottoutilizzereste": "sottoutilizzare",
    "sottoutilizzeresti": "sottoutilizzare",
    "sottoutilizzerete": "sottoutilizzare",
    "sottoutilizzerà": "sottoutilizzare",
    "sottoutilizzerò": "sottoutilizzare",
    "sottoutilizzi": "sottoutilizzare",
    "sottoutilizziamo": "sottoutilizzare",
    "sottoutilizziate": "sottoutilizzare",
    "sottoutilizzin": "sottoutilizzare",
    "sottoutilizzino": "sottoutilizzare",
    "sottoutilizzo": "sottoutilizzare",
    "sottoutilizzò": "sottoutilizzare",
    "sottovaluta": "sottovalutare",
    "sottovalutai": "sottovalutare",
    "sottovalutammo": "sottovalutare",
    "sottovalutan": "sottovalutare",
    "sottovalutando": "sottovalutare",
    "sottovalutano": "sottovalutare",
    "sottovalutante": "sottovalutare",
    "sottovalutanti": "sottovalutare",
    "sottovalutar": "sottovalutare",
    "sottovalutaron": "sottovalutare",
    "sottovalutarono": "sottovalutare",
    "sottovalutasse": "sottovalutare",
    "sottovalutasser": "sottovalutare",
    "sottovalutassero": "sottovalutare",
    "sottovalutassi": "sottovalutare",
    "sottovalutassimo": "sottovalutare",
    "sottovalutaste": "sottovalutare",
    "sottovalutasti": "sottovalutare",
    "sottovalutata": "sottovalutare",
    "sottovalutate": "sottovalutare",
    "sottovalutati": "sottovalutare",
    "sottovalutato": "sottovalutare",
    "sottovalutava": "sottovalutare",
    "sottovalutavamo": "sottovalutare",
    "sottovalutavan": "sottovalutare",
    "sottovalutavano": "sottovalutare",
    "sottovalutavate": "sottovalutare",
    "sottovalutavi": "sottovalutare",
    "sottovalutavo": "sottovalutare",
    "sottovalutazioni": "sottovalutazione",
    "sottovaluterai": "sottovalutare",
    "sottovaluteran": "sottovalutare",
    "sottovaluteranno": "sottovalutare",
    "sottovaluterebbe": "sottovalutare",
    "sottovaluterebber": "sottovalutare",
    "sottovaluterebbero": "sottovalutare",
    "sottovaluterei": "sottovalutare",
    "sottovaluteremmo": "sottovalutare",
    "sottovaluteremo": "sottovalutare",
    "sottovalutereste": "sottovalutare",
    "sottovaluteresti": "sottovalutare",
    "sottovaluterete": "sottovalutare",
    "sottovaluterà": "sottovalutare",
    "sottovaluterò": "sottovalutare",
    "sottovaluti": "sottovalutare",
    "sottovalutiamo": "sottovalutare",
    "sottovalutiate": "sottovalutare",
    "sottovalutin": "sottovalutare",
    "sottovalutino": "sottovalutare",
    "sottovaluto": "sottovalutare",
    "sottovalutò": "sottovalutare",
    "sottoventa": "sottovento",
    "sottovente": "sottovento",
    "sottoventi": "sottovento",
    "sottovesti": "sottoveste",
    "sottrae": "sottrarre",
    "sottraemmo": "sottrarre",
    "sottraendo": "sottrarre",
    "sottraente": "sottrarre",
    "sottraenti": "sottrarre",
    "sottraesse": "sottrarre",
    "sottraesser": "sottrarre",
    "sottraessero": "sottrarre",
    "sottraessi": "sottrarre",
    "sottraessimo": "sottrarre",
    "sottraeste": "sottrarre",
    "sottraesti": "sottrarre",
    "sottraete": "sottrarre",
    "sottraeva": "sottrarre",
    "sottraevamo": "sottrarre",
    "sottraevan": "sottrarre",
    "sottraevano": "sottrarre",
    "sottraevate": "sottrarre",
    "sottraevi": "sottrarre",
    "sottraevo": "sottrarre",
    "sottragga": "sottrarre",
    "sottraggan": "sottrarre",
    "sottraggano": "sottrarre",
    "sottraggo": "sottrarre",
    "sottraggon": "sottrarre",
    "sottraggono": "sottrarre",
    "sottrai": "sottrarre",
    "sottraiamo": "sottrarre",
    "sottraiate": "sottrarre",
    "sottrarr": "sottrarre",
    "sottrarrai": "sottrarre",
    "sottrarran": "sottrarre",
    "sottrarranno": "sottrarre",
    "sottrarrebbe": "sottrarre",
    "sottrarrebber": "sottrarre",
    "sottrarrebbero": "sottrarre",
    "sottrarrei": "sottrarre",
    "sottrarremmo": "sottrarre",
    "sottrarremo": "sottrarre",
    "sottrarreste": "sottrarre",
    "sottrarresti": "sottrarre",
    "sottrarrete": "sottrarre",
    "sottrarrà": "sottrarre",
    "sottrarrò": "sottrarre",
    "sottrasse": "sottrarre",
    "sottrasser": "sottrarre",
    "sottrassero": "sottrarre",
    "sottrassi": "sottrarre",
    "sottratta": "sottrarre",
    "sottratte": "sottrarre",
    "sottratti": "sottrarre",
    "sottratto": "sottrarre",
    "sottrazioni": "sottrazione",
    "sottufficiali": "sottufficiale",
    "soverchi": "soverchio",
    "soverchia": "soverchio",
    "soverchiai": "soverchiare",
    "soverchiammo": "soverchiare",
    "soverchiamo": "soverchiare",
    "soverchian": "soverchiare",
    "soverchiando": "soverchiare",
    "soverchiano": "soverchiare",
    "soverchiante": "soverchiare",
    "soverchianti": "soverchiare",
    "soverchiar": "soverchiare",
    "soverchiaron": "soverchiare",
    "soverchiarono": "soverchiare",
    "soverchiasse": "soverchiare",
    "soverchiasser": "soverchiare",
    "soverchiassero": "soverchiare",
    "soverchiassi": "soverchiare",
    "soverchiassimo": "soverchiare",
    "soverchiaste": "soverchiare",
    "soverchiasti": "soverchiare",
    "soverchiata": "soverchiare",
    "soverchiate": "soverchiare",
    "soverchiati": "soverchiare",
    "soverchiato": "soverchiare",
    "soverchiava": "soverchiare",
    "soverchiavamo": "soverchiare",
    "soverchiavan": "soverchiare",
    "soverchiavano": "soverchiare",
    "soverchiavate": "soverchiare",
    "soverchiavi": "soverchiare",
    "soverchiavo": "soverchiare",
    "soverchie": "soverchio",
    "soverchierai": "soverchiare",
    "soverchieran": "soverchiare",
    "soverchieranno": "soverchiare",
    "soverchierebbe": "soverchiare",
    "soverchierebber": "soverchiare",
    "soverchierebbero": "soverchiare",
    "soverchierei": "soverchiare",
    "soverchieremmo": "soverchiare",
    "soverchieremo": "soverchiare",
    "soverchiereste": "soverchiare",
    "soverchieresti": "soverchiare",
    "soverchierete": "soverchiare",
    "soverchierà": "soverchiare",
    "soverchierò": "soverchiare",
    "soverchin": "soverchiare",
    "soverchino": "soverchiare",
    "soverchio": "soverchiare",
    "soverchiò": "soverchiare",
    "sovietica": "sovietico",
    "sovietiche": "sovietico",
    "sovietici": "sovietico",
    "sovietico-americana": "sovietico-americano",
    "sovietico-americane": "sovietico-americano",
    "sovietico-americani": "sovietico-americano",
    "sovietologi": "sovietologo",
    "sovrabbonda": "sovrabbondare",
    "sovrabbondai": "sovrabbondare",
    "sovrabbondammo": "sovrabbondare",
    "sovrabbondan": "sovrabbondare",
    "sovrabbondando": "sovrabbondare",
    "sovrabbondano": "sovrabbondare",
    "sovrabbondante": "sovrabbondare",
    "sovrabbondanti": "sovrabbondare",
    "sovrabbondanze": "sovrabbondanza",
    "sovrabbondar": "sovrabbondare",
    "sovrabbondaron": "sovrabbondare",
    "sovrabbondarono": "sovrabbondare",
    "sovrabbondasse": "sovrabbondare",
    "sovrabbondasser": "sovrabbondare",
    "sovrabbondassero": "sovrabbondare",
    "sovrabbondassi": "sovrabbondare",
    "sovrabbondassimo": "sovrabbondare",
    "sovrabbondaste": "sovrabbondare",
    "sovrabbondasti": "sovrabbondare",
    "sovrabbondata": "sovrabbondare",
    "sovrabbondate": "sovrabbondare",
    "sovrabbondati": "sovrabbondare",
    "sovrabbondato": "sovrabbondare",
    "sovrabbondava": "sovrabbondare",
    "sovrabbondavamo": "sovrabbondare",
    "sovrabbondavan": "sovrabbondare",
    "sovrabbondavano": "sovrabbondare",
    "sovrabbondavate": "sovrabbondare",
    "sovrabbondavi": "sovrabbondare",
    "sovrabbondavo": "sovrabbondare",
    "sovrabbonderai": "sovrabbondare",
    "sovrabbonderan": "sovrabbondare",
    "sovrabbonderanno": "sovrabbondare",
    "sovrabbonderebbe": "sovrabbondare",
    "sovrabbonderebber": "sovrabbondare",
    "sovrabbonderebbero": "sovrabbondare",
    "sovrabbonderei": "sovrabbondare",
    "sovrabbonderemmo": "sovrabbondare",
    "sovrabbonderemo": "sovrabbondare",
    "sovrabbondereste": "sovrabbondare",
    "sovrabbonderesti": "sovrabbondare",
    "sovrabbonderete": "sovrabbondare",
    "sovrabbonderà": "sovrabbondare",
    "sovrabbonderò": "sovrabbondare",
    "sovrabbondi": "sovrabbondare",
    "sovrabbondiamo": "sovrabbondare",
    "sovrabbondiate": "sovrabbondare",
    "sovrabbondin": "sovrabbondare",
    "sovrabbondino": "sovrabbondare",
    "sovrabbondo": "sovrabbondare",
    "sovrabbondò": "sovrabbondare",
    "sovraccarica": "sovraccarico",
    "sovraccaricai": "sovraccaricare",
    "sovraccaricammo": "sovraccaricare",
    "sovraccarican": "sovraccaricare",
    "sovraccaricando": "sovraccaricare",
    "sovraccaricano": "sovraccaricare",
    "sovraccaricante": "sovraccaricare",
    "sovraccaricanti": "sovraccaricare",
    "sovraccaricar": "sovraccaricare",
    "sovraccaricaron": "sovraccaricare",
    "sovraccaricarono": "sovraccaricare",
    "sovraccaricasse": "sovraccaricare",
    "sovraccaricasser": "sovraccaricare",
    "sovraccaricassero": "sovraccaricare",
    "sovraccaricassi": "sovraccaricare",
    "sovraccaricassimo": "sovraccaricare",
    "sovraccaricaste": "sovraccaricare",
    "sovraccaricasti": "sovraccaricare",
    "sovraccaricata": "sovraccaricare",
    "sovraccaricate": "sovraccaricare",
    "sovraccaricati": "sovraccaricare",
    "sovraccaricato": "sovraccaricare",
    "sovraccaricava": "sovraccaricare",
    "sovraccaricavamo": "sovraccaricare",
    "sovraccaricavan": "sovraccaricare",
    "sovraccaricavano": "sovraccaricare",
    "sovraccaricavate": "sovraccaricare",
    "sovraccaricavi": "sovraccaricare",
    "sovraccaricavo": "sovraccaricare",
    "sovraccariche": "sovraccarico",
    "sovraccaricherai": "sovraccaricare",
    "sovraccaricheran": "sovraccaricare",
    "sovraccaricheranno": "sovraccaricare",
    "sovraccaricherebbe": "sovraccaricare",
    "sovraccaricherebber": "sovraccaricare",
    "sovraccaricherebbero": "sovraccaricare",
    "sovraccaricherei": "sovraccaricare",
    "sovraccaricheremmo": "sovraccaricare",
    "sovraccaricheremo": "sovraccaricare",
    "sovraccarichereste": "sovraccaricare",
    "sovraccaricheresti": "sovraccaricare",
    "sovraccaricherete": "sovraccaricare",
    "sovraccaricherà": "sovraccaricare",
    "sovraccaricherò": "sovraccaricare",
    "sovraccarichi": "sovraccarico",
    "sovraccarichiamo": "sovraccaricare",
    "sovraccarichiate": "sovraccaricare",
    "sovraccarichin": "sovraccaricare",
    "sovraccarichino": "sovraccaricare",
    "sovraccarici": "sovraccarico",
    "sovraccarico": "sovraccaricare",
    "sovraccaricò": "sovraccaricare",
    "sovracuti": "sovracuto",
    "sovraespone": "sovraesporre",
    "sovraesponemmo": "sovraesporre",
    "sovraesponendo": "sovraesporre",
    "sovraesponente": "sovraesporre",
    "sovraesponenti": "sovraesporre",
    "sovraesponesse": "sovraesporre",
    "sovraesponesser": "sovraesporre",
    "sovraesponessero": "sovraesporre",
    "sovraesponessi": "sovraesporre",
    "sovraesponessimo": "sovraesporre",
    "sovraesponeste": "sovraesporre",
    "sovraesponesti": "sovraesporre",
    "sovraesponete": "sovraesporre",
    "sovraesponeva": "sovraesporre",
    "sovraesponevamo": "sovraesporre",
    "sovraesponevan": "sovraesporre",
    "sovraesponevano": "sovraesporre",
    "sovraesponevate": "sovraesporre",
    "sovraesponevi": "sovraesporre",
    "sovraesponevo": "sovraesporre",
    "sovraesponga": "sovraesporre",
    "sovraespongan": "sovraesporre",
    "sovraespongano": "sovraesporre",
    "sovraespongo": "sovraesporre",
    "sovraespongon": "sovraesporre",
    "sovraespongono": "sovraesporre",
    "sovraesponi": "sovraesporre",
    "sovraesponiamo": "sovraesporre",
    "sovraesponiate": "sovraesporre",
    "sovraesporr": "sovraesporre",
    "sovraesporrai": "sovraesporre",
    "sovraesporran": "sovraesporre",
    "sovraesporranno": "sovraesporre",
    "sovraesporrebbe": "sovraesporre",
    "sovraesporrebber": "sovraesporre",
    "sovraesporrebbero": "sovraesporre",
    "sovraesporrei": "sovraesporre",
    "sovraesporremmo": "sovraesporre",
    "sovraesporremo": "sovraesporre",
    "sovraesporreste": "sovraesporre",
    "sovraesporresti": "sovraesporre",
    "sovraesporrete": "sovraesporre",
    "sovraesporrà": "sovraesporre",
    "sovraesporrò": "sovraesporre",
    "sovraespose": "sovraesporre",
    "sovraesposer": "sovraesporre",
    "sovraesposero": "sovraesporre",
    "sovraesposi": "sovraesporre",
    "sovraesposizioni": "sovraesposizione",
    "sovraesposta": "sovraesporre",
    "sovraesposte": "sovraesporre",
    "sovraesposti": "sovraesporre",
    "sovraesposto": "sovraesporre",
    "sovrafatturazioni": "sovrafatturazione",
    "sovraffatica": "sovraffaticare",
    "sovraffaticai": "sovraffaticare",
    "sovraffaticammo": "sovraffaticare",
    "sovraffatican": "sovraffaticare",
    "sovraffaticando": "sovraffaticare",
    "sovraffaticano": "sovraffaticare",
    "sovraffaticante": "sovraffaticare",
    "sovraffaticanti": "sovraffaticare",
    "sovraffaticar": "sovraffaticare",
    "sovraffaticaron": "sovraffaticare",
    "sovraffaticarono": "sovraffaticare",
    "sovraffaticasse": "sovraffaticare",
    "sovraffaticasser": "sovraffaticare",
    "sovraffaticassero": "sovraffaticare",
    "sovraffaticassi": "sovraffaticare",
    "sovraffaticassimo": "sovraffaticare",
    "sovraffaticaste": "sovraffaticare",
    "sovraffaticasti": "sovraffaticare",
    "sovraffaticata": "sovraffaticare",
    "sovraffaticate": "sovraffaticare",
    "sovraffaticati": "sovraffaticare",
    "sovraffaticato": "sovraffaticare",
    "sovraffaticava": "sovraffaticare",
    "sovraffaticavamo": "sovraffaticare",
    "sovraffaticavan": "sovraffaticare",
    "sovraffaticavano": "sovraffaticare",
    "sovraffaticavate": "sovraffaticare",
    "sovraffaticavi": "sovraffaticare",
    "sovraffaticavo": "sovraffaticare",
    "sovraffaticherai": "sovraffaticare",
    "sovraffaticheran": "sovraffaticare",
    "sovraffaticheranno": "sovraffaticare",
    "sovraffaticherebbe": "sovraffaticare",
    "sovraffaticherebber": "sovraffaticare",
    "sovraffaticherebbero": "sovraffaticare",
    "sovraffaticherei": "sovraffaticare",
    "sovraffaticheremmo": "sovraffaticare",
    "sovraffaticheremo": "sovraffaticare",
    "sovraffatichereste": "sovraffaticare",
    "sovraffaticheresti": "sovraffaticare",
    "sovraffaticherete": "sovraffaticare",
    "sovraffaticherà": "sovraffaticare",
    "sovraffaticherò": "sovraffaticare",
    "sovraffatichi": "sovraffaticare",
    "sovraffatichiamo": "sovraffaticare",
    "sovraffatichiate": "sovraffaticare",
    "sovraffatichin": "sovraffaticare",
    "sovraffatichino": "sovraffaticare",
    "sovraffatico": "sovraffaticare",
    "sovraffaticò": "sovraffaticare",
    "sovraffollamenti": "sovraffollamento",
    "sovraffollata": "sovraffollato",
    "sovraffollate": "sovraffollato",
    "sovraffollati": "sovraffollato",
    "sovraintendenti": "sovraintendente",
    "sovraintendenze": "sovraintendenza",
    "sovralimentata": "sovralimentato",
    "sovralimentate": "sovralimentato",
    "sovralimentati": "sovralimentato",
    "sovrana": "sovrano",
    "sovranazionali": "sovranazionale",
    "sovrane": "sovrano",
    "sovrani": "sovrano",
    "sovrannaturali": "sovrannaturale",
    "sovrappassi": "sovrappasso",
    "sovrappone": "sovrapporre",
    "sovrapponemmo": "sovrapporre",
    "sovrapponendo": "sovrapporre",
    "sovrapponente": "sovrapporre",
    "sovrapponenti": "sovrapporre",
    "sovrapponesse": "sovrapporre",
    "sovrapponesser": "sovrapporre",
    "sovrapponessero": "sovrapporre",
    "sovrapponessi": "sovrapporre",
    "sovrapponessimo": "sovrapporre",
    "sovrapponeste": "sovrapporre",
    "sovrapponesti": "sovrapporre",
    "sovrapponete": "sovrapporre",
    "sovrapponeva": "sovrapporre",
    "sovrapponevamo": "sovrapporre",
    "sovrapponevan": "sovrapporre",
    "sovrapponevano": "sovrapporre",
    "sovrapponevate": "sovrapporre",
    "sovrapponevi": "sovrapporre",
    "sovrapponevo": "sovrapporre",
    "sovrapponga": "sovrapporre",
    "sovrappongan": "sovrapporre",
    "sovrappongano": "sovrapporre",
    "sovrappongo": "sovrapporre",
    "sovrappongon": "sovrapporre",
    "sovrappongono": "sovrapporre",
    "sovrapponi": "sovrapporre",
    "sovrapponiamo": "sovrapporre",
    "sovrapponiate": "sovrapporre",
    "sovrapponibili": "sovrapponibile",
    "sovrappopola": "sovrappopolare",
    "sovrappopolai": "sovrappopolare",
    "sovrappopolammo": "sovrappopolare",
    "sovrappopolan": "sovrappopolare",
    "sovrappopolando": "sovrappopolare",
    "sovrappopolano": "sovrappopolare",
    "sovrappopolante": "sovrappopolare",
    "sovrappopolanti": "sovrappopolare",
    "sovrappopolar": "sovrappopolare",
    "sovrappopolaron": "sovrappopolare",
    "sovrappopolarono": "sovrappopolare",
    "sovrappopolasse": "sovrappopolare",
    "sovrappopolasser": "sovrappopolare",
    "sovrappopolassero": "sovrappopolare",
    "sovrappopolassi": "sovrappopolare",
    "sovrappopolassimo": "sovrappopolare",
    "sovrappopolaste": "sovrappopolare",
    "sovrappopolasti": "sovrappopolare",
    "sovrappopolata": "sovrappopolare",
    "sovrappopolate": "sovrappopolare",
    "sovrappopolati": "sovrappopolare",
    "sovrappopolato": "sovrappopolare",
    "sovrappopolava": "sovrappopolare",
    "sovrappopolavamo": "sovrappopolare",
    "sovrappopolavan": "sovrappopolare",
    "sovrappopolavano": "sovrappopolare",
    "sovrappopolavate": "sovrappopolare",
    "sovrappopolavi": "sovrappopolare",
    "sovrappopolavo": "sovrappopolare",
    "sovrappopolazioni": "sovrappopolazione",
    "sovrappopolerai": "sovrappopolare",
    "sovrappopoleran": "sovrappopolare",
    "sovrappopoleranno": "sovrappopolare",
    "sovrappopolerebbe": "sovrappopolare",
    "sovrappopolerebber": "sovrappopolare",
    "sovrappopolerebbero": "sovrappopolare",
    "sovrappopolerei": "sovrappopolare",
    "sovrappopoleremmo": "sovrappopolare",
    "sovrappopoleremo": "sovrappopolare",
    "sovrappopolereste": "sovrappopolare",
    "sovrappopoleresti": "sovrappopolare",
    "sovrappopolerete": "sovrappopolare",
    "sovrappopolerà": "sovrappopolare",
    "sovrappopolerò": "sovrappopolare",
    "sovrappopoli": "sovrappopolare",
    "sovrappopoliamo": "sovrappopolare",
    "sovrappopoliate": "sovrappopolare",
    "sovrappopolin": "sovrappopolare",
    "sovrappopolino": "sovrappopolare",
    "sovrappopolo": "sovrappopolare",
    "sovrappopolò": "sovrappopolare",
    "sovrapporr": "sovrapporre",
    "sovrapporrai": "sovrapporre",
    "sovrapporran": "sovrapporre",
    "sovrapporranno": "sovrapporre",
    "sovrapporrebbe": "sovrapporre",
    "sovrapporrebber": "sovrapporre",
    "sovrapporrebbero": "sovrapporre",
    "sovrapporrei": "sovrapporre",
    "sovrapporremmo": "sovrapporre",
    "sovrapporremo": "sovrapporre",
    "sovrapporreste": "sovrapporre",
    "sovrapporresti": "sovrapporre",
    "sovrapporrete": "sovrapporre",
    "sovrapporrà": "sovrapporre",
    "sovrapporrò": "sovrapporre",
    "sovrappose": "sovrapporre",
    "sovrapposer": "sovrapporre",
    "sovrapposero": "sovrapporre",
    "sovrapposi": "sovrapporre",
    "sovrapposizioni": "sovrapposizione",
    "sovrapposta": "sovrapposto",
    "sovrapposte": "sovrapposto",
    "sovrapposti": "sovrapposto",
    "sovrapposto": "sovrapporre",
    "sovrapprezzi": "sovrapprezzo",
    "sovrapproduzioni": "sovrapproduzione",
    "sovrasta": "sovrastare",
    "sovrastai": "sovrastare",
    "sovrastammo": "sovrastare",
    "sovrastampa": "sovrastampare",
    "sovrastampai": "sovrastampare",
    "sovrastampammo": "sovrastampare",
    "sovrastampan": "sovrastampare",
    "sovrastampando": "sovrastampare",
    "sovrastampano": "sovrastampare",
    "sovrastampante": "sovrastampare",
    "sovrastampanti": "sovrastampare",
    "sovrastampar": "sovrastampare",
    "sovrastamparon": "sovrastampare",
    "sovrastamparono": "sovrastampare",
    "sovrastampasse": "sovrastampare",
    "sovrastampasser": "sovrastampare",
    "sovrastampassero": "sovrastampare",
    "sovrastampassi": "sovrastampare",
    "sovrastampassimo": "sovrastampare",
    "sovrastampaste": "sovrastampare",
    "sovrastampasti": "sovrastampare",
    "sovrastampata": "sovrastampare",
    "sovrastampate": "sovrastampare",
    "sovrastampati": "sovrastampare",
    "sovrastampato": "sovrastampare",
    "sovrastampava": "sovrastampare",
    "sovrastampavamo": "sovrastampare",
    "sovrastampavan": "sovrastampare",
    "sovrastampavano": "sovrastampare",
    "sovrastampavate": "sovrastampare",
    "sovrastampavi": "sovrastampare",
    "sovrastampavo": "sovrastampare",
    "sovrastamperai": "sovrastampare",
    "sovrastamperan": "sovrastampare",
    "sovrastamperanno": "sovrastampare",
    "sovrastamperebbe": "sovrastampare",
    "sovrastamperebber": "sovrastampare",
    "sovrastamperebbero": "sovrastampare",
    "sovrastamperei": "sovrastampare",
    "sovrastamperemmo": "sovrastampare",
    "sovrastamperemo": "sovrastampare",
    "sovrastampereste": "sovrastampare",
    "sovrastamperesti": "sovrastampare",
    "sovrastamperete": "sovrastampare",
    "sovrastamperà": "sovrastampare",
    "sovrastamperò": "sovrastampare",
    "sovrastampi": "sovrastampare",
    "sovrastampiamo": "sovrastampare",
    "sovrastampiate": "sovrastampare",
    "sovrastampin": "sovrastampare",
    "sovrastampino": "sovrastampare",
    "sovrastampo": "sovrastampare",
    "sovrastampò": "sovrastampare",
    "sovrastan": "sovrastare",
    "sovrastando": "sovrastare",
    "sovrastano": "sovrastare",
    "sovrastante": "sovrastare",
    "sovrastanti": "sovrastare",
    "sovrastar": "sovrastare",
    "sovrastaron": "sovrastare",
    "sovrastarono": "sovrastare",
    "sovrastasse": "sovrastare",
    "sovrastasser": "sovrastare",
    "sovrastassero": "sovrastare",
    "sovrastassi": "sovrastare",
    "sovrastassimo": "sovrastare",
    "sovrastaste": "sovrastare",
    "sovrastasti": "sovrastare",
    "sovrastata": "sovrastare",
    "sovrastate": "sovrastare",
    "sovrastati": "sovrastare",
    "sovrastato": "sovrastare",
    "sovrastava": "sovrastare",
    "sovrastavamo": "sovrastare",
    "sovrastavan": "sovrastare",
    "sovrastavano": "sovrastare",
    "sovrastavate": "sovrastare",
    "sovrastavi": "sovrastare",
    "sovrastavo": "sovrastare",
    "sovrasterai": "sovrastare",
    "sovrasteran": "sovrastare",
    "sovrasteranno": "sovrastare",
    "sovrasterebbe": "sovrastare",
    "sovrasterebber": "sovrastare",
    "sovrasterebbero": "sovrastare",
    "sovrasterei": "sovrastare",
    "sovrasteremmo": "sovrastare",
    "sovrasteremo": "sovrastare",
    "sovrastereste": "sovrastare",
    "sovrasteresti": "sovrastare",
    "sovrasterete": "sovrastare",
    "sovrasterà": "sovrastare",
    "sovrasterò": "sovrastare",
    "sovrasti": "sovrastare",
    "sovrastiamo": "sovrastare",
    "sovrastiate": "sovrastare",
    "sovrastima": "sovrastimare",
    "sovrastimai": "sovrastimare",
    "sovrastimammo": "sovrastimare",
    "sovrastiman": "sovrastimare",
    "sovrastimando": "sovrastimare",
    "sovrastimano": "sovrastimare",
    "sovrastimante": "sovrastimare",
    "sovrastimanti": "sovrastimare",
    "sovrastimar": "sovrastimare",
    "sovrastimaron": "sovrastimare",
    "sovrastimarono": "sovrastimare",
    "sovrastimasse": "sovrastimare",
    "sovrastimasser": "sovrastimare",
    "sovrastimassero": "sovrastimare",
    "sovrastimassi": "sovrastimare",
    "sovrastimassimo": "sovrastimare",
    "sovrastimaste": "sovrastimare",
    "sovrastimasti": "sovrastimare",
    "sovrastimata": "sovrastimare",
    "sovrastimate": "sovrastimare",
    "sovrastimati": "sovrastimare",
    "sovrastimato": "sovrastimare",
    "sovrastimava": "sovrastimare",
    "sovrastimavamo": "sovrastimare",
    "sovrastimavan": "sovrastimare",
    "sovrastimavano": "sovrastimare",
    "sovrastimavate": "sovrastimare",
    "sovrastimavi": "sovrastimare",
    "sovrastimavo": "sovrastimare",
    "sovrastimerai": "sovrastimare",
    "sovrastimeran": "sovrastimare",
    "sovrastimeranno": "sovrastimare",
    "sovrastimerebbe": "sovrastimare",
    "sovrastimerebber": "sovrastimare",
    "sovrastimerebbero": "sovrastimare",
    "sovrastimerei": "sovrastimare",
    "sovrastimeremmo": "sovrastimare",
    "sovrastimeremo": "sovrastimare",
    "sovrastimereste": "sovrastimare",
    "sovrastimeresti": "sovrastimare",
    "sovrastimerete": "sovrastimare",
    "sovrastimerà": "sovrastimare",
    "sovrastimerò": "sovrastimare",
    "sovrastimi": "sovrastimare",
    "sovrastimiamo": "sovrastimare",
    "sovrastimiate": "sovrastimare",
    "sovrastimin": "sovrastimare",
    "sovrastimino": "sovrastimare",
    "sovrastimo": "sovrastimare",
    "sovrastimò": "sovrastimare",
    "sovrastin": "sovrastare",
    "sovrastino": "sovrastare",
    "sovrasto": "sovrastare",
    "sovrastrutture": "sovrastruttura",
    "sovrastò": "sovrastare",
    "sovratasse": "sovratassa",
    "sovrattasse": "sovrattassa",
    "sovreccita": "sovreccitare",
    "sovreccitai": "sovreccitare",
    "sovreccitammo": "sovreccitare",
    "sovreccitan": "sovreccitare",
    "sovreccitando": "sovreccitare",
    "sovreccitano": "sovreccitare",
    "sovreccitante": "sovreccitare",
    "sovreccitanti": "sovreccitare",
    "sovreccitar": "sovreccitare",
    "sovreccitaron": "sovreccitare",
    "sovreccitarono": "sovreccitare",
    "sovreccitasse": "sovreccitare",
    "sovreccitasser": "sovreccitare",
    "sovreccitassero": "sovreccitare",
    "sovreccitassi": "sovreccitare",
    "sovreccitassimo": "sovreccitare",
    "sovreccitaste": "sovreccitare",
    "sovreccitasti": "sovreccitare",
    "sovreccitata": "sovreccitare",
    "sovreccitate": "sovreccitare",
    "sovreccitati": "sovreccitare",
    "sovreccitato": "sovreccitare",
    "sovreccitava": "sovreccitare",
    "sovreccitavamo": "sovreccitare",
    "sovreccitavan": "sovreccitare",
    "sovreccitavano": "sovreccitare",
    "sovreccitavate": "sovreccitare",
    "sovreccitavi": "sovreccitare",
    "sovreccitavo": "sovreccitare",
    "sovrecciterai": "sovreccitare",
    "sovrecciteran": "sovreccitare",
    "sovrecciteranno": "sovreccitare",
    "sovrecciterebbe": "sovreccitare",
    "sovrecciterebber": "sovreccitare",
    "sovrecciterebbero": "sovreccitare",
    "sovrecciterei": "sovreccitare",
    "sovrecciteremmo": "sovreccitare",
    "sovrecciteremo": "sovreccitare",
    "sovreccitereste": "sovreccitare",
    "sovrecciteresti": "sovreccitare",
    "sovrecciterete": "sovreccitare",
    "sovrecciterà": "sovreccitare",
    "sovrecciterò": "sovreccitare",
    "sovrecciti": "sovreccitare",
    "sovreccitiamo": "sovreccitare",
    "sovreccitiate": "sovreccitare",
    "sovreccitin": "sovreccitare",
    "sovreccitino": "sovreccitare",
    "sovreccito": "sovreccitare",
    "sovreccitò": "sovreccitare",
    "sovrimposte": "sovrimposta",
    "sovrintenda": "sovrintendere",
    "sovrintendan": "sovrintendere",
    "sovrintendano": "sovrintendere",
    "sovrintende": "sovrintendere",
    "sovrintendemmo": "sovrintendere",
    "sovrintendendo": "sovrintendere",
    "sovrintendente": "sovrintendere",
    "sovrintendenti": "sovrintendere",
    "sovrintendenze": "sovrintendenza",
    "sovrintender": "sovrintendere",
    "sovrintenderai": "sovrintendere",
    "sovrintenderan": "sovrintendere",
    "sovrintenderanno": "sovrintendere",
    "sovrintenderebbe": "sovrintendere",
    "sovrintenderebber": "sovrintendere",
    "sovrintenderebbero": "sovrintendere",
    "sovrintenderei": "sovrintendere",
    "sovrintenderemmo": "sovrintendere",
    "sovrintenderemo": "sovrintendere",
    "sovrintendereste": "sovrintendere",
    "sovrintenderesti": "sovrintendere",
    "sovrintenderete": "sovrintendere",
    "sovrintenderà": "sovrintendere",
    "sovrintenderò": "sovrintendere",
    "sovrintendesse": "sovrintendere",
    "sovrintendesser": "sovrintendere",
    "sovrintendessero": "sovrintendere",
    "sovrintendessi": "sovrintendere",
    "sovrintendessimo": "sovrintendere",
    "sovrintendeste": "sovrintendere",
    "sovrintendesti": "sovrintendere",
    "sovrintendete": "sovrintendere",
    "sovrintendeva": "sovrintendere",
    "sovrintendevamo": "sovrintendere",
    "sovrintendevan": "sovrintendere",
    "sovrintendevano": "sovrintendere",
    "sovrintendevate": "sovrintendere",
    "sovrintendevi": "sovrintendere",
    "sovrintendevo": "sovrintendere",
    "sovrintendi": "sovrintendere",
    "sovrintendiamo": "sovrintendere",
    "sovrintendiate": "sovrintendere",
    "sovrintendo": "sovrintendere",
    "sovrintendon": "sovrintendere",
    "sovrintendono": "sovrintendere",
    "sovrintesa": "sovrintendere",
    "sovrintese": "sovrintendere",
    "sovrinteser": "sovrintendere",
    "sovrintesero": "sovrintendere",
    "sovrintesi": "sovrintendere",
    "sovrinteso": "sovrintendere",
    "sovrintesè": "sovrintendere",
    "sovrumana": "sovrumano",
    "sovrumane": "sovrumano",
    "sovrumani": "sovrumano",
    "sovvenendo": "sovvenire",
    "sovvenente": "sovvenire",
    "sovvenenti": "sovvenire",
    "sovvenga": "sovvenire",
    "sovvengan": "sovvenire",
    "sovvengano": "sovvenire",
    "sovvengo": "sovvenire",
    "sovvengon": "sovvenire",
    "sovvengono": "sovvenire",
    "sovveniamo": "sovvenire",
    "sovveniate": "sovvenire",
    "sovvenimmo": "sovvenire",
    "sovvenir": "sovvenire",
    "sovvenisse": "sovvenire",
    "sovvenisser": "sovvenire",
    "sovvenissero": "sovvenire",
    "sovvenissi": "sovvenire",
    "sovvenissimo": "sovvenire",
    "sovveniste": "sovvenire",
    "sovvenisti": "sovvenire",
    "sovvenite": "sovvenire",
    "sovveniva": "sovvenire",
    "sovvenivamo": "sovvenire",
    "sovvenivan": "sovvenire",
    "sovvenivano": "sovvenire",
    "sovvenivate": "sovvenire",
    "sovvenivi": "sovvenire",
    "sovvenivo": "sovvenire",
    "sovvenne": "sovvenire",
    "sovvenner": "sovvenire",
    "sovvennero": "sovvenire",
    "sovvenni": "sovvenire",
    "sovvenuta": "sovvenire",
    "sovvenute": "sovvenire",
    "sovvenuti": "sovvenire",
    "sovvenuto": "sovvenire",
    "sovvenziona": "sovvenzionare",
    "sovvenzionai": "sovvenzionare",
    "sovvenzionamenti": "sovvenzionamento",
    "sovvenzionammo": "sovvenzionare",
    "sovvenzionan": "sovvenzionare",
    "sovvenzionando": "sovvenzionare",
    "sovvenzionano": "sovvenzionare",
    "sovvenzionante": "sovvenzionare",
    "sovvenzionanti": "sovvenzionare",
    "sovvenzionar": "sovvenzionare",
    "sovvenzionaron": "sovvenzionare",
    "sovvenzionarono": "sovvenzionare",
    "sovvenzionasse": "sovvenzionare",
    "sovvenzionasser": "sovvenzionare",
    "sovvenzionassero": "sovvenzionare",
    "sovvenzionassi": "sovvenzionare",
    "sovvenzionassimo": "sovvenzionare",
    "sovvenzionaste": "sovvenzionare",
    "sovvenzionasti": "sovvenzionare",
    "sovvenzionata": "sovvenzionare",
    "sovvenzionate": "sovvenzionare",
    "sovvenzionati": "sovvenzionare",
    "sovvenzionato": "sovvenzionare",
    "sovvenzionava": "sovvenzionare",
    "sovvenzionavamo": "sovvenzionare",
    "sovvenzionavan": "sovvenzionare",
    "sovvenzionavano": "sovvenzionare",
    "sovvenzionavate": "sovvenzionare",
    "sovvenzionavi": "sovvenzionare",
    "sovvenzionavo": "sovvenzionare",
    "sovvenzionerai": "sovvenzionare",
    "sovvenzioneran": "sovvenzionare",
    "sovvenzioneranno": "sovvenzionare",
    "sovvenzionerebbe": "sovvenzionare",
    "sovvenzionerebber": "sovvenzionare",
    "sovvenzionerebbero": "sovvenzionare",
    "sovvenzionerei": "sovvenzionare",
    "sovvenzioneremmo": "sovvenzionare",
    "sovvenzioneremo": "sovvenzionare",
    "sovvenzionereste": "sovvenzionare",
    "sovvenzioneresti": "sovvenzionare",
    "sovvenzionerete": "sovvenzionare",
    "sovvenzionerà": "sovvenzionare",
    "sovvenzionerò": "sovvenzionare",
    "sovvenzioni": "sovvenzione",
    "sovvenzioniamo": "sovvenzionare",
    "sovvenzioniate": "sovvenzionare",
    "sovvenzionin": "sovvenzionare",
    "sovvenzionino": "sovvenzionare",
    "sovvenziono": "sovvenzionare",
    "sovvenzionò": "sovvenzionare",
    "sovverrai": "sovvenire",
    "sovverran": "sovvenire",
    "sovverranno": "sovvenire",
    "sovverrebbe": "sovvenire",
    "sovverrebber": "sovvenire",
    "sovverrebbero": "sovvenire",
    "sovverrei": "sovvenire",
    "sovverremmo": "sovvenire",
    "sovverremo": "sovvenire",
    "sovverreste": "sovvenire",
    "sovverresti": "sovvenire",
    "sovverrete": "sovvenire",
    "sovverrà": "sovvenire",
    "sovverrò": "sovvenire",
    "sovversioni": "sovversione",
    "sovversiva": "sovversivo",
    "sovversive": "sovversivo",
    "sovversivi": "sovversivo",
    "sovversivismi": "sovversivismo",
    "sovverta": "sovvertire",
    "sovvertan": "sovvertire",
    "sovvertano": "sovvertire",
    "sovverte": "sovvertire",
    "sovvertendo": "sovvertire",
    "sovvertente": "sovvertire",
    "sovvertenti": "sovvertire",
    "sovverti": "sovvertire",
    "sovvertiamo": "sovvertire",
    "sovvertiate": "sovvertire",
    "sovvertii": "sovvertire",
    "sovvertimenti": "sovvertimento",
    "sovvertimmo": "sovvertire",
    "sovvertir": "sovvertire",
    "sovvertirai": "sovvertire",
    "sovvertiran": "sovvertire",
    "sovvertiranno": "sovvertire",
    "sovvertirebbe": "sovvertire",
    "sovvertirebber": "sovvertire",
    "sovvertirebbero": "sovvertire",
    "sovvertirei": "sovvertire",
    "sovvertiremmo": "sovvertire",
    "sovvertiremo": "sovvertire",
    "sovvertireste": "sovvertire",
    "sovvertiresti": "sovvertire",
    "sovvertirete": "sovvertire",
    "sovvertiron": "sovvertire",
    "sovvertirono": "sovvertire",
    "sovvertirà": "sovvertire",
    "sovvertirò": "sovvertire",
    "sovvertisse": "sovvertire",
    "sovvertisser": "sovvertire",
    "sovvertissero": "sovvertire",
    "sovvertissi": "sovvertire",
    "sovvertissimo": "sovvertire",
    "sovvertiste": "sovvertire",
    "sovvertisti": "sovvertire",
    "sovvertita": "sovvertire",
    "sovvertite": "sovvertire",
    "sovvertiti": "sovvertire",
    "sovvertito": "sovvertire",
    "sovvertitori": "sovvertitore",
    "sovvertitrice": "sovvertitore",
    "sovvertitrici": "sovvertitore",
    "sovvertiva": "sovvertire",
    "sovvertivamo": "sovvertire",
    "sovvertivan": "sovvertire",
    "sovvertivano": "sovvertire",
    "sovvertivate": "sovvertire",
    "sovvertivi": "sovvertire",
    "sovvertivo": "sovvertire",
    "sovverto": "sovvertire",
    "sovverton": "sovvertire",
    "sovvertono": "sovvertire",
    "sovvertì": "sovvertire",
    "sovviene": "sovvenire",
    "sovvieni": "sovvenire",
    "sozza": "sozzo",
    "sozze": "sozzo",
    "sozzi": "sozzo",
    "spacca": "spaccare",
    "spaccai": "spaccare",
    "spaccammo": "spaccare",
    "spaccan": "spaccare",
    "spaccando": "spaccare",
    "spaccano": "spaccare",
    "spaccante": "spaccare",
    "spaccanti": "spaccare",
    "spaccar": "spaccare",
    "spaccaron": "spaccare",
    "spaccarono": "spaccare",
    "spaccasse": "spaccare",
    "spaccasser": "spaccare",
    "spaccassero": "spaccare",
    "spaccassi": "spaccare",
    "spaccassimo": "spaccare",
    "spaccaste": "spaccare",
    "spaccasti": "spaccare",
    "spaccata": "spaccato",
    "spaccate": "spaccato",
    "spaccati": "spaccato",
    "spaccato": "spaccare",
    "spaccature": "spaccatura",
    "spaccava": "spaccare",
    "spaccavamo": "spaccare",
    "spaccavan": "spaccare",
    "spaccavano": "spaccare",
    "spaccavate": "spaccare",
    "spaccavi": "spaccare",
    "spaccavo": "spaccare",
    "spaccerai": "spacciare",
    "spacceran": "spacciare",
    "spacceranno": "spacciare",
    "spaccerebbe": "spacciare",
    "spaccerebber": "spacciare",
    "spaccerebbero": "spacciare",
    "spaccerei": "spacciare",
    "spacceremmo": "spacciare",
    "spacceremo": "spacciare",
    "spaccereste": "spacciare",
    "spacceresti": "spacciare",
    "spaccerete": "spacciare",
    "spaccerà": "spacciare",
    "spaccerò": "spacciare",
    "spaccherai": "spaccare",
    "spaccheran": "spaccare",
    "spaccheranno": "spaccare",
    "spaccherebbe": "spaccare",
    "spaccherebber": "spaccare",
    "spaccherebbero": "spaccare",
    "spaccherei": "spaccare",
    "spaccheremmo": "spaccare",
    "spaccheremo": "spaccare",
    "spacchereste": "spaccare",
    "spaccheresti": "spaccare",
    "spaccherete": "spaccare",
    "spaccherà": "spaccare",
    "spaccherò": "spaccare",
    "spacchetta": "spacchettare",
    "spacchettai": "spacchettare",
    "spacchettammo": "spacchettare",
    "spacchettan": "spacchettare",
    "spacchettando": "spacchettare",
    "spacchettano": "spacchettare",
    "spacchettante": "spacchettare",
    "spacchettanti": "spacchettare",
    "spacchettar": "spacchettare",
    "spacchettaron": "spacchettare",
    "spacchettarono": "spacchettare",
    "spacchettasse": "spacchettare",
    "spacchettasser": "spacchettare",
    "spacchettassero": "spacchettare",
    "spacchettassi": "spacchettare",
    "spacchettassimo": "spacchettare",
    "spacchettaste": "spacchettare",
    "spacchettasti": "spacchettare",
    "spacchettata": "spacchettare",
    "spacchettate": "spacchettare",
    "spacchettati": "spacchettare",
    "spacchettato": "spacchettare",
    "spacchettava": "spacchettare",
    "spacchettavamo": "spacchettare",
    "spacchettavan": "spacchettare",
    "spacchettavano": "spacchettare",
    "spacchettavate": "spacchettare",
    "spacchettavi": "spacchettare",
    "spacchettavo": "spacchettare",
    "spacchetterai": "spacchettare",
    "spacchetteran": "spacchettare",
    "spacchetteranno": "spacchettare",
    "spacchetterebbe": "spacchettare",
    "spacchetterebber": "spacchettare",
    "spacchetterebbero": "spacchettare",
    "spacchetterei": "spacchettare",
    "spacchetteremmo": "spacchettare",
    "spacchetteremo": "spacchettare",
    "spacchettereste": "spacchettare",
    "spacchetteresti": "spacchettare",
    "spacchetterete": "spacchettare",
    "spacchetterà": "spacchettare",
    "spacchetterò": "spacchettare",
    "spacchetti": "spacchettare",
    "spacchettiamo": "spacchettare",
    "spacchettiate": "spacchettare",
    "spacchettin": "spacchettare",
    "spacchettino": "spacchettare",
    "spacchetto": "spacchettare",
    "spacchettò": "spacchettare",
    "spacchi": "spacco",
    "spacchiamo": "spaccare",
    "spacchiate": "spaccare",
    "spacchin": "spaccare",
    "spacchino": "spaccare",
    "spacci": "spaccio",
    "spaccia": "spacciare",
    "spacciai": "spacciare",
    "spacciammo": "spacciare",
    "spacciamo": "spacciare",
    "spaccian": "spacciare",
    "spacciando": "spacciare",
    "spacciano": "spacciare",
    "spacciante": "spacciare",
    "spaccianti": "spacciare",
    "spacciar": "spacciare",
    "spacciaron": "spacciare",
    "spacciarono": "spacciare",
    "spacciasse": "spacciare",
    "spacciasser": "spacciare",
    "spacciassero": "spacciare",
    "spacciassi": "spacciare",
    "spacciassimo": "spacciare",
    "spacciaste": "spacciare",
    "spacciasti": "spacciare",
    "spacciata": "spacciare",
    "spacciate": "spacciare",
    "spacciati": "spacciare",
    "spacciato": "spacciare",
    "spacciatori": "spacciatore",
    "spacciava": "spacciare",
    "spacciavamo": "spacciare",
    "spacciavan": "spacciare",
    "spacciavano": "spacciare",
    "spacciavate": "spacciare",
    "spacciavi": "spacciare",
    "spacciavo": "spacciare",
    "spaccin": "spacciare",
    "spaccino": "spacciare",
    "spaccio": "spacciare",
    "spacciò": "spacciare",
    "spacco": "spaccare",
    "spacconate": "spacconata",
    "spaccò": "spaccare",
    "spadaccini": "spadaccino",
    "spade": "spada",
    "spadoni": "spadone",
    "spadroneggerai": "spadroneggiare",
    "spadroneggeran": "spadroneggiare",
    "spadroneggeranno": "spadroneggiare",
    "spadroneggerebbe": "spadroneggiare",
    "spadroneggerebber": "spadroneggiare",
    "spadroneggerebbero": "spadroneggiare",
    "spadroneggerei": "spadroneggiare",
    "spadroneggeremmo": "spadroneggiare",
    "spadroneggeremo": "spadroneggiare",
    "spadroneggereste": "spadroneggiare",
    "spadroneggeresti": "spadroneggiare",
    "spadroneggerete": "spadroneggiare",
    "spadroneggerà": "spadroneggiare",
    "spadroneggerò": "spadroneggiare",
    "spadroneggi": "spadroneggiare",
    "spadroneggia": "spadroneggiare",
    "spadroneggiai": "spadroneggiare",
    "spadroneggiammo": "spadroneggiare",
    "spadroneggiamo": "spadroneggiare",
    "spadroneggian": "spadroneggiare",
    "spadroneggiando": "spadroneggiare",
    "spadroneggiano": "spadroneggiare",
    "spadroneggiante": "spadroneggiare",
    "spadroneggianti": "spadroneggiare",
    "spadroneggiar": "spadroneggiare",
    "spadroneggiaron": "spadroneggiare",
    "spadroneggiarono": "spadroneggiare",
    "spadroneggiasse": "spadroneggiare",
    "spadroneggiasser": "spadroneggiare",
    "spadroneggiassero": "spadroneggiare",
    "spadroneggiassi": "spadroneggiare",
    "spadroneggiassimo": "spadroneggiare",
    "spadroneggiaste": "spadroneggiare",
    "spadroneggiasti": "spadroneggiare",
    "spadroneggiata": "spadroneggiare",
    "spadroneggiate": "spadroneggiare",
    "spadroneggiati": "spadroneggiare",
    "spadroneggiato": "spadroneggiare",
    "spadroneggiava": "spadroneggiare",
    "spadroneggiavamo": "spadroneggiare",
    "spadroneggiavan": "spadroneggiare",
    "spadroneggiavano": "spadroneggiare",
    "spadroneggiavate": "spadroneggiare",
    "spadroneggiavi": "spadroneggiare",
    "spadroneggiavo": "spadroneggiare",
    "spadroneggin": "spadroneggiare",
    "spadroneggino": "spadroneggiare",
    "spadroneggio": "spadroneggiare",
    "spadroneggiò": "spadroneggiare",
    "spaesamenti": "spaesamento",
    "spaesata": "spaesato",
    "spaesate": "spaesato",
    "spaesati": "spaesato",
    "spaghetti": "spaghetto",
    "spaghi": "spago",
    "spagina": "spaginare",
    "spaginai": "spaginare",
    "spaginammo": "spaginare",
    "spaginan": "spaginare",
    "spaginando": "spaginare",
    "spaginano": "spaginare",
    "spaginante": "spaginare",
    "spaginanti": "spaginare",
    "spaginar": "spaginare",
    "spaginaron": "spaginare",
    "spaginarono": "spaginare",
    "spaginasse": "spaginare",
    "spaginasser": "spaginare",
    "spaginassero": "spaginare",
    "spaginassi": "spaginare",
    "spaginassimo": "spaginare",
    "spaginaste": "spaginare",
    "spaginasti": "spaginare",
    "spaginata": "spaginare",
    "spaginate": "spaginare",
    "spaginati": "spaginare",
    "spaginato": "spaginare",
    "spaginava": "spaginare",
    "spaginavamo": "spaginare",
    "spaginavan": "spaginare",
    "spaginavano": "spaginare",
    "spaginavate": "spaginare",
    "spaginavi": "spaginare",
    "spaginavo": "spaginare",
    "spaginerai": "spaginare",
    "spagineran": "spaginare",
    "spagineranno": "spaginare",
    "spaginerebbe": "spaginare",
    "spaginerebber": "spaginare",
    "spaginerebbero": "spaginare",
    "spaginerei": "spaginare",
    "spagineremmo": "spaginare",
    "spagineremo": "spaginare",
    "spaginereste": "spaginare",
    "spagineresti": "spaginare",
    "spaginerete": "spaginare",
    "spaginerà": "spaginare",
    "spaginerò": "spaginare",
    "spagini": "spaginare",
    "spaginiamo": "spaginare",
    "spaginiate": "spaginare",
    "spaginin": "spaginare",
    "spaginino": "spaginare",
    "spagino": "spaginare",
    "spaginò": "spaginare",
    "spagli": "spagliare",
    "spaglia": "spagliare",
    "spagliai": "spagliare",
    "spagliammo": "spagliare",
    "spagliamo": "spagliare",
    "spaglian": "spagliare",
    "spagliando": "spagliare",
    "spagliano": "spagliare",
    "spagliante": "spagliare",
    "spaglianti": "spagliare",
    "spagliar": "spagliare",
    "spagliaron": "spagliare",
    "spagliarono": "spagliare",
    "spagliasse": "spagliare",
    "spagliasser": "spagliare",
    "spagliassero": "spagliare",
    "spagliassi": "spagliare",
    "spagliassimo": "spagliare",
    "spagliaste": "spagliare",
    "spagliasti": "spagliare",
    "spagliata": "spagliare",
    "spagliate": "spagliare",
    "spagliati": "spagliare",
    "spagliato": "spagliare",
    "spagliava": "spagliare",
    "spagliavamo": "spagliare",
    "spagliavan": "spagliare",
    "spagliavano": "spagliare",
    "spagliavate": "spagliare",
    "spagliavi": "spagliare",
    "spagliavo": "spagliare",
    "spaglierai": "spagliare",
    "spaglieran": "spagliare",
    "spaglieranno": "spagliare",
    "spaglierebbe": "spagliare",
    "spaglierebber": "spagliare",
    "spaglierebbero": "spagliare",
    "spaglierei": "spagliare",
    "spaglieremmo": "spagliare",
    "spaglieremo": "spagliare",
    "spagliereste": "spagliare",
    "spaglieresti": "spagliare",
    "spaglierete": "spagliare",
    "spaglierà": "spagliare",
    "spaglierò": "spagliare",
    "spaglin": "spagliare",
    "spaglino": "spagliare",
    "spaglio": "spagliare",
    "spagliò": "spagliare",
    "spagnola": "spagnolo",
    "spagnole": "spagnolo",
    "spagnolesca": "spagnolesco",
    "spagnolesche": "spagnolesco",
    "spagnoleschi": "spagnolesco",
    "spagnoli": "spagnolo",
    "spai": "spaiare",
    "spaia": "sparire",
    "spaiai": "spaiare",
    "spaiammo": "spaiare",
    "spaiamo": "spaiare",
    "spaian": "sparire",
    "spaiando": "spaiare",
    "spaiano": "sparire",
    "spaiante": "spaiare",
    "spaianti": "spaiare",
    "spaiar": "spaiare",
    "spaiaron": "spaiare",
    "spaiarono": "spaiare",
    "spaiasse": "spaiare",
    "spaiasser": "spaiare",
    "spaiassero": "spaiare",
    "spaiassi": "spaiare",
    "spaiassimo": "spaiare",
    "spaiaste": "spaiare",
    "spaiasti": "spaiare",
    "spaiata": "spaiare",
    "spaiate": "spaiare",
    "spaiati": "spaiare",
    "spaiato": "spaiare",
    "spaiava": "spaiare",
    "spaiavamo": "spaiare",
    "spaiavan": "spaiare",
    "spaiavano": "spaiare",
    "spaiavate": "spaiare",
    "spaiavi": "spaiare",
    "spaiavo": "spaiare",
    "spaierai": "spaiare",
    "spaieran": "spaiare",
    "spaieranno": "spaiare",
    "spaierebbe": "spaiare",
    "spaierebber": "spaiare",
    "spaierebbero": "spaiare",
    "spaierei": "spaiare",
    "spaieremmo": "spaiare",
    "spaieremo": "spaiare",
    "spaiereste": "spaiare",
    "spaieresti": "spaiare",
    "spaierete": "spaiare",
    "spaierà": "spaiare",
    "spaierò": "spaiare",
    "spain": "spaiare",
    "spaino": "spaiare",
    "spaio": "sparire",
    "spaion": "sparire",
    "spaiono": "sparire",
    "spaiò": "spaiare",
    "spala": "spalare",
    "spalai": "spalare",
    "spalammo": "spalare",
    "spalan": "spalare",
    "spalanca": "spalancare",
    "spalancai": "spalancare",
    "spalancammo": "spalancare",
    "spalancan": "spalancare",
    "spalancando": "spalancare",
    "spalancano": "spalancare",
    "spalancante": "spalancare",
    "spalancanti": "spalancare",
    "spalancar": "spalancare",
    "spalancaron": "spalancare",
    "spalancarono": "spalancare",
    "spalancasse": "spalancare",
    "spalancasser": "spalancare",
    "spalancassero": "spalancare",
    "spalancassi": "spalancare",
    "spalancassimo": "spalancare",
    "spalancaste": "spalancare",
    "spalancasti": "spalancare",
    "spalancata": "spalancare",
    "spalancate": "spalancare",
    "spalancati": "spalancare",
    "spalancato": "spalancare",
    "spalancava": "spalancare",
    "spalancavamo": "spalancare",
    "spalancavan": "spalancare",
    "spalancavano": "spalancare",
    "spalancavate": "spalancare",
    "spalancavi": "spalancare",
    "spalancavo": "spalancare",
    "spalancherai": "spalancare",
    "spalancheran": "spalancare",
    "spalancheranno": "spalancare",
    "spalancherebbe": "spalancare",
    "spalancherebber": "spalancare",
    "spalancherebbero": "spalancare",
    "spalancherei": "spalancare",
    "spalancheremmo": "spalancare",
    "spalancheremo": "spalancare",
    "spalanchereste": "spalancare",
    "spalancheresti": "spalancare",
    "spalancherete": "spalancare",
    "spalancherà": "spalancare",
    "spalancherò": "spalancare",
    "spalanchi": "spalancare",
    "spalanchiamo": "spalancare",
    "spalanchiate": "spalancare",
    "spalanchin": "spalancare",
    "spalanchino": "spalancare",
    "spalanco": "spalancare",
    "spalancò": "spalancare",
    "spalando": "spalare",
    "spalano": "spalare",
    "spalante": "spalare",
    "spalanti": "spalare",
    "spalar": "spalare",
    "spalaron": "spalare",
    "spalarono": "spalare",
    "spalasse": "spalare",
    "spalasser": "spalare",
    "spalassero": "spalare",
    "spalassi": "spalare",
    "spalassimo": "spalare",
    "spalaste": "spalare",
    "spalasti": "spalare",
    "spalata": "spalare",
    "spalate": "spalare",
    "spalati": "spalare",
    "spalato": "spalare",
    "spalava": "spalare",
    "spalavamo": "spalare",
    "spalavan": "spalare",
    "spalavano": "spalare",
    "spalavate": "spalare",
    "spalavi": "spalare",
    "spalavo": "spalare",
    "spalerai": "spalare",
    "spaleran": "spalare",
    "spaleranno": "spalare",
    "spalerebbe": "spalare",
    "spalerebber": "spalare",
    "spalerebbero": "spalare",
    "spalerei": "spalare",
    "spaleremmo": "spalare",
    "spaleremo": "spalare",
    "spalereste": "spalare",
    "spaleresti": "spalare",
    "spalerete": "spalare",
    "spalerà": "spalare",
    "spalerò": "spalare",
    "spali": "spalare",
    "spaliamo": "spalare",
    "spaliate": "spalare",
    "spalin": "spalare",
    "spalino": "spalare",
    "spallate": "spallata",
    "spalle": "spalla",
    "spalleggerai": "spalleggiare",
    "spalleggeran": "spalleggiare",
    "spalleggeranno": "spalleggiare",
    "spalleggerebbe": "spalleggiare",
    "spalleggerebber": "spalleggiare",
    "spalleggerebbero": "spalleggiare",
    "spalleggerei": "spalleggiare",
    "spalleggeremmo": "spalleggiare",
    "spalleggeremo": "spalleggiare",
    "spalleggereste": "spalleggiare",
    "spalleggeresti": "spalleggiare",
    "spalleggerete": "spalleggiare",
    "spalleggerà": "spalleggiare",
    "spalleggerò": "spalleggiare",
    "spalleggi": "spalleggiare",
    "spalleggia": "spalleggiare",
    "spalleggiai": "spalleggiare",
    "spalleggiammo": "spalleggiare",
    "spalleggiamo": "spalleggiare",
    "spalleggian": "spalleggiare",
    "spalleggiando": "spalleggiare",
    "spalleggiano": "spalleggiare",
    "spalleggiante": "spalleggiare",
    "spalleggianti": "spalleggiare",
    "spalleggiar": "spalleggiare",
    "spalleggiaron": "spalleggiare",
    "spalleggiarono": "spalleggiare",
    "spalleggiasse": "spalleggiare",
    "spalleggiasser": "spalleggiare",
    "spalleggiassero": "spalleggiare",
    "spalleggiassi": "spalleggiare",
    "spalleggiassimo": "spalleggiare",
    "spalleggiaste": "spalleggiare",
    "spalleggiasti": "spalleggiare",
    "spalleggiata": "spalleggiare",
    "spalleggiate": "spalleggiare",
    "spalleggiati": "spalleggiare",
    "spalleggiato": "spalleggiare",
    "spalleggiava": "spalleggiare",
    "spalleggiavamo": "spalleggiare",
    "spalleggiavan": "spalleggiare",
    "spalleggiavano": "spalleggiare",
    "spalleggiavate": "spalleggiare",
    "spalleggiavi": "spalleggiare",
    "spalleggiavo": "spalleggiare",
    "spalleggin": "spalleggiare",
    "spalleggino": "spalleggiare",
    "spalleggio": "spalleggiare",
    "spalleggiò": "spalleggiare",
    "spallette": "spalletta",
    "spalliere": "spalliera",
    "spalline": "spallina",
    "spalma": "spalmare",
    "spalmai": "spalmare",
    "spalmammo": "spalmare",
    "spalman": "spalmare",
    "spalmando": "spalmare",
    "spalmano": "spalmare",
    "spalmante": "spalmare",
    "spalmanti": "spalmare",
    "spalmar": "spalmare",
    "spalmaron": "spalmare",
    "spalmarono": "spalmare",
    "spalmasse": "spalmare",
    "spalmasser": "spalmare",
    "spalmassero": "spalmare",
    "spalmassi": "spalmare",
    "spalmassimo": "spalmare",
    "spalmaste": "spalmare",
    "spalmasti": "spalmare",
    "spalmata": "spalmare",
    "spalmate": "spalmare",
    "spalmati": "spalmare",
    "spalmato": "spalmare",
    "spalmava": "spalmare",
    "spalmavamo": "spalmare",
    "spalmavan": "spalmare",
    "spalmavano": "spalmare",
    "spalmavate": "spalmare",
    "spalmavi": "spalmare",
    "spalmavo": "spalmare",
    "spalmerai": "spalmare",
    "spalmeran": "spalmare",
    "spalmeranno": "spalmare",
    "spalmerebbe": "spalmare",
    "spalmerebber": "spalmare",
    "spalmerebbero": "spalmare",
    "spalmerei": "spalmare",
    "spalmeremmo": "spalmare",
    "spalmeremo": "spalmare",
    "spalmereste": "spalmare",
    "spalmeresti": "spalmare",
    "spalmerete": "spalmare",
    "spalmerà": "spalmare",
    "spalmerò": "spalmare",
    "spalmi": "spalmare",
    "spalmiamo": "spalmare",
    "spalmiate": "spalmare",
    "spalmin": "spalmare",
    "spalmino": "spalmare",
    "spalmo": "spalmare",
    "spalmò": "spalmare",
    "spalo": "spalare",
    "spalti": "spalto",
    "spalò": "spalare",
    "spampana": "spampanare",
    "spampanai": "spampanare",
    "spampanammo": "spampanare",
    "spampanan": "spampanare",
    "spampanando": "spampanare",
    "spampanano": "spampanare",
    "spampanante": "spampanare",
    "spampananti": "spampanare",
    "spampanar": "spampanare",
    "spampanaron": "spampanare",
    "spampanarono": "spampanare",
    "spampanasse": "spampanare",
    "spampanasser": "spampanare",
    "spampanassero": "spampanare",
    "spampanassi": "spampanare",
    "spampanassimo": "spampanare",
    "spampanaste": "spampanare",
    "spampanasti": "spampanare",
    "spampanata": "spampanare",
    "spampanate": "spampanare",
    "spampanati": "spampanare",
    "spampanato": "spampanare",
    "spampanava": "spampanare",
    "spampanavamo": "spampanare",
    "spampanavan": "spampanare",
    "spampanavano": "spampanare",
    "spampanavate": "spampanare",
    "spampanavi": "spampanare",
    "spampanavo": "spampanare",
    "spampanerai": "spampanare",
    "spampaneran": "spampanare",
    "spampaneranno": "spampanare",
    "spampanerebbe": "spampanare",
    "spampanerebber": "spampanare",
    "spampanerebbero": "spampanare",
    "spampanerei": "spampanare",
    "spampaneremmo": "spampanare",
    "spampaneremo": "spampanare",
    "spampanereste": "spampanare",
    "spampaneresti": "spampanare",
    "spampanerete": "spampanare",
    "spampanerà": "spampanare",
    "spampanerò": "spampanare",
    "spampani": "spampanare",
    "spampaniamo": "spampanare",
    "spampaniate": "spampanare",
    "spampanin": "spampanare",
    "spampanino": "spampanare",
    "spampano": "spampanare",
    "spampanò": "spampanare",
    "spana": "spanare",
    "spanai": "spanare",
    "spanammo": "spanare",
    "spanan": "spanare",
    "spanando": "spanare",
    "spanano": "spanare",
    "spanante": "spanare",
    "spananti": "spanare",
    "spanar": "spanare",
    "spanaron": "spanare",
    "spanarono": "spanare",
    "spanasse": "spanare",
    "spanasser": "spanare",
    "spanassero": "spanare",
    "spanassi": "spanare",
    "spanassimo": "spanare",
    "spanaste": "spanare",
    "spanasti": "spanare",
    "spanata": "spanare",
    "spanate": "spanare",
    "spanati": "spanare",
    "spanato": "spanare",
    "spanava": "spanare",
    "spanavamo": "spanare",
    "spanavan": "spanare",
    "spanavano": "spanare",
    "spanavate": "spanare",
    "spanavi": "spanare",
    "spanavo": "spanare",
    "spancerai": "spanciare",
    "spanceran": "spanciare",
    "spanceranno": "spanciare",
    "spancerebbe": "spanciare",
    "spancerebber": "spanciare",
    "spancerebbero": "spanciare",
    "spancerei": "spanciare",
    "spanceremmo": "spanciare",
    "spanceremo": "spanciare",
    "spancereste": "spanciare",
    "spanceresti": "spanciare",
    "spancerete": "spanciare",
    "spancerà": "spanciare",
    "spancerò": "spanciare",
    "spanci": "spanciare",
    "spancia": "spanciare",
    "spanciai": "spanciare",
    "spanciammo": "spanciare",
    "spanciamo": "spanciare",
    "spancian": "spanciare",
    "spanciando": "spanciare",
    "spanciano": "spanciare",
    "spanciante": "spanciare",
    "spancianti": "spanciare",
    "spanciar": "spanciare",
    "spanciaron": "spanciare",
    "spanciarono": "spanciare",
    "spanciasse": "spanciare",
    "spanciasser": "spanciare",
    "spanciassero": "spanciare",
    "spanciassi": "spanciare",
    "spanciassimo": "spanciare",
    "spanciaste": "spanciare",
    "spanciasti": "spanciare",
    "spanciata": "spanciare",
    "spanciate": "spanciare",
    "spanciati": "spanciare",
    "spanciato": "spanciare",
    "spanciava": "spanciare",
    "spanciavamo": "spanciare",
    "spanciavan": "spanciare",
    "spanciavano": "spanciare",
    "spanciavate": "spanciare",
    "spanciavi": "spanciare",
    "spanciavo": "spanciare",
    "spancin": "spanciare",
    "spancino": "spanciare",
    "spancio": "spanciare",
    "spanciò": "spanciare",
    "spanda": "spandere",
    "spandan": "spandere",
    "spandano": "spandere",
    "spande": "spandere",
    "spandemmo": "spandere",
    "spandendo": "spandere",
    "spandente": "spandere",
    "spandenti": "spandere",
    "spander": "spandere",
    "spanderai": "spandere",
    "spanderan": "spandere",
    "spanderanno": "spandere",
    "spanderebbe": "spandere",
    "spanderebber": "spandere",
    "spanderebbero": "spandere",
    "spanderei": "spandere",
    "spanderemmo": "spandere",
    "spanderemo": "spandere",
    "spandereste": "spandere",
    "spanderesti": "spandere",
    "spanderete": "spandere",
    "spanderà": "spandere",
    "spanderò": "spandere",
    "spandesse": "spandere",
    "spandesser": "spandere",
    "spandessero": "spandere",
    "spandessi": "spandere",
    "spandessimo": "spandere",
    "spandeste": "spandere",
    "spandesti": "spandere",
    "spandete": "spandere",
    "spandeva": "spandere",
    "spandevamo": "spandere",
    "spandevan": "spandere",
    "spandevano": "spandere",
    "spandevate": "spandere",
    "spandevi": "spandere",
    "spandevo": "spandere",
    "spandi": "spandere",
    "spandiamo": "spandere",
    "spandiate": "spandere",
    "spando": "spandere",
    "spandon": "spandere",
    "spandono": "spandere",
    "spanduta": "spandere",
    "spandute": "spandere",
    "spanduti": "spandere",
    "spanduto": "spandere",
    "spanerai": "spanare",
    "spaneran": "spanare",
    "spaneranno": "spanare",
    "spanerebbe": "spanare",
    "spanerebber": "spanare",
    "spanerebbero": "spanare",
    "spanerei": "spanare",
    "spaneremmo": "spanare",
    "spaneremo": "spanare",
    "spanereste": "spanare",
    "spaneresti": "spanare",
    "spanerete": "spanare",
    "spanerà": "spanare",
    "spanerò": "spanare",
    "spani": "spanare",
    "spaniamo": "spanare",
    "spaniate": "spanare",
    "spanin": "spanare",
    "spanino": "spanare",
    "spanne": "spanna",
    "spannocchi": "spannocchiare",
    "spannocchia": "spannocchiare",
    "spannocchiai": "spannocchiare",
    "spannocchiammo": "spannocchiare",
    "spannocchiamo": "spannocchiare",
    "spannocchian": "spannocchiare",
    "spannocchiando": "spannocchiare",
    "spannocchiano": "spannocchiare",
    "spannocchiante": "spannocchiare",
    "spannocchianti": "spannocchiare",
    "spannocchiar": "spannocchiare",
    "spannocchiaron": "spannocchiare",
    "spannocchiarono": "spannocchiare",
    "spannocchiasse": "spannocchiare",
    "spannocchiasser": "spannocchiare",
    "spannocchiassero": "spannocchiare",
    "spannocchiassi": "spannocchiare",
    "spannocchiassimo": "spannocchiare",
    "spannocchiaste": "spannocchiare",
    "spannocchiasti": "spannocchiare",
    "spannocchiata": "spannocchiare",
    "spannocchiate": "spannocchiare",
    "spannocchiati": "spannocchiare",
    "spannocchiato": "spannocchiare",
    "spannocchiava": "spannocchiare",
    "spannocchiavamo": "spannocchiare",
    "spannocchiavan": "spannocchiare",
    "spannocchiavano": "spannocchiare",
    "spannocchiavate": "spannocchiare",
    "spannocchiavi": "spannocchiare",
    "spannocchiavo": "spannocchiare",
    "spannocchierai": "spannocchiare",
    "spannocchieran": "spannocchiare",
    "spannocchieranno": "spannocchiare",
    "spannocchierebbe": "spannocchiare",
    "spannocchierebber": "spannocchiare",
    "spannocchierebbero": "spannocchiare",
    "spannocchierei": "spannocchiare",
    "spannocchieremmo": "spannocchiare",
    "spannocchieremo": "spannocchiare",
    "spannocchiereste": "spannocchiare",
    "spannocchieresti": "spannocchiare",
    "spannocchierete": "spannocchiare",
    "spannocchierà": "spannocchiare",
    "spannocchierò": "spannocchiare",
    "spannocchin": "spannocchiare",
    "spannocchino": "spannocchiare",
    "spannocchio": "spannocchiare",
    "spannocchiò": "spannocchiare",
    "spano": "spanare",
    "spanò": "spanare",
    "spaparacchi": "spaparacchiare",
    "spaparacchia": "spaparacchiare",
    "spaparacchiai": "spaparacchiare",
    "spaparacchiammo": "spaparacchiare",
    "spaparacchiamo": "spaparacchiare",
    "spaparacchian": "spaparacchiare",
    "spaparacchiando": "spaparacchiare",
    "spaparacchiano": "spaparacchiare",
    "spaparacchiar": "spaparacchiare",
    "spaparacchiaron": "spaparacchiare",
    "spaparacchiarono": "spaparacchiare",
    "spaparacchiasse": "spaparacchiare",
    "spaparacchiasser": "spaparacchiare",
    "spaparacchiassero": "spaparacchiare",
    "spaparacchiassi": "spaparacchiare",
    "spaparacchiassimo": "spaparacchiare",
    "spaparacchiaste": "spaparacchiare",
    "spaparacchiasti": "spaparacchiare",
    "spaparacchiata": "spaparacchiare",
    "spaparacchiate": "spaparacchiare",
    "spaparacchiati": "spaparacchiare",
    "spaparacchiato": "spaparacchiare",
    "spaparacchiava": "spaparacchiare",
    "spaparacchiavamo": "spaparacchiare",
    "spaparacchiavan": "spaparacchiare",
    "spaparacchiavano": "spaparacchiare",
    "spaparacchiavate": "spaparacchiare",
    "spaparacchiavi": "spaparacchiare",
    "spaparacchiavo": "spaparacchiare",
    "spaparacchierai": "spaparacchiare",
    "spaparacchieran": "spaparacchiare",
    "spaparacchieranno": "spaparacchiare",
    "spaparacchierebbe": "spaparacchiare",
    "spaparacchierebber": "spaparacchiare",
    "spaparacchierebbero": "spaparacchiare",
    "spaparacchierei": "spaparacchiare",
    "spaparacchieremmo": "spaparacchiare",
    "spaparacchieremo": "spaparacchiare",
    "spaparacchiereste": "spaparacchiare",
    "spaparacchieresti": "spaparacchiare",
    "spaparacchierete": "spaparacchiare",
    "spaparacchierà": "spaparacchiare",
    "spaparacchierò": "spaparacchiare",
    "spaparacchin": "spaparacchiare",
    "spaparacchino": "spaparacchiare",
    "spaparacchio": "spaparacchiare",
    "spaparacchiò": "spaparacchiare",
    "spaparanza": "spaparanzare",
    "spaparanzai": "spaparanzare",
    "spaparanzammo": "spaparanzare",
    "spaparanzan": "spaparanzare",
    "spaparanzando": "spaparanzare",
    "spaparanzano": "spaparanzare",
    "spaparanzar": "spaparanzare",
    "spaparanzaron": "spaparanzare",
    "spaparanzarono": "spaparanzare",
    "spaparanzasse": "spaparanzare",
    "spaparanzasser": "spaparanzare",
    "spaparanzassero": "spaparanzare",
    "spaparanzassi": "spaparanzare",
    "spaparanzassimo": "spaparanzare",
    "spaparanzaste": "spaparanzare",
    "spaparanzasti": "spaparanzare",
    "spaparanzata": "spaparanzare",
    "spaparanzate": "spaparanzare",
    "spaparanzati": "spaparanzare",
    "spaparanzato": "spaparanzare",
    "spaparanzava": "spaparanzare",
    "spaparanzavamo": "spaparanzare",
    "spaparanzavan": "spaparanzare",
    "spaparanzavano": "spaparanzare",
    "spaparanzavate": "spaparanzare",
    "spaparanzavi": "spaparanzare",
    "spaparanzavo": "spaparanzare",
    "spaparanzerai": "spaparanzare",
    "spaparanzeran": "spaparanzare",
    "spaparanzeranno": "spaparanzare",
    "spaparanzerebbe": "spaparanzare",
    "spaparanzerebber": "spaparanzare",
    "spaparanzerebbero": "spaparanzare",
    "spaparanzerei": "spaparanzare",
    "spaparanzeremmo": "spaparanzare",
    "spaparanzeremo": "spaparanzare",
    "spaparanzereste": "spaparanzare",
    "spaparanzeresti": "spaparanzare",
    "spaparanzerete": "spaparanzare",
    "spaparanzerà": "spaparanzare",
    "spaparanzerò": "spaparanzare",
    "spaparanzi": "spaparanzare",
    "spaparanziamo": "spaparanzare",
    "spaparanziate": "spaparanzare",
    "spaparanzin": "spaparanzare",
    "spaparanzino": "spaparanzare",
    "spaparanzo": "spaparanzare",
    "spaparanzò": "spaparanzare",
    "spappola": "spappolare",
    "spappolai": "spappolare",
    "spappolammo": "spappolare",
    "spappolan": "spappolare",
    "spappolando": "spappolare",
    "spappolano": "spappolare",
    "spappolante": "spappolare",
    "spappolanti": "spappolare",
    "spappolar": "spappolare",
    "spappolaron": "spappolare",
    "spappolarono": "spappolare",
    "spappolasse": "spappolare",
    "spappolasser": "spappolare",
    "spappolassero": "spappolare",
    "spappolassi": "spappolare",
    "spappolassimo": "spappolare",
    "spappolaste": "spappolare",
    "spappolasti": "spappolare",
    "spappolata": "spappolare",
    "spappolate": "spappolare",
    "spappolati": "spappolare",
    "spappolato": "spappolare",
    "spappolava": "spappolare",
    "spappolavamo": "spappolare",
    "spappolavan": "spappolare",
    "spappolavano": "spappolare",
    "spappolavate": "spappolare",
    "spappolavi": "spappolare",
    "spappolavo": "spappolare",
    "spappolerai": "spappolare",
    "spappoleran": "spappolare",
    "spappoleranno": "spappolare",
    "spappolerebbe": "spappolare",
    "spappolerebber": "spappolare",
    "spappolerebbero": "spappolare",
    "spappolerei": "spappolare",
    "spappoleremmo": "spappolare",
    "spappoleremo": "spappolare",
    "spappolereste": "spappolare",
    "spappoleresti": "spappolare",
    "spappolerete": "spappolare",
    "spappolerà": "spappolare",
    "spappolerò": "spappolare",
    "spappoli": "spappolare",
    "spappoliamo": "spappolare",
    "spappoliate": "spappolare",
    "spappolin": "spappolare",
    "spappolino": "spappolare",
    "spappolo": "spappolare",
    "spappolò": "spappolare",
    "spara": "sparare",
    "sparagnina": "sparagnino",
    "sparagnine": "sparagnino",
    "sparagnini": "sparagnino",
    "sparai": "sparare",
    "sparammo": "sparare",
    "sparan": "sparare",
    "sparando": "sparare",
    "sparano": "sparare",
    "sparante": "sparare",
    "sparanti": "sparare",
    "sparar": "sparare",
    "spararon": "sparare",
    "spararono": "sparare",
    "sparasse": "sparare",
    "sparasser": "sparare",
    "sparassero": "sparare",
    "sparassi": "sparare",
    "sparassimo": "sparare",
    "sparaste": "sparare",
    "sparasti": "sparare",
    "sparata": "sparato",
    "sparate": "sparato",
    "sparati": "sparato",
    "sparato": "sparare",
    "sparatori": "sparatore",
    "sparatorie": "sparatoria",
    "sparava": "sparare",
    "sparavamo": "sparare",
    "sparavan": "sparare",
    "sparavano": "sparare",
    "sparavate": "sparare",
    "sparavi": "sparare",
    "sparavo": "sparare",
    "spare": "sparire",
    "sparecchi": "sparecchiare",
    "sparecchia": "sparecchiare",
    "sparecchiai": "sparecchiare",
    "sparecchiammo": "sparecchiare",
    "sparecchiamo": "sparecchiare",
    "sparecchian": "sparecchiare",
    "sparecchiando": "sparecchiare",
    "sparecchiano": "sparecchiare",
    "sparecchiante": "sparecchiare",
    "sparecchianti": "sparecchiare",
    "sparecchiar": "sparecchiare",
    "sparecchiaron": "sparecchiare",
    "sparecchiarono": "sparecchiare",
    "sparecchiasse": "sparecchiare",
    "sparecchiasser": "sparecchiare",
    "sparecchiassero": "sparecchiare",
    "sparecchiassi": "sparecchiare",
    "sparecchiassimo": "sparecchiare",
    "sparecchiaste": "sparecchiare",
    "sparecchiasti": "sparecchiare",
    "sparecchiata": "sparecchiare",
    "sparecchiate": "sparecchiare",
    "sparecchiati": "sparecchiare",
    "sparecchiato": "sparecchiare",
    "sparecchiava": "sparecchiare",
    "sparecchiavamo": "sparecchiare",
    "sparecchiavan": "sparecchiare",
    "sparecchiavano": "sparecchiare",
    "sparecchiavate": "sparecchiare",
    "sparecchiavi": "sparecchiare",
    "sparecchiavo": "sparecchiare",
    "sparecchierai": "sparecchiare",
    "sparecchieran": "sparecchiare",
    "sparecchieranno": "sparecchiare",
    "sparecchierebbe": "sparecchiare",
    "sparecchierebber": "sparecchiare",
    "sparecchierebbero": "sparecchiare",
    "sparecchierei": "sparecchiare",
    "sparecchieremmo": "sparecchiare",
    "sparecchieremo": "sparecchiare",
    "sparecchiereste": "sparecchiare",
    "sparecchieresti": "sparecchiare",
    "sparecchierete": "sparecchiare",
    "sparecchierà": "sparecchiare",
    "sparecchierò": "sparecchiare",
    "sparecchin": "sparecchiare",
    "sparecchino": "sparecchiare",
    "sparecchio": "sparecchiare",
    "sparecchiò": "sparecchiare",
    "spareggi": "spareggio",
    "sparendo": "sparire",
    "sparente": "sparire",
    "sparenti": "sparire",
    "sparerai": "sparare",
    "spareran": "sparare",
    "spareranno": "sparare",
    "sparerebbe": "sparare",
    "sparerebber": "sparare",
    "sparerebbero": "sparare",
    "sparerei": "sparare",
    "spareremmo": "sparare",
    "spareremo": "sparare",
    "sparereste": "sparare",
    "spareresti": "sparare",
    "sparerete": "sparare",
    "sparerà": "sparare",
    "sparerò": "sparare",
    "sparga": "spargere",
    "spargan": "spargere",
    "spargano": "spargere",
    "sparge": "spargere",
    "spargemmo": "spargere",
    "spargendo": "spargere",
    "spargente": "spargere",
    "spargenti": "spargere",
    "sparger": "spargere",
    "spargerai": "spargere",
    "spargeran": "spargere",
    "spargeranno": "spargere",
    "spargerebbe": "spargere",
    "spargerebber": "spargere",
    "spargerebbero": "spargere",
    "spargerei": "spargere",
    "spargeremmo": "spargere",
    "spargeremo": "spargere",
    "spargereste": "spargere",
    "spargeresti": "spargere",
    "spargerete": "spargere",
    "spargerà": "spargere",
    "spargerò": "spargere",
    "spargesse": "spargere",
    "spargesser": "spargere",
    "spargessero": "spargere",
    "spargessi": "spargere",
    "spargessimo": "spargere",
    "spargeste": "spargere",
    "spargesti": "spargere",
    "spargete": "spargere",
    "spargeva": "spargere",
    "spargevamo": "spargere",
    "spargevan": "spargere",
    "spargevano": "spargere",
    "spargevate": "spargere",
    "spargevi": "spargere",
    "spargevo": "spargere",
    "spargi": "spargere",
    "spargiamo": "spargere",
    "spargiate": "spargere",
    "spargimenti": "spargimento",
    "spargo": "spargere",
    "spargon": "spargere",
    "spargono": "spargere",
    "spari": "sparo",
    "spariamo": "sparire",
    "spariate": "sparire",
    "sparigli": "sparigliare",
    "spariglia": "sparigliare",
    "sparigliai": "sparigliare",
    "sparigliammo": "sparigliare",
    "sparigliamo": "sparigliare",
    "spariglian": "sparigliare",
    "sparigliando": "sparigliare",
    "sparigliano": "sparigliare",
    "sparigliante": "sparigliare",
    "spariglianti": "sparigliare",
    "sparigliar": "sparigliare",
    "sparigliaron": "sparigliare",
    "sparigliarono": "sparigliare",
    "sparigliasse": "sparigliare",
    "sparigliasser": "sparigliare",
    "sparigliassero": "sparigliare",
    "sparigliassi": "sparigliare",
    "sparigliassimo": "sparigliare",
    "sparigliaste": "sparigliare",
    "sparigliasti": "sparigliare",
    "sparigliata": "sparigliare",
    "sparigliate": "sparigliare",
    "sparigliati": "sparigliare",
    "sparigliato": "sparigliare",
    "sparigliava": "sparigliare",
    "sparigliavamo": "sparigliare",
    "sparigliavan": "sparigliare",
    "sparigliavano": "sparigliare",
    "sparigliavate": "sparigliare",
    "sparigliavi": "sparigliare",
    "sparigliavo": "sparigliare",
    "spariglierai": "sparigliare",
    "spariglieran": "sparigliare",
    "spariglieranno": "sparigliare",
    "spariglierebbe": "sparigliare",
    "spariglierebber": "sparigliare",
    "spariglierebbero": "sparigliare",
    "spariglierei": "sparigliare",
    "spariglieremmo": "sparigliare",
    "spariglieremo": "sparigliare",
    "sparigliereste": "sparigliare",
    "spariglieresti": "sparigliare",
    "spariglierete": "sparigliare",
    "spariglierà": "sparigliare",
    "spariglierò": "sparigliare",
    "spariglin": "sparigliare",
    "spariglino": "sparigliare",
    "spariglio": "sparigliare",
    "sparigliò": "sparigliare",
    "sparimmo": "sparire",
    "sparin": "sparare",
    "sparino": "sparare",
    "sparir": "sparire",
    "sparirai": "sparire",
    "spariran": "sparire",
    "spariranno": "sparire",
    "sparirebbe": "sparire",
    "sparirebber": "sparire",
    "sparirebbero": "sparire",
    "sparirei": "sparire",
    "spariremmo": "sparire",
    "spariremo": "sparire",
    "sparireste": "sparire",
    "spariresti": "sparire",
    "sparirete": "sparire",
    "sparirà": "sparire",
    "sparirò": "sparire",
    "sparisse": "sparire",
    "sparisser": "sparire",
    "sparissero": "sparire",
    "sparissi": "sparire",
    "sparissimo": "sparire",
    "spariste": "sparire",
    "sparisti": "sparire",
    "sparite": "sparire",
    "spariva": "sparire",
    "sparivamo": "sparire",
    "sparivan": "sparire",
    "sparivano": "sparire",
    "sparivate": "sparire",
    "sparivi": "sparire",
    "sparivo": "sparire",
    "sparizioni": "sparizione",
    "sparla": "sparlare",
    "sparlai": "sparlare",
    "sparlammo": "sparlare",
    "sparlan": "sparlare",
    "sparlando": "sparlare",
    "sparlano": "sparlare",
    "sparlante": "sparlare",
    "sparlanti": "sparlare",
    "sparlar": "sparlare",
    "sparlaron": "sparlare",
    "sparlarono": "sparlare",
    "sparlasse": "sparlare",
    "sparlasser": "sparlare",
    "sparlassero": "sparlare",
    "sparlassi": "sparlare",
    "sparlassimo": "sparlare",
    "sparlaste": "sparlare",
    "sparlasti": "sparlare",
    "sparlata": "sparlare",
    "sparlate": "sparlare",
    "sparlati": "sparlare",
    "sparlato": "sparlare",
    "sparlava": "sparlare",
    "sparlavamo": "sparlare",
    "sparlavan": "sparlare",
    "sparlavano": "sparlare",
    "sparlavate": "sparlare",
    "sparlavi": "sparlare",
    "sparlavo": "sparlare",
    "sparlerai": "sparlare",
    "sparleran": "sparlare",
    "sparleranno": "sparlare",
    "sparlerebbe": "sparlare",
    "sparlerebber": "sparlare",
    "sparlerebbero": "sparlare",
    "sparlerei": "sparlare",
    "sparleremmo": "sparlare",
    "sparleremo": "sparlare",
    "sparlereste": "sparlare",
    "sparleresti": "sparlare",
    "sparlerete": "sparlare",
    "sparlerà": "sparlare",
    "sparlerò": "sparlare",
    "sparli": "sparlare",
    "sparliamo": "sparlare",
    "sparliate": "sparlare",
    "sparlin": "sparlare",
    "sparlino": "sparlare",
    "sparlo": "sparlare",
    "sparlò": "sparlare",
    "sparo": "sparare",
    "sparpagli": "sparpagliare",
    "sparpaglia": "sparpagliare",
    "sparpagliai": "sparpagliare",
    "sparpagliammo": "sparpagliare",
    "sparpagliamo": "sparpagliare",
    "sparpaglian": "sparpagliare",
    "sparpagliando": "sparpagliare",
    "sparpagliano": "sparpagliare",
    "sparpagliante": "sparpagliare",
    "sparpaglianti": "sparpagliare",
    "sparpagliar": "sparpagliare",
    "sparpagliaron": "sparpagliare",
    "sparpagliarono": "sparpagliare",
    "sparpagliasse": "sparpagliare",
    "sparpagliasser": "sparpagliare",
    "sparpagliassero": "sparpagliare",
    "sparpagliassi": "sparpagliare",
    "sparpagliassimo": "sparpagliare",
    "sparpagliaste": "sparpagliare",
    "sparpagliasti": "sparpagliare",
    "sparpagliata": "sparpagliare",
    "sparpagliate": "sparpagliare",
    "sparpagliati": "sparpagliare",
    "sparpagliato": "sparpagliare",
    "sparpagliava": "sparpagliare",
    "sparpagliavamo": "sparpagliare",
    "sparpagliavan": "sparpagliare",
    "sparpagliavano": "sparpagliare",
    "sparpagliavate": "sparpagliare",
    "sparpagliavi": "sparpagliare",
    "sparpagliavo": "sparpagliare",
    "sparpaglierai": "sparpagliare",
    "sparpaglieran": "sparpagliare",
    "sparpaglieranno": "sparpagliare",
    "sparpaglierebbe": "sparpagliare",
    "sparpaglierebber": "sparpagliare",
    "sparpaglierebbero": "sparpagliare",
    "sparpaglierei": "sparpagliare",
    "sparpaglieremmo": "sparpagliare",
    "sparpaglieremo": "sparpagliare",
    "sparpagliereste": "sparpagliare",
    "sparpaglieresti": "sparpagliare",
    "sparpaglierete": "sparpagliare",
    "sparpaglierà": "sparpagliare",
    "sparpaglierò": "sparpagliare",
    "sparpaglin": "sparpagliare",
    "sparpaglino": "sparpagliare",
    "sparpaglio": "sparpagliare",
    "sparpagliò": "sparpagliare",
    "sparsa": "sparso",
    "sparse": "sparso",
    "sparser": "spargere",
    "sparsero": "spargere",
    "sparsi": "sparso",
    "sparso": "sparire",
    "sparta": "sparto",
    "spartana": "spartano",
    "spartane": "spartano",
    "spartani": "spartano",
    "sparte": "sparto",
    "spartendo": "spartire",
    "spartente": "spartire",
    "spartenti": "spartire",
    "sparti": "sparto",
    "spartiamo": "spartire",
    "spartiate": "spartire",
    "spartii": "spartire",
    "spartimmo": "spartire",
    "spartir": "spartire",
    "spartirai": "spartire",
    "spartiran": "spartire",
    "spartiranno": "spartire",
    "spartirebbe": "spartire",
    "spartirebber": "spartire",
    "spartirebbero": "spartire",
    "spartirei": "spartire",
    "spartiremmo": "spartire",
    "spartiremo": "spartire",
    "spartireste": "spartire",
    "spartiresti": "spartire",
    "spartirete": "spartire",
    "spartiron": "spartire",
    "spartirono": "spartire",
    "spartirà": "spartire",
    "spartirò": "spartire",
    "spartisca": "spartire",
    "spartiscan": "spartire",
    "spartiscano": "spartire",
    "spartisce": "spartire",
    "spartisci": "spartire",
    "spartisco": "spartire",
    "spartiscon": "spartire",
    "spartiscono": "spartire",
    "spartisse": "spartire",
    "spartisser": "spartire",
    "spartissero": "spartire",
    "spartissi": "spartire",
    "spartissimo": "spartire",
    "spartiste": "spartire",
    "spartisti": "spartire",
    "spartita": "spartire",
    "spartite": "spartire",
    "spartiti": "spartito",
    "spartito": "spartire",
    "spartitraffica": "spartitraffico",
    "spartitraffiche": "spartitraffico",
    "spartitraffici": "spartitraffico",
    "spartiva": "spartire",
    "spartivamo": "spartire",
    "spartivan": "spartire",
    "spartivano": "spartire",
    "spartivate": "spartire",
    "spartivi": "spartire",
    "spartivo": "spartire",
    "spartizioni": "spartizione",
    "spartì": "spartire",
    "sparuta": "sparuto",
    "sparute": "sparuto",
    "sparuti": "sparuto",
    "sparve": "sparire",
    "sparver": "sparire",
    "sparvero": "sparire",
    "sparvi": "sparire",
    "sparò": "sparare",
    "spaser": "spandere",
    "spasero": "spandere",
    "spasi": "spandere",
    "spasima": "spasimare",
    "spasimai": "spasimare",
    "spasimammo": "spasimare",
    "spasiman": "spasimare",
    "spasimando": "spasimare",
    "spasimano": "spasimare",
    "spasimante": "spasimare",
    "spasimanti": "spasimare",
    "spasimar": "spasimare",
    "spasimaron": "spasimare",
    "spasimarono": "spasimare",
    "spasimasse": "spasimare",
    "spasimasser": "spasimare",
    "spasimassero": "spasimare",
    "spasimassi": "spasimare",
    "spasimassimo": "spasimare",
    "spasimaste": "spasimare",
    "spasimasti": "spasimare",
    "spasimata": "spasimare",
    "spasimate": "spasimare",
    "spasimati": "spasimare",
    "spasimato": "spasimare",
    "spasimava": "spasimare",
    "spasimavamo": "spasimare",
    "spasimavan": "spasimare",
    "spasimavano": "spasimare",
    "spasimavate": "spasimare",
    "spasimavi": "spasimare",
    "spasimavo": "spasimare",
    "spasimerai": "spasimare",
    "spasimeran": "spasimare",
    "spasimeranno": "spasimare",
    "spasimerebbe": "spasimare",
    "spasimerebber": "spasimare",
    "spasimerebbero": "spasimare",
    "spasimerei": "spasimare",
    "spasimeremmo": "spasimare",
    "spasimeremo": "spasimare",
    "spasimereste": "spasimare",
    "spasimeresti": "spasimare",
    "spasimerete": "spasimare",
    "spasimerà": "spasimare",
    "spasimerò": "spasimare",
    "spasimi": "spasimo",
    "spasimiamo": "spasimare",
    "spasimiate": "spasimare",
    "spasimin": "spasimare",
    "spasimino": "spasimare",
    "spasimo": "spasimare",
    "spasimò": "spasimare",
    "spasmi": "spasmo",
    "spasmodica": "spasmodico",
    "spasmodiche": "spasmodico",
    "spasmodici": "spasmodico",
    "spassa": "spassare",
    "spassai": "spassare",
    "spassammo": "spassare",
    "spassan": "spassare",
    "spassando": "spassare",
    "spassano": "spassare",
    "spassante": "spassare",
    "spassanti": "spassare",
    "spassar": "spassare",
    "spassaron": "spassare",
    "spassarono": "spassare",
    "spassasse": "spassare",
    "spassasser": "spassare",
    "spassassero": "spassare",
    "spassassi": "spassare",
    "spassassimo": "spassare",
    "spassaste": "spassare",
    "spassasti": "spassare",
    "spassata": "spassare",
    "spassate": "spassare",
    "spassati": "spassare",
    "spassato": "spassare",
    "spassava": "spassare",
    "spassavamo": "spassare",
    "spassavan": "spassare",
    "spassavano": "spassare",
    "spassavate": "spassare",
    "spassavi": "spassare",
    "spassavo": "spassare",
    "spasserai": "spassare",
    "spasseran": "spassare",
    "spasseranno": "spassare",
    "spasserebbe": "spassare",
    "spasserebber": "spassare",
    "spasserebbero": "spassare",
    "spasserei": "spassare",
    "spasseremmo": "spassare",
    "spasseremo": "spassare",
    "spassereste": "spassare",
    "spasseresti": "spassare",
    "spasserete": "spassare",
    "spasserà": "spassare",
    "spasserò": "spassare",
    "spassi": "spassare",
    "spassiamo": "spassare",
    "spassiate": "spassare",
    "spassin": "spassare",
    "spassino": "spassare",
    "spassionata": "spassionato",
    "spassionate": "spassionato",
    "spassionati": "spassionato",
    "spasso": "spassare",
    "spassosa": "spassoso",
    "spassose": "spassoso",
    "spassosi": "spassoso",
    "spassò": "spassare",
    "spasè": "spandere",
    "spatolata": "spatolato",
    "spatolate": "spatolato",
    "spatolati": "spatolato",
    "spaura": "spaurire",
    "spauracchi": "spauracchio",
    "spauran": "spaurire",
    "spaurano": "spaurire",
    "spaure": "spaurire",
    "spaurendo": "spaurire",
    "spaurente": "spaurire",
    "spaurenti": "spaurire",
    "spauri": "spaurire",
    "spauriamo": "spaurire",
    "spauriate": "spaurire",
    "spaurii": "spaurire",
    "spaurimmo": "spaurire",
    "spaurir": "spaurire",
    "spaurirai": "spaurire",
    "spauriran": "spaurire",
    "spauriranno": "spaurire",
    "spaurirebbe": "spaurire",
    "spaurirebber": "spaurire",
    "spaurirebbero": "spaurire",
    "spaurirei": "spaurire",
    "spauriremmo": "spaurire",
    "spauriremo": "spaurire",
    "spaurireste": "spaurire",
    "spauriresti": "spaurire",
    "spaurirete": "spaurire",
    "spauriron": "spaurire",
    "spaurirono": "spaurire",
    "spaurirà": "spaurire",
    "spaurirò": "spaurire",
    "spaurisse": "spaurire",
    "spaurisser": "spaurire",
    "spaurissero": "spaurire",
    "spaurissi": "spaurire",
    "spaurissimo": "spaurire",
    "spauriste": "spaurire",
    "spauristi": "spaurire",
    "spaurita": "spaurito",
    "spaurite": "spaurito",
    "spauriti": "spaurito",
    "spaurito": "spaurire",
    "spauriva": "spaurire",
    "spaurivamo": "spaurire",
    "spaurivan": "spaurire",
    "spaurivano": "spaurire",
    "spaurivate": "spaurire",
    "spaurivi": "spaurire",
    "spaurivo": "spaurire",
    "spauro": "spaurire",
    "spauron": "spaurire",
    "spaurono": "spaurire",
    "spaurì": "spaurire",
    "spavalda": "spavaldo",
    "spavalde": "spavaldo",
    "spavalderie": "spavalderia",
    "spavaldi": "spavaldo",
    "spaventa": "spaventare",
    "spaventai": "spaventare",
    "spaventammo": "spaventare",
    "spaventan": "spaventare",
    "spaventando": "spaventare",
    "spaventano": "spaventare",
    "spaventante": "spaventare",
    "spaventanti": "spaventare",
    "spaventar": "spaventare",
    "spaventaron": "spaventare",
    "spaventarono": "spaventare",
    "spaventasse": "spaventare",
    "spaventasser": "spaventare",
    "spaventassero": "spaventare",
    "spaventassi": "spaventare",
    "spaventassimo": "spaventare",
    "spaventaste": "spaventare",
    "spaventasti": "spaventare",
    "spaventata": "spaventato",
    "spaventate": "spaventato",
    "spaventati": "spaventato",
    "spaventato": "spaventare",
    "spaventava": "spaventare",
    "spaventavamo": "spaventare",
    "spaventavan": "spaventare",
    "spaventavano": "spaventare",
    "spaventavate": "spaventare",
    "spaventavi": "spaventare",
    "spaventavo": "spaventare",
    "spaventerai": "spaventare",
    "spaventeran": "spaventare",
    "spaventeranno": "spaventare",
    "spaventerebbe": "spaventare",
    "spaventerebber": "spaventare",
    "spaventerebbero": "spaventare",
    "spaventerei": "spaventare",
    "spaventeremmo": "spaventare",
    "spaventeremo": "spaventare",
    "spaventereste": "spaventare",
    "spaventeresti": "spaventare",
    "spaventerete": "spaventare",
    "spaventerà": "spaventare",
    "spaventerò": "spaventare",
    "spaventevoli": "spaventevole",
    "spaventi": "spavento",
    "spaventiamo": "spaventare",
    "spaventiate": "spaventare",
    "spaventin": "spaventare",
    "spaventino": "spaventare",
    "spavento": "spaventare",
    "spaventosa": "spaventoso",
    "spaventose": "spaventoso",
    "spaventosi": "spaventoso",
    "spaventò": "spaventare",
    "spazi": "spazio",
    "spazia": "spaziare",
    "spaziai": "spaziare",
    "spaziali": "spaziale",
    "spaziammo": "spaziare",
    "spaziamo": "spaziare",
    "spazian": "spaziare",
    "spaziando": "spaziare",
    "spaziano": "spaziare",
    "spaziante": "spaziare",
    "spazianti": "spaziare",
    "spaziar": "spaziare",
    "spaziaron": "spaziare",
    "spaziarono": "spaziare",
    "spaziasse": "spaziare",
    "spaziasser": "spaziare",
    "spaziassero": "spaziare",
    "spaziassi": "spaziare",
    "spaziassimo": "spaziare",
    "spaziaste": "spaziare",
    "spaziasti": "spaziare",
    "spaziata": "spaziare",
    "spaziate": "spaziare",
    "spaziati": "spaziare",
    "spaziato": "spaziare",
    "spaziava": "spaziare",
    "spaziavamo": "spaziare",
    "spaziavan": "spaziare",
    "spaziavano": "spaziare",
    "spaziavate": "spaziare",
    "spaziavi": "spaziare",
    "spaziavo": "spaziare",
    "spazientendo": "spazientire",
    "spazientente": "spazientire",
    "spaziententi": "spazientire",
    "spazientiamo": "spazientire",
    "spazientiate": "spazientire",
    "spazientii": "spazientire",
    "spazientimmo": "spazientire",
    "spazientir": "spazientire",
    "spazientirai": "spazientire",
    "spazientiran": "spazientire",
    "spazientiranno": "spazientire",
    "spazientirebbe": "spazientire",
    "spazientirebber": "spazientire",
    "spazientirebbero": "spazientire",
    "spazientirei": "spazientire",
    "spazientiremmo": "spazientire",
    "spazientiremo": "spazientire",
    "spazientireste": "spazientire",
    "spazientiresti": "spazientire",
    "spazientirete": "spazientire",
    "spazientiron": "spazientire",
    "spazientirono": "spazientire",
    "spazientirà": "spazientire",
    "spazientirò": "spazientire",
    "spazientisca": "spazientire",
    "spazientiscan": "spazientire",
    "spazientiscano": "spazientire",
    "spazientisce": "spazientire",
    "spazientisci": "spazientire",
    "spazientisco": "spazientire",
    "spazientiscon": "spazientire",
    "spazientiscono": "spazientire",
    "spazientisse": "spazientire",
    "spazientisser": "spazientire",
    "spazientissero": "spazientire",
    "spazientissi": "spazientire",
    "spazientissimo": "spazientire",
    "spazientiste": "spazientire",
    "spazientisti": "spazientire",
    "spazientita": "spazientire",
    "spazientite": "spazientire",
    "spazientiti": "spazientire",
    "spazientito": "spazientire",
    "spazientiva": "spazientire",
    "spazientivamo": "spazientire",
    "spazientivan": "spazientire",
    "spazientivano": "spazientire",
    "spazientivate": "spazientire",
    "spazientivi": "spazientire",
    "spazientivo": "spazientire",
    "spazientì": "spazientire",
    "spazierai": "spaziare",
    "spazieran": "spaziare",
    "spazieranno": "spaziare",
    "spazierebbe": "spaziare",
    "spazierebber": "spaziare",
    "spazierebbero": "spaziare",
    "spazierei": "spaziare",
    "spazieremmo": "spaziare",
    "spazieremo": "spaziare",
    "spaziereste": "spaziare",
    "spazieresti": "spaziare",
    "spazierete": "spaziare",
    "spazierà": "spaziare",
    "spazierò": "spaziare",
    "spazin": "spaziare",
    "spazino": "spaziare",
    "spazio": "spaziare",
    "spaziosa": "spazioso",
    "spaziose": "spazioso",
    "spaziosi": "spazioso",
    "spaziò": "spaziare",
    "spazza": "spazzare",
    "spazzacamini": "spazzacamino",
    "spazzai": "spazzare",
    "spazzammo": "spazzare",
    "spazzan": "spazzare",
    "spazzando": "spazzare",
    "spazzano": "spazzare",
    "spazzante": "spazzare",
    "spazzanti": "spazzare",
    "spazzar": "spazzare",
    "spazzaron": "spazzare",
    "spazzarono": "spazzare",
    "spazzasse": "spazzare",
    "spazzasser": "spazzare",
    "spazzassero": "spazzare",
    "spazzassi": "spazzare",
    "spazzassimo": "spazzare",
    "spazzaste": "spazzare",
    "spazzasti": "spazzare",
    "spazzata": "spazzare",
    "spazzate": "spazzare",
    "spazzati": "spazzare",
    "spazzato": "spazzare",
    "spazzature": "spazzatura",
    "spazzava": "spazzare",
    "spazzavamo": "spazzare",
    "spazzavan": "spazzare",
    "spazzavano": "spazzare",
    "spazzavate": "spazzare",
    "spazzavi": "spazzare",
    "spazzavo": "spazzare",
    "spazzerai": "spazzare",
    "spazzeran": "spazzare",
    "spazzeranno": "spazzare",
    "spazzerebbe": "spazzare",
    "spazzerebber": "spazzare",
    "spazzerebbero": "spazzare",
    "spazzerei": "spazzare",
    "spazzeremmo": "spazzare",
    "spazzeremo": "spazzare",
    "spazzereste": "spazzare",
    "spazzeresti": "spazzare",
    "spazzerete": "spazzare",
    "spazzerà": "spazzare",
    "spazzerò": "spazzare",
    "spazzi": "spazzare",
    "spazziamo": "spazzare",
    "spazziate": "spazzare",
    "spazzin": "spazzare",
    "spazzini": "spazzino",
    "spazzino": "spazzare",
    "spazzo": "spazzare",
    "spazzola": "spazzolare",
    "spazzolai": "spazzolare",
    "spazzolammo": "spazzolare",
    "spazzolan": "spazzolare",
    "spazzolando": "spazzolare",
    "spazzolano": "spazzolare",
    "spazzolante": "spazzolare",
    "spazzolanti": "spazzolare",
    "spazzolar": "spazzolare",
    "spazzolaron": "spazzolare",
    "spazzolarono": "spazzolare",
    "spazzolasse": "spazzolare",
    "spazzolasser": "spazzolare",
    "spazzolassero": "spazzolare",
    "spazzolassi": "spazzolare",
    "spazzolassimo": "spazzolare",
    "spazzolaste": "spazzolare",
    "spazzolasti": "spazzolare",
    "spazzolata": "spazzolare",
    "spazzolate": "spazzolare",
    "spazzolati": "spazzolare",
    "spazzolato": "spazzolare",
    "spazzolava": "spazzolare",
    "spazzolavamo": "spazzolare",
    "spazzolavan": "spazzolare",
    "spazzolavano": "spazzolare",
    "spazzolavate": "spazzolare",
    "spazzolavi": "spazzolare",
    "spazzolavo": "spazzolare",
    "spazzole": "spazzola",
    "spazzolerai": "spazzolare",
    "spazzoleran": "spazzolare",
    "spazzoleranno": "spazzolare",
    "spazzolerebbe": "spazzolare",
    "spazzolerebber": "spazzolare",
    "spazzolerebbero": "spazzolare",
    "spazzolerei": "spazzolare",
    "spazzoleremmo": "spazzolare",
    "spazzoleremo": "spazzolare",
    "spazzolereste": "spazzolare",
    "spazzoleresti": "spazzolare",
    "spazzolerete": "spazzolare",
    "spazzolerà": "spazzolare",
    "spazzolerò": "spazzolare",
    "spazzoli": "spazzolare",
    "spazzoliamo": "spazzolare",
    "spazzoliate": "spazzolare",
    "spazzolin": "spazzolare",
    "spazzolini": "spazzolino",
    "spazzolino": "spazzolare",
    "spazzolo": "spazzolare",
    "spazzolò": "spazzolare",
    "spazzò": "spazzare",
    "specchi": "specchio",
    "specchia": "specchiare",
    "specchiai": "specchiare",
    "specchiammo": "specchiare",
    "specchiamo": "specchiare",
    "specchian": "specchiare",
    "specchiando": "specchiare",
    "specchiano": "specchiare",
    "specchiar": "specchiare",
    "specchiaron": "specchiare",
    "specchiarono": "specchiare",
    "specchiasse": "specchiare",
    "specchiasser": "specchiare",
    "specchiassero": "specchiare",
    "specchiassi": "specchiare",
    "specchiassimo": "specchiare",
    "specchiaste": "specchiare",
    "specchiasti": "specchiare",
    "specchiata": "specchiato",
    "specchiate": "specchiato",
    "specchiati": "specchiato",
    "specchiato": "specchiare",
    "specchiava": "specchiare",
    "specchiavamo": "specchiare",
    "specchiavan": "specchiare",
    "specchiavano": "specchiare",
    "specchiavate": "specchiare",
    "specchiavi": "specchiare",
    "specchiavo": "specchiare",
    "specchierai": "specchiare",
    "specchieran": "specchiare",
    "specchieranno": "specchiare",
    "specchiere": "specchiera",
    "specchierebbe": "specchiare",
    "specchierebber": "specchiare",
    "specchierebbero": "specchiare",
    "specchierei": "specchiare",
    "specchieremmo": "specchiare",
    "specchieremo": "specchiare",
    "specchiereste": "specchiare",
    "specchieresti": "specchiare",
    "specchierete": "specchiare",
    "specchierà": "specchiare",
    "specchierò": "specchiare",
    "specchietti": "specchietto",
    "specchin": "specchiare",
    "specchino": "specchiare",
    "specchio": "specchiare",
    "specchiò": "specchiare",
    "speci": "specie",
    "speciali": "speciale",
    "specialismi": "specialismo",
    "specialiste": "specialista",
    "specialisti": "specialista",
    "specialistica": "specialistico",
    "specialistiche": "specialistico",
    "specialistici": "specialistico",
    "specializza": "specializzare",
    "specializzai": "specializzare",
    "specializzammo": "specializzare",
    "specializzan": "specializzare",
    "specializzando": "specializzare",
    "specializzano": "specializzare",
    "specializzante": "specializzare",
    "specializzanti": "specializzare",
    "specializzar": "specializzare",
    "specializzaron": "specializzare",
    "specializzarono": "specializzare",
    "specializzasse": "specializzare",
    "specializzasser": "specializzare",
    "specializzassero": "specializzare",
    "specializzassi": "specializzare",
    "specializzassimo": "specializzare",
    "specializzaste": "specializzare",
    "specializzasti": "specializzare",
    "specializzata": "specializzato",
    "specializzate": "specializzato",
    "specializzati": "specializzato",
    "specializzato": "specializzare",
    "specializzava": "specializzare",
    "specializzavamo": "specializzare",
    "specializzavan": "specializzare",
    "specializzavano": "specializzare",
    "specializzavate": "specializzare",
    "specializzavi": "specializzare",
    "specializzavo": "specializzare",
    "specializzazioni": "specializzazione",
    "specializzerai": "specializzare",
    "specializzeran": "specializzare",
    "specializzeranno": "specializzare",
    "specializzerebbe": "specializzare",
    "specializzerebber": "specializzare",
    "specializzerebbero": "specializzare",
    "specializzerei": "specializzare",
    "specializzeremmo": "specializzare",
    "specializzeremo": "specializzare",
    "specializzereste": "specializzare",
    "specializzeresti": "specializzare",
    "specializzerete": "specializzare",
    "specializzerà": "specializzare",
    "specializzerò": "specializzare",
    "specializzi": "specializzare",
    "specializziamo": "specializzare",
    "specializziate": "specializzare",
    "specializzin": "specializzare",
    "specializzino": "specializzare",
    "specializzo": "specializzare",
    "specializzò": "specializzare",
    "specifica": "specifico",
    "specificai": "specificare",
    "specificammo": "specificare",
    "specifican": "specificare",
    "specificando": "specificare",
    "specificano": "specificare",
    "specificante": "specificare",
    "specificanti": "specificare",
    "specificar": "specificare",
    "specificaron": "specificare",
    "specificarono": "specificare",
    "specificasse": "specificare",
    "specificasser": "specificare",
    "specificassero": "specificare",
    "specificassi": "specificare",
    "specificassimo": "specificare",
    "specificaste": "specificare",
    "specificasti": "specificare",
    "specificata": "specificato",
    "specificate": "specificato",
    "specificati": "specificato",
    "specificato": "specificare",
    "specificava": "specificare",
    "specificavamo": "specificare",
    "specificavan": "specificare",
    "specificavano": "specificare",
    "specificavate": "specificare",
    "specificavi": "specificare",
    "specificavo": "specificare",
    "specificazioni": "specificazione",
    "specifiche": "specifico",
    "specificherai": "specificare",
    "specificheran": "specificare",
    "specificheranno": "specificare",
    "specificherebbe": "specificare",
    "specificherebber": "specificare",
    "specificherebbero": "specificare",
    "specificherei": "specificare",
    "specificheremmo": "specificare",
    "specificheremo": "specificare",
    "specifichereste": "specificare",
    "specificheresti": "specificare",
    "specificherete": "specificare",
    "specificherà": "specificare",
    "specificherò": "specificare",
    "specifichi": "specificare",
    "specifichiamo": "specificare",
    "specifichiate": "specificare",
    "specifichin": "specificare",
    "specifichino": "specificare",
    "specifici": "specifico",
    "specifico": "specificare",
    "specificò": "specificare",
    "speciosa": "specioso",
    "speciose": "specioso",
    "speciosi": "specioso",
    "specula": "speculare",
    "speculai": "speculare",
    "speculammo": "speculare",
    "speculan": "speculare",
    "speculando": "speculare",
    "speculano": "speculare",
    "speculante": "speculare",
    "speculanti": "speculare",
    "specular": "speculare",
    "speculari": "speculare",
    "specularon": "speculare",
    "specularono": "speculare",
    "speculasse": "speculare",
    "speculasser": "speculare",
    "speculassero": "speculare",
    "speculassi": "speculare",
    "speculassimo": "speculare",
    "speculaste": "speculare",
    "speculasti": "speculare",
    "speculata": "speculare",
    "speculate": "speculare",
    "speculati": "speculare",
    "speculativa": "speculativo",
    "speculative": "speculativo",
    "speculativi": "speculativo",
    "speculato": "speculare",
    "speculatori": "speculatore",
    "speculatrice": "speculatore",
    "speculatrici": "speculatore",
    "speculava": "speculare",
    "speculavamo": "speculare",
    "speculavan": "speculare",
    "speculavano": "speculare",
    "speculavate": "speculare",
    "speculavi": "speculare",
    "speculavo": "speculare",
    "speculazioni": "speculazione",
    "speculerai": "speculare",
    "speculeran": "speculare",
    "speculeranno": "speculare",
    "speculerebbe": "speculare",
    "speculerebber": "speculare",
    "speculerebbero": "speculare",
    "speculerei": "speculare",
    "speculeremmo": "speculare",
    "speculeremo": "speculare",
    "speculereste": "speculare",
    "speculeresti": "speculare",
    "speculerete": "speculare",
    "speculerà": "speculare",
    "speculerò": "speculare",
    "speculi": "speculare",
    "speculiamo": "speculare",
    "speculiate": "speculare",
    "speculin": "speculare",
    "speculino": "speculare",
    "speculo": "speculare",
    "speculò": "speculare",
    "spedalizza": "spedalizzare",
    "spedalizzai": "spedalizzare",
    "spedalizzammo": "spedalizzare",
    "spedalizzan": "spedalizzare",
    "spedalizzando": "spedalizzare",
    "spedalizzano": "spedalizzare",
    "spedalizzante": "spedalizzare",
    "spedalizzanti": "spedalizzare",
    "spedalizzar": "spedalizzare",
    "spedalizzaron": "spedalizzare",
    "spedalizzarono": "spedalizzare",
    "spedalizzasse": "spedalizzare",
    "spedalizzasser": "spedalizzare",
    "spedalizzassero": "spedalizzare",
    "spedalizzassi": "spedalizzare",
    "spedalizzassimo": "spedalizzare",
    "spedalizzaste": "spedalizzare",
    "spedalizzasti": "spedalizzare",
    "spedalizzata": "spedalizzare",
    "spedalizzate": "spedalizzare",
    "spedalizzati": "spedalizzare",
    "spedalizzato": "spedalizzare",
    "spedalizzava": "spedalizzare",
    "spedalizzavamo": "spedalizzare",
    "spedalizzavan": "spedalizzare",
    "spedalizzavano": "spedalizzare",
    "spedalizzavate": "spedalizzare",
    "spedalizzavi": "spedalizzare",
    "spedalizzavo": "spedalizzare",
    "spedalizzerai": "spedalizzare",
    "spedalizzeran": "spedalizzare",
    "spedalizzeranno": "spedalizzare",
    "spedalizzerebbe": "spedalizzare",
    "spedalizzerebber": "spedalizzare",
    "spedalizzerebbero": "spedalizzare",
    "spedalizzerei": "spedalizzare",
    "spedalizzeremmo": "spedalizzare",
    "spedalizzeremo": "spedalizzare",
    "spedalizzereste": "spedalizzare",
    "spedalizzeresti": "spedalizzare",
    "spedalizzerete": "spedalizzare",
    "spedalizzerà": "spedalizzare",
    "spedalizzerò": "spedalizzare",
    "spedalizzi": "spedalizzare",
    "spedalizziamo": "spedalizzare",
    "spedalizziate": "spedalizzare",
    "spedalizzin": "spedalizzare",
    "spedalizzino": "spedalizzare",
    "spedalizzo": "spedalizzare",
    "spedalizzò": "spedalizzare",
    "spedendo": "spedire",
    "spedente": "spedire",
    "spedenti": "spedire",
    "spediamo": "spedire",
    "spediate": "spedire",
    "spedii": "spedire",
    "spedimmo": "spedire",
    "spedir": "spedire",
    "spedirai": "spedire",
    "spediran": "spedire",
    "spediranno": "spedire",
    "spedirebbe": "spedire",
    "spedirebber": "spedire",
    "spedirebbero": "spedire",
    "spedirei": "spedire",
    "spediremmo": "spedire",
    "spediremo": "spedire",
    "spedireste": "spedire",
    "spediresti": "spedire",
    "spedirete": "spedire",
    "spediron": "spedire",
    "spedirono": "spedire",
    "spedirà": "spedire",
    "spedirò": "spedire",
    "spedisca": "spedire",
    "spediscan": "spedire",
    "spediscano": "spedire",
    "spedisce": "spedire",
    "spedisci": "spedire",
    "spedisco": "spedire",
    "spediscon": "spedire",
    "spediscono": "spedire",
    "spedisse": "spedire",
    "spedisser": "spedire",
    "spedissero": "spedire",
    "spedissi": "spedire",
    "spedissimo": "spedire",
    "spediste": "spedire",
    "spedisti": "spedire",
    "spedita": "spedito",
    "spedite": "spedito",
    "speditezze": "speditezza",
    "spediti": "spedito",
    "spedito": "spedire",
    "spediva": "spedire",
    "spedivamo": "spedire",
    "spedivan": "spedire",
    "spedivano": "spedire",
    "spedivate": "spedire",
    "spedivi": "spedire",
    "spedivo": "spedire",
    "spedizioni": "spedizione",
    "spedizionieri": "spedizioniere",
    "spedì": "spedire",
    "spegna": "spegnare",
    "spegnai": "spegnare",
    "spegnammo": "spegnare",
    "spegnan": "spegnare",
    "spegnando": "spegnare",
    "spegnano": "spegnare",
    "spegnante": "spegnare",
    "spegnanti": "spegnare",
    "spegnar": "spegnare",
    "spegnaron": "spegnare",
    "spegnarono": "spegnare",
    "spegnasse": "spegnare",
    "spegnasser": "spegnare",
    "spegnassero": "spegnare",
    "spegnassi": "spegnare",
    "spegnassimo": "spegnare",
    "spegnaste": "spegnare",
    "spegnasti": "spegnare",
    "spegnata": "spegnare",
    "spegnate": "spegnare",
    "spegnati": "spegnare",
    "spegnato": "spegnare",
    "spegnava": "spegnare",
    "spegnavamo": "spegnare",
    "spegnavan": "spegnare",
    "spegnavano": "spegnare",
    "spegnavate": "spegnare",
    "spegnavi": "spegnare",
    "spegnavo": "spegnare",
    "spegne": "spegnere",
    "spegnemmo": "spegnere",
    "spegnendo": "spegnere",
    "spegnente": "spegnere",
    "spegnenti": "spegnere",
    "spegner": "spegnere",
    "spegnerai": "spegnere",
    "spegneran": "spegnere",
    "spegneranno": "spegnere",
    "spegnerebbe": "spegnere",
    "spegnerebber": "spegnere",
    "spegnerebbero": "spegnere",
    "spegnerei": "spegnere",
    "spegneremmo": "spegnere",
    "spegneremo": "spegnere",
    "spegnereste": "spegnere",
    "spegneresti": "spegnere",
    "spegnerete": "spegnere",
    "spegnerà": "spegnere",
    "spegnerò": "spegnere",
    "spegnesse": "spegnere",
    "spegnesser": "spegnere",
    "spegnessero": "spegnere",
    "spegnessi": "spegnere",
    "spegnessimo": "spegnere",
    "spegneste": "spegnere",
    "spegnesti": "spegnere",
    "spegnete": "spegnere",
    "spegneva": "spegnere",
    "spegnevamo": "spegnere",
    "spegnevan": "spegnere",
    "spegnevano": "spegnere",
    "spegnevate": "spegnere",
    "spegnevi": "spegnere",
    "spegnevo": "spegnere",
    "spegni": "spegnere",
    "spegniamo": "spegnere",
    "spegniate": "spegnere",
    "spegnimenti": "spegnimento",
    "spegnin": "spegnare",
    "spegnino": "spegnare",
    "spegno": "spegnare",
    "spegnò": "spegnare",
    "spela": "spelare",
    "spelacchi": "spelacchiare",
    "spelacchia": "spelacchiare",
    "spelacchiai": "spelacchiare",
    "spelacchiammo": "spelacchiare",
    "spelacchiamo": "spelacchiare",
    "spelacchian": "spelacchiare",
    "spelacchiando": "spelacchiare",
    "spelacchiano": "spelacchiare",
    "spelacchiante": "spelacchiare",
    "spelacchianti": "spelacchiare",
    "spelacchiar": "spelacchiare",
    "spelacchiaron": "spelacchiare",
    "spelacchiarono": "spelacchiare",
    "spelacchiasse": "spelacchiare",
    "spelacchiasser": "spelacchiare",
    "spelacchiassero": "spelacchiare",
    "spelacchiassi": "spelacchiare",
    "spelacchiassimo": "spelacchiare",
    "spelacchiaste": "spelacchiare",
    "spelacchiasti": "spelacchiare",
    "spelacchiata": "spelacchiato",
    "spelacchiate": "spelacchiato",
    "spelacchiati": "spelacchiato",
    "spelacchiato": "spelacchiare",
    "spelacchiava": "spelacchiare",
    "spelacchiavamo": "spelacchiare",
    "spelacchiavan": "spelacchiare",
    "spelacchiavano": "spelacchiare",
    "spelacchiavate": "spelacchiare",
    "spelacchiavi": "spelacchiare",
    "spelacchiavo": "spelacchiare",
    "spelacchierai": "spelacchiare",
    "spelacchieran": "spelacchiare",
    "spelacchieranno": "spelacchiare",
    "spelacchierebbe": "spelacchiare",
    "spelacchierebber": "spelacchiare",
    "spelacchierebbero": "spelacchiare",
    "spelacchierei": "spelacchiare",
    "spelacchieremmo": "spelacchiare",
    "spelacchieremo": "spelacchiare",
    "spelacchiereste": "spelacchiare",
    "spelacchieresti": "spelacchiare",
    "spelacchierete": "spelacchiare",
    "spelacchierà": "spelacchiare",
    "spelacchierò": "spelacchiare",
    "spelacchin": "spelacchiare",
    "spelacchino": "spelacchiare",
    "spelacchio": "spelacchiare",
    "spelacchiò": "spelacchiare",
    "spelai": "spelare",
    "spelammo": "spelare",
    "spelan": "spelare",
    "spelando": "spelare",
    "spelano": "spelare",
    "spelante": "spelare",
    "spelanti": "spelare",
    "spelar": "spelare",
    "spelaron": "spelare",
    "spelarono": "spelare",
    "spelasse": "spelare",
    "spelasser": "spelare",
    "spelassero": "spelare",
    "spelassi": "spelare",
    "spelassimo": "spelare",
    "spelaste": "spelare",
    "spelasti": "spelare",
    "spelata": "spelare",
    "spelate": "spelare",
    "spelati": "spelare",
    "spelato": "spelare",
    "spelava": "spelare",
    "spelavamo": "spelare",
    "spelavan": "spelare",
    "spelavano": "spelare",
    "spelavate": "spelare",
    "spelavi": "spelare",
    "spelavo": "spelare",
    "speleologi": "speleologo",
    "speleologica": "speleologico",
    "speleologiche": "speleologico",
    "speleologici": "speleologico",
    "spelerai": "spelare",
    "speleran": "spelare",
    "speleranno": "spelare",
    "spelerebbe": "spelare",
    "spelerebber": "spelare",
    "spelerebbero": "spelare",
    "spelerei": "spelare",
    "speleremmo": "spelare",
    "speleremo": "spelare",
    "spelereste": "spelare",
    "speleresti": "spelare",
    "spelerete": "spelare",
    "spelerà": "spelare",
    "spelerò": "spelare",
    "speli": "spelare",
    "speliamo": "spelare",
    "speliate": "spelare",
    "spelin": "spelare",
    "spelino": "spelare",
    "spella": "spellare",
    "spellai": "spellare",
    "spellammo": "spellare",
    "spellan": "spellare",
    "spellando": "spellare",
    "spellano": "spellare",
    "spellante": "spellare",
    "spellanti": "spellare",
    "spellar": "spellare",
    "spellaron": "spellare",
    "spellarono": "spellare",
    "spellasse": "spellare",
    "spellasser": "spellare",
    "spellassero": "spellare",
    "spellassi": "spellare",
    "spellassimo": "spellare",
    "spellaste": "spellare",
    "spellasti": "spellare",
    "spellata": "spellare",
    "spellate": "spellare",
    "spellati": "spellare",
    "spellato": "spellare",
    "spellava": "spellare",
    "spellavamo": "spellare",
    "spellavan": "spellare",
    "spellavano": "spellare",
    "spellavate": "spellare",
    "spellavi": "spellare",
    "spellavo": "spellare",
    "spellerai": "spellare",
    "spelleran": "spellare",
    "spelleranno": "spellare",
    "spellerebbe": "spellare",
    "spellerebber": "spellare",
    "spellerebbero": "spellare",
    "spellerei": "spellare",
    "spelleremmo": "spellare",
    "spelleremo": "spellare",
    "spellereste": "spellare",
    "spelleresti": "spellare",
    "spellerete": "spellare",
    "spellerà": "spellare",
    "spellerò": "spellare",
    "spelli": "spellare",
    "spelliamo": "spellare",
    "spelliate": "spellare",
    "spellin": "spellare",
    "spellino": "spellare",
    "spello": "spellare",
    "spellò": "spellare",
    "spelo": "spelare",
    "spelonche": "spelonca",
    "spelò": "spelare",
    "spenda": "spendere",
    "spendaccioni": "spendaccione",
    "spendan": "spendere",
    "spendano": "spendere",
    "spende": "spendere",
    "spendemmo": "spendere",
    "spendendo": "spendere",
    "spendente": "spendere",
    "spendenti": "spendere",
    "spender": "spendere",
    "spenderai": "spendere",
    "spenderan": "spendere",
    "spenderanno": "spendere",
    "spenderebbe": "spendere",
    "spenderebber": "spendere",
    "spenderebbero": "spendere",
    "spenderecce": "spendereccio",
    "spenderecci": "spendereccio",
    "spendereccia": "spendereccio",
    "spenderei": "spendere",
    "spenderemmo": "spendere",
    "spenderemo": "spendere",
    "spendereste": "spendere",
    "spenderesti": "spendere",
    "spenderete": "spendere",
    "spenderà": "spendere",
    "spenderò": "spendere",
    "spendesse": "spendere",
    "spendesser": "spendere",
    "spendessero": "spendere",
    "spendessi": "spendere",
    "spendessimo": "spendere",
    "spendeste": "spendere",
    "spendesti": "spendere",
    "spendete": "spendere",
    "spendeva": "spendere",
    "spendevamo": "spendere",
    "spendevan": "spendere",
    "spendevano": "spendere",
    "spendevate": "spendere",
    "spendevi": "spendere",
    "spendevo": "spendere",
    "spendi": "spendere",
    "spendiamo": "spendere",
    "spendiate": "spendere",
    "spendo": "spendere",
    "spendon": "spendere",
    "spendono": "spendere",
    "spenga": "spengere",
    "spengan": "spengere",
    "spengano": "spengere",
    "spenge": "spengere",
    "spengemmo": "spengere",
    "spengendo": "spengere",
    "spengente": "spengere",
    "spengenti": "spengere",
    "spenger": "spengere",
    "spengerai": "spengere",
    "spengeran": "spengere",
    "spengeranno": "spengere",
    "spengerebbe": "spengere",
    "spengerebber": "spengere",
    "spengerebbero": "spengere",
    "spengerei": "spengere",
    "spengeremmo": "spengere",
    "spengeremo": "spengere",
    "spengereste": "spengere",
    "spengeresti": "spengere",
    "spengerete": "spengere",
    "spengerà": "spengere",
    "spengerò": "spengere",
    "spengesse": "spengere",
    "spengesser": "spengere",
    "spengessero": "spengere",
    "spengessi": "spengere",
    "spengessimo": "spengere",
    "spengeste": "spengere",
    "spengesti": "spengere",
    "spengete": "spengere",
    "spengeva": "spengere",
    "spengevamo": "spengere",
    "spengevan": "spengere",
    "spengevano": "spengere",
    "spengevate": "spengere",
    "spengevi": "spengere",
    "spengevo": "spengere",
    "spengi": "spengere",
    "spengiamo": "spengere",
    "spengiate": "spengere",
    "spengo": "spengere",
    "spengon": "spengere",
    "spengono": "spengere",
    "spenna": "spennare",
    "spennacchi": "spennacchiare",
    "spennacchia": "spennacchiare",
    "spennacchiai": "spennacchiare",
    "spennacchiammo": "spennacchiare",
    "spennacchiamo": "spennacchiare",
    "spennacchian": "spennacchiare",
    "spennacchiando": "spennacchiare",
    "spennacchiano": "spennacchiare",
    "spennacchiante": "spennacchiare",
    "spennacchianti": "spennacchiare",
    "spennacchiar": "spennacchiare",
    "spennacchiaron": "spennacchiare",
    "spennacchiarono": "spennacchiare",
    "spennacchiasse": "spennacchiare",
    "spennacchiasser": "spennacchiare",
    "spennacchiassero": "spennacchiare",
    "spennacchiassi": "spennacchiare",
    "spennacchiassimo": "spennacchiare",
    "spennacchiaste": "spennacchiare",
    "spennacchiasti": "spennacchiare",
    "spennacchiata": "spennacchiare",
    "spennacchiate": "spennacchiare",
    "spennacchiati": "spennacchiare",
    "spennacchiato": "spennacchiare",
    "spennacchiava": "spennacchiare",
    "spennacchiavamo": "spennacchiare",
    "spennacchiavan": "spennacchiare",
    "spennacchiavano": "spennacchiare",
    "spennacchiavate": "spennacchiare",
    "spennacchiavi": "spennacchiare",
    "spennacchiavo": "spennacchiare",
    "spennacchierai": "spennacchiare",
    "spennacchieran": "spennacchiare",
    "spennacchieranno": "spennacchiare",
    "spennacchierebbe": "spennacchiare",
    "spennacchierebber": "spennacchiare",
    "spennacchierebbero": "spennacchiare",
    "spennacchierei": "spennacchiare",
    "spennacchieremmo": "spennacchiare",
    "spennacchieremo": "spennacchiare",
    "spennacchiereste": "spennacchiare",
    "spennacchieresti": "spennacchiare",
    "spennacchierete": "spennacchiare",
    "spennacchierà": "spennacchiare",
    "spennacchierò": "spennacchiare",
    "spennacchin": "spennacchiare",
    "spennacchino": "spennacchiare",
    "spennacchio": "spennacchiare",
    "spennacchiò": "spennacchiare",
    "spennai": "spennare",
    "spennammo": "spennare",
    "spennan": "spennare",
    "spennando": "spennare",
    "spennano": "spennare",
    "spennante": "spennare",
    "spennanti": "spennare",
    "spennar": "spennare",
    "spennaron": "spennare",
    "spennarono": "spennare",
    "spennasse": "spennare",
    "spennasser": "spennare",
    "spennassero": "spennare",
    "spennassi": "spennare",
    "spennassimo": "spennare",
    "spennaste": "spennare",
    "spennasti": "spennare",
    "spennata": "spennare",
    "spennate": "spennare",
    "spennati": "spennare",
    "spennato": "spennare",
    "spennava": "spennare",
    "spennavamo": "spennare",
    "spennavan": "spennare",
    "spennavano": "spennare",
    "spennavate": "spennare",
    "spennavi": "spennare",
    "spennavo": "spennare",
    "spennella": "spennellare",
    "spennellai": "spennellare",
    "spennellammo": "spennellare",
    "spennellan": "spennellare",
    "spennellando": "spennellare",
    "spennellano": "spennellare",
    "spennellante": "spennellare",
    "spennellanti": "spennellare",
    "spennellar": "spennellare",
    "spennellaron": "spennellare",
    "spennellarono": "spennellare",
    "spennellasse": "spennellare",
    "spennellasser": "spennellare",
    "spennellassero": "spennellare",
    "spennellassi": "spennellare",
    "spennellassimo": "spennellare",
    "spennellaste": "spennellare",
    "spennellasti": "spennellare",
    "spennellata": "spennellare",
    "spennellate": "spennellare",
    "spennellati": "spennellare",
    "spennellato": "spennellare",
    "spennellava": "spennellare",
    "spennellavamo": "spennellare",
    "spennellavan": "spennellare",
    "spennellavano": "spennellare",
    "spennellavate": "spennellare",
    "spennellavi": "spennellare",
    "spennellavo": "spennellare",
    "spennellerai": "spennellare",
    "spennelleran": "spennellare",
    "spennelleranno": "spennellare",
    "spennellerebbe": "spennellare",
    "spennellerebber": "spennellare",
    "spennellerebbero": "spennellare",
    "spennellerei": "spennellare",
    "spennelleremmo": "spennellare",
    "spennelleremo": "spennellare",
    "spennellereste": "spennellare",
    "spennelleresti": "spennellare",
    "spennellerete": "spennellare",
    "spennellerà": "spennellare",
    "spennellerò": "spennellare",
    "spennelli": "spennellare",
    "spennelliamo": "spennellare",
    "spennelliate": "spennellare",
    "spennellin": "spennellare",
    "spennellino": "spennellare",
    "spennello": "spennellare",
    "spennellò": "spennellare",
    "spennerai": "spennare",
    "spenneran": "spennare",
    "spenneranno": "spennare",
    "spennerebbe": "spennare",
    "spennerebber": "spennare",
    "spennerebbero": "spennare",
    "spennerei": "spennare",
    "spenneremmo": "spennare",
    "spenneremo": "spennare",
    "spennereste": "spennare",
    "spenneresti": "spennare",
    "spennerete": "spennare",
    "spennerà": "spennare",
    "spennerò": "spennare",
    "spenni": "spennare",
    "spenniamo": "spennare",
    "spenniate": "spennare",
    "spennin": "spennare",
    "spennino": "spennare",
    "spenno": "spennare",
    "spennò": "spennare",
    "spenser": "spengere",
    "spensero": "spengere",
    "spensi": "spengere",
    "spensierata": "spensierato",
    "spensierate": "spensierato",
    "spensieratezze": "spensieratezza",
    "spensierati": "spensierato",
    "spensè": "spengere",
    "spenta": "spento",
    "spente": "spento",
    "spenti": "spento",
    "spento": "spengere",
    "spenzola": "spenzolare",
    "spenzolai": "spenzolare",
    "spenzolammo": "spenzolare",
    "spenzolan": "spenzolare",
    "spenzolando": "spenzolare",
    "spenzolano": "spenzolare",
    "spenzolante": "spenzolare",
    "spenzolanti": "spenzolare",
    "spenzolar": "spenzolare",
    "spenzolaron": "spenzolare",
    "spenzolarono": "spenzolare",
    "spenzolasse": "spenzolare",
    "spenzolasser": "spenzolare",
    "spenzolassero": "spenzolare",
    "spenzolassi": "spenzolare",
    "spenzolassimo": "spenzolare",
    "spenzolaste": "spenzolare",
    "spenzolasti": "spenzolare",
    "spenzolata": "spenzolare",
    "spenzolate": "spenzolare",
    "spenzolati": "spenzolare",
    "spenzolato": "spenzolare",
    "spenzolava": "spenzolare",
    "spenzolavamo": "spenzolare",
    "spenzolavan": "spenzolare",
    "spenzolavano": "spenzolare",
    "spenzolavate": "spenzolare",
    "spenzolavi": "spenzolare",
    "spenzolavo": "spenzolare",
    "spenzolerai": "spenzolare",
    "spenzoleran": "spenzolare",
    "spenzoleranno": "spenzolare",
    "spenzolerebbe": "spenzolare",
    "spenzolerebber": "spenzolare",
    "spenzolerebbero": "spenzolare",
    "spenzolerei": "spenzolare",
    "spenzoleremmo": "spenzolare",
    "spenzoleremo": "spenzolare",
    "spenzolereste": "spenzolare",
    "spenzoleresti": "spenzolare",
    "spenzolerete": "spenzolare",
    "spenzolerà": "spenzolare",
    "spenzolerò": "spenzolare",
    "spenzoli": "spenzolare",
    "spenzoliamo": "spenzolare",
    "spenzoliate": "spenzolare",
    "spenzolin": "spenzolare",
    "spenzolino": "spenzolare",
    "spenzolo": "spenzolare",
    "spenzolò": "spenzolare",
    "spera": "sperare",
    "sperabili": "sperabile",
    "sperai": "sperare",
    "sperammo": "sperare",
    "speran": "sperare",
    "sperando": "sperare",
    "sperano": "sperare",
    "sperante": "sperare",
    "speranti": "sperare",
    "speranze": "speranza",
    "speranzosa": "speranzoso",
    "speranzose": "speranzoso",
    "speranzosi": "speranzoso",
    "sperar": "sperare",
    "speraron": "sperare",
    "sperarono": "sperare",
    "sperasse": "sperare",
    "sperasser": "sperare",
    "sperassero": "sperare",
    "sperassi": "sperare",
    "sperassimo": "sperare",
    "speraste": "sperare",
    "sperasti": "sperare",
    "sperata": "sperare",
    "sperate": "sperare",
    "sperati": "sperare",
    "sperato": "sperare",
    "sperava": "sperare",
    "speravamo": "sperare",
    "speravan": "sperare",
    "speravano": "sperare",
    "speravate": "sperare",
    "speravi": "sperare",
    "speravo": "sperare",
    "sperda": "sperdere",
    "sperdan": "sperdere",
    "sperdano": "sperdere",
    "sperde": "sperdere",
    "sperdemmo": "sperdere",
    "sperdendo": "sperdere",
    "sperdente": "sperdere",
    "sperdenti": "sperdere",
    "sperder": "sperdere",
    "sperderai": "sperdere",
    "sperderan": "sperdere",
    "sperderanno": "sperdere",
    "sperderebbe": "sperdere",
    "sperderebber": "sperdere",
    "sperderebbero": "sperdere",
    "sperderei": "sperdere",
    "sperderemmo": "sperdere",
    "sperderemo": "sperdere",
    "sperdereste": "sperdere",
    "sperderesti": "sperdere",
    "sperderete": "sperdere",
    "sperderà": "sperdere",
    "sperderò": "sperdere",
    "sperdesse": "sperdere",
    "sperdesser": "sperdere",
    "sperdessero": "sperdere",
    "sperdessi": "sperdere",
    "sperdessimo": "sperdere",
    "sperdeste": "sperdere",
    "sperdesti": "sperdere",
    "sperdete": "sperdere",
    "sperdeva": "sperdere",
    "sperdevamo": "sperdere",
    "sperdevan": "sperdere",
    "sperdevano": "sperdere",
    "sperdevate": "sperdere",
    "sperdevi": "sperdere",
    "sperdevo": "sperdere",
    "sperdi": "sperdere",
    "sperdiamo": "sperdere",
    "sperdiate": "sperdere",
    "sperdo": "sperdere",
    "sperdon": "sperdere",
    "sperdono": "sperdere",
    "sperduta": "sperduto",
    "sperdute": "sperduto",
    "sperduti": "sperduto",
    "sperequa": "sperequare",
    "sperequai": "sperequare",
    "sperequammo": "sperequare",
    "sperequan": "sperequare",
    "sperequando": "sperequare",
    "sperequano": "sperequare",
    "sperequante": "sperequare",
    "sperequanti": "sperequare",
    "sperequar": "sperequare",
    "sperequaron": "sperequare",
    "sperequarono": "sperequare",
    "sperequasse": "sperequare",
    "sperequasser": "sperequare",
    "sperequassero": "sperequare",
    "sperequassi": "sperequare",
    "sperequassimo": "sperequare",
    "sperequaste": "sperequare",
    "sperequasti": "sperequare",
    "sperequata": "sperequato",
    "sperequate": "sperequato",
    "sperequati": "sperequato",
    "sperequato": "sperequare",
    "sperequava": "sperequare",
    "sperequavamo": "sperequare",
    "sperequavan": "sperequare",
    "sperequavano": "sperequare",
    "sperequavate": "sperequare",
    "sperequavi": "sperequare",
    "sperequavo": "sperequare",
    "sperequazioni": "sperequazione",
    "sperequerai": "sperequare",
    "sperequeran": "sperequare",
    "sperequeranno": "sperequare",
    "sperequerebbe": "sperequare",
    "sperequerebber": "sperequare",
    "sperequerebbero": "sperequare",
    "sperequerei": "sperequare",
    "sperequeremmo": "sperequare",
    "sperequeremo": "sperequare",
    "sperequereste": "sperequare",
    "sperequeresti": "sperequare",
    "sperequerete": "sperequare",
    "sperequerà": "sperequare",
    "sperequerò": "sperequare",
    "sperequi": "sperequare",
    "sperequiamo": "sperequare",
    "sperequiate": "sperequare",
    "sperequin": "sperequare",
    "sperequino": "sperequare",
    "sperequo": "sperequare",
    "sperequò": "sperequare",
    "spererai": "sperare",
    "spereran": "sperare",
    "spereranno": "sperare",
    "spererebbe": "sperare",
    "spererebber": "sperare",
    "spererebbero": "sperare",
    "spererei": "sperare",
    "spereremmo": "sperare",
    "spereremo": "sperare",
    "sperereste": "sperare",
    "spereresti": "sperare",
    "spererete": "sperare",
    "spererà": "sperare",
    "spererò": "sperare",
    "spergiura": "spergiurare",
    "spergiurai": "spergiurare",
    "spergiurammo": "spergiurare",
    "spergiuran": "spergiurare",
    "spergiurando": "spergiurare",
    "spergiurano": "spergiurare",
    "spergiurante": "spergiurare",
    "spergiuranti": "spergiurare",
    "spergiurar": "spergiurare",
    "spergiuraron": "spergiurare",
    "spergiurarono": "spergiurare",
    "spergiurasse": "spergiurare",
    "spergiurasser": "spergiurare",
    "spergiurassero": "spergiurare",
    "spergiurassi": "spergiurare",
    "spergiurassimo": "spergiurare",
    "spergiuraste": "spergiurare",
    "spergiurasti": "spergiurare",
    "spergiurata": "spergiurare",
    "spergiurate": "spergiurare",
    "spergiurati": "spergiurare",
    "spergiurato": "spergiurare",
    "spergiurava": "spergiurare",
    "spergiuravamo": "spergiurare",
    "spergiuravan": "spergiurare",
    "spergiuravano": "spergiurare",
    "spergiuravate": "spergiurare",
    "spergiuravi": "spergiurare",
    "spergiuravo": "spergiurare",
    "spergiurerai": "spergiurare",
    "spergiureran": "spergiurare",
    "spergiureranno": "spergiurare",
    "spergiurerebbe": "spergiurare",
    "spergiurerebber": "spergiurare",
    "spergiurerebbero": "spergiurare",
    "spergiurerei": "spergiurare",
    "spergiureremmo": "spergiurare",
    "spergiureremo": "spergiurare",
    "spergiurereste": "spergiurare",
    "spergiureresti": "spergiurare",
    "spergiurerete": "spergiurare",
    "spergiurerà": "spergiurare",
    "spergiurerò": "spergiurare",
    "spergiuri": "spergiurare",
    "spergiuriamo": "spergiurare",
    "spergiuriate": "spergiurare",
    "spergiurin": "spergiurare",
    "spergiurino": "spergiurare",
    "spergiuro": "spergiurare",
    "spergiurò": "spergiurare",
    "speri": "sperare",
    "speriamo": "sperare",
    "speriate": "sperare",
    "spericola": "spericolare",
    "spericolai": "spericolare",
    "spericolammo": "spericolare",
    "spericolan": "spericolare",
    "spericolando": "spericolare",
    "spericolano": "spericolare",
    "spericolar": "spericolare",
    "spericolaron": "spericolare",
    "spericolarono": "spericolare",
    "spericolasse": "spericolare",
    "spericolasser": "spericolare",
    "spericolassero": "spericolare",
    "spericolassi": "spericolare",
    "spericolassimo": "spericolare",
    "spericolaste": "spericolare",
    "spericolasti": "spericolare",
    "spericolata": "spericolato",
    "spericolate": "spericolato",
    "spericolatezze": "spericolatezza",
    "spericolati": "spericolato",
    "spericolato": "spericolare",
    "spericolava": "spericolare",
    "spericolavamo": "spericolare",
    "spericolavan": "spericolare",
    "spericolavano": "spericolare",
    "spericolavate": "spericolare",
    "spericolavi": "spericolare",
    "spericolavo": "spericolare",
    "spericolerai": "spericolare",
    "spericoleran": "spericolare",
    "spericoleranno": "spericolare",
    "spericolerebbe": "spericolare",
    "spericolerebber": "spericolare",
    "spericolerebbero": "spericolare",
    "spericolerei": "spericolare",
    "spericoleremmo": "spericolare",
    "spericoleremo": "spericolare",
    "spericolereste": "spericolare",
    "spericoleresti": "spericolare",
    "spericolerete": "spericolare",
    "spericolerà": "spericolare",
    "spericolerò": "spericolare",
    "spericoli": "spericolare",
    "spericoliamo": "spericolare",
    "spericoliate": "spericolare",
    "spericolin": "spericolare",
    "spericolino": "spericolare",
    "spericolo": "spericolare",
    "spericolò": "spericolare",
    "sperimenta": "sperimentare",
    "sperimentai": "sperimentare",
    "sperimentali": "sperimentale",
    "sperimentalismi": "sperimentalismo",
    "sperimentammo": "sperimentare",
    "sperimentan": "sperimentare",
    "sperimentando": "sperimentare",
    "sperimentano": "sperimentare",
    "sperimentante": "sperimentare",
    "sperimentanti": "sperimentare",
    "sperimentar": "sperimentare",
    "sperimentaron": "sperimentare",
    "sperimentarono": "sperimentare",
    "sperimentasse": "sperimentare",
    "sperimentasser": "sperimentare",
    "sperimentassero": "sperimentare",
    "sperimentassi": "sperimentare",
    "sperimentassimo": "sperimentare",
    "sperimentaste": "sperimentare",
    "sperimentasti": "sperimentare",
    "sperimentata": "sperimentato",
    "sperimentate": "sperimentato",
    "sperimentati": "sperimentato",
    "sperimentato": "sperimentare",
    "sperimentatori": "sperimentatore",
    "sperimentava": "sperimentare",
    "sperimentavamo": "sperimentare",
    "sperimentavan": "sperimentare",
    "sperimentavano": "sperimentare",
    "sperimentavate": "sperimentare",
    "sperimentavi": "sperimentare",
    "sperimentavo": "sperimentare",
    "sperimentazioni": "sperimentazione",
    "sperimenterai": "sperimentare",
    "sperimenteran": "sperimentare",
    "sperimenteranno": "sperimentare",
    "sperimenterebbe": "sperimentare",
    "sperimenterebber": "sperimentare",
    "sperimenterebbero": "sperimentare",
    "sperimenterei": "sperimentare",
    "sperimenteremmo": "sperimentare",
    "sperimenteremo": "sperimentare",
    "sperimentereste": "sperimentare",
    "sperimenteresti": "sperimentare",
    "sperimenterete": "sperimentare",
    "sperimenterà": "sperimentare",
    "sperimenterò": "sperimentare",
    "sperimenti": "sperimentare",
    "sperimentiamo": "sperimentare",
    "sperimentiate": "sperimentare",
    "sperimentin": "sperimentare",
    "sperimentino": "sperimentare",
    "sperimento": "sperimentare",
    "sperimentò": "sperimentare",
    "sperin": "sperare",
    "sperino": "sperare",
    "spermatozoi": "spermatozoo",
    "spermi": "sperma",
    "spero": "sperare",
    "sperona": "speronare",
    "speronai": "speronare",
    "speronamenti": "speronamento",
    "speronammo": "speronare",
    "speronan": "speronare",
    "speronando": "speronare",
    "speronano": "speronare",
    "speronante": "speronare",
    "speronanti": "speronare",
    "speronar": "speronare",
    "speronaron": "speronare",
    "speronarono": "speronare",
    "speronasse": "speronare",
    "speronasser": "speronare",
    "speronassero": "speronare",
    "speronassi": "speronare",
    "speronassimo": "speronare",
    "speronaste": "speronare",
    "speronasti": "speronare",
    "speronata": "speronare",
    "speronate": "speronare",
    "speronati": "speronare",
    "speronato": "speronare",
    "speronava": "speronare",
    "speronavamo": "speronare",
    "speronavan": "speronare",
    "speronavano": "speronare",
    "speronavate": "speronare",
    "speronavi": "speronare",
    "speronavo": "speronare",
    "speronerai": "speronare",
    "speroneran": "speronare",
    "speroneranno": "speronare",
    "speronerebbe": "speronare",
    "speronerebber": "speronare",
    "speronerebbero": "speronare",
    "speronerei": "speronare",
    "speroneremmo": "speronare",
    "speroneremo": "speronare",
    "speronereste": "speronare",
    "speroneresti": "speronare",
    "speronerete": "speronare",
    "speronerà": "speronare",
    "speronerò": "speronare",
    "speroni": "sperone",
    "speroniamo": "speronare",
    "speroniate": "speronare",
    "speronin": "speronare",
    "speronino": "speronare",
    "sperono": "speronare",
    "speronò": "speronare",
    "sperpera": "sperperare",
    "sperperai": "sperperare",
    "sperperammo": "sperperare",
    "sperperan": "sperperare",
    "sperperando": "sperperare",
    "sperperano": "sperperare",
    "sperperante": "sperperare",
    "sperperanti": "sperperare",
    "sperperar": "sperperare",
    "sperperaron": "sperperare",
    "sperperarono": "sperperare",
    "sperperasse": "sperperare",
    "sperperasser": "sperperare",
    "sperperassero": "sperperare",
    "sperperassi": "sperperare",
    "sperperassimo": "sperperare",
    "sperperaste": "sperperare",
    "sperperasti": "sperperare",
    "sperperata": "sperperare",
    "sperperate": "sperperare",
    "sperperati": "sperperare",
    "sperperato": "sperperare",
    "sperperava": "sperperare",
    "sperperavamo": "sperperare",
    "sperperavan": "sperperare",
    "sperperavano": "sperperare",
    "sperperavate": "sperperare",
    "sperperavi": "sperperare",
    "sperperavo": "sperperare",
    "sperpererai": "sperperare",
    "sperpereran": "sperperare",
    "sperpereranno": "sperperare",
    "sperpererebbe": "sperperare",
    "sperpererebber": "sperperare",
    "sperpererebbero": "sperperare",
    "sperpererei": "sperperare",
    "sperpereremmo": "sperperare",
    "sperpereremo": "sperperare",
    "sperperereste": "sperperare",
    "sperpereresti": "sperperare",
    "sperpererete": "sperperare",
    "sperpererà": "sperperare",
    "sperpererò": "sperperare",
    "sperperi": "sperpero",
    "sperperiamo": "sperperare",
    "sperperiate": "sperperare",
    "sperperin": "sperperare",
    "sperperino": "sperperare",
    "sperpero": "sperperare",
    "sperperò": "sperperare",
    "spersa": "sperdere",
    "sperse": "sperdere",
    "sperser": "sperdere",
    "spersero": "sperdere",
    "spersi": "sperdere",
    "sperso": "sperdere",
    "spersonalizza": "spersonalizzare",
    "spersonalizzai": "spersonalizzare",
    "spersonalizzammo": "spersonalizzare",
    "spersonalizzan": "spersonalizzare",
    "spersonalizzando": "spersonalizzare",
    "spersonalizzano": "spersonalizzare",
    "spersonalizzante": "spersonalizzare",
    "spersonalizzanti": "spersonalizzare",
    "spersonalizzar": "spersonalizzare",
    "spersonalizzaron": "spersonalizzare",
    "spersonalizzarono": "spersonalizzare",
    "spersonalizzasse": "spersonalizzare",
    "spersonalizzasser": "spersonalizzare",
    "spersonalizzassero": "spersonalizzare",
    "spersonalizzassi": "spersonalizzare",
    "spersonalizzassimo": "spersonalizzare",
    "spersonalizzaste": "spersonalizzare",
    "spersonalizzasti": "spersonalizzare",
    "spersonalizzata": "spersonalizzare",
    "spersonalizzate": "spersonalizzare",
    "spersonalizzati": "spersonalizzare",
    "spersonalizzato": "spersonalizzare",
    "spersonalizzava": "spersonalizzare",
    "spersonalizzavamo": "spersonalizzare",
    "spersonalizzavan": "spersonalizzare",
    "spersonalizzavano": "spersonalizzare",
    "spersonalizzavate": "spersonalizzare",
    "spersonalizzavi": "spersonalizzare",
    "spersonalizzavo": "spersonalizzare",
    "spersonalizzerai": "spersonalizzare",
    "spersonalizzeran": "spersonalizzare",
    "spersonalizzeranno": "spersonalizzare",
    "spersonalizzerebbe": "spersonalizzare",
    "spersonalizzerebber": "spersonalizzare",
    "spersonalizzerebbero": "spersonalizzare",
    "spersonalizzerei": "spersonalizzare",
    "spersonalizzeremmo": "spersonalizzare",
    "spersonalizzeremo": "spersonalizzare",
    "spersonalizzereste": "spersonalizzare",
    "spersonalizzeresti": "spersonalizzare",
    "spersonalizzerete": "spersonalizzare",
    "spersonalizzerà": "spersonalizzare",
    "spersonalizzerò": "spersonalizzare",
    "spersonalizzi": "spersonalizzare",
    "spersonalizziamo": "spersonalizzare",
    "spersonalizziate": "spersonalizzare",
    "spersonalizzin": "spersonalizzare",
    "spersonalizzino": "spersonalizzare",
    "spersonalizzo": "spersonalizzare",
    "spersonalizzò": "spersonalizzare",
    "spersè": "sperdere",
    "spertica": "sperticare",
    "sperticai": "sperticare",
    "sperticammo": "sperticare",
    "spertican": "sperticare",
    "sperticando": "sperticare",
    "sperticano": "sperticare",
    "sperticante": "sperticare",
    "sperticanti": "sperticare",
    "sperticar": "sperticare",
    "sperticaron": "sperticare",
    "sperticarono": "sperticare",
    "sperticasse": "sperticare",
    "sperticasser": "sperticare",
    "sperticassero": "sperticare",
    "sperticassi": "sperticare",
    "sperticassimo": "sperticare",
    "sperticaste": "sperticare",
    "sperticasti": "sperticare",
    "sperticata": "sperticato",
    "sperticate": "sperticato",
    "sperticati": "sperticato",
    "sperticato": "sperticare",
    "sperticava": "sperticare",
    "sperticavamo": "sperticare",
    "sperticavan": "sperticare",
    "sperticavano": "sperticare",
    "sperticavate": "sperticare",
    "sperticavi": "sperticare",
    "sperticavo": "sperticare",
    "sperticherai": "sperticare",
    "sperticheran": "sperticare",
    "sperticheranno": "sperticare",
    "sperticherebbe": "sperticare",
    "sperticherebber": "sperticare",
    "sperticherebbero": "sperticare",
    "sperticherei": "sperticare",
    "sperticheremmo": "sperticare",
    "sperticheremo": "sperticare",
    "spertichereste": "sperticare",
    "sperticheresti": "sperticare",
    "sperticherete": "sperticare",
    "sperticherà": "sperticare",
    "sperticherò": "sperticare",
    "spertichi": "sperticare",
    "spertichiamo": "sperticare",
    "spertichiate": "sperticare",
    "spertichin": "sperticare",
    "spertichino": "sperticare",
    "spertico": "sperticare",
    "sperticò": "sperticare",
    "sperò": "sperare",
    "spesa": "spesare",
    "spesai": "spesare",
    "spesammo": "spesare",
    "spesan": "spesare",
    "spesando": "spesare",
    "spesano": "spesare",
    "spesante": "spesare",
    "spesanti": "spesare",
    "spesar": "spesare",
    "spesaron": "spesare",
    "spesarono": "spesare",
    "spesasse": "spesare",
    "spesasser": "spesare",
    "spesassero": "spesare",
    "spesassi": "spesare",
    "spesassimo": "spesare",
    "spesaste": "spesare",
    "spesasti": "spesare",
    "spesata": "spesare",
    "spesate": "spesare",
    "spesati": "spesare",
    "spesato": "spesare",
    "spesava": "spesare",
    "spesavamo": "spesare",
    "spesavan": "spesare",
    "spesavano": "spesare",
    "spesavate": "spesare",
    "spesavi": "spesare",
    "spesavo": "spesare",
    "spese": "spesa",
    "speser": "spendere",
    "speserai": "spesare",
    "speseran": "spesare",
    "speseranno": "spesare",
    "speserebbe": "spesare",
    "speserebber": "spesare",
    "speserebbero": "spesare",
    "speserei": "spesare",
    "speseremmo": "spesare",
    "speseremo": "spesare",
    "spesereste": "spesare",
    "speseresti": "spesare",
    "speserete": "spesare",
    "spesero": "spendere",
    "speserà": "spesare",
    "speserò": "spesare",
    "spesi": "spesare",
    "spesiamo": "spesare",
    "spesiate": "spesare",
    "spesin": "spesare",
    "spesino": "spesare",
    "speso": "spesare",
    "spessa": "spesso",
    "spesse": "spesso",
    "spessi": "spesso",
    "spessissa": "spessisso",
    "spessisse": "spessisso",
    "spessissi": "spessisso",
    "spessori": "spessore",
    "spesè": "spendere",
    "spesò": "spesare",
    "spetta": "spettare",
    "spettacolari": "spettacolare",
    "spettacolarizzazioni": "spettacolarizzazione",
    "spettacoli": "spettacolo",
    "spettacolini": "spettacolino",
    "spettacoloni": "spettacolone",
    "spettacolosa": "spettacoloso",
    "spettacolose": "spettacoloso",
    "spettacolosi": "spettacoloso",
    "spettai": "spettare",
    "spettammo": "spettare",
    "spettan": "spettare",
    "spettando": "spettare",
    "spettano": "spettare",
    "spettante": "spettare",
    "spettanti": "spettare",
    "spettanze": "spettanza",
    "spettar": "spettare",
    "spettaron": "spettare",
    "spettarono": "spettare",
    "spettasse": "spettare",
    "spettasser": "spettare",
    "spettassero": "spettare",
    "spettassi": "spettare",
    "spettassimo": "spettare",
    "spettaste": "spettare",
    "spettasti": "spettare",
    "spettata": "spettare",
    "spettate": "spettare",
    "spettati": "spettare",
    "spettato": "spettare",
    "spettatori": "spettatore",
    "spettatrice": "spettatore",
    "spettatrici": "spettatrice",
    "spettava": "spettare",
    "spettavamo": "spettare",
    "spettavan": "spettare",
    "spettavano": "spettare",
    "spettavate": "spettare",
    "spettavi": "spettare",
    "spettavo": "spettare",
    "spettegola": "spettegolare",
    "spettegolai": "spettegolare",
    "spettegolammo": "spettegolare",
    "spettegolan": "spettegolare",
    "spettegolando": "spettegolare",
    "spettegolano": "spettegolare",
    "spettegolante": "spettegolare",
    "spettegolanti": "spettegolare",
    "spettegolar": "spettegolare",
    "spettegolaron": "spettegolare",
    "spettegolarono": "spettegolare",
    "spettegolasse": "spettegolare",
    "spettegolasser": "spettegolare",
    "spettegolassero": "spettegolare",
    "spettegolassi": "spettegolare",
    "spettegolassimo": "spettegolare",
    "spettegolaste": "spettegolare",
    "spettegolasti": "spettegolare",
    "spettegolata": "spettegolare",
    "spettegolate": "spettegolare",
    "spettegolati": "spettegolare",
    "spettegolato": "spettegolare",
    "spettegolava": "spettegolare",
    "spettegolavamo": "spettegolare",
    "spettegolavan": "spettegolare",
    "spettegolavano": "spettegolare",
    "spettegolavate": "spettegolare",
    "spettegolavi": "spettegolare",
    "spettegolavo": "spettegolare",
    "spettegolerai": "spettegolare",
    "spettegoleran": "spettegolare",
    "spettegoleranno": "spettegolare",
    "spettegolerebbe": "spettegolare",
    "spettegolerebber": "spettegolare",
    "spettegolerebbero": "spettegolare",
    "spettegolerei": "spettegolare",
    "spettegoleremmo": "spettegolare",
    "spettegoleremo": "spettegolare",
    "spettegolereste": "spettegolare",
    "spettegoleresti": "spettegolare",
    "spettegolerete": "spettegolare",
    "spettegolerà": "spettegolare",
    "spettegolerò": "spettegolare",
    "spettegoli": "spettegolare",
    "spettegoliamo": "spettegolare",
    "spettegoliate": "spettegolare",
    "spettegolin": "spettegolare",
    "spettegolino": "spettegolare",
    "spettegolo": "spettegolare",
    "spettegolò": "spettegolare",
    "spetterai": "spettare",
    "spetteran": "spettare",
    "spetteranno": "spettare",
    "spetterebbe": "spettare",
    "spetterebber": "spettare",
    "spetterebbero": "spettare",
    "spetterei": "spettare",
    "spetteremmo": "spettare",
    "spetteremo": "spettare",
    "spettereste": "spettare",
    "spetteresti": "spettare",
    "spetterete": "spettare",
    "spetterà": "spettare",
    "spetterò": "spettare",
    "spetti": "spettare",
    "spettiamo": "spettare",
    "spettiate": "spettare",
    "spettin": "spettare",
    "spettina": "spettinare",
    "spettinai": "spettinare",
    "spettinammo": "spettinare",
    "spettinan": "spettinare",
    "spettinando": "spettinare",
    "spettinano": "spettinare",
    "spettinante": "spettinare",
    "spettinanti": "spettinare",
    "spettinar": "spettinare",
    "spettinaron": "spettinare",
    "spettinarono": "spettinare",
    "spettinasse": "spettinare",
    "spettinasser": "spettinare",
    "spettinassero": "spettinare",
    "spettinassi": "spettinare",
    "spettinassimo": "spettinare",
    "spettinaste": "spettinare",
    "spettinasti": "spettinare",
    "spettinata": "spettinare",
    "spettinate": "spettinare",
    "spettinati": "spettinare",
    "spettinato": "spettinare",
    "spettinava": "spettinare",
    "spettinavamo": "spettinare",
    "spettinavan": "spettinare",
    "spettinavano": "spettinare",
    "spettinavate": "spettinare",
    "spettinavi": "spettinare",
    "spettinavo": "spettinare",
    "spettinerai": "spettinare",
    "spettineran": "spettinare",
    "spettineranno": "spettinare",
    "spettinerebbe": "spettinare",
    "spettinerebber": "spettinare",
    "spettinerebbero": "spettinare",
    "spettinerei": "spettinare",
    "spettineremmo": "spettinare",
    "spettineremo": "spettinare",
    "spettinereste": "spettinare",
    "spettineresti": "spettinare",
    "spettinerete": "spettinare",
    "spettinerà": "spettinare",
    "spettinerò": "spettinare",
    "spettini": "spettinare",
    "spettiniamo": "spettinare",
    "spettiniate": "spettinare",
    "spettinin": "spettinare",
    "spettinino": "spettinare",
    "spettino": "spettinare",
    "spettinò": "spettinare",
    "spetto": "spettare",
    "spettrali": "spettrale",
    "spettri": "spettro",
    "spettrometri": "spettrometro",
    "spettroscopica": "spettroscopico",
    "spettroscopiche": "spettroscopico",
    "spettroscopici": "spettroscopico",
    "spettò": "spettare",
    "spezie": "spezia",
    "spezza": "spezzare",
    "spezzai": "spezzare",
    "spezzammo": "spezzare",
    "spezzan": "spezzare",
    "spezzando": "spezzare",
    "spezzano": "spezzare",
    "spezzante": "spezzare",
    "spezzanti": "spezzare",
    "spezzar": "spezzare",
    "spezzaron": "spezzare",
    "spezzarono": "spezzare",
    "spezzasse": "spezzare",
    "spezzasser": "spezzare",
    "spezzassero": "spezzare",
    "spezzassi": "spezzare",
    "spezzassimo": "spezzare",
    "spezzaste": "spezzare",
    "spezzasti": "spezzare",
    "spezzata": "spezzato",
    "spezzate": "spezzato",
    "spezzati": "spezzato",
    "spezzato": "spezzare",
    "spezzature": "spezzatura",
    "spezzava": "spezzare",
    "spezzavamo": "spezzare",
    "spezzavan": "spezzare",
    "spezzavano": "spezzare",
    "spezzavate": "spezzare",
    "spezzavi": "spezzare",
    "spezzavo": "spezzare",
    "spezzerai": "spezzare",
    "spezzeran": "spezzare",
    "spezzeranno": "spezzare",
    "spezzerebbe": "spezzare",
    "spezzerebber": "spezzare",
    "spezzerebbero": "spezzare",
    "spezzerei": "spezzare",
    "spezzeremmo": "spezzare",
    "spezzeremo": "spezzare",
    "spezzereste": "spezzare",
    "spezzeresti": "spezzare",
    "spezzerete": "spezzare",
    "spezzerà": "spezzare",
    "spezzerò": "spezzare",
    "spezzetta": "spezzettare",
    "spezzettai": "spezzettare",
    "spezzettammo": "spezzettare",
    "spezzettan": "spezzettare",
    "spezzettando": "spezzettare",
    "spezzettano": "spezzettare",
    "spezzettante": "spezzettare",
    "spezzettanti": "spezzettare",
    "spezzettar": "spezzettare",
    "spezzettaron": "spezzettare",
    "spezzettarono": "spezzettare",
    "spezzettasse": "spezzettare",
    "spezzettasser": "spezzettare",
    "spezzettassero": "spezzettare",
    "spezzettassi": "spezzettare",
    "spezzettassimo": "spezzettare",
    "spezzettaste": "spezzettare",
    "spezzettasti": "spezzettare",
    "spezzettata": "spezzettare",
    "spezzettate": "spezzettare",
    "spezzettati": "spezzettare",
    "spezzettato": "spezzettare",
    "spezzettava": "spezzettare",
    "spezzettavamo": "spezzettare",
    "spezzettavan": "spezzettare",
    "spezzettavano": "spezzettare",
    "spezzettavate": "spezzettare",
    "spezzettavi": "spezzettare",
    "spezzettavo": "spezzettare",
    "spezzetterai": "spezzettare",
    "spezzetteran": "spezzettare",
    "spezzetteranno": "spezzettare",
    "spezzetterebbe": "spezzettare",
    "spezzetterebber": "spezzettare",
    "spezzetterebbero": "spezzettare",
    "spezzetterei": "spezzettare",
    "spezzetteremmo": "spezzettare",
    "spezzetteremo": "spezzettare",
    "spezzettereste": "spezzettare",
    "spezzetteresti": "spezzettare",
    "spezzetterete": "spezzettare",
    "spezzetterà": "spezzettare",
    "spezzetterò": "spezzettare",
    "spezzetti": "spezzettare",
    "spezzettiamo": "spezzettare",
    "spezzettiate": "spezzettare",
    "spezzettin": "spezzettare",
    "spezzettino": "spezzettare",
    "spezzetto": "spezzettare",
    "spezzettò": "spezzettare",
    "spezzi": "spezzare",
    "spezziamo": "spezzare",
    "spezziate": "spezzare",
    "spezzin": "spezzare",
    "spezzini": "spezzino",
    "spezzino": "spezzare",
    "spezzo": "spezzare",
    "spezzona": "spezzonare",
    "spezzonai": "spezzonare",
    "spezzonammo": "spezzonare",
    "spezzonan": "spezzonare",
    "spezzonando": "spezzonare",
    "spezzonano": "spezzonare",
    "spezzonante": "spezzonare",
    "spezzonanti": "spezzonare",
    "spezzonar": "spezzonare",
    "spezzonaron": "spezzonare",
    "spezzonarono": "spezzonare",
    "spezzonasse": "spezzonare",
    "spezzonasser": "spezzonare",
    "spezzonassero": "spezzonare",
    "spezzonassi": "spezzonare",
    "spezzonassimo": "spezzonare",
    "spezzonaste": "spezzonare",
    "spezzonasti": "spezzonare",
    "spezzonata": "spezzonare",
    "spezzonate": "spezzonare",
    "spezzonati": "spezzonare",
    "spezzonato": "spezzonare",
    "spezzonava": "spezzonare",
    "spezzonavamo": "spezzonare",
    "spezzonavan": "spezzonare",
    "spezzonavano": "spezzonare",
    "spezzonavate": "spezzonare",
    "spezzonavi": "spezzonare",
    "spezzonavo": "spezzonare",
    "spezzonerai": "spezzonare",
    "spezzoneran": "spezzonare",
    "spezzoneranno": "spezzonare",
    "spezzonerebbe": "spezzonare",
    "spezzonerebber": "spezzonare",
    "spezzonerebbero": "spezzonare",
    "spezzonerei": "spezzonare",
    "spezzoneremmo": "spezzonare",
    "spezzoneremo": "spezzonare",
    "spezzonereste": "spezzonare",
    "spezzoneresti": "spezzonare",
    "spezzonerete": "spezzonare",
    "spezzonerà": "spezzonare",
    "spezzonerò": "spezzonare",
    "spezzoni": "spezzone",
    "spezzoniamo": "spezzonare",
    "spezzoniate": "spezzonare",
    "spezzonin": "spezzonare",
    "spezzonino": "spezzonare",
    "spezzono": "spezzonare",
    "spezzonò": "spezzonare",
    "spezzò": "spezzare",
    "spia": "spiare",
    "spiaccia": "spiacere",
    "spiacciamo": "spiacere",
    "spiaccian": "spiacere",
    "spiacciano": "spiacere",
    "spiacciate": "spiacere",
    "spiaccica": "spiaccicare",
    "spiaccicai": "spiaccicare",
    "spiaccicammo": "spiaccicare",
    "spiaccican": "spiaccicare",
    "spiaccicando": "spiaccicare",
    "spiaccicano": "spiaccicare",
    "spiaccicante": "spiaccicare",
    "spiaccicanti": "spiaccicare",
    "spiaccicar": "spiaccicare",
    "spiaccicaron": "spiaccicare",
    "spiaccicarono": "spiaccicare",
    "spiaccicasse": "spiaccicare",
    "spiaccicasser": "spiaccicare",
    "spiaccicassero": "spiaccicare",
    "spiaccicassi": "spiaccicare",
    "spiaccicassimo": "spiaccicare",
    "spiaccicaste": "spiaccicare",
    "spiaccicasti": "spiaccicare",
    "spiaccicata": "spiaccicare",
    "spiaccicate": "spiaccicare",
    "spiaccicati": "spiaccicare",
    "spiaccicato": "spiaccicare",
    "spiaccicava": "spiaccicare",
    "spiaccicavamo": "spiaccicare",
    "spiaccicavan": "spiaccicare",
    "spiaccicavano": "spiaccicare",
    "spiaccicavate": "spiaccicare",
    "spiaccicavi": "spiaccicare",
    "spiaccicavo": "spiaccicare",
    "spiaccicherai": "spiaccicare",
    "spiaccicheran": "spiaccicare",
    "spiaccicheranno": "spiaccicare",
    "spiaccicherebbe": "spiaccicare",
    "spiaccicherebber": "spiaccicare",
    "spiaccicherebbero": "spiaccicare",
    "spiaccicherei": "spiaccicare",
    "spiaccicheremmo": "spiaccicare",
    "spiaccicheremo": "spiaccicare",
    "spiaccichereste": "spiaccicare",
    "spiaccicheresti": "spiaccicare",
    "spiaccicherete": "spiaccicare",
    "spiaccicherà": "spiaccicare",
    "spiaccicherò": "spiaccicare",
    "spiaccichi": "spiaccicare",
    "spiaccichiamo": "spiaccicare",
    "spiaccichiate": "spiaccicare",
    "spiaccichin": "spiaccicare",
    "spiaccichino": "spiaccicare",
    "spiaccico": "spiaccicare",
    "spiaccicò": "spiaccicare",
    "spiaccio": "spiacere",
    "spiaccion": "spiacere",
    "spiacciono": "spiacere",
    "spiace": "spiacere",
    "spiacemmo": "spiacere",
    "spiacendo": "spiacere",
    "spiacente": "spiacere",
    "spiacenti": "spiacere",
    "spiacer": "spiacere",
    "spiacerai": "spiacere",
    "spiaceran": "spiacere",
    "spiaceranno": "spiacere",
    "spiacerebbe": "spiacere",
    "spiacerebber": "spiacere",
    "spiacerebbero": "spiacere",
    "spiacerei": "spiacere",
    "spiaceremmo": "spiacere",
    "spiaceremo": "spiacere",
    "spiacereste": "spiacere",
    "spiaceresti": "spiacere",
    "spiacerete": "spiacere",
    "spiacerà": "spiacere",
    "spiacerò": "spiacere",
    "spiacesse": "spiacere",
    "spiacesser": "spiacere",
    "spiacessero": "spiacere",
    "spiacessi": "spiacere",
    "spiacessimo": "spiacere",
    "spiaceste": "spiacere",
    "spiacesti": "spiacere",
    "spiacete": "spiacere",
    "spiaceva": "spiacere",
    "spiacevamo": "spiacere",
    "spiacevan": "spiacere",
    "spiacevano": "spiacere",
    "spiacevate": "spiacere",
    "spiacevi": "spiacere",
    "spiacevo": "spiacere",
    "spiacevolezze": "spiacevolezza",
    "spiacevoli": "spiacevole",
    "spiaci": "spiacere",
    "spiaciuta": "spiacere",
    "spiaciute": "spiacere",
    "spiaciuti": "spiacere",
    "spiaciuto": "spiacere",
    "spiacque": "spiacere",
    "spiacquer": "spiacere",
    "spiacquero": "spiacere",
    "spiacqui": "spiacere",
    "spiagge": "spiaggia",
    "spiaggette": "spiaggetta",
    "spiaggie": "spiaggia",
    "spiai": "spiare",
    "spiammo": "spiare",
    "spiamo": "spiare",
    "spian": "spiare",
    "spiana": "spianare",
    "spianai": "spianare",
    "spianammo": "spianare",
    "spianan": "spianare",
    "spianando": "spianare",
    "spianano": "spianare",
    "spianante": "spianare",
    "spiananti": "spianare",
    "spianar": "spianare",
    "spianaron": "spianare",
    "spianarono": "spianare",
    "spianasse": "spianare",
    "spianasser": "spianare",
    "spianassero": "spianare",
    "spianassi": "spianare",
    "spianassimo": "spianare",
    "spianaste": "spianare",
    "spianasti": "spianare",
    "spianata": "spianare",
    "spianate": "spianata",
    "spianati": "spianare",
    "spianato": "spianare",
    "spianava": "spianare",
    "spianavamo": "spianare",
    "spianavan": "spianare",
    "spianavano": "spianare",
    "spianavate": "spianare",
    "spianavi": "spianare",
    "spianavo": "spianare",
    "spiando": "spiare",
    "spianerai": "spianare",
    "spianeran": "spianare",
    "spianeranno": "spianare",
    "spianerebbe": "spianare",
    "spianerebber": "spianare",
    "spianerebbero": "spianare",
    "spianerei": "spianare",
    "spianeremmo": "spianare",
    "spianeremo": "spianare",
    "spianereste": "spianare",
    "spianeresti": "spianare",
    "spianerete": "spianare",
    "spianerà": "spianare",
    "spianerò": "spianare",
    "spiani": "spianare",
    "spianiamo": "spianare",
    "spianiate": "spianare",
    "spianin": "spianare",
    "spianino": "spianare",
    "spiano": "spiare",
    "spianta": "spiantare",
    "spiantai": "spiantare",
    "spiantammo": "spiantare",
    "spiantan": "spiantare",
    "spiantando": "spiantare",
    "spiantano": "spiantare",
    "spiantante": "spiantare",
    "spiantanti": "spiantare",
    "spiantar": "spiantare",
    "spiantaron": "spiantare",
    "spiantarono": "spiantare",
    "spiantasse": "spiantare",
    "spiantasser": "spiantare",
    "spiantassero": "spiantare",
    "spiantassi": "spiantare",
    "spiantassimo": "spiantare",
    "spiantaste": "spiantare",
    "spiantasti": "spiantare",
    "spiantata": "spiantare",
    "spiantate": "spiantare",
    "spiantati": "spiantare",
    "spiantato": "spiantare",
    "spiantava": "spiantare",
    "spiantavamo": "spiantare",
    "spiantavan": "spiantare",
    "spiantavano": "spiantare",
    "spiantavate": "spiantare",
    "spiantavi": "spiantare",
    "spiantavo": "spiantare",
    "spiante": "spiare",
    "spianterai": "spiantare",
    "spianteran": "spiantare",
    "spianteranno": "spiantare",
    "spianterebbe": "spiantare",
    "spianterebber": "spiantare",
    "spianterebbero": "spiantare",
    "spianterei": "spiantare",
    "spianteremmo": "spiantare",
    "spianteremo": "spiantare",
    "spiantereste": "spiantare",
    "spianteresti": "spiantare",
    "spianterete": "spiantare",
    "spianterà": "spiantare",
    "spianterò": "spiantare",
    "spianti": "spiare",
    "spiantiamo": "spiantare",
    "spiantiate": "spiantare",
    "spiantin": "spiantare",
    "spiantino": "spiantare",
    "spianto": "spiantare",
    "spiantò": "spiantare",
    "spianò": "spianare",
    "spiar": "spiare",
    "spiaron": "spiare",
    "spiarono": "spiare",
    "spiasse": "spiare",
    "spiasser": "spiare",
    "spiassero": "spiare",
    "spiassi": "spiare",
    "spiassimo": "spiare",
    "spiaste": "spiare",
    "spiasti": "spiare",
    "spiata": "spiare",
    "spiate": "spiata",
    "spiati": "spiare",
    "spiato": "spiare",
    "spiattella": "spiattellare",
    "spiattellai": "spiattellare",
    "spiattellammo": "spiattellare",
    "spiattellan": "spiattellare",
    "spiattellando": "spiattellare",
    "spiattellano": "spiattellare",
    "spiattellante": "spiattellare",
    "spiattellanti": "spiattellare",
    "spiattellar": "spiattellare",
    "spiattellaron": "spiattellare",
    "spiattellarono": "spiattellare",
    "spiattellasse": "spiattellare",
    "spiattellasser": "spiattellare",
    "spiattellassero": "spiattellare",
    "spiattellassi": "spiattellare",
    "spiattellassimo": "spiattellare",
    "spiattellaste": "spiattellare",
    "spiattellasti": "spiattellare",
    "spiattellata": "spiattellare",
    "spiattellate": "spiattellare",
    "spiattellati": "spiattellare",
    "spiattellato": "spiattellare",
    "spiattellava": "spiattellare",
    "spiattellavamo": "spiattellare",
    "spiattellavan": "spiattellare",
    "spiattellavano": "spiattellare",
    "spiattellavate": "spiattellare",
    "spiattellavi": "spiattellare",
    "spiattellavo": "spiattellare",
    "spiattellerai": "spiattellare",
    "spiattelleran": "spiattellare",
    "spiattelleranno": "spiattellare",
    "spiattellerebbe": "spiattellare",
    "spiattellerebber": "spiattellare",
    "spiattellerebbero": "spiattellare",
    "spiattellerei": "spiattellare",
    "spiattelleremmo": "spiattellare",
    "spiattelleremo": "spiattellare",
    "spiattellereste": "spiattellare",
    "spiattelleresti": "spiattellare",
    "spiattellerete": "spiattellare",
    "spiattellerà": "spiattellare",
    "spiattellerò": "spiattellare",
    "spiattelli": "spiattellare",
    "spiattelliamo": "spiattellare",
    "spiattelliate": "spiattellare",
    "spiattellin": "spiattellare",
    "spiattellino": "spiattellare",
    "spiattello": "spiattellare",
    "spiattellò": "spiattellare",
    "spiava": "spiare",
    "spiavamo": "spiare",
    "spiavan": "spiare",
    "spiavano": "spiare",
    "spiavate": "spiare",
    "spiavi": "spiare",
    "spiavo": "spiare",
    "spiazza": "spiazzare",
    "spiazzai": "spiazzare",
    "spiazzamenti": "spiazzamento",
    "spiazzammo": "spiazzare",
    "spiazzan": "spiazzare",
    "spiazzando": "spiazzare",
    "spiazzano": "spiazzare",
    "spiazzante": "spiazzare",
    "spiazzanti": "spiazzare",
    "spiazzar": "spiazzare",
    "spiazzaron": "spiazzare",
    "spiazzarono": "spiazzare",
    "spiazzasse": "spiazzare",
    "spiazzasser": "spiazzare",
    "spiazzassero": "spiazzare",
    "spiazzassi": "spiazzare",
    "spiazzassimo": "spiazzare",
    "spiazzaste": "spiazzare",
    "spiazzasti": "spiazzare",
    "spiazzata": "spiazzare",
    "spiazzate": "spiazzare",
    "spiazzati": "spiazzare",
    "spiazzato": "spiazzare",
    "spiazzava": "spiazzare",
    "spiazzavamo": "spiazzare",
    "spiazzavan": "spiazzare",
    "spiazzavano": "spiazzare",
    "spiazzavate": "spiazzare",
    "spiazzavi": "spiazzare",
    "spiazzavo": "spiazzare",
    "spiazzerai": "spiazzare",
    "spiazzeran": "spiazzare",
    "spiazzeranno": "spiazzare",
    "spiazzerebbe": "spiazzare",
    "spiazzerebber": "spiazzare",
    "spiazzerebbero": "spiazzare",
    "spiazzerei": "spiazzare",
    "spiazzeremmo": "spiazzare",
    "spiazzeremo": "spiazzare",
    "spiazzereste": "spiazzare",
    "spiazzeresti": "spiazzare",
    "spiazzerete": "spiazzare",
    "spiazzerà": "spiazzare",
    "spiazzerò": "spiazzare",
    "spiazzi": "spiazzo",
    "spiazziamo": "spiazzare",
    "spiazziate": "spiazzare",
    "spiazzin": "spiazzare",
    "spiazzino": "spiazzare",
    "spiazzo": "spiazzare",
    "spiazzò": "spiazzare",
    "spicca": "spiccare",
    "spiccai": "spiccare",
    "spiccammo": "spiccare",
    "spiccan": "spiccare",
    "spiccando": "spiccare",
    "spiccano": "spiccare",
    "spiccante": "spiccare",
    "spiccanti": "spiccare",
    "spiccar": "spiccare",
    "spiccaron": "spiccare",
    "spiccarono": "spiccare",
    "spiccasse": "spiccare",
    "spiccasser": "spiccare",
    "spiccassero": "spiccare",
    "spiccassi": "spiccare",
    "spiccassimo": "spiccare",
    "spiccaste": "spiccare",
    "spiccasti": "spiccare",
    "spiccata": "spiccato",
    "spiccate": "spiccato",
    "spiccati": "spiccato",
    "spiccato": "spiccare",
    "spiccava": "spiccare",
    "spiccavamo": "spiccare",
    "spiccavan": "spiccare",
    "spiccavano": "spiccare",
    "spiccavate": "spiccare",
    "spiccavi": "spiccare",
    "spiccavo": "spiccare",
    "spicce": "spiccio",
    "spiccerai": "spicciare",
    "spicceran": "spicciare",
    "spicceranno": "spicciare",
    "spiccerebbe": "spicciare",
    "spiccerebber": "spicciare",
    "spiccerebbero": "spicciare",
    "spiccerei": "spicciare",
    "spicceremmo": "spicciare",
    "spicceremo": "spicciare",
    "spiccereste": "spicciare",
    "spicceresti": "spicciare",
    "spiccerete": "spicciare",
    "spiccerà": "spicciare",
    "spiccerò": "spicciare",
    "spiccherai": "spiccare",
    "spiccheran": "spiccare",
    "spiccheranno": "spiccare",
    "spiccherebbe": "spiccare",
    "spiccherebber": "spiccare",
    "spiccherebbero": "spiccare",
    "spiccherei": "spiccare",
    "spiccheremmo": "spiccare",
    "spiccheremo": "spiccare",
    "spicchereste": "spiccare",
    "spiccheresti": "spiccare",
    "spiccherete": "spiccare",
    "spiccherà": "spiccare",
    "spiccherò": "spiccare",
    "spicchi": "spicchio",
    "spicchiamo": "spiccare",
    "spicchiate": "spiccare",
    "spicchin": "spiccare",
    "spicchino": "spiccare",
    "spicci": "spiccio",
    "spiccia": "spiccio",
    "spicciai": "spicciare",
    "spicciammo": "spicciare",
    "spicciamo": "spicciare",
    "spiccian": "spicciare",
    "spicciando": "spicciare",
    "spicciano": "spicciare",
    "spicciante": "spicciare",
    "spiccianti": "spicciare",
    "spicciar": "spicciare",
    "spicciaron": "spicciare",
    "spicciarono": "spicciare",
    "spicciasse": "spicciare",
    "spicciasser": "spicciare",
    "spicciassero": "spicciare",
    "spicciassi": "spicciare",
    "spicciassimo": "spicciare",
    "spicciaste": "spicciare",
    "spicciasti": "spicciare",
    "spicciata": "spicciare",
    "spicciate": "spicciare",
    "spicciati": "spicciare",
    "spicciativa": "spicciativo",
    "spicciative": "spicciativo",
    "spicciativi": "spicciativo",
    "spicciato": "spicciare",
    "spicciava": "spicciare",
    "spicciavamo": "spicciare",
    "spicciavan": "spicciare",
    "spicciavano": "spicciare",
    "spicciavate": "spicciare",
    "spicciavi": "spicciare",
    "spicciavo": "spicciare",
    "spiccica": "spiccicare",
    "spiccicai": "spiccicare",
    "spiccicammo": "spiccicare",
    "spiccican": "spiccicare",
    "spiccicando": "spiccicare",
    "spiccicano": "spiccicare",
    "spiccicante": "spiccicare",
    "spiccicanti": "spiccicare",
    "spiccicar": "spiccicare",
    "spiccicaron": "spiccicare",
    "spiccicarono": "spiccicare",
    "spiccicasse": "spiccicare",
    "spiccicasser": "spiccicare",
    "spiccicassero": "spiccicare",
    "spiccicassi": "spiccicare",
    "spiccicassimo": "spiccicare",
    "spiccicaste": "spiccicare",
    "spiccicasti": "spiccicare",
    "spiccicata": "spiccicare",
    "spiccicate": "spiccicare",
    "spiccicati": "spiccicare",
    "spiccicato": "spiccicare",
    "spiccicava": "spiccicare",
    "spiccicavamo": "spiccicare",
    "spiccicavan": "spiccicare",
    "spiccicavano": "spiccicare",
    "spiccicavate": "spiccicare",
    "spiccicavi": "spiccicare",
    "spiccicavo": "spiccicare",
    "spiccicherai": "spiccicare",
    "spiccicheran": "spiccicare",
    "spiccicheranno": "spiccicare",
    "spiccicherebbe": "spiccicare",
    "spiccicherebber": "spiccicare",
    "spiccicherebbero": "spiccicare",
    "spiccicherei": "spiccicare",
    "spiccicheremmo": "spiccicare",
    "spiccicheremo": "spiccicare",
    "spiccichereste": "spiccicare",
    "spiccicheresti": "spiccicare",
    "spiccicherete": "spiccicare",
    "spiccicherà": "spiccicare",
    "spiccicherò": "spiccicare",
    "spiccichi": "spiccicare",
    "spiccichiamo": "spiccicare",
    "spiccichiate": "spiccicare",
    "spiccichin": "spiccicare",
    "spiccichino": "spiccicare",
    "spiccico": "spiccicare",
    "spiccicò": "spiccicare",
    "spiccin": "spicciare",
    "spiccino": "spicciare",
    "spiccio": "spicciare",
    "spicciola": "spicciolo",
    "spicciolai": "spicciolare",
    "spicciolammo": "spicciolare",
    "spicciolan": "spicciolare",
    "spicciolando": "spicciolare",
    "spicciolano": "spicciolare",
    "spicciolante": "spicciolare",
    "spicciolanti": "spicciolare",
    "spicciolar": "spicciolare",
    "spicciolaron": "spicciolare",
    "spicciolarono": "spicciolare",
    "spicciolasse": "spicciolare",
    "spicciolasser": "spicciolare",
    "spicciolassero": "spicciolare",
    "spicciolassi": "spicciolare",
    "spicciolassimo": "spicciolare",
    "spicciolaste": "spicciolare",
    "spicciolasti": "spicciolare",
    "spicciolata": "spicciolato",
    "spicciolate": "spicciolato",
    "spicciolati": "spicciolato",
    "spicciolato": "spicciolare",
    "spicciolava": "spicciolare",
    "spicciolavamo": "spicciolare",
    "spicciolavan": "spicciolare",
    "spicciolavano": "spicciolare",
    "spicciolavate": "spicciolare",
    "spicciolavi": "spicciolare",
    "spicciolavo": "spicciolare",
    "spicciole": "spicciolo",
    "spicciolerai": "spicciolare",
    "spiccioleran": "spicciolare",
    "spiccioleranno": "spicciolare",
    "spicciolerebbe": "spicciolare",
    "spicciolerebber": "spicciolare",
    "spicciolerebbero": "spicciolare",
    "spicciolerei": "spicciolare",
    "spiccioleremmo": "spicciolare",
    "spiccioleremo": "spicciolare",
    "spicciolereste": "spicciolare",
    "spiccioleresti": "spicciolare",
    "spicciolerete": "spicciolare",
    "spicciolerà": "spicciolare",
    "spicciolerò": "spicciolare",
    "spiccioli": "spicciolo",
    "spiccioliamo": "spicciolare",
    "spiccioliate": "spicciolare",
    "spicciolin": "spicciolare",
    "spicciolino": "spicciolare",
    "spicciolo": "spicciolare",
    "spicciolò": "spicciolare",
    "spicciò": "spicciare",
    "spicco": "spiccare",
    "spiccò": "spiccare",
    "spidocchi": "spidocchiare",
    "spidocchia": "spidocchiare",
    "spidocchiai": "spidocchiare",
    "spidocchiammo": "spidocchiare",
    "spidocchiamo": "spidocchiare",
    "spidocchian": "spidocchiare",
    "spidocchiando": "spidocchiare",
    "spidocchiano": "spidocchiare",
    "spidocchiante": "spidocchiare",
    "spidocchianti": "spidocchiare",
    "spidocchiar": "spidocchiare",
    "spidocchiaron": "spidocchiare",
    "spidocchiarono": "spidocchiare",
    "spidocchiasse": "spidocchiare",
    "spidocchiasser": "spidocchiare",
    "spidocchiassero": "spidocchiare",
    "spidocchiassi": "spidocchiare",
    "spidocchiassimo": "spidocchiare",
    "spidocchiaste": "spidocchiare",
    "spidocchiasti": "spidocchiare",
    "spidocchiata": "spidocchiare",
    "spidocchiate": "spidocchiare",
    "spidocchiati": "spidocchiare",
    "spidocchiato": "spidocchiare",
    "spidocchiava": "spidocchiare",
    "spidocchiavamo": "spidocchiare",
    "spidocchiavan": "spidocchiare",
    "spidocchiavano": "spidocchiare",
    "spidocchiavate": "spidocchiare",
    "spidocchiavi": "spidocchiare",
    "spidocchiavo": "spidocchiare",
    "spidocchierai": "spidocchiare",
    "spidocchieran": "spidocchiare",
    "spidocchieranno": "spidocchiare",
    "spidocchierebbe": "spidocchiare",
    "spidocchierebber": "spidocchiare",
    "spidocchierebbero": "spidocchiare",
    "spidocchierei": "spidocchiare",
    "spidocchieremmo": "spidocchiare",
    "spidocchieremo": "spidocchiare",
    "spidocchiereste": "spidocchiare",
    "spidocchieresti": "spidocchiare",
    "spidocchierete": "spidocchiare",
    "spidocchierà": "spidocchiare",
    "spidocchierò": "spidocchiare",
    "spidocchin": "spidocchiare",
    "spidocchino": "spidocchiare",
    "spidocchio": "spidocchiare",
    "spidocchiò": "spidocchiare",
    "spie": "spia",
    "spiega": "spiegare",
    "spiegabili": "spiegabile",
    "spiegai": "spiegare",
    "spiegamenti": "spiegamento",
    "spiegammo": "spiegare",
    "spiegan": "spiegare",
    "spiegando": "spiegare",
    "spiegano": "spiegare",
    "spiegante": "spiegare",
    "spieganti": "spiegare",
    "spiegar": "spiegare",
    "spiegaron": "spiegare",
    "spiegarono": "spiegare",
    "spiegasse": "spiegare",
    "spiegasser": "spiegare",
    "spiegassero": "spiegare",
    "spiegassi": "spiegare",
    "spiegassimo": "spiegare",
    "spiegaste": "spiegare",
    "spiegasti": "spiegare",
    "spiegata": "spiegare",
    "spiegate": "spiegare",
    "spiegati": "spiegare",
    "spiegato": "spiegare",
    "spiegava": "spiegare",
    "spiegavamo": "spiegare",
    "spiegavan": "spiegare",
    "spiegavano": "spiegare",
    "spiegavate": "spiegare",
    "spiegavi": "spiegare",
    "spiegavo": "spiegare",
    "spiegazioni": "spiegazione",
    "spiegazza": "spiegazzare",
    "spiegazzai": "spiegazzare",
    "spiegazzammo": "spiegazzare",
    "spiegazzan": "spiegazzare",
    "spiegazzando": "spiegazzare",
    "spiegazzano": "spiegazzare",
    "spiegazzante": "spiegazzare",
    "spiegazzanti": "spiegazzare",
    "spiegazzar": "spiegazzare",
    "spiegazzaron": "spiegazzare",
    "spiegazzarono": "spiegazzare",
    "spiegazzasse": "spiegazzare",
    "spiegazzasser": "spiegazzare",
    "spiegazzassero": "spiegazzare",
    "spiegazzassi": "spiegazzare",
    "spiegazzassimo": "spiegazzare",
    "spiegazzaste": "spiegazzare",
    "spiegazzasti": "spiegazzare",
    "spiegazzata": "spiegazzare",
    "spiegazzate": "spiegazzare",
    "spiegazzati": "spiegazzare",
    "spiegazzato": "spiegazzare",
    "spiegazzava": "spiegazzare",
    "spiegazzavamo": "spiegazzare",
    "spiegazzavan": "spiegazzare",
    "spiegazzavano": "spiegazzare",
    "spiegazzavate": "spiegazzare",
    "spiegazzavi": "spiegazzare",
    "spiegazzavo": "spiegazzare",
    "spiegazzerai": "spiegazzare",
    "spiegazzeran": "spiegazzare",
    "spiegazzeranno": "spiegazzare",
    "spiegazzerebbe": "spiegazzare",
    "spiegazzerebber": "spiegazzare",
    "spiegazzerebbero": "spiegazzare",
    "spiegazzerei": "spiegazzare",
    "spiegazzeremmo": "spiegazzare",
    "spiegazzeremo": "spiegazzare",
    "spiegazzereste": "spiegazzare",
    "spiegazzeresti": "spiegazzare",
    "spiegazzerete": "spiegazzare",
    "spiegazzerà": "spiegazzare",
    "spiegazzerò": "spiegazzare",
    "spiegazzi": "spiegazzare",
    "spiegazziamo": "spiegazzare",
    "spiegazziate": "spiegazzare",
    "spiegazzin": "spiegazzare",
    "spiegazzino": "spiegazzare",
    "spiegazzo": "spiegazzare",
    "spiegazzò": "spiegazzare",
    "spiegherai": "spiegare",
    "spiegheran": "spiegare",
    "spiegheranno": "spiegare",
    "spiegherebbe": "spiegare",
    "spiegherebber": "spiegare",
    "spiegherebbero": "spiegare",
    "spiegherei": "spiegare",
    "spiegheremmo": "spiegare",
    "spiegheremo": "spiegare",
    "spieghereste": "spiegare",
    "spiegheresti": "spiegare",
    "spiegherete": "spiegare",
    "spiegherà": "spiegare",
    "spiegherò": "spiegare",
    "spieghi": "spiegare",
    "spieghiamo": "spiegare",
    "spieghiate": "spiegare",
    "spieghin": "spiegare",
    "spieghino": "spiegare",
    "spiego": "spiegare",
    "spiegò": "spiegare",
    "spierai": "spiare",
    "spieran": "spiare",
    "spieranno": "spiare",
    "spierebbe": "spiare",
    "spierebber": "spiare",
    "spierebbero": "spiare",
    "spierei": "spiare",
    "spieremmo": "spiare",
    "spieremo": "spiare",
    "spiereste": "spiare",
    "spieresti": "spiare",
    "spierete": "spiare",
    "spierà": "spiare",
    "spierò": "spiare",
    "spietata": "spietato",
    "spietate": "spietato",
    "spietatezze": "spietatezza",
    "spietati": "spietato",
    "spiffera": "spifferare",
    "spifferai": "spifferare",
    "spifferammo": "spifferare",
    "spifferan": "spifferare",
    "spifferando": "spifferare",
    "spifferano": "spifferare",
    "spifferante": "spifferare",
    "spifferanti": "spifferare",
    "spifferar": "spifferare",
    "spifferaron": "spifferare",
    "spifferarono": "spifferare",
    "spifferasse": "spifferare",
    "spifferasser": "spifferare",
    "spifferassero": "spifferare",
    "spifferassi": "spifferare",
    "spifferassimo": "spifferare",
    "spifferaste": "spifferare",
    "spifferasti": "spifferare",
    "spifferata": "spifferare",
    "spifferate": "spifferare",
    "spifferati": "spifferare",
    "spifferato": "spifferare",
    "spifferava": "spifferare",
    "spifferavamo": "spifferare",
    "spifferavan": "spifferare",
    "spifferavano": "spifferare",
    "spifferavate": "spifferare",
    "spifferavi": "spifferare",
    "spifferavo": "spifferare",
    "spiffererai": "spifferare",
    "spiffereran": "spifferare",
    "spiffereranno": "spifferare",
    "spiffererebbe": "spifferare",
    "spiffererebber": "spifferare",
    "spiffererebbero": "spifferare",
    "spiffererei": "spifferare",
    "spiffereremmo": "spifferare",
    "spiffereremo": "spifferare",
    "spifferereste": "spifferare",
    "spiffereresti": "spifferare",
    "spiffererete": "spifferare",
    "spiffererà": "spifferare",
    "spiffererò": "spifferare",
    "spifferi": "spiffero",
    "spifferiamo": "spifferare",
    "spifferiate": "spifferare",
    "spifferin": "spifferare",
    "spifferino": "spifferare",
    "spiffero": "spifferare",
    "spifferò": "spifferare",
    "spiga": "spigare",
    "spigai": "spigare",
    "spigammo": "spigare",
    "spigan": "spigare",
    "spigando": "spigare",
    "spigano": "spigare",
    "spigante": "spigare",
    "spiganti": "spigare",
    "spigar": "spigare",
    "spigaron": "spigare",
    "spigarono": "spigare",
    "spigasse": "spigare",
    "spigasser": "spigare",
    "spigassero": "spigare",
    "spigassi": "spigare",
    "spigassimo": "spigare",
    "spigaste": "spigare",
    "spigasti": "spigare",
    "spigata": "spigare",
    "spigate": "spigare",
    "spigati": "spigare",
    "spigato": "spigare",
    "spigava": "spigare",
    "spigavamo": "spigare",
    "spigavan": "spigare",
    "spigavano": "spigare",
    "spigavate": "spigare",
    "spigavi": "spigare",
    "spigavo": "spigare",
    "spighe": "spiga",
    "spigherai": "spigare",
    "spigheran": "spigare",
    "spigheranno": "spigare",
    "spigherebbe": "spigare",
    "spigherebber": "spigare",
    "spigherebbero": "spigare",
    "spigherei": "spigare",
    "spigheremmo": "spigare",
    "spigheremo": "spigare",
    "spighereste": "spigare",
    "spigheresti": "spigare",
    "spigherete": "spigare",
    "spigherà": "spigare",
    "spigherò": "spigare",
    "spighi": "spigare",
    "spighiamo": "spigare",
    "spighiate": "spigare",
    "spighin": "spigare",
    "spighino": "spigare",
    "spigliata": "spigliato",
    "spigliate": "spigliato",
    "spigliatezze": "spigliatezza",
    "spigliati": "spigliato",
    "spignatta": "spignattare",
    "spignattai": "spignattare",
    "spignattammo": "spignattare",
    "spignattan": "spignattare",
    "spignattando": "spignattare",
    "spignattano": "spignattare",
    "spignattante": "spignattare",
    "spignattanti": "spignattare",
    "spignattar": "spignattare",
    "spignattaron": "spignattare",
    "spignattarono": "spignattare",
    "spignattasse": "spignattare",
    "spignattasser": "spignattare",
    "spignattassero": "spignattare",
    "spignattassi": "spignattare",
    "spignattassimo": "spignattare",
    "spignattaste": "spignattare",
    "spignattasti": "spignattare",
    "spignattata": "spignattare",
    "spignattate": "spignattare",
    "spignattati": "spignattare",
    "spignattato": "spignattare",
    "spignattava": "spignattare",
    "spignattavamo": "spignattare",
    "spignattavan": "spignattare",
    "spignattavano": "spignattare",
    "spignattavate": "spignattare",
    "spignattavi": "spignattare",
    "spignattavo": "spignattare",
    "spignatterai": "spignattare",
    "spignatteran": "spignattare",
    "spignatteranno": "spignattare",
    "spignatterebbe": "spignattare",
    "spignatterebber": "spignattare",
    "spignatterebbero": "spignattare",
    "spignatterei": "spignattare",
    "spignatteremmo": "spignattare",
    "spignatteremo": "spignattare",
    "spignattereste": "spignattare",
    "spignatteresti": "spignattare",
    "spignatterete": "spignattare",
    "spignatterà": "spignattare",
    "spignatterò": "spignattare",
    "spignatti": "spignattare",
    "spignattiamo": "spignattare",
    "spignattiate": "spignattare",
    "spignattin": "spignattare",
    "spignattino": "spignattare",
    "spignatto": "spignattare",
    "spignattò": "spignattare",
    "spigo": "spigare",
    "spigola": "spigolare",
    "spigolai": "spigolare",
    "spigolammo": "spigolare",
    "spigolan": "spigolare",
    "spigolando": "spigolare",
    "spigolano": "spigolare",
    "spigolante": "spigolare",
    "spigolanti": "spigolare",
    "spigolar": "spigolare",
    "spigolaron": "spigolare",
    "spigolarono": "spigolare",
    "spigolasse": "spigolare",
    "spigolasser": "spigolare",
    "spigolassero": "spigolare",
    "spigolassi": "spigolare",
    "spigolassimo": "spigolare",
    "spigolaste": "spigolare",
    "spigolasti": "spigolare",
    "spigolata": "spigolare",
    "spigolate": "spigolare",
    "spigolati": "spigolare",
    "spigolato": "spigolare",
    "spigolature": "spigolatura",
    "spigolava": "spigolare",
    "spigolavamo": "spigolare",
    "spigolavan": "spigolare",
    "spigolavano": "spigolare",
    "spigolavate": "spigolare",
    "spigolavi": "spigolare",
    "spigolavo": "spigolare",
    "spigolerai": "spigolare",
    "spigoleran": "spigolare",
    "spigoleranno": "spigolare",
    "spigolerebbe": "spigolare",
    "spigolerebber": "spigolare",
    "spigolerebbero": "spigolare",
    "spigolerei": "spigolare",
    "spigoleremmo": "spigolare",
    "spigoleremo": "spigolare",
    "spigolereste": "spigolare",
    "spigoleresti": "spigolare",
    "spigolerete": "spigolare",
    "spigolerà": "spigolare",
    "spigolerò": "spigolare",
    "spigoli": "spigolo",
    "spigoliamo": "spigolare",
    "spigoliate": "spigolare",
    "spigolin": "spigolare",
    "spigolino": "spigolare",
    "spigolo": "spigolare",
    "spigolosa": "spigoloso",
    "spigolose": "spigoloso",
    "spigolosi": "spigoloso",
    "spigolò": "spigolare",
    "spigò": "spigare",
    "spii": "spiare",
    "spilla": "spillare",
    "spillai": "spillare",
    "spillammo": "spillare",
    "spillan": "spillare",
    "spillando": "spillare",
    "spillano": "spillare",
    "spillante": "spillare",
    "spillanti": "spillare",
    "spillar": "spillare",
    "spillaron": "spillare",
    "spillarono": "spillare",
    "spillasse": "spillare",
    "spillasser": "spillare",
    "spillassero": "spillare",
    "spillassi": "spillare",
    "spillassimo": "spillare",
    "spillaste": "spillare",
    "spillasti": "spillare",
    "spillata": "spillare",
    "spillate": "spillare",
    "spillati": "spillare",
    "spillato": "spillare",
    "spillava": "spillare",
    "spillavamo": "spillare",
    "spillavan": "spillare",
    "spillavano": "spillare",
    "spillavate": "spillare",
    "spillavi": "spillare",
    "spillavo": "spillare",
    "spille": "spilla",
    "spillerai": "spillare",
    "spilleran": "spillare",
    "spilleranno": "spillare",
    "spillerebbe": "spillare",
    "spillerebber": "spillare",
    "spillerebbero": "spillare",
    "spillerei": "spillare",
    "spilleremmo": "spillare",
    "spilleremo": "spillare",
    "spillereste": "spillare",
    "spilleresti": "spillare",
    "spillerete": "spillare",
    "spillerà": "spillare",
    "spillerò": "spillare",
    "spillette": "spilletta",
    "spilli": "spillo",
    "spilliamo": "spillare",
    "spilliate": "spillare",
    "spillin": "spillare",
    "spillino": "spillare",
    "spillo": "spillare",
    "spilloni": "spillone",
    "spilluzzica": "spilluzzicare",
    "spilluzzicai": "spilluzzicare",
    "spilluzzicammo": "spilluzzicare",
    "spilluzzican": "spilluzzicare",
    "spilluzzicando": "spilluzzicare",
    "spilluzzicano": "spilluzzicare",
    "spilluzzicante": "spilluzzicare",
    "spilluzzicanti": "spilluzzicare",
    "spilluzzicar": "spilluzzicare",
    "spilluzzicaron": "spilluzzicare",
    "spilluzzicarono": "spilluzzicare",
    "spilluzzicasse": "spilluzzicare",
    "spilluzzicasser": "spilluzzicare",
    "spilluzzicassero": "spilluzzicare",
    "spilluzzicassi": "spilluzzicare",
    "spilluzzicassimo": "spilluzzicare",
    "spilluzzicaste": "spilluzzicare",
    "spilluzzicasti": "spilluzzicare",
    "spilluzzicata": "spilluzzicare",
    "spilluzzicate": "spilluzzicare",
    "spilluzzicati": "spilluzzicare",
    "spilluzzicato": "spilluzzicare",
    "spilluzzicava": "spilluzzicare",
    "spilluzzicavamo": "spilluzzicare",
    "spilluzzicavan": "spilluzzicare",
    "spilluzzicavano": "spilluzzicare",
    "spilluzzicavate": "spilluzzicare",
    "spilluzzicavi": "spilluzzicare",
    "spilluzzicavo": "spilluzzicare",
    "spilluzzicherai": "spilluzzicare",
    "spilluzzicheran": "spilluzzicare",
    "spilluzzicheranno": "spilluzzicare",
    "spilluzzicherebbe": "spilluzzicare",
    "spilluzzicherebber": "spilluzzicare",
    "spilluzzicherebbero": "spilluzzicare",
    "spilluzzicherei": "spilluzzicare",
    "spilluzzicheremmo": "spilluzzicare",
    "spilluzzicheremo": "spilluzzicare",
    "spilluzzichereste": "spilluzzicare",
    "spilluzzicheresti": "spilluzzicare",
    "spilluzzicherete": "spilluzzicare",
    "spilluzzicherà": "spilluzzicare",
    "spilluzzicherò": "spilluzzicare",
    "spilluzzichi": "spilluzzicare",
    "spilluzzichiamo": "spilluzzicare",
    "spilluzzichiate": "spilluzzicare",
    "spilluzzichin": "spilluzzicare",
    "spilluzzichino": "spilluzzicare",
    "spilluzzico": "spilluzzicare",
    "spilluzzicò": "spilluzzicare",
    "spillò": "spillare",
    "spilungoni": "spilungone",
    "spin": "spiare",
    "spina": "spino",
    "spinai": "spinare",
    "spinali": "spinale",
    "spinammo": "spinare",
    "spinan": "spinare",
    "spinando": "spinare",
    "spinano": "spinare",
    "spinante": "spinare",
    "spinanti": "spinare",
    "spinar": "spinare",
    "spinaron": "spinare",
    "spinarono": "spinare",
    "spinasse": "spinare",
    "spinasser": "spinare",
    "spinassero": "spinare",
    "spinassi": "spinare",
    "spinassimo": "spinare",
    "spinaste": "spinare",
    "spinasti": "spinare",
    "spinata": "spinato",
    "spinate": "spinato",
    "spinati": "spinato",
    "spinato": "spinare",
    "spinava": "spinare",
    "spinavamo": "spinare",
    "spinavan": "spinare",
    "spinavano": "spinare",
    "spinavate": "spinare",
    "spinavi": "spinare",
    "spinavo": "spinare",
    "spine": "spino",
    "spinelli": "spinello",
    "spinerai": "spinare",
    "spineran": "spinare",
    "spineranno": "spinare",
    "spinerebbe": "spinare",
    "spinerebber": "spinare",
    "spinerebbero": "spinare",
    "spinerei": "spinare",
    "spineremmo": "spinare",
    "spineremo": "spinare",
    "spinereste": "spinare",
    "spineresti": "spinare",
    "spinerete": "spinare",
    "spinerà": "spinare",
    "spinerò": "spinare",
    "spinga": "spingere",
    "spingan": "spingere",
    "spingano": "spingere",
    "spinge": "spingere",
    "spingemmo": "spingere",
    "spingendo": "spingere",
    "spingente": "spingere",
    "spingenti": "spingere",
    "spinger": "spingere",
    "spingerai": "spingere",
    "spingeran": "spingere",
    "spingeranno": "spingere",
    "spingerebbe": "spingere",
    "spingerebber": "spingere",
    "spingerebbero": "spingere",
    "spingerei": "spingere",
    "spingeremmo": "spingere",
    "spingeremo": "spingere",
    "spingereste": "spingere",
    "spingeresti": "spingere",
    "spingerete": "spingere",
    "spingerà": "spingere",
    "spingerò": "spingere",
    "spingesse": "spingere",
    "spingesser": "spingere",
    "spingessero": "spingere",
    "spingessi": "spingere",
    "spingessimo": "spingere",
    "spingeste": "spingere",
    "spingesti": "spingere",
    "spingete": "spingere",
    "spingeva": "spingere",
    "spingevamo": "spingere",
    "spingevan": "spingere",
    "spingevano": "spingere",
    "spingevate": "spingere",
    "spingevi": "spingere",
    "spingevo": "spingere",
    "spingi": "spingere",
    "spingiamo": "spingere",
    "spingiate": "spingere",
    "spingo": "spingere",
    "spingon": "spingere",
    "spingono": "spingere",
    "spini": "spino",
    "spiniamo": "spinare",
    "spiniate": "spinare",
    "spinin": "spinare",
    "spinino": "spinare",
    "spino": "spinare",
    "spinosa": "spinoso",
    "spinose": "spinoso",
    "spinosi": "spinoso",
    "spinse": "spingere",
    "spinser": "spingere",
    "spinsero": "spingere",
    "spinsi": "spingere",
    "spinta": "spinto",
    "spintarelle": "spintarella",
    "spinte": "spinto",
    "spinti": "spinto",
    "spinto": "spingere",
    "spintona": "spintonare",
    "spintonai": "spintonare",
    "spintonammo": "spintonare",
    "spintonan": "spintonare",
    "spintonando": "spintonare",
    "spintonano": "spintonare",
    "spintonante": "spintonare",
    "spintonanti": "spintonare",
    "spintonar": "spintonare",
    "spintonaron": "spintonare",
    "spintonarono": "spintonare",
    "spintonasse": "spintonare",
    "spintonasser": "spintonare",
    "spintonassero": "spintonare",
    "spintonassi": "spintonare",
    "spintonassimo": "spintonare",
    "spintonaste": "spintonare",
    "spintonasti": "spintonare",
    "spintonata": "spintonare",
    "spintonate": "spintonare",
    "spintonati": "spintonare",
    "spintonato": "spintonare",
    "spintonava": "spintonare",
    "spintonavamo": "spintonare",
    "spintonavan": "spintonare",
    "spintonavano": "spintonare",
    "spintonavate": "spintonare",
    "spintonavi": "spintonare",
    "spintonavo": "spintonare",
    "spintonerai": "spintonare",
    "spintoneran": "spintonare",
    "spintoneranno": "spintonare",
    "spintonerebbe": "spintonare",
    "spintonerebber": "spintonare",
    "spintonerebbero": "spintonare",
    "spintonerei": "spintonare",
    "spintoneremmo": "spintonare",
    "spintoneremo": "spintonare",
    "spintonereste": "spintonare",
    "spintoneresti": "spintonare",
    "spintonerete": "spintonare",
    "spintonerà": "spintonare",
    "spintonerò": "spintonare",
    "spintoni": "spintone",
    "spintoniamo": "spintonare",
    "spintoniate": "spintonare",
    "spintonin": "spintonare",
    "spintonino": "spintonare",
    "spintono": "spintonare",
    "spintonò": "spintonare",
    "spinò": "spinare",
    "spio": "spiare",
    "spiomba": "spiombare",
    "spiombai": "spiombare",
    "spiombammo": "spiombare",
    "spiomban": "spiombare",
    "spiombando": "spiombare",
    "spiombano": "spiombare",
    "spiombante": "spiombare",
    "spiombanti": "spiombare",
    "spiombar": "spiombare",
    "spiombaron": "spiombare",
    "spiombarono": "spiombare",
    "spiombasse": "spiombare",
    "spiombasser": "spiombare",
    "spiombassero": "spiombare",
    "spiombassi": "spiombare",
    "spiombassimo": "spiombare",
    "spiombaste": "spiombare",
    "spiombasti": "spiombare",
    "spiombata": "spiombare",
    "spiombate": "spiombare",
    "spiombati": "spiombare",
    "spiombato": "spiombare",
    "spiombava": "spiombare",
    "spiombavamo": "spiombare",
    "spiombavan": "spiombare",
    "spiombavano": "spiombare",
    "spiombavate": "spiombare",
    "spiombavi": "spiombare",
    "spiombavo": "spiombare",
    "spiomberai": "spiombare",
    "spiomberan": "spiombare",
    "spiomberanno": "spiombare",
    "spiomberebbe": "spiombare",
    "spiomberebber": "spiombare",
    "spiomberebbero": "spiombare",
    "spiomberei": "spiombare",
    "spiomberemmo": "spiombare",
    "spiomberemo": "spiombare",
    "spiombereste": "spiombare",
    "spiomberesti": "spiombare",
    "spiomberete": "spiombare",
    "spiomberà": "spiombare",
    "spiomberò": "spiombare",
    "spiombi": "spiombare",
    "spiombiamo": "spiombare",
    "spiombiate": "spiombare",
    "spiombin": "spiombare",
    "spiombino": "spiombare",
    "spiombo": "spiombare",
    "spiombò": "spiombare",
    "spionaggi": "spionaggio",
    "spioncini": "spioncino",
    "spioni": "spione",
    "spionistica": "spionistico",
    "spionistiche": "spionistico",
    "spionistici": "spionistico",
    "spiova": "spiovere",
    "spiovan": "spiovere",
    "spiovano": "spiovere",
    "spiove": "spiovere",
    "spiovei": "spiovere",
    "spiovemmo": "spiovere",
    "spiovendo": "spiovere",
    "spiovente": "spiovere",
    "spioventi": "spiovere",
    "spiover": "spiovere",
    "spioverai": "spiovere",
    "spioveran": "spiovere",
    "spioveranno": "spiovere",
    "spioverebbe": "spiovere",
    "spioverebber": "spiovere",
    "spioverebbero": "spiovere",
    "spioverei": "spiovere",
    "spioveremmo": "spiovere",
    "spioveremo": "spiovere",
    "spiovereste": "spiovere",
    "spioveresti": "spiovere",
    "spioverete": "spiovere",
    "spioveron": "spiovere",
    "spioverono": "spiovere",
    "spioverà": "spiovere",
    "spioverò": "spiovere",
    "spiovesse": "spiovere",
    "spiovesser": "spiovere",
    "spiovessero": "spiovere",
    "spiovessi": "spiovere",
    "spiovessimo": "spiovere",
    "spioveste": "spiovere",
    "spiovesti": "spiovere",
    "spiovete": "spiovere",
    "spioveva": "spiovere",
    "spiovevamo": "spiovere",
    "spiovevan": "spiovere",
    "spiovevano": "spiovere",
    "spiovevate": "spiovere",
    "spiovevi": "spiovere",
    "spiovevo": "spiovere",
    "spiovi": "spiovere",
    "spioviamo": "spiovere",
    "spioviate": "spiovere",
    "spiovo": "spiovere",
    "spiovon": "spiovere",
    "spiovono": "spiovere",
    "spiovuta": "spiovere",
    "spiovute": "spiovere",
    "spiovuti": "spiovere",
    "spiovuto": "spiovere",
    "spiovè": "spiovere",
    "spira": "spirare",
    "spiragli": "spiraglio",
    "spirai": "spirare",
    "spirali": "spirale",
    "spirammo": "spirare",
    "spiran": "spirare",
    "spirando": "spirare",
    "spirano": "spirare",
    "spirante": "spirare",
    "spiranti": "spirare",
    "spirar": "spirare",
    "spiraron": "spirare",
    "spirarono": "spirare",
    "spirasse": "spirare",
    "spirasser": "spirare",
    "spirassero": "spirare",
    "spirassi": "spirare",
    "spirassimo": "spirare",
    "spiraste": "spirare",
    "spirasti": "spirare",
    "spirata": "spirare",
    "spirate": "spirare",
    "spirati": "spirare",
    "spirato": "spirare",
    "spirava": "spirare",
    "spiravamo": "spirare",
    "spiravan": "spirare",
    "spiravano": "spirare",
    "spiravate": "spirare",
    "spiravi": "spirare",
    "spiravo": "spirare",
    "spirerai": "spirare",
    "spireran": "spirare",
    "spireranno": "spirare",
    "spirerebbe": "spirare",
    "spirerebber": "spirare",
    "spirerebbero": "spirare",
    "spirerei": "spirare",
    "spireremmo": "spirare",
    "spireremo": "spirare",
    "spirereste": "spirare",
    "spireresti": "spirare",
    "spirerete": "spirare",
    "spirerà": "spirare",
    "spirerò": "spirare",
    "spiri": "spirare",
    "spiriamo": "spirare",
    "spiriate": "spirare",
    "spirin": "spirare",
    "spirino": "spirare",
    "spiritata": "spiritato",
    "spiritate": "spiritato",
    "spiritati": "spiritato",
    "spiritelli": "spiritello",
    "spiriti": "spirito",
    "spiritica": "spiritico",
    "spiritiche": "spiritico",
    "spiritici": "spiritico",
    "spiritosa": "spiritoso",
    "spiritosaggini": "spiritosaggine",
    "spiritose": "spiritoso",
    "spiritosi": "spiritoso",
    "spirituali": "spirituale",
    "spiritualismi": "spiritualismo",
    "spiritualizza": "spiritualizzare",
    "spiritualizzai": "spiritualizzare",
    "spiritualizzammo": "spiritualizzare",
    "spiritualizzan": "spiritualizzare",
    "spiritualizzando": "spiritualizzare",
    "spiritualizzano": "spiritualizzare",
    "spiritualizzante": "spiritualizzare",
    "spiritualizzanti": "spiritualizzare",
    "spiritualizzar": "spiritualizzare",
    "spiritualizzaron": "spiritualizzare",
    "spiritualizzarono": "spiritualizzare",
    "spiritualizzasse": "spiritualizzare",
    "spiritualizzasser": "spiritualizzare",
    "spiritualizzassero": "spiritualizzare",
    "spiritualizzassi": "spiritualizzare",
    "spiritualizzassimo": "spiritualizzare",
    "spiritualizzaste": "spiritualizzare",
    "spiritualizzasti": "spiritualizzare",
    "spiritualizzata": "spiritualizzare",
    "spiritualizzate": "spiritualizzare",
    "spiritualizzati": "spiritualizzare",
    "spiritualizzato": "spiritualizzare",
    "spiritualizzava": "spiritualizzare",
    "spiritualizzavamo": "spiritualizzare",
    "spiritualizzavan": "spiritualizzare",
    "spiritualizzavano": "spiritualizzare",
    "spiritualizzavate": "spiritualizzare",
    "spiritualizzavi": "spiritualizzare",
    "spiritualizzavo": "spiritualizzare",
    "spiritualizzerai": "spiritualizzare",
    "spiritualizzeran": "spiritualizzare",
    "spiritualizzeranno": "spiritualizzare",
    "spiritualizzerebbe": "spiritualizzare",
    "spiritualizzerebber": "spiritualizzare",
    "spiritualizzerebbero": "spiritualizzare",
    "spiritualizzerei": "spiritualizzare",
    "spiritualizzeremmo": "spiritualizzare",
    "spiritualizzeremo": "spiritualizzare",
    "spiritualizzereste": "spiritualizzare",
    "spiritualizzeresti": "spiritualizzare",
    "spiritualizzerete": "spiritualizzare",
    "spiritualizzerà": "spiritualizzare",
    "spiritualizzerò": "spiritualizzare",
    "spiritualizzi": "spiritualizzare",
    "spiritualizziamo": "spiritualizzare",
    "spiritualizziate": "spiritualizzare",
    "spiritualizzin": "spiritualizzare",
    "spiritualizzino": "spiritualizzare",
    "spiritualizzo": "spiritualizzare",
    "spiritualizzò": "spiritualizzare",
    "spiro": "spirare",
    "spirò": "spirare",
    "spiuma": "spiumare",
    "spiumai": "spiumare",
    "spiumammo": "spiumare",
    "spiuman": "spiumare",
    "spiumando": "spiumare",
    "spiumano": "spiumare",
    "spiumante": "spiumare",
    "spiumanti": "spiumare",
    "spiumar": "spiumare",
    "spiumaron": "spiumare",
    "spiumarono": "spiumare",
    "spiumasse": "spiumare",
    "spiumasser": "spiumare",
    "spiumassero": "spiumare",
    "spiumassi": "spiumare",
    "spiumassimo": "spiumare",
    "spiumaste": "spiumare",
    "spiumasti": "spiumare",
    "spiumata": "spiumare",
    "spiumate": "spiumare",
    "spiumati": "spiumare",
    "spiumato": "spiumare",
    "spiumava": "spiumare",
    "spiumavamo": "spiumare",
    "spiumavan": "spiumare",
    "spiumavano": "spiumare",
    "spiumavate": "spiumare",
    "spiumavi": "spiumare",
    "spiumavo": "spiumare",
    "spiumerai": "spiumare",
    "spiumeran": "spiumare",
    "spiumeranno": "spiumare",
    "spiumerebbe": "spiumare",
    "spiumerebber": "spiumare",
    "spiumerebbero": "spiumare",
    "spiumerei": "spiumare",
    "spiumeremmo": "spiumare",
    "spiumeremo": "spiumare",
    "spiumereste": "spiumare",
    "spiumeresti": "spiumare",
    "spiumerete": "spiumare",
    "spiumerà": "spiumare",
    "spiumerò": "spiumare",
    "spiumi": "spiumare",
    "spiumiamo": "spiumare",
    "spiumiate": "spiumare",
    "spiumin": "spiumare",
    "spiumino": "spiumare",
    "spiumo": "spiumare",
    "spiumò": "spiumare",
    "spizzica": "spizzicare",
    "spizzicai": "spizzicare",
    "spizzicammo": "spizzicare",
    "spizzican": "spizzicare",
    "spizzicando": "spizzicare",
    "spizzicano": "spizzicare",
    "spizzicante": "spizzicare",
    "spizzicanti": "spizzicare",
    "spizzicar": "spizzicare",
    "spizzicaron": "spizzicare",
    "spizzicarono": "spizzicare",
    "spizzicasse": "spizzicare",
    "spizzicasser": "spizzicare",
    "spizzicassero": "spizzicare",
    "spizzicassi": "spizzicare",
    "spizzicassimo": "spizzicare",
    "spizzicaste": "spizzicare",
    "spizzicasti": "spizzicare",
    "spizzicata": "spizzicare",
    "spizzicate": "spizzicare",
    "spizzicati": "spizzicare",
    "spizzicato": "spizzicare",
    "spizzicava": "spizzicare",
    "spizzicavamo": "spizzicare",
    "spizzicavan": "spizzicare",
    "spizzicavano": "spizzicare",
    "spizzicavate": "spizzicare",
    "spizzicavi": "spizzicare",
    "spizzicavo": "spizzicare",
    "spizzicherai": "spizzicare",
    "spizzicheran": "spizzicare",
    "spizzicheranno": "spizzicare",
    "spizzicherebbe": "spizzicare",
    "spizzicherebber": "spizzicare",
    "spizzicherebbero": "spizzicare",
    "spizzicherei": "spizzicare",
    "spizzicheremmo": "spizzicare",
    "spizzicheremo": "spizzicare",
    "spizzichereste": "spizzicare",
    "spizzicheresti": "spizzicare",
    "spizzicherete": "spizzicare",
    "spizzicherà": "spizzicare",
    "spizzicherò": "spizzicare",
    "spizzichi": "spizzicare",
    "spizzichiamo": "spizzicare",
    "spizzichiate": "spizzicare",
    "spizzichin": "spizzicare",
    "spizzichino": "spizzicare",
    "spizzico": "spizzicare",
    "spizzicò": "spizzicare",
    "spiò": "spiare",
    "splendida": "splendido",
    "splendide": "splendido",
    "splendidi": "splendido",
    "splendori": "splendore",
    "splenetica": "splenetico",
    "splenetiche": "splenetico",
    "splenetici": "splenetico",
    "spocchie": "spocchia",
    "spocchiosa": "spocchioso",
    "spocchiose": "spocchioso",
    "spocchiosi": "spocchioso",
    "spodesta": "spodestare",
    "spodestai": "spodestare",
    "spodestammo": "spodestare",
    "spodestan": "spodestare",
    "spodestando": "spodestare",
    "spodestano": "spodestare",
    "spodestante": "spodestare",
    "spodestanti": "spodestare",
    "spodestar": "spodestare",
    "spodestaron": "spodestare",
    "spodestarono": "spodestare",
    "spodestasse": "spodestare",
    "spodestasser": "spodestare",
    "spodestassero": "spodestare",
    "spodestassi": "spodestare",
    "spodestassimo": "spodestare",
    "spodestaste": "spodestare",
    "spodestasti": "spodestare",
    "spodestata": "spodestare",
    "spodestate": "spodestare",
    "spodestati": "spodestare",
    "spodestato": "spodestare",
    "spodestava": "spodestare",
    "spodestavamo": "spodestare",
    "spodestavan": "spodestare",
    "spodestavano": "spodestare",
    "spodestavate": "spodestare",
    "spodestavi": "spodestare",
    "spodestavo": "spodestare",
    "spodesterai": "spodestare",
    "spodesteran": "spodestare",
    "spodesteranno": "spodestare",
    "spodesterebbe": "spodestare",
    "spodesterebber": "spodestare",
    "spodesterebbero": "spodestare",
    "spodesterei": "spodestare",
    "spodesteremmo": "spodestare",
    "spodesteremo": "spodestare",
    "spodestereste": "spodestare",
    "spodesteresti": "spodestare",
    "spodesterete": "spodestare",
    "spodesterà": "spodestare",
    "spodesterò": "spodestare",
    "spodesti": "spodestare",
    "spodestiamo": "spodestare",
    "spodestiate": "spodestare",
    "spodestin": "spodestare",
    "spodestino": "spodestare",
    "spodesto": "spodestare",
    "spodestò": "spodestare",
    "spoetizza": "spoetizzare",
    "spoetizzai": "spoetizzare",
    "spoetizzammo": "spoetizzare",
    "spoetizzan": "spoetizzare",
    "spoetizzando": "spoetizzare",
    "spoetizzano": "spoetizzare",
    "spoetizzante": "spoetizzare",
    "spoetizzanti": "spoetizzare",
    "spoetizzar": "spoetizzare",
    "spoetizzaron": "spoetizzare",
    "spoetizzarono": "spoetizzare",
    "spoetizzasse": "spoetizzare",
    "spoetizzasser": "spoetizzare",
    "spoetizzassero": "spoetizzare",
    "spoetizzassi": "spoetizzare",
    "spoetizzassimo": "spoetizzare",
    "spoetizzaste": "spoetizzare",
    "spoetizzasti": "spoetizzare",
    "spoetizzata": "spoetizzare",
    "spoetizzate": "spoetizzare",
    "spoetizzati": "spoetizzare",
    "spoetizzato": "spoetizzare",
    "spoetizzava": "spoetizzare",
    "spoetizzavamo": "spoetizzare",
    "spoetizzavan": "spoetizzare",
    "spoetizzavano": "spoetizzare",
    "spoetizzavate": "spoetizzare",
    "spoetizzavi": "spoetizzare",
    "spoetizzavo": "spoetizzare",
    "spoetizzerai": "spoetizzare",
    "spoetizzeran": "spoetizzare",
    "spoetizzeranno": "spoetizzare",
    "spoetizzerebbe": "spoetizzare",
    "spoetizzerebber": "spoetizzare",
    "spoetizzerebbero": "spoetizzare",
    "spoetizzerei": "spoetizzare",
    "spoetizzeremmo": "spoetizzare",
    "spoetizzeremo": "spoetizzare",
    "spoetizzereste": "spoetizzare",
    "spoetizzeresti": "spoetizzare",
    "spoetizzerete": "spoetizzare",
    "spoetizzerà": "spoetizzare",
    "spoetizzerò": "spoetizzare",
    "spoetizzi": "spoetizzare",
    "spoetizziamo": "spoetizzare",
    "spoetizziate": "spoetizzare",
    "spoetizzin": "spoetizzare",
    "spoetizzino": "spoetizzare",
    "spoetizzo": "spoetizzare",
    "spoetizzò": "spoetizzare",
    "spogli": "spoglio",
    "spoglia": "spoglio",
    "spogliai": "spogliare",
    "spogliammo": "spogliare",
    "spogliamo": "spogliare",
    "spoglian": "spogliare",
    "spogliando": "spogliare",
    "spogliano": "spogliare",
    "spogliante": "spogliare",
    "spoglianti": "spogliare",
    "spogliar": "spogliare",
    "spogliarelli": "spogliarello",
    "spogliarelliste": "spogliarellista",
    "spogliarellisti": "spogliarellista",
    "spogliaron": "spogliare",
    "spogliarono": "spogliare",
    "spogliasse": "spogliare",
    "spogliasser": "spogliare",
    "spogliassero": "spogliare",
    "spogliassi": "spogliare",
    "spogliassimo": "spogliare",
    "spogliaste": "spogliare",
    "spogliasti": "spogliare",
    "spogliata": "spogliare",
    "spogliate": "spogliare",
    "spogliati": "spogliare",
    "spogliato": "spogliare",
    "spogliatoi": "spogliatoio",
    "spogliava": "spogliare",
    "spogliavamo": "spogliare",
    "spogliavan": "spogliare",
    "spogliavano": "spogliare",
    "spogliavate": "spogliare",
    "spogliavi": "spogliare",
    "spogliavo": "spogliare",
    "spoglie": "spoglio",
    "spoglierai": "spogliare",
    "spoglieran": "spogliare",
    "spoglieranno": "spogliare",
    "spoglierebbe": "spogliare",
    "spoglierebber": "spogliare",
    "spoglierebbero": "spogliare",
    "spoglierei": "spogliare",
    "spoglieremmo": "spogliare",
    "spoglieremo": "spogliare",
    "spogliereste": "spogliare",
    "spoglieresti": "spogliare",
    "spoglierete": "spogliare",
    "spoglierà": "spogliare",
    "spoglierò": "spogliare",
    "spoglin": "spogliare",
    "spoglino": "spogliare",
    "spoglio": "spogliare",
    "spogliò": "spogliare",
    "spole": "spola",
    "spolette": "spoletta",
    "spoliazioni": "spoliazione",
    "spoliticizza": "spoliticizzare",
    "spoliticizzai": "spoliticizzare",
    "spoliticizzammo": "spoliticizzare",
    "spoliticizzan": "spoliticizzare",
    "spoliticizzando": "spoliticizzare",
    "spoliticizzano": "spoliticizzare",
    "spoliticizzante": "spoliticizzare",
    "spoliticizzanti": "spoliticizzare",
    "spoliticizzar": "spoliticizzare",
    "spoliticizzaron": "spoliticizzare",
    "spoliticizzarono": "spoliticizzare",
    "spoliticizzasse": "spoliticizzare",
    "spoliticizzasser": "spoliticizzare",
    "spoliticizzassero": "spoliticizzare",
    "spoliticizzassi": "spoliticizzare",
    "spoliticizzassimo": "spoliticizzare",
    "spoliticizzaste": "spoliticizzare",
    "spoliticizzasti": "spoliticizzare",
    "spoliticizzata": "spoliticizzare",
    "spoliticizzate": "spoliticizzare",
    "spoliticizzati": "spoliticizzare",
    "spoliticizzato": "spoliticizzare",
    "spoliticizzava": "spoliticizzare",
    "spoliticizzavamo": "spoliticizzare",
    "spoliticizzavan": "spoliticizzare",
    "spoliticizzavano": "spoliticizzare",
    "spoliticizzavate": "spoliticizzare",
    "spoliticizzavi": "spoliticizzare",
    "spoliticizzavo": "spoliticizzare",
    "spoliticizzerai": "spoliticizzare",
    "spoliticizzeran": "spoliticizzare",
    "spoliticizzeranno": "spoliticizzare",
    "spoliticizzerebbe": "spoliticizzare",
    "spoliticizzerebber": "spoliticizzare",
    "spoliticizzerebbero": "spoliticizzare",
    "spoliticizzerei": "spoliticizzare",
    "spoliticizzeremmo": "spoliticizzare",
    "spoliticizzeremo": "spoliticizzare",
    "spoliticizzereste": "spoliticizzare",
    "spoliticizzeresti": "spoliticizzare",
    "spoliticizzerete": "spoliticizzare",
    "spoliticizzerà": "spoliticizzare",
    "spoliticizzerò": "spoliticizzare",
    "spoliticizzi": "spoliticizzare",
    "spoliticizziamo": "spoliticizzare",
    "spoliticizziate": "spoliticizzare",
    "spoliticizzin": "spoliticizzare",
    "spoliticizzino": "spoliticizzare",
    "spoliticizzo": "spoliticizzare",
    "spoliticizzò": "spoliticizzare",
    "spolmona": "spolmonare",
    "spolmonai": "spolmonare",
    "spolmonammo": "spolmonare",
    "spolmonan": "spolmonare",
    "spolmonando": "spolmonare",
    "spolmonano": "spolmonare",
    "spolmonar": "spolmonare",
    "spolmonaron": "spolmonare",
    "spolmonarono": "spolmonare",
    "spolmonasse": "spolmonare",
    "spolmonasser": "spolmonare",
    "spolmonassero": "spolmonare",
    "spolmonassi": "spolmonare",
    "spolmonassimo": "spolmonare",
    "spolmonaste": "spolmonare",
    "spolmonasti": "spolmonare",
    "spolmonata": "spolmonare",
    "spolmonate": "spolmonare",
    "spolmonati": "spolmonare",
    "spolmonato": "spolmonare",
    "spolmonava": "spolmonare",
    "spolmonavamo": "spolmonare",
    "spolmonavan": "spolmonare",
    "spolmonavano": "spolmonare",
    "spolmonavate": "spolmonare",
    "spolmonavi": "spolmonare",
    "spolmonavo": "spolmonare",
    "spolmonerai": "spolmonare",
    "spolmoneran": "spolmonare",
    "spolmoneranno": "spolmonare",
    "spolmonerebbe": "spolmonare",
    "spolmonerebber": "spolmonare",
    "spolmonerebbero": "spolmonare",
    "spolmonerei": "spolmonare",
    "spolmoneremmo": "spolmonare",
    "spolmoneremo": "spolmonare",
    "spolmonereste": "spolmonare",
    "spolmoneresti": "spolmonare",
    "spolmonerete": "spolmonare",
    "spolmonerà": "spolmonare",
    "spolmonerò": "spolmonare",
    "spolmoni": "spolmonare",
    "spolmoniamo": "spolmonare",
    "spolmoniate": "spolmonare",
    "spolmonin": "spolmonare",
    "spolmonino": "spolmonare",
    "spolmono": "spolmonare",
    "spolmonò": "spolmonare",
    "spolpa": "spolpare",
    "spolpai": "spolpare",
    "spolpammo": "spolpare",
    "spolpan": "spolpare",
    "spolpando": "spolpare",
    "spolpano": "spolpare",
    "spolpante": "spolpare",
    "spolpanti": "spolpare",
    "spolpar": "spolpare",
    "spolparon": "spolpare",
    "spolparono": "spolpare",
    "spolpasse": "spolpare",
    "spolpasser": "spolpare",
    "spolpassero": "spolpare",
    "spolpassi": "spolpare",
    "spolpassimo": "spolpare",
    "spolpaste": "spolpare",
    "spolpasti": "spolpare",
    "spolpata": "spolpare",
    "spolpate": "spolpare",
    "spolpati": "spolpare",
    "spolpato": "spolpare",
    "spolpava": "spolpare",
    "spolpavamo": "spolpare",
    "spolpavan": "spolpare",
    "spolpavano": "spolpare",
    "spolpavate": "spolpare",
    "spolpavi": "spolpare",
    "spolpavo": "spolpare",
    "spolperai": "spolpare",
    "spolperan": "spolpare",
    "spolperanno": "spolpare",
    "spolperebbe": "spolpare",
    "spolperebber": "spolpare",
    "spolperebbero": "spolpare",
    "spolperei": "spolpare",
    "spolperemmo": "spolpare",
    "spolperemo": "spolpare",
    "spolpereste": "spolpare",
    "spolperesti": "spolpare",
    "spolperete": "spolpare",
    "spolperà": "spolpare",
    "spolperò": "spolpare",
    "spolpi": "spolpare",
    "spolpiamo": "spolpare",
    "spolpiate": "spolpare",
    "spolpin": "spolpare",
    "spolpino": "spolpare",
    "spolpo": "spolpare",
    "spolpò": "spolpare",
    "spolvera": "spolverare",
    "spolverai": "spolverare",
    "spolverammo": "spolverare",
    "spolveran": "spolverare",
    "spolverando": "spolverare",
    "spolverano": "spolverare",
    "spolverante": "spolverare",
    "spolveranti": "spolverare",
    "spolverar": "spolverare",
    "spolveraron": "spolverare",
    "spolverarono": "spolverare",
    "spolverasse": "spolverare",
    "spolverasser": "spolverare",
    "spolverassero": "spolverare",
    "spolverassi": "spolverare",
    "spolverassimo": "spolverare",
    "spolveraste": "spolverare",
    "spolverasti": "spolverare",
    "spolverata": "spolverare",
    "spolverate": "spolverare",
    "spolverati": "spolverare",
    "spolverato": "spolverare",
    "spolverava": "spolverare",
    "spolveravamo": "spolverare",
    "spolveravan": "spolverare",
    "spolveravano": "spolverare",
    "spolveravate": "spolverare",
    "spolveravi": "spolverare",
    "spolveravo": "spolverare",
    "spolvererai": "spolverare",
    "spolvereran": "spolverare",
    "spolvereranno": "spolverare",
    "spolvererebbe": "spolverare",
    "spolvererebber": "spolverare",
    "spolvererebbero": "spolverare",
    "spolvererei": "spolverare",
    "spolvereremmo": "spolverare",
    "spolvereremo": "spolverare",
    "spolverereste": "spolverare",
    "spolvereresti": "spolverare",
    "spolvererete": "spolverare",
    "spolvererà": "spolverare",
    "spolvererò": "spolverare",
    "spolveri": "spolverare",
    "spolveriamo": "spolverare",
    "spolveriate": "spolverare",
    "spolverin": "spolverare",
    "spolverini": "spolverino",
    "spolverino": "spolverare",
    "spolverizza": "spolverizzare",
    "spolverizzai": "spolverizzare",
    "spolverizzammo": "spolverizzare",
    "spolverizzan": "spolverizzare",
    "spolverizzando": "spolverizzare",
    "spolverizzano": "spolverizzare",
    "spolverizzante": "spolverizzare",
    "spolverizzanti": "spolverizzare",
    "spolverizzar": "spolverizzare",
    "spolverizzaron": "spolverizzare",
    "spolverizzarono": "spolverizzare",
    "spolverizzasse": "spolverizzare",
    "spolverizzasser": "spolverizzare",
    "spolverizzassero": "spolverizzare",
    "spolverizzassi": "spolverizzare",
    "spolverizzassimo": "spolverizzare",
    "spolverizzaste": "spolverizzare",
    "spolverizzasti": "spolverizzare",
    "spolverizzata": "spolverizzare",
    "spolverizzate": "spolverizzare",
    "spolverizzati": "spolverizzare",
    "spolverizzato": "spolverizzare",
    "spolverizzava": "spolverizzare",
    "spolverizzavamo": "spolverizzare",
    "spolverizzavan": "spolverizzare",
    "spolverizzavano": "spolverizzare",
    "spolverizzavate": "spolverizzare",
    "spolverizzavi": "spolverizzare",
    "spolverizzavo": "spolverizzare",
    "spolverizzerai": "spolverizzare",
    "spolverizzeran": "spolverizzare",
    "spolverizzeranno": "spolverizzare",
    "spolverizzerebbe": "spolverizzare",
    "spolverizzerebber": "spolverizzare",
    "spolverizzerebbero": "spolverizzare",
    "spolverizzerei": "spolverizzare",
    "spolverizzeremmo": "spolverizzare",
    "spolverizzeremo": "spolverizzare",
    "spolverizzereste": "spolverizzare",
    "spolverizzeresti": "spolverizzare",
    "spolverizzerete": "spolverizzare",
    "spolverizzerà": "spolverizzare",
    "spolverizzerò": "spolverizzare",
    "spolverizzi": "spolverizzare",
    "spolverizziamo": "spolverizzare",
    "spolverizziate": "spolverizzare",
    "spolverizzin": "spolverizzare",
    "spolverizzino": "spolverizzare",
    "spolverizzo": "spolverizzare",
    "spolverizzò": "spolverizzare",
    "spolvero": "spolverare",
    "spolverò": "spolverare",
    "sponde": "sponda",
    "sponsali": "sponsale",
    "sponsorizza": "sponsorizzare",
    "sponsorizzai": "sponsorizzare",
    "sponsorizzammo": "sponsorizzare",
    "sponsorizzan": "sponsorizzare",
    "sponsorizzando": "sponsorizzare",
    "sponsorizzano": "sponsorizzare",
    "sponsorizzante": "sponsorizzare",
    "sponsorizzanti": "sponsorizzare",
    "sponsorizzar": "sponsorizzare",
    "sponsorizzaron": "sponsorizzare",
    "sponsorizzarono": "sponsorizzare",
    "sponsorizzasse": "sponsorizzare",
    "sponsorizzasser": "sponsorizzare",
    "sponsorizzassero": "sponsorizzare",
    "sponsorizzassi": "sponsorizzare",
    "sponsorizzassimo": "sponsorizzare",
    "sponsorizzaste": "sponsorizzare",
    "sponsorizzasti": "sponsorizzare",
    "sponsorizzata": "sponsorizzare",
    "sponsorizzate": "sponsorizzare",
    "sponsorizzati": "sponsorizzare",
    "sponsorizzato": "sponsorizzare",
    "sponsorizzava": "sponsorizzare",
    "sponsorizzavamo": "sponsorizzare",
    "sponsorizzavan": "sponsorizzare",
    "sponsorizzavano": "sponsorizzare",
    "sponsorizzavate": "sponsorizzare",
    "sponsorizzavi": "sponsorizzare",
    "sponsorizzavo": "sponsorizzare",
    "sponsorizzazioni": "sponsorizzazione",
    "sponsorizzerai": "sponsorizzare",
    "sponsorizzeran": "sponsorizzare",
    "sponsorizzeranno": "sponsorizzare",
    "sponsorizzerebbe": "sponsorizzare",
    "sponsorizzerebber": "sponsorizzare",
    "sponsorizzerebbero": "sponsorizzare",
    "sponsorizzerei": "sponsorizzare",
    "sponsorizzeremmo": "sponsorizzare",
    "sponsorizzeremo": "sponsorizzare",
    "sponsorizzereste": "sponsorizzare",
    "sponsorizzeresti": "sponsorizzare",
    "sponsorizzerete": "sponsorizzare",
    "sponsorizzerà": "sponsorizzare",
    "sponsorizzerò": "sponsorizzare",
    "sponsorizzi": "sponsorizzare",
    "sponsorizziamo": "sponsorizzare",
    "sponsorizziate": "sponsorizzare",
    "sponsorizzin": "sponsorizzare",
    "sponsorizzino": "sponsorizzare",
    "sponsorizzo": "sponsorizzare",
    "sponsorizzò": "sponsorizzare",
    "sponsors": "sponsor",
    "spontanea": "spontaneo",
    "spontanee": "spontaneo",
    "spontanei": "spontaneo",
    "spontaneismi": "spontaneismo",
    "spopola": "spopolare",
    "spopolai": "spopolare",
    "spopolamenti": "spopolamento",
    "spopolammo": "spopolare",
    "spopolan": "spopolare",
    "spopolando": "spopolare",
    "spopolano": "spopolare",
    "spopolante": "spopolare",
    "spopolanti": "spopolare",
    "spopolar": "spopolare",
    "spopolaron": "spopolare",
    "spopolarono": "spopolare",
    "spopolasse": "spopolare",
    "spopolasser": "spopolare",
    "spopolassero": "spopolare",
    "spopolassi": "spopolare",
    "spopolassimo": "spopolare",
    "spopolaste": "spopolare",
    "spopolasti": "spopolare",
    "spopolata": "spopolare",
    "spopolate": "spopolare",
    "spopolati": "spopolare",
    "spopolato": "spopolare",
    "spopolava": "spopolare",
    "spopolavamo": "spopolare",
    "spopolavan": "spopolare",
    "spopolavano": "spopolare",
    "spopolavate": "spopolare",
    "spopolavi": "spopolare",
    "spopolavo": "spopolare",
    "spopolerai": "spopolare",
    "spopoleran": "spopolare",
    "spopoleranno": "spopolare",
    "spopolerebbe": "spopolare",
    "spopolerebber": "spopolare",
    "spopolerebbero": "spopolare",
    "spopolerei": "spopolare",
    "spopoleremmo": "spopolare",
    "spopoleremo": "spopolare",
    "spopolereste": "spopolare",
    "spopoleresti": "spopolare",
    "spopolerete": "spopolare",
    "spopolerà": "spopolare",
    "spopolerò": "spopolare",
    "spopoli": "spopolare",
    "spopoliamo": "spopolare",
    "spopoliate": "spopolare",
    "spopolin": "spopolare",
    "spopolino": "spopolare",
    "spopolo": "spopolare",
    "spopolò": "spopolare",
    "sporadica": "sporadico",
    "sporadiche": "sporadico",
    "sporadici": "sporadico",
    "sporca": "sporco",
    "sporcaccioni": "sporcaccione",
    "sporcai": "sporcare",
    "sporcammo": "sporcare",
    "sporcan": "sporcare",
    "sporcando": "sporcare",
    "sporcano": "sporcare",
    "sporcante": "sporcare",
    "sporcanti": "sporcare",
    "sporcar": "sporcare",
    "sporcaron": "sporcare",
    "sporcarono": "sporcare",
    "sporcasse": "sporcare",
    "sporcasser": "sporcare",
    "sporcassero": "sporcare",
    "sporcassi": "sporcare",
    "sporcassimo": "sporcare",
    "sporcaste": "sporcare",
    "sporcasti": "sporcare",
    "sporcata": "sporcare",
    "sporcate": "sporcare",
    "sporcati": "sporcare",
    "sporcato": "sporcare",
    "sporcava": "sporcare",
    "sporcavamo": "sporcare",
    "sporcavan": "sporcare",
    "sporcavano": "sporcare",
    "sporcavate": "sporcare",
    "sporcavi": "sporcare",
    "sporcavo": "sporcare",
    "sporche": "sporco",
    "sporcherai": "sporcare",
    "sporcheran": "sporcare",
    "sporcheranno": "sporcare",
    "sporcherebbe": "sporcare",
    "sporcherebber": "sporcare",
    "sporcherebbero": "sporcare",
    "sporcherei": "sporcare",
    "sporcheremmo": "sporcare",
    "sporcheremo": "sporcare",
    "sporchereste": "sporcare",
    "sporcheresti": "sporcare",
    "sporcherete": "sporcare",
    "sporcherà": "sporcare",
    "sporcherò": "sporcare",
    "sporchi": "sporco",
    "sporchiamo": "sporcare",
    "sporchiate": "sporcare",
    "sporchin": "sporcare",
    "sporchino": "sporcare",
    "sporcizie": "sporcizia",
    "sporco": "sporcare",
    "sporcò": "sporcare",
    "spore": "spora",
    "sporga": "sporgere",
    "sporgan": "sporgere",
    "sporgano": "sporgere",
    "sporge": "sporgere",
    "sporgemmo": "sporgere",
    "sporgendo": "sporgere",
    "sporgente": "sporgere",
    "sporgenti": "sporgere",
    "sporgenze": "sporgenza",
    "sporger": "sporgere",
    "sporgerai": "sporgere",
    "sporgeran": "sporgere",
    "sporgeranno": "sporgere",
    "sporgerebbe": "sporgere",
    "sporgerebber": "sporgere",
    "sporgerebbero": "sporgere",
    "sporgerei": "sporgere",
    "sporgeremmo": "sporgere",
    "sporgeremo": "sporgere",
    "sporgereste": "sporgere",
    "sporgeresti": "sporgere",
    "sporgerete": "sporgere",
    "sporgerà": "sporgere",
    "sporgerò": "sporgere",
    "sporgesse": "sporgere",
    "sporgesser": "sporgere",
    "sporgessero": "sporgere",
    "sporgessi": "sporgere",
    "sporgessimo": "sporgere",
    "sporgeste": "sporgere",
    "sporgesti": "sporgere",
    "sporgete": "sporgere",
    "sporgeva": "sporgere",
    "sporgevamo": "sporgere",
    "sporgevan": "sporgere",
    "sporgevano": "sporgere",
    "sporgevate": "sporgere",
    "sporgevi": "sporgere",
    "sporgevo": "sporgere",
    "sporgi": "sporgere",
    "sporgiamo": "sporgere",
    "sporgiate": "sporgere",
    "sporgo": "sporgere",
    "sporgon": "sporgere",
    "sporgono": "sporgere",
    "sporser": "sporgere",
    "sporsero": "sporgere",
    "sporsi": "sporgere",
    "sporsè": "sporgere",
    "sporta": "sporgere",
    "sporte": "sporta",
    "sportelli": "sportello",
    "sporti": "sporgere",
    "sportiva": "sportivo",
    "sportive": "sportivo",
    "sportivi": "sportivo",
    "sporto": "sporgere",
    "sposa": "sposare",
    "sposai": "sposare",
    "sposalizi": "sposalizio",
    "sposammo": "sposare",
    "sposan": "sposare",
    "sposando": "sposare",
    "sposano": "sposare",
    "sposante": "sposare",
    "sposanti": "sposare",
    "sposar": "sposare",
    "sposaron": "sposare",
    "sposarono": "sposare",
    "sposasse": "sposare",
    "sposasser": "sposare",
    "sposassero": "sposare",
    "sposassi": "sposare",
    "sposassimo": "sposare",
    "sposaste": "sposare",
    "sposasti": "sposare",
    "sposata": "sposato",
    "sposate": "sposato",
    "sposati": "sposato",
    "sposato": "sposare",
    "sposava": "sposare",
    "sposavamo": "sposare",
    "sposavan": "sposare",
    "sposavano": "sposare",
    "sposavate": "sposare",
    "sposavi": "sposare",
    "sposavo": "sposare",
    "sposerai": "sposare",
    "sposeran": "sposare",
    "sposeranno": "sposare",
    "sposerebbe": "sposare",
    "sposerebber": "sposare",
    "sposerebbero": "sposare",
    "sposerei": "sposare",
    "sposeremmo": "sposare",
    "sposeremo": "sposare",
    "sposereste": "sposare",
    "sposeresti": "sposare",
    "sposerete": "sposare",
    "sposerà": "sposare",
    "sposerò": "sposare",
    "sposi": "sposo",
    "sposiamo": "sposare",
    "sposiate": "sposare",
    "sposin": "sposare",
    "sposini": "sposino",
    "sposino": "sposare",
    "sposo": "sposare",
    "spossa": "spossare",
    "spossai": "spossare",
    "spossammo": "spossare",
    "spossan": "spossare",
    "spossando": "spossare",
    "spossano": "spossare",
    "spossante": "spossare",
    "spossanti": "spossare",
    "spossar": "spossare",
    "spossaron": "spossare",
    "spossarono": "spossare",
    "spossasse": "spossare",
    "spossasser": "spossare",
    "spossassero": "spossare",
    "spossassi": "spossare",
    "spossassimo": "spossare",
    "spossaste": "spossare",
    "spossasti": "spossare",
    "spossata": "spossare",
    "spossate": "spossare",
    "spossati": "spossare",
    "spossato": "spossare",
    "spossava": "spossare",
    "spossavamo": "spossare",
    "spossavan": "spossare",
    "spossavano": "spossare",
    "spossavate": "spossare",
    "spossavi": "spossare",
    "spossavo": "spossare",
    "sposserai": "spossare",
    "sposseran": "spossare",
    "sposseranno": "spossare",
    "sposserebbe": "spossare",
    "sposserebber": "spossare",
    "sposserebbero": "spossare",
    "sposserei": "spossare",
    "sposseremmo": "spossare",
    "sposseremo": "spossare",
    "spossereste": "spossare",
    "sposseresti": "spossare",
    "sposserete": "spossare",
    "sposserà": "spossare",
    "sposserò": "spossare",
    "spossessa": "spossessare",
    "spossessai": "spossessare",
    "spossessammo": "spossessare",
    "spossessan": "spossessare",
    "spossessando": "spossessare",
    "spossessano": "spossessare",
    "spossessante": "spossessare",
    "spossessanti": "spossessare",
    "spossessar": "spossessare",
    "spossessaron": "spossessare",
    "spossessarono": "spossessare",
    "spossessasse": "spossessare",
    "spossessasser": "spossessare",
    "spossessassero": "spossessare",
    "spossessassi": "spossessare",
    "spossessassimo": "spossessare",
    "spossessaste": "spossessare",
    "spossessasti": "spossessare",
    "spossessata": "spossessare",
    "spossessate": "spossessare",
    "spossessati": "spossessare",
    "spossessato": "spossessare",
    "spossessava": "spossessare",
    "spossessavamo": "spossessare",
    "spossessavan": "spossessare",
    "spossessavano": "spossessare",
    "spossessavate": "spossessare",
    "spossessavi": "spossessare",
    "spossessavo": "spossessare",
    "spossesserai": "spossessare",
    "spossesseran": "spossessare",
    "spossesseranno": "spossessare",
    "spossesserebbe": "spossessare",
    "spossesserebber": "spossessare",
    "spossesserebbero": "spossessare",
    "spossesserei": "spossessare",
    "spossesseremmo": "spossessare",
    "spossesseremo": "spossessare",
    "spossessereste": "spossessare",
    "spossesseresti": "spossessare",
    "spossesserete": "spossessare",
    "spossesserà": "spossessare",
    "spossesserò": "spossessare",
    "spossessi": "spossessare",
    "spossessiamo": "spossessare",
    "spossessiate": "spossessare",
    "spossessin": "spossessare",
    "spossessino": "spossessare",
    "spossesso": "spossessare",
    "spossessò": "spossessare",
    "spossi": "spossare",
    "spossiamo": "spossare",
    "spossiate": "spossare",
    "spossin": "spossare",
    "spossino": "spossare",
    "sposso": "spossare",
    "spossò": "spossare",
    "sposta": "spostare",
    "spostai": "spostare",
    "spostamenti": "spostamento",
    "spostammo": "spostare",
    "spostan": "spostare",
    "spostando": "spostare",
    "spostano": "spostare",
    "spostante": "spostare",
    "spostanti": "spostare",
    "spostar": "spostare",
    "spostaron": "spostare",
    "spostarono": "spostare",
    "spostasse": "spostare",
    "spostasser": "spostare",
    "spostassero": "spostare",
    "spostassi": "spostare",
    "spostassimo": "spostare",
    "spostaste": "spostare",
    "spostasti": "spostare",
    "spostata": "spostato",
    "spostate": "spostato",
    "spostati": "spostato",
    "spostato": "spostare",
    "spostava": "spostare",
    "spostavamo": "spostare",
    "spostavan": "spostare",
    "spostavano": "spostare",
    "spostavate": "spostare",
    "spostavi": "spostare",
    "spostavo": "spostare",
    "sposterai": "spostare",
    "sposteran": "spostare",
    "sposteranno": "spostare",
    "sposterebbe": "spostare",
    "sposterebber": "spostare",
    "sposterebbero": "spostare",
    "sposterei": "spostare",
    "sposteremmo": "spostare",
    "sposteremo": "spostare",
    "spostereste": "spostare",
    "sposteresti": "spostare",
    "sposterete": "spostare",
    "sposterà": "spostare",
    "sposterò": "spostare",
    "sposti": "spostare",
    "spostiamo": "spostare",
    "spostiate": "spostare",
    "spostin": "spostare",
    "spostino": "spostare",
    "sposto": "spostare",
    "spostò": "spostare",
    "sposò": "sposare",
    "spranga": "sprangare",
    "sprangai": "sprangare",
    "sprangammo": "sprangare",
    "sprangan": "sprangare",
    "sprangando": "sprangare",
    "sprangano": "sprangare",
    "sprangante": "sprangare",
    "spranganti": "sprangare",
    "sprangar": "sprangare",
    "sprangaron": "sprangare",
    "sprangarono": "sprangare",
    "sprangasse": "sprangare",
    "sprangasser": "sprangare",
    "sprangassero": "sprangare",
    "sprangassi": "sprangare",
    "sprangassimo": "sprangare",
    "sprangaste": "sprangare",
    "sprangasti": "sprangare",
    "sprangata": "sprangare",
    "sprangate": "sprangata",
    "sprangati": "sprangare",
    "sprangato": "sprangare",
    "sprangava": "sprangare",
    "sprangavamo": "sprangare",
    "sprangavan": "sprangare",
    "sprangavano": "sprangare",
    "sprangavate": "sprangare",
    "sprangavi": "sprangare",
    "sprangavo": "sprangare",
    "spranghe": "spranga",
    "sprangherai": "sprangare",
    "sprangheran": "sprangare",
    "sprangheranno": "sprangare",
    "sprangherebbe": "sprangare",
    "sprangherebber": "sprangare",
    "sprangherebbero": "sprangare",
    "sprangherei": "sprangare",
    "sprangheremmo": "sprangare",
    "sprangheremo": "sprangare",
    "spranghereste": "sprangare",
    "sprangheresti": "sprangare",
    "sprangherete": "sprangare",
    "sprangherà": "sprangare",
    "sprangherò": "sprangare",
    "spranghi": "sprangare",
    "spranghiamo": "sprangare",
    "spranghiate": "sprangare",
    "spranghin": "sprangare",
    "spranghino": "sprangare",
    "sprango": "sprangare",
    "sprangò": "sprangare",
    "sprazzi": "sprazzo",
    "spreca": "sprecare",
    "sprecai": "sprecare",
    "sprecammo": "sprecare",
    "sprecan": "sprecare",
    "sprecando": "sprecare",
    "sprecano": "sprecare",
    "sprecante": "sprecare",
    "sprecanti": "sprecare",
    "sprecar": "sprecare",
    "sprecaron": "sprecare",
    "sprecarono": "sprecare",
    "sprecasse": "sprecare",
    "sprecasser": "sprecare",
    "sprecassero": "sprecare",
    "sprecassi": "sprecare",
    "sprecassimo": "sprecare",
    "sprecaste": "sprecare",
    "sprecasti": "sprecare",
    "sprecata": "sprecare",
    "sprecate": "sprecare",
    "sprecati": "sprecare",
    "sprecato": "sprecare",
    "sprecava": "sprecare",
    "sprecavamo": "sprecare",
    "sprecavan": "sprecare",
    "sprecavano": "sprecare",
    "sprecavate": "sprecare",
    "sprecavi": "sprecare",
    "sprecavo": "sprecare",
    "sprecherai": "sprecare",
    "sprecheran": "sprecare",
    "sprecheranno": "sprecare",
    "sprecherebbe": "sprecare",
    "sprecherebber": "sprecare",
    "sprecherebbero": "sprecare",
    "sprecherei": "sprecare",
    "sprecheremmo": "sprecare",
    "sprecheremo": "sprecare",
    "sprechereste": "sprecare",
    "sprecheresti": "sprecare",
    "sprecherete": "sprecare",
    "sprecherà": "sprecare",
    "sprecherò": "sprecare",
    "sprechi": "spreco",
    "sprechiamo": "sprecare",
    "sprechiate": "sprecare",
    "sprechin": "sprecare",
    "sprechino": "sprecare",
    "spreco": "sprecare",
    "spreconi": "sprecone",
    "sprecò": "sprecare",
    "spregerai": "spregiare",
    "spregeran": "spregiare",
    "spregeranno": "spregiare",
    "spregerebbe": "spregiare",
    "spregerebber": "spregiare",
    "spregerebbero": "spregiare",
    "spregerei": "spregiare",
    "spregeremmo": "spregiare",
    "spregeremo": "spregiare",
    "spregereste": "spregiare",
    "spregeresti": "spregiare",
    "spregerete": "spregiare",
    "spregerà": "spregiare",
    "spregerò": "spregiare",
    "spregevoli": "spregevole",
    "spregi": "spregiare",
    "spregia": "spregiare",
    "spregiai": "spregiare",
    "spregiammo": "spregiare",
    "spregiamo": "spregiare",
    "spregian": "spregiare",
    "spregiando": "spregiare",
    "spregiano": "spregiare",
    "spregiante": "spregiare",
    "spregianti": "spregiare",
    "spregiar": "spregiare",
    "spregiaron": "spregiare",
    "spregiarono": "spregiare",
    "spregiasse": "spregiare",
    "spregiasser": "spregiare",
    "spregiassero": "spregiare",
    "spregiassi": "spregiare",
    "spregiassimo": "spregiare",
    "spregiaste": "spregiare",
    "spregiasti": "spregiare",
    "spregiata": "spregiare",
    "spregiate": "spregiare",
    "spregiati": "spregiare",
    "spregiativa": "spregiativo",
    "spregiative": "spregiativo",
    "spregiativi": "spregiativo",
    "spregiato": "spregiare",
    "spregiava": "spregiare",
    "spregiavamo": "spregiare",
    "spregiavan": "spregiare",
    "spregiavano": "spregiare",
    "spregiavate": "spregiare",
    "spregiavi": "spregiare",
    "spregiavo": "spregiare",
    "spregin": "spregiare",
    "spregino": "spregiare",
    "spregio": "spregiare",
    "spregiosa": "spregioso",
    "spregiose": "spregioso",
    "spregiosi": "spregioso",
    "spregiudicata": "spregiudicato",
    "spregiudicate": "spregiudicato",
    "spregiudicatezze": "spregiudicatezza",
    "spregiudicati": "spregiudicato",
    "spregiò": "spregiare",
    "sprema": "spremere",
    "spreman": "spremere",
    "spremano": "spremere",
    "spreme": "spremere",
    "spremei": "spremere",
    "sprememmo": "spremere",
    "spremendo": "spremere",
    "spremente": "spremere",
    "sprementi": "spremere",
    "spremer": "spremere",
    "spremerai": "spremere",
    "spremeran": "spremere",
    "spremeranno": "spremere",
    "spremerebbe": "spremere",
    "spremerebber": "spremere",
    "spremerebbero": "spremere",
    "spremerei": "spremere",
    "spremeremmo": "spremere",
    "spremeremo": "spremere",
    "spremereste": "spremere",
    "spremeresti": "spremere",
    "spremerete": "spremere",
    "spremeron": "spremere",
    "spremerono": "spremere",
    "spremerà": "spremere",
    "spremerò": "spremere",
    "spremesse": "spremere",
    "spremesser": "spremere",
    "spremessero": "spremere",
    "spremessi": "spremere",
    "spremessimo": "spremere",
    "spremeste": "spremere",
    "spremesti": "spremere",
    "spremete": "spremere",
    "spremeva": "spremere",
    "spremevamo": "spremere",
    "spremevan": "spremere",
    "spremevano": "spremere",
    "spremevate": "spremere",
    "spremevi": "spremere",
    "spremevo": "spremere",
    "spremi": "spremere",
    "spremiamo": "spremere",
    "spremiate": "spremere",
    "spremiture": "spremitura",
    "spremo": "spremere",
    "spremon": "spremere",
    "spremono": "spremere",
    "spremuta": "spremere",
    "spremute": "spremere",
    "spremuti": "spremere",
    "spremuto": "spremere",
    "spremè": "spremere",
    "spreta": "spretare",
    "spretai": "spretare",
    "spretammo": "spretare",
    "spretan": "spretare",
    "spretando": "spretare",
    "spretano": "spretare",
    "spretar": "spretare",
    "spretaron": "spretare",
    "spretarono": "spretare",
    "spretasse": "spretare",
    "spretasser": "spretare",
    "spretassero": "spretare",
    "spretassi": "spretare",
    "spretassimo": "spretare",
    "spretaste": "spretare",
    "spretasti": "spretare",
    "spretata": "spretare",
    "spretate": "spretare",
    "spretati": "spretare",
    "spretato": "spretare",
    "spretava": "spretare",
    "spretavamo": "spretare",
    "spretavan": "spretare",
    "spretavano": "spretare",
    "spretavate": "spretare",
    "spretavi": "spretare",
    "spretavo": "spretare",
    "spreterai": "spretare",
    "spreteran": "spretare",
    "spreteranno": "spretare",
    "spreterebbe": "spretare",
    "spreterebber": "spretare",
    "spreterebbero": "spretare",
    "spreterei": "spretare",
    "spreteremmo": "spretare",
    "spreteremo": "spretare",
    "spretereste": "spretare",
    "spreteresti": "spretare",
    "spreterete": "spretare",
    "spreterà": "spretare",
    "spreterò": "spretare",
    "spreti": "spretare",
    "spretiamo": "spretare",
    "spretiate": "spretare",
    "spretin": "spretare",
    "spretino": "spretare",
    "spreto": "spretare",
    "spretò": "spretare",
    "sprezza": "sprezzare",
    "sprezzai": "sprezzare",
    "sprezzammo": "sprezzare",
    "sprezzan": "sprezzare",
    "sprezzando": "sprezzare",
    "sprezzano": "sprezzare",
    "sprezzante": "sprezzare",
    "sprezzanti": "sprezzare",
    "sprezzar": "sprezzare",
    "sprezzaron": "sprezzare",
    "sprezzarono": "sprezzare",
    "sprezzasse": "sprezzare",
    "sprezzasser": "sprezzare",
    "sprezzassero": "sprezzare",
    "sprezzassi": "sprezzare",
    "sprezzassimo": "sprezzare",
    "sprezzaste": "sprezzare",
    "sprezzasti": "sprezzare",
    "sprezzata": "sprezzare",
    "sprezzate": "sprezzare",
    "sprezzati": "sprezzare",
    "sprezzato": "sprezzare",
    "sprezzava": "sprezzare",
    "sprezzavamo": "sprezzare",
    "sprezzavan": "sprezzare",
    "sprezzavano": "sprezzare",
    "sprezzavate": "sprezzare",
    "sprezzavi": "sprezzare",
    "sprezzavo": "sprezzare",
    "sprezzerai": "sprezzare",
    "sprezzeran": "sprezzare",
    "sprezzeranno": "sprezzare",
    "sprezzerebbe": "sprezzare",
    "sprezzerebber": "sprezzare",
    "sprezzerebbero": "sprezzare",
    "sprezzerei": "sprezzare",
    "sprezzeremmo": "sprezzare",
    "sprezzeremo": "sprezzare",
    "sprezzereste": "sprezzare",
    "sprezzeresti": "sprezzare",
    "sprezzerete": "sprezzare",
    "sprezzerà": "sprezzare",
    "sprezzerò": "sprezzare",
    "sprezzi": "sprezzare",
    "sprezziamo": "sprezzare",
    "sprezziate": "sprezzare",
    "sprezzin": "sprezzare",
    "sprezzino": "sprezzare",
    "sprezzo": "sprezzare",
    "sprezzò": "sprezzare",
    "sprigiona": "sprigionare",
    "sprigionai": "sprigionare",
    "sprigionammo": "sprigionare",
    "sprigionan": "sprigionare",
    "sprigionando": "sprigionare",
    "sprigionano": "sprigionare",
    "sprigionante": "sprigionare",
    "sprigionanti": "sprigionare",
    "sprigionar": "sprigionare",
    "sprigionaron": "sprigionare",
    "sprigionarono": "sprigionare",
    "sprigionasse": "sprigionare",
    "sprigionasser": "sprigionare",
    "sprigionassero": "sprigionare",
    "sprigionassi": "sprigionare",
    "sprigionassimo": "sprigionare",
    "sprigionaste": "sprigionare",
    "sprigionasti": "sprigionare",
    "sprigionata": "sprigionare",
    "sprigionate": "sprigionare",
    "sprigionati": "sprigionare",
    "sprigionato": "sprigionare",
    "sprigionava": "sprigionare",
    "sprigionavamo": "sprigionare",
    "sprigionavan": "sprigionare",
    "sprigionavano": "sprigionare",
    "sprigionavate": "sprigionare",
    "sprigionavi": "sprigionare",
    "sprigionavo": "sprigionare",
    "sprigionerai": "sprigionare",
    "sprigioneran": "sprigionare",
    "sprigioneranno": "sprigionare",
    "sprigionerebbe": "sprigionare",
    "sprigionerebber": "sprigionare",
    "sprigionerebbero": "sprigionare",
    "sprigionerei": "sprigionare",
    "sprigioneremmo": "sprigionare",
    "sprigioneremo": "sprigionare",
    "sprigionereste": "sprigionare",
    "sprigioneresti": "sprigionare",
    "sprigionerete": "sprigionare",
    "sprigionerà": "sprigionare",
    "sprigionerò": "sprigionare",
    "sprigioni": "sprigionare",
    "sprigioniamo": "sprigionare",
    "sprigioniate": "sprigionare",
    "sprigionin": "sprigionare",
    "sprigionino": "sprigionare",
    "sprigiono": "sprigionare",
    "sprigionò": "sprigionare",
    "sprimaccerai": "sprimacciare",
    "sprimacceran": "sprimacciare",
    "sprimacceranno": "sprimacciare",
    "sprimaccerebbe": "sprimacciare",
    "sprimaccerebber": "sprimacciare",
    "sprimaccerebbero": "sprimacciare",
    "sprimaccerei": "sprimacciare",
    "sprimacceremmo": "sprimacciare",
    "sprimacceremo": "sprimacciare",
    "sprimaccereste": "sprimacciare",
    "sprimacceresti": "sprimacciare",
    "sprimaccerete": "sprimacciare",
    "sprimaccerà": "sprimacciare",
    "sprimaccerò": "sprimacciare",
    "sprimacci": "sprimacciare",
    "sprimaccia": "sprimacciare",
    "sprimacciai": "sprimacciare",
    "sprimacciammo": "sprimacciare",
    "sprimacciamo": "sprimacciare",
    "sprimaccian": "sprimacciare",
    "sprimacciando": "sprimacciare",
    "sprimacciano": "sprimacciare",
    "sprimacciante": "sprimacciare",
    "sprimaccianti": "sprimacciare",
    "sprimacciar": "sprimacciare",
    "sprimacciaron": "sprimacciare",
    "sprimacciarono": "sprimacciare",
    "sprimacciasse": "sprimacciare",
    "sprimacciasser": "sprimacciare",
    "sprimacciassero": "sprimacciare",
    "sprimacciassi": "sprimacciare",
    "sprimacciassimo": "sprimacciare",
    "sprimacciaste": "sprimacciare",
    "sprimacciasti": "sprimacciare",
    "sprimacciata": "sprimacciare",
    "sprimacciate": "sprimacciare",
    "sprimacciati": "sprimacciare",
    "sprimacciato": "sprimacciare",
    "sprimacciava": "sprimacciare",
    "sprimacciavamo": "sprimacciare",
    "sprimacciavan": "sprimacciare",
    "sprimacciavano": "sprimacciare",
    "sprimacciavate": "sprimacciare",
    "sprimacciavi": "sprimacciare",
    "sprimacciavo": "sprimacciare",
    "sprimaccin": "sprimacciare",
    "sprimaccino": "sprimacciare",
    "sprimaccio": "sprimacciare",
    "sprimacciò": "sprimacciare",
    "sprinta": "sprintare",
    "sprintai": "sprintare",
    "sprintammo": "sprintare",
    "sprintan": "sprintare",
    "sprintando": "sprintare",
    "sprintano": "sprintare",
    "sprintante": "sprintare",
    "sprintanti": "sprintare",
    "sprintar": "sprintare",
    "sprintaron": "sprintare",
    "sprintarono": "sprintare",
    "sprintasse": "sprintare",
    "sprintasser": "sprintare",
    "sprintassero": "sprintare",
    "sprintassi": "sprintare",
    "sprintassimo": "sprintare",
    "sprintaste": "sprintare",
    "sprintasti": "sprintare",
    "sprintata": "sprintare",
    "sprintate": "sprintare",
    "sprintati": "sprintare",
    "sprintato": "sprintare",
    "sprintava": "sprintare",
    "sprintavamo": "sprintare",
    "sprintavan": "sprintare",
    "sprintavano": "sprintare",
    "sprintavate": "sprintare",
    "sprintavi": "sprintare",
    "sprintavo": "sprintare",
    "sprinterai": "sprintare",
    "sprinteran": "sprintare",
    "sprinteranno": "sprintare",
    "sprinterebbe": "sprintare",
    "sprinterebber": "sprintare",
    "sprinterebbero": "sprintare",
    "sprinterei": "sprintare",
    "sprinteremmo": "sprintare",
    "sprinteremo": "sprintare",
    "sprintereste": "sprintare",
    "sprinteresti": "sprintare",
    "sprinterete": "sprintare",
    "sprinterà": "sprintare",
    "sprinterò": "sprintare",
    "sprinti": "sprintare",
    "sprintiamo": "sprintare",
    "sprintiate": "sprintare",
    "sprintin": "sprintare",
    "sprintino": "sprintare",
    "sprinto": "sprintare",
    "sprintò": "sprintare",
    "sprizza": "sprizzare",
    "sprizzai": "sprizzare",
    "sprizzammo": "sprizzare",
    "sprizzan": "sprizzare",
    "sprizzando": "sprizzare",
    "sprizzano": "sprizzare",
    "sprizzante": "sprizzare",
    "sprizzanti": "sprizzare",
    "sprizzar": "sprizzare",
    "sprizzaron": "sprizzare",
    "sprizzarono": "sprizzare",
    "sprizzasse": "sprizzare",
    "sprizzasser": "sprizzare",
    "sprizzassero": "sprizzare",
    "sprizzassi": "sprizzare",
    "sprizzassimo": "sprizzare",
    "sprizzaste": "sprizzare",
    "sprizzasti": "sprizzare",
    "sprizzata": "sprizzare",
    "sprizzate": "sprizzare",
    "sprizzati": "sprizzare",
    "sprizzato": "sprizzare",
    "sprizzava": "sprizzare",
    "sprizzavamo": "sprizzare",
    "sprizzavan": "sprizzare",
    "sprizzavano": "sprizzare",
    "sprizzavate": "sprizzare",
    "sprizzavi": "sprizzare",
    "sprizzavo": "sprizzare",
    "sprizzerai": "sprizzare",
    "sprizzeran": "sprizzare",
    "sprizzeranno": "sprizzare",
    "sprizzerebbe": "sprizzare",
    "sprizzerebber": "sprizzare",
    "sprizzerebbero": "sprizzare",
    "sprizzerei": "sprizzare",
    "sprizzeremmo": "sprizzare",
    "sprizzeremo": "sprizzare",
    "sprizzereste": "sprizzare",
    "sprizzeresti": "sprizzare",
    "sprizzerete": "sprizzare",
    "sprizzerà": "sprizzare",
    "sprizzerò": "sprizzare",
    "sprizzi": "sprizzare",
    "sprizziamo": "sprizzare",
    "sprizziate": "sprizzare",
    "sprizzin": "sprizzare",
    "sprizzino": "sprizzare",
    "sprizzo": "sprizzare",
    "sprizzò": "sprizzare",
    "sprofonda": "sprofondare",
    "sprofondai": "sprofondare",
    "sprofondammo": "sprofondare",
    "sprofondan": "sprofondare",
    "sprofondando": "sprofondare",
    "sprofondano": "sprofondare",
    "sprofondante": "sprofondare",
    "sprofondanti": "sprofondare",
    "sprofondar": "sprofondare",
    "sprofondaron": "sprofondare",
    "sprofondarono": "sprofondare",
    "sprofondasse": "sprofondare",
    "sprofondasser": "sprofondare",
    "sprofondassero": "sprofondare",
    "sprofondassi": "sprofondare",
    "sprofondassimo": "sprofondare",
    "sprofondaste": "sprofondare",
    "sprofondasti": "sprofondare",
    "sprofondata": "sprofondare",
    "sprofondate": "sprofondare",
    "sprofondati": "sprofondare",
    "sprofondato": "sprofondare",
    "sprofondava": "sprofondare",
    "sprofondavamo": "sprofondare",
    "sprofondavan": "sprofondare",
    "sprofondavano": "sprofondare",
    "sprofondavate": "sprofondare",
    "sprofondavi": "sprofondare",
    "sprofondavo": "sprofondare",
    "sprofonderai": "sprofondare",
    "sprofonderan": "sprofondare",
    "sprofonderanno": "sprofondare",
    "sprofonderebbe": "sprofondare",
    "sprofonderebber": "sprofondare",
    "sprofonderebbero": "sprofondare",
    "sprofonderei": "sprofondare",
    "sprofonderemmo": "sprofondare",
    "sprofonderemo": "sprofondare",
    "sprofondereste": "sprofondare",
    "sprofonderesti": "sprofondare",
    "sprofonderete": "sprofondare",
    "sprofonderà": "sprofondare",
    "sprofonderò": "sprofondare",
    "sprofondi": "sprofondare",
    "sprofondiamo": "sprofondare",
    "sprofondiate": "sprofondare",
    "sprofondin": "sprofondare",
    "sprofondino": "sprofondare",
    "sprofondo": "sprofondare",
    "sprofondò": "sprofondare",
    "sproloqui": "sproloquio",
    "sproloquia": "sproloquiare",
    "sproloquiai": "sproloquiare",
    "sproloquiammo": "sproloquiare",
    "sproloquiamo": "sproloquiare",
    "sproloquian": "sproloquiare",
    "sproloquiando": "sproloquiare",
    "sproloquiano": "sproloquiare",
    "sproloquiante": "sproloquiare",
    "sproloquianti": "sproloquiare",
    "sproloquiar": "sproloquiare",
    "sproloquiaron": "sproloquiare",
    "sproloquiarono": "sproloquiare",
    "sproloquiasse": "sproloquiare",
    "sproloquiasser": "sproloquiare",
    "sproloquiassero": "sproloquiare",
    "sproloquiassi": "sproloquiare",
    "sproloquiassimo": "sproloquiare",
    "sproloquiaste": "sproloquiare",
    "sproloquiasti": "sproloquiare",
    "sproloquiata": "sproloquiare",
    "sproloquiate": "sproloquiare",
    "sproloquiati": "sproloquiare",
    "sproloquiato": "sproloquiare",
    "sproloquiava": "sproloquiare",
    "sproloquiavamo": "sproloquiare",
    "sproloquiavan": "sproloquiare",
    "sproloquiavano": "sproloquiare",
    "sproloquiavate": "sproloquiare",
    "sproloquiavi": "sproloquiare",
    "sproloquiavo": "sproloquiare",
    "sproloquierai": "sproloquiare",
    "sproloquieran": "sproloquiare",
    "sproloquieranno": "sproloquiare",
    "sproloquierebbe": "sproloquiare",
    "sproloquierebber": "sproloquiare",
    "sproloquierebbero": "sproloquiare",
    "sproloquierei": "sproloquiare",
    "sproloquieremmo": "sproloquiare",
    "sproloquieremo": "sproloquiare",
    "sproloquiereste": "sproloquiare",
    "sproloquieresti": "sproloquiare",
    "sproloquierete": "sproloquiare",
    "sproloquierà": "sproloquiare",
    "sproloquierò": "sproloquiare",
    "sproloquin": "sproloquiare",
    "sproloquino": "sproloquiare",
    "sproloquio": "sproloquiare",
    "sproloquiò": "sproloquiare",
    "sprona": "spronare",
    "spronai": "spronare",
    "spronammo": "spronare",
    "spronan": "spronare",
    "spronando": "spronare",
    "spronano": "spronare",
    "spronante": "spronare",
    "spronanti": "spronare",
    "spronar": "spronare",
    "spronaron": "spronare",
    "spronarono": "spronare",
    "spronasse": "spronare",
    "spronasser": "spronare",
    "spronassero": "spronare",
    "spronassi": "spronare",
    "spronassimo": "spronare",
    "spronaste": "spronare",
    "spronasti": "spronare",
    "spronata": "spronare",
    "spronate": "spronare",
    "spronati": "spronare",
    "spronato": "spronare",
    "spronava": "spronare",
    "spronavamo": "spronare",
    "spronavan": "spronare",
    "spronavano": "spronare",
    "spronavate": "spronare",
    "spronavi": "spronare",
    "spronavo": "spronare",
    "spronerai": "spronare",
    "sproneran": "spronare",
    "sproneranno": "spronare",
    "spronerebbe": "spronare",
    "spronerebber": "spronare",
    "spronerebbero": "spronare",
    "spronerei": "spronare",
    "sproneremmo": "spronare",
    "sproneremo": "spronare",
    "spronereste": "spronare",
    "sproneresti": "spronare",
    "spronerete": "spronare",
    "spronerà": "spronare",
    "spronerò": "spronare",
    "sproni": "sprone",
    "sproniamo": "spronare",
    "sproniate": "spronare",
    "spronin": "spronare",
    "spronino": "spronare",
    "sprono": "spronare",
    "spronò": "spronare",
    "sproporzionata": "sproporzionato",
    "sproporzionate": "sproporzionato",
    "sproporzionati": "sproporzionato",
    "sproporzioni": "sproporzione",
    "sproposita": "spropositare",
    "spropositai": "spropositare",
    "spropositammo": "spropositare",
    "spropositan": "spropositare",
    "spropositando": "spropositare",
    "spropositano": "spropositare",
    "spropositante": "spropositare",
    "spropositanti": "spropositare",
    "spropositar": "spropositare",
    "spropositaron": "spropositare",
    "spropositarono": "spropositare",
    "spropositasse": "spropositare",
    "spropositasser": "spropositare",
    "spropositassero": "spropositare",
    "spropositassi": "spropositare",
    "spropositassimo": "spropositare",
    "spropositaste": "spropositare",
    "spropositasti": "spropositare",
    "spropositata": "spropositato",
    "spropositate": "spropositato",
    "spropositati": "spropositato",
    "spropositato": "spropositare",
    "spropositava": "spropositare",
    "spropositavamo": "spropositare",
    "spropositavan": "spropositare",
    "spropositavano": "spropositare",
    "spropositavate": "spropositare",
    "spropositavi": "spropositare",
    "spropositavo": "spropositare",
    "spropositerai": "spropositare",
    "spropositeran": "spropositare",
    "spropositeranno": "spropositare",
    "spropositerebbe": "spropositare",
    "spropositerebber": "spropositare",
    "spropositerebbero": "spropositare",
    "spropositerei": "spropositare",
    "spropositeremmo": "spropositare",
    "spropositeremo": "spropositare",
    "spropositereste": "spropositare",
    "spropositeresti": "spropositare",
    "spropositerete": "spropositare",
    "spropositerà": "spropositare",
    "spropositerò": "spropositare",
    "spropositi": "sproposito",
    "spropositiamo": "spropositare",
    "spropositiate": "spropositare",
    "spropositin": "spropositare",
    "spropositino": "spropositare",
    "sproposito": "spropositare",
    "spropositò": "spropositare",
    "spropri": "spropriare",
    "spropria": "spropriare",
    "spropriai": "spropriare",
    "spropriammo": "spropriare",
    "spropriamo": "spropriare",
    "sproprian": "spropriare",
    "spropriando": "spropriare",
    "spropriano": "spropriare",
    "spropriante": "spropriare",
    "sproprianti": "spropriare",
    "spropriar": "spropriare",
    "spropriaron": "spropriare",
    "spropriarono": "spropriare",
    "spropriasse": "spropriare",
    "spropriasser": "spropriare",
    "spropriassero": "spropriare",
    "spropriassi": "spropriare",
    "spropriassimo": "spropriare",
    "spropriaste": "spropriare",
    "spropriasti": "spropriare",
    "spropriata": "spropriare",
    "spropriate": "spropriare",
    "spropriati": "spropriare",
    "spropriato": "spropriare",
    "spropriava": "spropriare",
    "spropriavamo": "spropriare",
    "spropriavan": "spropriare",
    "spropriavano": "spropriare",
    "spropriavate": "spropriare",
    "spropriavi": "spropriare",
    "spropriavo": "spropriare",
    "sproprierai": "spropriare",
    "sproprieran": "spropriare",
    "sproprieranno": "spropriare",
    "sproprierebbe": "spropriare",
    "sproprierebber": "spropriare",
    "sproprierebbero": "spropriare",
    "sproprierei": "spropriare",
    "sproprieremmo": "spropriare",
    "sproprieremo": "spropriare",
    "spropriereste": "spropriare",
    "sproprieresti": "spropriare",
    "sproprierete": "spropriare",
    "sproprierà": "spropriare",
    "sproprierò": "spropriare",
    "sproprin": "spropriare",
    "sproprino": "spropriare",
    "sproprio": "spropriare",
    "spropriò": "spropriare",
    "sprovveda": "sprovvedere",
    "sprovvedan": "sprovvedere",
    "sprovvedano": "sprovvedere",
    "sprovvede": "sprovvedere",
    "sprovvedei": "sprovvedere",
    "sprovvedemmo": "sprovvedere",
    "sprovvedendo": "sprovvedere",
    "sprovvedente": "sprovvedere",
    "sprovvedenti": "sprovvedere",
    "sprovveder": "sprovvedere",
    "sprovvederai": "sprovvedere",
    "sprovvederan": "sprovvedere",
    "sprovvederanno": "sprovvedere",
    "sprovvederebbe": "sprovvedere",
    "sprovvederebber": "sprovvedere",
    "sprovvederebbero": "sprovvedere",
    "sprovvederei": "sprovvedere",
    "sprovvederemmo": "sprovvedere",
    "sprovvederemo": "sprovvedere",
    "sprovvedereste": "sprovvedere",
    "sprovvederesti": "sprovvedere",
    "sprovvederete": "sprovvedere",
    "sprovvederon": "sprovvedere",
    "sprovvederono": "sprovvedere",
    "sprovvederà": "sprovvedere",
    "sprovvederò": "sprovvedere",
    "sprovvedesse": "sprovvedere",
    "sprovvedesser": "sprovvedere",
    "sprovvedessero": "sprovvedere",
    "sprovvedessi": "sprovvedere",
    "sprovvedessimo": "sprovvedere",
    "sprovvedeste": "sprovvedere",
    "sprovvedesti": "sprovvedere",
    "sprovvedete": "sprovvedere",
    "sprovvedeva": "sprovvedere",
    "sprovvedevamo": "sprovvedere",
    "sprovvedevan": "sprovvedere",
    "sprovvedevano": "sprovvedere",
    "sprovvedevate": "sprovvedere",
    "sprovvedevi": "sprovvedere",
    "sprovvedevo": "sprovvedere",
    "sprovvedi": "sprovvedere",
    "sprovvediamo": "sprovvedere",
    "sprovvediate": "sprovvedere",
    "sprovvedo": "sprovvedere",
    "sprovvedon": "sprovvedere",
    "sprovvedono": "sprovvedere",
    "sprovveduta": "sprovveduto",
    "sprovvedute": "sprovveduto",
    "sprovveduti": "sprovveduto",
    "sprovveduto": "sprovvedere",
    "sprovvedè": "sprovvedere",
    "sprovvista": "sprovvisto",
    "sprovviste": "sprovvisto",
    "sprovvisti": "sprovvisto",
    "spruzza": "spruzzare",
    "spruzzai": "spruzzare",
    "spruzzammo": "spruzzare",
    "spruzzan": "spruzzare",
    "spruzzando": "spruzzare",
    "spruzzano": "spruzzare",
    "spruzzante": "spruzzare",
    "spruzzanti": "spruzzare",
    "spruzzar": "spruzzare",
    "spruzzaron": "spruzzare",
    "spruzzarono": "spruzzare",
    "spruzzasse": "spruzzare",
    "spruzzasser": "spruzzare",
    "spruzzassero": "spruzzare",
    "spruzzassi": "spruzzare",
    "spruzzassimo": "spruzzare",
    "spruzzaste": "spruzzare",
    "spruzzasti": "spruzzare",
    "spruzzata": "spruzzare",
    "spruzzate": "spruzzata",
    "spruzzati": "spruzzare",
    "spruzzato": "spruzzare",
    "spruzzava": "spruzzare",
    "spruzzavamo": "spruzzare",
    "spruzzavan": "spruzzare",
    "spruzzavano": "spruzzare",
    "spruzzavate": "spruzzare",
    "spruzzavi": "spruzzare",
    "spruzzavo": "spruzzare",
    "spruzzerai": "spruzzare",
    "spruzzeran": "spruzzare",
    "spruzzeranno": "spruzzare",
    "spruzzerebbe": "spruzzare",
    "spruzzerebber": "spruzzare",
    "spruzzerebbero": "spruzzare",
    "spruzzerei": "spruzzare",
    "spruzzeremmo": "spruzzare",
    "spruzzeremo": "spruzzare",
    "spruzzereste": "spruzzare",
    "spruzzeresti": "spruzzare",
    "spruzzerete": "spruzzare",
    "spruzzerà": "spruzzare",
    "spruzzerò": "spruzzare",
    "spruzzi": "spruzzo",
    "spruzziamo": "spruzzare",
    "spruzziate": "spruzzare",
    "spruzzin": "spruzzare",
    "spruzzino": "spruzzare",
    "spruzzo": "spruzzare",
    "spruzzò": "spruzzare",
    "spudorata": "spudorato",
    "spudorate": "spudorato",
    "spudoratezze": "spudoratezza",
    "spudorati": "spudorato",
    "spugne": "spugna",
    "spugnosa": "spugnoso",
    "spugnose": "spugnoso",
    "spugnosi": "spugnoso",
    "spula": "spulare",
    "spulai": "spulare",
    "spulammo": "spulare",
    "spulan": "spulare",
    "spulando": "spulare",
    "spulano": "spulare",
    "spulante": "spulare",
    "spulanti": "spulare",
    "spular": "spulare",
    "spularon": "spulare",
    "spularono": "spulare",
    "spulasse": "spulare",
    "spulasser": "spulare",
    "spulassero": "spulare",
    "spulassi": "spulare",
    "spulassimo": "spulare",
    "spulaste": "spulare",
    "spulasti": "spulare",
    "spulata": "spulare",
    "spulate": "spulare",
    "spulati": "spulare",
    "spulato": "spulare",
    "spulava": "spulare",
    "spulavamo": "spulare",
    "spulavan": "spulare",
    "spulavano": "spulare",
    "spulavate": "spulare",
    "spulavi": "spulare",
    "spulavo": "spulare",
    "spulcerai": "spulciare",
    "spulceran": "spulciare",
    "spulceranno": "spulciare",
    "spulcerebbe": "spulciare",
    "spulcerebber": "spulciare",
    "spulcerebbero": "spulciare",
    "spulcerei": "spulciare",
    "spulceremmo": "spulciare",
    "spulceremo": "spulciare",
    "spulcereste": "spulciare",
    "spulceresti": "spulciare",
    "spulcerete": "spulciare",
    "spulcerà": "spulciare",
    "spulcerò": "spulciare",
    "spulci": "spulciare",
    "spulcia": "spulciare",
    "spulciai": "spulciare",
    "spulciammo": "spulciare",
    "spulciamo": "spulciare",
    "spulcian": "spulciare",
    "spulciando": "spulciare",
    "spulciano": "spulciare",
    "spulciante": "spulciare",
    "spulcianti": "spulciare",
    "spulciar": "spulciare",
    "spulciaron": "spulciare",
    "spulciarono": "spulciare",
    "spulciasse": "spulciare",
    "spulciasser": "spulciare",
    "spulciassero": "spulciare",
    "spulciassi": "spulciare",
    "spulciassimo": "spulciare",
    "spulciaste": "spulciare",
    "spulciasti": "spulciare",
    "spulciata": "spulciare",
    "spulciate": "spulciare",
    "spulciati": "spulciare",
    "spulciato": "spulciare",
    "spulciava": "spulciare",
    "spulciavamo": "spulciare",
    "spulciavan": "spulciare",
    "spulciavano": "spulciare",
    "spulciavate": "spulciare",
    "spulciavi": "spulciare",
    "spulciavo": "spulciare",
    "spulcin": "spulciare",
    "spulcino": "spulciare",
    "spulcio": "spulciare",
    "spulciò": "spulciare",
    "spulerai": "spulare",
    "spuleran": "spulare",
    "spuleranno": "spulare",
    "spulerebbe": "spulare",
    "spulerebber": "spulare",
    "spulerebbero": "spulare",
    "spulerei": "spulare",
    "spuleremmo": "spulare",
    "spuleremo": "spulare",
    "spulereste": "spulare",
    "spuleresti": "spulare",
    "spulerete": "spulare",
    "spulerà": "spulare",
    "spulerò": "spulare",
    "spuli": "spulare",
    "spuliamo": "spulare",
    "spuliate": "spulare",
    "spulin": "spulare",
    "spulino": "spulare",
    "spulo": "spulare",
    "spulò": "spulare",
    "spuma": "spumare",
    "spumai": "spumare",
    "spumammo": "spumare",
    "spuman": "spumare",
    "spumando": "spumare",
    "spumano": "spumare",
    "spumante": "spumare",
    "spumanti": "spumare",
    "spumar": "spumare",
    "spumaron": "spumare",
    "spumarono": "spumare",
    "spumasse": "spumare",
    "spumasser": "spumare",
    "spumassero": "spumare",
    "spumassi": "spumare",
    "spumassimo": "spumare",
    "spumaste": "spumare",
    "spumasti": "spumare",
    "spumata": "spumare",
    "spumate": "spumare",
    "spumati": "spumare",
    "spumato": "spumare",
    "spumava": "spumare",
    "spumavamo": "spumare",
    "spumavan": "spumare",
    "spumavano": "spumare",
    "spumavate": "spumare",
    "spumavi": "spumare",
    "spumavo": "spumare",
    "spume": "spuma",
    "spumeggerai": "spumeggiare",
    "spumeggeran": "spumeggiare",
    "spumeggeranno": "spumeggiare",
    "spumeggerebbe": "spumeggiare",
    "spumeggerebber": "spumeggiare",
    "spumeggerebbero": "spumeggiare",
    "spumeggerei": "spumeggiare",
    "spumeggeremmo": "spumeggiare",
    "spumeggeremo": "spumeggiare",
    "spumeggereste": "spumeggiare",
    "spumeggeresti": "spumeggiare",
    "spumeggerete": "spumeggiare",
    "spumeggerà": "spumeggiare",
    "spumeggerò": "spumeggiare",
    "spumeggi": "spumeggiare",
    "spumeggia": "spumeggiare",
    "spumeggiai": "spumeggiare",
    "spumeggiammo": "spumeggiare",
    "spumeggiamo": "spumeggiare",
    "spumeggian": "spumeggiare",
    "spumeggiando": "spumeggiare",
    "spumeggiano": "spumeggiare",
    "spumeggiante": "spumeggiare",
    "spumeggianti": "spumeggiare",
    "spumeggiar": "spumeggiare",
    "spumeggiaron": "spumeggiare",
    "spumeggiarono": "spumeggiare",
    "spumeggiasse": "spumeggiare",
    "spumeggiasser": "spumeggiare",
    "spumeggiassero": "spumeggiare",
    "spumeggiassi": "spumeggiare",
    "spumeggiassimo": "spumeggiare",
    "spumeggiaste": "spumeggiare",
    "spumeggiasti": "spumeggiare",
    "spumeggiata": "spumeggiare",
    "spumeggiate": "spumeggiare",
    "spumeggiati": "spumeggiare",
    "spumeggiato": "spumeggiare",
    "spumeggiava": "spumeggiare",
    "spumeggiavamo": "spumeggiare",
    "spumeggiavan": "spumeggiare",
    "spumeggiavano": "spumeggiare",
    "spumeggiavate": "spumeggiare",
    "spumeggiavi": "spumeggiare",
    "spumeggiavo": "spumeggiare",
    "spumeggin": "spumeggiare",
    "spumeggino": "spumeggiare",
    "spumeggio": "spumeggiare",
    "spumeggiò": "spumeggiare",
    "spumerai": "spumare",
    "spumeran": "spumare",
    "spumeranno": "spumare",
    "spumerebbe": "spumare",
    "spumerebber": "spumare",
    "spumerebbero": "spumare",
    "spumerei": "spumare",
    "spumeremmo": "spumare",
    "spumeremo": "spumare",
    "spumereste": "spumare",
    "spumeresti": "spumare",
    "spumerete": "spumare",
    "spumerà": "spumare",
    "spumerò": "spumare",
    "spumi": "spumare",
    "spumiamo": "spumare",
    "spumiate": "spumare",
    "spumin": "spumare",
    "spumino": "spumare",
    "spumo": "spumare",
    "spumò": "spumare",
    "spunta": "spuntare",
    "spuntai": "spuntare",
    "spuntammo": "spuntare",
    "spuntan": "spuntare",
    "spuntando": "spuntare",
    "spuntano": "spuntare",
    "spuntante": "spuntare",
    "spuntanti": "spuntare",
    "spuntar": "spuntare",
    "spuntaron": "spuntare",
    "spuntarono": "spuntare",
    "spuntasse": "spuntare",
    "spuntasser": "spuntare",
    "spuntassero": "spuntare",
    "spuntassi": "spuntare",
    "spuntassimo": "spuntare",
    "spuntaste": "spuntare",
    "spuntasti": "spuntare",
    "spuntata": "spuntare",
    "spuntate": "spuntare",
    "spuntati": "spuntare",
    "spuntato": "spuntare",
    "spuntava": "spuntare",
    "spuntavamo": "spuntare",
    "spuntavan": "spuntare",
    "spuntavano": "spuntare",
    "spuntavate": "spuntare",
    "spuntavi": "spuntare",
    "spuntavo": "spuntare",
    "spunterai": "spuntare",
    "spunteran": "spuntare",
    "spunteranno": "spuntare",
    "spunterebbe": "spuntare",
    "spunterebber": "spuntare",
    "spunterebbero": "spuntare",
    "spunterei": "spuntare",
    "spunteremmo": "spuntare",
    "spunteremo": "spuntare",
    "spuntereste": "spuntare",
    "spunteresti": "spuntare",
    "spunterete": "spuntare",
    "spunterà": "spuntare",
    "spunterò": "spuntare",
    "spunti": "spunto",
    "spuntiamo": "spuntare",
    "spuntiate": "spuntare",
    "spuntin": "spuntare",
    "spuntini": "spuntino",
    "spuntino": "spuntare",
    "spunto": "spuntare",
    "spuntoni": "spuntone",
    "spuntò": "spuntare",
    "spurga": "spurgare",
    "spurgai": "spurgare",
    "spurgammo": "spurgare",
    "spurgan": "spurgare",
    "spurgando": "spurgare",
    "spurgano": "spurgare",
    "spurgante": "spurgare",
    "spurganti": "spurgare",
    "spurgar": "spurgare",
    "spurgaron": "spurgare",
    "spurgarono": "spurgare",
    "spurgasse": "spurgare",
    "spurgasser": "spurgare",
    "spurgassero": "spurgare",
    "spurgassi": "spurgare",
    "spurgassimo": "spurgare",
    "spurgaste": "spurgare",
    "spurgasti": "spurgare",
    "spurgata": "spurgare",
    "spurgate": "spurgare",
    "spurgati": "spurgare",
    "spurgato": "spurgare",
    "spurgava": "spurgare",
    "spurgavamo": "spurgare",
    "spurgavan": "spurgare",
    "spurgavano": "spurgare",
    "spurgavate": "spurgare",
    "spurgavi": "spurgare",
    "spurgavo": "spurgare",
    "spurgherai": "spurgare",
    "spurgheran": "spurgare",
    "spurgheranno": "spurgare",
    "spurgherebbe": "spurgare",
    "spurgherebber": "spurgare",
    "spurgherebbero": "spurgare",
    "spurgherei": "spurgare",
    "spurgheremmo": "spurgare",
    "spurgheremo": "spurgare",
    "spurghereste": "spurgare",
    "spurgheresti": "spurgare",
    "spurgherete": "spurgare",
    "spurgherà": "spurgare",
    "spurgherò": "spurgare",
    "spurghi": "spurgare",
    "spurghiamo": "spurgare",
    "spurghiate": "spurgare",
    "spurghin": "spurgare",
    "spurghino": "spurgare",
    "spurgo": "spurgare",
    "spurgò": "spurgare",
    "spuri": "spurio",
    "spuria": "spurio",
    "spurie": "spurio",
    "sputa": "sputare",
    "sputacchi": "sputacchiare",
    "sputacchia": "sputacchiare",
    "sputacchiai": "sputacchiare",
    "sputacchiammo": "sputacchiare",
    "sputacchiamo": "sputacchiare",
    "sputacchian": "sputacchiare",
    "sputacchiando": "sputacchiare",
    "sputacchiano": "sputacchiare",
    "sputacchiante": "sputacchiare",
    "sputacchianti": "sputacchiare",
    "sputacchiar": "sputacchiare",
    "sputacchiaron": "sputacchiare",
    "sputacchiarono": "sputacchiare",
    "sputacchiasse": "sputacchiare",
    "sputacchiasser": "sputacchiare",
    "sputacchiassero": "sputacchiare",
    "sputacchiassi": "sputacchiare",
    "sputacchiassimo": "sputacchiare",
    "sputacchiaste": "sputacchiare",
    "sputacchiasti": "sputacchiare",
    "sputacchiata": "sputacchiare",
    "sputacchiate": "sputacchiare",
    "sputacchiati": "sputacchiare",
    "sputacchiato": "sputacchiare",
    "sputacchiava": "sputacchiare",
    "sputacchiavamo": "sputacchiare",
    "sputacchiavan": "sputacchiare",
    "sputacchiavano": "sputacchiare",
    "sputacchiavate": "sputacchiare",
    "sputacchiavi": "sputacchiare",
    "sputacchiavo": "sputacchiare",
    "sputacchierai": "sputacchiare",
    "sputacchieran": "sputacchiare",
    "sputacchieranno": "sputacchiare",
    "sputacchierebbe": "sputacchiare",
    "sputacchierebber": "sputacchiare",
    "sputacchierebbero": "sputacchiare",
    "sputacchierei": "sputacchiare",
    "sputacchieremmo": "sputacchiare",
    "sputacchieremo": "sputacchiare",
    "sputacchiereste": "sputacchiare",
    "sputacchieresti": "sputacchiare",
    "sputacchierete": "sputacchiare",
    "sputacchierà": "sputacchiare",
    "sputacchierò": "sputacchiare",
    "sputacchin": "sputacchiare",
    "sputacchino": "sputacchiare",
    "sputacchio": "sputacchiare",
    "sputacchiò": "sputacchiare",
    "sputai": "sputare",
    "sputammo": "sputare",
    "sputan": "sputare",
    "sputando": "sputare",
    "sputano": "sputare",
    "sputante": "sputare",
    "sputanti": "sputare",
    "sputar": "sputare",
    "sputaron": "sputare",
    "sputarono": "sputare",
    "sputasse": "sputare",
    "sputasser": "sputare",
    "sputassero": "sputare",
    "sputassi": "sputare",
    "sputassimo": "sputare",
    "sputaste": "sputare",
    "sputasti": "sputare",
    "sputata": "sputare",
    "sputate": "sputare",
    "sputati": "sputare",
    "sputato": "sputare",
    "sputava": "sputare",
    "sputavamo": "sputare",
    "sputavan": "sputare",
    "sputavano": "sputare",
    "sputavate": "sputare",
    "sputavi": "sputare",
    "sputavo": "sputare",
    "sputerai": "sputare",
    "sputeran": "sputare",
    "sputeranno": "sputare",
    "sputerebbe": "sputare",
    "sputerebber": "sputare",
    "sputerebbero": "sputare",
    "sputerei": "sputare",
    "sputeremmo": "sputare",
    "sputeremo": "sputare",
    "sputereste": "sputare",
    "sputeresti": "sputare",
    "sputerete": "sputare",
    "sputerà": "sputare",
    "sputerò": "sputare",
    "sputi": "sputo",
    "sputiamo": "sputare",
    "sputiate": "sputare",
    "sputin": "sputare",
    "sputino": "sputare",
    "sputo": "sputare",
    "sputtana": "sputtanare",
    "sputtanai": "sputtanare",
    "sputtanammo": "sputtanare",
    "sputtanan": "sputtanare",
    "sputtanando": "sputtanare",
    "sputtanano": "sputtanare",
    "sputtanante": "sputtanare",
    "sputtananti": "sputtanare",
    "sputtanar": "sputtanare",
    "sputtanaron": "sputtanare",
    "sputtanarono": "sputtanare",
    "sputtanasse": "sputtanare",
    "sputtanasser": "sputtanare",
    "sputtanassero": "sputtanare",
    "sputtanassi": "sputtanare",
    "sputtanassimo": "sputtanare",
    "sputtanaste": "sputtanare",
    "sputtanasti": "sputtanare",
    "sputtanata": "sputtanare",
    "sputtanate": "sputtanare",
    "sputtanati": "sputtanare",
    "sputtanato": "sputtanare",
    "sputtanava": "sputtanare",
    "sputtanavamo": "sputtanare",
    "sputtanavan": "sputtanare",
    "sputtanavano": "sputtanare",
    "sputtanavate": "sputtanare",
    "sputtanavi": "sputtanare",
    "sputtanavo": "sputtanare",
    "sputtanerai": "sputtanare",
    "sputtaneran": "sputtanare",
    "sputtaneranno": "sputtanare",
    "sputtanerebbe": "sputtanare",
    "sputtanerebber": "sputtanare",
    "sputtanerebbero": "sputtanare",
    "sputtanerei": "sputtanare",
    "sputtaneremmo": "sputtanare",
    "sputtaneremo": "sputtanare",
    "sputtanereste": "sputtanare",
    "sputtaneresti": "sputtanare",
    "sputtanerete": "sputtanare",
    "sputtanerà": "sputtanare",
    "sputtanerò": "sputtanare",
    "sputtani": "sputtanare",
    "sputtaniamo": "sputtanare",
    "sputtaniate": "sputtanare",
    "sputtanin": "sputtanare",
    "sputtanino": "sputtanare",
    "sputtano": "sputtanare",
    "sputtanò": "sputtanare",
    "sputò": "sputare",
    "squaderna": "squadernare",
    "squadernai": "squadernare",
    "squadernammo": "squadernare",
    "squadernan": "squadernare",
    "squadernando": "squadernare",
    "squadernano": "squadernare",
    "squadernante": "squadernare",
    "squadernanti": "squadernare",
    "squadernar": "squadernare",
    "squadernaron": "squadernare",
    "squadernarono": "squadernare",
    "squadernasse": "squadernare",
    "squadernasser": "squadernare",
    "squadernassero": "squadernare",
    "squadernassi": "squadernare",
    "squadernassimo": "squadernare",
    "squadernaste": "squadernare",
    "squadernasti": "squadernare",
    "squadernata": "squadernare",
    "squadernate": "squadernare",
    "squadernati": "squadernare",
    "squadernato": "squadernare",
    "squadernava": "squadernare",
    "squadernavamo": "squadernare",
    "squadernavan": "squadernare",
    "squadernavano": "squadernare",
    "squadernavate": "squadernare",
    "squadernavi": "squadernare",
    "squadernavo": "squadernare",
    "squadernerai": "squadernare",
    "squaderneran": "squadernare",
    "squaderneranno": "squadernare",
    "squadernerebbe": "squadernare",
    "squadernerebber": "squadernare",
    "squadernerebbero": "squadernare",
    "squadernerei": "squadernare",
    "squaderneremmo": "squadernare",
    "squaderneremo": "squadernare",
    "squadernereste": "squadernare",
    "squaderneresti": "squadernare",
    "squadernerete": "squadernare",
    "squadernerà": "squadernare",
    "squadernerò": "squadernare",
    "squaderni": "squadernare",
    "squaderniamo": "squadernare",
    "squaderniate": "squadernare",
    "squadernin": "squadernare",
    "squadernino": "squadernare",
    "squaderno": "squadernare",
    "squadernò": "squadernare",
    "squadra": "squadrare",
    "squadracce": "squadraccia",
    "squadrai": "squadrare",
    "squadrammo": "squadrare",
    "squadran": "squadrare",
    "squadrando": "squadrare",
    "squadrano": "squadrare",
    "squadrante": "squadrare",
    "squadranti": "squadrare",
    "squadrar": "squadrare",
    "squadraron": "squadrare",
    "squadrarono": "squadrare",
    "squadrasse": "squadrare",
    "squadrasser": "squadrare",
    "squadrassero": "squadrare",
    "squadrassi": "squadrare",
    "squadrassimo": "squadrare",
    "squadraste": "squadrare",
    "squadrasti": "squadrare",
    "squadrata": "squadrare",
    "squadrate": "squadrare",
    "squadrati": "squadrare",
    "squadrato": "squadrare",
    "squadrava": "squadrare",
    "squadravamo": "squadrare",
    "squadravan": "squadrare",
    "squadravano": "squadrare",
    "squadravate": "squadrare",
    "squadravi": "squadrare",
    "squadravo": "squadrare",
    "squadre": "squadra",
    "squadrerai": "squadrare",
    "squadreran": "squadrare",
    "squadreranno": "squadrare",
    "squadrerebbe": "squadrare",
    "squadrerebber": "squadrare",
    "squadrerebbero": "squadrare",
    "squadrerei": "squadrare",
    "squadreremmo": "squadrare",
    "squadreremo": "squadrare",
    "squadrereste": "squadrare",
    "squadreresti": "squadrare",
    "squadrerete": "squadrare",
    "squadrerà": "squadrare",
    "squadrerò": "squadrare",
    "squadrette": "squadretta",
    "squadri": "squadrare",
    "squadriamo": "squadrare",
    "squadriate": "squadrare",
    "squadriglie": "squadriglia",
    "squadrin": "squadrare",
    "squadrino": "squadrare",
    "squadrismi": "squadrismo",
    "squadristi": "squadrista",
    "squadro": "squadrare",
    "squadroni": "squadrone",
    "squadrò": "squadrare",
    "squagli": "squagliare",
    "squaglia": "squagliare",
    "squagliai": "squagliare",
    "squagliammo": "squagliare",
    "squagliamo": "squagliare",
    "squaglian": "squagliare",
    "squagliando": "squagliare",
    "squagliano": "squagliare",
    "squagliante": "squagliare",
    "squaglianti": "squagliare",
    "squagliar": "squagliare",
    "squagliaron": "squagliare",
    "squagliarono": "squagliare",
    "squagliasse": "squagliare",
    "squagliasser": "squagliare",
    "squagliassero": "squagliare",
    "squagliassi": "squagliare",
    "squagliassimo": "squagliare",
    "squagliaste": "squagliare",
    "squagliasti": "squagliare",
    "squagliata": "squagliare",
    "squagliate": "squagliare",
    "squagliati": "squagliare",
    "squagliato": "squagliare",
    "squagliava": "squagliare",
    "squagliavamo": "squagliare",
    "squagliavan": "squagliare",
    "squagliavano": "squagliare",
    "squagliavate": "squagliare",
    "squagliavi": "squagliare",
    "squagliavo": "squagliare",
    "squaglierai": "squagliare",
    "squaglieran": "squagliare",
    "squaglieranno": "squagliare",
    "squaglierebbe": "squagliare",
    "squaglierebber": "squagliare",
    "squaglierebbero": "squagliare",
    "squaglierei": "squagliare",
    "squaglieremmo": "squagliare",
    "squaglieremo": "squagliare",
    "squagliereste": "squagliare",
    "squaglieresti": "squagliare",
    "squaglierete": "squagliare",
    "squaglierà": "squagliare",
    "squaglierò": "squagliare",
    "squaglin": "squagliare",
    "squaglino": "squagliare",
    "squaglio": "squagliare",
    "squagliò": "squagliare",
    "squali": "squalo",
    "squalifica": "squalificare",
    "squalificai": "squalificare",
    "squalificammo": "squalificare",
    "squalifican": "squalificare",
    "squalificando": "squalificare",
    "squalificano": "squalificare",
    "squalificante": "squalificare",
    "squalificanti": "squalificare",
    "squalificar": "squalificare",
    "squalificaron": "squalificare",
    "squalificarono": "squalificare",
    "squalificasse": "squalificare",
    "squalificasser": "squalificare",
    "squalificassero": "squalificare",
    "squalificassi": "squalificare",
    "squalificassimo": "squalificare",
    "squalificaste": "squalificare",
    "squalificasti": "squalificare",
    "squalificata": "squalificare",
    "squalificate": "squalificare",
    "squalificati": "squalificato",
    "squalificato": "squalificare",
    "squalificava": "squalificare",
    "squalificavamo": "squalificare",
    "squalificavan": "squalificare",
    "squalificavano": "squalificare",
    "squalificavate": "squalificare",
    "squalificavi": "squalificare",
    "squalificavo": "squalificare",
    "squalifiche": "squalifica",
    "squalificherai": "squalificare",
    "squalificheran": "squalificare",
    "squalificheranno": "squalificare",
    "squalificherebbe": "squalificare",
    "squalificherebber": "squalificare",
    "squalificherebbero": "squalificare",
    "squalificherei": "squalificare",
    "squalificheremmo": "squalificare",
    "squalificheremo": "squalificare",
    "squalifichereste": "squalificare",
    "squalificheresti": "squalificare",
    "squalificherete": "squalificare",
    "squalificherà": "squalificare",
    "squalificherò": "squalificare",
    "squalifichi": "squalificare",
    "squalifichiamo": "squalificare",
    "squalifichiate": "squalificare",
    "squalifichin": "squalificare",
    "squalifichino": "squalificare",
    "squalifico": "squalificare",
    "squalificò": "squalificare",
    "squallida": "squallido",
    "squallide": "squallido",
    "squallidi": "squallido",
    "squallori": "squallore",
    "squama": "squamare",
    "squamai": "squamare",
    "squamammo": "squamare",
    "squaman": "squamare",
    "squamando": "squamare",
    "squamano": "squamare",
    "squamante": "squamare",
    "squamanti": "squamare",
    "squamar": "squamare",
    "squamaron": "squamare",
    "squamarono": "squamare",
    "squamasse": "squamare",
    "squamasser": "squamare",
    "squamassero": "squamare",
    "squamassi": "squamare",
    "squamassimo": "squamare",
    "squamaste": "squamare",
    "squamasti": "squamare",
    "squamata": "squamare",
    "squamate": "squamare",
    "squamati": "squamare",
    "squamato": "squamare",
    "squamava": "squamare",
    "squamavamo": "squamare",
    "squamavan": "squamare",
    "squamavano": "squamare",
    "squamavate": "squamare",
    "squamavi": "squamare",
    "squamavo": "squamare",
    "squamerai": "squamare",
    "squameran": "squamare",
    "squameranno": "squamare",
    "squamerebbe": "squamare",
    "squamerebber": "squamare",
    "squamerebbero": "squamare",
    "squamerei": "squamare",
    "squameremmo": "squamare",
    "squameremo": "squamare",
    "squamereste": "squamare",
    "squameresti": "squamare",
    "squamerete": "squamare",
    "squamerà": "squamare",
    "squamerò": "squamare",
    "squami": "squamare",
    "squamiamo": "squamare",
    "squamiate": "squamare",
    "squamin": "squamare",
    "squamino": "squamare",
    "squamo": "squamare",
    "squamò": "squamare",
    "squarcerai": "squarciare",
    "squarceran": "squarciare",
    "squarceranno": "squarciare",
    "squarcerebbe": "squarciare",
    "squarcerebber": "squarciare",
    "squarcerebbero": "squarciare",
    "squarcerei": "squarciare",
    "squarceremmo": "squarciare",
    "squarceremo": "squarciare",
    "squarcereste": "squarciare",
    "squarceresti": "squarciare",
    "squarcerete": "squarciare",
    "squarcerà": "squarciare",
    "squarcerò": "squarciare",
    "squarci": "squarcio",
    "squarcia": "squarciare",
    "squarciai": "squarciare",
    "squarciammo": "squarciare",
    "squarciamo": "squarciare",
    "squarcian": "squarciare",
    "squarciando": "squarciare",
    "squarciano": "squarciare",
    "squarciante": "squarciare",
    "squarcianti": "squarciare",
    "squarciar": "squarciare",
    "squarciaron": "squarciare",
    "squarciarono": "squarciare",
    "squarciasse": "squarciare",
    "squarciasser": "squarciare",
    "squarciassero": "squarciare",
    "squarciassi": "squarciare",
    "squarciassimo": "squarciare",
    "squarciaste": "squarciare",
    "squarciasti": "squarciare",
    "squarciata": "squarciare",
    "squarciate": "squarciare",
    "squarciati": "squarciare",
    "squarciato": "squarciare",
    "squarciava": "squarciare",
    "squarciavamo": "squarciare",
    "squarciavan": "squarciare",
    "squarciavano": "squarciare",
    "squarciavate": "squarciare",
    "squarciavi": "squarciare",
    "squarciavo": "squarciare",
    "squarcin": "squarciare",
    "squarcino": "squarciare",
    "squarcio": "squarciare",
    "squarciò": "squarciare",
    "squarta": "squartare",
    "squartai": "squartare",
    "squartamenti": "squartamento",
    "squartammo": "squartare",
    "squartan": "squartare",
    "squartando": "squartare",
    "squartano": "squartare",
    "squartante": "squartare",
    "squartanti": "squartare",
    "squartar": "squartare",
    "squartaron": "squartare",
    "squartarono": "squartare",
    "squartasse": "squartare",
    "squartasser": "squartare",
    "squartassero": "squartare",
    "squartassi": "squartare",
    "squartassimo": "squartare",
    "squartaste": "squartare",
    "squartasti": "squartare",
    "squartata": "squartare",
    "squartate": "squartare",
    "squartati": "squartare",
    "squartato": "squartare",
    "squartava": "squartare",
    "squartavamo": "squartare",
    "squartavan": "squartare",
    "squartavano": "squartare",
    "squartavate": "squartare",
    "squartavi": "squartare",
    "squartavo": "squartare",
    "squarterai": "squartare",
    "squarteran": "squartare",
    "squarteranno": "squartare",
    "squarterebbe": "squartare",
    "squarterebber": "squartare",
    "squarterebbero": "squartare",
    "squarterei": "squartare",
    "squarteremmo": "squartare",
    "squarteremo": "squartare",
    "squartereste": "squartare",
    "squarteresti": "squartare",
    "squarterete": "squartare",
    "squarterà": "squartare",
    "squarterò": "squartare",
    "squarti": "squartare",
    "squartiamo": "squartare",
    "squartiate": "squartare",
    "squartin": "squartare",
    "squartino": "squartare",
    "squarto": "squartare",
    "squartò": "squartare",
    "squassa": "squassare",
    "squassai": "squassare",
    "squassammo": "squassare",
    "squassan": "squassare",
    "squassando": "squassare",
    "squassano": "squassare",
    "squassante": "squassare",
    "squassanti": "squassare",
    "squassar": "squassare",
    "squassaron": "squassare",
    "squassarono": "squassare",
    "squassasse": "squassare",
    "squassasser": "squassare",
    "squassassero": "squassare",
    "squassassi": "squassare",
    "squassassimo": "squassare",
    "squassaste": "squassare",
    "squassasti": "squassare",
    "squassata": "squassare",
    "squassate": "squassare",
    "squassati": "squassare",
    "squassato": "squassare",
    "squassava": "squassare",
    "squassavamo": "squassare",
    "squassavan": "squassare",
    "squassavano": "squassare",
    "squassavate": "squassare",
    "squassavi": "squassare",
    "squassavo": "squassare",
    "squasserai": "squassare",
    "squasseran": "squassare",
    "squasseranno": "squassare",
    "squasserebbe": "squassare",
    "squasserebber": "squassare",
    "squasserebbero": "squassare",
    "squasserei": "squassare",
    "squasseremmo": "squassare",
    "squasseremo": "squassare",
    "squassereste": "squassare",
    "squasseresti": "squassare",
    "squasserete": "squassare",
    "squasserà": "squassare",
    "squasserò": "squassare",
    "squassi": "squassare",
    "squassiamo": "squassare",
    "squassiate": "squassare",
    "squassin": "squassare",
    "squassino": "squassare",
    "squasso": "squassare",
    "squassò": "squassare",
    "squatters": "squatter",
    "squattrinata": "squattrinato",
    "squattrinate": "squattrinato",
    "squattrinati": "squattrinato",
    "squilibra": "squilibrare",
    "squilibrai": "squilibrare",
    "squilibrammo": "squilibrare",
    "squilibran": "squilibrare",
    "squilibrando": "squilibrare",
    "squilibrano": "squilibrare",
    "squilibrante": "squilibrare",
    "squilibranti": "squilibrare",
    "squilibrar": "squilibrare",
    "squilibraron": "squilibrare",
    "squilibrarono": "squilibrare",
    "squilibrasse": "squilibrare",
    "squilibrasser": "squilibrare",
    "squilibrassero": "squilibrare",
    "squilibrassi": "squilibrare",
    "squilibrassimo": "squilibrare",
    "squilibraste": "squilibrare",
    "squilibrasti": "squilibrare",
    "squilibrata": "squilibrato",
    "squilibrate": "squilibrato",
    "squilibrati": "squilibrato",
    "squilibrato": "squilibrare",
    "squilibrava": "squilibrare",
    "squilibravamo": "squilibrare",
    "squilibravan": "squilibrare",
    "squilibravano": "squilibrare",
    "squilibravate": "squilibrare",
    "squilibravi": "squilibrare",
    "squilibravo": "squilibrare",
    "squilibrerai": "squilibrare",
    "squilibreran": "squilibrare",
    "squilibreranno": "squilibrare",
    "squilibrerebbe": "squilibrare",
    "squilibrerebber": "squilibrare",
    "squilibrerebbero": "squilibrare",
    "squilibrerei": "squilibrare",
    "squilibreremmo": "squilibrare",
    "squilibreremo": "squilibrare",
    "squilibrereste": "squilibrare",
    "squilibreresti": "squilibrare",
    "squilibrerete": "squilibrare",
    "squilibrerà": "squilibrare",
    "squilibrerò": "squilibrare",
    "squilibri": "squilibrio",
    "squilibriamo": "squilibrare",
    "squilibriate": "squilibrare",
    "squilibrin": "squilibrare",
    "squilibrino": "squilibrare",
    "squilibro": "squilibrare",
    "squilibrò": "squilibrare",
    "squilla": "squillo",
    "squillai": "squillare",
    "squillammo": "squillare",
    "squillan": "squillare",
    "squillando": "squillare",
    "squillano": "squillare",
    "squillante": "squillare",
    "squillanti": "squillare",
    "squillar": "squillare",
    "squillaron": "squillare",
    "squillarono": "squillare",
    "squillasse": "squillare",
    "squillasser": "squillare",
    "squillassero": "squillare",
    "squillassi": "squillare",
    "squillassimo": "squillare",
    "squillaste": "squillare",
    "squillasti": "squillare",
    "squillata": "squillare",
    "squillate": "squillare",
    "squillati": "squillare",
    "squillato": "squillare",
    "squillava": "squillare",
    "squillavamo": "squillare",
    "squillavan": "squillare",
    "squillavano": "squillare",
    "squillavate": "squillare",
    "squillavi": "squillare",
    "squillavo": "squillare",
    "squille": "squillo",
    "squillerai": "squillare",
    "squilleran": "squillare",
    "squilleranno": "squillare",
    "squillerebbe": "squillare",
    "squillerebber": "squillare",
    "squillerebbero": "squillare",
    "squillerei": "squillare",
    "squilleremmo": "squillare",
    "squilleremo": "squillare",
    "squillereste": "squillare",
    "squilleresti": "squillare",
    "squillerete": "squillare",
    "squillerà": "squillare",
    "squillerò": "squillare",
    "squilli": "squillo",
    "squilliamo": "squillare",
    "squilliate": "squillare",
    "squillin": "squillare",
    "squillino": "squillare",
    "squillo": "squillare",
    "squillò": "squillare",
    "squinterna": "squinternare",
    "squinternai": "squinternare",
    "squinternammo": "squinternare",
    "squinternan": "squinternare",
    "squinternando": "squinternare",
    "squinternano": "squinternare",
    "squinternante": "squinternare",
    "squinternanti": "squinternare",
    "squinternar": "squinternare",
    "squinternaron": "squinternare",
    "squinternarono": "squinternare",
    "squinternasse": "squinternare",
    "squinternasser": "squinternare",
    "squinternassero": "squinternare",
    "squinternassi": "squinternare",
    "squinternassimo": "squinternare",
    "squinternaste": "squinternare",
    "squinternasti": "squinternare",
    "squinternata": "squinternato",
    "squinternate": "squinternato",
    "squinternati": "squinternato",
    "squinternato": "squinternare",
    "squinternava": "squinternare",
    "squinternavamo": "squinternare",
    "squinternavan": "squinternare",
    "squinternavano": "squinternare",
    "squinternavate": "squinternare",
    "squinternavi": "squinternare",
    "squinternavo": "squinternare",
    "squinternerai": "squinternare",
    "squinterneran": "squinternare",
    "squinterneranno": "squinternare",
    "squinternerebbe": "squinternare",
    "squinternerebber": "squinternare",
    "squinternerebbero": "squinternare",
    "squinternerei": "squinternare",
    "squinterneremmo": "squinternare",
    "squinterneremo": "squinternare",
    "squinternereste": "squinternare",
    "squinterneresti": "squinternare",
    "squinternerete": "squinternare",
    "squinternerà": "squinternare",
    "squinternerò": "squinternare",
    "squinterni": "squinternare",
    "squinterniamo": "squinternare",
    "squinterniate": "squinternare",
    "squinternin": "squinternare",
    "squinternino": "squinternare",
    "squinterno": "squinternare",
    "squinternò": "squinternare",
    "squisita": "squisito",
    "squisite": "squisito",
    "squisitezze": "squisitezza",
    "squisiti": "squisito",
    "squittendo": "squittire",
    "squittente": "squittire",
    "squittenti": "squittire",
    "squittiamo": "squittire",
    "squittiate": "squittire",
    "squittii": "squittire",
    "squittimmo": "squittire",
    "squittir": "squittire",
    "squittirai": "squittire",
    "squittiran": "squittire",
    "squittiranno": "squittire",
    "squittirebbe": "squittire",
    "squittirebber": "squittire",
    "squittirebbero": "squittire",
    "squittirei": "squittire",
    "squittiremmo": "squittire",
    "squittiremo": "squittire",
    "squittireste": "squittire",
    "squittiresti": "squittire",
    "squittirete": "squittire",
    "squittiron": "squittire",
    "squittirono": "squittire",
    "squittirà": "squittire",
    "squittirò": "squittire",
    "squittisca": "squittire",
    "squittiscan": "squittire",
    "squittiscano": "squittire",
    "squittisce": "squittire",
    "squittisci": "squittire",
    "squittisco": "squittire",
    "squittiscon": "squittire",
    "squittiscono": "squittire",
    "squittisse": "squittire",
    "squittisser": "squittire",
    "squittissero": "squittire",
    "squittissi": "squittire",
    "squittissimo": "squittire",
    "squittiste": "squittire",
    "squittisti": "squittire",
    "squittita": "squittire",
    "squittite": "squittire",
    "squittiti": "squittire",
    "squittito": "squittire",
    "squittiva": "squittire",
    "squittivamo": "squittire",
    "squittivan": "squittire",
    "squittivano": "squittire",
    "squittivate": "squittire",
    "squittivi": "squittire",
    "squittivo": "squittire",
    "squittì": "squittire",
    "sradica": "sradicare",
    "sradicai": "sradicare",
    "sradicamenti": "sradicamento",
    "sradicammo": "sradicare",
    "sradican": "sradicare",
    "sradicando": "sradicare",
    "sradicano": "sradicare",
    "sradicante": "sradicare",
    "sradicanti": "sradicare",
    "sradicar": "sradicare",
    "sradicaron": "sradicare",
    "sradicarono": "sradicare",
    "sradicasse": "sradicare",
    "sradicasser": "sradicare",
    "sradicassero": "sradicare",
    "sradicassi": "sradicare",
    "sradicassimo": "sradicare",
    "sradicaste": "sradicare",
    "sradicasti": "sradicare",
    "sradicata": "sradicato",
    "sradicate": "sradicato",
    "sradicati": "sradicato",
    "sradicato": "sradicare",
    "sradicava": "sradicare",
    "sradicavamo": "sradicare",
    "sradicavan": "sradicare",
    "sradicavano": "sradicare",
    "sradicavate": "sradicare",
    "sradicavi": "sradicare",
    "sradicavo": "sradicare",
    "sradicherai": "sradicare",
    "sradicheran": "sradicare",
    "sradicheranno": "sradicare",
    "sradicherebbe": "sradicare",
    "sradicherebber": "sradicare",
    "sradicherebbero": "sradicare",
    "sradicherei": "sradicare",
    "sradicheremmo": "sradicare",
    "sradicheremo": "sradicare",
    "sradichereste": "sradicare",
    "sradicheresti": "sradicare",
    "sradicherete": "sradicare",
    "sradicherà": "sradicare",
    "sradicherò": "sradicare",
    "sradichi": "sradicare",
    "sradichiamo": "sradicare",
    "sradichiate": "sradicare",
    "sradichin": "sradicare",
    "sradichino": "sradicare",
    "sradico": "sradicare",
    "sradicò": "sradicare",
    "sragiona": "sragionare",
    "sragionai": "sragionare",
    "sragionammo": "sragionare",
    "sragionan": "sragionare",
    "sragionando": "sragionare",
    "sragionano": "sragionare",
    "sragionante": "sragionare",
    "sragionanti": "sragionare",
    "sragionar": "sragionare",
    "sragionaron": "sragionare",
    "sragionarono": "sragionare",
    "sragionasse": "sragionare",
    "sragionasser": "sragionare",
    "sragionassero": "sragionare",
    "sragionassi": "sragionare",
    "sragionassimo": "sragionare",
    "sragionaste": "sragionare",
    "sragionasti": "sragionare",
    "sragionata": "sragionare",
    "sragionate": "sragionare",
    "sragionati": "sragionare",
    "sragionato": "sragionare",
    "sragionava": "sragionare",
    "sragionavamo": "sragionare",
    "sragionavan": "sragionare",
    "sragionavano": "sragionare",
    "sragionavate": "sragionare",
    "sragionavi": "sragionare",
    "sragionavo": "sragionare",
    "sragionerai": "sragionare",
    "sragioneran": "sragionare",
    "sragioneranno": "sragionare",
    "sragionerebbe": "sragionare",
    "sragionerebber": "sragionare",
    "sragionerebbero": "sragionare",
    "sragionerei": "sragionare",
    "sragioneremmo": "sragionare",
    "sragioneremo": "sragionare",
    "sragionereste": "sragionare",
    "sragioneresti": "sragionare",
    "sragionerete": "sragionare",
    "sragionerà": "sragionare",
    "sragionerò": "sragionare",
    "sragioni": "sragionare",
    "sragioniamo": "sragionare",
    "sragioniate": "sragionare",
    "sragionin": "sragionare",
    "sragionino": "sragionare",
    "sragiono": "sragionare",
    "sragionò": "sragionare",
    "sregola": "sregolare",
    "sregolai": "sregolare",
    "sregolammo": "sregolare",
    "sregolan": "sregolare",
    "sregolando": "sregolare",
    "sregolano": "sregolare",
    "sregolante": "sregolare",
    "sregolanti": "sregolare",
    "sregolar": "sregolare",
    "sregolaron": "sregolare",
    "sregolarono": "sregolare",
    "sregolasse": "sregolare",
    "sregolasser": "sregolare",
    "sregolassero": "sregolare",
    "sregolassi": "sregolare",
    "sregolassimo": "sregolare",
    "sregolaste": "sregolare",
    "sregolasti": "sregolare",
    "sregolata": "sregolato",
    "sregolate": "sregolato",
    "sregolatezze": "sregolatezza",
    "sregolati": "sregolato",
    "sregolato": "sregolare",
    "sregolava": "sregolare",
    "sregolavamo": "sregolare",
    "sregolavan": "sregolare",
    "sregolavano": "sregolare",
    "sregolavate": "sregolare",
    "sregolavi": "sregolare",
    "sregolavo": "sregolare",
    "sregolerai": "sregolare",
    "sregoleran": "sregolare",
    "sregoleranno": "sregolare",
    "sregolerebbe": "sregolare",
    "sregolerebber": "sregolare",
    "sregolerebbero": "sregolare",
    "sregolerei": "sregolare",
    "sregoleremmo": "sregolare",
    "sregoleremo": "sregolare",
    "sregolereste": "sregolare",
    "sregoleresti": "sregolare",
    "sregolerete": "sregolare",
    "sregolerà": "sregolare",
    "sregolerò": "sregolare",
    "sregoli": "sregolare",
    "sregoliamo": "sregolare",
    "sregoliate": "sregolare",
    "sregolin": "sregolare",
    "sregolino": "sregolare",
    "sregolo": "sregolare",
    "sregolò": "sregolare",
    "srotola": "srotolare",
    "srotolai": "srotolare",
    "srotolammo": "srotolare",
    "srotolan": "srotolare",
    "srotolando": "srotolare",
    "srotolano": "srotolare",
    "srotolante": "srotolare",
    "srotolanti": "srotolare",
    "srotolar": "srotolare",
    "srotolaron": "srotolare",
    "srotolarono": "srotolare",
    "srotolasse": "srotolare",
    "srotolasser": "srotolare",
    "srotolassero": "srotolare",
    "srotolassi": "srotolare",
    "srotolassimo": "srotolare",
    "srotolaste": "srotolare",
    "srotolasti": "srotolare",
    "srotolata": "srotolare",
    "srotolate": "srotolare",
    "srotolati": "srotolare",
    "srotolato": "srotolare",
    "srotolava": "srotolare",
    "srotolavamo": "srotolare",
    "srotolavan": "srotolare",
    "srotolavano": "srotolare",
    "srotolavate": "srotolare",
    "srotolavi": "srotolare",
    "srotolavo": "srotolare",
    "srotolerai": "srotolare",
    "srotoleran": "srotolare",
    "srotoleranno": "srotolare",
    "srotolerebbe": "srotolare",
    "srotolerebber": "srotolare",
    "srotolerebbero": "srotolare",
    "srotolerei": "srotolare",
    "srotoleremmo": "srotolare",
    "srotoleremo": "srotolare",
    "srotolereste": "srotolare",
    "srotoleresti": "srotolare",
    "srotolerete": "srotolare",
    "srotolerà": "srotolare",
    "srotolerò": "srotolare",
    "srotoli": "srotolare",
    "srotoliamo": "srotolare",
    "srotoliate": "srotolare",
    "srotolin": "srotolare",
    "srotolino": "srotolare",
    "srotolo": "srotolare",
    "srotolò": "srotolare",
    "sta": "stare",
    "sta'": "stare",
    "stabilendo": "stabilire",
    "stabilente": "stabilire",
    "stabilenti": "stabilire",
    "stabili": "stabile",
    "stabiliamo": "stabilire",
    "stabiliate": "stabilire",
    "stabilii": "stabilire",
    "stabilimenti": "stabilimento",
    "stabilimmo": "stabilire",
    "stabilir": "stabilire",
    "stabilirai": "stabilire",
    "stabiliran": "stabilire",
    "stabiliranno": "stabilire",
    "stabilirebbe": "stabilire",
    "stabilirebber": "stabilire",
    "stabilirebbero": "stabilire",
    "stabilirei": "stabilire",
    "stabiliremmo": "stabilire",
    "stabiliremo": "stabilire",
    "stabilireste": "stabilire",
    "stabiliresti": "stabilire",
    "stabilirete": "stabilire",
    "stabiliron": "stabilire",
    "stabilirono": "stabilire",
    "stabilirà": "stabilire",
    "stabilirò": "stabilire",
    "stabilisca": "stabilire",
    "stabiliscan": "stabilire",
    "stabiliscano": "stabilire",
    "stabilisce": "stabilire",
    "stabilisci": "stabilire",
    "stabilisco": "stabilire",
    "stabiliscon": "stabilire",
    "stabiliscono": "stabilire",
    "stabilisse": "stabilire",
    "stabilisser": "stabilire",
    "stabilissero": "stabilire",
    "stabilissi": "stabilire",
    "stabilissimo": "stabilire",
    "stabiliste": "stabilire",
    "stabilisti": "stabilire",
    "stabilita": "stabilito",
    "stabilite": "stabilito",
    "stabiliti": "stabilito",
    "stabilito": "stabilire",
    "stabiliva": "stabilire",
    "stabilivamo": "stabilire",
    "stabilivan": "stabilire",
    "stabilivano": "stabilire",
    "stabilivate": "stabilire",
    "stabilivi": "stabilire",
    "stabilivo": "stabilire",
    "stabilizza": "stabilizzare",
    "stabilizzai": "stabilizzare",
    "stabilizzammo": "stabilizzare",
    "stabilizzan": "stabilizzare",
    "stabilizzando": "stabilizzare",
    "stabilizzano": "stabilizzare",
    "stabilizzante": "stabilizzare",
    "stabilizzanti": "stabilizzare",
    "stabilizzar": "stabilizzare",
    "stabilizzaron": "stabilizzare",
    "stabilizzarono": "stabilizzare",
    "stabilizzasse": "stabilizzare",
    "stabilizzasser": "stabilizzare",
    "stabilizzassero": "stabilizzare",
    "stabilizzassi": "stabilizzare",
    "stabilizzassimo": "stabilizzare",
    "stabilizzaste": "stabilizzare",
    "stabilizzasti": "stabilizzare",
    "stabilizzata": "stabilizzare",
    "stabilizzate": "stabilizzare",
    "stabilizzati": "stabilizzare",
    "stabilizzato": "stabilizzare",
    "stabilizzatori": "stabilizzatore",
    "stabilizzatrice": "stabilizzatore",
    "stabilizzatrici": "stabilizzatore",
    "stabilizzava": "stabilizzare",
    "stabilizzavamo": "stabilizzare",
    "stabilizzavan": "stabilizzare",
    "stabilizzavano": "stabilizzare",
    "stabilizzavate": "stabilizzare",
    "stabilizzavi": "stabilizzare",
    "stabilizzavo": "stabilizzare",
    "stabilizzazioni": "stabilizzazione",
    "stabilizzerai": "stabilizzare",
    "stabilizzeran": "stabilizzare",
    "stabilizzeranno": "stabilizzare",
    "stabilizzerebbe": "stabilizzare",
    "stabilizzerebber": "stabilizzare",
    "stabilizzerebbero": "stabilizzare",
    "stabilizzerei": "stabilizzare",
    "stabilizzeremmo": "stabilizzare",
    "stabilizzeremo": "stabilizzare",
    "stabilizzereste": "stabilizzare",
    "stabilizzeresti": "stabilizzare",
    "stabilizzerete": "stabilizzare",
    "stabilizzerà": "stabilizzare",
    "stabilizzerò": "stabilizzare",
    "stabilizzi": "stabilizzare",
    "stabilizziamo": "stabilizzare",
    "stabilizziate": "stabilizzare",
    "stabilizzin": "stabilizzare",
    "stabilizzino": "stabilizzare",
    "stabilizzo": "stabilizzare",
    "stabilizzò": "stabilizzare",
    "stabilì": "stabilire",
    "stacca": "staccare",
    "staccabili": "staccabile",
    "staccai": "staccare",
    "staccammo": "staccare",
    "staccan": "staccare",
    "staccando": "staccare",
    "staccano": "staccare",
    "staccante": "staccare",
    "staccanti": "staccare",
    "staccar": "staccare",
    "staccaron": "staccare",
    "staccarono": "staccare",
    "staccasse": "staccare",
    "staccasser": "staccare",
    "staccassero": "staccare",
    "staccassi": "staccare",
    "staccassimo": "staccare",
    "staccaste": "staccare",
    "staccasti": "staccare",
    "staccata": "staccato",
    "staccate": "staccato",
    "staccati": "staccato",
    "staccato": "staccare",
    "staccava": "staccare",
    "staccavamo": "staccare",
    "staccavan": "staccare",
    "staccavano": "staccare",
    "staccavate": "staccare",
    "staccavi": "staccare",
    "staccavo": "staccare",
    "staccerai": "stacciare",
    "stacceran": "stacciare",
    "stacceranno": "stacciare",
    "staccerebbe": "stacciare",
    "staccerebber": "stacciare",
    "staccerebbero": "stacciare",
    "staccerei": "stacciare",
    "stacceremmo": "stacciare",
    "stacceremo": "stacciare",
    "staccereste": "stacciare",
    "stacceresti": "stacciare",
    "staccerete": "stacciare",
    "staccerà": "stacciare",
    "staccerò": "stacciare",
    "staccherai": "staccare",
    "staccheran": "staccare",
    "staccheranno": "staccare",
    "staccherebbe": "staccare",
    "staccherebber": "staccare",
    "staccherebbero": "staccare",
    "staccherei": "staccare",
    "staccheremmo": "staccare",
    "staccheremo": "staccare",
    "stacchereste": "staccare",
    "staccheresti": "staccare",
    "staccherete": "staccare",
    "staccherà": "staccare",
    "staccherò": "staccare",
    "stacchi": "stacco",
    "stacchiamo": "staccare",
    "stacchiate": "staccare",
    "stacchin": "staccare",
    "stacchino": "staccare",
    "stacci": "stacciare",
    "staccia": "stacciare",
    "stacciai": "stacciare",
    "stacciammo": "stacciare",
    "stacciamo": "stacciare",
    "staccian": "stacciare",
    "stacciando": "stacciare",
    "stacciano": "stacciare",
    "stacciante": "stacciare",
    "staccianti": "stacciare",
    "stacciar": "stacciare",
    "stacciaron": "stacciare",
    "stacciarono": "stacciare",
    "stacciasse": "stacciare",
    "stacciasser": "stacciare",
    "stacciassero": "stacciare",
    "stacciassi": "stacciare",
    "stacciassimo": "stacciare",
    "stacciaste": "stacciare",
    "stacciasti": "stacciare",
    "stacciata": "stacciare",
    "stacciate": "stacciare",
    "stacciati": "stacciare",
    "stacciato": "stacciare",
    "stacciava": "stacciare",
    "stacciavamo": "stacciare",
    "stacciavan": "stacciare",
    "stacciavano": "stacciare",
    "stacciavate": "stacciare",
    "stacciavi": "stacciare",
    "stacciavo": "stacciare",
    "staccin": "stacciare",
    "staccino": "stacciare",
    "staccio": "stacciare",
    "staccionate": "staccionata",
    "stacciò": "stacciare",
    "stacco": "staccare",
    "staccò": "staccare",
    "stadi": "stadio",
    "staffette": "staffetta",
    "staffila": "staffilare",
    "staffilai": "staffilare",
    "staffilammo": "staffilare",
    "staffilan": "staffilare",
    "staffilando": "staffilare",
    "staffilano": "staffilare",
    "staffilante": "staffilare",
    "staffilanti": "staffilare",
    "staffilar": "staffilare",
    "staffilaron": "staffilare",
    "staffilarono": "staffilare",
    "staffilasse": "staffilare",
    "staffilasser": "staffilare",
    "staffilassero": "staffilare",
    "staffilassi": "staffilare",
    "staffilassimo": "staffilare",
    "staffilaste": "staffilare",
    "staffilasti": "staffilare",
    "staffilata": "staffilare",
    "staffilate": "staffilata",
    "staffilati": "staffilare",
    "staffilato": "staffilare",
    "staffilava": "staffilare",
    "staffilavamo": "staffilare",
    "staffilavan": "staffilare",
    "staffilavano": "staffilare",
    "staffilavate": "staffilare",
    "staffilavi": "staffilare",
    "staffilavo": "staffilare",
    "staffilerai": "staffilare",
    "staffileran": "staffilare",
    "staffileranno": "staffilare",
    "staffilerebbe": "staffilare",
    "staffilerebber": "staffilare",
    "staffilerebbero": "staffilare",
    "staffilerei": "staffilare",
    "staffileremmo": "staffilare",
    "staffileremo": "staffilare",
    "staffilereste": "staffilare",
    "staffileresti": "staffilare",
    "staffilerete": "staffilare",
    "staffilerà": "staffilare",
    "staffilerò": "staffilare",
    "staffili": "staffilare",
    "staffiliamo": "staffilare",
    "staffiliate": "staffilare",
    "staffilin": "staffilare",
    "staffilino": "staffilare",
    "staffilo": "staffilare",
    "staffilò": "staffilare",
    "stages": "stage",
    "stagiona": "stagionare",
    "stagionai": "stagionare",
    "stagionali": "stagionale",
    "stagionammo": "stagionare",
    "stagionan": "stagionare",
    "stagionando": "stagionare",
    "stagionano": "stagionare",
    "stagionante": "stagionare",
    "stagionanti": "stagionare",
    "stagionar": "stagionare",
    "stagionaron": "stagionare",
    "stagionarono": "stagionare",
    "stagionasse": "stagionare",
    "stagionasser": "stagionare",
    "stagionassero": "stagionare",
    "stagionassi": "stagionare",
    "stagionassimo": "stagionare",
    "stagionaste": "stagionare",
    "stagionasti": "stagionare",
    "stagionata": "stagionato",
    "stagionate": "stagionato",
    "stagionati": "stagionato",
    "stagionato": "stagionare",
    "stagionava": "stagionare",
    "stagionavamo": "stagionare",
    "stagionavan": "stagionare",
    "stagionavano": "stagionare",
    "stagionavate": "stagionare",
    "stagionavi": "stagionare",
    "stagionavo": "stagionare",
    "stagionerai": "stagionare",
    "stagioneran": "stagionare",
    "stagioneranno": "stagionare",
    "stagionerebbe": "stagionare",
    "stagionerebber": "stagionare",
    "stagionerebbero": "stagionare",
    "stagionerei": "stagionare",
    "stagioneremmo": "stagionare",
    "stagioneremo": "stagionare",
    "stagionereste": "stagionare",
    "stagioneresti": "stagionare",
    "stagionerete": "stagionare",
    "stagionerà": "stagionare",
    "stagionerò": "stagionare",
    "stagioni": "stagione",
    "stagioniamo": "stagionare",
    "stagioniate": "stagionare",
    "stagionin": "stagionare",
    "stagionino": "stagionare",
    "stagiono": "stagionare",
    "stagionò": "stagionare",
    "stagiste": "stagista",
    "stagli": "stagliare",
    "staglia": "stagliare",
    "stagliai": "stagliare",
    "stagliammo": "stagliare",
    "stagliamo": "stagliare",
    "staglian": "stagliare",
    "stagliando": "stagliare",
    "stagliano": "stagliare",
    "stagliante": "stagliare",
    "staglianti": "stagliare",
    "stagliar": "stagliare",
    "stagliaron": "stagliare",
    "stagliarono": "stagliare",
    "stagliasse": "stagliare",
    "stagliasser": "stagliare",
    "stagliassero": "stagliare",
    "stagliassi": "stagliare",
    "stagliassimo": "stagliare",
    "stagliaste": "stagliare",
    "stagliasti": "stagliare",
    "stagliata": "stagliare",
    "stagliate": "stagliare",
    "stagliati": "stagliare",
    "stagliato": "stagliare",
    "stagliava": "stagliare",
    "stagliavamo": "stagliare",
    "stagliavan": "stagliare",
    "stagliavano": "stagliare",
    "stagliavate": "stagliare",
    "stagliavi": "stagliare",
    "stagliavo": "stagliare",
    "staglierai": "stagliare",
    "staglieran": "stagliare",
    "staglieranno": "stagliare",
    "staglierebbe": "stagliare",
    "staglierebber": "stagliare",
    "staglierebbero": "stagliare",
    "staglierei": "stagliare",
    "staglieremmo": "stagliare",
    "staglieremo": "stagliare",
    "stagliereste": "stagliare",
    "staglieresti": "stagliare",
    "staglierete": "stagliare",
    "staglierà": "stagliare",
    "staglierò": "stagliare",
    "staglin": "stagliare",
    "staglino": "stagliare",
    "staglio": "stagliare",
    "stagliò": "stagliare",
    "stagna": "stagno",
    "stagnai": "stagnare",
    "stagnammo": "stagnare",
    "stagnan": "stagnare",
    "stagnando": "stagnare",
    "stagnano": "stagnare",
    "stagnante": "stagnare",
    "stagnanti": "stagnare",
    "stagnar": "stagnare",
    "stagnaron": "stagnare",
    "stagnarono": "stagnare",
    "stagnasse": "stagnare",
    "stagnasser": "stagnare",
    "stagnassero": "stagnare",
    "stagnassi": "stagnare",
    "stagnassimo": "stagnare",
    "stagnaste": "stagnare",
    "stagnasti": "stagnare",
    "stagnata": "stagnare",
    "stagnate": "stagnare",
    "stagnati": "stagnare",
    "stagnato": "stagnare",
    "stagnava": "stagnare",
    "stagnavamo": "stagnare",
    "stagnavan": "stagnare",
    "stagnavano": "stagnare",
    "stagnavate": "stagnare",
    "stagnavi": "stagnare",
    "stagnavo": "stagnare",
    "stagnazioni": "stagnazione",
    "stagne": "stagno",
    "stagnerai": "stagnare",
    "stagneran": "stagnare",
    "stagneranno": "stagnare",
    "stagnerebbe": "stagnare",
    "stagnerebber": "stagnare",
    "stagnerebbero": "stagnare",
    "stagnerei": "stagnare",
    "stagneremmo": "stagnare",
    "stagneremo": "stagnare",
    "stagnereste": "stagnare",
    "stagneresti": "stagnare",
    "stagnerete": "stagnare",
    "stagnerà": "stagnare",
    "stagnerò": "stagnare",
    "stagni": "stagno",
    "stagniamo": "stagnare",
    "stagniate": "stagnare",
    "stagnin": "stagnare",
    "stagnino": "stagnare",
    "stagno": "stagnare",
    "stagnola": "stagnolo",
    "stagnole": "stagnolo",
    "stagnoli": "stagnolo",
    "stagnò": "stagnare",
    "stai": "stare",
    "stakanovisti": "stakanovista",
    "stalattiti": "stalattite",
    "staliniana": "staliniano",
    "staliniane": "staliniano",
    "staliniani": "staliniano",
    "stalinismi": "stalinismo",
    "staliniste": "stalinista",
    "stalinisti": "stalinista",
    "stalle": "stalla",
    "stalli": "stallo",
    "stallieri": "stalliere",
    "stalloni": "stallone",
    "stambecchi": "stambecco",
    "stamberghe": "stamberga",
    "stambura": "stamburare",
    "stamburai": "stamburare",
    "stamburammo": "stamburare",
    "stamburan": "stamburare",
    "stamburando": "stamburare",
    "stamburano": "stamburare",
    "stamburante": "stamburare",
    "stamburanti": "stamburare",
    "stamburar": "stamburare",
    "stamburaron": "stamburare",
    "stamburarono": "stamburare",
    "stamburasse": "stamburare",
    "stamburasser": "stamburare",
    "stamburassero": "stamburare",
    "stamburassi": "stamburare",
    "stamburassimo": "stamburare",
    "stamburaste": "stamburare",
    "stamburasti": "stamburare",
    "stamburata": "stamburare",
    "stamburate": "stamburare",
    "stamburati": "stamburare",
    "stamburato": "stamburare",
    "stamburava": "stamburare",
    "stamburavamo": "stamburare",
    "stamburavan": "stamburare",
    "stamburavano": "stamburare",
    "stamburavate": "stamburare",
    "stamburavi": "stamburare",
    "stamburavo": "stamburare",
    "stamburerai": "stamburare",
    "stambureran": "stamburare",
    "stambureranno": "stamburare",
    "stamburerebbe": "stamburare",
    "stamburerebber": "stamburare",
    "stamburerebbero": "stamburare",
    "stamburerei": "stamburare",
    "stambureremmo": "stamburare",
    "stambureremo": "stamburare",
    "stamburereste": "stamburare",
    "stambureresti": "stamburare",
    "stamburerete": "stamburare",
    "stamburerà": "stamburare",
    "stamburerò": "stamburare",
    "stamburi": "stamburare",
    "stamburiamo": "stamburare",
    "stamburiate": "stamburare",
    "stamburin": "stamburare",
    "stamburino": "stamburare",
    "stamburo": "stamburare",
    "stamburò": "stamburare",
    "stammo": "stare",
    "stampa": "stampare",
    "stampai": "stampare",
    "stampammo": "stampare",
    "stampan": "stampare",
    "stampando": "stampare",
    "stampano": "stampare",
    "stampante": "stampare",
    "stampanti": "stampare",
    "stampar": "stampare",
    "stamparon": "stampare",
    "stamparono": "stampare",
    "stampasse": "stampare",
    "stampasser": "stampare",
    "stampassero": "stampare",
    "stampassi": "stampare",
    "stampassimo": "stampare",
    "stampaste": "stampare",
    "stampasti": "stampare",
    "stampata": "stampato",
    "stampate": "stampato",
    "stampati": "stampato",
    "stampato": "stampare",
    "stampatori": "stampatore",
    "stampava": "stampare",
    "stampavamo": "stampare",
    "stampavan": "stampare",
    "stampavano": "stampare",
    "stampavate": "stampare",
    "stampavi": "stampare",
    "stampavo": "stampare",
    "stampe": "stampa",
    "stampelle": "stampella",
    "stamperai": "stampare",
    "stamperan": "stampare",
    "stamperanno": "stampare",
    "stamperebbe": "stampare",
    "stamperebber": "stampare",
    "stamperebbero": "stampare",
    "stamperei": "stampare",
    "stamperemmo": "stampare",
    "stamperemo": "stampare",
    "stampereste": "stampare",
    "stamperesti": "stampare",
    "stamperete": "stampare",
    "stamperie": "stamperia",
    "stamperà": "stampare",
    "stamperò": "stampare",
    "stampi": "stampo",
    "stampiamo": "stampare",
    "stampiate": "stampare",
    "stampigli": "stampigliare",
    "stampiglia": "stampigliare",
    "stampigliai": "stampigliare",
    "stampigliammo": "stampigliare",
    "stampigliamo": "stampigliare",
    "stampiglian": "stampigliare",
    "stampigliando": "stampigliare",
    "stampigliano": "stampigliare",
    "stampigliante": "stampigliare",
    "stampiglianti": "stampigliare",
    "stampigliar": "stampigliare",
    "stampigliaron": "stampigliare",
    "stampigliarono": "stampigliare",
    "stampigliasse": "stampigliare",
    "stampigliasser": "stampigliare",
    "stampigliassero": "stampigliare",
    "stampigliassi": "stampigliare",
    "stampigliassimo": "stampigliare",
    "stampigliaste": "stampigliare",
    "stampigliasti": "stampigliare",
    "stampigliata": "stampigliare",
    "stampigliate": "stampigliare",
    "stampigliati": "stampigliare",
    "stampigliato": "stampigliare",
    "stampigliava": "stampigliare",
    "stampigliavamo": "stampigliare",
    "stampigliavan": "stampigliare",
    "stampigliavano": "stampigliare",
    "stampigliavate": "stampigliare",
    "stampigliavi": "stampigliare",
    "stampigliavo": "stampigliare",
    "stampiglierai": "stampigliare",
    "stampiglieran": "stampigliare",
    "stampiglieranno": "stampigliare",
    "stampiglierebbe": "stampigliare",
    "stampiglierebber": "stampigliare",
    "stampiglierebbero": "stampigliare",
    "stampiglierei": "stampigliare",
    "stampiglieremmo": "stampigliare",
    "stampiglieremo": "stampigliare",
    "stampigliereste": "stampigliare",
    "stampiglieresti": "stampigliare",
    "stampiglierete": "stampigliare",
    "stampiglierà": "stampigliare",
    "stampiglierò": "stampigliare",
    "stampiglin": "stampigliare",
    "stampiglino": "stampigliare",
    "stampiglio": "stampigliare",
    "stampigliò": "stampigliare",
    "stampin": "stampare",
    "stampino": "stampare",
    "stampo": "stampare",
    "stampò": "stampare",
    "stan": "stare",
    "stana": "stanare",
    "stanai": "stanare",
    "stanammo": "stanare",
    "stanan": "stanare",
    "stanando": "stanare",
    "stanano": "stanare",
    "stanante": "stanare",
    "stananti": "stanare",
    "stanar": "stanare",
    "stanaron": "stanare",
    "stanarono": "stanare",
    "stanasse": "stanare",
    "stanasser": "stanare",
    "stanassero": "stanare",
    "stanassi": "stanare",
    "stanassimo": "stanare",
    "stanaste": "stanare",
    "stanasti": "stanare",
    "stanata": "stanare",
    "stanate": "stanare",
    "stanati": "stanare",
    "stanato": "stanare",
    "stanava": "stanare",
    "stanavamo": "stanare",
    "stanavan": "stanare",
    "stanavano": "stanare",
    "stanavate": "stanare",
    "stanavi": "stanare",
    "stanavo": "stanare",
    "stanca": "stanco",
    "stancai": "stancare",
    "stancammo": "stancare",
    "stancan": "stancare",
    "stancando": "stancare",
    "stancano": "stancare",
    "stancante": "stancare",
    "stancanti": "stancare",
    "stancar": "stancare",
    "stancaron": "stancare",
    "stancarono": "stancare",
    "stancasse": "stancare",
    "stancasser": "stancare",
    "stancassero": "stancare",
    "stancassi": "stancare",
    "stancassimo": "stancare",
    "stancaste": "stancare",
    "stancasti": "stancare",
    "stancata": "stancare",
    "stancate": "stancare",
    "stancati": "stancare",
    "stancato": "stancare",
    "stancava": "stancare",
    "stancavamo": "stancare",
    "stancavan": "stancare",
    "stancavano": "stancare",
    "stancavate": "stancare",
    "stancavi": "stancare",
    "stancavo": "stancare",
    "stanche": "stanco",
    "stancherai": "stancare",
    "stancheran": "stancare",
    "stancheranno": "stancare",
    "stancherebbe": "stancare",
    "stancherebber": "stancare",
    "stancherebbero": "stancare",
    "stancherei": "stancare",
    "stancheremmo": "stancare",
    "stancheremo": "stancare",
    "stanchereste": "stancare",
    "stancheresti": "stancare",
    "stancherete": "stancare",
    "stancherà": "stancare",
    "stancherò": "stancare",
    "stanchezze": "stanchezza",
    "stanchi": "stanco",
    "stanchiamo": "stancare",
    "stanchiate": "stancare",
    "stanchin": "stancare",
    "stanchino": "stancare",
    "stanco": "stancare",
    "stancò": "stancare",
    "standardizza": "standardizzare",
    "standardizzai": "standardizzare",
    "standardizzammo": "standardizzare",
    "standardizzan": "standardizzare",
    "standardizzando": "standardizzare",
    "standardizzano": "standardizzare",
    "standardizzante": "standardizzare",
    "standardizzanti": "standardizzare",
    "standardizzar": "standardizzare",
    "standardizzaron": "standardizzare",
    "standardizzarono": "standardizzare",
    "standardizzasse": "standardizzare",
    "standardizzasser": "standardizzare",
    "standardizzassero": "standardizzare",
    "standardizzassi": "standardizzare",
    "standardizzassimo": "standardizzare",
    "standardizzaste": "standardizzare",
    "standardizzasti": "standardizzare",
    "standardizzata": "standardizzare",
    "standardizzate": "standardizzare",
    "standardizzati": "standardizzare",
    "standardizzato": "standardizzare",
    "standardizzava": "standardizzare",
    "standardizzavamo": "standardizzare",
    "standardizzavan": "standardizzare",
    "standardizzavano": "standardizzare",
    "standardizzavate": "standardizzare",
    "standardizzavi": "standardizzare",
    "standardizzavo": "standardizzare",
    "standardizzazioni": "standardizzazione",
    "standardizzerai": "standardizzare",
    "standardizzeran": "standardizzare",
    "standardizzeranno": "standardizzare",
    "standardizzerebbe": "standardizzare",
    "standardizzerebber": "standardizzare",
    "standardizzerebbero": "standardizzare",
    "standardizzerei": "standardizzare",
    "standardizzeremmo": "standardizzare",
    "standardizzeremo": "standardizzare",
    "standardizzereste": "standardizzare",
    "standardizzeresti": "standardizzare",
    "standardizzerete": "standardizzare",
    "standardizzerà": "standardizzare",
    "standardizzerò": "standardizzare",
    "standardizzi": "standardizzare",
    "standardizziamo": "standardizzare",
    "standardizziate": "standardizzare",
    "standardizzin": "standardizzare",
    "standardizzino": "standardizzare",
    "standardizzo": "standardizzare",
    "standardizzò": "standardizzare",
    "standards": "standard",
    "stando": "stare",
    "stanerai": "stanare",
    "staneran": "stanare",
    "staneranno": "stanare",
    "stanerebbe": "stanare",
    "stanerebber": "stanare",
    "stanerebbero": "stanare",
    "stanerei": "stanare",
    "staneremmo": "stanare",
    "staneremo": "stanare",
    "stanereste": "stanare",
    "staneresti": "stanare",
    "stanerete": "stanare",
    "stanerà": "stanare",
    "stanerò": "stanare",
    "stanga": "stangare",
    "stangai": "stangare",
    "stangammo": "stangare",
    "stangan": "stangare",
    "stangando": "stangare",
    "stangano": "stangare",
    "stangante": "stangare",
    "stanganti": "stangare",
    "stangar": "stangare",
    "stangaron": "stangare",
    "stangarono": "stangare",
    "stangasse": "stangare",
    "stangasser": "stangare",
    "stangassero": "stangare",
    "stangassi": "stangare",
    "stangassimo": "stangare",
    "stangaste": "stangare",
    "stangasti": "stangare",
    "stangata": "stangare",
    "stangate": "stangata",
    "stangati": "stangare",
    "stangato": "stangare",
    "stangava": "stangare",
    "stangavamo": "stangare",
    "stangavan": "stangare",
    "stangavano": "stangare",
    "stangavate": "stangare",
    "stangavi": "stangare",
    "stangavo": "stangare",
    "stangherai": "stangare",
    "stangheran": "stangare",
    "stangheranno": "stangare",
    "stangherebbe": "stangare",
    "stangherebber": "stangare",
    "stangherebbero": "stangare",
    "stangherei": "stangare",
    "stangheremmo": "stangare",
    "stangheremo": "stangare",
    "stanghereste": "stangare",
    "stangheresti": "stangare",
    "stangherete": "stangare",
    "stangherà": "stangare",
    "stangherò": "stangare",
    "stanghi": "stangare",
    "stanghiamo": "stangare",
    "stanghiate": "stangare",
    "stanghin": "stangare",
    "stanghino": "stangare",
    "stango": "stangare",
    "stangone": "stangona",
    "stangò": "stangare",
    "stani": "stanare",
    "staniamo": "stanare",
    "staniate": "stanare",
    "stanin": "stanare",
    "stanino": "stanare",
    "stanno": "stare",
    "stano": "stanare",
    "stante": "stare",
    "stanti": "stare",
    "stantia": "stantio",
    "stantie": "stantio",
    "stantuffi": "stantuffo",
    "stanze": "stanza",
    "stanzette": "stanzetta",
    "stanzi": "stanziare",
    "stanzia": "stanziare",
    "stanziai": "stanziare",
    "stanziali": "stanziale",
    "stanziamenti": "stanziamento",
    "stanziammo": "stanziare",
    "stanziamo": "stanziare",
    "stanzian": "stanziare",
    "stanziando": "stanziare",
    "stanziano": "stanziare",
    "stanziante": "stanziare",
    "stanzianti": "stanziare",
    "stanziar": "stanziare",
    "stanziaron": "stanziare",
    "stanziarono": "stanziare",
    "stanziasse": "stanziare",
    "stanziasser": "stanziare",
    "stanziassero": "stanziare",
    "stanziassi": "stanziare",
    "stanziassimo": "stanziare",
    "stanziaste": "stanziare",
    "stanziasti": "stanziare",
    "stanziata": "stanziare",
    "stanziate": "stanziare",
    "stanziati": "stanziare",
    "stanziato": "stanziare",
    "stanziava": "stanziare",
    "stanziavamo": "stanziare",
    "stanziavan": "stanziare",
    "stanziavano": "stanziare",
    "stanziavate": "stanziare",
    "stanziavi": "stanziare",
    "stanziavo": "stanziare",
    "stanzierai": "stanziare",
    "stanzieran": "stanziare",
    "stanzieranno": "stanziare",
    "stanzierebbe": "stanziare",
    "stanzierebber": "stanziare",
    "stanzierebbero": "stanziare",
    "stanzierei": "stanziare",
    "stanzieremmo": "stanziare",
    "stanzieremo": "stanziare",
    "stanziereste": "stanziare",
    "stanzieresti": "stanziare",
    "stanzierete": "stanziare",
    "stanzierà": "stanziare",
    "stanzierò": "stanziare",
    "stanzin": "stanziare",
    "stanzini": "stanzino",
    "stanzino": "stanziare",
    "stanzio": "stanziare",
    "stanziò": "stanziare",
    "stanzoni": "stanzone",
    "stanò": "stanare",
    "stappa": "stappare",
    "stappai": "stappare",
    "stappammo": "stappare",
    "stappan": "stappare",
    "stappando": "stappare",
    "stappano": "stappare",
    "stappante": "stappare",
    "stappanti": "stappare",
    "stappar": "stappare",
    "stapparon": "stappare",
    "stapparono": "stappare",
    "stappasse": "stappare",
    "stappasser": "stappare",
    "stappassero": "stappare",
    "stappassi": "stappare",
    "stappassimo": "stappare",
    "stappaste": "stappare",
    "stappasti": "stappare",
    "stappata": "stappare",
    "stappate": "stappare",
    "stappati": "stappare",
    "stappato": "stappare",
    "stappava": "stappare",
    "stappavamo": "stappare",
    "stappavan": "stappare",
    "stappavano": "stappare",
    "stappavate": "stappare",
    "stappavi": "stappare",
    "stappavo": "stappare",
    "stapperai": "stappare",
    "stapperan": "stappare",
    "stapperanno": "stappare",
    "stapperebbe": "stappare",
    "stapperebber": "stappare",
    "stapperebbero": "stappare",
    "stapperei": "stappare",
    "stapperemmo": "stappare",
    "stapperemo": "stappare",
    "stappereste": "stappare",
    "stapperesti": "stappare",
    "stapperete": "stappare",
    "stapperà": "stappare",
    "stapperò": "stappare",
    "stappi": "stappare",
    "stappiamo": "stappare",
    "stappiate": "stappare",
    "stappin": "stappare",
    "stappino": "stappare",
    "stappo": "stappare",
    "stappò": "stappare",
    "star": "stare",
    "starai": "stare",
    "staran": "stare",
    "staranno": "stare",
    "starebbe": "stare",
    "starebber": "stare",
    "starebbero": "stare",
    "starei": "stare",
    "staremmo": "stare",
    "staremo": "stare",
    "stareste": "stare",
    "staresti": "stare",
    "starete": "stare",
    "starnazza": "starnazzare",
    "starnazzai": "starnazzare",
    "starnazzammo": "starnazzare",
    "starnazzan": "starnazzare",
    "starnazzando": "starnazzare",
    "starnazzano": "starnazzare",
    "starnazzante": "starnazzare",
    "starnazzanti": "starnazzare",
    "starnazzar": "starnazzare",
    "starnazzaron": "starnazzare",
    "starnazzarono": "starnazzare",
    "starnazzasse": "starnazzare",
    "starnazzasser": "starnazzare",
    "starnazzassero": "starnazzare",
    "starnazzassi": "starnazzare",
    "starnazzassimo": "starnazzare",
    "starnazzaste": "starnazzare",
    "starnazzasti": "starnazzare",
    "starnazzata": "starnazzare",
    "starnazzate": "starnazzare",
    "starnazzati": "starnazzare",
    "starnazzato": "starnazzare",
    "starnazzava": "starnazzare",
    "starnazzavamo": "starnazzare",
    "starnazzavan": "starnazzare",
    "starnazzavano": "starnazzare",
    "starnazzavate": "starnazzare",
    "starnazzavi": "starnazzare",
    "starnazzavo": "starnazzare",
    "starnazzerai": "starnazzare",
    "starnazzeran": "starnazzare",
    "starnazzeranno": "starnazzare",
    "starnazzerebbe": "starnazzare",
    "starnazzerebber": "starnazzare",
    "starnazzerebbero": "starnazzare",
    "starnazzerei": "starnazzare",
    "starnazzeremmo": "starnazzare",
    "starnazzeremo": "starnazzare",
    "starnazzereste": "starnazzare",
    "starnazzeresti": "starnazzare",
    "starnazzerete": "starnazzare",
    "starnazzerà": "starnazzare",
    "starnazzerò": "starnazzare",
    "starnazzi": "starnazzare",
    "starnazziamo": "starnazzare",
    "starnazziate": "starnazzare",
    "starnazzin": "starnazzare",
    "starnazzino": "starnazzare",
    "starnazzo": "starnazzare",
    "starnazzò": "starnazzare",
    "starnuta": "starnutare",
    "starnutai": "starnutare",
    "starnutammo": "starnutare",
    "starnutan": "starnutare",
    "starnutando": "starnutare",
    "starnutano": "starnutare",
    "starnutante": "starnutare",
    "starnutanti": "starnutare",
    "starnutar": "starnutare",
    "starnutaron": "starnutare",
    "starnutarono": "starnutare",
    "starnutasse": "starnutare",
    "starnutasser": "starnutare",
    "starnutassero": "starnutare",
    "starnutassi": "starnutare",
    "starnutassimo": "starnutare",
    "starnutaste": "starnutare",
    "starnutasti": "starnutare",
    "starnutata": "starnutare",
    "starnutate": "starnutare",
    "starnutati": "starnutare",
    "starnutato": "starnutare",
    "starnutava": "starnutare",
    "starnutavamo": "starnutare",
    "starnutavan": "starnutare",
    "starnutavano": "starnutare",
    "starnutavate": "starnutare",
    "starnutavi": "starnutare",
    "starnutavo": "starnutare",
    "starnutendo": "starnutire",
    "starnutente": "starnutire",
    "starnutenti": "starnutire",
    "starnuterai": "starnutare",
    "starnuteran": "starnutare",
    "starnuteranno": "starnutare",
    "starnuterebbe": "starnutare",
    "starnuterebber": "starnutare",
    "starnuterebbero": "starnutare",
    "starnuterei": "starnutare",
    "starnuteremmo": "starnutare",
    "starnuteremo": "starnutare",
    "starnutereste": "starnutare",
    "starnuteresti": "starnutare",
    "starnuterete": "starnutare",
    "starnuterà": "starnutare",
    "starnuterò": "starnutare",
    "starnuti": "starnuto",
    "starnutiamo": "starnutire",
    "starnutiate": "starnutire",
    "starnutii": "starnutire",
    "starnutimmo": "starnutire",
    "starnutin": "starnutare",
    "starnutino": "starnutare",
    "starnutir": "starnutire",
    "starnutirai": "starnutire",
    "starnutiran": "starnutire",
    "starnutiranno": "starnutire",
    "starnutirebbe": "starnutire",
    "starnutirebber": "starnutire",
    "starnutirebbero": "starnutire",
    "starnutirei": "starnutire",
    "starnutiremmo": "starnutire",
    "starnutiremo": "starnutire",
    "starnutireste": "starnutire",
    "starnutiresti": "starnutire",
    "starnutirete": "starnutire",
    "starnutiron": "starnutire",
    "starnutirono": "starnutire",
    "starnutirà": "starnutire",
    "starnutirò": "starnutire",
    "starnutisca": "starnutire",
    "starnutiscan": "starnutire",
    "starnutiscano": "starnutire",
    "starnutisce": "starnutire",
    "starnutisci": "starnutire",
    "starnutisco": "starnutire",
    "starnutiscon": "starnutire",
    "starnutiscono": "starnutire",
    "starnutisse": "starnutire",
    "starnutisser": "starnutire",
    "starnutissero": "starnutire",
    "starnutissi": "starnutire",
    "starnutissimo": "starnutire",
    "starnutiste": "starnutire",
    "starnutisti": "starnutire",
    "starnutita": "starnutire",
    "starnutite": "starnutire",
    "starnutiti": "starnutire",
    "starnutito": "starnutire",
    "starnutiva": "starnutire",
    "starnutivamo": "starnutire",
    "starnutivan": "starnutire",
    "starnutivano": "starnutire",
    "starnutivate": "starnutire",
    "starnutivi": "starnutire",
    "starnutivo": "starnutire",
    "starnuto": "starnutare",
    "starnutì": "starnutire",
    "starnutò": "starnutare",
    "staron": "stare",
    "starono": "stare",
    "starà": "stare",
    "starò": "stare",
    "stasa": "stasare",
    "stasai": "stasare",
    "stasammo": "stasare",
    "stasan": "stasare",
    "stasando": "stasare",
    "stasano": "stasare",
    "stasante": "stasare",
    "stasanti": "stasare",
    "stasar": "stasare",
    "stasaron": "stasare",
    "stasarono": "stasare",
    "stasasse": "stasare",
    "stasasser": "stasare",
    "stasassero": "stasare",
    "stasassi": "stasare",
    "stasassimo": "stasare",
    "stasaste": "stasare",
    "stasasti": "stasare",
    "stasata": "stasare",
    "stasate": "stasare",
    "stasati": "stasare",
    "stasato": "stasare",
    "stasava": "stasare",
    "stasavamo": "stasare",
    "stasavan": "stasare",
    "stasavano": "stasare",
    "stasavate": "stasare",
    "stasavi": "stasare",
    "stasavo": "stasare",
    "staserai": "stasare",
    "staseran": "stasare",
    "staseranno": "stasare",
    "staserebbe": "stasare",
    "staserebber": "stasare",
    "staserebbero": "stasare",
    "staserei": "stasare",
    "staseremmo": "stasare",
    "staseremo": "stasare",
    "stasereste": "stasare",
    "staseresti": "stasare",
    "staserete": "stasare",
    "staserà": "stasare",
    "staserò": "stasare",
    "stasi": "stasare",
    "stasiamo": "stasare",
    "stasiate": "stasare",
    "stasin": "stasare",
    "stasino": "stasare",
    "staso": "stasare",
    "staste": "stare",
    "stasò": "stasare",
    "stata": "stare",
    "statali": "statale",
    "statalismi": "statalismo",
    "statalisti": "statalista",
    "statalizza": "statalizzare",
    "statalizzai": "statalizzare",
    "statalizzammo": "statalizzare",
    "statalizzan": "statalizzare",
    "statalizzando": "statalizzare",
    "statalizzano": "statalizzare",
    "statalizzante": "statalizzare",
    "statalizzanti": "statalizzare",
    "statalizzar": "statalizzare",
    "statalizzaron": "statalizzare",
    "statalizzarono": "statalizzare",
    "statalizzasse": "statalizzare",
    "statalizzasser": "statalizzare",
    "statalizzassero": "statalizzare",
    "statalizzassi": "statalizzare",
    "statalizzassimo": "statalizzare",
    "statalizzaste": "statalizzare",
    "statalizzasti": "statalizzare",
    "statalizzata": "statalizzare",
    "statalizzate": "statalizzare",
    "statalizzati": "statalizzare",
    "statalizzato": "statalizzare",
    "statalizzava": "statalizzare",
    "statalizzavamo": "statalizzare",
    "statalizzavan": "statalizzare",
    "statalizzavano": "statalizzare",
    "statalizzavate": "statalizzare",
    "statalizzavi": "statalizzare",
    "statalizzavo": "statalizzare",
    "statalizzerai": "statalizzare",
    "statalizzeran": "statalizzare",
    "statalizzeranno": "statalizzare",
    "statalizzerebbe": "statalizzare",
    "statalizzerebber": "statalizzare",
    "statalizzerebbero": "statalizzare",
    "statalizzerei": "statalizzare",
    "statalizzeremmo": "statalizzare",
    "statalizzeremo": "statalizzare",
    "statalizzereste": "statalizzare",
    "statalizzeresti": "statalizzare",
    "statalizzerete": "statalizzare",
    "statalizzerà": "statalizzare",
    "statalizzerò": "statalizzare",
    "statalizzi": "statalizzare",
    "statalizziamo": "statalizzare",
    "statalizziate": "statalizzare",
    "statalizzin": "statalizzare",
    "statalizzino": "statalizzare",
    "statalizzo": "statalizzare",
    "statalizzò": "statalizzare",
    "state": "stare",
    "stategie": "stategia",
    "staterelli": "staterello",
    "stati": "stato",
    "statica": "statico",
    "statiche": "statico",
    "statici": "statico",
    "statisti": "statista",
    "statistica": "statistico",
    "statistiche": "statistico",
    "statistici": "statistico",
    "statizza": "statizzare",
    "statizzai": "statizzare",
    "statizzammo": "statizzare",
    "statizzan": "statizzare",
    "statizzando": "statizzare",
    "statizzano": "statizzare",
    "statizzante": "statizzare",
    "statizzanti": "statizzare",
    "statizzar": "statizzare",
    "statizzaron": "statizzare",
    "statizzarono": "statizzare",
    "statizzasse": "statizzare",
    "statizzasser": "statizzare",
    "statizzassero": "statizzare",
    "statizzassi": "statizzare",
    "statizzassimo": "statizzare",
    "statizzaste": "statizzare",
    "statizzasti": "statizzare",
    "statizzata": "statizzare",
    "statizzate": "statizzare",
    "statizzati": "statizzare",
    "statizzato": "statizzare",
    "statizzava": "statizzare",
    "statizzavamo": "statizzare",
    "statizzavan": "statizzare",
    "statizzavano": "statizzare",
    "statizzavate": "statizzare",
    "statizzavi": "statizzare",
    "statizzavo": "statizzare",
    "statizzerai": "statizzare",
    "statizzeran": "statizzare",
    "statizzeranno": "statizzare",
    "statizzerebbe": "statizzare",
    "statizzerebber": "statizzare",
    "statizzerebbero": "statizzare",
    "statizzerei": "statizzare",
    "statizzeremmo": "statizzare",
    "statizzeremo": "statizzare",
    "statizzereste": "statizzare",
    "statizzeresti": "statizzare",
    "statizzerete": "statizzare",
    "statizzerà": "statizzare",
    "statizzerò": "statizzare",
    "statizzi": "statizzare",
    "statizziamo": "statizzare",
    "statizziate": "statizzare",
    "statizzin": "statizzare",
    "statizzino": "statizzare",
    "statizzo": "statizzare",
    "statizzò": "statizzare",
    "stato": "stare",
    "statuali": "statuale",
    "statuari": "statuario",
    "statuaria": "statuario",
    "statuarie": "statuario",
    "statue": "statua",
    "statuendo": "statuire",
    "statuente": "statuire",
    "statuenti": "statuire",
    "statuette": "statuetta",
    "statuiamo": "statuire",
    "statuiate": "statuire",
    "statuii": "statuire",
    "statuimmo": "statuire",
    "statuine": "statuina",
    "statuir": "statuire",
    "statuirai": "statuire",
    "statuiran": "statuire",
    "statuiranno": "statuire",
    "statuirebbe": "statuire",
    "statuirebber": "statuire",
    "statuirebbero": "statuire",
    "statuirei": "statuire",
    "statuiremmo": "statuire",
    "statuiremo": "statuire",
    "statuireste": "statuire",
    "statuiresti": "statuire",
    "statuirete": "statuire",
    "statuiron": "statuire",
    "statuirono": "statuire",
    "statuirà": "statuire",
    "statuirò": "statuire",
    "statuisca": "statuire",
    "statuiscan": "statuire",
    "statuiscano": "statuire",
    "statuisce": "statuire",
    "statuisci": "statuire",
    "statuisco": "statuire",
    "statuiscon": "statuire",
    "statuiscono": "statuire",
    "statuisse": "statuire",
    "statuisser": "statuire",
    "statuissero": "statuire",
    "statuissi": "statuire",
    "statuissimo": "statuire",
    "statuiste": "statuire",
    "statuisti": "statuire",
    "statuita": "statuire",
    "statuite": "statuire",
    "statuiti": "statuire",
    "statuito": "statuire",
    "statuiva": "statuire",
    "statuivamo": "statuire",
    "statuivan": "statuire",
    "statuivano": "statuire",
    "statuivate": "statuire",
    "statuivi": "statuire",
    "statuivo": "statuire",
    "statunitensi": "statunitense",
    "stature": "statura",
    "statutari": "statutario",
    "statutaria": "statutario",
    "statutarie": "statutario",
    "statuti": "statuto",
    "statuì": "statuire",
    "stava": "stare",
    "stavamo": "stare",
    "stavan": "stare",
    "stavano": "stare",
    "stavate": "stare",
    "stavi": "stare",
    "stavo": "stare",
    "staziona": "stazionare",
    "stazionai": "stazionare",
    "stazionammo": "stazionare",
    "stazionan": "stazionare",
    "stazionando": "stazionare",
    "stazionano": "stazionare",
    "stazionante": "stazionare",
    "stazionanti": "stazionare",
    "stazionar": "stazionare",
    "stazionari": "stazionario",
    "stazionaria": "stazionario",
    "stazionarie": "stazionario",
    "stazionaron": "stazionare",
    "stazionarono": "stazionare",
    "stazionasse": "stazionare",
    "stazionasser": "stazionare",
    "stazionassero": "stazionare",
    "stazionassi": "stazionare",
    "stazionassimo": "stazionare",
    "stazionaste": "stazionare",
    "stazionasti": "stazionare",
    "stazionata": "stazionare",
    "stazionate": "stazionare",
    "stazionati": "stazionare",
    "stazionato": "stazionare",
    "stazionava": "stazionare",
    "stazionavamo": "stazionare",
    "stazionavan": "stazionare",
    "stazionavano": "stazionare",
    "stazionavate": "stazionare",
    "stazionavi": "stazionare",
    "stazionavo": "stazionare",
    "stazioncine": "stazioncina",
    "stazionerai": "stazionare",
    "stazioneran": "stazionare",
    "stazioneranno": "stazionare",
    "stazionerebbe": "stazionare",
    "stazionerebber": "stazionare",
    "stazionerebbero": "stazionare",
    "stazionerei": "stazionare",
    "stazioneremmo": "stazionare",
    "stazioneremo": "stazionare",
    "stazionereste": "stazionare",
    "stazioneresti": "stazionare",
    "stazionerete": "stazionare",
    "stazionerà": "stazionare",
    "stazionerò": "stazionare",
    "stazioni": "stazione",
    "stazioniamo": "stazionare",
    "stazioniate": "stazionare",
    "stazionin": "stazionare",
    "stazionino": "stazionare",
    "staziono": "stazionare",
    "stazionò": "stazionare",
    "stazza": "stazzare",
    "stazzai": "stazzare",
    "stazzammo": "stazzare",
    "stazzan": "stazzare",
    "stazzando": "stazzare",
    "stazzano": "stazzare",
    "stazzante": "stazzare",
    "stazzanti": "stazzare",
    "stazzar": "stazzare",
    "stazzaron": "stazzare",
    "stazzarono": "stazzare",
    "stazzasse": "stazzare",
    "stazzasser": "stazzare",
    "stazzassero": "stazzare",
    "stazzassi": "stazzare",
    "stazzassimo": "stazzare",
    "stazzaste": "stazzare",
    "stazzasti": "stazzare",
    "stazzata": "stazzare",
    "stazzate": "stazzare",
    "stazzati": "stazzare",
    "stazzato": "stazzare",
    "stazzava": "stazzare",
    "stazzavamo": "stazzare",
    "stazzavan": "stazzare",
    "stazzavano": "stazzare",
    "stazzavate": "stazzare",
    "stazzavi": "stazzare",
    "stazzavo": "stazzare",
    "stazze": "stazza",
    "stazzerai": "stazzare",
    "stazzeran": "stazzare",
    "stazzeranno": "stazzare",
    "stazzerebbe": "stazzare",
    "stazzerebber": "stazzare",
    "stazzerebbero": "stazzare",
    "stazzerei": "stazzare",
    "stazzeremmo": "stazzare",
    "stazzeremo": "stazzare",
    "stazzereste": "stazzare",
    "stazzeresti": "stazzare",
    "stazzerete": "stazzare",
    "stazzerà": "stazzare",
    "stazzerò": "stazzare",
    "stazzi": "stazzare",
    "stazziamo": "stazzare",
    "stazziate": "stazzare",
    "stazzin": "stazzare",
    "stazzino": "stazzare",
    "stazzo": "stazzare",
    "stazzona": "stazzonare",
    "stazzonai": "stazzonare",
    "stazzonammo": "stazzonare",
    "stazzonan": "stazzonare",
    "stazzonando": "stazzonare",
    "stazzonano": "stazzonare",
    "stazzonante": "stazzonare",
    "stazzonanti": "stazzonare",
    "stazzonar": "stazzonare",
    "stazzonaron": "stazzonare",
    "stazzonarono": "stazzonare",
    "stazzonasse": "stazzonare",
    "stazzonasser": "stazzonare",
    "stazzonassero": "stazzonare",
    "stazzonassi": "stazzonare",
    "stazzonassimo": "stazzonare",
    "stazzonaste": "stazzonare",
    "stazzonasti": "stazzonare",
    "stazzonata": "stazzonare",
    "stazzonate": "stazzonare",
    "stazzonati": "stazzonare",
    "stazzonato": "stazzonare",
    "stazzonava": "stazzonare",
    "stazzonavamo": "stazzonare",
    "stazzonavan": "stazzonare",
    "stazzonavano": "stazzonare",
    "stazzonavate": "stazzonare",
    "stazzonavi": "stazzonare",
    "stazzonavo": "stazzonare",
    "stazzonerai": "stazzonare",
    "stazzoneran": "stazzonare",
    "stazzoneranno": "stazzonare",
    "stazzonerebbe": "stazzonare",
    "stazzonerebber": "stazzonare",
    "stazzonerebbero": "stazzonare",
    "stazzonerei": "stazzonare",
    "stazzoneremmo": "stazzonare",
    "stazzoneremo": "stazzonare",
    "stazzonereste": "stazzonare",
    "stazzoneresti": "stazzonare",
    "stazzonerete": "stazzonare",
    "stazzonerà": "stazzonare",
    "stazzonerò": "stazzonare",
    "stazzoni": "stazzonare",
    "stazzoniamo": "stazzonare",
    "stazzoniate": "stazzonare",
    "stazzonin": "stazzonare",
    "stazzonino": "stazzonare",
    "stazzono": "stazzonare",
    "stazzonò": "stazzonare",
    "stazzò": "stazzare",
    "stecca": "steccare",
    "steccai": "steccare",
    "steccammo": "steccare",
    "steccan": "steccare",
    "steccando": "steccare",
    "steccano": "steccare",
    "steccante": "steccare",
    "steccanti": "steccare",
    "steccar": "steccare",
    "steccaron": "steccare",
    "steccarono": "steccare",
    "steccasse": "steccare",
    "steccasser": "steccare",
    "steccassero": "steccare",
    "steccassi": "steccare",
    "steccassimo": "steccare",
    "steccaste": "steccare",
    "steccasti": "steccare",
    "steccata": "steccare",
    "steccate": "steccare",
    "steccati": "steccato",
    "steccato": "steccare",
    "steccava": "steccare",
    "steccavamo": "steccare",
    "steccavan": "steccare",
    "steccavano": "steccare",
    "steccavate": "steccare",
    "steccavi": "steccare",
    "steccavo": "steccare",
    "steccha": "stecchire",
    "stecchan": "stecchire",
    "stecchano": "stecchire",
    "stecche": "stecchire",
    "stecchendo": "stecchire",
    "stecchente": "stecchire",
    "stecchenti": "stecchire",
    "steccherai": "steccare",
    "steccheran": "steccare",
    "steccheranno": "steccare",
    "steccherebbe": "steccare",
    "steccherebber": "steccare",
    "steccherebbero": "steccare",
    "steccherei": "steccare",
    "steccheremmo": "steccare",
    "steccheremo": "steccare",
    "stecchereste": "steccare",
    "steccheresti": "steccare",
    "steccherete": "steccare",
    "steccherà": "steccare",
    "steccherò": "steccare",
    "stecchi": "stecchire",
    "stecchiamo": "stecchire",
    "stecchiate": "stecchire",
    "stecchii": "stecchire",
    "stecchimmo": "stecchire",
    "stecchin": "steccare",
    "stecchino": "steccare",
    "stecchir": "stecchire",
    "stecchirai": "stecchire",
    "stecchiran": "stecchire",
    "stecchiranno": "stecchire",
    "stecchirebbe": "stecchire",
    "stecchirebber": "stecchire",
    "stecchirebbero": "stecchire",
    "stecchirei": "stecchire",
    "stecchiremmo": "stecchire",
    "stecchiremo": "stecchire",
    "stecchireste": "stecchire",
    "stecchiresti": "stecchire",
    "stecchirete": "stecchire",
    "stecchiron": "stecchire",
    "stecchirono": "stecchire",
    "stecchirà": "stecchire",
    "stecchirò": "stecchire",
    "stecchisse": "stecchire",
    "stecchisser": "stecchire",
    "stecchissero": "stecchire",
    "stecchissi": "stecchire",
    "stecchissimo": "stecchire",
    "stecchiste": "stecchire",
    "stecchisti": "stecchire",
    "stecchita": "stecchito",
    "stecchite": "stecchito",
    "stecchiti": "stecchito",
    "stecchito": "stecchire",
    "stecchiva": "stecchire",
    "stecchivamo": "stecchire",
    "stecchivan": "stecchire",
    "stecchivano": "stecchire",
    "stecchivate": "stecchire",
    "stecchivi": "stecchire",
    "stecchivo": "stecchire",
    "steccho": "stecchire",
    "stecchon": "stecchire",
    "stecchono": "stecchire",
    "stecchì": "stecchire",
    "stecco": "steccare",
    "steccò": "steccare",
    "steineriana": "steineriano",
    "steineriane": "steineriano",
    "steineriani": "steineriano",
    "steli": "stelo",
    "stella": "stellare",
    "stellai": "stellare",
    "stellammo": "stellare",
    "stellan": "stellare",
    "stellando": "stellare",
    "stellano": "stellare",
    "stellante": "stellare",
    "stellanti": "stellare",
    "stellar": "stellare",
    "stellari": "stellare",
    "stellaron": "stellare",
    "stellarono": "stellare",
    "stellasse": "stellare",
    "stellasser": "stellare",
    "stellassero": "stellare",
    "stellassi": "stellare",
    "stellassimo": "stellare",
    "stellaste": "stellare",
    "stellasti": "stellare",
    "stellata": "stellato",
    "stellate": "stellato",
    "stellati": "stellato",
    "stellato": "stellare",
    "stellava": "stellare",
    "stellavamo": "stellare",
    "stellavan": "stellare",
    "stellavano": "stellare",
    "stellavate": "stellare",
    "stellavi": "stellare",
    "stellavo": "stellare",
    "stelle": "stella",
    "stellerai": "stellare",
    "stelleran": "stellare",
    "stelleranno": "stellare",
    "stellerebbe": "stellare",
    "stellerebber": "stellare",
    "stellerebbero": "stellare",
    "stellerei": "stellare",
    "stelleremmo": "stellare",
    "stelleremo": "stellare",
    "stellereste": "stellare",
    "stelleresti": "stellare",
    "stellerete": "stellare",
    "stellerà": "stellare",
    "stellerò": "stellare",
    "stellette": "stelletta",
    "stelli": "stellare",
    "stelliamo": "stellare",
    "stelliate": "stellare",
    "stellin": "stellare",
    "stelline": "stellina",
    "stellino": "stellare",
    "stello": "stellare",
    "stelloni": "stellone",
    "stellò": "stellare",
    "stemmi": "stemma",
    "stempera": "stemperare",
    "stemperai": "stemperare",
    "stemperammo": "stemperare",
    "stemperan": "stemperare",
    "stemperando": "stemperare",
    "stemperano": "stemperare",
    "stemperante": "stemperare",
    "stemperanti": "stemperare",
    "stemperar": "stemperare",
    "stemperaron": "stemperare",
    "stemperarono": "stemperare",
    "stemperasse": "stemperare",
    "stemperasser": "stemperare",
    "stemperassero": "stemperare",
    "stemperassi": "stemperare",
    "stemperassimo": "stemperare",
    "stemperaste": "stemperare",
    "stemperasti": "stemperare",
    "stemperata": "stemperare",
    "stemperate": "stemperare",
    "stemperati": "stemperare",
    "stemperato": "stemperare",
    "stemperava": "stemperare",
    "stemperavamo": "stemperare",
    "stemperavan": "stemperare",
    "stemperavano": "stemperare",
    "stemperavate": "stemperare",
    "stemperavi": "stemperare",
    "stemperavo": "stemperare",
    "stempererai": "stemperare",
    "stempereran": "stemperare",
    "stempereranno": "stemperare",
    "stempererebbe": "stemperare",
    "stempererebber": "stemperare",
    "stempererebbero": "stemperare",
    "stempererei": "stemperare",
    "stempereremmo": "stemperare",
    "stempereremo": "stemperare",
    "stemperereste": "stemperare",
    "stempereresti": "stemperare",
    "stempererete": "stemperare",
    "stempererà": "stemperare",
    "stempererò": "stemperare",
    "stemperi": "stemperare",
    "stemperiamo": "stemperare",
    "stemperiate": "stemperare",
    "stemperin": "stemperare",
    "stemperino": "stemperare",
    "stempero": "stemperare",
    "stemperò": "stemperare",
    "stempi": "stempiare",
    "stempia": "stempiare",
    "stempiai": "stempiare",
    "stempiammo": "stempiare",
    "stempiamo": "stempiare",
    "stempian": "stempiare",
    "stempiando": "stempiare",
    "stempiano": "stempiare",
    "stempiar": "stempiare",
    "stempiaron": "stempiare",
    "stempiarono": "stempiare",
    "stempiasse": "stempiare",
    "stempiasser": "stempiare",
    "stempiassero": "stempiare",
    "stempiassi": "stempiare",
    "stempiassimo": "stempiare",
    "stempiaste": "stempiare",
    "stempiasti": "stempiare",
    "stempiata": "stempiare",
    "stempiate": "stempiare",
    "stempiati": "stempiare",
    "stempiato": "stempiare",
    "stempiava": "stempiare",
    "stempiavamo": "stempiare",
    "stempiavan": "stempiare",
    "stempiavano": "stempiare",
    "stempiavate": "stempiare",
    "stempiavi": "stempiare",
    "stempiavo": "stempiare",
    "stempierai": "stempiare",
    "stempieran": "stempiare",
    "stempieranno": "stempiare",
    "stempierebbe": "stempiare",
    "stempierebber": "stempiare",
    "stempierebbero": "stempiare",
    "stempierei": "stempiare",
    "stempieremmo": "stempiare",
    "stempieremo": "stempiare",
    "stempiereste": "stempiare",
    "stempieresti": "stempiare",
    "stempierete": "stempiare",
    "stempierà": "stempiare",
    "stempierò": "stempiare",
    "stempin": "stempiare",
    "stempino": "stempiare",
    "stempio": "stempiare",
    "stempiò": "stempiare",
    "stenda": "stendere",
    "stendan": "stendere",
    "stendano": "stendere",
    "stendardi": "stendardo",
    "stende": "stendere",
    "stendemmo": "stendere",
    "stendendo": "stendere",
    "stendente": "stendere",
    "stendenti": "stendere",
    "stender": "stendere",
    "stenderai": "stendere",
    "stenderan": "stendere",
    "stenderanno": "stendere",
    "stenderebbe": "stendere",
    "stenderebber": "stendere",
    "stenderebbero": "stendere",
    "stenderei": "stendere",
    "stenderemmo": "stendere",
    "stenderemo": "stendere",
    "stendereste": "stendere",
    "stenderesti": "stendere",
    "stenderete": "stendere",
    "stenderà": "stendere",
    "stenderò": "stendere",
    "stendesse": "stendere",
    "stendesser": "stendere",
    "stendessero": "stendere",
    "stendessi": "stendere",
    "stendessimo": "stendere",
    "stendeste": "stendere",
    "stendesti": "stendere",
    "stendete": "stendere",
    "stendeva": "stendere",
    "stendevamo": "stendere",
    "stendevan": "stendere",
    "stendevano": "stendere",
    "stendevate": "stendere",
    "stendevi": "stendere",
    "stendevo": "stendere",
    "stendi": "stendere",
    "stendiamo": "stendere",
    "stendiate": "stendere",
    "stendo": "stendere",
    "stendon": "stendere",
    "stendono": "stendere",
    "stenografa": "stenografare",
    "stenografai": "stenografare",
    "stenografammo": "stenografare",
    "stenografan": "stenografare",
    "stenografando": "stenografare",
    "stenografano": "stenografare",
    "stenografante": "stenografare",
    "stenografanti": "stenografare",
    "stenografar": "stenografare",
    "stenografaron": "stenografare",
    "stenografarono": "stenografare",
    "stenografasse": "stenografare",
    "stenografasser": "stenografare",
    "stenografassero": "stenografare",
    "stenografassi": "stenografare",
    "stenografassimo": "stenografare",
    "stenografaste": "stenografare",
    "stenografasti": "stenografare",
    "stenografata": "stenografare",
    "stenografate": "stenografare",
    "stenografati": "stenografare",
    "stenografato": "stenografare",
    "stenografava": "stenografare",
    "stenografavamo": "stenografare",
    "stenografavan": "stenografare",
    "stenografavano": "stenografare",
    "stenografavate": "stenografare",
    "stenografavi": "stenografare",
    "stenografavo": "stenografare",
    "stenograferai": "stenografare",
    "stenograferan": "stenografare",
    "stenograferanno": "stenografare",
    "stenograferebbe": "stenografare",
    "stenograferebber": "stenografare",
    "stenograferebbero": "stenografare",
    "stenograferei": "stenografare",
    "stenograferemmo": "stenografare",
    "stenograferemo": "stenografare",
    "stenografereste": "stenografare",
    "stenograferesti": "stenografare",
    "stenograferete": "stenografare",
    "stenograferà": "stenografare",
    "stenograferò": "stenografare",
    "stenografi": "stenografo",
    "stenografiamo": "stenografare",
    "stenografiate": "stenografare",
    "stenografica": "stenografico",
    "stenografiche": "stenografico",
    "stenografici": "stenografico",
    "stenografin": "stenografare",
    "stenografino": "stenografare",
    "stenografo": "stenografare",
    "stenografò": "stenografare",
    "stenta": "stento",
    "stentai": "stentare",
    "stentammo": "stentare",
    "stentan": "stentare",
    "stentando": "stentare",
    "stentano": "stentare",
    "stentante": "stentare",
    "stentanti": "stentare",
    "stentar": "stentare",
    "stentaron": "stentare",
    "stentarono": "stentare",
    "stentasse": "stentare",
    "stentasser": "stentare",
    "stentassero": "stentare",
    "stentassi": "stentare",
    "stentassimo": "stentare",
    "stentaste": "stentare",
    "stentasti": "stentare",
    "stentata": "stentato",
    "stentate": "stentato",
    "stentati": "stentato",
    "stentato": "stentare",
    "stentava": "stentare",
    "stentavamo": "stentare",
    "stentavan": "stentare",
    "stentavano": "stentare",
    "stentavate": "stentare",
    "stentavi": "stentare",
    "stentavo": "stentare",
    "stente": "stento",
    "stenterai": "stentare",
    "stenteran": "stentare",
    "stenteranno": "stentare",
    "stenterebbe": "stentare",
    "stenterebber": "stentare",
    "stenterebbero": "stentare",
    "stenterei": "stentare",
    "stenteremmo": "stentare",
    "stenteremo": "stentare",
    "stentereste": "stentare",
    "stenteresti": "stentare",
    "stenterete": "stentare",
    "stenterà": "stentare",
    "stenterò": "stentare",
    "stenti": "stento",
    "stentiamo": "stentare",
    "stentiate": "stentare",
    "stentin": "stentare",
    "stentino": "stentare",
    "stento": "stentare",
    "stentorea": "stentoreo",
    "stentoree": "stentoreo",
    "stentorei": "stentoreo",
    "stentò": "stentare",
    "steppe": "steppa",
    "stepposa": "stepposo",
    "steppose": "stepposo",
    "stepposi": "stepposo",
    "sterea": "stereo",
    "steree": "stereo",
    "sterei": "stereo",
    "stereofonica": "stereofonico",
    "stereofoniche": "stereofonico",
    "stereofonici": "stereofonico",
    "stereoscopica": "stereoscopico",
    "stereoscopiche": "stereoscopico",
    "stereoscopici": "stereoscopico",
    "stereotipa": "stereotipo",
    "stereotipata": "stereotipato",
    "stereotipate": "stereotipato",
    "stereotipati": "stereotipato",
    "stereotipe": "stereotipo",
    "stereotipi": "stereotipo",
    "stereotipizza": "stereotipizzare",
    "stereotipizzai": "stereotipizzare",
    "stereotipizzammo": "stereotipizzare",
    "stereotipizzan": "stereotipizzare",
    "stereotipizzando": "stereotipizzare",
    "stereotipizzano": "stereotipizzare",
    "stereotipizzante": "stereotipizzare",
    "stereotipizzanti": "stereotipizzare",
    "stereotipizzar": "stereotipizzare",
    "stereotipizzaron": "stereotipizzare",
    "stereotipizzarono": "stereotipizzare",
    "stereotipizzasse": "stereotipizzare",
    "stereotipizzasser": "stereotipizzare",
    "stereotipizzassero": "stereotipizzare",
    "stereotipizzassi": "stereotipizzare",
    "stereotipizzassimo": "stereotipizzare",
    "stereotipizzaste": "stereotipizzare",
    "stereotipizzasti": "stereotipizzare",
    "stereotipizzata": "stereotipizzare",
    "stereotipizzate": "stereotipizzare",
    "stereotipizzati": "stereotipizzare",
    "stereotipizzato": "stereotipizzare",
    "stereotipizzava": "stereotipizzare",
    "stereotipizzavamo": "stereotipizzare",
    "stereotipizzavan": "stereotipizzare",
    "stereotipizzavano": "stereotipizzare",
    "stereotipizzavate": "stereotipizzare",
    "stereotipizzavi": "stereotipizzare",
    "stereotipizzavo": "stereotipizzare",
    "stereotipizzerai": "stereotipizzare",
    "stereotipizzeran": "stereotipizzare",
    "stereotipizzeranno": "stereotipizzare",
    "stereotipizzerebbe": "stereotipizzare",
    "stereotipizzerebber": "stereotipizzare",
    "stereotipizzerebbero": "stereotipizzare",
    "stereotipizzerei": "stereotipizzare",
    "stereotipizzeremmo": "stereotipizzare",
    "stereotipizzeremo": "stereotipizzare",
    "stereotipizzereste": "stereotipizzare",
    "stereotipizzeresti": "stereotipizzare",
    "stereotipizzerete": "stereotipizzare",
    "stereotipizzerà": "stereotipizzare",
    "stereotipizzerò": "stereotipizzare",
    "stereotipizzi": "stereotipizzare",
    "stereotipizziamo": "stereotipizzare",
    "stereotipizziate": "stereotipizzare",
    "stereotipizzin": "stereotipizzare",
    "stereotipizzino": "stereotipizzare",
    "stereotipizzo": "stereotipizzare",
    "stereotipizzò": "stereotipizzare",
    "sterili": "sterile",
    "sterilizza": "sterilizzare",
    "sterilizzai": "sterilizzare",
    "sterilizzammo": "sterilizzare",
    "sterilizzan": "sterilizzare",
    "sterilizzando": "sterilizzare",
    "sterilizzano": "sterilizzare",
    "sterilizzante": "sterilizzare",
    "sterilizzanti": "sterilizzare",
    "sterilizzar": "sterilizzare",
    "sterilizzaron": "sterilizzare",
    "sterilizzarono": "sterilizzare",
    "sterilizzasse": "sterilizzare",
    "sterilizzasser": "sterilizzare",
    "sterilizzassero": "sterilizzare",
    "sterilizzassi": "sterilizzare",
    "sterilizzassimo": "sterilizzare",
    "sterilizzaste": "sterilizzare",
    "sterilizzasti": "sterilizzare",
    "sterilizzata": "sterilizzare",
    "sterilizzate": "sterilizzare",
    "sterilizzati": "sterilizzare",
    "sterilizzato": "sterilizzare",
    "sterilizzatori": "sterilizzatore",
    "sterilizzatrice": "sterilizzatore",
    "sterilizzatrici": "sterilizzatore",
    "sterilizzava": "sterilizzare",
    "sterilizzavamo": "sterilizzare",
    "sterilizzavan": "sterilizzare",
    "sterilizzavano": "sterilizzare",
    "sterilizzavate": "sterilizzare",
    "sterilizzavi": "sterilizzare",
    "sterilizzavo": "sterilizzare",
    "sterilizzazioni": "sterilizzazione",
    "sterilizzerai": "sterilizzare",
    "sterilizzeran": "sterilizzare",
    "sterilizzeranno": "sterilizzare",
    "sterilizzerebbe": "sterilizzare",
    "sterilizzerebber": "sterilizzare",
    "sterilizzerebbero": "sterilizzare",
    "sterilizzerei": "sterilizzare",
    "sterilizzeremmo": "sterilizzare",
    "sterilizzeremo": "sterilizzare",
    "sterilizzereste": "sterilizzare",
    "sterilizzeresti": "sterilizzare",
    "sterilizzerete": "sterilizzare",
    "sterilizzerà": "sterilizzare",
    "sterilizzerò": "sterilizzare",
    "sterilizzi": "sterilizzare",
    "sterilizziamo": "sterilizzare",
    "sterilizziate": "sterilizzare",
    "sterilizzin": "sterilizzare",
    "sterilizzino": "sterilizzare",
    "sterilizzo": "sterilizzare",
    "sterilizzò": "sterilizzare",
    "sterline": "sterlina",
    "stermina": "sterminare",
    "sterminai": "sterminare",
    "sterminammo": "sterminare",
    "sterminan": "sterminare",
    "sterminando": "sterminare",
    "sterminano": "sterminare",
    "sterminante": "sterminare",
    "sterminanti": "sterminare",
    "sterminar": "sterminare",
    "sterminaron": "sterminare",
    "sterminarono": "sterminare",
    "sterminasse": "sterminare",
    "sterminasser": "sterminare",
    "sterminassero": "sterminare",
    "sterminassi": "sterminare",
    "sterminassimo": "sterminare",
    "sterminaste": "sterminare",
    "sterminasti": "sterminare",
    "sterminata": "sterminato",
    "sterminate": "sterminato",
    "sterminati": "sterminato",
    "sterminato": "sterminare",
    "sterminatori": "sterminatore",
    "sterminatrice": "sterminatore",
    "sterminatrici": "sterminatore",
    "sterminava": "sterminare",
    "sterminavamo": "sterminare",
    "sterminavan": "sterminare",
    "sterminavano": "sterminare",
    "sterminavate": "sterminare",
    "sterminavi": "sterminare",
    "sterminavo": "sterminare",
    "sterminerai": "sterminare",
    "stermineran": "sterminare",
    "stermineranno": "sterminare",
    "sterminerebbe": "sterminare",
    "sterminerebber": "sterminare",
    "sterminerebbero": "sterminare",
    "sterminerei": "sterminare",
    "stermineremmo": "sterminare",
    "stermineremo": "sterminare",
    "sterminereste": "sterminare",
    "stermineresti": "sterminare",
    "sterminerete": "sterminare",
    "sterminerà": "sterminare",
    "sterminerò": "sterminare",
    "stermini": "sterminio",
    "sterminiamo": "sterminare",
    "sterminiate": "sterminare",
    "sterminin": "sterminare",
    "sterminino": "sterminare",
    "stermino": "sterminare",
    "sterminò": "sterminare",
    "sterni": "sterno",
    "steroidi": "steroide",
    "sterpaglie": "sterpaglia",
    "sterra": "sterrare",
    "sterrai": "sterrare",
    "sterrammo": "sterrare",
    "sterran": "sterrare",
    "sterrando": "sterrare",
    "sterrano": "sterrare",
    "sterrante": "sterrare",
    "sterranti": "sterrare",
    "sterrar": "sterrare",
    "sterraron": "sterrare",
    "sterrarono": "sterrare",
    "sterrasse": "sterrare",
    "sterrasser": "sterrare",
    "sterrassero": "sterrare",
    "sterrassi": "sterrare",
    "sterrassimo": "sterrare",
    "sterraste": "sterrare",
    "sterrasti": "sterrare",
    "sterrata": "sterrare",
    "sterrate": "sterrare",
    "sterrati": "sterrato",
    "sterrato": "sterrare",
    "sterrava": "sterrare",
    "sterravamo": "sterrare",
    "sterravan": "sterrare",
    "sterravano": "sterrare",
    "sterravate": "sterrare",
    "sterravi": "sterrare",
    "sterravo": "sterrare",
    "sterrerai": "sterrare",
    "sterreran": "sterrare",
    "sterreranno": "sterrare",
    "sterrerebbe": "sterrare",
    "sterrerebber": "sterrare",
    "sterrerebbero": "sterrare",
    "sterrerei": "sterrare",
    "sterreremmo": "sterrare",
    "sterreremo": "sterrare",
    "sterrereste": "sterrare",
    "sterreresti": "sterrare",
    "sterrerete": "sterrare",
    "sterrerà": "sterrare",
    "sterrerò": "sterrare",
    "sterri": "sterrare",
    "sterriamo": "sterrare",
    "sterriate": "sterrare",
    "sterrin": "sterrare",
    "sterrino": "sterrare",
    "sterro": "sterrare",
    "sterrò": "sterrare",
    "sterza": "sterzare",
    "sterzai": "sterzare",
    "sterzammo": "sterzare",
    "sterzan": "sterzare",
    "sterzando": "sterzare",
    "sterzano": "sterzare",
    "sterzante": "sterzare",
    "sterzanti": "sterzare",
    "sterzar": "sterzare",
    "sterzaron": "sterzare",
    "sterzarono": "sterzare",
    "sterzasse": "sterzare",
    "sterzasser": "sterzare",
    "sterzassero": "sterzare",
    "sterzassi": "sterzare",
    "sterzassimo": "sterzare",
    "sterzaste": "sterzare",
    "sterzasti": "sterzare",
    "sterzata": "sterzare",
    "sterzate": "sterzata",
    "sterzati": "sterzare",
    "sterzato": "sterzare",
    "sterzava": "sterzare",
    "sterzavamo": "sterzare",
    "sterzavan": "sterzare",
    "sterzavano": "sterzare",
    "sterzavate": "sterzare",
    "sterzavi": "sterzare",
    "sterzavo": "sterzare",
    "sterzerai": "sterzare",
    "sterzeran": "sterzare",
    "sterzeranno": "sterzare",
    "sterzerebbe": "sterzare",
    "sterzerebber": "sterzare",
    "sterzerebbero": "sterzare",
    "sterzerei": "sterzare",
    "sterzeremmo": "sterzare",
    "sterzeremo": "sterzare",
    "sterzereste": "sterzare",
    "sterzeresti": "sterzare",
    "sterzerete": "sterzare",
    "sterzerà": "sterzare",
    "sterzerò": "sterzare",
    "sterzi": "sterzo",
    "sterziamo": "sterzare",
    "sterziate": "sterzare",
    "sterzin": "sterzare",
    "sterzino": "sterzare",
    "sterzo": "sterzare",
    "sterzò": "sterzare",
    "stesa": "stendere",
    "stese": "stendere",
    "steser": "stendere",
    "stesero": "stendere",
    "stesi": "stendere",
    "steso": "stendere",
    "stessa": "stesso",
    "stesse": "stesso",
    "stesser": "stare",
    "stessero": "stare",
    "stessi": "stesso",
    "stessimo": "stare",
    "steste": "stare",
    "stesti": "stare",
    "stesure": "stesura",
    "stesè": "stendere",
    "stette": "stare",
    "stetti": "stare",
    "stia": "stare",
    "stiamo": "stare",
    "stian": "stare",
    "stiano": "stare",
    "stiate": "stare",
    "stie": "stia",
    "stigmatizza": "stigmatizzare",
    "stigmatizzai": "stigmatizzare",
    "stigmatizzammo": "stigmatizzare",
    "stigmatizzan": "stigmatizzare",
    "stigmatizzando": "stigmatizzare",
    "stigmatizzano": "stigmatizzare",
    "stigmatizzante": "stigmatizzare",
    "stigmatizzanti": "stigmatizzare",
    "stigmatizzar": "stigmatizzare",
    "stigmatizzaron": "stigmatizzare",
    "stigmatizzarono": "stigmatizzare",
    "stigmatizzasse": "stigmatizzare",
    "stigmatizzasser": "stigmatizzare",
    "stigmatizzassero": "stigmatizzare",
    "stigmatizzassi": "stigmatizzare",
    "stigmatizzassimo": "stigmatizzare",
    "stigmatizzaste": "stigmatizzare",
    "stigmatizzasti": "stigmatizzare",
    "stigmatizzata": "stigmatizzare",
    "stigmatizzate": "stigmatizzare",
    "stigmatizzati": "stigmatizzare",
    "stigmatizzato": "stigmatizzare",
    "stigmatizzava": "stigmatizzare",
    "stigmatizzavamo": "stigmatizzare",
    "stigmatizzavan": "stigmatizzare",
    "stigmatizzavano": "stigmatizzare",
    "stigmatizzavate": "stigmatizzare",
    "stigmatizzavi": "stigmatizzare",
    "stigmatizzavo": "stigmatizzare",
    "stigmatizzerai": "stigmatizzare",
    "stigmatizzeran": "stigmatizzare",
    "stigmatizzeranno": "stigmatizzare",
    "stigmatizzerebbe": "stigmatizzare",
    "stigmatizzerebber": "stigmatizzare",
    "stigmatizzerebbero": "stigmatizzare",
    "stigmatizzerei": "stigmatizzare",
    "stigmatizzeremmo": "stigmatizzare",
    "stigmatizzeremo": "stigmatizzare",
    "stigmatizzereste": "stigmatizzare",
    "stigmatizzeresti": "stigmatizzare",
    "stigmatizzerete": "stigmatizzare",
    "stigmatizzerà": "stigmatizzare",
    "stigmatizzerò": "stigmatizzare",
    "stigmatizzi": "stigmatizzare",
    "stigmatizziamo": "stigmatizzare",
    "stigmatizziate": "stigmatizzare",
    "stigmatizzin": "stigmatizzare",
    "stigmatizzino": "stigmatizzare",
    "stigmatizzo": "stigmatizzare",
    "stigmatizzò": "stigmatizzare",
    "stil": "stile",
    "stila": "stilare",
    "stilai": "stilare",
    "stilammo": "stilare",
    "stilan": "stilare",
    "stilando": "stilare",
    "stilano": "stilare",
    "stilante": "stilare",
    "stilanti": "stilare",
    "stilar": "stilare",
    "stilaron": "stilare",
    "stilarono": "stilare",
    "stilasse": "stilare",
    "stilasser": "stilare",
    "stilassero": "stilare",
    "stilassi": "stilare",
    "stilassimo": "stilare",
    "stilaste": "stilare",
    "stilasti": "stilare",
    "stilata": "stilare",
    "stilate": "stilare",
    "stilati": "stilare",
    "stilato": "stilare",
    "stilava": "stilare",
    "stilavamo": "stilare",
    "stilavan": "stilare",
    "stilavano": "stilare",
    "stilavate": "stilare",
    "stilavi": "stilare",
    "stilavo": "stilare",
    "stilerai": "stilare",
    "stileran": "stilare",
    "stileranno": "stilare",
    "stilerebbe": "stilare",
    "stilerebber": "stilare",
    "stilerebbero": "stilare",
    "stilerei": "stilare",
    "stileremmo": "stilare",
    "stileremo": "stilare",
    "stilereste": "stilare",
    "stileresti": "stilare",
    "stilerete": "stilare",
    "stilerà": "stilare",
    "stilerò": "stilare",
    "stilettate": "stilettata",
    "stili": "stilo",
    "stiliamo": "stilare",
    "stiliate": "stilare",
    "stilin": "stilare",
    "stilino": "stilare",
    "stiliste": "stilista",
    "stilisti": "stilista",
    "stilistica": "stilistico",
    "stilistiche": "stilistico",
    "stilistici": "stilistico",
    "stilizza": "stilizzare",
    "stilizzai": "stilizzare",
    "stilizzammo": "stilizzare",
    "stilizzan": "stilizzare",
    "stilizzando": "stilizzare",
    "stilizzano": "stilizzare",
    "stilizzante": "stilizzare",
    "stilizzanti": "stilizzare",
    "stilizzar": "stilizzare",
    "stilizzaron": "stilizzare",
    "stilizzarono": "stilizzare",
    "stilizzasse": "stilizzare",
    "stilizzasser": "stilizzare",
    "stilizzassero": "stilizzare",
    "stilizzassi": "stilizzare",
    "stilizzassimo": "stilizzare",
    "stilizzaste": "stilizzare",
    "stilizzasti": "stilizzare",
    "stilizzata": "stilizzare",
    "stilizzate": "stilizzare",
    "stilizzati": "stilizzare",
    "stilizzato": "stilizzare",
    "stilizzava": "stilizzare",
    "stilizzavamo": "stilizzare",
    "stilizzavan": "stilizzare",
    "stilizzavano": "stilizzare",
    "stilizzavate": "stilizzare",
    "stilizzavi": "stilizzare",
    "stilizzavo": "stilizzare",
    "stilizzazioni": "stilizzazione",
    "stilizzerai": "stilizzare",
    "stilizzeran": "stilizzare",
    "stilizzeranno": "stilizzare",
    "stilizzerebbe": "stilizzare",
    "stilizzerebber": "stilizzare",
    "stilizzerebbero": "stilizzare",
    "stilizzerei": "stilizzare",
    "stilizzeremmo": "stilizzare",
    "stilizzeremo": "stilizzare",
    "stilizzereste": "stilizzare",
    "stilizzeresti": "stilizzare",
    "stilizzerete": "stilizzare",
    "stilizzerà": "stilizzare",
    "stilizzerò": "stilizzare",
    "stilizzi": "stilizzare",
    "stilizziamo": "stilizzare",
    "stilizziate": "stilizzare",
    "stilizzin": "stilizzare",
    "stilizzino": "stilizzare",
    "stilizzo": "stilizzare",
    "stilizzò": "stilizzare",
    "stilla": "stillare",
    "stillai": "stillare",
    "stillammo": "stillare",
    "stillan": "stillare",
    "stillando": "stillare",
    "stillano": "stillare",
    "stillante": "stillare",
    "stillanti": "stillare",
    "stillar": "stillare",
    "stillaron": "stillare",
    "stillarono": "stillare",
    "stillasse": "stillare",
    "stillasser": "stillare",
    "stillassero": "stillare",
    "stillassi": "stillare",
    "stillassimo": "stillare",
    "stillaste": "stillare",
    "stillasti": "stillare",
    "stillata": "stillare",
    "stillate": "stillare",
    "stillati": "stillare",
    "stillato": "stillare",
    "stillava": "stillare",
    "stillavamo": "stillare",
    "stillavan": "stillare",
    "stillavano": "stillare",
    "stillavate": "stillare",
    "stillavi": "stillare",
    "stillavo": "stillare",
    "stille": "stilla",
    "stillerai": "stillare",
    "stilleran": "stillare",
    "stilleranno": "stillare",
    "stillerebbe": "stillare",
    "stillerebber": "stillare",
    "stillerebbero": "stillare",
    "stillerei": "stillare",
    "stilleremmo": "stillare",
    "stilleremo": "stillare",
    "stillereste": "stillare",
    "stilleresti": "stillare",
    "stillerete": "stillare",
    "stillerà": "stillare",
    "stillerò": "stillare",
    "stilli": "stillare",
    "stilliamo": "stillare",
    "stilliate": "stillare",
    "stillicidi": "stillicidio",
    "stillin": "stillare",
    "stillino": "stillare",
    "stillo": "stillare",
    "stillò": "stillare",
    "stilo": "stilare",
    "stilografica": "stilografico",
    "stilografiche": "stilografico",
    "stilografici": "stilografico",
    "stilò": "stilare",
    "stima": "stimare",
    "stimabili": "stimabile",
    "stimai": "stimare",
    "stimammo": "stimare",
    "stiman": "stimare",
    "stimando": "stimare",
    "stimano": "stimare",
    "stimante": "stimare",
    "stimanti": "stimare",
    "stimar": "stimare",
    "stimaron": "stimare",
    "stimarono": "stimare",
    "stimasse": "stimare",
    "stimasser": "stimare",
    "stimassero": "stimare",
    "stimassi": "stimare",
    "stimassimo": "stimare",
    "stimaste": "stimare",
    "stimasti": "stimare",
    "stimata": "stimato",
    "stimate": "stimato",
    "stimati": "stimato",
    "stimato": "stimare",
    "stimava": "stimare",
    "stimavamo": "stimare",
    "stimavan": "stimare",
    "stimavano": "stimare",
    "stimavate": "stimare",
    "stimavi": "stimare",
    "stimavo": "stimare",
    "stime": "stima",
    "stimerai": "stimare",
    "stimeran": "stimare",
    "stimeranno": "stimare",
    "stimerebbe": "stimare",
    "stimerebber": "stimare",
    "stimerebbero": "stimare",
    "stimerei": "stimare",
    "stimeremmo": "stimare",
    "stimeremo": "stimare",
    "stimereste": "stimare",
    "stimeresti": "stimare",
    "stimerete": "stimare",
    "stimerà": "stimare",
    "stimerò": "stimare",
    "stimi": "stimare",
    "stimiamo": "stimare",
    "stimiate": "stimare",
    "stimin": "stimare",
    "stimino": "stimare",
    "stimmate": "stimmata",
    "stimmatizza": "stimmatizzare",
    "stimmatizzai": "stimmatizzare",
    "stimmatizzammo": "stimmatizzare",
    "stimmatizzan": "stimmatizzare",
    "stimmatizzando": "stimmatizzare",
    "stimmatizzano": "stimmatizzare",
    "stimmatizzante": "stimmatizzare",
    "stimmatizzanti": "stimmatizzare",
    "stimmatizzar": "stimmatizzare",
    "stimmatizzaron": "stimmatizzare",
    "stimmatizzarono": "stimmatizzare",
    "stimmatizzasse": "stimmatizzare",
    "stimmatizzasser": "stimmatizzare",
    "stimmatizzassero": "stimmatizzare",
    "stimmatizzassi": "stimmatizzare",
    "stimmatizzassimo": "stimmatizzare",
    "stimmatizzaste": "stimmatizzare",
    "stimmatizzasti": "stimmatizzare",
    "stimmatizzata": "stimmatizzare",
    "stimmatizzate": "stimmatizzare",
    "stimmatizzati": "stimmatizzare",
    "stimmatizzato": "stimmatizzare",
    "stimmatizzava": "stimmatizzare",
    "stimmatizzavamo": "stimmatizzare",
    "stimmatizzavan": "stimmatizzare",
    "stimmatizzavano": "stimmatizzare",
    "stimmatizzavate": "stimmatizzare",
    "stimmatizzavi": "stimmatizzare",
    "stimmatizzavo": "stimmatizzare",
    "stimmatizzerai": "stimmatizzare",
    "stimmatizzeran": "stimmatizzare",
    "stimmatizzeranno": "stimmatizzare",
    "stimmatizzerebbe": "stimmatizzare",
    "stimmatizzerebber": "stimmatizzare",
    "stimmatizzerebbero": "stimmatizzare",
    "stimmatizzerei": "stimmatizzare",
    "stimmatizzeremmo": "stimmatizzare",
    "stimmatizzeremo": "stimmatizzare",
    "stimmatizzereste": "stimmatizzare",
    "stimmatizzeresti": "stimmatizzare",
    "stimmatizzerete": "stimmatizzare",
    "stimmatizzerà": "stimmatizzare",
    "stimmatizzerò": "stimmatizzare",
    "stimmatizzi": "stimmatizzare",
    "stimmatizziamo": "stimmatizzare",
    "stimmatizziate": "stimmatizzare",
    "stimmatizzin": "stimmatizzare",
    "stimmatizzino": "stimmatizzare",
    "stimmatizzo": "stimmatizzare",
    "stimmatizzò": "stimmatizzare",
    "stimo": "stimare",
    "stimola": "stimolare",
    "stimolai": "stimolare",
    "stimolammo": "stimolare",
    "stimolan": "stimolare",
    "stimolando": "stimolare",
    "stimolano": "stimolare",
    "stimolante": "stimolare",
    "stimolanti": "stimolare",
    "stimolar": "stimolare",
    "stimolaron": "stimolare",
    "stimolarono": "stimolare",
    "stimolasse": "stimolare",
    "stimolasser": "stimolare",
    "stimolassero": "stimolare",
    "stimolassi": "stimolare",
    "stimolassimo": "stimolare",
    "stimolaste": "stimolare",
    "stimolasti": "stimolare",
    "stimolata": "stimolare",
    "stimolate": "stimolare",
    "stimolati": "stimolare",
    "stimolato": "stimolare",
    "stimolatori": "stimolatore",
    "stimolava": "stimolare",
    "stimolavamo": "stimolare",
    "stimolavan": "stimolare",
    "stimolavano": "stimolare",
    "stimolavate": "stimolare",
    "stimolavi": "stimolare",
    "stimolavo": "stimolare",
    "stimolazioni": "stimolazione",
    "stimolerai": "stimolare",
    "stimoleran": "stimolare",
    "stimoleranno": "stimolare",
    "stimolerebbe": "stimolare",
    "stimolerebber": "stimolare",
    "stimolerebbero": "stimolare",
    "stimolerei": "stimolare",
    "stimoleremmo": "stimolare",
    "stimoleremo": "stimolare",
    "stimolereste": "stimolare",
    "stimoleresti": "stimolare",
    "stimolerete": "stimolare",
    "stimolerà": "stimolare",
    "stimolerò": "stimolare",
    "stimoli": "stimolo",
    "stimoliamo": "stimolare",
    "stimoliate": "stimolare",
    "stimolin": "stimolare",
    "stimolino": "stimolare",
    "stimolo": "stimolare",
    "stimolò": "stimolare",
    "stimò": "stimare",
    "stinchi": "stinco",
    "stinga": "stingere",
    "stingan": "stingere",
    "stingano": "stingere",
    "stinge": "stingere",
    "stingemmo": "stingere",
    "stingendo": "stingere",
    "stingente": "stingere",
    "stingenti": "stingere",
    "stinger": "stingere",
    "stingerai": "stingere",
    "stingeran": "stingere",
    "stingeranno": "stingere",
    "stingerebbe": "stingere",
    "stingerebber": "stingere",
    "stingerebbero": "stingere",
    "stingerei": "stingere",
    "stingeremmo": "stingere",
    "stingeremo": "stingere",
    "stingereste": "stingere",
    "stingeresti": "stingere",
    "stingerete": "stingere",
    "stingerà": "stingere",
    "stingerò": "stingere",
    "stingesse": "stingere",
    "stingesser": "stingere",
    "stingessero": "stingere",
    "stingessi": "stingere",
    "stingessimo": "stingere",
    "stingeste": "stingere",
    "stingesti": "stingere",
    "stingete": "stingere",
    "stingeva": "stingere",
    "stingevamo": "stingere",
    "stingevan": "stingere",
    "stingevano": "stingere",
    "stingevate": "stingere",
    "stingevi": "stingere",
    "stingevo": "stingere",
    "stingi": "stingere",
    "stingiamo": "stingere",
    "stingiate": "stingere",
    "stingo": "stingere",
    "stingon": "stingere",
    "stingono": "stingere",
    "stinse": "stingere",
    "stinser": "stingere",
    "stinsero": "stingere",
    "stinsi": "stingere",
    "stinta": "stingere",
    "stinte": "stingere",
    "stinti": "stingere",
    "stinto": "stingere",
    "stipa": "stipare",
    "stipai": "stipare",
    "stipammo": "stipare",
    "stipan": "stipare",
    "stipando": "stipare",
    "stipano": "stipare",
    "stipante": "stipare",
    "stipanti": "stipare",
    "stipar": "stipare",
    "stiparon": "stipare",
    "stiparono": "stipare",
    "stipasse": "stipare",
    "stipasser": "stipare",
    "stipassero": "stipare",
    "stipassi": "stipare",
    "stipassimo": "stipare",
    "stipaste": "stipare",
    "stipasti": "stipare",
    "stipata": "stipare",
    "stipate": "stipare",
    "stipati": "stipare",
    "stipato": "stipare",
    "stipava": "stipare",
    "stipavamo": "stipare",
    "stipavan": "stipare",
    "stipavano": "stipare",
    "stipavate": "stipare",
    "stipavi": "stipare",
    "stipavo": "stipare",
    "stipendi": "stipendio",
    "stipendia": "stipendiare",
    "stipendiai": "stipendiare",
    "stipendiammo": "stipendiare",
    "stipendiamo": "stipendiare",
    "stipendian": "stipendiare",
    "stipendiando": "stipendiare",
    "stipendiano": "stipendiare",
    "stipendiante": "stipendiare",
    "stipendianti": "stipendiare",
    "stipendiar": "stipendiare",
    "stipendiaron": "stipendiare",
    "stipendiarono": "stipendiare",
    "stipendiasse": "stipendiare",
    "stipendiasser": "stipendiare",
    "stipendiassero": "stipendiare",
    "stipendiassi": "stipendiare",
    "stipendiassimo": "stipendiare",
    "stipendiaste": "stipendiare",
    "stipendiasti": "stipendiare",
    "stipendiata": "stipendiato",
    "stipendiate": "stipendiato",
    "stipendiati": "stipendiato",
    "stipendiato": "stipendiare",
    "stipendiava": "stipendiare",
    "stipendiavamo": "stipendiare",
    "stipendiavan": "stipendiare",
    "stipendiavano": "stipendiare",
    "stipendiavate": "stipendiare",
    "stipendiavi": "stipendiare",
    "stipendiavo": "stipendiare",
    "stipendierai": "stipendiare",
    "stipendieran": "stipendiare",
    "stipendieranno": "stipendiare",
    "stipendierebbe": "stipendiare",
    "stipendierebber": "stipendiare",
    "stipendierebbero": "stipendiare",
    "stipendierei": "stipendiare",
    "stipendieremmo": "stipendiare",
    "stipendieremo": "stipendiare",
    "stipendiereste": "stipendiare",
    "stipendieresti": "stipendiare",
    "stipendierete": "stipendiare",
    "stipendierà": "stipendiare",
    "stipendierò": "stipendiare",
    "stipendin": "stipendiare",
    "stipendino": "stipendiare",
    "stipendio": "stipendiare",
    "stipendiò": "stipendiare",
    "stiperai": "stipare",
    "stiperan": "stipare",
    "stiperanno": "stipare",
    "stiperebbe": "stipare",
    "stiperebber": "stipare",
    "stiperebbero": "stipare",
    "stiperei": "stipare",
    "stiperemmo": "stipare",
    "stiperemo": "stipare",
    "stipereste": "stipare",
    "stiperesti": "stipare",
    "stiperete": "stipare",
    "stiperà": "stipare",
    "stiperò": "stipare",
    "stipi": "stipare",
    "stipiamo": "stipare",
    "stipiate": "stipare",
    "stipin": "stipare",
    "stipino": "stipare",
    "stipiti": "stipite",
    "stipo": "stipare",
    "stipula": "stipulare",
    "stipulai": "stipulare",
    "stipulammo": "stipulare",
    "stipulan": "stipulare",
    "stipulando": "stipulare",
    "stipulano": "stipulare",
    "stipulante": "stipulare",
    "stipulanti": "stipulare",
    "stipular": "stipulare",
    "stipularon": "stipulare",
    "stipularono": "stipulare",
    "stipulasse": "stipulare",
    "stipulasser": "stipulare",
    "stipulassero": "stipulare",
    "stipulassi": "stipulare",
    "stipulassimo": "stipulare",
    "stipulaste": "stipulare",
    "stipulasti": "stipulare",
    "stipulata": "stipulare",
    "stipulate": "stipulare",
    "stipulati": "stipulare",
    "stipulato": "stipulare",
    "stipulava": "stipulare",
    "stipulavamo": "stipulare",
    "stipulavan": "stipulare",
    "stipulavano": "stipulare",
    "stipulavate": "stipulare",
    "stipulavi": "stipulare",
    "stipulavo": "stipulare",
    "stipulazioni": "stipulazione",
    "stipulerai": "stipulare",
    "stipuleran": "stipulare",
    "stipuleranno": "stipulare",
    "stipulerebbe": "stipulare",
    "stipulerebber": "stipulare",
    "stipulerebbero": "stipulare",
    "stipulerei": "stipulare",
    "stipuleremmo": "stipulare",
    "stipuleremo": "stipulare",
    "stipulereste": "stipulare",
    "stipuleresti": "stipulare",
    "stipulerete": "stipulare",
    "stipulerà": "stipulare",
    "stipulerò": "stipulare",
    "stipuli": "stipulare",
    "stipuliamo": "stipulare",
    "stipuliate": "stipulare",
    "stipulin": "stipulare",
    "stipulino": "stipulare",
    "stipulo": "stipulare",
    "stipulò": "stipulare",
    "stipò": "stipare",
    "stira": "stirare",
    "stiracchi": "stiracchiare",
    "stiracchia": "stiracchiare",
    "stiracchiai": "stiracchiare",
    "stiracchiammo": "stiracchiare",
    "stiracchiamo": "stiracchiare",
    "stiracchian": "stiracchiare",
    "stiracchiando": "stiracchiare",
    "stiracchiano": "stiracchiare",
    "stiracchiante": "stiracchiare",
    "stiracchianti": "stiracchiare",
    "stiracchiar": "stiracchiare",
    "stiracchiaron": "stiracchiare",
    "stiracchiarono": "stiracchiare",
    "stiracchiasse": "stiracchiare",
    "stiracchiasser": "stiracchiare",
    "stiracchiassero": "stiracchiare",
    "stiracchiassi": "stiracchiare",
    "stiracchiassimo": "stiracchiare",
    "stiracchiaste": "stiracchiare",
    "stiracchiasti": "stiracchiare",
    "stiracchiata": "stiracchiato",
    "stiracchiate": "stiracchiato",
    "stiracchiati": "stiracchiato",
    "stiracchiato": "stiracchiare",
    "stiracchiava": "stiracchiare",
    "stiracchiavamo": "stiracchiare",
    "stiracchiavan": "stiracchiare",
    "stiracchiavano": "stiracchiare",
    "stiracchiavate": "stiracchiare",
    "stiracchiavi": "stiracchiare",
    "stiracchiavo": "stiracchiare",
    "stiracchierai": "stiracchiare",
    "stiracchieran": "stiracchiare",
    "stiracchieranno": "stiracchiare",
    "stiracchierebbe": "stiracchiare",
    "stiracchierebber": "stiracchiare",
    "stiracchierebbero": "stiracchiare",
    "stiracchierei": "stiracchiare",
    "stiracchieremmo": "stiracchiare",
    "stiracchieremo": "stiracchiare",
    "stiracchiereste": "stiracchiare",
    "stiracchieresti": "stiracchiare",
    "stiracchierete": "stiracchiare",
    "stiracchierà": "stiracchiare",
    "stiracchierò": "stiracchiare",
    "stiracchin": "stiracchiare",
    "stiracchino": "stiracchiare",
    "stiracchio": "stiracchiare",
    "stiracchiò": "stiracchiare",
    "stirai": "stirare",
    "stiramenti": "stiramento",
    "stirammo": "stirare",
    "stiran": "stirare",
    "stirando": "stirare",
    "stirano": "stirare",
    "stirante": "stirare",
    "stiranti": "stirare",
    "stirar": "stirare",
    "stiraron": "stirare",
    "stirarono": "stirare",
    "stirasse": "stirare",
    "stirasser": "stirare",
    "stirassero": "stirare",
    "stirassi": "stirare",
    "stirassimo": "stirare",
    "stiraste": "stirare",
    "stirasti": "stirare",
    "stirata": "stirare",
    "stirate": "stirare",
    "stirati": "stirare",
    "stirato": "stirare",
    "stirava": "stirare",
    "stiravamo": "stirare",
    "stiravan": "stirare",
    "stiravano": "stirare",
    "stiravate": "stirare",
    "stiravi": "stirare",
    "stiravo": "stirare",
    "stirerai": "stirare",
    "stireran": "stirare",
    "stireranno": "stirare",
    "stirerebbe": "stirare",
    "stirerebber": "stirare",
    "stirerebbero": "stirare",
    "stirerei": "stirare",
    "stireremmo": "stirare",
    "stireremo": "stirare",
    "stirereste": "stirare",
    "stireresti": "stirare",
    "stirerete": "stirare",
    "stirerà": "stirare",
    "stirerò": "stirare",
    "stiri": "stirare",
    "stiriamo": "stirare",
    "stiriate": "stirare",
    "stirin": "stirare",
    "stirino": "stirare",
    "stiro": "stirare",
    "stirpi": "stirpe",
    "stirò": "stirare",
    "stitica": "stitico",
    "stitiche": "stitico",
    "stitichezze": "stitichezza",
    "stitici": "stitico",
    "stiva": "stivare",
    "stivai": "stivare",
    "stivaletti": "stivaletto",
    "stivali": "stivale",
    "stivaloni": "stivalone",
    "stivammo": "stivare",
    "stivan": "stivare",
    "stivando": "stivare",
    "stivano": "stivare",
    "stivante": "stivare",
    "stivanti": "stivare",
    "stivar": "stivare",
    "stivaron": "stivare",
    "stivarono": "stivare",
    "stivasse": "stivare",
    "stivasser": "stivare",
    "stivassero": "stivare",
    "stivassi": "stivare",
    "stivassimo": "stivare",
    "stivaste": "stivare",
    "stivasti": "stivare",
    "stivata": "stivare",
    "stivate": "stivare",
    "stivati": "stivare",
    "stivato": "stivare",
    "stivava": "stivare",
    "stivavamo": "stivare",
    "stivavan": "stivare",
    "stivavano": "stivare",
    "stivavate": "stivare",
    "stivavi": "stivare",
    "stivavo": "stivare",
    "stive": "stiva",
    "stiverai": "stivare",
    "stiveran": "stivare",
    "stiveranno": "stivare",
    "stiverebbe": "stivare",
    "stiverebber": "stivare",
    "stiverebbero": "stivare",
    "stiverei": "stivare",
    "stiveremmo": "stivare",
    "stiveremo": "stivare",
    "stivereste": "stivare",
    "stiveresti": "stivare",
    "stiverete": "stivare",
    "stiverà": "stivare",
    "stiverò": "stivare",
    "stivi": "stivare",
    "stiviamo": "stivare",
    "stiviate": "stivare",
    "stivin": "stivare",
    "stivino": "stivare",
    "stivo": "stivare",
    "stivò": "stivare",
    "stizza": "stizzire",
    "stizzan": "stizzire",
    "stizzano": "stizzire",
    "stizze": "stizzire",
    "stizzendo": "stizzire",
    "stizzente": "stizzire",
    "stizzenti": "stizzire",
    "stizzi": "stizzire",
    "stizziamo": "stizzire",
    "stizziate": "stizzire",
    "stizzii": "stizzire",
    "stizzimmo": "stizzire",
    "stizzir": "stizzire",
    "stizzirai": "stizzire",
    "stizziran": "stizzire",
    "stizziranno": "stizzire",
    "stizzirebbe": "stizzire",
    "stizzirebber": "stizzire",
    "stizzirebbero": "stizzire",
    "stizzirei": "stizzire",
    "stizziremmo": "stizzire",
    "stizziremo": "stizzire",
    "stizzireste": "stizzire",
    "stizziresti": "stizzire",
    "stizzirete": "stizzire",
    "stizziron": "stizzire",
    "stizzirono": "stizzire",
    "stizzirà": "stizzire",
    "stizzirò": "stizzire",
    "stizzisse": "stizzire",
    "stizzisser": "stizzire",
    "stizzissero": "stizzire",
    "stizzissi": "stizzire",
    "stizzissimo": "stizzire",
    "stizziste": "stizzire",
    "stizzisti": "stizzire",
    "stizzita": "stizzire",
    "stizzite": "stizzire",
    "stizziti": "stizzire",
    "stizzito": "stizzire",
    "stizziva": "stizzire",
    "stizzivamo": "stizzire",
    "stizzivan": "stizzire",
    "stizzivano": "stizzire",
    "stizzivate": "stizzire",
    "stizzivi": "stizzire",
    "stizzivo": "stizzire",
    "stizzo": "stizzire",
    "stizzon": "stizzire",
    "stizzono": "stizzire",
    "stizzosa": "stizzoso",
    "stizzose": "stizzoso",
    "stizzosi": "stizzoso",
    "stizzì": "stizzire",
    "sto": "stare",
    "stocastica": "stocastico",
    "stocastiche": "stocastico",
    "stocastici": "stocastico",
    "stocca": "stoccare",
    "stoccaggi": "stoccaggio",
    "stoccai": "stoccare",
    "stoccammo": "stoccare",
    "stoccan": "stoccare",
    "stoccando": "stoccare",
    "stoccano": "stoccare",
    "stoccante": "stoccare",
    "stoccanti": "stoccare",
    "stoccar": "stoccare",
    "stoccaron": "stoccare",
    "stoccarono": "stoccare",
    "stoccasse": "stoccare",
    "stoccasser": "stoccare",
    "stoccassero": "stoccare",
    "stoccassi": "stoccare",
    "stoccassimo": "stoccare",
    "stoccaste": "stoccare",
    "stoccasti": "stoccare",
    "stoccata": "stoccare",
    "stoccate": "stoccata",
    "stoccati": "stoccare",
    "stoccato": "stoccare",
    "stoccava": "stoccare",
    "stoccavamo": "stoccare",
    "stoccavan": "stoccare",
    "stoccavano": "stoccare",
    "stoccavate": "stoccare",
    "stoccavi": "stoccare",
    "stoccavo": "stoccare",
    "stoccherai": "stoccare",
    "stoccheran": "stoccare",
    "stoccheranno": "stoccare",
    "stoccherebbe": "stoccare",
    "stoccherebber": "stoccare",
    "stoccherebbero": "stoccare",
    "stoccherei": "stoccare",
    "stoccheremmo": "stoccare",
    "stoccheremo": "stoccare",
    "stocchereste": "stoccare",
    "stoccheresti": "stoccare",
    "stoccherete": "stoccare",
    "stoccherà": "stoccare",
    "stoccherò": "stoccare",
    "stocchi": "stoccare",
    "stocchiamo": "stoccare",
    "stocchiate": "stoccare",
    "stocchin": "stoccare",
    "stocchino": "stoccare",
    "stocco": "stoccare",
    "stoccò": "stoccare",
    "stoffe": "stoffa",
    "stoica": "stoico",
    "stoiche": "stoico",
    "stoici": "stoico",
    "stole": "stola",
    "stolida": "stolido",
    "stolide": "stolido",
    "stolidi": "stolido",
    "stolta": "stolto",
    "stolte": "stolto",
    "stoltezze": "stoltezza",
    "stolti": "stolto",
    "stomaca": "stomacare",
    "stomacai": "stomacare",
    "stomacammo": "stomacare",
    "stomacan": "stomacare",
    "stomacando": "stomacare",
    "stomacano": "stomacare",
    "stomacante": "stomacare",
    "stomacanti": "stomacare",
    "stomacar": "stomacare",
    "stomacaron": "stomacare",
    "stomacarono": "stomacare",
    "stomacasse": "stomacare",
    "stomacasser": "stomacare",
    "stomacassero": "stomacare",
    "stomacassi": "stomacare",
    "stomacassimo": "stomacare",
    "stomacaste": "stomacare",
    "stomacasti": "stomacare",
    "stomacata": "stomacare",
    "stomacate": "stomacare",
    "stomacati": "stomacare",
    "stomacato": "stomacare",
    "stomacava": "stomacare",
    "stomacavamo": "stomacare",
    "stomacavan": "stomacare",
    "stomacavano": "stomacare",
    "stomacavate": "stomacare",
    "stomacavi": "stomacare",
    "stomacavo": "stomacare",
    "stomacherai": "stomacare",
    "stomacheran": "stomacare",
    "stomacheranno": "stomacare",
    "stomacherebbe": "stomacare",
    "stomacherebber": "stomacare",
    "stomacherebbero": "stomacare",
    "stomacherei": "stomacare",
    "stomacheremmo": "stomacare",
    "stomacheremo": "stomacare",
    "stomachereste": "stomacare",
    "stomacheresti": "stomacare",
    "stomacherete": "stomacare",
    "stomacherà": "stomacare",
    "stomacherò": "stomacare",
    "stomachevoli": "stomachevole",
    "stomachi": "stomacare",
    "stomachiamo": "stomacare",
    "stomachiate": "stomacare",
    "stomachin": "stomacare",
    "stomachino": "stomacare",
    "stomaci": "stomaco",
    "stomaco": "stomacare",
    "stomacò": "stomacare",
    "stona": "stonare",
    "stonai": "stonare",
    "stonammo": "stonare",
    "stonan": "stonare",
    "stonando": "stonare",
    "stonano": "stonare",
    "stonante": "stonare",
    "stonanti": "stonare",
    "stonar": "stonare",
    "stonaron": "stonare",
    "stonarono": "stonare",
    "stonasse": "stonare",
    "stonasser": "stonare",
    "stonassero": "stonare",
    "stonassi": "stonare",
    "stonassimo": "stonare",
    "stonaste": "stonare",
    "stonasti": "stonare",
    "stonata": "stonato",
    "stonate": "stonato",
    "stonati": "stonato",
    "stonato": "stonare",
    "stonature": "stonatura",
    "stonava": "stonare",
    "stonavamo": "stonare",
    "stonavan": "stonare",
    "stonavano": "stonare",
    "stonavate": "stonare",
    "stonavi": "stonare",
    "stonavo": "stonare",
    "stonerai": "stonare",
    "stoneran": "stonare",
    "stoneranno": "stonare",
    "stonerebbe": "stonare",
    "stonerebber": "stonare",
    "stonerebbero": "stonare",
    "stonerei": "stonare",
    "stoneremmo": "stonare",
    "stoneremo": "stonare",
    "stonereste": "stonare",
    "stoneresti": "stonare",
    "stonerete": "stonare",
    "stonerà": "stonare",
    "stonerò": "stonare",
    "stoni": "stonare",
    "stoniamo": "stonare",
    "stoniate": "stonare",
    "stonin": "stonare",
    "stonino": "stonare",
    "stono": "stonare",
    "stonò": "stonare",
    "stoppa": "stoppare",
    "stoppai": "stoppare",
    "stoppammo": "stoppare",
    "stoppan": "stoppare",
    "stoppando": "stoppare",
    "stoppano": "stoppare",
    "stoppante": "stoppare",
    "stoppanti": "stoppare",
    "stoppar": "stoppare",
    "stopparon": "stoppare",
    "stopparono": "stoppare",
    "stoppasse": "stoppare",
    "stoppasser": "stoppare",
    "stoppassero": "stoppare",
    "stoppassi": "stoppare",
    "stoppassimo": "stoppare",
    "stoppaste": "stoppare",
    "stoppasti": "stoppare",
    "stoppata": "stoppare",
    "stoppate": "stoppata",
    "stoppati": "stoppare",
    "stoppato": "stoppare",
    "stoppava": "stoppare",
    "stoppavamo": "stoppare",
    "stoppavan": "stoppare",
    "stoppavano": "stoppare",
    "stoppavate": "stoppare",
    "stoppavi": "stoppare",
    "stoppavo": "stoppare",
    "stopperai": "stoppare",
    "stopperan": "stoppare",
    "stopperanno": "stoppare",
    "stopperebbe": "stoppare",
    "stopperebber": "stoppare",
    "stopperebbero": "stoppare",
    "stopperei": "stoppare",
    "stopperemmo": "stoppare",
    "stopperemo": "stoppare",
    "stoppereste": "stoppare",
    "stopperesti": "stoppare",
    "stopperete": "stoppare",
    "stopperà": "stoppare",
    "stopperò": "stoppare",
    "stoppi": "stoppare",
    "stoppiamo": "stoppare",
    "stoppiate": "stoppare",
    "stoppin": "stoppare",
    "stoppino": "stoppare",
    "stoppo": "stoppare",
    "stopposa": "stopposo",
    "stoppose": "stopposo",
    "stopposi": "stopposo",
    "stoppò": "stoppare",
    "storca": "storcere",
    "storcan": "storcere",
    "storcano": "storcere",
    "storce": "storcere",
    "storcemmo": "storcere",
    "storcendo": "storcere",
    "storcente": "storcere",
    "storcenti": "storcere",
    "storcer": "storcere",
    "storcerai": "storcere",
    "storceran": "storcere",
    "storceranno": "storcere",
    "storcerebbe": "storcere",
    "storcerebber": "storcere",
    "storcerebbero": "storcere",
    "storcerei": "storcere",
    "storceremmo": "storcere",
    "storceremo": "storcere",
    "storcereste": "storcere",
    "storceresti": "storcere",
    "storcerete": "storcere",
    "storcerà": "storcere",
    "storcerò": "storcere",
    "storcesse": "storcere",
    "storcesser": "storcere",
    "storcessero": "storcere",
    "storcessi": "storcere",
    "storcessimo": "storcere",
    "storceste": "storcere",
    "storcesti": "storcere",
    "storcete": "storcere",
    "storceva": "storcere",
    "storcevamo": "storcere",
    "storcevan": "storcere",
    "storcevano": "storcere",
    "storcevate": "storcere",
    "storcevi": "storcere",
    "storcevo": "storcere",
    "storci": "storcere",
    "storciamo": "storcere",
    "storciate": "storcere",
    "storco": "storcere",
    "storcon": "storcere",
    "storcono": "storcere",
    "stordendo": "stordire",
    "stordente": "stordire",
    "stordenti": "stordire",
    "stordiamo": "stordire",
    "stordiate": "stordire",
    "stordii": "stordire",
    "stordimenti": "stordimento",
    "stordimmo": "stordire",
    "stordir": "stordire",
    "stordirai": "stordire",
    "stordiran": "stordire",
    "stordiranno": "stordire",
    "stordirebbe": "stordire",
    "stordirebber": "stordire",
    "stordirebbero": "stordire",
    "stordirei": "stordire",
    "stordiremmo": "stordire",
    "stordiremo": "stordire",
    "stordireste": "stordire",
    "stordiresti": "stordire",
    "stordirete": "stordire",
    "stordiron": "stordire",
    "stordirono": "stordire",
    "stordirà": "stordire",
    "stordirò": "stordire",
    "stordisca": "stordire",
    "stordiscan": "stordire",
    "stordiscano": "stordire",
    "stordisce": "stordire",
    "stordisci": "stordire",
    "stordisco": "stordire",
    "stordiscon": "stordire",
    "stordiscono": "stordire",
    "stordisse": "stordire",
    "stordisser": "stordire",
    "stordissero": "stordire",
    "stordissi": "stordire",
    "stordissimo": "stordire",
    "stordiste": "stordire",
    "stordisti": "stordire",
    "stordita": "stordito",
    "stordite": "stordito",
    "storditi": "stordito",
    "stordito": "stordire",
    "stordiva": "stordire",
    "stordivamo": "stordire",
    "stordivan": "stordire",
    "stordivano": "stordire",
    "stordivate": "stordire",
    "stordivi": "stordire",
    "stordivo": "stordire",
    "stordì": "stordire",
    "storiacce": "storiaccia",
    "storica": "storico",
    "storiche": "storico",
    "storici": "storico",
    "storicismi": "storicismo",
    "storicisti": "storicista",
    "storicizza": "storicizzare",
    "storicizzai": "storicizzare",
    "storicizzammo": "storicizzare",
    "storicizzan": "storicizzare",
    "storicizzando": "storicizzare",
    "storicizzano": "storicizzare",
    "storicizzante": "storicizzare",
    "storicizzanti": "storicizzare",
    "storicizzar": "storicizzare",
    "storicizzaron": "storicizzare",
    "storicizzarono": "storicizzare",
    "storicizzasse": "storicizzare",
    "storicizzasser": "storicizzare",
    "storicizzassero": "storicizzare",
    "storicizzassi": "storicizzare",
    "storicizzassimo": "storicizzare",
    "storicizzaste": "storicizzare",
    "storicizzasti": "storicizzare",
    "storicizzata": "storicizzare",
    "storicizzate": "storicizzare",
    "storicizzati": "storicizzare",
    "storicizzato": "storicizzare",
    "storicizzava": "storicizzare",
    "storicizzavamo": "storicizzare",
    "storicizzavan": "storicizzare",
    "storicizzavano": "storicizzare",
    "storicizzavate": "storicizzare",
    "storicizzavi": "storicizzare",
    "storicizzavo": "storicizzare",
    "storicizzerai": "storicizzare",
    "storicizzeran": "storicizzare",
    "storicizzeranno": "storicizzare",
    "storicizzerebbe": "storicizzare",
    "storicizzerebber": "storicizzare",
    "storicizzerebbero": "storicizzare",
    "storicizzerei": "storicizzare",
    "storicizzeremmo": "storicizzare",
    "storicizzeremo": "storicizzare",
    "storicizzereste": "storicizzare",
    "storicizzeresti": "storicizzare",
    "storicizzerete": "storicizzare",
    "storicizzerà": "storicizzare",
    "storicizzerò": "storicizzare",
    "storicizzi": "storicizzare",
    "storicizziamo": "storicizzare",
    "storicizziate": "storicizzare",
    "storicizzin": "storicizzare",
    "storicizzino": "storicizzare",
    "storicizzo": "storicizzare",
    "storicizzò": "storicizzare",
    "storico-aneddotica": "storico-aneddotico",
    "storico-aneddotiche": "storico-aneddotico",
    "storico-aneddotici": "storico-aneddotico",
    "storico-artistica": "storico-artistico",
    "storico-artistiche": "storico-artistico",
    "storico-artistici": "storico-artistico",
    "storico-culturali": "storico-culturale",
    "storico-etnografica": "storico-etnografico",
    "storico-etnografiche": "storico-etnografico",
    "storico-etnografici": "storico-etnografico",
    "storico-politica": "storico-politico",
    "storico-politiche": "storico-politico",
    "storico-politici": "storico-politico",
    "storie": "storia",
    "storielle": "storiella",
    "storielline": "storiellina",
    "storiografi": "storiografo",
    "storiografica": "storiografico",
    "storiografiche": "storiografico",
    "storiografici": "storiografico",
    "storiografie": "storiografia",
    "storioni": "storione",
    "storma": "stormire",
    "storman": "stormire",
    "stormano": "stormire",
    "storme": "stormire",
    "stormendo": "stormire",
    "stormente": "stormire",
    "stormenti": "stormire",
    "stormi": "stormo",
    "stormiamo": "stormire",
    "stormiate": "stormire",
    "stormii": "stormire",
    "stormimmo": "stormire",
    "stormir": "stormire",
    "stormirai": "stormire",
    "stormiran": "stormire",
    "stormiranno": "stormire",
    "stormirebbe": "stormire",
    "stormirebber": "stormire",
    "stormirebbero": "stormire",
    "stormirei": "stormire",
    "stormiremmo": "stormire",
    "stormiremo": "stormire",
    "stormireste": "stormire",
    "stormiresti": "stormire",
    "stormirete": "stormire",
    "stormiron": "stormire",
    "stormirono": "stormire",
    "stormirà": "stormire",
    "stormirò": "stormire",
    "stormisse": "stormire",
    "stormisser": "stormire",
    "stormissero": "stormire",
    "stormissi": "stormire",
    "stormissimo": "stormire",
    "stormiste": "stormire",
    "stormisti": "stormire",
    "stormita": "stormire",
    "stormite": "stormire",
    "stormiti": "stormire",
    "stormito": "stormire",
    "stormiva": "stormire",
    "stormivamo": "stormire",
    "stormivan": "stormire",
    "stormivano": "stormire",
    "stormivate": "stormire",
    "stormivi": "stormire",
    "stormivo": "stormire",
    "stormo": "stormire",
    "stormon": "stormire",
    "stormono": "stormire",
    "stormì": "stormire",
    "storna": "storno",
    "stornai": "stornare",
    "stornammo": "stornare",
    "stornan": "stornare",
    "stornando": "stornare",
    "stornano": "stornare",
    "stornante": "stornare",
    "stornanti": "stornare",
    "stornar": "stornare",
    "stornaron": "stornare",
    "stornarono": "stornare",
    "stornasse": "stornare",
    "stornasser": "stornare",
    "stornassero": "stornare",
    "stornassi": "stornare",
    "stornassimo": "stornare",
    "stornaste": "stornare",
    "stornasti": "stornare",
    "stornata": "stornare",
    "stornate": "stornare",
    "stornati": "stornare",
    "stornato": "stornare",
    "stornava": "stornare",
    "stornavamo": "stornare",
    "stornavan": "stornare",
    "stornavano": "stornare",
    "stornavate": "stornare",
    "stornavi": "stornare",
    "stornavo": "stornare",
    "storne": "storno",
    "stornella": "stornellare",
    "stornellai": "stornellare",
    "stornellammo": "stornellare",
    "stornellan": "stornellare",
    "stornellando": "stornellare",
    "stornellano": "stornellare",
    "stornellante": "stornellare",
    "stornellanti": "stornellare",
    "stornellar": "stornellare",
    "stornellaron": "stornellare",
    "stornellarono": "stornellare",
    "stornellasse": "stornellare",
    "stornellasser": "stornellare",
    "stornellassero": "stornellare",
    "stornellassi": "stornellare",
    "stornellassimo": "stornellare",
    "stornellaste": "stornellare",
    "stornellasti": "stornellare",
    "stornellata": "stornellare",
    "stornellate": "stornellare",
    "stornellati": "stornellare",
    "stornellato": "stornellare",
    "stornellava": "stornellare",
    "stornellavamo": "stornellare",
    "stornellavan": "stornellare",
    "stornellavano": "stornellare",
    "stornellavate": "stornellare",
    "stornellavi": "stornellare",
    "stornellavo": "stornellare",
    "stornellerai": "stornellare",
    "stornelleran": "stornellare",
    "stornelleranno": "stornellare",
    "stornellerebbe": "stornellare",
    "stornellerebber": "stornellare",
    "stornellerebbero": "stornellare",
    "stornellerei": "stornellare",
    "stornelleremmo": "stornellare",
    "stornelleremo": "stornellare",
    "stornellereste": "stornellare",
    "stornelleresti": "stornellare",
    "stornellerete": "stornellare",
    "stornellerà": "stornellare",
    "stornellerò": "stornellare",
    "stornelli": "stornello",
    "stornelliamo": "stornellare",
    "stornelliate": "stornellare",
    "stornellin": "stornellare",
    "stornellino": "stornellare",
    "stornello": "stornellare",
    "stornellò": "stornellare",
    "stornerai": "stornare",
    "storneran": "stornare",
    "storneranno": "stornare",
    "stornerebbe": "stornare",
    "stornerebber": "stornare",
    "stornerebbero": "stornare",
    "stornerei": "stornare",
    "storneremmo": "stornare",
    "storneremo": "stornare",
    "stornereste": "stornare",
    "storneresti": "stornare",
    "stornerete": "stornare",
    "stornerà": "stornare",
    "stornerò": "stornare",
    "storni": "storno",
    "storniamo": "stornare",
    "storniate": "stornare",
    "stornin": "stornare",
    "stornino": "stornare",
    "storno": "stornare",
    "stornò": "stornare",
    "storpi": "storpio",
    "storpia": "storpio",
    "storpiai": "storpiare",
    "storpiammo": "storpiare",
    "storpiamo": "storpiare",
    "storpian": "storpiare",
    "storpiando": "storpiare",
    "storpiano": "storpiare",
    "storpiante": "storpiare",
    "storpianti": "storpiare",
    "storpiar": "storpiare",
    "storpiaron": "storpiare",
    "storpiarono": "storpiare",
    "storpiasse": "storpiare",
    "storpiasser": "storpiare",
    "storpiassero": "storpiare",
    "storpiassi": "storpiare",
    "storpiassimo": "storpiare",
    "storpiaste": "storpiare",
    "storpiasti": "storpiare",
    "storpiata": "storpiare",
    "storpiate": "storpiare",
    "storpiati": "storpiare",
    "storpiato": "storpiare",
    "storpiature": "storpiatura",
    "storpiava": "storpiare",
    "storpiavamo": "storpiare",
    "storpiavan": "storpiare",
    "storpiavano": "storpiare",
    "storpiavate": "storpiare",
    "storpiavi": "storpiare",
    "storpiavo": "storpiare",
    "storpie": "storpio",
    "storpierai": "storpiare",
    "storpieran": "storpiare",
    "storpieranno": "storpiare",
    "storpierebbe": "storpiare",
    "storpierebber": "storpiare",
    "storpierebbero": "storpiare",
    "storpierei": "storpiare",
    "storpieremmo": "storpiare",
    "storpieremo": "storpiare",
    "storpiereste": "storpiare",
    "storpieresti": "storpiare",
    "storpierete": "storpiare",
    "storpierà": "storpiare",
    "storpierò": "storpiare",
    "storpin": "storpiare",
    "storpino": "storpiare",
    "storpio": "storpiare",
    "storpiò": "storpiare",
    "storse": "storcere",
    "storser": "storcere",
    "storsero": "storcere",
    "storsi": "storcere",
    "storta": "storto",
    "storte": "storto",
    "storti": "storto",
    "storto": "storcere",
    "storture": "stortura",
    "strabica": "strabico",
    "strabiche": "strabico",
    "strabici": "strabico",
    "strabili": "strabiliare",
    "strabilia": "strabiliare",
    "strabiliai": "strabiliare",
    "strabiliammo": "strabiliare",
    "strabiliamo": "strabiliare",
    "strabilian": "strabiliare",
    "strabiliando": "strabiliare",
    "strabiliano": "strabiliare",
    "strabiliante": "strabiliare",
    "strabilianti": "strabiliare",
    "strabiliar": "strabiliare",
    "strabiliaron": "strabiliare",
    "strabiliarono": "strabiliare",
    "strabiliasse": "strabiliare",
    "strabiliasser": "strabiliare",
    "strabiliassero": "strabiliare",
    "strabiliassi": "strabiliare",
    "strabiliassimo": "strabiliare",
    "strabiliaste": "strabiliare",
    "strabiliasti": "strabiliare",
    "strabiliata": "strabiliare",
    "strabiliate": "strabiliare",
    "strabiliati": "strabiliare",
    "strabiliato": "strabiliare",
    "strabiliava": "strabiliare",
    "strabiliavamo": "strabiliare",
    "strabiliavan": "strabiliare",
    "strabiliavano": "strabiliare",
    "strabiliavate": "strabiliare",
    "strabiliavi": "strabiliare",
    "strabiliavo": "strabiliare",
    "strabilierai": "strabiliare",
    "strabilieran": "strabiliare",
    "strabilieranno": "strabiliare",
    "strabilierebbe": "strabiliare",
    "strabilierebber": "strabiliare",
    "strabilierebbero": "strabiliare",
    "strabilierei": "strabiliare",
    "strabilieremmo": "strabiliare",
    "strabilieremo": "strabiliare",
    "strabiliereste": "strabiliare",
    "strabilieresti": "strabiliare",
    "strabilierete": "strabiliare",
    "strabilierà": "strabiliare",
    "strabilierò": "strabiliare",
    "strabilin": "strabiliare",
    "strabilino": "strabiliare",
    "strabilio": "strabiliare",
    "strabiliò": "strabiliare",
    "strabismi": "strabismo",
    "strabocca": "straboccare",
    "straboccai": "straboccare",
    "straboccammo": "straboccare",
    "straboccan": "straboccare",
    "straboccando": "straboccare",
    "straboccano": "straboccare",
    "straboccante": "straboccare",
    "straboccanti": "straboccare",
    "straboccar": "straboccare",
    "straboccaron": "straboccare",
    "straboccarono": "straboccare",
    "straboccasse": "straboccare",
    "straboccasser": "straboccare",
    "straboccassero": "straboccare",
    "straboccassi": "straboccare",
    "straboccassimo": "straboccare",
    "straboccaste": "straboccare",
    "straboccasti": "straboccare",
    "straboccata": "straboccare",
    "straboccate": "straboccare",
    "straboccati": "straboccare",
    "straboccato": "straboccare",
    "straboccava": "straboccare",
    "straboccavamo": "straboccare",
    "straboccavan": "straboccare",
    "straboccavano": "straboccare",
    "straboccavate": "straboccare",
    "straboccavi": "straboccare",
    "straboccavo": "straboccare",
    "straboccherai": "straboccare",
    "straboccheran": "straboccare",
    "straboccheranno": "straboccare",
    "straboccherebbe": "straboccare",
    "straboccherebber": "straboccare",
    "straboccherebbero": "straboccare",
    "straboccherei": "straboccare",
    "straboccheremmo": "straboccare",
    "straboccheremo": "straboccare",
    "strabocchereste": "straboccare",
    "straboccheresti": "straboccare",
    "straboccherete": "straboccare",
    "straboccherà": "straboccare",
    "straboccherò": "straboccare",
    "strabocchevoli": "strabocchevole",
    "strabocchi": "straboccare",
    "strabocchiamo": "straboccare",
    "strabocchiate": "straboccare",
    "strabocchin": "straboccare",
    "strabocchino": "straboccare",
    "strabocco": "straboccare",
    "straboccò": "straboccare",
    "strabuzza": "strabuzzare",
    "strabuzzai": "strabuzzare",
    "strabuzzammo": "strabuzzare",
    "strabuzzan": "strabuzzare",
    "strabuzzando": "strabuzzare",
    "strabuzzano": "strabuzzare",
    "strabuzzante": "strabuzzare",
    "strabuzzanti": "strabuzzare",
    "strabuzzar": "strabuzzare",
    "strabuzzaron": "strabuzzare",
    "strabuzzarono": "strabuzzare",
    "strabuzzasse": "strabuzzare",
    "strabuzzasser": "strabuzzare",
    "strabuzzassero": "strabuzzare",
    "strabuzzassi": "strabuzzare",
    "strabuzzassimo": "strabuzzare",
    "strabuzzaste": "strabuzzare",
    "strabuzzasti": "strabuzzare",
    "strabuzzata": "strabuzzare",
    "strabuzzate": "strabuzzare",
    "strabuzzati": "strabuzzare",
    "strabuzzato": "strabuzzare",
    "strabuzzava": "strabuzzare",
    "strabuzzavamo": "strabuzzare",
    "strabuzzavan": "strabuzzare",
    "strabuzzavano": "strabuzzare",
    "strabuzzavate": "strabuzzare",
    "strabuzzavi": "strabuzzare",
    "strabuzzavo": "strabuzzare",
    "strabuzzerai": "strabuzzare",
    "strabuzzeran": "strabuzzare",
    "strabuzzeranno": "strabuzzare",
    "strabuzzerebbe": "strabuzzare",
    "strabuzzerebber": "strabuzzare",
    "strabuzzerebbero": "strabuzzare",
    "strabuzzerei": "strabuzzare",
    "strabuzzeremmo": "strabuzzare",
    "strabuzzeremo": "strabuzzare",
    "strabuzzereste": "strabuzzare",
    "strabuzzeresti": "strabuzzare",
    "strabuzzerete": "strabuzzare",
    "strabuzzerà": "strabuzzare",
    "strabuzzerò": "strabuzzare",
    "strabuzzi": "strabuzzare",
    "strabuzziamo": "strabuzzare",
    "strabuzziate": "strabuzzare",
    "strabuzzin": "strabuzzare",
    "strabuzzino": "strabuzzare",
    "strabuzzo": "strabuzzare",
    "strabuzzò": "strabuzzare",
    "stracarica": "stracarico",
    "stracariche": "stracarico",
    "stracarici": "stracarico",
    "stracca": "straccare",
    "straccai": "straccare",
    "straccali": "straccale",
    "straccammo": "straccare",
    "straccan": "straccare",
    "straccando": "straccare",
    "straccano": "straccare",
    "straccante": "straccare",
    "straccanti": "straccare",
    "straccar": "straccare",
    "straccaron": "straccare",
    "straccarono": "straccare",
    "straccasse": "straccare",
    "straccasser": "straccare",
    "straccassero": "straccare",
    "straccassi": "straccare",
    "straccassimo": "straccare",
    "straccaste": "straccare",
    "straccasti": "straccare",
    "straccata": "straccare",
    "straccate": "straccare",
    "straccati": "straccare",
    "straccato": "straccare",
    "straccava": "straccare",
    "straccavamo": "straccare",
    "straccavan": "straccare",
    "straccavano": "straccare",
    "straccavate": "straccare",
    "straccavi": "straccare",
    "straccavo": "straccare",
    "stracce": "straccio",
    "straccerai": "stracciare",
    "stracceran": "stracciare",
    "stracceranno": "stracciare",
    "straccerebbe": "stracciare",
    "straccerebber": "stracciare",
    "straccerebbero": "stracciare",
    "straccerei": "stracciare",
    "stracceremmo": "stracciare",
    "stracceremo": "stracciare",
    "straccereste": "stracciare",
    "stracceresti": "stracciare",
    "straccerete": "stracciare",
    "straccerà": "stracciare",
    "straccerò": "stracciare",
    "straccherai": "straccare",
    "straccheran": "straccare",
    "straccheranno": "straccare",
    "straccherebbe": "straccare",
    "straccherebber": "straccare",
    "straccherebbero": "straccare",
    "straccherei": "straccare",
    "straccheremmo": "straccare",
    "straccheremo": "straccare",
    "stracchereste": "straccare",
    "straccheresti": "straccare",
    "straccherete": "straccare",
    "straccherà": "straccare",
    "straccherò": "straccare",
    "stracchi": "straccare",
    "stracchiamo": "straccare",
    "stracchiate": "straccare",
    "stracchin": "straccare",
    "stracchino": "straccare",
    "stracci": "straccio",
    "straccia": "straccio",
    "stracciai": "stracciare",
    "stracciammo": "stracciare",
    "stracciamo": "stracciare",
    "straccian": "stracciare",
    "stracciando": "stracciare",
    "stracciano": "stracciare",
    "stracciante": "stracciare",
    "straccianti": "stracciare",
    "stracciar": "stracciare",
    "stracciaron": "stracciare",
    "stracciarono": "stracciare",
    "stracciasse": "stracciare",
    "stracciasser": "stracciare",
    "stracciassero": "stracciare",
    "stracciassi": "stracciare",
    "stracciassimo": "stracciare",
    "stracciaste": "stracciare",
    "stracciasti": "stracciare",
    "stracciata": "stracciato",
    "stracciate": "stracciato",
    "stracciati": "stracciato",
    "stracciato": "stracciare",
    "stracciava": "stracciare",
    "stracciavamo": "stracciare",
    "stracciavan": "stracciare",
    "stracciavano": "stracciare",
    "stracciavate": "stracciare",
    "stracciavi": "stracciare",
    "stracciavo": "stracciare",
    "straccin": "stracciare",
    "straccino": "stracciare",
    "straccio": "stracciare",
    "straccioni": "straccione",
    "stracciò": "stracciare",
    "stracco": "straccare",
    "straccò": "straccare",
    "stracolma": "stracolmo",
    "stracolme": "stracolmo",
    "stracolmi": "stracolmo",
    "stracotta": "stracotto",
    "stracotte": "stracotto",
    "stracotti": "stracotto",
    "stracuoca": "stracuocere",
    "stracuocan": "stracuocere",
    "stracuocano": "stracuocere",
    "stracuoce": "stracuocere",
    "stracuocei": "stracuocere",
    "stracuocemmo": "stracuocere",
    "stracuocendo": "stracuocere",
    "stracuocente": "stracuocere",
    "stracuocenti": "stracuocere",
    "stracuocer": "stracuocere",
    "stracuocerai": "stracuocere",
    "stracuoceran": "stracuocere",
    "stracuoceranno": "stracuocere",
    "stracuocerebbe": "stracuocere",
    "stracuocerebber": "stracuocere",
    "stracuocerebbero": "stracuocere",
    "stracuocerei": "stracuocere",
    "stracuoceremmo": "stracuocere",
    "stracuoceremo": "stracuocere",
    "stracuocereste": "stracuocere",
    "stracuoceresti": "stracuocere",
    "stracuocerete": "stracuocere",
    "stracuoceron": "stracuocere",
    "stracuocerono": "stracuocere",
    "stracuocerà": "stracuocere",
    "stracuocerò": "stracuocere",
    "stracuocesse": "stracuocere",
    "stracuocesser": "stracuocere",
    "stracuocessero": "stracuocere",
    "stracuocessi": "stracuocere",
    "stracuocessimo": "stracuocere",
    "stracuoceste": "stracuocere",
    "stracuocesti": "stracuocere",
    "stracuocete": "stracuocere",
    "stracuoceva": "stracuocere",
    "stracuocevamo": "stracuocere",
    "stracuocevan": "stracuocere",
    "stracuocevano": "stracuocere",
    "stracuocevate": "stracuocere",
    "stracuocevi": "stracuocere",
    "stracuocevo": "stracuocere",
    "stracuoci": "stracuocere",
    "stracuociamo": "stracuocere",
    "stracuociate": "stracuocere",
    "stracuociuta": "stracuocere",
    "stracuociute": "stracuocere",
    "stracuociuti": "stracuocere",
    "stracuociuto": "stracuocere",
    "stracuoco": "stracuocere",
    "stracuocon": "stracuocere",
    "stracuocono": "stracuocere",
    "stracuocè": "stracuocere",
    "stradali": "stradale",
    "strade": "strada",
    "stradette": "stradetta",
    "stradicciole": "stradicciola",
    "stradine": "stradina",
    "stradoni": "stradone",
    "strafa": "strafare",
    "strafa'": "strafare",
    "strafaccia": "strafare",
    "strafacciamo": "strafare",
    "strafaccian": "strafare",
    "strafacciano": "strafare",
    "strafacciate": "strafare",
    "strafaccio": "strafare",
    "strafacemmo": "strafare",
    "strafacendo": "strafare",
    "strafacente": "strafare",
    "strafacenti": "strafare",
    "strafacesse": "strafare",
    "strafacesser": "strafare",
    "strafacessero": "strafare",
    "strafacessi": "strafare",
    "strafacessimo": "strafare",
    "strafaceste": "strafare",
    "strafacesti": "strafare",
    "strafaceva": "strafare",
    "strafacevamo": "strafare",
    "strafacevan": "strafare",
    "strafacevano": "strafare",
    "strafacevate": "strafare",
    "strafacevi": "strafare",
    "strafacevo": "strafare",
    "strafai": "strafare",
    "strafalcioni": "strafalcione",
    "strafan": "strafare",
    "strafanno": "strafare",
    "strafar": "strafare",
    "strafarai": "strafare",
    "strafaran": "strafare",
    "strafaranno": "strafare",
    "strafarebbe": "strafare",
    "strafarebber": "strafare",
    "strafarebbero": "strafare",
    "strafarei": "strafare",
    "strafaremmo": "strafare",
    "strafaremo": "strafare",
    "strafareste": "strafare",
    "strafaresti": "strafare",
    "strafarete": "strafare",
    "strafarà": "strafare",
    "strafarò": "strafare",
    "strafate": "strafare",
    "strafatta": "strafare",
    "strafatte": "strafare",
    "strafatti": "strafare",
    "strafatto": "strafare",
    "strafece": "strafare",
    "strafecer": "strafare",
    "strafecero": "strafare",
    "strafeci": "strafare",
    "strafotta": "strafottere",
    "strafottan": "strafottere",
    "strafottano": "strafottere",
    "strafotte": "strafottere",
    "strafottei": "strafottere",
    "strafottemmo": "strafottere",
    "strafottendo": "strafottere",
    "strafottente": "strafottere",
    "strafottenti": "strafottere",
    "strafottenze": "strafottenza",
    "strafotter": "strafottere",
    "strafotterai": "strafottere",
    "strafotteran": "strafottere",
    "strafotteranno": "strafottere",
    "strafotterebbe": "strafottere",
    "strafotterebber": "strafottere",
    "strafotterebbero": "strafottere",
    "strafotterei": "strafottere",
    "strafotteremmo": "strafottere",
    "strafotteremo": "strafottere",
    "strafottereste": "strafottere",
    "strafotteresti": "strafottere",
    "strafotterete": "strafottere",
    "strafotteron": "strafottere",
    "strafotterono": "strafottere",
    "strafotterà": "strafottere",
    "strafotterò": "strafottere",
    "strafottesse": "strafottere",
    "strafottesser": "strafottere",
    "strafottessero": "strafottere",
    "strafottessi": "strafottere",
    "strafottessimo": "strafottere",
    "strafotteste": "strafottere",
    "strafottesti": "strafottere",
    "strafottete": "strafottere",
    "strafotteva": "strafottere",
    "strafottevamo": "strafottere",
    "strafottevan": "strafottere",
    "strafottevano": "strafottere",
    "strafottevate": "strafottere",
    "strafottevi": "strafottere",
    "strafottevo": "strafottere",
    "strafotti": "strafottere",
    "strafottiamo": "strafottere",
    "strafottiate": "strafottere",
    "strafotto": "strafottere",
    "strafotton": "strafottere",
    "strafottono": "strafottere",
    "strafottuta": "strafottere",
    "strafottute": "strafottere",
    "strafottuti": "strafottere",
    "strafottuto": "strafottere",
    "strafottè": "strafottere",
    "stragi": "strage",
    "stragismi": "stragismo",
    "stragrandi": "stragrande",
    "stralce": "stralcio",
    "stralcerai": "stralciare",
    "stralceran": "stralciare",
    "stralceranno": "stralciare",
    "stralcerebbe": "stralciare",
    "stralcerebber": "stralciare",
    "stralcerebbero": "stralciare",
    "stralcerei": "stralciare",
    "stralceremmo": "stralciare",
    "stralceremo": "stralciare",
    "stralcereste": "stralciare",
    "stralceresti": "stralciare",
    "stralcerete": "stralciare",
    "stralcerà": "stralciare",
    "stralcerò": "stralciare",
    "stralci": "stralcio",
    "stralcia": "stralcio",
    "stralciai": "stralciare",
    "stralciammo": "stralciare",
    "stralciamo": "stralciare",
    "stralcian": "stralciare",
    "stralciando": "stralciare",
    "stralciano": "stralciare",
    "stralciante": "stralciare",
    "stralcianti": "stralciare",
    "stralciar": "stralciare",
    "stralciaron": "stralciare",
    "stralciarono": "stralciare",
    "stralciasse": "stralciare",
    "stralciasser": "stralciare",
    "stralciassero": "stralciare",
    "stralciassi": "stralciare",
    "stralciassimo": "stralciare",
    "stralciaste": "stralciare",
    "stralciasti": "stralciare",
    "stralciata": "stralciare",
    "stralciate": "stralciare",
    "stralciati": "stralciare",
    "stralciato": "stralciare",
    "stralciava": "stralciare",
    "stralciavamo": "stralciare",
    "stralciavan": "stralciare",
    "stralciavano": "stralciare",
    "stralciavate": "stralciare",
    "stralciavi": "stralciare",
    "stralciavo": "stralciare",
    "stralcin": "stralciare",
    "stralcino": "stralciare",
    "stralcio": "stralciare",
    "stralciò": "stralciare",
    "strali": "strale",
    "straluna": "stralunare",
    "stralunai": "stralunare",
    "stralunammo": "stralunare",
    "stralunan": "stralunare",
    "stralunando": "stralunare",
    "stralunano": "stralunare",
    "stralunante": "stralunare",
    "stralunanti": "stralunare",
    "stralunar": "stralunare",
    "stralunaron": "stralunare",
    "stralunarono": "stralunare",
    "stralunasse": "stralunare",
    "stralunasser": "stralunare",
    "stralunassero": "stralunare",
    "stralunassi": "stralunare",
    "stralunassimo": "stralunare",
    "stralunaste": "stralunare",
    "stralunasti": "stralunare",
    "stralunata": "stralunato",
    "stralunate": "stralunato",
    "stralunati": "stralunato",
    "stralunato": "stralunare",
    "stralunava": "stralunare",
    "stralunavamo": "stralunare",
    "stralunavan": "stralunare",
    "stralunavano": "stralunare",
    "stralunavate": "stralunare",
    "stralunavi": "stralunare",
    "stralunavo": "stralunare",
    "stralunerai": "stralunare",
    "straluneran": "stralunare",
    "straluneranno": "stralunare",
    "stralunerebbe": "stralunare",
    "stralunerebber": "stralunare",
    "stralunerebbero": "stralunare",
    "stralunerei": "stralunare",
    "straluneremmo": "stralunare",
    "straluneremo": "stralunare",
    "stralunereste": "stralunare",
    "straluneresti": "stralunare",
    "stralunerete": "stralunare",
    "stralunerà": "stralunare",
    "stralunerò": "stralunare",
    "straluni": "stralunare",
    "straluniamo": "stralunare",
    "straluniate": "stralunare",
    "stralunin": "stralunare",
    "stralunino": "stralunare",
    "straluno": "stralunare",
    "stralunò": "stralunare",
    "stramaledetta": "stramaledire",
    "stramaledette": "stramaledire",
    "stramaledetti": "stramaledire",
    "stramaledetto": "stramaledire",
    "stramaledica": "stramaledire",
    "stramaledican": "stramaledire",
    "stramaledicano": "stramaledire",
    "stramaledice": "stramaledire",
    "stramaledicemmo": "stramaledire",
    "stramaledicendo": "stramaledire",
    "stramaledicente": "stramaledire",
    "stramaledicenti": "stramaledire",
    "stramaledicesse": "stramaledire",
    "stramaledicesser": "stramaledire",
    "stramaledicessero": "stramaledire",
    "stramaledicessi": "stramaledire",
    "stramaledicessimo": "stramaledire",
    "stramalediceste": "stramaledire",
    "stramaledicesti": "stramaledire",
    "stramalediceva": "stramaledire",
    "stramaledicevamo": "stramaledire",
    "stramaledicevan": "stramaledire",
    "stramaledicevano": "stramaledire",
    "stramaledicevate": "stramaledire",
    "stramaledicevi": "stramaledire",
    "stramaledicevo": "stramaledire",
    "stramaledici": "stramaledire",
    "stramalediciamo": "stramaledire",
    "stramalediciate": "stramaledire",
    "stramaledico": "stramaledire",
    "stramaledicon": "stramaledire",
    "stramaledicono": "stramaledire",
    "stramaledir": "stramaledire",
    "stramaledirai": "stramaledire",
    "stramalediran": "stramaledire",
    "stramalediranno": "stramaledire",
    "stramaledirebbe": "stramaledire",
    "stramaledirebber": "stramaledire",
    "stramaledirebbero": "stramaledire",
    "stramaledirei": "stramaledire",
    "stramalediremmo": "stramaledire",
    "stramalediremo": "stramaledire",
    "stramaledireste": "stramaledire",
    "stramalediresti": "stramaledire",
    "stramaledirete": "stramaledire",
    "stramaledirà": "stramaledire",
    "stramaledirò": "stramaledire",
    "stramaledisse": "stramaledire",
    "stramaledisser": "stramaledire",
    "stramaledissero": "stramaledire",
    "stramaledissi": "stramaledire",
    "stramaledite": "stramaledire",
    "stramazza": "stramazzare",
    "stramazzai": "stramazzare",
    "stramazzammo": "stramazzare",
    "stramazzan": "stramazzare",
    "stramazzando": "stramazzare",
    "stramazzano": "stramazzare",
    "stramazzante": "stramazzare",
    "stramazzanti": "stramazzare",
    "stramazzar": "stramazzare",
    "stramazzaron": "stramazzare",
    "stramazzarono": "stramazzare",
    "stramazzasse": "stramazzare",
    "stramazzasser": "stramazzare",
    "stramazzassero": "stramazzare",
    "stramazzassi": "stramazzare",
    "stramazzassimo": "stramazzare",
    "stramazzaste": "stramazzare",
    "stramazzasti": "stramazzare",
    "stramazzata": "stramazzare",
    "stramazzate": "stramazzare",
    "stramazzati": "stramazzare",
    "stramazzato": "stramazzare",
    "stramazzava": "stramazzare",
    "stramazzavamo": "stramazzare",
    "stramazzavan": "stramazzare",
    "stramazzavano": "stramazzare",
    "stramazzavate": "stramazzare",
    "stramazzavi": "stramazzare",
    "stramazzavo": "stramazzare",
    "stramazzerai": "stramazzare",
    "stramazzeran": "stramazzare",
    "stramazzeranno": "stramazzare",
    "stramazzerebbe": "stramazzare",
    "stramazzerebber": "stramazzare",
    "stramazzerebbero": "stramazzare",
    "stramazzerei": "stramazzare",
    "stramazzeremmo": "stramazzare",
    "stramazzeremo": "stramazzare",
    "stramazzereste": "stramazzare",
    "stramazzeresti": "stramazzare",
    "stramazzerete": "stramazzare",
    "stramazzerà": "stramazzare",
    "stramazzerò": "stramazzare",
    "stramazzi": "stramazzare",
    "stramazziamo": "stramazzare",
    "stramazziate": "stramazzare",
    "stramazzin": "stramazzare",
    "stramazzino": "stramazzare",
    "stramazzo": "stramazzare",
    "stramazzò": "stramazzare",
    "stramba": "strambo",
    "strambe": "strambo",
    "stramberie": "stramberia",
    "strambi": "strambo",
    "strampalata": "strampalato",
    "strampalate": "strampalato",
    "strampalati": "strampalato",
    "strana": "strano",
    "strane": "strano",
    "stranezze": "stranezza",
    "strangola": "strangolare",
    "strangolai": "strangolare",
    "strangolamenti": "strangolamento",
    "strangolammo": "strangolare",
    "strangolan": "strangolare",
    "strangolando": "strangolare",
    "strangolano": "strangolare",
    "strangolante": "strangolare",
    "strangolanti": "strangolare",
    "strangolar": "strangolare",
    "strangolaron": "strangolare",
    "strangolarono": "strangolare",
    "strangolasse": "strangolare",
    "strangolasser": "strangolare",
    "strangolassero": "strangolare",
    "strangolassi": "strangolare",
    "strangolassimo": "strangolare",
    "strangolaste": "strangolare",
    "strangolasti": "strangolare",
    "strangolata": "strangolare",
    "strangolate": "strangolare",
    "strangolati": "strangolare",
    "strangolato": "strangolare",
    "strangolatori": "strangolatore",
    "strangolava": "strangolare",
    "strangolavamo": "strangolare",
    "strangolavan": "strangolare",
    "strangolavano": "strangolare",
    "strangolavate": "strangolare",
    "strangolavi": "strangolare",
    "strangolavo": "strangolare",
    "strangolerai": "strangolare",
    "strangoleran": "strangolare",
    "strangoleranno": "strangolare",
    "strangolerebbe": "strangolare",
    "strangolerebber": "strangolare",
    "strangolerebbero": "strangolare",
    "strangolerei": "strangolare",
    "strangoleremmo": "strangolare",
    "strangoleremo": "strangolare",
    "strangolereste": "strangolare",
    "strangoleresti": "strangolare",
    "strangolerete": "strangolare",
    "strangolerà": "strangolare",
    "strangolerò": "strangolare",
    "strangoli": "strangolare",
    "strangoliamo": "strangolare",
    "strangoliate": "strangolare",
    "strangolin": "strangolare",
    "strangolino": "strangolare",
    "strangolo": "strangolare",
    "strangolò": "strangolare",
    "stranguglioni": "stranguglione",
    "strani": "strano",
    "strania": "straniare",
    "straniai": "straniare",
    "straniamenti": "straniamento",
    "straniammo": "straniare",
    "straniamo": "straniare",
    "stranian": "straniare",
    "straniando": "straniare",
    "straniano": "straniare",
    "straniante": "straniare",
    "stranianti": "straniare",
    "straniar": "straniare",
    "straniaron": "straniare",
    "straniarono": "straniare",
    "straniasse": "straniare",
    "straniasser": "straniare",
    "straniassero": "straniare",
    "straniassi": "straniare",
    "straniassimo": "straniare",
    "straniaste": "straniare",
    "straniasti": "straniare",
    "straniata": "straniare",
    "straniate": "straniare",
    "straniati": "straniare",
    "straniato": "straniare",
    "straniava": "straniare",
    "straniavamo": "straniare",
    "straniavan": "straniare",
    "straniavano": "straniare",
    "straniavate": "straniare",
    "straniavi": "straniare",
    "straniavo": "straniare",
    "straniera": "straniero",
    "stranierai": "straniare",
    "stranieran": "straniare",
    "stranieranno": "straniare",
    "straniere": "straniero",
    "stranierebbe": "straniare",
    "stranierebber": "straniare",
    "stranierebbero": "straniare",
    "stranierei": "straniare",
    "stranieremmo": "straniare",
    "stranieremo": "straniare",
    "straniereste": "straniare",
    "stranieresti": "straniare",
    "stranierete": "straniare",
    "stranieri": "straniero",
    "stranierà": "straniare",
    "stranierò": "straniare",
    "stranin": "straniare",
    "stranino": "straniare",
    "stranio": "straniare",
    "stranita": "stranito",
    "stranite": "stranito",
    "straniti": "stranito",
    "straniò": "straniare",
    "straordinari": "straordinario",
    "straordinaria": "straordinario",
    "straordinarie": "straordinario",
    "strapaesana": "strapaesano",
    "strapaesane": "strapaesano",
    "strapaesani": "strapaesano",
    "strapaga": "strapagare",
    "strapagai": "strapagare",
    "strapagammo": "strapagare",
    "strapagan": "strapagare",
    "strapagando": "strapagare",
    "strapagano": "strapagare",
    "strapagante": "strapagare",
    "strapaganti": "strapagare",
    "strapagar": "strapagare",
    "strapagaron": "strapagare",
    "strapagarono": "strapagare",
    "strapagasse": "strapagare",
    "strapagasser": "strapagare",
    "strapagassero": "strapagare",
    "strapagassi": "strapagare",
    "strapagassimo": "strapagare",
    "strapagaste": "strapagare",
    "strapagasti": "strapagare",
    "strapagata": "strapagare",
    "strapagate": "strapagare",
    "strapagati": "strapagare",
    "strapagato": "strapagare",
    "strapagava": "strapagare",
    "strapagavamo": "strapagare",
    "strapagavan": "strapagare",
    "strapagavano": "strapagare",
    "strapagavate": "strapagare",
    "strapagavi": "strapagare",
    "strapagavo": "strapagare",
    "strapagherai": "strapagare",
    "strapagheran": "strapagare",
    "strapagheranno": "strapagare",
    "strapagherebbe": "strapagare",
    "strapagherebber": "strapagare",
    "strapagherebbero": "strapagare",
    "strapagherei": "strapagare",
    "strapagheremmo": "strapagare",
    "strapagheremo": "strapagare",
    "strapaghereste": "strapagare",
    "strapagheresti": "strapagare",
    "strapagherete": "strapagare",
    "strapagherà": "strapagare",
    "strapagherò": "strapagare",
    "strapaghi": "strapagare",
    "strapaghiamo": "strapagare",
    "strapaghiate": "strapagare",
    "strapaghin": "strapagare",
    "strapaghino": "strapagare",
    "strapago": "strapagare",
    "strapagò": "strapagare",
    "straparla": "straparlare",
    "straparlai": "straparlare",
    "straparlammo": "straparlare",
    "straparlan": "straparlare",
    "straparlando": "straparlare",
    "straparlano": "straparlare",
    "straparlante": "straparlare",
    "straparlanti": "straparlare",
    "straparlar": "straparlare",
    "straparlaron": "straparlare",
    "straparlarono": "straparlare",
    "straparlasse": "straparlare",
    "straparlasser": "straparlare",
    "straparlassero": "straparlare",
    "straparlassi": "straparlare",
    "straparlassimo": "straparlare",
    "straparlaste": "straparlare",
    "straparlasti": "straparlare",
    "straparlata": "straparlare",
    "straparlate": "straparlare",
    "straparlati": "straparlare",
    "straparlato": "straparlare",
    "straparlava": "straparlare",
    "straparlavamo": "straparlare",
    "straparlavan": "straparlare",
    "straparlavano": "straparlare",
    "straparlavate": "straparlare",
    "straparlavi": "straparlare",
    "straparlavo": "straparlare",
    "straparlerai": "straparlare",
    "straparleran": "straparlare",
    "straparleranno": "straparlare",
    "straparlerebbe": "straparlare",
    "straparlerebber": "straparlare",
    "straparlerebbero": "straparlare",
    "straparlerei": "straparlare",
    "straparleremmo": "straparlare",
    "straparleremo": "straparlare",
    "straparlereste": "straparlare",
    "straparleresti": "straparlare",
    "straparlerete": "straparlare",
    "straparlerà": "straparlare",
    "straparlerò": "straparlare",
    "straparli": "straparlare",
    "straparliamo": "straparlare",
    "straparliate": "straparlare",
    "straparlin": "straparlare",
    "straparlino": "straparlare",
    "straparlo": "straparlare",
    "straparlò": "straparlare",
    "strapazza": "strapazzare",
    "strapazzai": "strapazzare",
    "strapazzammo": "strapazzare",
    "strapazzan": "strapazzare",
    "strapazzando": "strapazzare",
    "strapazzano": "strapazzare",
    "strapazzante": "strapazzare",
    "strapazzanti": "strapazzare",
    "strapazzar": "strapazzare",
    "strapazzaron": "strapazzare",
    "strapazzarono": "strapazzare",
    "strapazzasse": "strapazzare",
    "strapazzasser": "strapazzare",
    "strapazzassero": "strapazzare",
    "strapazzassi": "strapazzare",
    "strapazzassimo": "strapazzare",
    "strapazzaste": "strapazzare",
    "strapazzasti": "strapazzare",
    "strapazzata": "strapazzato",
    "strapazzate": "strapazzato",
    "strapazzati": "strapazzato",
    "strapazzato": "strapazzare",
    "strapazzava": "strapazzare",
    "strapazzavamo": "strapazzare",
    "strapazzavan": "strapazzare",
    "strapazzavano": "strapazzare",
    "strapazzavate": "strapazzare",
    "strapazzavi": "strapazzare",
    "strapazzavo": "strapazzare",
    "strapazzerai": "strapazzare",
    "strapazzeran": "strapazzare",
    "strapazzeranno": "strapazzare",
    "strapazzerebbe": "strapazzare",
    "strapazzerebber": "strapazzare",
    "strapazzerebbero": "strapazzare",
    "strapazzerei": "strapazzare",
    "strapazzeremmo": "strapazzare",
    "strapazzeremo": "strapazzare",
    "strapazzereste": "strapazzare",
    "strapazzeresti": "strapazzare",
    "strapazzerete": "strapazzare",
    "strapazzerà": "strapazzare",
    "strapazzerò": "strapazzare",
    "strapazzi": "strapazzare",
    "strapazziamo": "strapazzare",
    "strapazziate": "strapazzare",
    "strapazzin": "strapazzare",
    "strapazzino": "strapazzare",
    "strapazzo": "strapazzare",
    "strapazzosa": "strapazzoso",
    "strapazzose": "strapazzoso",
    "strapazzosi": "strapazzoso",
    "strapazzò": "strapazzare",
    "strapiena": "strapieno",
    "strapiene": "strapieno",
    "strapieni": "strapieno",
    "strapiomba": "strapiombare",
    "strapiombai": "strapiombare",
    "strapiombammo": "strapiombare",
    "strapiomban": "strapiombare",
    "strapiombando": "strapiombare",
    "strapiombano": "strapiombare",
    "strapiombante": "strapiombare",
    "strapiombanti": "strapiombare",
    "strapiombar": "strapiombare",
    "strapiombaron": "strapiombare",
    "strapiombarono": "strapiombare",
    "strapiombasse": "strapiombare",
    "strapiombasser": "strapiombare",
    "strapiombassero": "strapiombare",
    "strapiombassi": "strapiombare",
    "strapiombassimo": "strapiombare",
    "strapiombaste": "strapiombare",
    "strapiombasti": "strapiombare",
    "strapiombata": "strapiombare",
    "strapiombate": "strapiombare",
    "strapiombati": "strapiombare",
    "strapiombato": "strapiombare",
    "strapiombava": "strapiombare",
    "strapiombavamo": "strapiombare",
    "strapiombavan": "strapiombare",
    "strapiombavano": "strapiombare",
    "strapiombavate": "strapiombare",
    "strapiombavi": "strapiombare",
    "strapiombavo": "strapiombare",
    "strapiomberai": "strapiombare",
    "strapiomberan": "strapiombare",
    "strapiomberanno": "strapiombare",
    "strapiomberebbe": "strapiombare",
    "strapiomberebber": "strapiombare",
    "strapiomberebbero": "strapiombare",
    "strapiomberei": "strapiombare",
    "strapiomberemmo": "strapiombare",
    "strapiomberemo": "strapiombare",
    "strapiombereste": "strapiombare",
    "strapiomberesti": "strapiombare",
    "strapiomberete": "strapiombare",
    "strapiomberà": "strapiombare",
    "strapiomberò": "strapiombare",
    "strapiombi": "strapiombo",
    "strapiombiamo": "strapiombare",
    "strapiombiate": "strapiombare",
    "strapiombin": "strapiombare",
    "strapiombino": "strapiombare",
    "strapiombo": "strapiombare",
    "strapiombò": "strapiombare",
    "strapotenti": "strapotente",
    "strapotenze": "strapotenza",
    "strapoteri": "strapotere",
    "strappa": "strappare",
    "strappai": "strappare",
    "strappammo": "strappare",
    "strappan": "strappare",
    "strappando": "strappare",
    "strappano": "strappare",
    "strappante": "strappare",
    "strappanti": "strappare",
    "strappar": "strappare",
    "strapparon": "strappare",
    "strapparono": "strappare",
    "strappasse": "strappare",
    "strappasser": "strappare",
    "strappassero": "strappare",
    "strappassi": "strappare",
    "strappassimo": "strappare",
    "strappaste": "strappare",
    "strappasti": "strappare",
    "strappata": "strappato",
    "strappate": "strappato",
    "strappati": "strappato",
    "strappato": "strappare",
    "strappava": "strappare",
    "strappavamo": "strappare",
    "strappavan": "strappare",
    "strappavano": "strappare",
    "strappavate": "strappare",
    "strappavi": "strappare",
    "strappavo": "strappare",
    "strapperai": "strappare",
    "strapperan": "strappare",
    "strapperanno": "strappare",
    "strapperebbe": "strappare",
    "strapperebber": "strappare",
    "strapperebbero": "strappare",
    "strapperei": "strappare",
    "strapperemmo": "strappare",
    "strapperemo": "strappare",
    "strappereste": "strappare",
    "strapperesti": "strappare",
    "strapperete": "strappare",
    "strapperà": "strappare",
    "strapperò": "strappare",
    "strappi": "strappo",
    "strappiamo": "strappare",
    "strappiate": "strappare",
    "strappin": "strappare",
    "strappino": "strappare",
    "strappo": "strappare",
    "strappò": "strappare",
    "strapuntini": "strapuntino",
    "straricca": "straricco",
    "straricche": "straricco",
    "straricchi": "straricco",
    "straripa": "straripare",
    "straripai": "straripare",
    "straripamenti": "straripamento",
    "straripammo": "straripare",
    "straripan": "straripare",
    "straripando": "straripare",
    "straripano": "straripare",
    "straripante": "straripare",
    "straripanti": "straripare",
    "straripar": "straripare",
    "strariparon": "straripare",
    "strariparono": "straripare",
    "straripasse": "straripare",
    "straripasser": "straripare",
    "straripassero": "straripare",
    "straripassi": "straripare",
    "straripassimo": "straripare",
    "straripaste": "straripare",
    "straripasti": "straripare",
    "straripata": "straripare",
    "straripate": "straripare",
    "straripati": "straripare",
    "straripato": "straripare",
    "straripava": "straripare",
    "straripavamo": "straripare",
    "straripavan": "straripare",
    "straripavano": "straripare",
    "straripavate": "straripare",
    "straripavi": "straripare",
    "straripavo": "straripare",
    "strariperai": "straripare",
    "strariperan": "straripare",
    "strariperanno": "straripare",
    "strariperebbe": "straripare",
    "strariperebber": "straripare",
    "strariperebbero": "straripare",
    "strariperei": "straripare",
    "strariperemmo": "straripare",
    "strariperemo": "straripare",
    "straripereste": "straripare",
    "strariperesti": "straripare",
    "strariperete": "straripare",
    "strariperà": "straripare",
    "strariperò": "straripare",
    "straripi": "straripare",
    "straripiamo": "straripare",
    "straripiate": "straripare",
    "straripin": "straripare",
    "straripino": "straripare",
    "straripo": "straripare",
    "straripò": "straripare",
    "strascica": "strascicare",
    "strascicai": "strascicare",
    "strascicammo": "strascicare",
    "strascican": "strascicare",
    "strascicando": "strascicare",
    "strascicano": "strascicare",
    "strascicante": "strascicare",
    "strascicanti": "strascicare",
    "strascicar": "strascicare",
    "strascicaron": "strascicare",
    "strascicarono": "strascicare",
    "strascicasse": "strascicare",
    "strascicasser": "strascicare",
    "strascicassero": "strascicare",
    "strascicassi": "strascicare",
    "strascicassimo": "strascicare",
    "strascicaste": "strascicare",
    "strascicasti": "strascicare",
    "strascicata": "strascicare",
    "strascicate": "strascicare",
    "strascicati": "strascicare",
    "strascicato": "strascicare",
    "strascicava": "strascicare",
    "strascicavamo": "strascicare",
    "strascicavan": "strascicare",
    "strascicavano": "strascicare",
    "strascicavate": "strascicare",
    "strascicavi": "strascicare",
    "strascicavo": "strascicare",
    "strascicherai": "strascicare",
    "strascicheran": "strascicare",
    "strascicheranno": "strascicare",
    "strascicherebbe": "strascicare",
    "strascicherebber": "strascicare",
    "strascicherebbero": "strascicare",
    "strascicherei": "strascicare",
    "strascicheremmo": "strascicare",
    "strascicheremo": "strascicare",
    "strascichereste": "strascicare",
    "strascicheresti": "strascicare",
    "strascicherete": "strascicare",
    "strascicherà": "strascicare",
    "strascicherò": "strascicare",
    "strascichi": "strascico",
    "strascichiamo": "strascicare",
    "strascichiate": "strascicare",
    "strascichin": "strascicare",
    "strascichino": "strascicare",
    "strascico": "strascicare",
    "strascicò": "strascicare",
    "strascina": "strascinare",
    "strascinai": "strascinare",
    "strascinammo": "strascinare",
    "strascinan": "strascinare",
    "strascinando": "strascinare",
    "strascinano": "strascinare",
    "strascinante": "strascinare",
    "strascinanti": "strascinare",
    "strascinar": "strascinare",
    "strascinaron": "strascinare",
    "strascinarono": "strascinare",
    "strascinasse": "strascinare",
    "strascinasser": "strascinare",
    "strascinassero": "strascinare",
    "strascinassi": "strascinare",
    "strascinassimo": "strascinare",
    "strascinaste": "strascinare",
    "strascinasti": "strascinare",
    "strascinata": "strascinare",
    "strascinate": "strascinare",
    "strascinati": "strascinare",
    "strascinato": "strascinare",
    "strascinava": "strascinare",
    "strascinavamo": "strascinare",
    "strascinavan": "strascinare",
    "strascinavano": "strascinare",
    "strascinavate": "strascinare",
    "strascinavi": "strascinare",
    "strascinavo": "strascinare",
    "strascinerai": "strascinare",
    "strascineran": "strascinare",
    "strascineranno": "strascinare",
    "strascinerebbe": "strascinare",
    "strascinerebber": "strascinare",
    "strascinerebbero": "strascinare",
    "strascinerei": "strascinare",
    "strascineremmo": "strascinare",
    "strascineremo": "strascinare",
    "strascinereste": "strascinare",
    "strascineresti": "strascinare",
    "strascinerete": "strascinare",
    "strascinerà": "strascinare",
    "strascinerò": "strascinare",
    "strascini": "strascinare",
    "strasciniamo": "strascinare",
    "strasciniate": "strascinare",
    "strascinin": "strascinare",
    "strascinino": "strascinare",
    "strascino": "strascinare",
    "strascinò": "strascinare",
    "stratagemmi": "stratagemma",
    "strateghi": "stratega",
    "strategica": "strategico",
    "strategiche": "strategico",
    "strategici": "strategico",
    "strategie": "strategia",
    "strati": "strato",
    "stratifica": "stratificare",
    "stratificai": "stratificare",
    "stratificammo": "stratificare",
    "stratifican": "stratificare",
    "stratificando": "stratificare",
    "stratificano": "stratificare",
    "stratificante": "stratificare",
    "stratificanti": "stratificare",
    "stratificar": "stratificare",
    "stratificaron": "stratificare",
    "stratificarono": "stratificare",
    "stratificasse": "stratificare",
    "stratificasser": "stratificare",
    "stratificassero": "stratificare",
    "stratificassi": "stratificare",
    "stratificassimo": "stratificare",
    "stratificaste": "stratificare",
    "stratificasti": "stratificare",
    "stratificata": "stratificare",
    "stratificate": "stratificare",
    "stratificati": "stratificare",
    "stratificato": "stratificare",
    "stratificava": "stratificare",
    "stratificavamo": "stratificare",
    "stratificavan": "stratificare",
    "stratificavano": "stratificare",
    "stratificavate": "stratificare",
    "stratificavi": "stratificare",
    "stratificavo": "stratificare",
    "stratificazioni": "stratificazione",
    "stratificherai": "stratificare",
    "stratificheran": "stratificare",
    "stratificheranno": "stratificare",
    "stratificherebbe": "stratificare",
    "stratificherebber": "stratificare",
    "stratificherebbero": "stratificare",
    "stratificherei": "stratificare",
    "stratificheremmo": "stratificare",
    "stratificheremo": "stratificare",
    "stratifichereste": "stratificare",
    "stratificheresti": "stratificare",
    "stratificherete": "stratificare",
    "stratificherà": "stratificare",
    "stratificherò": "stratificare",
    "stratifichi": "stratificare",
    "stratifichiamo": "stratificare",
    "stratifichiate": "stratificare",
    "stratifichin": "stratificare",
    "stratifichino": "stratificare",
    "stratifico": "stratificare",
    "stratificò": "stratificare",
    "stratosfere": "stratosfera",
    "stratosferica": "stratosferico",
    "stratosferiche": "stratosferico",
    "stratosferici": "stratosferico",
    "strattona": "strattonare",
    "strattonai": "strattonare",
    "strattonammo": "strattonare",
    "strattonan": "strattonare",
    "strattonando": "strattonare",
    "strattonano": "strattonare",
    "strattonante": "strattonare",
    "strattonanti": "strattonare",
    "strattonar": "strattonare",
    "strattonaron": "strattonare",
    "strattonarono": "strattonare",
    "strattonasse": "strattonare",
    "strattonasser": "strattonare",
    "strattonassero": "strattonare",
    "strattonassi": "strattonare",
    "strattonassimo": "strattonare",
    "strattonaste": "strattonare",
    "strattonasti": "strattonare",
    "strattonata": "strattonare",
    "strattonate": "strattonare",
    "strattonati": "strattonare",
    "strattonato": "strattonare",
    "strattonava": "strattonare",
    "strattonavamo": "strattonare",
    "strattonavan": "strattonare",
    "strattonavano": "strattonare",
    "strattonavate": "strattonare",
    "strattonavi": "strattonare",
    "strattonavo": "strattonare",
    "strattonerai": "strattonare",
    "strattoneran": "strattonare",
    "strattoneranno": "strattonare",
    "strattonerebbe": "strattonare",
    "strattonerebber": "strattonare",
    "strattonerebbero": "strattonare",
    "strattonerei": "strattonare",
    "strattoneremmo": "strattonare",
    "strattoneremo": "strattonare",
    "strattonereste": "strattonare",
    "strattoneresti": "strattonare",
    "strattonerete": "strattonare",
    "strattonerà": "strattonare",
    "strattonerò": "strattonare",
    "strattoni": "strattone",
    "strattoniamo": "strattonare",
    "strattoniate": "strattonare",
    "strattonin": "strattonare",
    "strattonino": "strattonare",
    "strattono": "strattonare",
    "strattonò": "strattonare",
    "stravacca": "stravaccare",
    "stravaccai": "stravaccare",
    "stravaccammo": "stravaccare",
    "stravaccan": "stravaccare",
    "stravaccando": "stravaccare",
    "stravaccano": "stravaccare",
    "stravaccar": "stravaccare",
    "stravaccaron": "stravaccare",
    "stravaccarono": "stravaccare",
    "stravaccasse": "stravaccare",
    "stravaccasser": "stravaccare",
    "stravaccassero": "stravaccare",
    "stravaccassi": "stravaccare",
    "stravaccassimo": "stravaccare",
    "stravaccaste": "stravaccare",
    "stravaccasti": "stravaccare",
    "stravaccata": "stravaccare",
    "stravaccate": "stravaccare",
    "stravaccati": "stravaccare",
    "stravaccato": "stravaccare",
    "stravaccava": "stravaccare",
    "stravaccavamo": "stravaccare",
    "stravaccavan": "stravaccare",
    "stravaccavano": "stravaccare",
    "stravaccavate": "stravaccare",
    "stravaccavi": "stravaccare",
    "stravaccavo": "stravaccare",
    "stravaccherai": "stravaccare",
    "stravaccheran": "stravaccare",
    "stravaccheranno": "stravaccare",
    "stravaccherebbe": "stravaccare",
    "stravaccherebber": "stravaccare",
    "stravaccherebbero": "stravaccare",
    "stravaccherei": "stravaccare",
    "stravaccheremmo": "stravaccare",
    "stravaccheremo": "stravaccare",
    "stravacchereste": "stravaccare",
    "stravaccheresti": "stravaccare",
    "stravaccherete": "stravaccare",
    "stravaccherà": "stravaccare",
    "stravaccherò": "stravaccare",
    "stravacchi": "stravaccare",
    "stravacchiamo": "stravaccare",
    "stravacchiate": "stravaccare",
    "stravacchin": "stravaccare",
    "stravacchino": "stravaccare",
    "stravacco": "stravaccare",
    "stravaccò": "stravaccare",
    "stravaganti": "stravagante",
    "stravaganze": "stravaganza",
    "straveda": "stravedere",
    "stravedan": "stravedere",
    "stravedano": "stravedere",
    "stravede": "stravedere",
    "stravedemmo": "stravedere",
    "stravedendo": "stravedere",
    "stravedente": "stravedere",
    "stravedenti": "stravedere",
    "straveder": "stravedere",
    "stravedesse": "stravedere",
    "stravedesser": "stravedere",
    "stravedessero": "stravedere",
    "stravedessi": "stravedere",
    "stravedessimo": "stravedere",
    "stravedeste": "stravedere",
    "stravedesti": "stravedere",
    "stravedete": "stravedere",
    "stravedeva": "stravedere",
    "stravedevamo": "stravedere",
    "stravedevan": "stravedere",
    "stravedevano": "stravedere",
    "stravedevate": "stravedere",
    "stravedevi": "stravedere",
    "stravedevo": "stravedere",
    "stravedi": "stravedere",
    "stravediamo": "stravedere",
    "stravediate": "stravedere",
    "stravedo": "stravedere",
    "stravedon": "stravedere",
    "stravedono": "stravedere",
    "stravedrai": "stravedere",
    "stravedran": "stravedere",
    "stravedranno": "stravedere",
    "stravedrebbe": "stravedere",
    "stravedrebber": "stravedere",
    "stravedrebbero": "stravedere",
    "stravedrei": "stravedere",
    "stravedremmo": "stravedere",
    "stravedremo": "stravedere",
    "stravedreste": "stravedere",
    "stravedresti": "stravedere",
    "stravedrete": "stravedere",
    "stravedrà": "stravedere",
    "stravedrò": "stravedere",
    "straveduta": "stravedere",
    "stravedute": "stravedere",
    "straveduti": "stravedere",
    "straveduto": "stravedere",
    "stravide": "stravedere",
    "stravider": "stravedere",
    "stravidero": "stravedere",
    "stravidi": "stravedere",
    "stravinca": "stravincere",
    "stravincan": "stravincere",
    "stravincano": "stravincere",
    "stravince": "stravincere",
    "stravincemmo": "stravincere",
    "stravincendo": "stravincere",
    "stravincente": "stravincere",
    "stravincenti": "stravincere",
    "stravincer": "stravincere",
    "stravincerai": "stravincere",
    "stravinceran": "stravincere",
    "stravinceranno": "stravincere",
    "stravincerebbe": "stravincere",
    "stravincerebber": "stravincere",
    "stravincerebbero": "stravincere",
    "stravincerei": "stravincere",
    "stravinceremmo": "stravincere",
    "stravinceremo": "stravincere",
    "stravincereste": "stravincere",
    "stravinceresti": "stravincere",
    "stravincerete": "stravincere",
    "stravincerà": "stravincere",
    "stravincerò": "stravincere",
    "stravincesse": "stravincere",
    "stravincesser": "stravincere",
    "stravincessero": "stravincere",
    "stravincessi": "stravincere",
    "stravincessimo": "stravincere",
    "stravinceste": "stravincere",
    "stravincesti": "stravincere",
    "stravincete": "stravincere",
    "stravinceva": "stravincere",
    "stravincevamo": "stravincere",
    "stravincevan": "stravincere",
    "stravincevano": "stravincere",
    "stravincevate": "stravincere",
    "stravincevi": "stravincere",
    "stravincevo": "stravincere",
    "stravinci": "stravincere",
    "stravinciamo": "stravincere",
    "stravinciate": "stravincere",
    "stravinco": "stravincere",
    "stravincon": "stravincere",
    "stravincono": "stravincere",
    "stravinse": "stravincere",
    "stravinser": "stravincere",
    "stravinsero": "stravincere",
    "stravinsi": "stravincere",
    "stravinta": "stravincere",
    "stravinte": "stravincere",
    "stravinti": "stravincere",
    "stravinto": "stravincere",
    "stravizi": "straviziare",
    "stravizia": "straviziare",
    "straviziai": "straviziare",
    "straviziammo": "straviziare",
    "straviziamo": "straviziare",
    "stravizian": "straviziare",
    "straviziando": "straviziare",
    "straviziano": "straviziare",
    "straviziante": "straviziare",
    "stravizianti": "straviziare",
    "straviziar": "straviziare",
    "straviziaron": "straviziare",
    "straviziarono": "straviziare",
    "straviziasse": "straviziare",
    "straviziasser": "straviziare",
    "straviziassero": "straviziare",
    "straviziassi": "straviziare",
    "straviziassimo": "straviziare",
    "straviziaste": "straviziare",
    "straviziasti": "straviziare",
    "straviziata": "straviziare",
    "straviziate": "straviziare",
    "straviziati": "straviziare",
    "straviziato": "straviziare",
    "straviziava": "straviziare",
    "straviziavamo": "straviziare",
    "straviziavan": "straviziare",
    "straviziavano": "straviziare",
    "straviziavate": "straviziare",
    "straviziavi": "straviziare",
    "straviziavo": "straviziare",
    "stravizierai": "straviziare",
    "stravizieran": "straviziare",
    "stravizieranno": "straviziare",
    "stravizierebbe": "straviziare",
    "stravizierebber": "straviziare",
    "stravizierebbero": "straviziare",
    "stravizierei": "straviziare",
    "stravizieremmo": "straviziare",
    "stravizieremo": "straviziare",
    "straviziereste": "straviziare",
    "stravizieresti": "straviziare",
    "stravizierete": "straviziare",
    "stravizierà": "straviziare",
    "stravizierò": "straviziare",
    "stravizin": "straviziare",
    "stravizino": "straviziare",
    "stravizio": "straviziare",
    "straviziò": "straviziare",
    "stravolga": "stravolgere",
    "stravolgan": "stravolgere",
    "stravolgano": "stravolgere",
    "stravolge": "stravolgere",
    "stravolgei": "stravolgere",
    "stravolgemmo": "stravolgere",
    "stravolgendo": "stravolgere",
    "stravolgente": "stravolgere",
    "stravolgenti": "stravolgere",
    "stravolger": "stravolgere",
    "stravolgerai": "stravolgere",
    "stravolgeran": "stravolgere",
    "stravolgeranno": "stravolgere",
    "stravolgerebbe": "stravolgere",
    "stravolgerebber": "stravolgere",
    "stravolgerebbero": "stravolgere",
    "stravolgerei": "stravolgere",
    "stravolgeremmo": "stravolgere",
    "stravolgeremo": "stravolgere",
    "stravolgereste": "stravolgere",
    "stravolgeresti": "stravolgere",
    "stravolgerete": "stravolgere",
    "stravolgeron": "stravolgere",
    "stravolgerono": "stravolgere",
    "stravolgerà": "stravolgere",
    "stravolgerò": "stravolgere",
    "stravolgesse": "stravolgere",
    "stravolgesser": "stravolgere",
    "stravolgessero": "stravolgere",
    "stravolgessi": "stravolgere",
    "stravolgessimo": "stravolgere",
    "stravolgeste": "stravolgere",
    "stravolgesti": "stravolgere",
    "stravolgete": "stravolgere",
    "stravolgeva": "stravolgere",
    "stravolgevamo": "stravolgere",
    "stravolgevan": "stravolgere",
    "stravolgevano": "stravolgere",
    "stravolgevate": "stravolgere",
    "stravolgevi": "stravolgere",
    "stravolgevo": "stravolgere",
    "stravolgi": "stravolgere",
    "stravolgiamo": "stravolgere",
    "stravolgiate": "stravolgere",
    "stravolgimenti": "stravolgimento",
    "stravolgo": "stravolgere",
    "stravolgon": "stravolgere",
    "stravolgono": "stravolgere",
    "stravolgè": "stravolgere",
    "stravolta": "stravolto",
    "stravolte": "stravolto",
    "stravolti": "stravolto",
    "stravolto": "stravolgere",
    "strazi": "strazio",
    "strazia": "straziare",
    "straziai": "straziare",
    "straziammo": "straziare",
    "straziamo": "straziare",
    "strazian": "straziare",
    "straziando": "straziare",
    "straziano": "straziare",
    "straziante": "straziare",
    "strazianti": "straziare",
    "straziar": "straziare",
    "straziaron": "straziare",
    "straziarono": "straziare",
    "straziasse": "straziare",
    "straziasser": "straziare",
    "straziassero": "straziare",
    "straziassi": "straziare",
    "straziassimo": "straziare",
    "straziaste": "straziare",
    "straziasti": "straziare",
    "straziata": "straziato",
    "straziate": "straziato",
    "straziati": "straziato",
    "straziato": "straziare",
    "straziava": "straziare",
    "straziavamo": "straziare",
    "straziavan": "straziare",
    "straziavano": "straziare",
    "straziavate": "straziare",
    "straziavi": "straziare",
    "straziavo": "straziare",
    "strazierai": "straziare",
    "strazieran": "straziare",
    "strazieranno": "straziare",
    "strazierebbe": "straziare",
    "strazierebber": "straziare",
    "strazierebbero": "straziare",
    "strazierei": "straziare",
    "strazieremmo": "straziare",
    "strazieremo": "straziare",
    "straziereste": "straziare",
    "strazieresti": "straziare",
    "strazierete": "straziare",
    "strazierà": "straziare",
    "strazierò": "straziare",
    "strazin": "straziare",
    "strazino": "straziare",
    "strazio": "straziare",
    "straziò": "straziare",
    "strega": "stregare",
    "stregai": "stregare",
    "stregammo": "stregare",
    "stregan": "stregare",
    "stregando": "stregare",
    "stregano": "stregare",
    "stregante": "stregare",
    "streganti": "stregare",
    "stregar": "stregare",
    "stregaron": "stregare",
    "stregarono": "stregare",
    "stregasse": "stregare",
    "stregasser": "stregare",
    "stregassero": "stregare",
    "stregassi": "stregare",
    "stregassimo": "stregare",
    "stregaste": "stregare",
    "stregasti": "stregare",
    "stregata": "stregare",
    "stregate": "stregare",
    "stregati": "stregare",
    "stregato": "stregare",
    "stregava": "stregare",
    "stregavamo": "stregare",
    "stregavan": "stregare",
    "stregavano": "stregare",
    "stregavate": "stregare",
    "stregavi": "stregare",
    "stregavo": "stregare",
    "streghe": "strega",
    "stregherai": "stregare",
    "stregheran": "stregare",
    "stregheranno": "stregare",
    "stregherebbe": "stregare",
    "stregherebber": "stregare",
    "stregherebbero": "stregare",
    "stregherei": "stregare",
    "stregheremmo": "stregare",
    "stregheremo": "stregare",
    "streghereste": "stregare",
    "stregheresti": "stregare",
    "stregherete": "stregare",
    "stregherà": "stregare",
    "stregherò": "stregare",
    "streghi": "stregare",
    "streghiamo": "stregare",
    "streghiate": "stregare",
    "streghin": "stregare",
    "streghino": "stregare",
    "strego": "stregare",
    "stregonerie": "stregoneria",
    "stregoni": "stregone",
    "stregò": "stregare",
    "strema": "stremare",
    "stremai": "stremare",
    "stremammo": "stremare",
    "streman": "stremare",
    "stremando": "stremare",
    "stremano": "stremare",
    "stremante": "stremare",
    "stremanti": "stremare",
    "stremar": "stremare",
    "stremaron": "stremare",
    "stremarono": "stremare",
    "stremasse": "stremare",
    "stremasser": "stremare",
    "stremassero": "stremare",
    "stremassi": "stremare",
    "stremassimo": "stremare",
    "stremaste": "stremare",
    "stremasti": "stremare",
    "stremata": "stremare",
    "stremate": "stremare",
    "stremati": "stremare",
    "stremato": "stremare",
    "stremava": "stremare",
    "stremavamo": "stremare",
    "stremavan": "stremare",
    "stremavano": "stremare",
    "stremavate": "stremare",
    "stremavi": "stremare",
    "stremavo": "stremare",
    "stremerai": "stremare",
    "stremeran": "stremare",
    "stremeranno": "stremare",
    "stremerebbe": "stremare",
    "stremerebber": "stremare",
    "stremerebbero": "stremare",
    "stremerei": "stremare",
    "stremeremmo": "stremare",
    "stremeremo": "stremare",
    "stremereste": "stremare",
    "stremeresti": "stremare",
    "stremerete": "stremare",
    "stremerà": "stremare",
    "stremerò": "stremare",
    "stremi": "stremare",
    "stremiamo": "stremare",
    "stremiate": "stremare",
    "stremin": "stremare",
    "stremino": "stremare",
    "stremo": "stremare",
    "stremò": "stremare",
    "strenne": "strenna",
    "strepita": "strepitare",
    "strepitai": "strepitare",
    "strepitammo": "strepitare",
    "strepitan": "strepitare",
    "strepitando": "strepitare",
    "strepitano": "strepitare",
    "strepitante": "strepitare",
    "strepitanti": "strepitare",
    "strepitar": "strepitare",
    "strepitaron": "strepitare",
    "strepitarono": "strepitare",
    "strepitasse": "strepitare",
    "strepitasser": "strepitare",
    "strepitassero": "strepitare",
    "strepitassi": "strepitare",
    "strepitassimo": "strepitare",
    "strepitaste": "strepitare",
    "strepitasti": "strepitare",
    "strepitata": "strepitare",
    "strepitate": "strepitare",
    "strepitati": "strepitare",
    "strepitato": "strepitare",
    "strepitava": "strepitare",
    "strepitavamo": "strepitare",
    "strepitavan": "strepitare",
    "strepitavano": "strepitare",
    "strepitavate": "strepitare",
    "strepitavi": "strepitare",
    "strepitavo": "strepitare",
    "strepiterai": "strepitare",
    "strepiteran": "strepitare",
    "strepiteranno": "strepitare",
    "strepiterebbe": "strepitare",
    "strepiterebber": "strepitare",
    "strepiterebbero": "strepitare",
    "strepiterei": "strepitare",
    "strepiteremmo": "strepitare",
    "strepiteremo": "strepitare",
    "strepitereste": "strepitare",
    "strepiteresti": "strepitare",
    "strepiterete": "strepitare",
    "strepiterà": "strepitare",
    "strepiterò": "strepitare",
    "strepiti": "strepito",
    "strepitiamo": "strepitare",
    "strepitiate": "strepitare",
    "strepitin": "strepitare",
    "strepitino": "strepitare",
    "strepito": "strepitare",
    "strepitosa": "strepitoso",
    "strepitose": "strepitoso",
    "strepitosi": "strepitoso",
    "strepitò": "strepitare",
    "streptococchi": "streptococco",
    "stressa": "stressare",
    "stressai": "stressare",
    "stressammo": "stressare",
    "stressan": "stressare",
    "stressando": "stressare",
    "stressano": "stressare",
    "stressante": "stressare",
    "stressanti": "stressare",
    "stressar": "stressare",
    "stressaron": "stressare",
    "stressarono": "stressare",
    "stressasse": "stressare",
    "stressasser": "stressare",
    "stressassero": "stressare",
    "stressassi": "stressare",
    "stressassimo": "stressare",
    "stressaste": "stressare",
    "stressasti": "stressare",
    "stressata": "stressato",
    "stressate": "stressato",
    "stressati": "stressato",
    "stressato": "stressare",
    "stressava": "stressare",
    "stressavamo": "stressare",
    "stressavan": "stressare",
    "stressavano": "stressare",
    "stressavate": "stressare",
    "stressavi": "stressare",
    "stressavo": "stressare",
    "stresserai": "stressare",
    "stresseran": "stressare",
    "stresseranno": "stressare",
    "stresserebbe": "stressare",
    "stresserebber": "stressare",
    "stresserebbero": "stressare",
    "stresserei": "stressare",
    "stresseremmo": "stressare",
    "stresseremo": "stressare",
    "stressereste": "stressare",
    "stresseresti": "stressare",
    "stresserete": "stressare",
    "stresserà": "stressare",
    "stresserò": "stressare",
    "stressi": "stressare",
    "stressiamo": "stressare",
    "stressiate": "stressare",
    "stressin": "stressare",
    "stressino": "stressare",
    "stresso": "stressare",
    "stressò": "stressare",
    "stretta": "stringere",
    "strette": "stringere",
    "strettezze": "strettezza",
    "stretti": "stringere",
    "stretto": "stringere",
    "strettoie": "strettoia",
    "stri": "striare",
    "stria": "striare",
    "striai": "striare",
    "striammo": "striare",
    "striamo": "striare",
    "strian": "striare",
    "striando": "striare",
    "striano": "striare",
    "striante": "striare",
    "strianti": "striare",
    "striar": "striare",
    "striaron": "striare",
    "striarono": "striare",
    "striasse": "striare",
    "striasser": "striare",
    "striassero": "striare",
    "striassi": "striare",
    "striassimo": "striare",
    "striaste": "striare",
    "striasti": "striare",
    "striata": "striato",
    "striate": "striato",
    "striati": "striato",
    "striato": "striare",
    "striature": "striatura",
    "striava": "striare",
    "striavamo": "striare",
    "striavan": "striare",
    "striavano": "striare",
    "striavate": "striare",
    "striavi": "striare",
    "striavo": "striare",
    "strida": "stridere",
    "stridan": "stridere",
    "stridano": "stridere",
    "stride": "stridere",
    "stridei": "stridere",
    "stridemmo": "stridere",
    "stridendo": "stridere",
    "stridente": "stridere",
    "stridenti": "stridere",
    "strider": "stridere",
    "striderai": "stridere",
    "strideran": "stridere",
    "strideranno": "stridere",
    "striderebbe": "stridere",
    "striderebber": "stridere",
    "striderebbero": "stridere",
    "striderei": "stridere",
    "strideremmo": "stridere",
    "strideremo": "stridere",
    "stridereste": "stridere",
    "strideresti": "stridere",
    "striderete": "stridere",
    "strideron": "stridere",
    "striderono": "stridere",
    "striderà": "stridere",
    "striderò": "stridere",
    "stridesse": "stridere",
    "stridesser": "stridere",
    "stridessero": "stridere",
    "stridessi": "stridere",
    "stridessimo": "stridere",
    "strideste": "stridere",
    "stridesti": "stridere",
    "stridete": "stridere",
    "strideva": "stridere",
    "stridevamo": "stridere",
    "stridevan": "stridere",
    "stridevano": "stridere",
    "stridevate": "stridere",
    "stridevi": "stridere",
    "stridevo": "stridere",
    "stridi": "stridere",
    "stridiamo": "stridere",
    "stridiate": "stridere",
    "strido": "stridere",
    "stridon": "stridere",
    "stridono": "stridere",
    "stridori": "stridore",
    "stridula": "stridulo",
    "stridule": "stridulo",
    "striduli": "stridulo",
    "striduta": "stridere",
    "stridute": "stridere",
    "striduti": "stridere",
    "striduto": "stridere",
    "stridè": "stridere",
    "strierai": "striare",
    "strieran": "striare",
    "strieranno": "striare",
    "strierebbe": "striare",
    "strierebber": "striare",
    "strierebbero": "striare",
    "strierei": "striare",
    "strieremmo": "striare",
    "strieremo": "striare",
    "striereste": "striare",
    "strieresti": "striare",
    "strierete": "striare",
    "strierà": "striare",
    "strierò": "striare",
    "strigli": "strigliare",
    "striglia": "strigliare",
    "strigliai": "strigliare",
    "strigliammo": "strigliare",
    "strigliamo": "strigliare",
    "striglian": "strigliare",
    "strigliando": "strigliare",
    "strigliano": "strigliare",
    "strigliante": "strigliare",
    "striglianti": "strigliare",
    "strigliar": "strigliare",
    "strigliaron": "strigliare",
    "strigliarono": "strigliare",
    "strigliasse": "strigliare",
    "strigliasser": "strigliare",
    "strigliassero": "strigliare",
    "strigliassi": "strigliare",
    "strigliassimo": "strigliare",
    "strigliaste": "strigliare",
    "strigliasti": "strigliare",
    "strigliata": "strigliare",
    "strigliate": "strigliata",
    "strigliati": "strigliare",
    "strigliato": "strigliare",
    "strigliava": "strigliare",
    "strigliavamo": "strigliare",
    "strigliavan": "strigliare",
    "strigliavano": "strigliare",
    "strigliavate": "strigliare",
    "strigliavi": "strigliare",
    "strigliavo": "strigliare",
    "striglierai": "strigliare",
    "striglieran": "strigliare",
    "striglieranno": "strigliare",
    "striglierebbe": "strigliare",
    "striglierebber": "strigliare",
    "striglierebbero": "strigliare",
    "striglierei": "strigliare",
    "striglieremmo": "strigliare",
    "striglieremo": "strigliare",
    "strigliereste": "strigliare",
    "striglieresti": "strigliare",
    "striglierete": "strigliare",
    "striglierà": "strigliare",
    "striglierò": "strigliare",
    "striglin": "strigliare",
    "striglino": "strigliare",
    "striglio": "strigliare",
    "strigliò": "strigliare",
    "strilla": "strillare",
    "strillai": "strillare",
    "strillammo": "strillare",
    "strillan": "strillare",
    "strillando": "strillare",
    "strillano": "strillare",
    "strillante": "strillare",
    "strillanti": "strillare",
    "strillar": "strillare",
    "strillaron": "strillare",
    "strillarono": "strillare",
    "strillasse": "strillare",
    "strillasser": "strillare",
    "strillassero": "strillare",
    "strillassi": "strillare",
    "strillassimo": "strillare",
    "strillaste": "strillare",
    "strillasti": "strillare",
    "strillata": "strillare",
    "strillate": "strillare",
    "strillati": "strillare",
    "strillato": "strillare",
    "strillava": "strillare",
    "strillavamo": "strillare",
    "strillavan": "strillare",
    "strillavano": "strillare",
    "strillavate": "strillare",
    "strillavi": "strillare",
    "strillavo": "strillare",
    "strillerai": "strillare",
    "strilleran": "strillare",
    "strilleranno": "strillare",
    "strillerebbe": "strillare",
    "strillerebber": "strillare",
    "strillerebbero": "strillare",
    "strillerei": "strillare",
    "strilleremmo": "strillare",
    "strilleremo": "strillare",
    "strillereste": "strillare",
    "strilleresti": "strillare",
    "strillerete": "strillare",
    "strillerà": "strillare",
    "strillerò": "strillare",
    "strilli": "strillo",
    "strilliamo": "strillare",
    "strilliate": "strillare",
    "strillin": "strillare",
    "strillino": "strillare",
    "strillo": "strillare",
    "strilloni": "strillone",
    "strillò": "strillare",
    "striminza": "striminzire",
    "striminzan": "striminzire",
    "striminzano": "striminzire",
    "striminze": "striminzire",
    "striminzendo": "striminzire",
    "striminzente": "striminzire",
    "striminzenti": "striminzire",
    "striminzi": "striminzire",
    "striminziamo": "striminzire",
    "striminziate": "striminzire",
    "striminzii": "striminzire",
    "striminzimmo": "striminzire",
    "striminzir": "striminzire",
    "striminzirai": "striminzire",
    "striminziran": "striminzire",
    "striminziranno": "striminzire",
    "striminzirebbe": "striminzire",
    "striminzirebber": "striminzire",
    "striminzirebbero": "striminzire",
    "striminzirei": "striminzire",
    "striminziremmo": "striminzire",
    "striminziremo": "striminzire",
    "striminzireste": "striminzire",
    "striminziresti": "striminzire",
    "striminzirete": "striminzire",
    "striminziron": "striminzire",
    "striminzirono": "striminzire",
    "striminzirà": "striminzire",
    "striminzirò": "striminzire",
    "striminzisse": "striminzire",
    "striminzisser": "striminzire",
    "striminzissero": "striminzire",
    "striminzissi": "striminzire",
    "striminzissimo": "striminzire",
    "striminziste": "striminzire",
    "striminzisti": "striminzire",
    "striminzita": "striminzito",
    "striminzite": "striminzito",
    "striminziti": "striminzito",
    "striminzito": "striminzire",
    "striminziva": "striminzire",
    "striminzivamo": "striminzire",
    "striminzivan": "striminzire",
    "striminzivano": "striminzire",
    "striminzivate": "striminzire",
    "striminzivi": "striminzire",
    "striminzivo": "striminzire",
    "striminzo": "striminzire",
    "striminzon": "striminzire",
    "striminzono": "striminzire",
    "striminzì": "striminzire",
    "strimpella": "strimpellare",
    "strimpellai": "strimpellare",
    "strimpellammo": "strimpellare",
    "strimpellan": "strimpellare",
    "strimpellando": "strimpellare",
    "strimpellano": "strimpellare",
    "strimpellante": "strimpellare",
    "strimpellanti": "strimpellare",
    "strimpellar": "strimpellare",
    "strimpellaron": "strimpellare",
    "strimpellarono": "strimpellare",
    "strimpellasse": "strimpellare",
    "strimpellasser": "strimpellare",
    "strimpellassero": "strimpellare",
    "strimpellassi": "strimpellare",
    "strimpellassimo": "strimpellare",
    "strimpellaste": "strimpellare",
    "strimpellasti": "strimpellare",
    "strimpellata": "strimpellare",
    "strimpellate": "strimpellare",
    "strimpellati": "strimpellare",
    "strimpellato": "strimpellare",
    "strimpellava": "strimpellare",
    "strimpellavamo": "strimpellare",
    "strimpellavan": "strimpellare",
    "strimpellavano": "strimpellare",
    "strimpellavate": "strimpellare",
    "strimpellavi": "strimpellare",
    "strimpellavo": "strimpellare",
    "strimpellerai": "strimpellare",
    "strimpelleran": "strimpellare",
    "strimpelleranno": "strimpellare",
    "strimpellerebbe": "strimpellare",
    "strimpellerebber": "strimpellare",
    "strimpellerebbero": "strimpellare",
    "strimpellerei": "strimpellare",
    "strimpelleremmo": "strimpellare",
    "strimpelleremo": "strimpellare",
    "strimpellereste": "strimpellare",
    "strimpelleresti": "strimpellare",
    "strimpellerete": "strimpellare",
    "strimpellerà": "strimpellare",
    "strimpellerò": "strimpellare",
    "strimpelli": "strimpellare",
    "strimpelliamo": "strimpellare",
    "strimpelliate": "strimpellare",
    "strimpellin": "strimpellare",
    "strimpellino": "strimpellare",
    "strimpello": "strimpellare",
    "strimpellò": "strimpellare",
    "strin": "striare",
    "strina": "strinare",
    "strinai": "strinare",
    "strinammo": "strinare",
    "strinan": "strinare",
    "strinando": "strinare",
    "strinano": "strinare",
    "strinante": "strinare",
    "strinanti": "strinare",
    "strinar": "strinare",
    "strinaron": "strinare",
    "strinarono": "strinare",
    "strinasse": "strinare",
    "strinasser": "strinare",
    "strinassero": "strinare",
    "strinassi": "strinare",
    "strinassimo": "strinare",
    "strinaste": "strinare",
    "strinasti": "strinare",
    "strinata": "strinare",
    "strinate": "strinare",
    "strinati": "strinare",
    "strinato": "strinare",
    "strinava": "strinare",
    "strinavamo": "strinare",
    "strinavan": "strinare",
    "strinavano": "strinare",
    "strinavate": "strinare",
    "strinavi": "strinare",
    "strinavo": "strinare",
    "strinerai": "strinare",
    "strineran": "strinare",
    "strineranno": "strinare",
    "strinerebbe": "strinare",
    "strinerebber": "strinare",
    "strinerebbero": "strinare",
    "strinerei": "strinare",
    "strineremmo": "strinare",
    "strineremo": "strinare",
    "strinereste": "strinare",
    "strineresti": "strinare",
    "strinerete": "strinare",
    "strinerà": "strinare",
    "strinerò": "strinare",
    "stringa": "stringere",
    "stringai": "stringare",
    "stringammo": "stringare",
    "stringan": "stringere",
    "stringando": "stringare",
    "stringano": "stringere",
    "stringante": "stringare",
    "stringanti": "stringare",
    "stringar": "stringare",
    "stringaron": "stringare",
    "stringarono": "stringare",
    "stringasse": "stringare",
    "stringasser": "stringare",
    "stringassero": "stringare",
    "stringassi": "stringare",
    "stringassimo": "stringare",
    "stringaste": "stringare",
    "stringasti": "stringare",
    "stringata": "stringato",
    "stringate": "stringato",
    "stringatezze": "stringatezza",
    "stringati": "stringato",
    "stringato": "stringare",
    "stringava": "stringare",
    "stringavamo": "stringare",
    "stringavan": "stringare",
    "stringavano": "stringare",
    "stringavate": "stringare",
    "stringavi": "stringare",
    "stringavo": "stringare",
    "stringe": "stringere",
    "stringemmo": "stringere",
    "stringendo": "stringere",
    "stringente": "stringere",
    "stringenti": "stringere",
    "stringer": "stringere",
    "stringerai": "stringere",
    "stringeran": "stringere",
    "stringeranno": "stringere",
    "stringerebbe": "stringere",
    "stringerebber": "stringere",
    "stringerebbero": "stringere",
    "stringerei": "stringere",
    "stringeremmo": "stringere",
    "stringeremo": "stringere",
    "stringereste": "stringere",
    "stringeresti": "stringere",
    "stringerete": "stringere",
    "stringerà": "stringere",
    "stringerò": "stringere",
    "stringesse": "stringere",
    "stringesser": "stringere",
    "stringessero": "stringere",
    "stringessi": "stringere",
    "stringessimo": "stringere",
    "stringeste": "stringere",
    "stringesti": "stringere",
    "stringete": "stringere",
    "stringeva": "stringere",
    "stringevamo": "stringere",
    "stringevan": "stringere",
    "stringevano": "stringere",
    "stringevate": "stringere",
    "stringevi": "stringere",
    "stringevo": "stringere",
    "stringherai": "stringare",
    "stringheran": "stringare",
    "stringheranno": "stringare",
    "stringherebbe": "stringare",
    "stringherebber": "stringare",
    "stringherebbero": "stringare",
    "stringherei": "stringare",
    "stringheremmo": "stringare",
    "stringheremo": "stringare",
    "stringhereste": "stringare",
    "stringheresti": "stringare",
    "stringherete": "stringare",
    "stringherà": "stringare",
    "stringherò": "stringare",
    "stringhi": "stringare",
    "stringhiamo": "stringare",
    "stringhiate": "stringare",
    "stringhin": "stringare",
    "stringhino": "stringare",
    "stringi": "stringere",
    "stringiamo": "stringere",
    "stringiate": "stringere",
    "stringo": "stringere",
    "stringon": "stringere",
    "stringono": "stringere",
    "stringò": "stringare",
    "strini": "strinare",
    "striniamo": "strinare",
    "striniate": "strinare",
    "strinin": "strinare",
    "strinino": "strinare",
    "strino": "strinare",
    "strinse": "stringere",
    "strinser": "stringere",
    "strinsero": "stringere",
    "strinsi": "stringere",
    "strinò": "strinare",
    "strio": "striare",
    "striscerai": "strisciare",
    "strisceran": "strisciare",
    "strisceranno": "strisciare",
    "striscerebbe": "strisciare",
    "striscerebber": "strisciare",
    "striscerebbero": "strisciare",
    "striscerei": "strisciare",
    "strisceremmo": "strisciare",
    "strisceremo": "strisciare",
    "striscereste": "strisciare",
    "strisceresti": "strisciare",
    "striscerete": "strisciare",
    "striscerà": "strisciare",
    "striscerò": "strisciare",
    "strisci": "strisciare",
    "striscia": "strisciare",
    "strisciai": "strisciare",
    "strisciammo": "strisciare",
    "strisciamo": "strisciare",
    "striscian": "strisciare",
    "strisciando": "strisciare",
    "strisciano": "strisciare",
    "strisciante": "strisciare",
    "striscianti": "strisciare",
    "strisciar": "strisciare",
    "strisciaron": "strisciare",
    "strisciarono": "strisciare",
    "strisciasse": "strisciare",
    "strisciasser": "strisciare",
    "strisciassero": "strisciare",
    "strisciassi": "strisciare",
    "strisciassimo": "strisciare",
    "strisciaste": "strisciare",
    "strisciasti": "strisciare",
    "strisciata": "strisciare",
    "strisciate": "strisciata",
    "strisciati": "strisciare",
    "strisciato": "strisciare",
    "strisciava": "strisciare",
    "strisciavamo": "strisciare",
    "strisciavan": "strisciare",
    "strisciavano": "strisciare",
    "strisciavate": "strisciare",
    "strisciavi": "strisciare",
    "strisciavo": "strisciare",
    "striscie": "striscia",
    "striscin": "strisciare",
    "striscino": "strisciare",
    "striscio": "strisciare",
    "striscioline": "strisciolina",
    "striscioni": "striscione",
    "strisciò": "strisciare",
    "stritola": "stritolare",
    "stritolai": "stritolare",
    "stritolammo": "stritolare",
    "stritolan": "stritolare",
    "stritolando": "stritolare",
    "stritolano": "stritolare",
    "stritolante": "stritolare",
    "stritolanti": "stritolare",
    "stritolar": "stritolare",
    "stritolaron": "stritolare",
    "stritolarono": "stritolare",
    "stritolasse": "stritolare",
    "stritolasser": "stritolare",
    "stritolassero": "stritolare",
    "stritolassi": "stritolare",
    "stritolassimo": "stritolare",
    "stritolaste": "stritolare",
    "stritolasti": "stritolare",
    "stritolata": "stritolare",
    "stritolate": "stritolare",
    "stritolati": "stritolare",
    "stritolato": "stritolare",
    "stritolava": "stritolare",
    "stritolavamo": "stritolare",
    "stritolavan": "stritolare",
    "stritolavano": "stritolare",
    "stritolavate": "stritolare",
    "stritolavi": "stritolare",
    "stritolavo": "stritolare",
    "stritolerai": "stritolare",
    "stritoleran": "stritolare",
    "stritoleranno": "stritolare",
    "stritolerebbe": "stritolare",
    "stritolerebber": "stritolare",
    "stritolerebbero": "stritolare",
    "stritolerei": "stritolare",
    "stritoleremmo": "stritolare",
    "stritoleremo": "stritolare",
    "stritolereste": "stritolare",
    "stritoleresti": "stritolare",
    "stritolerete": "stritolare",
    "stritolerà": "stritolare",
    "stritolerò": "stritolare",
    "stritoli": "stritolare",
    "stritoliamo": "stritolare",
    "stritoliate": "stritolare",
    "stritolin": "stritolare",
    "stritolino": "stritolare",
    "stritolo": "stritolare",
    "stritolò": "stritolare",
    "strizza": "strizzare",
    "strizzai": "strizzare",
    "strizzammo": "strizzare",
    "strizzan": "strizzare",
    "strizzando": "strizzare",
    "strizzano": "strizzare",
    "strizzante": "strizzare",
    "strizzanti": "strizzare",
    "strizzar": "strizzare",
    "strizzaron": "strizzare",
    "strizzarono": "strizzare",
    "strizzasse": "strizzare",
    "strizzasser": "strizzare",
    "strizzassero": "strizzare",
    "strizzassi": "strizzare",
    "strizzassimo": "strizzare",
    "strizzaste": "strizzare",
    "strizzasti": "strizzare",
    "strizzata": "strizzare",
    "strizzate": "strizzata",
    "strizzati": "strizzare",
    "strizzatine": "strizzatina",
    "strizzato": "strizzare",
    "strizzava": "strizzare",
    "strizzavamo": "strizzare",
    "strizzavan": "strizzare",
    "strizzavano": "strizzare",
    "strizzavate": "strizzare",
    "strizzavi": "strizzare",
    "strizzavo": "strizzare",
    "strizzerai": "strizzare",
    "strizzeran": "strizzare",
    "strizzeranno": "strizzare",
    "strizzerebbe": "strizzare",
    "strizzerebber": "strizzare",
    "strizzerebbero": "strizzare",
    "strizzerei": "strizzare",
    "strizzeremmo": "strizzare",
    "strizzeremo": "strizzare",
    "strizzereste": "strizzare",
    "strizzeresti": "strizzare",
    "strizzerete": "strizzare",
    "strizzerà": "strizzare",
    "strizzerò": "strizzare",
    "strizzi": "strizzare",
    "strizziamo": "strizzare",
    "strizziate": "strizzare",
    "strizzin": "strizzare",
    "strizzino": "strizzare",
    "strizzo": "strizzare",
    "strizzò": "strizzare",
    "striò": "striare",
    "strofe": "strofa",
    "strofette": "strofetta",
    "strofina": "strofinare",
    "strofinacci": "strofinaccio",
    "strofinai": "strofinare",
    "strofinammo": "strofinare",
    "strofinan": "strofinare",
    "strofinando": "strofinare",
    "strofinano": "strofinare",
    "strofinante": "strofinare",
    "strofinanti": "strofinare",
    "strofinar": "strofinare",
    "strofinaron": "strofinare",
    "strofinarono": "strofinare",
    "strofinasse": "strofinare",
    "strofinasser": "strofinare",
    "strofinassero": "strofinare",
    "strofinassi": "strofinare",
    "strofinassimo": "strofinare",
    "strofinaste": "strofinare",
    "strofinasti": "strofinare",
    "strofinata": "strofinare",
    "strofinate": "strofinare",
    "strofinati": "strofinare",
    "strofinato": "strofinare",
    "strofinava": "strofinare",
    "strofinavamo": "strofinare",
    "strofinavan": "strofinare",
    "strofinavano": "strofinare",
    "strofinavate": "strofinare",
    "strofinavi": "strofinare",
    "strofinavo": "strofinare",
    "strofinerai": "strofinare",
    "strofineran": "strofinare",
    "strofineranno": "strofinare",
    "strofinerebbe": "strofinare",
    "strofinerebber": "strofinare",
    "strofinerebbero": "strofinare",
    "strofinerei": "strofinare",
    "strofineremmo": "strofinare",
    "strofineremo": "strofinare",
    "strofinereste": "strofinare",
    "strofineresti": "strofinare",
    "strofinerete": "strofinare",
    "strofinerà": "strofinare",
    "strofinerò": "strofinare",
    "strofini": "strofinare",
    "strofiniamo": "strofinare",
    "strofiniate": "strofinare",
    "strofinin": "strofinare",
    "strofinino": "strofinare",
    "strofino": "strofinare",
    "strofinò": "strofinare",
    "strombazza": "strombazzare",
    "strombazzai": "strombazzare",
    "strombazzammo": "strombazzare",
    "strombazzan": "strombazzare",
    "strombazzando": "strombazzare",
    "strombazzano": "strombazzare",
    "strombazzante": "strombazzare",
    "strombazzanti": "strombazzare",
    "strombazzar": "strombazzare",
    "strombazzaron": "strombazzare",
    "strombazzarono": "strombazzare",
    "strombazzasse": "strombazzare",
    "strombazzasser": "strombazzare",
    "strombazzassero": "strombazzare",
    "strombazzassi": "strombazzare",
    "strombazzassimo": "strombazzare",
    "strombazzaste": "strombazzare",
    "strombazzasti": "strombazzare",
    "strombazzata": "strombazzare",
    "strombazzate": "strombazzare",
    "strombazzati": "strombazzare",
    "strombazzato": "strombazzare",
    "strombazzava": "strombazzare",
    "strombazzavamo": "strombazzare",
    "strombazzavan": "strombazzare",
    "strombazzavano": "strombazzare",
    "strombazzavate": "strombazzare",
    "strombazzavi": "strombazzare",
    "strombazzavo": "strombazzare",
    "strombazzerai": "strombazzare",
    "strombazzeran": "strombazzare",
    "strombazzeranno": "strombazzare",
    "strombazzerebbe": "strombazzare",
    "strombazzerebber": "strombazzare",
    "strombazzerebbero": "strombazzare",
    "strombazzerei": "strombazzare",
    "strombazzeremmo": "strombazzare",
    "strombazzeremo": "strombazzare",
    "strombazzereste": "strombazzare",
    "strombazzeresti": "strombazzare",
    "strombazzerete": "strombazzare",
    "strombazzerà": "strombazzare",
    "strombazzerò": "strombazzare",
    "strombazzi": "strombazzare",
    "strombazziamo": "strombazzare",
    "strombazziate": "strombazzare",
    "strombazzin": "strombazzare",
    "strombazzino": "strombazzare",
    "strombazzo": "strombazzare",
    "strombazzò": "strombazzare",
    "strombetta": "strombettare",
    "strombettai": "strombettare",
    "strombettammo": "strombettare",
    "strombettan": "strombettare",
    "strombettando": "strombettare",
    "strombettano": "strombettare",
    "strombettante": "strombettare",
    "strombettanti": "strombettare",
    "strombettar": "strombettare",
    "strombettaron": "strombettare",
    "strombettarono": "strombettare",
    "strombettasse": "strombettare",
    "strombettasser": "strombettare",
    "strombettassero": "strombettare",
    "strombettassi": "strombettare",
    "strombettassimo": "strombettare",
    "strombettaste": "strombettare",
    "strombettasti": "strombettare",
    "strombettata": "strombettare",
    "strombettate": "strombettare",
    "strombettati": "strombettare",
    "strombettato": "strombettare",
    "strombettava": "strombettare",
    "strombettavamo": "strombettare",
    "strombettavan": "strombettare",
    "strombettavano": "strombettare",
    "strombettavate": "strombettare",
    "strombettavi": "strombettare",
    "strombettavo": "strombettare",
    "strombetterai": "strombettare",
    "strombetteran": "strombettare",
    "strombetteranno": "strombettare",
    "strombetterebbe": "strombettare",
    "strombetterebber": "strombettare",
    "strombetterebbero": "strombettare",
    "strombetterei": "strombettare",
    "strombetteremmo": "strombettare",
    "strombetteremo": "strombettare",
    "strombettereste": "strombettare",
    "strombetteresti": "strombettare",
    "strombetterete": "strombettare",
    "strombetterà": "strombettare",
    "strombetterò": "strombettare",
    "strombetti": "strombettare",
    "strombettiamo": "strombettare",
    "strombettiate": "strombettare",
    "strombettin": "strombettare",
    "strombettino": "strombettare",
    "strombetto": "strombettare",
    "strombettò": "strombettare",
    "stronca": "stroncare",
    "stroncai": "stroncare",
    "stroncammo": "stroncare",
    "stroncan": "stroncare",
    "stroncando": "stroncare",
    "stroncano": "stroncare",
    "stroncante": "stroncare",
    "stroncanti": "stroncare",
    "stroncar": "stroncare",
    "stroncaron": "stroncare",
    "stroncarono": "stroncare",
    "stroncasse": "stroncare",
    "stroncasser": "stroncare",
    "stroncassero": "stroncare",
    "stroncassi": "stroncare",
    "stroncassimo": "stroncare",
    "stroncaste": "stroncare",
    "stroncasti": "stroncare",
    "stroncata": "stroncare",
    "stroncate": "stroncare",
    "stroncati": "stroncare",
    "stroncato": "stroncare",
    "stroncatori": "stroncatore",
    "stroncature": "stroncatura",
    "stroncava": "stroncare",
    "stroncavamo": "stroncare",
    "stroncavan": "stroncare",
    "stroncavano": "stroncare",
    "stroncavate": "stroncare",
    "stroncavi": "stroncare",
    "stroncavo": "stroncare",
    "stroncherai": "stroncare",
    "stroncheran": "stroncare",
    "stroncheranno": "stroncare",
    "stroncherebbe": "stroncare",
    "stroncherebber": "stroncare",
    "stroncherebbero": "stroncare",
    "stroncherei": "stroncare",
    "stroncheremmo": "stroncare",
    "stroncheremo": "stroncare",
    "stronchereste": "stroncare",
    "stroncheresti": "stroncare",
    "stroncherete": "stroncare",
    "stroncherà": "stroncare",
    "stroncherò": "stroncare",
    "stronchi": "stroncare",
    "stronchiamo": "stroncare",
    "stronchiate": "stroncare",
    "stronchin": "stroncare",
    "stronchino": "stroncare",
    "stronco": "stroncare",
    "stroncò": "stroncare",
    "stronfi": "stronfiare",
    "stronfia": "stronfiare",
    "stronfiai": "stronfiare",
    "stronfiammo": "stronfiare",
    "stronfiamo": "stronfiare",
    "stronfian": "stronfiare",
    "stronfiando": "stronfiare",
    "stronfiano": "stronfiare",
    "stronfiante": "stronfiare",
    "stronfianti": "stronfiare",
    "stronfiar": "stronfiare",
    "stronfiaron": "stronfiare",
    "stronfiarono": "stronfiare",
    "stronfiasse": "stronfiare",
    "stronfiasser": "stronfiare",
    "stronfiassero": "stronfiare",
    "stronfiassi": "stronfiare",
    "stronfiassimo": "stronfiare",
    "stronfiaste": "stronfiare",
    "stronfiasti": "stronfiare",
    "stronfiata": "stronfiare",
    "stronfiate": "stronfiare",
    "stronfiati": "stronfiare",
    "stronfiato": "stronfiare",
    "stronfiava": "stronfiare",
    "stronfiavamo": "stronfiare",
    "stronfiavan": "stronfiare",
    "stronfiavano": "stronfiare",
    "stronfiavate": "stronfiare",
    "stronfiavi": "stronfiare",
    "stronfiavo": "stronfiare",
    "stronfierai": "stronfiare",
    "stronfieran": "stronfiare",
    "stronfieranno": "stronfiare",
    "stronfierebbe": "stronfiare",
    "stronfierebber": "stronfiare",
    "stronfierebbero": "stronfiare",
    "stronfierei": "stronfiare",
    "stronfieremmo": "stronfiare",
    "stronfieremo": "stronfiare",
    "stronfiereste": "stronfiare",
    "stronfieresti": "stronfiare",
    "stronfierete": "stronfiare",
    "stronfierà": "stronfiare",
    "stronfierò": "stronfiare",
    "stronfin": "stronfiare",
    "stronfino": "stronfiare",
    "stronfio": "stronfiare",
    "stronfiò": "stronfiare",
    "stronzate": "stronzata",
    "stronzi": "stronzo",
    "stropiccerai": "stropicciare",
    "stropicceran": "stropicciare",
    "stropicceranno": "stropicciare",
    "stropiccerebbe": "stropicciare",
    "stropiccerebber": "stropicciare",
    "stropiccerebbero": "stropicciare",
    "stropiccerei": "stropicciare",
    "stropicceremmo": "stropicciare",
    "stropicceremo": "stropicciare",
    "stropiccereste": "stropicciare",
    "stropicceresti": "stropicciare",
    "stropiccerete": "stropicciare",
    "stropiccerà": "stropicciare",
    "stropiccerò": "stropicciare",
    "stropicci": "stropicciare",
    "stropiccia": "stropicciare",
    "stropicciai": "stropicciare",
    "stropicciammo": "stropicciare",
    "stropicciamo": "stropicciare",
    "stropiccian": "stropicciare",
    "stropicciando": "stropicciare",
    "stropicciano": "stropicciare",
    "stropicciante": "stropicciare",
    "stropiccianti": "stropicciare",
    "stropicciar": "stropicciare",
    "stropicciaron": "stropicciare",
    "stropicciarono": "stropicciare",
    "stropicciasse": "stropicciare",
    "stropicciasser": "stropicciare",
    "stropicciassero": "stropicciare",
    "stropicciassi": "stropicciare",
    "stropicciassimo": "stropicciare",
    "stropicciaste": "stropicciare",
    "stropicciasti": "stropicciare",
    "stropicciata": "stropicciare",
    "stropicciate": "stropicciare",
    "stropicciati": "stropicciare",
    "stropicciato": "stropicciare",
    "stropicciava": "stropicciare",
    "stropicciavamo": "stropicciare",
    "stropicciavan": "stropicciare",
    "stropicciavano": "stropicciare",
    "stropicciavate": "stropicciare",
    "stropicciavi": "stropicciare",
    "stropicciavo": "stropicciare",
    "stropiccin": "stropicciare",
    "stropiccino": "stropicciare",
    "stropiccio": "stropicciare",
    "stropicciò": "stropicciare",
    "stroppi": "stroppiare",
    "stroppia": "stroppiare",
    "stroppiai": "stroppiare",
    "stroppiammo": "stroppiare",
    "stroppiamo": "stroppiare",
    "stroppian": "stroppiare",
    "stroppiando": "stroppiare",
    "stroppiano": "stroppiare",
    "stroppiante": "stroppiare",
    "stroppianti": "stroppiare",
    "stroppiar": "stroppiare",
    "stroppiaron": "stroppiare",
    "stroppiarono": "stroppiare",
    "stroppiasse": "stroppiare",
    "stroppiasser": "stroppiare",
    "stroppiassero": "stroppiare",
    "stroppiassi": "stroppiare",
    "stroppiassimo": "stroppiare",
    "stroppiaste": "stroppiare",
    "stroppiasti": "stroppiare",
    "stroppiata": "stroppiare",
    "stroppiate": "stroppiare",
    "stroppiati": "stroppiare",
    "stroppiato": "stroppiare",
    "stroppiava": "stroppiare",
    "stroppiavamo": "stroppiare",
    "stroppiavan": "stroppiare",
    "stroppiavano": "stroppiare",
    "stroppiavate": "stroppiare",
    "stroppiavi": "stroppiare",
    "stroppiavo": "stroppiare",
    "stroppierai": "stroppiare",
    "stroppieran": "stroppiare",
    "stroppieranno": "stroppiare",
    "stroppierebbe": "stroppiare",
    "stroppierebber": "stroppiare",
    "stroppierebbero": "stroppiare",
    "stroppierei": "stroppiare",
    "stroppieremmo": "stroppiare",
    "stroppieremo": "stroppiare",
    "stroppiereste": "stroppiare",
    "stroppieresti": "stroppiare",
    "stroppierete": "stroppiare",
    "stroppierà": "stroppiare",
    "stroppierò": "stroppiare",
    "stroppin": "stroppiare",
    "stroppino": "stroppiare",
    "stroppio": "stroppiare",
    "stroppiò": "stroppiare",
    "strozza": "strozzare",
    "strozzai": "strozzare",
    "strozzammo": "strozzare",
    "strozzan": "strozzare",
    "strozzando": "strozzare",
    "strozzano": "strozzare",
    "strozzante": "strozzare",
    "strozzanti": "strozzare",
    "strozzar": "strozzare",
    "strozzaron": "strozzare",
    "strozzarono": "strozzare",
    "strozzasse": "strozzare",
    "strozzasser": "strozzare",
    "strozzassero": "strozzare",
    "strozzassi": "strozzare",
    "strozzassimo": "strozzare",
    "strozzaste": "strozzare",
    "strozzasti": "strozzare",
    "strozzata": "strozzato",
    "strozzate": "strozzato",
    "strozzati": "strozzato",
    "strozzato": "strozzare",
    "strozzature": "strozzatura",
    "strozzava": "strozzare",
    "strozzavamo": "strozzare",
    "strozzavan": "strozzare",
    "strozzavano": "strozzare",
    "strozzavate": "strozzare",
    "strozzavi": "strozzare",
    "strozzavo": "strozzare",
    "strozzerai": "strozzare",
    "strozzeran": "strozzare",
    "strozzeranno": "strozzare",
    "strozzerebbe": "strozzare",
    "strozzerebber": "strozzare",
    "strozzerebbero": "strozzare",
    "strozzerei": "strozzare",
    "strozzeremmo": "strozzare",
    "strozzeremo": "strozzare",
    "strozzereste": "strozzare",
    "strozzeresti": "strozzare",
    "strozzerete": "strozzare",
    "strozzerà": "strozzare",
    "strozzerò": "strozzare",
    "strozzi": "strozzare",
    "strozziamo": "strozzare",
    "strozziate": "strozzare",
    "strozzin": "strozzare",
    "strozzini": "strozzino",
    "strozzino": "strozzare",
    "strozzo": "strozzare",
    "strozzò": "strozzare",
    "strucca": "struccare",
    "struccai": "struccare",
    "struccammo": "struccare",
    "struccan": "struccare",
    "struccando": "struccare",
    "struccano": "struccare",
    "struccante": "struccare",
    "struccanti": "struccare",
    "struccar": "struccare",
    "struccaron": "struccare",
    "struccarono": "struccare",
    "struccasse": "struccare",
    "struccasser": "struccare",
    "struccassero": "struccare",
    "struccassi": "struccare",
    "struccassimo": "struccare",
    "struccaste": "struccare",
    "struccasti": "struccare",
    "struccata": "struccare",
    "struccate": "struccare",
    "struccati": "struccare",
    "struccato": "struccare",
    "struccava": "struccare",
    "struccavamo": "struccare",
    "struccavan": "struccare",
    "struccavano": "struccare",
    "struccavate": "struccare",
    "struccavi": "struccare",
    "struccavo": "struccare",
    "struccherai": "struccare",
    "struccheran": "struccare",
    "struccheranno": "struccare",
    "struccherebbe": "struccare",
    "struccherebber": "struccare",
    "struccherebbero": "struccare",
    "struccherei": "struccare",
    "struccheremmo": "struccare",
    "struccheremo": "struccare",
    "strucchereste": "struccare",
    "struccheresti": "struccare",
    "struccherete": "struccare",
    "struccherà": "struccare",
    "struccherò": "struccare",
    "strucchi": "struccare",
    "strucchiamo": "struccare",
    "strucchiate": "struccare",
    "strucchin": "struccare",
    "strucchino": "struccare",
    "strucco": "struccare",
    "struccò": "struccare",
    "strugga": "struggere",
    "struggan": "struggere",
    "struggano": "struggere",
    "strugge": "struggere",
    "struggemmo": "struggere",
    "struggendo": "struggere",
    "struggente": "struggere",
    "struggenti": "struggere",
    "strugger": "struggere",
    "struggerai": "struggere",
    "struggeran": "struggere",
    "struggeranno": "struggere",
    "struggerebbe": "struggere",
    "struggerebber": "struggere",
    "struggerebbero": "struggere",
    "struggerei": "struggere",
    "struggeremmo": "struggere",
    "struggeremo": "struggere",
    "struggereste": "struggere",
    "struggeresti": "struggere",
    "struggerete": "struggere",
    "struggerà": "struggere",
    "struggerò": "struggere",
    "struggesse": "struggere",
    "struggesser": "struggere",
    "struggessero": "struggere",
    "struggessi": "struggere",
    "struggessimo": "struggere",
    "struggeste": "struggere",
    "struggesti": "struggere",
    "struggete": "struggere",
    "struggeva": "struggere",
    "struggevamo": "struggere",
    "struggevan": "struggere",
    "struggevano": "struggere",
    "struggevate": "struggere",
    "struggevi": "struggere",
    "struggevo": "struggere",
    "struggi": "struggere",
    "struggiamo": "struggere",
    "struggiate": "struggere",
    "struggimenti": "struggimento",
    "struggo": "struggere",
    "struggon": "struggere",
    "struggono": "struggere",
    "strumenta": "strumentare",
    "strumentai": "strumentare",
    "strumentali": "strumentale",
    "strumentalismi": "strumentalismo",
    "strumentalizza": "strumentalizzare",
    "strumentalizzai": "strumentalizzare",
    "strumentalizzammo": "strumentalizzare",
    "strumentalizzan": "strumentalizzare",
    "strumentalizzando": "strumentalizzare",
    "strumentalizzano": "strumentalizzare",
    "strumentalizzante": "strumentalizzare",
    "strumentalizzanti": "strumentalizzare",
    "strumentalizzar": "strumentalizzare",
    "strumentalizzaron": "strumentalizzare",
    "strumentalizzarono": "strumentalizzare",
    "strumentalizzasse": "strumentalizzare",
    "strumentalizzasser": "strumentalizzare",
    "strumentalizzassero": "strumentalizzare",
    "strumentalizzassi": "strumentalizzare",
    "strumentalizzassimo": "strumentalizzare",
    "strumentalizzaste": "strumentalizzare",
    "strumentalizzasti": "strumentalizzare",
    "strumentalizzata": "strumentalizzare",
    "strumentalizzate": "strumentalizzare",
    "strumentalizzati": "strumentalizzare",
    "strumentalizzato": "strumentalizzare",
    "strumentalizzava": "strumentalizzare",
    "strumentalizzavamo": "strumentalizzare",
    "strumentalizzavan": "strumentalizzare",
    "strumentalizzavano": "strumentalizzare",
    "strumentalizzavate": "strumentalizzare",
    "strumentalizzavi": "strumentalizzare",
    "strumentalizzavo": "strumentalizzare",
    "strumentalizzazioni": "strumentalizzazione",
    "strumentalizzerai": "strumentalizzare",
    "strumentalizzeran": "strumentalizzare",
    "strumentalizzeranno": "strumentalizzare",
    "strumentalizzerebbe": "strumentalizzare",
    "strumentalizzerebber": "strumentalizzare",
    "strumentalizzerebbero": "strumentalizzare",
    "strumentalizzerei": "strumentalizzare",
    "strumentalizzeremmo": "strumentalizzare",
    "strumentalizzeremo": "strumentalizzare",
    "strumentalizzereste": "strumentalizzare",
    "strumentalizzeresti": "strumentalizzare",
    "strumentalizzerete": "strumentalizzare",
    "strumentalizzerà": "strumentalizzare",
    "strumentalizzerò": "strumentalizzare",
    "strumentalizzi": "strumentalizzare",
    "strumentalizziamo": "strumentalizzare",
    "strumentalizziate": "strumentalizzare",
    "strumentalizzin": "strumentalizzare",
    "strumentalizzino": "strumentalizzare",
    "strumentalizzo": "strumentalizzare",
    "strumentalizzò": "strumentalizzare",
    "strumentammo": "strumentare",
    "strumentan": "strumentare",
    "strumentando": "strumentare",
    "strumentano": "strumentare",
    "strumentante": "strumentare",
    "strumentanti": "strumentare",
    "strumentar": "strumentare",
    "strumentaron": "strumentare",
    "strumentarono": "strumentare",
    "strumentasse": "strumentare",
    "strumentasser": "strumentare",
    "strumentassero": "strumentare",
    "strumentassi": "strumentare",
    "strumentassimo": "strumentare",
    "strumentaste": "strumentare",
    "strumentasti": "strumentare",
    "strumentata": "strumentare",
    "strumentate": "strumentare",
    "strumentati": "strumentare",
    "strumentato": "strumentare",
    "strumentava": "strumentare",
    "strumentavamo": "strumentare",
    "strumentavan": "strumentare",
    "strumentavano": "strumentare",
    "strumentavate": "strumentare",
    "strumentavi": "strumentare",
    "strumentavo": "strumentare",
    "strumentazioni": "strumentazione",
    "strumenterai": "strumentare",
    "strumenteran": "strumentare",
    "strumenteranno": "strumentare",
    "strumenterebbe": "strumentare",
    "strumenterebber": "strumentare",
    "strumenterebbero": "strumentare",
    "strumenterei": "strumentare",
    "strumenteremmo": "strumentare",
    "strumenteremo": "strumentare",
    "strumentereste": "strumentare",
    "strumenteresti": "strumentare",
    "strumenterete": "strumentare",
    "strumenterà": "strumentare",
    "strumenterò": "strumentare",
    "strumenti": "strumento",
    "strumentiamo": "strumentare",
    "strumentiate": "strumentare",
    "strumentin": "strumentare",
    "strumentino": "strumentare",
    "strumentisti": "strumentista",
    "strumento": "strumentare",
    "strumentò": "strumentare",
    "struscerai": "strusciare",
    "strusceran": "strusciare",
    "strusceranno": "strusciare",
    "struscerebbe": "strusciare",
    "struscerebber": "strusciare",
    "struscerebbero": "strusciare",
    "struscerei": "strusciare",
    "strusceremmo": "strusciare",
    "strusceremo": "strusciare",
    "struscereste": "strusciare",
    "strusceresti": "strusciare",
    "struscerete": "strusciare",
    "struscerà": "strusciare",
    "struscerò": "strusciare",
    "strusci": "struscio",
    "struscia": "strusciare",
    "strusciai": "strusciare",
    "strusciammo": "strusciare",
    "strusciamo": "strusciare",
    "struscian": "strusciare",
    "strusciando": "strusciare",
    "strusciano": "strusciare",
    "strusciante": "strusciare",
    "struscianti": "strusciare",
    "strusciar": "strusciare",
    "strusciaron": "strusciare",
    "strusciarono": "strusciare",
    "strusciasse": "strusciare",
    "strusciasser": "strusciare",
    "strusciassero": "strusciare",
    "strusciassi": "strusciare",
    "strusciassimo": "strusciare",
    "strusciaste": "strusciare",
    "strusciasti": "strusciare",
    "strusciata": "strusciare",
    "strusciate": "strusciare",
    "strusciati": "strusciare",
    "strusciato": "strusciare",
    "strusciava": "strusciare",
    "strusciavamo": "strusciare",
    "strusciavan": "strusciare",
    "strusciavano": "strusciare",
    "strusciavate": "strusciare",
    "strusciavi": "strusciare",
    "strusciavo": "strusciare",
    "struscin": "strusciare",
    "struscino": "strusciare",
    "struscio": "strusciare",
    "strusciò": "strusciare",
    "strusser": "struggere",
    "strussero": "struggere",
    "strussi": "struggere",
    "strussè": "struggere",
    "strutta": "struggere",
    "strutte": "struggere",
    "strutti": "struggere",
    "strutto": "struggere",
    "struttura": "strutturare",
    "strutturai": "strutturare",
    "strutturali": "strutturale",
    "strutturalismi": "strutturalismo",
    "strutturammo": "strutturare",
    "strutturan": "strutturare",
    "strutturando": "strutturare",
    "strutturano": "strutturare",
    "strutturante": "strutturare",
    "strutturanti": "strutturare",
    "strutturar": "strutturare",
    "strutturaron": "strutturare",
    "strutturarono": "strutturare",
    "strutturasse": "strutturare",
    "strutturasser": "strutturare",
    "strutturassero": "strutturare",
    "strutturassi": "strutturare",
    "strutturassimo": "strutturare",
    "strutturaste": "strutturare",
    "strutturasti": "strutturare",
    "strutturata": "strutturato",
    "strutturate": "strutturato",
    "strutturati": "strutturato",
    "strutturato": "strutturare",
    "strutturava": "strutturare",
    "strutturavamo": "strutturare",
    "strutturavan": "strutturare",
    "strutturavano": "strutturare",
    "strutturavate": "strutturare",
    "strutturavi": "strutturare",
    "strutturavo": "strutturare",
    "strutturazioni": "strutturazione",
    "strutture": "struttura",
    "strutturerai": "strutturare",
    "struttureran": "strutturare",
    "struttureranno": "strutturare",
    "strutturerebbe": "strutturare",
    "strutturerebber": "strutturare",
    "strutturerebbero": "strutturare",
    "strutturerei": "strutturare",
    "struttureremmo": "strutturare",
    "struttureremo": "strutturare",
    "strutturereste": "strutturare",
    "struttureresti": "strutturare",
    "strutturerete": "strutturare",
    "strutturerà": "strutturare",
    "strutturerò": "strutturare",
    "strutturi": "strutturare",
    "strutturiamo": "strutturare",
    "strutturiate": "strutturare",
    "strutturin": "strutturare",
    "strutturino": "strutturare",
    "strutturo": "strutturare",
    "strutturò": "strutturare",
    "struzzi": "struzzo",
    "stucca": "stucco",
    "stuccai": "stuccare",
    "stuccammo": "stuccare",
    "stuccan": "stuccare",
    "stuccando": "stuccare",
    "stuccano": "stuccare",
    "stuccante": "stuccare",
    "stuccanti": "stuccare",
    "stuccar": "stuccare",
    "stuccaron": "stuccare",
    "stuccarono": "stuccare",
    "stuccasse": "stuccare",
    "stuccasser": "stuccare",
    "stuccassero": "stuccare",
    "stuccassi": "stuccare",
    "stuccassimo": "stuccare",
    "stuccaste": "stuccare",
    "stuccasti": "stuccare",
    "stuccata": "stuccare",
    "stuccate": "stuccare",
    "stuccati": "stuccare",
    "stuccato": "stuccare",
    "stuccava": "stuccare",
    "stuccavamo": "stuccare",
    "stuccavan": "stuccare",
    "stuccavano": "stuccare",
    "stuccavate": "stuccare",
    "stuccavi": "stuccare",
    "stuccavo": "stuccare",
    "stucche": "stucco",
    "stuccherai": "stuccare",
    "stuccheran": "stuccare",
    "stuccheranno": "stuccare",
    "stuccherebbe": "stuccare",
    "stuccherebber": "stuccare",
    "stuccherebbero": "stuccare",
    "stuccherei": "stuccare",
    "stuccheremmo": "stuccare",
    "stuccheremo": "stuccare",
    "stucchereste": "stuccare",
    "stuccheresti": "stuccare",
    "stuccherete": "stuccare",
    "stuccherà": "stuccare",
    "stuccherò": "stuccare",
    "stucchevoli": "stucchevole",
    "stucchi": "stucco",
    "stucchiamo": "stuccare",
    "stucchiate": "stuccare",
    "stucchin": "stuccare",
    "stucchino": "stuccare",
    "stucco": "stuccare",
    "stuccò": "stuccare",
    "studentelli": "studentello",
    "studentesca": "studentesco",
    "studentesche": "studentesco",
    "studenteschi": "studentesco",
    "studentesse": "studentessa",
    "studenti": "studente",
    "studi": "studio",
    "studia": "studiare",
    "studiai": "studiare",
    "studiammo": "studiare",
    "studiamo": "studiare",
    "studian": "studiare",
    "studiando": "studiare",
    "studiano": "studiare",
    "studiante": "studiare",
    "studianti": "studiare",
    "studiar": "studiare",
    "studiaron": "studiare",
    "studiarono": "studiare",
    "studiasse": "studiare",
    "studiasser": "studiare",
    "studiassero": "studiare",
    "studiassi": "studiare",
    "studiassimo": "studiare",
    "studiaste": "studiare",
    "studiasti": "studiare",
    "studiata": "studiato",
    "studiate": "studiato",
    "studiati": "studiato",
    "studiato": "studiare",
    "studiava": "studiare",
    "studiavamo": "studiare",
    "studiavan": "studiare",
    "studiavano": "studiare",
    "studiavate": "studiare",
    "studiavi": "studiare",
    "studiavo": "studiare",
    "studierai": "studiare",
    "studieran": "studiare",
    "studieranno": "studiare",
    "studierebbe": "studiare",
    "studierebber": "studiare",
    "studierebbero": "studiare",
    "studierei": "studiare",
    "studieremmo": "studiare",
    "studieremo": "studiare",
    "studiereste": "studiare",
    "studieresti": "studiare",
    "studierete": "studiare",
    "studierà": "studiare",
    "studierò": "studiare",
    "studin": "studiare",
    "studino": "studiare",
    "studio": "studiare",
    "studioli": "studiolo",
    "studios": "studio",
    "studiosa": "studioso",
    "studiose": "studioso",
    "studiosi": "studioso",
    "studiò": "studiare",
    "stufa": "stufo",
    "stufai": "stufare",
    "stufammo": "stufare",
    "stufan": "stufare",
    "stufando": "stufare",
    "stufano": "stufare",
    "stufante": "stufare",
    "stufanti": "stufare",
    "stufar": "stufare",
    "stufaron": "stufare",
    "stufarono": "stufare",
    "stufasse": "stufare",
    "stufasser": "stufare",
    "stufassero": "stufare",
    "stufassi": "stufare",
    "stufassimo": "stufare",
    "stufaste": "stufare",
    "stufasti": "stufare",
    "stufata": "stufato",
    "stufate": "stufato",
    "stufati": "stufato",
    "stufato": "stufare",
    "stufava": "stufare",
    "stufavamo": "stufare",
    "stufavan": "stufare",
    "stufavano": "stufare",
    "stufavate": "stufare",
    "stufavi": "stufare",
    "stufavo": "stufare",
    "stufe": "stufo",
    "stuferai": "stufare",
    "stuferan": "stufare",
    "stuferanno": "stufare",
    "stuferebbe": "stufare",
    "stuferebber": "stufare",
    "stuferebbero": "stufare",
    "stuferei": "stufare",
    "stuferemmo": "stufare",
    "stuferemo": "stufare",
    "stufereste": "stufare",
    "stuferesti": "stufare",
    "stuferete": "stufare",
    "stuferà": "stufare",
    "stuferò": "stufare",
    "stufette": "stufetta",
    "stufi": "stufo",
    "stufiamo": "stufare",
    "stufiate": "stufare",
    "stufin": "stufare",
    "stufino": "stufare",
    "stufo": "stufare",
    "stufò": "stufare",
    "stuoie": "stuoia",
    "stuoli": "stuolo",
    "stupefa": "stupefare",
    "stupefa'": "stupefare",
    "stupefaccia": "stupefare",
    "stupefacciamo": "stupefare",
    "stupefaccian": "stupefare",
    "stupefacciano": "stupefare",
    "stupefacciate": "stupefare",
    "stupefaccio": "stupefare",
    "stupefacemmo": "stupefare",
    "stupefacendo": "stupefare",
    "stupefacente": "stupefare",
    "stupefacenti": "stupefare",
    "stupefacesse": "stupefare",
    "stupefacesser": "stupefare",
    "stupefacessero": "stupefare",
    "stupefacessi": "stupefare",
    "stupefacessimo": "stupefare",
    "stupefaceste": "stupefare",
    "stupefacesti": "stupefare",
    "stupefaceva": "stupefare",
    "stupefacevamo": "stupefare",
    "stupefacevan": "stupefare",
    "stupefacevano": "stupefare",
    "stupefacevate": "stupefare",
    "stupefacevi": "stupefare",
    "stupefacevo": "stupefare",
    "stupefai": "stupefare",
    "stupefan": "stupefare",
    "stupefanno": "stupefare",
    "stupefar": "stupefare",
    "stupefarai": "stupefare",
    "stupefaran": "stupefare",
    "stupefaranno": "stupefare",
    "stupefarebbe": "stupefare",
    "stupefarebber": "stupefare",
    "stupefarebbero": "stupefare",
    "stupefarei": "stupefare",
    "stupefaremmo": "stupefare",
    "stupefaremo": "stupefare",
    "stupefareste": "stupefare",
    "stupefaresti": "stupefare",
    "stupefarete": "stupefare",
    "stupefarà": "stupefare",
    "stupefarò": "stupefare",
    "stupefate": "stupefare",
    "stupefatta": "stupefare",
    "stupefatte": "stupefare",
    "stupefatti": "stupefatto",
    "stupefatto": "stupefare",
    "stupefazioni": "stupefazione",
    "stupefece": "stupefare",
    "stupefecer": "stupefare",
    "stupefecero": "stupefare",
    "stupefeci": "stupefare",
    "stupenda": "stupendo",
    "stupende": "stupendo",
    "stupendi": "stupendo",
    "stupendo": "stupire",
    "stupente": "stupire",
    "stupenti": "stupire",
    "stupiamo": "stupire",
    "stupiate": "stupire",
    "stupida": "stupido",
    "stupidaggini": "stupidaggine",
    "stupidan": "stupidire",
    "stupidano": "stupidire",
    "stupidari": "stupidario",
    "stupidate": "stupidata",
    "stupide": "stupido",
    "stupidendo": "stupidire",
    "stupidente": "stupidire",
    "stupidenti": "stupidire",
    "stupidi": "stupido",
    "stupidiamo": "stupidire",
    "stupidiate": "stupidire",
    "stupidii": "stupidire",
    "stupidimmo": "stupidire",
    "stupidir": "stupidire",
    "stupidirai": "stupidire",
    "stupidiran": "stupidire",
    "stupidiranno": "stupidire",
    "stupidirebbe": "stupidire",
    "stupidirebber": "stupidire",
    "stupidirebbero": "stupidire",
    "stupidirei": "stupidire",
    "stupidiremmo": "stupidire",
    "stupidiremo": "stupidire",
    "stupidireste": "stupidire",
    "stupidiresti": "stupidire",
    "stupidirete": "stupidire",
    "stupidiron": "stupidire",
    "stupidirono": "stupidire",
    "stupidirà": "stupidire",
    "stupidirò": "stupidire",
    "stupidisse": "stupidire",
    "stupidisser": "stupidire",
    "stupidissero": "stupidire",
    "stupidissi": "stupidire",
    "stupidissimo": "stupidire",
    "stupidiste": "stupidire",
    "stupidisti": "stupidire",
    "stupidita": "stupidire",
    "stupidite": "stupidire",
    "stupiditi": "stupidire",
    "stupidito": "stupidire",
    "stupidiva": "stupidire",
    "stupidivamo": "stupidire",
    "stupidivan": "stupidire",
    "stupidivano": "stupidire",
    "stupidivate": "stupidire",
    "stupidivi": "stupidire",
    "stupidivo": "stupidire",
    "stupido": "stupidire",
    "stupidon": "stupidire",
    "stupidono": "stupidire",
    "stupidì": "stupidire",
    "stupii": "stupire",
    "stupimmo": "stupire",
    "stupir": "stupire",
    "stupirai": "stupire",
    "stupiran": "stupire",
    "stupiranno": "stupire",
    "stupirebbe": "stupire",
    "stupirebber": "stupire",
    "stupirebbero": "stupire",
    "stupirei": "stupire",
    "stupiremmo": "stupire",
    "stupiremo": "stupire",
    "stupireste": "stupire",
    "stupiresti": "stupire",
    "stupirete": "stupire",
    "stupiron": "stupire",
    "stupirono": "stupire",
    "stupirà": "stupire",
    "stupirò": "stupire",
    "stupisca": "stupire",
    "stupiscan": "stupire",
    "stupiscano": "stupire",
    "stupisce": "stupire",
    "stupisci": "stupire",
    "stupisco": "stupire",
    "stupiscon": "stupire",
    "stupiscono": "stupire",
    "stupisse": "stupire",
    "stupisser": "stupire",
    "stupissero": "stupire",
    "stupissi": "stupire",
    "stupissimo": "stupire",
    "stupiste": "stupire",
    "stupisti": "stupire",
    "stupita": "stupito",
    "stupite": "stupito",
    "stupiti": "stupito",
    "stupito": "stupire",
    "stupiva": "stupire",
    "stupivamo": "stupire",
    "stupivan": "stupire",
    "stupivano": "stupire",
    "stupivate": "stupire",
    "stupivi": "stupire",
    "stupivo": "stupire",
    "stupori": "stupore",
    "stupra": "stuprare",
    "stuprai": "stuprare",
    "stuprammo": "stuprare",
    "stupran": "stuprare",
    "stuprando": "stuprare",
    "stuprano": "stuprare",
    "stuprante": "stuprare",
    "stupranti": "stuprare",
    "stuprar": "stuprare",
    "stupraron": "stuprare",
    "stuprarono": "stuprare",
    "stuprasse": "stuprare",
    "stuprasser": "stuprare",
    "stuprassero": "stuprare",
    "stuprassi": "stuprare",
    "stuprassimo": "stuprare",
    "stupraste": "stuprare",
    "stuprasti": "stuprare",
    "stuprata": "stuprare",
    "stuprate": "stuprare",
    "stuprati": "stuprare",
    "stuprato": "stuprare",
    "stupratori": "stupratore",
    "stuprava": "stuprare",
    "stupravamo": "stuprare",
    "stupravan": "stuprare",
    "stupravano": "stuprare",
    "stupravate": "stuprare",
    "stupravi": "stuprare",
    "stupravo": "stuprare",
    "stuprerai": "stuprare",
    "stupreran": "stuprare",
    "stupreranno": "stuprare",
    "stuprerebbe": "stuprare",
    "stuprerebber": "stuprare",
    "stuprerebbero": "stuprare",
    "stuprerei": "stuprare",
    "stupreremmo": "stuprare",
    "stupreremo": "stuprare",
    "stuprereste": "stuprare",
    "stupreresti": "stuprare",
    "stuprerete": "stuprare",
    "stuprerà": "stuprare",
    "stuprerò": "stuprare",
    "stupri": "stupro",
    "stupriamo": "stuprare",
    "stupriate": "stuprare",
    "stuprin": "stuprare",
    "stuprino": "stuprare",
    "stupro": "stuprare",
    "stuprò": "stuprare",
    "stupì": "stupire",
    "stura": "sturare",
    "sturai": "sturare",
    "sturammo": "sturare",
    "sturan": "sturare",
    "sturando": "sturare",
    "sturano": "sturare",
    "sturante": "sturare",
    "sturanti": "sturare",
    "sturar": "sturare",
    "sturaron": "sturare",
    "sturarono": "sturare",
    "sturasse": "sturare",
    "sturasser": "sturare",
    "sturassero": "sturare",
    "sturassi": "sturare",
    "sturassimo": "sturare",
    "sturaste": "sturare",
    "sturasti": "sturare",
    "sturata": "sturare",
    "sturate": "sturare",
    "sturati": "sturare",
    "sturato": "sturare",
    "sturava": "sturare",
    "sturavamo": "sturare",
    "sturavan": "sturare",
    "sturavano": "sturare",
    "sturavate": "sturare",
    "sturavi": "sturare",
    "sturavo": "sturare",
    "sturerai": "sturare",
    "stureran": "sturare",
    "stureranno": "sturare",
    "sturerebbe": "sturare",
    "sturerebber": "sturare",
    "sturerebbero": "sturare",
    "sturerei": "sturare",
    "stureremmo": "sturare",
    "stureremo": "sturare",
    "sturereste": "sturare",
    "stureresti": "sturare",
    "sturerete": "sturare",
    "sturerà": "sturare",
    "sturerò": "sturare",
    "sturi": "sturare",
    "sturiamo": "sturare",
    "sturiate": "sturare",
    "sturin": "sturare",
    "sturino": "sturare",
    "sturo": "sturare",
    "sturò": "sturare",
    "stuzzica": "stuzzicare",
    "stuzzicai": "stuzzicare",
    "stuzzicammo": "stuzzicare",
    "stuzzican": "stuzzicare",
    "stuzzicando": "stuzzicare",
    "stuzzicano": "stuzzicare",
    "stuzzicante": "stuzzicare",
    "stuzzicanti": "stuzzicare",
    "stuzzicar": "stuzzicare",
    "stuzzicaron": "stuzzicare",
    "stuzzicarono": "stuzzicare",
    "stuzzicasse": "stuzzicare",
    "stuzzicasser": "stuzzicare",
    "stuzzicassero": "stuzzicare",
    "stuzzicassi": "stuzzicare",
    "stuzzicassimo": "stuzzicare",
    "stuzzicaste": "stuzzicare",
    "stuzzicasti": "stuzzicare",
    "stuzzicata": "stuzzicare",
    "stuzzicate": "stuzzicare",
    "stuzzicati": "stuzzicare",
    "stuzzicato": "stuzzicare",
    "stuzzicava": "stuzzicare",
    "stuzzicavamo": "stuzzicare",
    "stuzzicavan": "stuzzicare",
    "stuzzicavano": "stuzzicare",
    "stuzzicavate": "stuzzicare",
    "stuzzicavi": "stuzzicare",
    "stuzzicavo": "stuzzicare",
    "stuzzicherai": "stuzzicare",
    "stuzzicheran": "stuzzicare",
    "stuzzicheranno": "stuzzicare",
    "stuzzicherebbe": "stuzzicare",
    "stuzzicherebber": "stuzzicare",
    "stuzzicherebbero": "stuzzicare",
    "stuzzicherei": "stuzzicare",
    "stuzzicheremmo": "stuzzicare",
    "stuzzicheremo": "stuzzicare",
    "stuzzichereste": "stuzzicare",
    "stuzzicheresti": "stuzzicare",
    "stuzzicherete": "stuzzicare",
    "stuzzicherà": "stuzzicare",
    "stuzzicherò": "stuzzicare",
    "stuzzichi": "stuzzicare",
    "stuzzichiamo": "stuzzicare",
    "stuzzichiate": "stuzzicare",
    "stuzzichin": "stuzzicare",
    "stuzzichino": "stuzzicare",
    "stuzzico": "stuzzicare",
    "stuzzicò": "stuzzicare",
    "sua": "suo",
    "suada": "suadere",
    "suadan": "suadere",
    "suadano": "suadere",
    "suade": "suadere",
    "suademmo": "suadere",
    "suadendo": "suadere",
    "suadente": "suadere",
    "suadenti": "suadere",
    "suader": "suadere",
    "suaderai": "suadere",
    "suaderan": "suadere",
    "suaderanno": "suadere",
    "suaderebbe": "suadere",
    "suaderebber": "suadere",
    "suaderebbero": "suadere",
    "suaderei": "suadere",
    "suaderemmo": "suadere",
    "suaderemo": "suadere",
    "suadereste": "suadere",
    "suaderesti": "suadere",
    "suaderete": "suadere",
    "suaderà": "suadere",
    "suaderò": "suadere",
    "suadesse": "suadere",
    "suadesser": "suadere",
    "suadessero": "suadere",
    "suadessi": "suadere",
    "suadessimo": "suadere",
    "suadeste": "suadere",
    "suadesti": "suadere",
    "suadete": "suadere",
    "suadeva": "suadere",
    "suadevamo": "suadere",
    "suadevan": "suadere",
    "suadevano": "suadere",
    "suadevate": "suadere",
    "suadevi": "suadere",
    "suadevo": "suadere",
    "suadi": "suadere",
    "suadiamo": "suadere",
    "suadiate": "suadere",
    "suado": "suadere",
    "suadon": "suadere",
    "suadono": "suadere",
    "suasa": "suadere",
    "suase": "suadere",
    "suaser": "suadere",
    "suasero": "suadere",
    "suasi": "suadere",
    "suasiva": "suasivo",
    "suasive": "suasivo",
    "suasivi": "suasivo",
    "suaso": "suadere",
    "sub-appalti": "sub-appalto",
    "sub-continenti": "sub-continente",
    "sub-culture": "sub-cultura",
    "sub-emendamenti": "sub-emendamento",
    "sub-tropicali": "sub-tropicale",
    "sub-umana": "sub-umano",
    "sub-umane": "sub-umano",
    "sub-umani": "sub-umano",
    "subacquea": "subacqueo",
    "subacquee": "subacqueo",
    "subacquei": "subacqueo",
    "subaffitta": "subaffittare",
    "subaffittai": "subaffittare",
    "subaffittammo": "subaffittare",
    "subaffittan": "subaffittare",
    "subaffittando": "subaffittare",
    "subaffittano": "subaffittare",
    "subaffittante": "subaffittare",
    "subaffittanti": "subaffittare",
    "subaffittar": "subaffittare",
    "subaffittaron": "subaffittare",
    "subaffittarono": "subaffittare",
    "subaffittasse": "subaffittare",
    "subaffittasser": "subaffittare",
    "subaffittassero": "subaffittare",
    "subaffittassi": "subaffittare",
    "subaffittassimo": "subaffittare",
    "subaffittaste": "subaffittare",
    "subaffittasti": "subaffittare",
    "subaffittata": "subaffittare",
    "subaffittate": "subaffittare",
    "subaffittati": "subaffittare",
    "subaffittato": "subaffittare",
    "subaffittava": "subaffittare",
    "subaffittavamo": "subaffittare",
    "subaffittavan": "subaffittare",
    "subaffittavano": "subaffittare",
    "subaffittavate": "subaffittare",
    "subaffittavi": "subaffittare",
    "subaffittavo": "subaffittare",
    "subaffitterai": "subaffittare",
    "subaffitteran": "subaffittare",
    "subaffitteranno": "subaffittare",
    "subaffitterebbe": "subaffittare",
    "subaffitterebber": "subaffittare",
    "subaffitterebbero": "subaffittare",
    "subaffitterei": "subaffittare",
    "subaffitteremmo": "subaffittare",
    "subaffitteremo": "subaffittare",
    "subaffittereste": "subaffittare",
    "subaffitteresti": "subaffittare",
    "subaffitterete": "subaffittare",
    "subaffitterà": "subaffittare",
    "subaffitterò": "subaffittare",
    "subaffitti": "subaffittare",
    "subaffittiamo": "subaffittare",
    "subaffittiate": "subaffittare",
    "subaffittin": "subaffittare",
    "subaffittino": "subaffittare",
    "subaffitto": "subaffittare",
    "subaffittò": "subaffittare",
    "subalpina": "subalpino",
    "subalpine": "subalpino",
    "subalpini": "subalpino",
    "subalterna": "subalterno",
    "subalterne": "subalterno",
    "subalterni": "subalterno",
    "subappalta": "subappaltare",
    "subappaltai": "subappaltare",
    "subappaltammo": "subappaltare",
    "subappaltan": "subappaltare",
    "subappaltando": "subappaltare",
    "subappaltano": "subappaltare",
    "subappaltante": "subappaltare",
    "subappaltanti": "subappaltare",
    "subappaltar": "subappaltare",
    "subappaltaron": "subappaltare",
    "subappaltarono": "subappaltare",
    "subappaltasse": "subappaltare",
    "subappaltasser": "subappaltare",
    "subappaltassero": "subappaltare",
    "subappaltassi": "subappaltare",
    "subappaltassimo": "subappaltare",
    "subappaltaste": "subappaltare",
    "subappaltasti": "subappaltare",
    "subappaltata": "subappaltare",
    "subappaltate": "subappaltare",
    "subappaltati": "subappaltare",
    "subappaltato": "subappaltare",
    "subappaltatori": "subappaltatore",
    "subappaltava": "subappaltare",
    "subappaltavamo": "subappaltare",
    "subappaltavan": "subappaltare",
    "subappaltavano": "subappaltare",
    "subappaltavate": "subappaltare",
    "subappaltavi": "subappaltare",
    "subappaltavo": "subappaltare",
    "subappalterai": "subappaltare",
    "subappalteran": "subappaltare",
    "subappalteranno": "subappaltare",
    "subappalterebbe": "subappaltare",
    "subappalterebber": "subappaltare",
    "subappalterebbero": "subappaltare",
    "subappalterei": "subappaltare",
    "subappalteremmo": "subappaltare",
    "subappalteremo": "subappaltare",
    "subappaltereste": "subappaltare",
    "subappalteresti": "subappaltare",
    "subappalterete": "subappaltare",
    "subappalterà": "subappaltare",
    "subappalterò": "subappaltare",
    "subappalti": "subappalto",
    "subappaltiamo": "subappaltare",
    "subappaltiate": "subappaltare",
    "subappaltin": "subappaltare",
    "subappaltino": "subappaltare",
    "subappalto": "subappaltare",
    "subappaltò": "subappaltare",
    "subbugli": "subbuglio",
    "subconsce": "subconscio",
    "subconsci": "subconscio",
    "subconscia": "subconscio",
    "subcontinenti": "subcontinente",
    "subculture": "subcultura",
    "subdola": "subdolo",
    "subdole": "subdolo",
    "subdoli": "subdolo",
    "subendo": "subire",
    "subente": "subire",
    "subenti": "subire",
    "subentra": "subentrare",
    "subentrai": "subentrare",
    "subentrammo": "subentrare",
    "subentran": "subentrare",
    "subentrando": "subentrare",
    "subentrano": "subentrare",
    "subentrante": "subentrare",
    "subentranti": "subentrare",
    "subentrar": "subentrare",
    "subentraron": "subentrare",
    "subentrarono": "subentrare",
    "subentrasse": "subentrare",
    "subentrasser": "subentrare",
    "subentrassero": "subentrare",
    "subentrassi": "subentrare",
    "subentrassimo": "subentrare",
    "subentraste": "subentrare",
    "subentrasti": "subentrare",
    "subentrata": "subentrare",
    "subentrate": "subentrare",
    "subentrati": "subentrare",
    "subentrato": "subentrare",
    "subentrava": "subentrare",
    "subentravamo": "subentrare",
    "subentravan": "subentrare",
    "subentravano": "subentrare",
    "subentravate": "subentrare",
    "subentravi": "subentrare",
    "subentravo": "subentrare",
    "subentrerai": "subentrare",
    "subentreran": "subentrare",
    "subentreranno": "subentrare",
    "subentrerebbe": "subentrare",
    "subentrerebber": "subentrare",
    "subentrerebbero": "subentrare",
    "subentrerei": "subentrare",
    "subentreremmo": "subentrare",
    "subentreremo": "subentrare",
    "subentrereste": "subentrare",
    "subentreresti": "subentrare",
    "subentrerete": "subentrare",
    "subentrerà": "subentrare",
    "subentrerò": "subentrare",
    "subentri": "subentrare",
    "subentriamo": "subentrare",
    "subentriate": "subentrare",
    "subentrin": "subentrare",
    "subentrino": "subentrare",
    "subentro": "subentrare",
    "subentrò": "subentrare",
    "subforniture": "subfornitura",
    "subiamo": "subire",
    "subiate": "subire",
    "subii": "subire",
    "subimmo": "subire",
    "subir": "subire",
    "subirai": "subire",
    "subiran": "subire",
    "subiranno": "subire",
    "subirebbe": "subire",
    "subirebber": "subire",
    "subirebbero": "subire",
    "subirei": "subire",
    "subiremmo": "subire",
    "subiremo": "subire",
    "subireste": "subire",
    "subiresti": "subire",
    "subirete": "subire",
    "subiron": "subire",
    "subirono": "subire",
    "subirà": "subire",
    "subirò": "subire",
    "subisca": "subire",
    "subiscan": "subire",
    "subiscano": "subire",
    "subisce": "subire",
    "subisci": "subire",
    "subisco": "subire",
    "subiscon": "subire",
    "subiscono": "subire",
    "subissa": "subissare",
    "subissai": "subissare",
    "subissammo": "subissare",
    "subissan": "subissare",
    "subissando": "subissare",
    "subissano": "subissare",
    "subissante": "subissare",
    "subissanti": "subissare",
    "subissar": "subissare",
    "subissaron": "subissare",
    "subissarono": "subissare",
    "subissasse": "subissare",
    "subissasser": "subissare",
    "subissassero": "subissare",
    "subissassi": "subissare",
    "subissassimo": "subissare",
    "subissaste": "subissare",
    "subissasti": "subissare",
    "subissata": "subissare",
    "subissate": "subissare",
    "subissati": "subissare",
    "subissato": "subissare",
    "subissava": "subissare",
    "subissavamo": "subissare",
    "subissavan": "subissare",
    "subissavano": "subissare",
    "subissavate": "subissare",
    "subissavi": "subissare",
    "subissavo": "subissare",
    "subisse": "subire",
    "subisser": "subire",
    "subisserai": "subissare",
    "subisseran": "subissare",
    "subisseranno": "subissare",
    "subisserebbe": "subissare",
    "subisserebber": "subissare",
    "subisserebbero": "subissare",
    "subisserei": "subissare",
    "subisseremmo": "subissare",
    "subisseremo": "subissare",
    "subissereste": "subissare",
    "subisseresti": "subissare",
    "subisserete": "subissare",
    "subissero": "subire",
    "subisserà": "subissare",
    "subisserò": "subissare",
    "subissi": "subissare",
    "subissiamo": "subissare",
    "subissiate": "subissare",
    "subissimo": "subire",
    "subissin": "subissare",
    "subissino": "subissare",
    "subisso": "subissare",
    "subissò": "subissare",
    "subiste": "subire",
    "subisti": "subire",
    "subita": "subito",
    "subitanea": "subitaneo",
    "subitanee": "subitaneo",
    "subitanei": "subitaneo",
    "subite": "subito",
    "subiti": "subito",
    "subito": "subire",
    "subiva": "subire",
    "subivamo": "subire",
    "subivan": "subire",
    "subivano": "subire",
    "subivate": "subire",
    "subivi": "subire",
    "subivo": "subire",
    "sublima": "sublimare",
    "sublimai": "sublimare",
    "sublimammo": "sublimare",
    "subliman": "sublimare",
    "sublimando": "sublimare",
    "sublimano": "sublimare",
    "sublimante": "sublimare",
    "sublimanti": "sublimare",
    "sublimar": "sublimare",
    "sublimaron": "sublimare",
    "sublimarono": "sublimare",
    "sublimasse": "sublimare",
    "sublimasser": "sublimare",
    "sublimassero": "sublimare",
    "sublimassi": "sublimare",
    "sublimassimo": "sublimare",
    "sublimaste": "sublimare",
    "sublimasti": "sublimare",
    "sublimata": "sublimare",
    "sublimate": "sublimare",
    "sublimati": "sublimare",
    "sublimato": "sublimare",
    "sublimava": "sublimare",
    "sublimavamo": "sublimare",
    "sublimavan": "sublimare",
    "sublimavano": "sublimare",
    "sublimavate": "sublimare",
    "sublimavi": "sublimare",
    "sublimavo": "sublimare",
    "sublimazioni": "sublimazione",
    "sublimerai": "sublimare",
    "sublimeran": "sublimare",
    "sublimeranno": "sublimare",
    "sublimerebbe": "sublimare",
    "sublimerebber": "sublimare",
    "sublimerebbero": "sublimare",
    "sublimerei": "sublimare",
    "sublimeremmo": "sublimare",
    "sublimeremo": "sublimare",
    "sublimereste": "sublimare",
    "sublimeresti": "sublimare",
    "sublimerete": "sublimare",
    "sublimerà": "sublimare",
    "sublimerò": "sublimare",
    "sublimi": "sublime",
    "sublimiamo": "sublimare",
    "sublimiate": "sublimare",
    "sublimin": "sublimare",
    "subliminali": "subliminale",
    "sublimino": "sublimare",
    "sublimo": "sublimare",
    "sublimò": "sublimare",
    "subloca": "sublocare",
    "sublocai": "sublocare",
    "sublocammo": "sublocare",
    "sublocan": "sublocare",
    "sublocando": "sublocare",
    "sublocano": "sublocare",
    "sublocante": "sublocare",
    "sublocanti": "sublocare",
    "sublocar": "sublocare",
    "sublocaron": "sublocare",
    "sublocarono": "sublocare",
    "sublocasse": "sublocare",
    "sublocasser": "sublocare",
    "sublocassero": "sublocare",
    "sublocassi": "sublocare",
    "sublocassimo": "sublocare",
    "sublocaste": "sublocare",
    "sublocasti": "sublocare",
    "sublocata": "sublocare",
    "sublocate": "sublocare",
    "sublocati": "sublocare",
    "sublocato": "sublocare",
    "sublocava": "sublocare",
    "sublocavamo": "sublocare",
    "sublocavan": "sublocare",
    "sublocavano": "sublocare",
    "sublocavate": "sublocare",
    "sublocavi": "sublocare",
    "sublocavo": "sublocare",
    "sublocherai": "sublocare",
    "sublocheran": "sublocare",
    "sublocheranno": "sublocare",
    "sublocherebbe": "sublocare",
    "sublocherebber": "sublocare",
    "sublocherebbero": "sublocare",
    "sublocherei": "sublocare",
    "sublocheremmo": "sublocare",
    "sublocheremo": "sublocare",
    "sublochereste": "sublocare",
    "sublocheresti": "sublocare",
    "sublocherete": "sublocare",
    "sublocherà": "sublocare",
    "sublocherò": "sublocare",
    "sublochi": "sublocare",
    "sublochiamo": "sublocare",
    "sublochiate": "sublocare",
    "sublochin": "sublocare",
    "sublochino": "sublocare",
    "subloco": "sublocare",
    "sublocò": "sublocare",
    "subnormali": "subnormale",
    "subodora": "subodorare",
    "subodorai": "subodorare",
    "subodorammo": "subodorare",
    "subodoran": "subodorare",
    "subodorando": "subodorare",
    "subodorano": "subodorare",
    "subodorante": "subodorare",
    "subodoranti": "subodorare",
    "subodorar": "subodorare",
    "subodoraron": "subodorare",
    "subodorarono": "subodorare",
    "subodorasse": "subodorare",
    "subodorasser": "subodorare",
    "subodorassero": "subodorare",
    "subodorassi": "subodorare",
    "subodorassimo": "subodorare",
    "subodoraste": "subodorare",
    "subodorasti": "subodorare",
    "subodorata": "subodorare",
    "subodorate": "subodorare",
    "subodorati": "subodorare",
    "subodorato": "subodorare",
    "subodorava": "subodorare",
    "subodoravamo": "subodorare",
    "subodoravan": "subodorare",
    "subodoravano": "subodorare",
    "subodoravate": "subodorare",
    "subodoravi": "subodorare",
    "subodoravo": "subodorare",
    "subodorerai": "subodorare",
    "subodoreran": "subodorare",
    "subodoreranno": "subodorare",
    "subodorerebbe": "subodorare",
    "subodorerebber": "subodorare",
    "subodorerebbero": "subodorare",
    "subodorerei": "subodorare",
    "subodoreremmo": "subodorare",
    "subodoreremo": "subodorare",
    "subodorereste": "subodorare",
    "subodoreresti": "subodorare",
    "subodorerete": "subodorare",
    "subodorerà": "subodorare",
    "subodorerò": "subodorare",
    "subodori": "subodorare",
    "subodoriamo": "subodorare",
    "subodoriate": "subodorare",
    "subodorin": "subodorare",
    "subodorino": "subodorare",
    "subodoro": "subodorare",
    "subodorò": "subodorare",
    "subordina": "subordinare",
    "subordinai": "subordinare",
    "subordinammo": "subordinare",
    "subordinan": "subordinare",
    "subordinando": "subordinare",
    "subordinano": "subordinare",
    "subordinante": "subordinare",
    "subordinanti": "subordinare",
    "subordinar": "subordinare",
    "subordinaron": "subordinare",
    "subordinarono": "subordinare",
    "subordinasse": "subordinare",
    "subordinasser": "subordinare",
    "subordinassero": "subordinare",
    "subordinassi": "subordinare",
    "subordinassimo": "subordinare",
    "subordinaste": "subordinare",
    "subordinasti": "subordinare",
    "subordinata": "subordinato",
    "subordinate": "subordinato",
    "subordinati": "subordinato",
    "subordinato": "subordinare",
    "subordinava": "subordinare",
    "subordinavamo": "subordinare",
    "subordinavan": "subordinare",
    "subordinavano": "subordinare",
    "subordinavate": "subordinare",
    "subordinavi": "subordinare",
    "subordinavo": "subordinare",
    "subordinazioni": "subordinazione",
    "subordinerai": "subordinare",
    "subordineran": "subordinare",
    "subordineranno": "subordinare",
    "subordinerebbe": "subordinare",
    "subordinerebber": "subordinare",
    "subordinerebbero": "subordinare",
    "subordinerei": "subordinare",
    "subordineremmo": "subordinare",
    "subordineremo": "subordinare",
    "subordinereste": "subordinare",
    "subordineresti": "subordinare",
    "subordinerete": "subordinare",
    "subordinerà": "subordinare",
    "subordinerò": "subordinare",
    "subordini": "subordinare",
    "subordiniamo": "subordinare",
    "subordiniate": "subordinare",
    "subordinin": "subordinare",
    "subordinino": "subordinare",
    "subordino": "subordinare",
    "subordinò": "subordinare",
    "suborna": "subornare",
    "subornai": "subornare",
    "subornammo": "subornare",
    "subornan": "subornare",
    "subornando": "subornare",
    "subornano": "subornare",
    "subornante": "subornare",
    "subornanti": "subornare",
    "subornar": "subornare",
    "subornaron": "subornare",
    "subornarono": "subornare",
    "subornasse": "subornare",
    "subornasser": "subornare",
    "subornassero": "subornare",
    "subornassi": "subornare",
    "subornassimo": "subornare",
    "subornaste": "subornare",
    "subornasti": "subornare",
    "subornata": "subornare",
    "subornate": "subornare",
    "subornati": "subornare",
    "subornato": "subornare",
    "subornava": "subornare",
    "subornavamo": "subornare",
    "subornavan": "subornare",
    "subornavano": "subornare",
    "subornavate": "subornare",
    "subornavi": "subornare",
    "subornavo": "subornare",
    "subornerai": "subornare",
    "suborneran": "subornare",
    "suborneranno": "subornare",
    "subornerebbe": "subornare",
    "subornerebber": "subornare",
    "subornerebbero": "subornare",
    "subornerei": "subornare",
    "suborneremmo": "subornare",
    "suborneremo": "subornare",
    "subornereste": "subornare",
    "suborneresti": "subornare",
    "subornerete": "subornare",
    "subornerà": "subornare",
    "subornerò": "subornare",
    "suborni": "subornare",
    "suborniamo": "subornare",
    "suborniate": "subornare",
    "subornin": "subornare",
    "subornino": "subornare",
    "suborno": "subornare",
    "subornò": "subornare",
    "subsonica": "subsonico",
    "subsoniche": "subsonico",
    "subsonici": "subsonico",
    "substrati": "substrato",
    "subtropicali": "subtropicale",
    "subumana": "subumano",
    "subumane": "subumano",
    "subumani": "subumano",
    "suburbana": "suburbano",
    "suburbane": "suburbano",
    "suburbani": "suburbano",
    "suburbi": "suburbio",
    "subì": "subire",
    "succeda": "succedere",
    "succedan": "succedere",
    "succedanea": "succedaneo",
    "succedanee": "succedaneo",
    "succedanei": "succedaneo",
    "succedano": "succedere",
    "succede": "succedere",
    "succedemmo": "succedere",
    "succedendo": "succedere",
    "succedente": "succedere",
    "succedenti": "succedere",
    "succeder": "succedere",
    "succederai": "succedere",
    "succederan": "succedere",
    "succederanno": "succedere",
    "succederebbe": "succedere",
    "succederebber": "succedere",
    "succederebbero": "succedere",
    "succederei": "succedere",
    "succederemmo": "succedere",
    "succederemo": "succedere",
    "succedereste": "succedere",
    "succederesti": "succedere",
    "succederete": "succedere",
    "succederà": "succedere",
    "succederò": "succedere",
    "succedesse": "succedere",
    "succedesser": "succedere",
    "succedessero": "succedere",
    "succedessi": "succedere",
    "succedessimo": "succedere",
    "succedeste": "succedere",
    "succedesti": "succedere",
    "succedete": "succedere",
    "succedette": "succedere",
    "succedettero": "succedere",
    "succedetti": "succedere",
    "succedeva": "succedere",
    "succedevamo": "succedere",
    "succedevan": "succedere",
    "succedevano": "succedere",
    "succedevate": "succedere",
    "succedevi": "succedere",
    "succedevo": "succedere",
    "succedi": "succedere",
    "succediamo": "succedere",
    "succediate": "succedere",
    "succedo": "succedere",
    "succedon": "succedere",
    "succedono": "succedere",
    "succeduto": "succedere",
    "successe": "succedere",
    "successero": "succedere",
    "successi": "successo",
    "successioni": "successione",
    "successiva": "successivo",
    "successive": "successivo",
    "successivi": "successivo",
    "successo": "succedere",
    "successoni": "successone",
    "successori": "successorio",
    "successoria": "successorio",
    "successorie": "successorio",
    "succhi": "succo",
    "succhia": "succhiare",
    "succhiai": "succhiare",
    "succhiammo": "succhiare",
    "succhiamo": "succhiare",
    "succhian": "succhiare",
    "succhiando": "succhiare",
    "succhiano": "succhiare",
    "succhiante": "succhiare",
    "succhianti": "succhiare",
    "succhiar": "succhiare",
    "succhiaron": "succhiare",
    "succhiarono": "succhiare",
    "succhiasse": "succhiare",
    "succhiasser": "succhiare",
    "succhiassero": "succhiare",
    "succhiassi": "succhiare",
    "succhiassimo": "succhiare",
    "succhiaste": "succhiare",
    "succhiasti": "succhiare",
    "succhiata": "succhiare",
    "succhiate": "succhiare",
    "succhiati": "succhiare",
    "succhiato": "succhiare",
    "succhiava": "succhiare",
    "succhiavamo": "succhiare",
    "succhiavan": "succhiare",
    "succhiavano": "succhiare",
    "succhiavate": "succhiare",
    "succhiavi": "succhiare",
    "succhiavo": "succhiare",
    "succhierai": "succhiare",
    "succhieran": "succhiare",
    "succhieranno": "succhiare",
    "succhierebbe": "succhiare",
    "succhierebber": "succhiare",
    "succhierebbero": "succhiare",
    "succhierei": "succhiare",
    "succhieremmo": "succhiare",
    "succhieremo": "succhiare",
    "succhiereste": "succhiare",
    "succhieresti": "succhiare",
    "succhierete": "succhiare",
    "succhierà": "succhiare",
    "succhierò": "succhiare",
    "succhin": "succhiare",
    "succhino": "succhiare",
    "succhio": "succhiare",
    "succhiotti": "succhiotto",
    "succhiò": "succhiare",
    "succida": "succidere",
    "succidan": "succidere",
    "succidano": "succidere",
    "succide": "succidere",
    "succidei": "succidere",
    "succidemmo": "succidere",
    "succidendo": "succidere",
    "succidente": "succidere",
    "succidenti": "succidere",
    "succider": "succidere",
    "succiderai": "succidere",
    "succideran": "succidere",
    "succideranno": "succidere",
    "succiderebbe": "succidere",
    "succiderebber": "succidere",
    "succiderebbero": "succidere",
    "succiderei": "succidere",
    "succideremmo": "succidere",
    "succideremo": "succidere",
    "succidereste": "succidere",
    "succideresti": "succidere",
    "succiderete": "succidere",
    "succideron": "succidere",
    "succiderono": "succidere",
    "succiderà": "succidere",
    "succiderò": "succidere",
    "succidesse": "succidere",
    "succidesser": "succidere",
    "succidessero": "succidere",
    "succidessi": "succidere",
    "succidessimo": "succidere",
    "succideste": "succidere",
    "succidesti": "succidere",
    "succidete": "succidere",
    "succideva": "succidere",
    "succidevamo": "succidere",
    "succidevan": "succidere",
    "succidevano": "succidere",
    "succidevate": "succidere",
    "succidevi": "succidere",
    "succidevo": "succidere",
    "succidi": "succidere",
    "succidiamo": "succidere",
    "succidiate": "succidere",
    "succido": "succidere",
    "succidon": "succidere",
    "succidono": "succidere",
    "succiduta": "succidere",
    "succidute": "succidere",
    "succiduti": "succidere",
    "succiduto": "succidere",
    "succidè": "succidere",
    "succinga": "succingere",
    "succingan": "succingere",
    "succingano": "succingere",
    "succinge": "succingere",
    "succingemmo": "succingere",
    "succingendo": "succingere",
    "succingente": "succingere",
    "succingenti": "succingere",
    "succinger": "succingere",
    "succingerai": "succingere",
    "succingeran": "succingere",
    "succingeranno": "succingere",
    "succingerebbe": "succingere",
    "succingerebber": "succingere",
    "succingerebbero": "succingere",
    "succingerei": "succingere",
    "succingeremmo": "succingere",
    "succingeremo": "succingere",
    "succingereste": "succingere",
    "succingeresti": "succingere",
    "succingerete": "succingere",
    "succingerà": "succingere",
    "succingerò": "succingere",
    "succingesse": "succingere",
    "succingesser": "succingere",
    "succingessero": "succingere",
    "succingessi": "succingere",
    "succingessimo": "succingere",
    "succingeste": "succingere",
    "succingesti": "succingere",
    "succingete": "succingere",
    "succingeva": "succingere",
    "succingevamo": "succingere",
    "succingevan": "succingere",
    "succingevano": "succingere",
    "succingevate": "succingere",
    "succingevi": "succingere",
    "succingevo": "succingere",
    "succingi": "succingere",
    "succingiamo": "succingere",
    "succingiate": "succingere",
    "succingo": "succingere",
    "succingon": "succingere",
    "succingono": "succingere",
    "succinser": "succingere",
    "succinsero": "succingere",
    "succinsi": "succingere",
    "succinsè": "succingere",
    "succinta": "succinto",
    "succinte": "succinto",
    "succinti": "succinto",
    "succinto": "succingere",
    "succita": "succitare",
    "succitai": "succitare",
    "succitammo": "succitare",
    "succitan": "succitare",
    "succitando": "succitare",
    "succitano": "succitare",
    "succitante": "succitare",
    "succitanti": "succitare",
    "succitar": "succitare",
    "succitaron": "succitare",
    "succitarono": "succitare",
    "succitasse": "succitare",
    "succitasser": "succitare",
    "succitassero": "succitare",
    "succitassi": "succitare",
    "succitassimo": "succitare",
    "succitaste": "succitare",
    "succitasti": "succitare",
    "succitata": "succitare",
    "succitate": "succitare",
    "succitati": "succitare",
    "succitato": "succitare",
    "succitava": "succitare",
    "succitavamo": "succitare",
    "succitavan": "succitare",
    "succitavano": "succitare",
    "succitavate": "succitare",
    "succitavi": "succitare",
    "succitavo": "succitare",
    "succiterai": "succitare",
    "succiteran": "succitare",
    "succiteranno": "succitare",
    "succiterebbe": "succitare",
    "succiterebber": "succitare",
    "succiterebbero": "succitare",
    "succiterei": "succitare",
    "succiteremmo": "succitare",
    "succiteremo": "succitare",
    "succitereste": "succitare",
    "succiteresti": "succitare",
    "succiterete": "succitare",
    "succiterà": "succitare",
    "succiterò": "succitare",
    "succiti": "succitare",
    "succitiamo": "succitare",
    "succitiate": "succitare",
    "succitin": "succitare",
    "succitino": "succitare",
    "succito": "succitare",
    "succitò": "succitare",
    "succosa": "succoso",
    "succose": "succoso",
    "succosi": "succoso",
    "succuba": "succubo",
    "succube": "succubo",
    "succubi": "succubo",
    "succulenta": "succulento",
    "succulente": "succulento",
    "succulenti": "succulento",
    "succursali": "succursale",
    "sud-coreana": "sud-coreano",
    "sud-coreane": "sud-coreano",
    "sud-coreani": "sud-coreano",
    "sud-orientali": "sud-orientale",
    "suda": "sudare",
    "sudafricana": "sudafricano",
    "sudafricane": "sudafricano",
    "sudafricani": "sudafricano",
    "sudai": "sudare",
    "sudamericana": "sudamericano",
    "sudamericane": "sudamericano",
    "sudamericani": "sudamericano",
    "sudammo": "sudare",
    "sudan": "sudare",
    "sudando": "sudare",
    "sudanesi": "sudanese",
    "sudano": "sudare",
    "sudante": "sudare",
    "sudanti": "sudare",
    "sudar": "sudare",
    "sudari": "sudario",
    "sudaron": "sudare",
    "sudarono": "sudare",
    "sudasse": "sudare",
    "sudasser": "sudare",
    "sudassero": "sudare",
    "sudassi": "sudare",
    "sudassimo": "sudare",
    "sudaste": "sudare",
    "sudasti": "sudare",
    "sudata": "sudato",
    "sudate": "sudato",
    "sudati": "sudato",
    "sudaticce": "sudaticcio",
    "sudaticci": "sudaticcio",
    "sudaticcia": "sudaticcio",
    "sudato": "sudare",
    "sudava": "sudare",
    "sudavamo": "sudare",
    "sudavan": "sudare",
    "sudavano": "sudare",
    "sudavate": "sudare",
    "sudavi": "sudare",
    "sudavo": "sudare",
    "sudcoreana": "sudcoreano",
    "sudcoreane": "sudcoreano",
    "sudcoreani": "sudcoreano",
    "suddetta": "suddetto",
    "suddette": "suddetto",
    "suddetti": "suddetto",
    "sudditanze": "sudditanza",
    "sudditi": "suddito",
    "suddivida": "suddividere",
    "suddividan": "suddividere",
    "suddividano": "suddividere",
    "suddivide": "suddividere",
    "suddividemmo": "suddividere",
    "suddividendo": "suddividere",
    "suddividente": "suddividere",
    "suddividenti": "suddividere",
    "suddivider": "suddividere",
    "suddividerai": "suddividere",
    "suddivideran": "suddividere",
    "suddivideranno": "suddividere",
    "suddividerebbe": "suddividere",
    "suddividerebber": "suddividere",
    "suddividerebbero": "suddividere",
    "suddividerei": "suddividere",
    "suddivideremmo": "suddividere",
    "suddivideremo": "suddividere",
    "suddividereste": "suddividere",
    "suddivideresti": "suddividere",
    "suddividerete": "suddividere",
    "suddividerà": "suddividere",
    "suddividerò": "suddividere",
    "suddividesse": "suddividere",
    "suddividesser": "suddividere",
    "suddividessero": "suddividere",
    "suddividessi": "suddividere",
    "suddividessimo": "suddividere",
    "suddivideste": "suddividere",
    "suddividesti": "suddividere",
    "suddividete": "suddividere",
    "suddivideva": "suddividere",
    "suddividevamo": "suddividere",
    "suddividevan": "suddividere",
    "suddividevano": "suddividere",
    "suddividevate": "suddividere",
    "suddividevi": "suddividere",
    "suddividevo": "suddividere",
    "suddividi": "suddividere",
    "suddividiamo": "suddividere",
    "suddividiate": "suddividere",
    "suddivido": "suddividere",
    "suddividon": "suddividere",
    "suddividono": "suddividere",
    "suddivisa": "suddividere",
    "suddivise": "suddividere",
    "suddiviser": "suddividere",
    "suddivisero": "suddividere",
    "suddivisi": "suddividere",
    "suddivisioni": "suddivisione",
    "suddiviso": "suddividere",
    "suderai": "sudare",
    "suderan": "sudare",
    "suderanno": "sudare",
    "suderebbe": "sudare",
    "suderebber": "sudare",
    "suderebbero": "sudare",
    "suderei": "sudare",
    "suderemmo": "sudare",
    "suderemo": "sudare",
    "sudereste": "sudare",
    "suderesti": "sudare",
    "suderete": "sudare",
    "suderà": "sudare",
    "suderò": "sudare",
    "sudi": "sudare",
    "sudiamo": "sudare",
    "sudiate": "sudare",
    "sudice": "sudicio",
    "sudici": "sudicio",
    "sudicia": "sudicio",
    "sudin": "sudare",
    "sudino": "sudare",
    "sudiste": "sudista",
    "sudisti": "sudista",
    "sudo": "sudare",
    "sudorazioni": "sudorazione",
    "sudori": "sudore",
    "sudorientali": "sudorientale",
    "sudtirolesi": "sudtirolese",
    "sudò": "sudare",
    "sue": "suo",
    "sufficienti": "sufficiente",
    "sufficienze": "sufficienza",
    "suffraga": "suffragare",
    "suffragai": "suffragare",
    "suffragammo": "suffragare",
    "suffragan": "suffragare",
    "suffragando": "suffragare",
    "suffragano": "suffragare",
    "suffragante": "suffragare",
    "suffraganti": "suffragare",
    "suffragar": "suffragare",
    "suffragaron": "suffragare",
    "suffragarono": "suffragare",
    "suffragasse": "suffragare",
    "suffragasser": "suffragare",
    "suffragassero": "suffragare",
    "suffragassi": "suffragare",
    "suffragassimo": "suffragare",
    "suffragaste": "suffragare",
    "suffragasti": "suffragare",
    "suffragata": "suffragare",
    "suffragate": "suffragare",
    "suffragati": "suffragare",
    "suffragato": "suffragare",
    "suffragava": "suffragare",
    "suffragavamo": "suffragare",
    "suffragavan": "suffragare",
    "suffragavano": "suffragare",
    "suffragavate": "suffragare",
    "suffragavi": "suffragare",
    "suffragavo": "suffragare",
    "suffragette": "suffragetta",
    "suffragherai": "suffragare",
    "suffragheran": "suffragare",
    "suffragheranno": "suffragare",
    "suffragherebbe": "suffragare",
    "suffragherebber": "suffragare",
    "suffragherebbero": "suffragare",
    "suffragherei": "suffragare",
    "suffragheremmo": "suffragare",
    "suffragheremo": "suffragare",
    "suffraghereste": "suffragare",
    "suffragheresti": "suffragare",
    "suffragherete": "suffragare",
    "suffragherà": "suffragare",
    "suffragherò": "suffragare",
    "suffraghi": "suffragare",
    "suffraghiamo": "suffragare",
    "suffraghiate": "suffragare",
    "suffraghin": "suffragare",
    "suffraghino": "suffragare",
    "suffragi": "suffragio",
    "suffrago": "suffragare",
    "suffragò": "suffragare",
    "sugga": "suggere",
    "suggan": "suggere",
    "suggano": "suggere",
    "sugge": "suggere",
    "suggella": "suggellare",
    "suggellai": "suggellare",
    "suggellammo": "suggellare",
    "suggellan": "suggellare",
    "suggellando": "suggellare",
    "suggellano": "suggellare",
    "suggellante": "suggellare",
    "suggellanti": "suggellare",
    "suggellar": "suggellare",
    "suggellaron": "suggellare",
    "suggellarono": "suggellare",
    "suggellasse": "suggellare",
    "suggellasser": "suggellare",
    "suggellassero": "suggellare",
    "suggellassi": "suggellare",
    "suggellassimo": "suggellare",
    "suggellaste": "suggellare",
    "suggellasti": "suggellare",
    "suggellata": "suggellare",
    "suggellate": "suggellare",
    "suggellati": "suggellare",
    "suggellato": "suggellare",
    "suggellava": "suggellare",
    "suggellavamo": "suggellare",
    "suggellavan": "suggellare",
    "suggellavano": "suggellare",
    "suggellavate": "suggellare",
    "suggellavi": "suggellare",
    "suggellavo": "suggellare",
    "suggellerai": "suggellare",
    "suggelleran": "suggellare",
    "suggelleranno": "suggellare",
    "suggellerebbe": "suggellare",
    "suggellerebber": "suggellare",
    "suggellerebbero": "suggellare",
    "suggellerei": "suggellare",
    "suggelleremmo": "suggellare",
    "suggelleremo": "suggellare",
    "suggellereste": "suggellare",
    "suggelleresti": "suggellare",
    "suggellerete": "suggellare",
    "suggellerà": "suggellare",
    "suggellerò": "suggellare",
    "suggelli": "suggello",
    "suggelliamo": "suggellare",
    "suggelliate": "suggellare",
    "suggellin": "suggellare",
    "suggellino": "suggellare",
    "suggello": "suggellare",
    "suggellò": "suggellare",
    "suggemmo": "suggere",
    "suggendo": "suggere",
    "suggente": "suggere",
    "suggenti": "suggere",
    "sugger": "suggere",
    "suggerai": "suggere",
    "suggeran": "suggere",
    "suggeranno": "suggere",
    "suggerebbe": "suggere",
    "suggerebber": "suggere",
    "suggerebbero": "suggere",
    "suggerei": "suggere",
    "suggeremmo": "suggere",
    "suggeremo": "suggere",
    "suggerendo": "suggerire",
    "suggerente": "suggerire",
    "suggerenti": "suggerire",
    "suggereste": "suggere",
    "suggeresti": "suggere",
    "suggerete": "suggere",
    "suggeriamo": "suggerire",
    "suggeriate": "suggerire",
    "suggerii": "suggerire",
    "suggerimenti": "suggerimento",
    "suggerimmo": "suggerire",
    "suggerir": "suggerire",
    "suggerirai": "suggerire",
    "suggeriran": "suggerire",
    "suggeriranno": "suggerire",
    "suggerirebbe": "suggerire",
    "suggerirebber": "suggerire",
    "suggerirebbero": "suggerire",
    "suggerirei": "suggerire",
    "suggeriremmo": "suggerire",
    "suggeriremo": "suggerire",
    "suggerireste": "suggerire",
    "suggeriresti": "suggerire",
    "suggerirete": "suggerire",
    "suggeriron": "suggerire",
    "suggerirono": "suggerire",
    "suggerirà": "suggerire",
    "suggerirò": "suggerire",
    "suggerisca": "suggerire",
    "suggeriscan": "suggerire",
    "suggeriscano": "suggerire",
    "suggerisce": "suggerire",
    "suggerisci": "suggerire",
    "suggerisco": "suggerire",
    "suggeriscon": "suggerire",
    "suggeriscono": "suggerire",
    "suggerisse": "suggerire",
    "suggerisser": "suggerire",
    "suggerissero": "suggerire",
    "suggerissi": "suggerire",
    "suggerissimo": "suggerire",
    "suggeriste": "suggerire",
    "suggeristi": "suggerire",
    "suggerita": "suggerire",
    "suggerite": "suggerire",
    "suggeriti": "suggerire",
    "suggerito": "suggerire",
    "suggeritori": "suggeritore",
    "suggeriva": "suggerire",
    "suggerivamo": "suggerire",
    "suggerivan": "suggerire",
    "suggerivano": "suggerire",
    "suggerivate": "suggerire",
    "suggerivi": "suggerire",
    "suggerivo": "suggerire",
    "suggerà": "suggere",
    "suggerì": "suggerire",
    "suggerò": "suggere",
    "suggesse": "suggere",
    "suggesser": "suggere",
    "suggessero": "suggere",
    "suggessi": "suggere",
    "suggessimo": "suggere",
    "suggeste": "suggere",
    "suggesti": "suggere",
    "suggestiona": "suggestionare",
    "suggestionai": "suggestionare",
    "suggestionammo": "suggestionare",
    "suggestionan": "suggestionare",
    "suggestionando": "suggestionare",
    "suggestionano": "suggestionare",
    "suggestionante": "suggestionare",
    "suggestionanti": "suggestionare",
    "suggestionar": "suggestionare",
    "suggestionaron": "suggestionare",
    "suggestionarono": "suggestionare",
    "suggestionasse": "suggestionare",
    "suggestionasser": "suggestionare",
    "suggestionassero": "suggestionare",
    "suggestionassi": "suggestionare",
    "suggestionassimo": "suggestionare",
    "suggestionaste": "suggestionare",
    "suggestionasti": "suggestionare",
    "suggestionata": "suggestionare",
    "suggestionate": "suggestionare",
    "suggestionati": "suggestionare",
    "suggestionato": "suggestionare",
    "suggestionava": "suggestionare",
    "suggestionavamo": "suggestionare",
    "suggestionavan": "suggestionare",
    "suggestionavano": "suggestionare",
    "suggestionavate": "suggestionare",
    "suggestionavi": "suggestionare",
    "suggestionavo": "suggestionare",
    "suggestionerai": "suggestionare",
    "suggestioneran": "suggestionare",
    "suggestioneranno": "suggestionare",
    "suggestionerebbe": "suggestionare",
    "suggestionerebber": "suggestionare",
    "suggestionerebbero": "suggestionare",
    "suggestionerei": "suggestionare",
    "suggestioneremmo": "suggestionare",
    "suggestioneremo": "suggestionare",
    "suggestionereste": "suggestionare",
    "suggestioneresti": "suggestionare",
    "suggestionerete": "suggestionare",
    "suggestionerà": "suggestionare",
    "suggestionerò": "suggestionare",
    "suggestioni": "suggestione",
    "suggestioniamo": "suggestionare",
    "suggestioniate": "suggestionare",
    "suggestionin": "suggestionare",
    "suggestionino": "suggestionare",
    "suggestiono": "suggestionare",
    "suggestionò": "suggestionare",
    "suggestiva": "suggestivo",
    "suggestive": "suggestivo",
    "suggestivi": "suggestivo",
    "suggete": "suggere",
    "suggeva": "suggere",
    "suggevamo": "suggere",
    "suggevan": "suggere",
    "suggevano": "suggere",
    "suggevate": "suggere",
    "suggevi": "suggere",
    "suggevo": "suggere",
    "suggi": "suggere",
    "suggiamo": "suggere",
    "suggiate": "suggere",
    "suggo": "suggere",
    "suggon": "suggere",
    "suggono": "suggere",
    "sugheri": "sughero",
    "sughi": "sugo",
    "sugli": "sul",
    "sui": "sul",
    "suicida": "suicidare",
    "suicidai": "suicidare",
    "suicidammo": "suicidare",
    "suicidan": "suicidare",
    "suicidando": "suicidare",
    "suicidano": "suicidare",
    "suicidar": "suicidare",
    "suicidaron": "suicidare",
    "suicidarono": "suicidare",
    "suicidasse": "suicidare",
    "suicidasser": "suicidare",
    "suicidassero": "suicidare",
    "suicidassi": "suicidare",
    "suicidassimo": "suicidare",
    "suicidaste": "suicidare",
    "suicidasti": "suicidare",
    "suicidata": "suicidare",
    "suicidate": "suicidare",
    "suicidati": "suicidare",
    "suicidato": "suicidare",
    "suicidava": "suicidare",
    "suicidavamo": "suicidare",
    "suicidavan": "suicidare",
    "suicidavano": "suicidare",
    "suicidavate": "suicidare",
    "suicidavi": "suicidare",
    "suicidavo": "suicidare",
    "suiciderai": "suicidare",
    "suicideran": "suicidare",
    "suicideranno": "suicidare",
    "suiciderebbe": "suicidare",
    "suiciderebber": "suicidare",
    "suiciderebbero": "suicidare",
    "suiciderei": "suicidare",
    "suicideremmo": "suicidare",
    "suicideremo": "suicidare",
    "suicidereste": "suicidare",
    "suicideresti": "suicidare",
    "suiciderete": "suicidare",
    "suiciderà": "suicidare",
    "suiciderò": "suicidare",
    "suicidi": "suicidio",
    "suicidia": "suicidio",
    "suicidiamo": "suicidare",
    "suicidiate": "suicidare",
    "suicidie": "suicidio",
    "suicidin": "suicidare",
    "suicidino": "suicidare",
    "suicido": "suicidare",
    "suicidò": "suicidare",
    "suina": "suino",
    "suine": "suino",
    "suini": "suino",
    "sulfurea": "sulfureo",
    "sulfuree": "sulfureo",
    "sulfurei": "sulfureo",
    "sull'": "sulla",
    "sulle": "sulla",
    "sullo": "sul",
    "sultanati": "sultanato",
    "sultani": "sultano",
    "sumeri": "sumero",
    "summe": "summa",
    "summenziona": "summenzionare",
    "summenzionai": "summenzionare",
    "summenzionammo": "summenzionare",
    "summenzionan": "summenzionare",
    "summenzionando": "summenzionare",
    "summenzionano": "summenzionare",
    "summenzionante": "summenzionare",
    "summenzionanti": "summenzionare",
    "summenzionar": "summenzionare",
    "summenzionaron": "summenzionare",
    "summenzionarono": "summenzionare",
    "summenzionasse": "summenzionare",
    "summenzionasser": "summenzionare",
    "summenzionassero": "summenzionare",
    "summenzionassi": "summenzionare",
    "summenzionassimo": "summenzionare",
    "summenzionaste": "summenzionare",
    "summenzionasti": "summenzionare",
    "summenzionata": "summenzionare",
    "summenzionate": "summenzionare",
    "summenzionati": "summenzionare",
    "summenzionato": "summenzionare",
    "summenzionava": "summenzionare",
    "summenzionavamo": "summenzionare",
    "summenzionavan": "summenzionare",
    "summenzionavano": "summenzionare",
    "summenzionavate": "summenzionare",
    "summenzionavi": "summenzionare",
    "summenzionavo": "summenzionare",
    "summenzionerai": "summenzionare",
    "summenzioneran": "summenzionare",
    "summenzioneranno": "summenzionare",
    "summenzionerebbe": "summenzionare",
    "summenzionerebber": "summenzionare",
    "summenzionerebbero": "summenzionare",
    "summenzionerei": "summenzionare",
    "summenzioneremmo": "summenzionare",
    "summenzioneremo": "summenzionare",
    "summenzionereste": "summenzionare",
    "summenzioneresti": "summenzionare",
    "summenzionerete": "summenzionare",
    "summenzionerà": "summenzionare",
    "summenzionerò": "summenzionare",
    "summenzioni": "summenzionare",
    "summenzioniamo": "summenzionare",
    "summenzioniate": "summenzionare",
    "summenzionin": "summenzionare",
    "summenzionino": "summenzionare",
    "summenziono": "summenzionare",
    "summenzionò": "summenzionare",
    "sunnite": "sunnita",
    "sunniti": "sunnita",
    "sunteggerai": "sunteggiare",
    "sunteggeran": "sunteggiare",
    "sunteggeranno": "sunteggiare",
    "sunteggerebbe": "sunteggiare",
    "sunteggerebber": "sunteggiare",
    "sunteggerebbero": "sunteggiare",
    "sunteggerei": "sunteggiare",
    "sunteggeremmo": "sunteggiare",
    "sunteggeremo": "sunteggiare",
    "sunteggereste": "sunteggiare",
    "sunteggeresti": "sunteggiare",
    "sunteggerete": "sunteggiare",
    "sunteggerà": "sunteggiare",
    "sunteggerò": "sunteggiare",
    "sunteggi": "sunteggiare",
    "sunteggia": "sunteggiare",
    "sunteggiai": "sunteggiare",
    "sunteggiammo": "sunteggiare",
    "sunteggiamo": "sunteggiare",
    "sunteggian": "sunteggiare",
    "sunteggiando": "sunteggiare",
    "sunteggiano": "sunteggiare",
    "sunteggiante": "sunteggiare",
    "sunteggianti": "sunteggiare",
    "sunteggiar": "sunteggiare",
    "sunteggiaron": "sunteggiare",
    "sunteggiarono": "sunteggiare",
    "sunteggiasse": "sunteggiare",
    "sunteggiasser": "sunteggiare",
    "sunteggiassero": "sunteggiare",
    "sunteggiassi": "sunteggiare",
    "sunteggiassimo": "sunteggiare",
    "sunteggiaste": "sunteggiare",
    "sunteggiasti": "sunteggiare",
    "sunteggiata": "sunteggiare",
    "sunteggiate": "sunteggiare",
    "sunteggiati": "sunteggiare",
    "sunteggiato": "sunteggiare",
    "sunteggiava": "sunteggiare",
    "sunteggiavamo": "sunteggiare",
    "sunteggiavan": "sunteggiare",
    "sunteggiavano": "sunteggiare",
    "sunteggiavate": "sunteggiare",
    "sunteggiavi": "sunteggiare",
    "sunteggiavo": "sunteggiare",
    "sunteggin": "sunteggiare",
    "sunteggino": "sunteggiare",
    "sunteggio": "sunteggiare",
    "sunteggiò": "sunteggiare",
    "sunti": "sunto",
    "suocere": "suocera",
    "suoceri": "suocero",
    "suoi": "suo",
    "suola": "suolare",
    "suolai": "suolare",
    "suolammo": "suolare",
    "suolan": "suolare",
    "suolando": "suolare",
    "suolano": "suolare",
    "suolante": "suolare",
    "suolanti": "suolare",
    "suolar": "suolare",
    "suolaron": "suolare",
    "suolarono": "suolare",
    "suolasse": "suolare",
    "suolasser": "suolare",
    "suolassero": "suolare",
    "suolassi": "suolare",
    "suolassimo": "suolare",
    "suolaste": "suolare",
    "suolasti": "suolare",
    "suolata": "suolare",
    "suolate": "suolare",
    "suolati": "suolare",
    "suolato": "suolare",
    "suolava": "suolare",
    "suolavamo": "suolare",
    "suolavan": "suolare",
    "suolavano": "suolare",
    "suolavate": "suolare",
    "suolavi": "suolare",
    "suolavo": "suolare",
    "suole": "suola",
    "suolerai": "suolare",
    "suoleran": "suolare",
    "suoleranno": "suolare",
    "suolerebbe": "suolare",
    "suolerebber": "suolare",
    "suolerebbero": "suolare",
    "suolerei": "suolare",
    "suoleremmo": "suolare",
    "suoleremo": "suolare",
    "suolereste": "suolare",
    "suoleresti": "suolare",
    "suolerete": "suolare",
    "suolerà": "suolare",
    "suolerò": "suolare",
    "suoli": "suolo",
    "suoliamo": "suolare",
    "suoliate": "suolare",
    "suolin": "suolare",
    "suolino": "suolare",
    "suolo": "suolare",
    "suolò": "suolare",
    "suona": "suonare",
    "suonai": "suonare",
    "suonammo": "suonare",
    "suonan": "suonare",
    "suonando": "suonare",
    "suonano": "suonare",
    "suonante": "suonare",
    "suonanti": "suonare",
    "suonar": "suonare",
    "suonaron": "suonare",
    "suonarono": "suonare",
    "suonasse": "suonare",
    "suonasser": "suonare",
    "suonassero": "suonare",
    "suonassi": "suonare",
    "suonassimo": "suonare",
    "suonaste": "suonare",
    "suonasti": "suonare",
    "suonata": "suonato",
    "suonate": "suonato",
    "suonati": "suonato",
    "suonato": "suonare",
    "suonatori": "suonatore",
    "suonava": "suonare",
    "suonavamo": "suonare",
    "suonavan": "suonare",
    "suonavano": "suonare",
    "suonavate": "suonare",
    "suonavi": "suonare",
    "suonavo": "suonare",
    "suonerai": "suonare",
    "suoneran": "suonare",
    "suoneranno": "suonare",
    "suonerebbe": "suonare",
    "suonerebber": "suonare",
    "suonerebbero": "suonare",
    "suonerei": "suonare",
    "suoneremmo": "suonare",
    "suoneremo": "suonare",
    "suonereste": "suonare",
    "suoneresti": "suonare",
    "suonerete": "suonare",
    "suonerà": "suonare",
    "suonerò": "suonare",
    "suoni": "suono",
    "suoniamo": "suonare",
    "suoniate": "suonare",
    "suonin": "suonare",
    "suonino": "suonare",
    "suono": "suonare",
    "suonò": "suonare",
    "suore": "suora",
    "suorine": "suorina",
    "super-eroi": "super-eroe",
    "super-esperti": "super-esperto",
    "super-ispettori": "super-ispettore",
    "super-livellata": "super-livellato",
    "super-livellate": "super-livellato",
    "super-livellati": "super-livellato",
    "super-lussuosa": "super-lussuoso",
    "super-lussuose": "super-lussuoso",
    "super-lussuosi": "super-lussuoso",
    "super-magra": "super-magro",
    "super-magre": "super-magro",
    "super-magri": "super-magro",
    "super-moderata": "super-moderato",
    "super-moderate": "super-moderato",
    "super-moderati": "super-moderato",
    "super-moderna": "super-moderno",
    "super-moderne": "super-moderno",
    "super-moderni": "super-moderno",
    "super-mondana": "super-mondano",
    "super-mondane": "super-mondano",
    "super-mondani": "super-mondano",
    "super-ottimiste": "super-ottimista",
    "super-ottimisti": "super-ottimista",
    "super-paga": "super-pagare",
    "super-pagai": "super-pagare",
    "super-pagammo": "super-pagare",
    "super-pagan": "super-pagare",
    "super-pagando": "super-pagare",
    "super-pagano": "super-pagare",
    "super-pagante": "super-pagare",
    "super-paganti": "super-pagare",
    "super-pagar": "super-pagare",
    "super-pagaron": "super-pagare",
    "super-pagarono": "super-pagare",
    "super-pagasse": "super-pagare",
    "super-pagasser": "super-pagare",
    "super-pagassero": "super-pagare",
    "super-pagassi": "super-pagare",
    "super-pagassimo": "super-pagare",
    "super-pagaste": "super-pagare",
    "super-pagasti": "super-pagare",
    "super-pagata": "super-pagare",
    "super-pagate": "super-pagare",
    "super-pagati": "super-pagare",
    "super-pagato": "super-pagare",
    "super-pagava": "super-pagare",
    "super-pagavamo": "super-pagare",
    "super-pagavan": "super-pagare",
    "super-pagavano": "super-pagare",
    "super-pagavate": "super-pagare",
    "super-pagavi": "super-pagare",
    "super-pagavo": "super-pagare",
    "super-pagherai": "super-pagare",
    "super-pagheran": "super-pagare",
    "super-pagheranno": "super-pagare",
    "super-pagherebbe": "super-pagare",
    "super-pagherebber": "super-pagare",
    "super-pagherebbero": "super-pagare",
    "super-pagherei": "super-pagare",
    "super-pagheremmo": "super-pagare",
    "super-pagheremo": "super-pagare",
    "super-paghereste": "super-pagare",
    "super-pagheresti": "super-pagare",
    "super-pagherete": "super-pagare",
    "super-pagherà": "super-pagare",
    "super-pagherò": "super-pagare",
    "super-paghi": "super-pagare",
    "super-paghiamo": "super-pagare",
    "super-paghiate": "super-pagare",
    "super-paghin": "super-pagare",
    "super-paghino": "super-pagare",
    "super-pago": "super-pagare",
    "super-pagò": "super-pagare",
    "super-partitica": "super-partitico",
    "super-partitiche": "super-partitico",
    "super-partitici": "super-partitico",
    "super-potenti": "super-potente",
    "super-privilegiata": "super-privilegiato",
    "super-privilegiate": "super-privilegiato",
    "super-privilegiati": "super-privilegiato",
    "super-produttiva": "super-produttivo",
    "super-produttive": "super-produttivo",
    "super-produttivi": "super-produttivo",
    "super-professionali": "super-professionale",
    "super-professionistica": "super-professionistico",
    "super-professionistiche": "super-professionistico",
    "super-professionistici": "super-professionistico",
    "super-protetta": "super-protetto",
    "super-protette": "super-protetto",
    "super-protetti": "super-protetto",
    "super-pubblicizzata": "super-pubblicizzato",
    "super-pubblicizzate": "super-pubblicizzato",
    "super-pubblicizzati": "super-pubblicizzato",
    "super-raccomandata": "super-raccomandato",
    "super-raccomandate": "super-raccomandato",
    "super-raccomandati": "super-raccomandato",
    "super-rapida": "super-rapido",
    "super-rapide": "super-rapido",
    "super-rapidi": "super-rapido",
    "super-ricca": "super-ricco",
    "super-ricche": "super-ricco",
    "super-ricchi": "super-ricco",
    "supera": "superare",
    "superabili": "superabile",
    "superacceleratori": "superacceleratore",
    "superaccessoriata": "superaccessoriato",
    "superaccessoriate": "superaccessoriato",
    "superaccessoriati": "superaccessoriato",
    "superaffollata": "superaffollato",
    "superaffollate": "superaffollato",
    "superaffollati": "superaffollato",
    "superai": "superare",
    "superalcolici": "superalcolico",
    "superamenti": "superamento",
    "superammo": "superare",
    "superan": "superare",
    "superando": "superare",
    "superano": "superare",
    "superante": "superare",
    "superanti": "superare",
    "superar": "superare",
    "superaron": "superare",
    "superarono": "superare",
    "superasse": "superare",
    "superasser": "superare",
    "superassero": "superare",
    "superassi": "superare",
    "superassimo": "superare",
    "superaste": "superare",
    "superasti": "superare",
    "superata": "superato",
    "superate": "superato",
    "superati": "superato",
    "superato": "superare",
    "superava": "superare",
    "superavamo": "superare",
    "superavan": "superare",
    "superavano": "superare",
    "superavate": "superare",
    "superavi": "superare",
    "superavo": "superare",
    "superba": "superbo",
    "superbanche": "superbanca",
    "superbe": "superbo",
    "superbi": "superbo",
    "superbie": "superbia",
    "superbolli": "superbollo",
    "superbombardieri": "superbombardiere",
    "superburocrati": "superburocrate",
    "supercalcolatori": "supercalcolatore",
    "supercampioni": "supercampione",
    "supercannoni": "supercannone",
    "supercarceri": "supercarcere",
    "superconduttiva": "superconduttivo",
    "superconduttive": "superconduttivo",
    "superconduttivi": "superconduttivo",
    "superconsulenti": "superconsulente",
    "supercontrollori": "supercontrollore",
    "superdazi": "superdazio",
    "superdollari": "superdollaro",
    "superdonne": "superdonna",
    "superenalotti": "superenalotto",
    "supererai": "superare",
    "supereran": "superare",
    "supereranno": "superare",
    "supererebbe": "superare",
    "supererebber": "superare",
    "supererebbero": "superare",
    "supererei": "superare",
    "supereremmo": "superare",
    "supereremo": "superare",
    "superereste": "superare",
    "supereresti": "superare",
    "supererete": "superare",
    "supereroi": "supereroe",
    "supererà": "superare",
    "supererò": "superare",
    "superesperti": "superesperto",
    "superfetazioni": "superfetazione",
    "superfici": "superficie",
    "superficiali": "superficiale",
    "superflua": "superfluo",
    "superflue": "superfluo",
    "superflui": "superfluo",
    "superfortezze": "superfortezza",
    "supergiganti": "supergigante",
    "supergruppi": "supergruppo",
    "superi": "superare",
    "superiamo": "superare",
    "superiate": "superare",
    "superin": "superare",
    "superindici": "superindice",
    "superino": "superare",
    "superiore": "superiora",
    "superiori": "superiore",
    "superispettori": "superispettore",
    "superlatitanti": "superlatitante",
    "superlativa": "superlativo",
    "superlative": "superlativo",
    "superlativi": "superlativo",
    "superlavori": "superlavoro",
    "superleghe": "superlega",
    "superliquida": "superliquido",
    "superliquide": "superliquido",
    "superliquidi": "superliquido",
    "superlongeva": "superlongevo",
    "superlongeve": "superlongevo",
    "superlongevi": "superlongevo",
    "superloquaci": "superloquace",
    "superlottizzata": "superlottizzato",
    "superlottizzate": "superlottizzato",
    "superlottizzati": "superlottizzato",
    "superlussuosa": "superlussuoso",
    "superlussuose": "superlussuoso",
    "superlussuosi": "superlussuoso",
    "supermagra": "supermagro",
    "supermagre": "supermagro",
    "supermagri": "supermagro",
    "supermarchi": "supermarco",
    "supermegagalattica": "supermegagalattico",
    "supermegagalattiche": "supermegagalattico",
    "supermegagalattici": "supermegagalattico",
    "supermercati": "supermercato",
    "supermiliardari": "supermiliardario",
    "superminimi": "superminimo",
    "superministeri": "superministero",
    "superministri": "superministro",
    "supermodellanti": "supermodellante",
    "supermodelle": "supermodella",
    "supermoderata": "supermoderato",
    "supermoderate": "supermoderato",
    "supermoderati": "supermoderato",
    "supermoderna": "supermoderno",
    "supermoderne": "supermoderno",
    "supermoderni": "supermoderno",
    "supermolleggiata": "supermolleggiato",
    "supermolleggiate": "supermolleggiato",
    "supermolleggiati": "supermolleggiato",
    "supermondana": "supermondano",
    "supermondane": "supermondano",
    "supermondani": "supermondano",
    "supermulte": "supermulta",
    "superna": "superno",
    "supernazionali": "supernazionale",
    "superne": "superno",
    "superni": "superno",
    "supero": "superare",
    "superospiti": "superospite",
    "superottimiste": "superottimista",
    "superottimisti": "superottimista",
    "superpaga": "superpagare",
    "superpagai": "superpagare",
    "superpagammo": "superpagare",
    "superpagan": "superpagare",
    "superpagando": "superpagare",
    "superpagano": "superpagare",
    "superpagante": "superpagare",
    "superpaganti": "superpagare",
    "superpagar": "superpagare",
    "superpagaron": "superpagare",
    "superpagarono": "superpagare",
    "superpagasse": "superpagare",
    "superpagasser": "superpagare",
    "superpagassero": "superpagare",
    "superpagassi": "superpagare",
    "superpagassimo": "superpagare",
    "superpagaste": "superpagare",
    "superpagasti": "superpagare",
    "superpagata": "superpagare",
    "superpagate": "superpagare",
    "superpagati": "superpagare",
    "superpagato": "superpagare",
    "superpagava": "superpagare",
    "superpagavamo": "superpagare",
    "superpagavan": "superpagare",
    "superpagavano": "superpagare",
    "superpagavate": "superpagare",
    "superpagavi": "superpagare",
    "superpagavo": "superpagare",
    "superpagherai": "superpagare",
    "superpagheran": "superpagare",
    "superpagheranno": "superpagare",
    "superpagherebbe": "superpagare",
    "superpagherebber": "superpagare",
    "superpagherebbero": "superpagare",
    "superpagherei": "superpagare",
    "superpagheremmo": "superpagare",
    "superpagheremo": "superpagare",
    "superpaghereste": "superpagare",
    "superpagheresti": "superpagare",
    "superpagherete": "superpagare",
    "superpagherà": "superpagare",
    "superpagherò": "superpagare",
    "superpaghi": "superpagare",
    "superpaghiamo": "superpagare",
    "superpaghiate": "superpagare",
    "superpaghin": "superpagare",
    "superpaghino": "superpagare",
    "superpago": "superpagare",
    "superpagò": "superpagare",
    "superpartiti": "superpartito",
    "superpatinata": "superpatinato",
    "superpatinate": "superpatinato",
    "superpatinati": "superpatinato",
    "superpatriottica": "superpatriottico",
    "superpatriottiche": "superpatriottico",
    "superpatriottici": "superpatriottico",
    "superpentiti": "superpentito",
    "superperizie": "superperizia",
    "superpersonalizzata": "superpersonalizzato",
    "superpersonalizzate": "superpersonalizzato",
    "superpersonalizzati": "superpersonalizzato",
    "superpesanti": "superpesante",
    "superpetroliere": "superpetroliera",
    "superpolizie": "superpolizia",
    "superpoliziotti": "superpoliziotto",
    "superpotenti": "superpotente",
    "superpotenze": "superpotenza",
    "superpoteri": "superpotere",
    "superprecisa": "superpreciso",
    "superprecise": "superpreciso",
    "superprecisi": "superpreciso",
    "superpreferenziali": "superpreferenziale",
    "superprefetti": "superprefetto",
    "superprivilegiata": "superprivilegiato",
    "superprivilegiate": "superprivilegiato",
    "superprivilegiati": "superprivilegiato",
    "superprocuratori": "superprocuratore",
    "superprocure": "superprocura",
    "superproduttiva": "superproduttivo",
    "superproduttive": "superproduttivo",
    "superproduttivi": "superproduttivo",
    "superproduzioni": "superproduzione",
    "superprofessionali": "superprofessionale",
    "superprofessionistica": "superprofessionistico",
    "superprofessionistiche": "superprofessionistico",
    "superprofessionistici": "superprofessionistico",
    "superprotegga": "superproteggere",
    "superproteggan": "superproteggere",
    "superproteggano": "superproteggere",
    "superprotegge": "superproteggere",
    "superproteggemmo": "superproteggere",
    "superproteggendo": "superproteggere",
    "superproteggente": "superproteggere",
    "superproteggenti": "superproteggere",
    "superprotegger": "superproteggere",
    "superproteggerai": "superproteggere",
    "superproteggeran": "superproteggere",
    "superproteggeranno": "superproteggere",
    "superproteggerebbe": "superproteggere",
    "superproteggerebber": "superproteggere",
    "superproteggerebbero": "superproteggere",
    "superproteggerei": "superproteggere",
    "superproteggeremmo": "superproteggere",
    "superproteggeremo": "superproteggere",
    "superproteggereste": "superproteggere",
    "superproteggeresti": "superproteggere",
    "superproteggerete": "superproteggere",
    "superproteggerà": "superproteggere",
    "superproteggerò": "superproteggere",
    "superproteggesse": "superproteggere",
    "superproteggesser": "superproteggere",
    "superproteggessero": "superproteggere",
    "superproteggessi": "superproteggere",
    "superproteggessimo": "superproteggere",
    "superproteggeste": "superproteggere",
    "superproteggesti": "superproteggere",
    "superproteggete": "superproteggere",
    "superproteggeva": "superproteggere",
    "superproteggevamo": "superproteggere",
    "superproteggevan": "superproteggere",
    "superproteggevano": "superproteggere",
    "superproteggevate": "superproteggere",
    "superproteggevi": "superproteggere",
    "superproteggevo": "superproteggere",
    "superproteggi": "superproteggere",
    "superproteggiamo": "superproteggere",
    "superproteggiate": "superproteggere",
    "superproteggo": "superproteggere",
    "superproteggon": "superproteggere",
    "superproteggono": "superproteggere",
    "superprotesser": "superproteggere",
    "superprotessero": "superproteggere",
    "superprotessi": "superproteggere",
    "superprotessè": "superproteggere",
    "superprotetta": "superprotetto",
    "superprotette": "superprotetto",
    "superprotetti": "superprotetto",
    "superprotetto": "superproteggere",
    "superpubblicizzata": "superpubblicizzato",
    "superpubblicizzate": "superpubblicizzato",
    "superpubblicizzati": "superpubblicizzato",
    "superrapida": "superrapido",
    "superrapide": "superrapido",
    "superrapidi": "superrapido",
    "supersonica": "supersonico",
    "supersoniche": "supersonico",
    "supersonici": "supersonico",
    "superstiti": "superstite",
    "superstizioni": "superstizione",
    "superstiziosa": "superstizioso",
    "superstiziose": "superstizioso",
    "superstiziosi": "superstizioso",
    "superstrade": "superstrada",
    "supertasse": "supertassa",
    "supertecnici": "supertecnico",
    "supertelefonini": "supertelefonino",
    "supertesti": "superteste",
    "supertestimoni": "supertestimone",
    "supertreni": "supertreno",
    "superuomini": "superuomo",
    "supervalutazioni": "supervalutazione",
    "superveloci": "superveloce",
    "supervertici": "supervertice",
    "supervincitori": "supervincitore",
    "supervisioni": "supervisione",
    "supervisori": "supervisore",
    "superò": "superare",
    "supina": "supino",
    "supine": "supino",
    "supini": "supino",
    "suppellettili": "suppellettile",
    "supplementa": "supplementare",
    "supplementai": "supplementare",
    "supplementammo": "supplementare",
    "supplementan": "supplementare",
    "supplementando": "supplementare",
    "supplementano": "supplementare",
    "supplementante": "supplementare",
    "supplementanti": "supplementare",
    "supplementar": "supplementare",
    "supplementari": "supplementare",
    "supplementaron": "supplementare",
    "supplementarono": "supplementare",
    "supplementasse": "supplementare",
    "supplementasser": "supplementare",
    "supplementassero": "supplementare",
    "supplementassi": "supplementare",
    "supplementassimo": "supplementare",
    "supplementaste": "supplementare",
    "supplementasti": "supplementare",
    "supplementata": "supplementare",
    "supplementate": "supplementare",
    "supplementati": "supplementare",
    "supplementato": "supplementare",
    "supplementava": "supplementare",
    "supplementavamo": "supplementare",
    "supplementavan": "supplementare",
    "supplementavano": "supplementare",
    "supplementavate": "supplementare",
    "supplementavi": "supplementare",
    "supplementavo": "supplementare",
    "supplementerai": "supplementare",
    "supplementeran": "supplementare",
    "supplementeranno": "supplementare",
    "supplementerebbe": "supplementare",
    "supplementerebber": "supplementare",
    "supplementerebbero": "supplementare",
    "supplementerei": "supplementare",
    "supplementeremmo": "supplementare",
    "supplementeremo": "supplementare",
    "supplementereste": "supplementare",
    "supplementeresti": "supplementare",
    "supplementerete": "supplementare",
    "supplementerà": "supplementare",
    "supplementerò": "supplementare",
    "supplementi": "supplemento",
    "supplementiamo": "supplementare",
    "supplementiate": "supplementare",
    "supplementin": "supplementare",
    "supplementino": "supplementare",
    "supplemento": "supplementare",
    "supplementò": "supplementare",
    "supplendo": "supplire",
    "supplente": "supplire",
    "supplenti": "supplire",
    "supplenze": "supplenza",
    "suppletiva": "suppletivo",
    "suppletive": "suppletivo",
    "suppletivi": "suppletivo",
    "supplettiva": "supplettivo",
    "supplettive": "supplettivo",
    "supplettivi": "supplettivo",
    "suppliamo": "supplire",
    "suppliate": "supplire",
    "supplica": "supplicare",
    "supplicai": "supplicare",
    "supplicammo": "supplicare",
    "supplican": "supplicare",
    "supplicando": "supplicare",
    "supplicano": "supplicare",
    "supplicante": "supplicare",
    "supplicanti": "supplicare",
    "supplicar": "supplicare",
    "supplicaron": "supplicare",
    "supplicarono": "supplicare",
    "supplicasse": "supplicare",
    "supplicasser": "supplicare",
    "supplicassero": "supplicare",
    "supplicassi": "supplicare",
    "supplicassimo": "supplicare",
    "supplicaste": "supplicare",
    "supplicasti": "supplicare",
    "supplicata": "supplicare",
    "supplicate": "supplicare",
    "supplicati": "supplicare",
    "supplicato": "supplicare",
    "supplicava": "supplicare",
    "supplicavamo": "supplicare",
    "supplicavan": "supplicare",
    "supplicavano": "supplicare",
    "supplicavate": "supplicare",
    "supplicavi": "supplicare",
    "supplicavo": "supplicare",
    "suppliche": "supplica",
    "supplicherai": "supplicare",
    "supplicheran": "supplicare",
    "supplicheranno": "supplicare",
    "supplicherebbe": "supplicare",
    "supplicherebber": "supplicare",
    "supplicherebbero": "supplicare",
    "supplicherei": "supplicare",
    "supplicheremmo": "supplicare",
    "supplicheremo": "supplicare",
    "supplichereste": "supplicare",
    "supplicheresti": "supplicare",
    "supplicherete": "supplicare",
    "supplicherà": "supplicare",
    "supplicherò": "supplicare",
    "supplichevoli": "supplichevole",
    "supplichi": "supplicare",
    "supplichiamo": "supplicare",
    "supplichiate": "supplicare",
    "supplichin": "supplicare",
    "supplichino": "supplicare",
    "supplici": "supplice",
    "supplico": "supplicare",
    "supplicò": "supplicare",
    "supplii": "supplire",
    "supplimmo": "supplire",
    "supplir": "supplire",
    "supplirai": "supplire",
    "suppliran": "supplire",
    "suppliranno": "supplire",
    "supplirebbe": "supplire",
    "supplirebber": "supplire",
    "supplirebbero": "supplire",
    "supplirei": "supplire",
    "suppliremmo": "supplire",
    "suppliremo": "supplire",
    "supplireste": "supplire",
    "suppliresti": "supplire",
    "supplirete": "supplire",
    "suppliron": "supplire",
    "supplirono": "supplire",
    "supplirà": "supplire",
    "supplirò": "supplire",
    "supplisca": "supplire",
    "suppliscan": "supplire",
    "suppliscano": "supplire",
    "supplisce": "supplire",
    "supplisci": "supplire",
    "supplisco": "supplire",
    "suppliscon": "supplire",
    "suppliscono": "supplire",
    "supplisse": "supplire",
    "supplisser": "supplire",
    "supplissero": "supplire",
    "supplissi": "supplire",
    "supplissimo": "supplire",
    "suppliste": "supplire",
    "supplisti": "supplire",
    "supplita": "supplire",
    "supplite": "supplire",
    "suppliti": "supplire",
    "supplito": "supplire",
    "suppliva": "supplire",
    "supplivamo": "supplire",
    "supplivan": "supplire",
    "supplivano": "supplire",
    "supplivate": "supplire",
    "supplivi": "supplire",
    "supplivo": "supplire",
    "supplizi": "supplizio",
    "supplizia": "suppliziare",
    "suppliziai": "suppliziare",
    "suppliziammo": "suppliziare",
    "suppliziamo": "suppliziare",
    "supplizian": "suppliziare",
    "suppliziando": "suppliziare",
    "suppliziano": "suppliziare",
    "suppliziante": "suppliziare",
    "supplizianti": "suppliziare",
    "suppliziar": "suppliziare",
    "suppliziaron": "suppliziare",
    "suppliziarono": "suppliziare",
    "suppliziasse": "suppliziare",
    "suppliziasser": "suppliziare",
    "suppliziassero": "suppliziare",
    "suppliziassi": "suppliziare",
    "suppliziassimo": "suppliziare",
    "suppliziaste": "suppliziare",
    "suppliziasti": "suppliziare",
    "suppliziata": "suppliziare",
    "suppliziate": "suppliziare",
    "suppliziati": "suppliziare",
    "suppliziato": "suppliziare",
    "suppliziava": "suppliziare",
    "suppliziavamo": "suppliziare",
    "suppliziavan": "suppliziare",
    "suppliziavano": "suppliziare",
    "suppliziavate": "suppliziare",
    "suppliziavi": "suppliziare",
    "suppliziavo": "suppliziare",
    "supplizierai": "suppliziare",
    "supplizieran": "suppliziare",
    "supplizieranno": "suppliziare",
    "supplizierebbe": "suppliziare",
    "supplizierebber": "suppliziare",
    "supplizierebbero": "suppliziare",
    "supplizierei": "suppliziare",
    "supplizieremmo": "suppliziare",
    "supplizieremo": "suppliziare",
    "suppliziereste": "suppliziare",
    "supplizieresti": "suppliziare",
    "supplizierete": "suppliziare",
    "supplizierà": "suppliziare",
    "supplizierò": "suppliziare",
    "supplizin": "suppliziare",
    "supplizino": "suppliziare",
    "supplizio": "suppliziare",
    "suppliziò": "suppliziare",
    "supplì": "supplire",
    "suppone": "supporre",
    "supponemmo": "supporre",
    "supponendo": "supporre",
    "supponente": "supporre",
    "supponenti": "supporre",
    "supponenze": "supponenza",
    "supponesse": "supporre",
    "supponesser": "supporre",
    "supponessero": "supporre",
    "supponessi": "supporre",
    "supponessimo": "supporre",
    "supponeste": "supporre",
    "supponesti": "supporre",
    "supponete": "supporre",
    "supponeva": "supporre",
    "supponevamo": "supporre",
    "supponevan": "supporre",
    "supponevano": "supporre",
    "supponevate": "supporre",
    "supponevi": "supporre",
    "supponevo": "supporre",
    "supponga": "supporre",
    "suppongan": "supporre",
    "suppongano": "supporre",
    "suppongo": "supporre",
    "suppongon": "supporre",
    "suppongono": "supporre",
    "supponi": "supporre",
    "supponiamo": "supporre",
    "supponiate": "supporre",
    "supporr": "supporre",
    "supporrai": "supporre",
    "supporran": "supporre",
    "supporranno": "supporre",
    "supporrebbe": "supporre",
    "supporrebber": "supporre",
    "supporrebbero": "supporre",
    "supporrei": "supporre",
    "supporremmo": "supporre",
    "supporremo": "supporre",
    "supporreste": "supporre",
    "supporresti": "supporre",
    "supporrete": "supporre",
    "supporrà": "supporre",
    "supporrò": "supporre",
    "supporta": "supportare",
    "supportai": "supportare",
    "supportammo": "supportare",
    "supportan": "supportare",
    "supportando": "supportare",
    "supportano": "supportare",
    "supportante": "supportare",
    "supportanti": "supportare",
    "supportar": "supportare",
    "supportaron": "supportare",
    "supportarono": "supportare",
    "supportasse": "supportare",
    "supportasser": "supportare",
    "supportassero": "supportare",
    "supportassi": "supportare",
    "supportassimo": "supportare",
    "supportaste": "supportare",
    "supportasti": "supportare",
    "supportata": "supportare",
    "supportate": "supportare",
    "supportati": "supportare",
    "supportato": "supportare",
    "supportava": "supportare",
    "supportavamo": "supportare",
    "supportavan": "supportare",
    "supportavano": "supportare",
    "supportavate": "supportare",
    "supportavi": "supportare",
    "supportavo": "supportare",
    "supporterai": "supportare",
    "supporteran": "supportare",
    "supporteranno": "supportare",
    "supporterebbe": "supportare",
    "supporterebber": "supportare",
    "supporterebbero": "supportare",
    "supporterei": "supportare",
    "supporteremmo": "supportare",
    "supporteremo": "supportare",
    "supportereste": "supportare",
    "supporteresti": "supportare",
    "supporterete": "supportare",
    "supporters": "supporter",
    "supporterà": "supportare",
    "supporterò": "supportare",
    "supporti": "supporto",
    "supportiamo": "supportare",
    "supportiate": "supportare",
    "supportin": "supportare",
    "supportino": "supportare",
    "supporto": "supportare",
    "supportò": "supportare",
    "suppose": "supporre",
    "supposer": "supporre",
    "supposero": "supporre",
    "supposi": "supporre",
    "supposizioni": "supposizione",
    "supposta": "supporre",
    "supposte": "supposta",
    "supposti": "supporre",
    "supposto": "supporre",
    "suppura": "suppurare",
    "suppurai": "suppurare",
    "suppurammo": "suppurare",
    "suppuran": "suppurare",
    "suppurando": "suppurare",
    "suppurano": "suppurare",
    "suppurante": "suppurare",
    "suppuranti": "suppurare",
    "suppurar": "suppurare",
    "suppuraron": "suppurare",
    "suppurarono": "suppurare",
    "suppurasse": "suppurare",
    "suppurasser": "suppurare",
    "suppurassero": "suppurare",
    "suppurassi": "suppurare",
    "suppurassimo": "suppurare",
    "suppuraste": "suppurare",
    "suppurasti": "suppurare",
    "suppurata": "suppurare",
    "suppurate": "suppurare",
    "suppurati": "suppurare",
    "suppurato": "suppurare",
    "suppurava": "suppurare",
    "suppuravamo": "suppurare",
    "suppuravan": "suppurare",
    "suppuravano": "suppurare",
    "suppuravate": "suppurare",
    "suppuravi": "suppurare",
    "suppuravo": "suppurare",
    "suppurerai": "suppurare",
    "suppureran": "suppurare",
    "suppureranno": "suppurare",
    "suppurerebbe": "suppurare",
    "suppurerebber": "suppurare",
    "suppurerebbero": "suppurare",
    "suppurerei": "suppurare",
    "suppureremmo": "suppurare",
    "suppureremo": "suppurare",
    "suppurereste": "suppurare",
    "suppureresti": "suppurare",
    "suppurerete": "suppurare",
    "suppurerà": "suppurare",
    "suppurerò": "suppurare",
    "suppuri": "suppurare",
    "suppuriamo": "suppurare",
    "suppuriate": "suppurare",
    "suppurin": "suppurare",
    "suppurino": "suppurare",
    "suppuro": "suppurare",
    "suppurò": "suppurare",
    "suprema": "supremo",
    "supremazie": "supremazia",
    "supreme": "supremo",
    "supremi": "supremo",
    "surclassa": "surclassare",
    "surclassai": "surclassare",
    "surclassammo": "surclassare",
    "surclassan": "surclassare",
    "surclassando": "surclassare",
    "surclassano": "surclassare",
    "surclassante": "surclassare",
    "surclassanti": "surclassare",
    "surclassar": "surclassare",
    "surclassaron": "surclassare",
    "surclassarono": "surclassare",
    "surclassasse": "surclassare",
    "surclassasser": "surclassare",
    "surclassassero": "surclassare",
    "surclassassi": "surclassare",
    "surclassassimo": "surclassare",
    "surclassaste": "surclassare",
    "surclassasti": "surclassare",
    "surclassata": "surclassare",
    "surclassate": "surclassare",
    "surclassati": "surclassare",
    "surclassato": "surclassare",
    "surclassava": "surclassare",
    "surclassavamo": "surclassare",
    "surclassavan": "surclassare",
    "surclassavano": "surclassare",
    "surclassavate": "surclassare",
    "surclassavi": "surclassare",
    "surclassavo": "surclassare",
    "surclasserai": "surclassare",
    "surclasseran": "surclassare",
    "surclasseranno": "surclassare",
    "surclasserebbe": "surclassare",
    "surclasserebber": "surclassare",
    "surclasserebbero": "surclassare",
    "surclasserei": "surclassare",
    "surclasseremmo": "surclassare",
    "surclasseremo": "surclassare",
    "surclassereste": "surclassare",
    "surclasseresti": "surclassare",
    "surclasserete": "surclassare",
    "surclasserà": "surclassare",
    "surclasserò": "surclassare",
    "surclassi": "surclassare",
    "surclassiamo": "surclassare",
    "surclassiate": "surclassare",
    "surclassin": "surclassare",
    "surclassino": "surclassare",
    "surclasso": "surclassare",
    "surclassò": "surclassare",
    "surfisti": "surfista",
    "surgela": "surgelare",
    "surgelai": "surgelare",
    "surgelammo": "surgelare",
    "surgelan": "surgelare",
    "surgelando": "surgelare",
    "surgelano": "surgelare",
    "surgelante": "surgelare",
    "surgelanti": "surgelare",
    "surgelar": "surgelare",
    "surgelaron": "surgelare",
    "surgelarono": "surgelare",
    "surgelasse": "surgelare",
    "surgelasser": "surgelare",
    "surgelassero": "surgelare",
    "surgelassi": "surgelare",
    "surgelassimo": "surgelare",
    "surgelaste": "surgelare",
    "surgelasti": "surgelare",
    "surgelata": "surgelato",
    "surgelate": "surgelato",
    "surgelati": "surgelato",
    "surgelato": "surgelare",
    "surgelava": "surgelare",
    "surgelavamo": "surgelare",
    "surgelavan": "surgelare",
    "surgelavano": "surgelare",
    "surgelavate": "surgelare",
    "surgelavi": "surgelare",
    "surgelavo": "surgelare",
    "surgelerai": "surgelare",
    "surgeleran": "surgelare",
    "surgeleranno": "surgelare",
    "surgelerebbe": "surgelare",
    "surgelerebber": "surgelare",
    "surgelerebbero": "surgelare",
    "surgelerei": "surgelare",
    "surgeleremmo": "surgelare",
    "surgeleremo": "surgelare",
    "surgelereste": "surgelare",
    "surgeleresti": "surgelare",
    "surgelerete": "surgelare",
    "surgelerà": "surgelare",
    "surgelerò": "surgelare",
    "surgeli": "surgelare",
    "surgeliamo": "surgelare",
    "surgeliate": "surgelare",
    "surgelin": "surgelare",
    "surgelino": "surgelare",
    "surgelo": "surgelare",
    "surgelò": "surgelare",
    "surino-batava": "surino-batavo",
    "surino-batave": "surino-batavo",
    "surino-batavi": "surino-batavo",
    "surreali": "surreale",
    "surrealismi": "surrealismo",
    "surrealiste": "surrealista",
    "surrealisti": "surrealista",
    "surrealistica": "surrealistico",
    "surrealistiche": "surrealistico",
    "surrealistici": "surrealistico",
    "surrenali": "surrenale",
    "surrettizi": "surrettizio",
    "surrettizia": "surrettizio",
    "surrettizie": "surrettizio",
    "surriscalda": "surriscaldare",
    "surriscaldai": "surriscaldare",
    "surriscaldamenti": "surriscaldamento",
    "surriscaldammo": "surriscaldare",
    "surriscaldan": "surriscaldare",
    "surriscaldando": "surriscaldare",
    "surriscaldano": "surriscaldare",
    "surriscaldante": "surriscaldare",
    "surriscaldanti": "surriscaldare",
    "surriscaldar": "surriscaldare",
    "surriscaldaron": "surriscaldare",
    "surriscaldarono": "surriscaldare",
    "surriscaldasse": "surriscaldare",
    "surriscaldasser": "surriscaldare",
    "surriscaldassero": "surriscaldare",
    "surriscaldassi": "surriscaldare",
    "surriscaldassimo": "surriscaldare",
    "surriscaldaste": "surriscaldare",
    "surriscaldasti": "surriscaldare",
    "surriscaldata": "surriscaldato",
    "surriscaldate": "surriscaldato",
    "surriscaldati": "surriscaldato",
    "surriscaldato": "surriscaldare",
    "surriscaldava": "surriscaldare",
    "surriscaldavamo": "surriscaldare",
    "surriscaldavan": "surriscaldare",
    "surriscaldavano": "surriscaldare",
    "surriscaldavate": "surriscaldare",
    "surriscaldavi": "surriscaldare",
    "surriscaldavo": "surriscaldare",
    "surriscalderai": "surriscaldare",
    "surriscalderan": "surriscaldare",
    "surriscalderanno": "surriscaldare",
    "surriscalderebbe": "surriscaldare",
    "surriscalderebber": "surriscaldare",
    "surriscalderebbero": "surriscaldare",
    "surriscalderei": "surriscaldare",
    "surriscalderemmo": "surriscaldare",
    "surriscalderemo": "surriscaldare",
    "surriscaldereste": "surriscaldare",
    "surriscalderesti": "surriscaldare",
    "surriscalderete": "surriscaldare",
    "surriscalderà": "surriscaldare",
    "surriscalderò": "surriscaldare",
    "surriscaldi": "surriscaldare",
    "surriscaldiamo": "surriscaldare",
    "surriscaldiate": "surriscaldare",
    "surriscaldin": "surriscaldare",
    "surriscaldino": "surriscaldare",
    "surriscaldo": "surriscaldare",
    "surriscaldò": "surriscaldare",
    "surroga": "surrogare",
    "surrogabili": "surrogabile",
    "surrogai": "surrogare",
    "surrogammo": "surrogare",
    "surrogan": "surrogare",
    "surrogando": "surrogare",
    "surrogano": "surrogare",
    "surrogante": "surrogare",
    "surroganti": "surrogare",
    "surrogar": "surrogare",
    "surrogaron": "surrogare",
    "surrogarono": "surrogare",
    "surrogasse": "surrogare",
    "surrogasser": "surrogare",
    "surrogassero": "surrogare",
    "surrogassi": "surrogare",
    "surrogassimo": "surrogare",
    "surrogaste": "surrogare",
    "surrogasti": "surrogare",
    "surrogata": "surrogato",
    "surrogate": "surrogato",
    "surrogati": "surrogato",
    "surrogato": "surrogare",
    "surrogava": "surrogare",
    "surrogavamo": "surrogare",
    "surrogavan": "surrogare",
    "surrogavano": "surrogare",
    "surrogavate": "surrogare",
    "surrogavi": "surrogare",
    "surrogavo": "surrogare",
    "surrogherai": "surrogare",
    "surrogheran": "surrogare",
    "surrogheranno": "surrogare",
    "surrogherebbe": "surrogare",
    "surrogherebber": "surrogare",
    "surrogherebbero": "surrogare",
    "surrogherei": "surrogare",
    "surrogheremmo": "surrogare",
    "surrogheremo": "surrogare",
    "surroghereste": "surrogare",
    "surrogheresti": "surrogare",
    "surrogherete": "surrogare",
    "surrogherà": "surrogare",
    "surrogherò": "surrogare",
    "surroghi": "surrogare",
    "surroghiamo": "surrogare",
    "surroghiate": "surrogare",
    "surroghin": "surrogare",
    "surroghino": "surrogare",
    "surrogo": "surrogare",
    "surrogò": "surrogare",
    "suscettibili": "suscettibile",
    "suscita": "suscitare",
    "suscitai": "suscitare",
    "suscitammo": "suscitare",
    "suscitan": "suscitare",
    "suscitando": "suscitare",
    "suscitano": "suscitare",
    "suscitante": "suscitare",
    "suscitanti": "suscitare",
    "suscitar": "suscitare",
    "suscitaron": "suscitare",
    "suscitarono": "suscitare",
    "suscitasse": "suscitare",
    "suscitasser": "suscitare",
    "suscitassero": "suscitare",
    "suscitassi": "suscitare",
    "suscitassimo": "suscitare",
    "suscitaste": "suscitare",
    "suscitasti": "suscitare",
    "suscitata": "suscitare",
    "suscitate": "suscitare",
    "suscitati": "suscitare",
    "suscitato": "suscitare",
    "suscitatori": "suscitatore",
    "suscitatrice": "suscitatore",
    "suscitatrici": "suscitatore",
    "suscitava": "suscitare",
    "suscitavamo": "suscitare",
    "suscitavan": "suscitare",
    "suscitavano": "suscitare",
    "suscitavate": "suscitare",
    "suscitavi": "suscitare",
    "suscitavo": "suscitare",
    "susciterai": "suscitare",
    "susciteran": "suscitare",
    "susciteranno": "suscitare",
    "susciterebbe": "suscitare",
    "susciterebber": "suscitare",
    "susciterebbero": "suscitare",
    "susciterei": "suscitare",
    "susciteremmo": "suscitare",
    "susciteremo": "suscitare",
    "suscitereste": "suscitare",
    "susciteresti": "suscitare",
    "susciterete": "suscitare",
    "susciterà": "suscitare",
    "susciterò": "suscitare",
    "susciti": "suscitare",
    "suscitiamo": "suscitare",
    "suscitiate": "suscitare",
    "suscitin": "suscitare",
    "suscitino": "suscitare",
    "suscito": "suscitare",
    "suscitò": "suscitare",
    "susine": "susina",
    "sussegua": "susseguire",
    "susseguan": "susseguire",
    "susseguano": "susseguire",
    "sussegue": "susseguire",
    "susseguendo": "susseguire",
    "susseguente": "susseguire",
    "susseguenti": "susseguire",
    "sussegui": "susseguire",
    "susseguiamo": "susseguire",
    "susseguiate": "susseguire",
    "susseguii": "susseguire",
    "susseguimmo": "susseguire",
    "susseguir": "susseguire",
    "susseguirai": "susseguire",
    "susseguiran": "susseguire",
    "susseguiranno": "susseguire",
    "susseguirebbe": "susseguire",
    "susseguirebber": "susseguire",
    "susseguirebbero": "susseguire",
    "susseguirei": "susseguire",
    "susseguiremmo": "susseguire",
    "susseguiremo": "susseguire",
    "susseguireste": "susseguire",
    "susseguiresti": "susseguire",
    "susseguirete": "susseguire",
    "susseguiron": "susseguire",
    "susseguirono": "susseguire",
    "susseguirà": "susseguire",
    "susseguirò": "susseguire",
    "susseguisse": "susseguire",
    "susseguisser": "susseguire",
    "susseguissero": "susseguire",
    "susseguissi": "susseguire",
    "susseguissimo": "susseguire",
    "susseguiste": "susseguire",
    "susseguisti": "susseguire",
    "susseguita": "susseguire",
    "susseguite": "susseguire",
    "susseguiti": "susseguire",
    "susseguito": "susseguire",
    "susseguiva": "susseguire",
    "susseguivamo": "susseguire",
    "susseguivan": "susseguire",
    "susseguivano": "susseguire",
    "susseguivate": "susseguire",
    "susseguivi": "susseguire",
    "susseguivo": "susseguire",
    "susseguo": "susseguire",
    "susseguon": "susseguire",
    "susseguono": "susseguire",
    "susseguì": "susseguire",
    "susser": "suggere",
    "sussero": "suggere",
    "sussi": "suggere",
    "sussidi": "sussidio",
    "sussidia": "sussidiare",
    "sussidiai": "sussidiare",
    "sussidiammo": "sussidiare",
    "sussidiamo": "sussidiare",
    "sussidian": "sussidiare",
    "sussidiando": "sussidiare",
    "sussidiano": "sussidiare",
    "sussidiante": "sussidiare",
    "sussidianti": "sussidiare",
    "sussidiar": "sussidiare",
    "sussidiari": "sussidiario",
    "sussidiaria": "sussidiario",
    "sussidiarie": "sussidiario",
    "sussidiaron": "sussidiare",
    "sussidiarono": "sussidiare",
    "sussidiasse": "sussidiare",
    "sussidiasser": "sussidiare",
    "sussidiassero": "sussidiare",
    "sussidiassi": "sussidiare",
    "sussidiassimo": "sussidiare",
    "sussidiaste": "sussidiare",
    "sussidiasti": "sussidiare",
    "sussidiata": "sussidiare",
    "sussidiate": "sussidiare",
    "sussidiati": "sussidiare",
    "sussidiato": "sussidiare",
    "sussidiava": "sussidiare",
    "sussidiavamo": "sussidiare",
    "sussidiavan": "sussidiare",
    "sussidiavano": "sussidiare",
    "sussidiavate": "sussidiare",
    "sussidiavi": "sussidiare",
    "sussidiavo": "sussidiare",
    "sussidierai": "sussidiare",
    "sussidieran": "sussidiare",
    "sussidieranno": "sussidiare",
    "sussidierebbe": "sussidiare",
    "sussidierebber": "sussidiare",
    "sussidierebbero": "sussidiare",
    "sussidierei": "sussidiare",
    "sussidieremmo": "sussidiare",
    "sussidieremo": "sussidiare",
    "sussidiereste": "sussidiare",
    "sussidieresti": "sussidiare",
    "sussidierete": "sussidiare",
    "sussidierà": "sussidiare",
    "sussidierò": "sussidiare",
    "sussidii": "sussidio",
    "sussidin": "sussidiare",
    "sussidino": "sussidiare",
    "sussidio": "sussidiare",
    "sussidiò": "sussidiare",
    "sussiegosa": "sussiegoso",
    "sussiegose": "sussiegoso",
    "sussiegosi": "sussiegoso",
    "sussista": "sussistere",
    "sussistan": "sussistere",
    "sussistano": "sussistere",
    "sussiste": "sussistere",
    "sussistei": "sussistere",
    "sussistemmo": "sussistere",
    "sussistendo": "sussistere",
    "sussistente": "sussistere",
    "sussistenti": "sussistere",
    "sussistenze": "sussistenza",
    "sussister": "sussistere",
    "sussisterai": "sussistere",
    "sussisteran": "sussistere",
    "sussisteranno": "sussistere",
    "sussisterebbe": "sussistere",
    "sussisterebber": "sussistere",
    "sussisterebbero": "sussistere",
    "sussisterei": "sussistere",
    "sussisteremmo": "sussistere",
    "sussisteremo": "sussistere",
    "sussistereste": "sussistere",
    "sussisteresti": "sussistere",
    "sussisterete": "sussistere",
    "sussisteron": "sussistere",
    "sussisterono": "sussistere",
    "sussisterà": "sussistere",
    "sussisterò": "sussistere",
    "sussistesse": "sussistere",
    "sussistesser": "sussistere",
    "sussistessero": "sussistere",
    "sussistessi": "sussistere",
    "sussistessimo": "sussistere",
    "sussisteste": "sussistere",
    "sussistesti": "sussistere",
    "sussistete": "sussistere",
    "sussisteva": "sussistere",
    "sussistevamo": "sussistere",
    "sussistevan": "sussistere",
    "sussistevano": "sussistere",
    "sussistevate": "sussistere",
    "sussistevi": "sussistere",
    "sussistevo": "sussistere",
    "sussisti": "sussistere",
    "sussistiamo": "sussistere",
    "sussistiate": "sussistere",
    "sussisto": "sussistere",
    "sussiston": "sussistere",
    "sussistono": "sussistere",
    "sussistuta": "sussistere",
    "sussistute": "sussistere",
    "sussistuti": "sussistere",
    "sussistuto": "sussistere",
    "sussistè": "sussistere",
    "sussulta": "sussultare",
    "sussultai": "sussultare",
    "sussultammo": "sussultare",
    "sussultan": "sussultare",
    "sussultando": "sussultare",
    "sussultano": "sussultare",
    "sussultante": "sussultare",
    "sussultanti": "sussultare",
    "sussultar": "sussultare",
    "sussultaron": "sussultare",
    "sussultarono": "sussultare",
    "sussultasse": "sussultare",
    "sussultasser": "sussultare",
    "sussultassero": "sussultare",
    "sussultassi": "sussultare",
    "sussultassimo": "sussultare",
    "sussultaste": "sussultare",
    "sussultasti": "sussultare",
    "sussultata": "sussultare",
    "sussultate": "sussultare",
    "sussultati": "sussultare",
    "sussultato": "sussultare",
    "sussultava": "sussultare",
    "sussultavamo": "sussultare",
    "sussultavan": "sussultare",
    "sussultavano": "sussultare",
    "sussultavate": "sussultare",
    "sussultavi": "sussultare",
    "sussultavo": "sussultare",
    "sussulterai": "sussultare",
    "sussulteran": "sussultare",
    "sussulteranno": "sussultare",
    "sussulterebbe": "sussultare",
    "sussulterebber": "sussultare",
    "sussulterebbero": "sussultare",
    "sussulterei": "sussultare",
    "sussulteremmo": "sussultare",
    "sussulteremo": "sussultare",
    "sussultereste": "sussultare",
    "sussulteresti": "sussultare",
    "sussulterete": "sussultare",
    "sussulterà": "sussultare",
    "sussulterò": "sussultare",
    "sussulti": "sussulto",
    "sussultiamo": "sussultare",
    "sussultiate": "sussultare",
    "sussultin": "sussultare",
    "sussultino": "sussultare",
    "sussulto": "sussultare",
    "sussultori": "sussultorio",
    "sussultoria": "sussultorio",
    "sussultorie": "sussultorio",
    "sussultò": "sussultare",
    "sussurra": "sussurrare",
    "sussurrai": "sussurrare",
    "sussurrammo": "sussurrare",
    "sussurran": "sussurrare",
    "sussurrando": "sussurrare",
    "sussurrano": "sussurrare",
    "sussurrante": "sussurrare",
    "sussurranti": "sussurrare",
    "sussurrar": "sussurrare",
    "sussurraron": "sussurrare",
    "sussurrarono": "sussurrare",
    "sussurrasse": "sussurrare",
    "sussurrasser": "sussurrare",
    "sussurrassero": "sussurrare",
    "sussurrassi": "sussurrare",
    "sussurrassimo": "sussurrare",
    "sussurraste": "sussurrare",
    "sussurrasti": "sussurrare",
    "sussurrata": "sussurrare",
    "sussurrate": "sussurrare",
    "sussurrati": "sussurrare",
    "sussurrato": "sussurrare",
    "sussurrava": "sussurrare",
    "sussurravamo": "sussurrare",
    "sussurravan": "sussurrare",
    "sussurravano": "sussurrare",
    "sussurravate": "sussurrare",
    "sussurravi": "sussurrare",
    "sussurravo": "sussurrare",
    "sussurrerai": "sussurrare",
    "sussurreran": "sussurrare",
    "sussurreranno": "sussurrare",
    "sussurrerebbe": "sussurrare",
    "sussurrerebber": "sussurrare",
    "sussurrerebbero": "sussurrare",
    "sussurrerei": "sussurrare",
    "sussurreremmo": "sussurrare",
    "sussurreremo": "sussurrare",
    "sussurrereste": "sussurrare",
    "sussurreresti": "sussurrare",
    "sussurrerete": "sussurrare",
    "sussurrerà": "sussurrare",
    "sussurrerò": "sussurrare",
    "sussurri": "sussurro",
    "sussurriamo": "sussurrare",
    "sussurriate": "sussurrare",
    "sussurrin": "sussurrare",
    "sussurrino": "sussurrare",
    "sussurro": "sussurrare",
    "sussurrò": "sussurrare",
    "sussè": "suggere",
    "sutta": "suggere",
    "sutte": "suggere",
    "sutti": "suggere",
    "sutto": "suggere",
    "sutura": "suturare",
    "suturai": "suturare",
    "suturammo": "suturare",
    "suturan": "suturare",
    "suturando": "suturare",
    "suturano": "suturare",
    "suturante": "suturare",
    "suturanti": "suturare",
    "suturar": "suturare",
    "suturaron": "suturare",
    "suturarono": "suturare",
    "suturasse": "suturare",
    "suturasser": "suturare",
    "suturassero": "suturare",
    "suturassi": "suturare",
    "suturassimo": "suturare",
    "suturaste": "suturare",
    "suturasti": "suturare",
    "suturata": "suturare",
    "suturate": "suturare",
    "suturati": "suturare",
    "suturato": "suturare",
    "suturava": "suturare",
    "suturavamo": "suturare",
    "suturavan": "suturare",
    "suturavano": "suturare",
    "suturavate": "suturare",
    "suturavi": "suturare",
    "suturavo": "suturare",
    "suture": "sutura",
    "suturerai": "suturare",
    "sutureran": "suturare",
    "sutureranno": "suturare",
    "suturerebbe": "suturare",
    "suturerebber": "suturare",
    "suturerebbero": "suturare",
    "suturerei": "suturare",
    "sutureremmo": "suturare",
    "sutureremo": "suturare",
    "suturereste": "suturare",
    "sutureresti": "suturare",
    "suturerete": "suturare",
    "suturerà": "suturare",
    "suturerò": "suturare",
    "suturi": "suturare",
    "suturiamo": "suturare",
    "suturiate": "suturare",
    "suturin": "suturare",
    "suturino": "suturare",
    "suturo": "suturare",
    "suturò": "suturare",
    "svaga": "svagare",
    "svagai": "svagare",
    "svagammo": "svagare",
    "svagan": "svagare",
    "svagando": "svagare",
    "svagano": "svagare",
    "svagante": "svagare",
    "svaganti": "svagare",
    "svagar": "svagare",
    "svagaron": "svagare",
    "svagarono": "svagare",
    "svagasse": "svagare",
    "svagasser": "svagare",
    "svagassero": "svagare",
    "svagassi": "svagare",
    "svagassimo": "svagare",
    "svagaste": "svagare",
    "svagasti": "svagare",
    "svagata": "svagato",
    "svagate": "svagato",
    "svagatezze": "svagatezza",
    "svagati": "svagato",
    "svagato": "svagare",
    "svagava": "svagare",
    "svagavamo": "svagare",
    "svagavan": "svagare",
    "svagavano": "svagare",
    "svagavate": "svagare",
    "svagavi": "svagare",
    "svagavo": "svagare",
    "svagherai": "svagare",
    "svagheran": "svagare",
    "svagheranno": "svagare",
    "svagherebbe": "svagare",
    "svagherebber": "svagare",
    "svagherebbero": "svagare",
    "svagherei": "svagare",
    "svagheremmo": "svagare",
    "svagheremo": "svagare",
    "svaghereste": "svagare",
    "svagheresti": "svagare",
    "svagherete": "svagare",
    "svagherà": "svagare",
    "svagherò": "svagare",
    "svaghi": "svago",
    "svaghiamo": "svagare",
    "svaghiate": "svagare",
    "svaghin": "svagare",
    "svaghino": "svagare",
    "svago": "svagare",
    "svagò": "svagare",
    "svaligerai": "svaligiare",
    "svaligeran": "svaligiare",
    "svaligeranno": "svaligiare",
    "svaligerebbe": "svaligiare",
    "svaligerebber": "svaligiare",
    "svaligerebbero": "svaligiare",
    "svaligerei": "svaligiare",
    "svaligeremmo": "svaligiare",
    "svaligeremo": "svaligiare",
    "svaligereste": "svaligiare",
    "svaligeresti": "svaligiare",
    "svaligerete": "svaligiare",
    "svaligerà": "svaligiare",
    "svaligerò": "svaligiare",
    "svaligi": "svaligiare",
    "svaligia": "svaligiare",
    "svaligiai": "svaligiare",
    "svaligiammo": "svaligiare",
    "svaligiamo": "svaligiare",
    "svaligian": "svaligiare",
    "svaligiando": "svaligiare",
    "svaligiano": "svaligiare",
    "svaligiante": "svaligiare",
    "svaligianti": "svaligiare",
    "svaligiar": "svaligiare",
    "svaligiaron": "svaligiare",
    "svaligiarono": "svaligiare",
    "svaligiasse": "svaligiare",
    "svaligiasser": "svaligiare",
    "svaligiassero": "svaligiare",
    "svaligiassi": "svaligiare",
    "svaligiassimo": "svaligiare",
    "svaligiaste": "svaligiare",
    "svaligiasti": "svaligiare",
    "svaligiata": "svaligiare",
    "svaligiate": "svaligiare",
    "svaligiati": "svaligiare",
    "svaligiato": "svaligiare",
    "svaligiava": "svaligiare",
    "svaligiavamo": "svaligiare",
    "svaligiavan": "svaligiare",
    "svaligiavano": "svaligiare",
    "svaligiavate": "svaligiare",
    "svaligiavi": "svaligiare",
    "svaligiavo": "svaligiare",
    "svaligin": "svaligiare",
    "svaligino": "svaligiare",
    "svaligio": "svaligiare",
    "svaligiò": "svaligiare",
    "svaluta": "svalutare",
    "svalutai": "svalutare",
    "svalutammo": "svalutare",
    "svalutan": "svalutare",
    "svalutando": "svalutare",
    "svalutano": "svalutare",
    "svalutante": "svalutare",
    "svalutanti": "svalutare",
    "svalutar": "svalutare",
    "svalutaron": "svalutare",
    "svalutarono": "svalutare",
    "svalutasse": "svalutare",
    "svalutasser": "svalutare",
    "svalutassero": "svalutare",
    "svalutassi": "svalutare",
    "svalutassimo": "svalutare",
    "svalutaste": "svalutare",
    "svalutasti": "svalutare",
    "svalutata": "svalutare",
    "svalutate": "svalutare",
    "svalutati": "svalutare",
    "svalutato": "svalutare",
    "svalutava": "svalutare",
    "svalutavamo": "svalutare",
    "svalutavan": "svalutare",
    "svalutavano": "svalutare",
    "svalutavate": "svalutare",
    "svalutavi": "svalutare",
    "svalutavo": "svalutare",
    "svalutazioni": "svalutazione",
    "svaluterai": "svalutare",
    "svaluteran": "svalutare",
    "svaluteranno": "svalutare",
    "svaluterebbe": "svalutare",
    "svaluterebber": "svalutare",
    "svaluterebbero": "svalutare",
    "svaluterei": "svalutare",
    "svaluteremmo": "svalutare",
    "svaluteremo": "svalutare",
    "svalutereste": "svalutare",
    "svaluteresti": "svalutare",
    "svaluterete": "svalutare",
    "svaluterà": "svalutare",
    "svaluterò": "svalutare",
    "svaluti": "svalutare",
    "svalutiamo": "svalutare",
    "svalutiate": "svalutare",
    "svalutin": "svalutare",
    "svalutino": "svalutare",
    "svaluto": "svalutare",
    "svalutò": "svalutare",
    "svampita": "svampito",
    "svampite": "svampito",
    "svampiti": "svampito",
    "svanendo": "svanire",
    "svanente": "svanire",
    "svanenti": "svanire",
    "svaniamo": "svanire",
    "svaniate": "svanire",
    "svanii": "svanire",
    "svanimmo": "svanire",
    "svanir": "svanire",
    "svanirai": "svanire",
    "svaniran": "svanire",
    "svaniranno": "svanire",
    "svanirebbe": "svanire",
    "svanirebber": "svanire",
    "svanirebbero": "svanire",
    "svanirei": "svanire",
    "svaniremmo": "svanire",
    "svaniremo": "svanire",
    "svanireste": "svanire",
    "svaniresti": "svanire",
    "svanirete": "svanire",
    "svaniron": "svanire",
    "svanirono": "svanire",
    "svanirà": "svanire",
    "svanirò": "svanire",
    "svanisca": "svanire",
    "svaniscan": "svanire",
    "svaniscano": "svanire",
    "svanisce": "svanire",
    "svanisci": "svanire",
    "svanisco": "svanire",
    "svaniscon": "svanire",
    "svaniscono": "svanire",
    "svanisse": "svanire",
    "svanisser": "svanire",
    "svanissero": "svanire",
    "svanissi": "svanire",
    "svanissimo": "svanire",
    "svaniste": "svanire",
    "svanisti": "svanire",
    "svanita": "svanito",
    "svanite": "svanito",
    "svaniti": "svanito",
    "svanito": "svanire",
    "svaniva": "svanire",
    "svanivamo": "svanire",
    "svanivan": "svanire",
    "svanivano": "svanire",
    "svanivate": "svanire",
    "svanivi": "svanire",
    "svanivo": "svanire",
    "svantaggerai": "svantaggiare",
    "svantaggeran": "svantaggiare",
    "svantaggeranno": "svantaggiare",
    "svantaggerebbe": "svantaggiare",
    "svantaggerebber": "svantaggiare",
    "svantaggerebbero": "svantaggiare",
    "svantaggerei": "svantaggiare",
    "svantaggeremmo": "svantaggiare",
    "svantaggeremo": "svantaggiare",
    "svantaggereste": "svantaggiare",
    "svantaggeresti": "svantaggiare",
    "svantaggerete": "svantaggiare",
    "svantaggerà": "svantaggiare",
    "svantaggerò": "svantaggiare",
    "svantaggi": "svantaggio",
    "svantaggia": "svantaggiare",
    "svantaggiai": "svantaggiare",
    "svantaggiammo": "svantaggiare",
    "svantaggiamo": "svantaggiare",
    "svantaggian": "svantaggiare",
    "svantaggiando": "svantaggiare",
    "svantaggiano": "svantaggiare",
    "svantaggiante": "svantaggiare",
    "svantaggianti": "svantaggiare",
    "svantaggiar": "svantaggiare",
    "svantaggiaron": "svantaggiare",
    "svantaggiarono": "svantaggiare",
    "svantaggiasse": "svantaggiare",
    "svantaggiasser": "svantaggiare",
    "svantaggiassero": "svantaggiare",
    "svantaggiassi": "svantaggiare",
    "svantaggiassimo": "svantaggiare",
    "svantaggiaste": "svantaggiare",
    "svantaggiasti": "svantaggiare",
    "svantaggiata": "svantaggiato",
    "svantaggiate": "svantaggiato",
    "svantaggiati": "svantaggiato",
    "svantaggiato": "svantaggiare",
    "svantaggiava": "svantaggiare",
    "svantaggiavamo": "svantaggiare",
    "svantaggiavan": "svantaggiare",
    "svantaggiavano": "svantaggiare",
    "svantaggiavate": "svantaggiare",
    "svantaggiavi": "svantaggiare",
    "svantaggiavo": "svantaggiare",
    "svantaggin": "svantaggiare",
    "svantaggino": "svantaggiare",
    "svantaggio": "svantaggiare",
    "svantaggiosa": "svantaggioso",
    "svantaggiose": "svantaggioso",
    "svantaggiosi": "svantaggioso",
    "svantaggiò": "svantaggiare",
    "svanì": "svanire",
    "svapora": "svaporare",
    "svaporai": "svaporare",
    "svaporammo": "svaporare",
    "svaporan": "svaporare",
    "svaporando": "svaporare",
    "svaporano": "svaporare",
    "svaporante": "svaporare",
    "svaporanti": "svaporare",
    "svaporar": "svaporare",
    "svaporaron": "svaporare",
    "svaporarono": "svaporare",
    "svaporasse": "svaporare",
    "svaporasser": "svaporare",
    "svaporassero": "svaporare",
    "svaporassi": "svaporare",
    "svaporassimo": "svaporare",
    "svaporaste": "svaporare",
    "svaporasti": "svaporare",
    "svaporata": "svaporato",
    "svaporate": "svaporato",
    "svaporati": "svaporato",
    "svaporato": "svaporare",
    "svaporava": "svaporare",
    "svaporavamo": "svaporare",
    "svaporavan": "svaporare",
    "svaporavano": "svaporare",
    "svaporavate": "svaporare",
    "svaporavi": "svaporare",
    "svaporavo": "svaporare",
    "svaporerai": "svaporare",
    "svaporeran": "svaporare",
    "svaporeranno": "svaporare",
    "svaporerebbe": "svaporare",
    "svaporerebber": "svaporare",
    "svaporerebbero": "svaporare",
    "svaporerei": "svaporare",
    "svaporeremmo": "svaporare",
    "svaporeremo": "svaporare",
    "svaporereste": "svaporare",
    "svaporeresti": "svaporare",
    "svaporerete": "svaporare",
    "svaporerà": "svaporare",
    "svaporerò": "svaporare",
    "svapori": "svaporare",
    "svaporiamo": "svaporare",
    "svaporiate": "svaporare",
    "svaporin": "svaporare",
    "svaporino": "svaporare",
    "svaporo": "svaporare",
    "svaporò": "svaporare",
    "svari": "svariare",
    "svaria": "svariare",
    "svariai": "svariare",
    "svariammo": "svariare",
    "svariamo": "svariare",
    "svarian": "svariare",
    "svariando": "svariare",
    "svariano": "svariare",
    "svariante": "svariare",
    "svarianti": "svariare",
    "svariar": "svariare",
    "svariaron": "svariare",
    "svariarono": "svariare",
    "svariasse": "svariare",
    "svariasser": "svariare",
    "svariassero": "svariare",
    "svariassi": "svariare",
    "svariassimo": "svariare",
    "svariaste": "svariare",
    "svariasti": "svariare",
    "svariata": "svariato",
    "svariate": "svariato",
    "svariati": "svariato",
    "svariato": "svariare",
    "svariava": "svariare",
    "svariavamo": "svariare",
    "svariavan": "svariare",
    "svariavano": "svariare",
    "svariavate": "svariare",
    "svariavi": "svariare",
    "svariavo": "svariare",
    "svarierai": "svariare",
    "svarieran": "svariare",
    "svarieranno": "svariare",
    "svarierebbe": "svariare",
    "svarierebber": "svariare",
    "svarierebbero": "svariare",
    "svarierei": "svariare",
    "svarieremmo": "svariare",
    "svarieremo": "svariare",
    "svariereste": "svariare",
    "svarieresti": "svariare",
    "svarierete": "svariare",
    "svarierà": "svariare",
    "svarierò": "svariare",
    "svarin": "svariare",
    "svarino": "svariare",
    "svario": "svariare",
    "svarioni": "svarione",
    "svariò": "svariare",
    "svasa": "svasare",
    "svasai": "svasare",
    "svasammo": "svasare",
    "svasan": "svasare",
    "svasando": "svasare",
    "svasano": "svasare",
    "svasante": "svasare",
    "svasanti": "svasare",
    "svasar": "svasare",
    "svasaron": "svasare",
    "svasarono": "svasare",
    "svasasse": "svasare",
    "svasasser": "svasare",
    "svasassero": "svasare",
    "svasassi": "svasare",
    "svasassimo": "svasare",
    "svasaste": "svasare",
    "svasasti": "svasare",
    "svasata": "svasare",
    "svasate": "svasare",
    "svasati": "svasare",
    "svasato": "svasare",
    "svasava": "svasare",
    "svasavamo": "svasare",
    "svasavan": "svasare",
    "svasavano": "svasare",
    "svasavate": "svasare",
    "svasavi": "svasare",
    "svasavo": "svasare",
    "svaserai": "svasare",
    "svaseran": "svasare",
    "svaseranno": "svasare",
    "svaserebbe": "svasare",
    "svaserebber": "svasare",
    "svaserebbero": "svasare",
    "svaserei": "svasare",
    "svaseremmo": "svasare",
    "svaseremo": "svasare",
    "svasereste": "svasare",
    "svaseresti": "svasare",
    "svaserete": "svasare",
    "svaserà": "svasare",
    "svaserò": "svasare",
    "svasi": "svasare",
    "svasiamo": "svasare",
    "svasiate": "svasare",
    "svasin": "svasare",
    "svasino": "svasare",
    "svaso": "svasare",
    "svastiche": "svastica",
    "svasò": "svasare",
    "svecchi": "svecchiare",
    "svecchia": "svecchiare",
    "svecchiai": "svecchiare",
    "svecchiamenti": "svecchiamento",
    "svecchiammo": "svecchiare",
    "svecchiamo": "svecchiare",
    "svecchian": "svecchiare",
    "svecchiando": "svecchiare",
    "svecchiano": "svecchiare",
    "svecchiante": "svecchiare",
    "svecchianti": "svecchiare",
    "svecchiar": "svecchiare",
    "svecchiaron": "svecchiare",
    "svecchiarono": "svecchiare",
    "svecchiasse": "svecchiare",
    "svecchiasser": "svecchiare",
    "svecchiassero": "svecchiare",
    "svecchiassi": "svecchiare",
    "svecchiassimo": "svecchiare",
    "svecchiaste": "svecchiare",
    "svecchiasti": "svecchiare",
    "svecchiata": "svecchiare",
    "svecchiate": "svecchiare",
    "svecchiati": "svecchiare",
    "svecchiato": "svecchiare",
    "svecchiava": "svecchiare",
    "svecchiavamo": "svecchiare",
    "svecchiavan": "svecchiare",
    "svecchiavano": "svecchiare",
    "svecchiavate": "svecchiare",
    "svecchiavi": "svecchiare",
    "svecchiavo": "svecchiare",
    "svecchierai": "svecchiare",
    "svecchieran": "svecchiare",
    "svecchieranno": "svecchiare",
    "svecchierebbe": "svecchiare",
    "svecchierebber": "svecchiare",
    "svecchierebbero": "svecchiare",
    "svecchierei": "svecchiare",
    "svecchieremmo": "svecchiare",
    "svecchieremo": "svecchiare",
    "svecchiereste": "svecchiare",
    "svecchieresti": "svecchiare",
    "svecchierete": "svecchiare",
    "svecchierà": "svecchiare",
    "svecchierò": "svecchiare",
    "svecchin": "svecchiare",
    "svecchino": "svecchiare",
    "svecchio": "svecchiare",
    "svecchiò": "svecchiare",
    "svedesi": "svedese",
    "svegli": "sveglio",
    "sveglia": "sveglio",
    "svegliai": "svegliare",
    "svegliammo": "svegliare",
    "svegliamo": "svegliare",
    "sveglian": "svegliare",
    "svegliando": "svegliare",
    "svegliano": "svegliare",
    "svegliante": "svegliare",
    "sveglianti": "svegliare",
    "svegliar": "svegliare",
    "svegliaron": "svegliare",
    "svegliarono": "svegliare",
    "svegliasse": "svegliare",
    "svegliasser": "svegliare",
    "svegliassero": "svegliare",
    "svegliassi": "svegliare",
    "svegliassimo": "svegliare",
    "svegliaste": "svegliare",
    "svegliasti": "svegliare",
    "svegliata": "svegliare",
    "svegliate": "svegliare",
    "svegliati": "svegliare",
    "svegliato": "svegliare",
    "svegliava": "svegliare",
    "svegliavamo": "svegliare",
    "svegliavan": "svegliare",
    "svegliavano": "svegliare",
    "svegliavate": "svegliare",
    "svegliavi": "svegliare",
    "svegliavo": "svegliare",
    "sveglie": "sveglio",
    "sveglierai": "svegliare",
    "sveglieran": "svegliare",
    "sveglieranno": "svegliare",
    "sveglierebbe": "svegliare",
    "sveglierebber": "svegliare",
    "sveglierebbero": "svegliare",
    "sveglierei": "svegliare",
    "sveglieremmo": "svegliare",
    "sveglieremo": "svegliare",
    "svegliereste": "svegliare",
    "sveglieresti": "svegliare",
    "sveglierete": "svegliare",
    "sveglierà": "svegliare",
    "sveglierò": "svegliare",
    "sveglin": "svegliare",
    "sveglino": "svegliare",
    "sveglio": "svegliare",
    "svegliò": "svegliare",
    "svela": "svelare",
    "svelai": "svelare",
    "svelamenti": "svelamento",
    "svelammo": "svelare",
    "svelan": "svelare",
    "svelando": "svelare",
    "svelano": "svelare",
    "svelante": "svelare",
    "svelanti": "svelare",
    "svelar": "svelare",
    "svelaron": "svelare",
    "svelarono": "svelare",
    "svelasse": "svelare",
    "svelasser": "svelare",
    "svelassero": "svelare",
    "svelassi": "svelare",
    "svelassimo": "svelare",
    "svelaste": "svelare",
    "svelasti": "svelare",
    "svelata": "svelare",
    "svelate": "svelare",
    "svelati": "svelare",
    "svelato": "svelare",
    "svelava": "svelare",
    "svelavamo": "svelare",
    "svelavan": "svelare",
    "svelavano": "svelare",
    "svelavate": "svelare",
    "svelavi": "svelare",
    "svelavo": "svelare",
    "svelenendo": "svelenire",
    "svelenente": "svelenire",
    "svelenenti": "svelenire",
    "sveleniamo": "svelenire",
    "sveleniate": "svelenire",
    "svelenii": "svelenire",
    "svelenimmo": "svelenire",
    "svelenir": "svelenire",
    "svelenirai": "svelenire",
    "sveleniran": "svelenire",
    "sveleniranno": "svelenire",
    "svelenirebbe": "svelenire",
    "svelenirebber": "svelenire",
    "svelenirebbero": "svelenire",
    "svelenirei": "svelenire",
    "sveleniremmo": "svelenire",
    "sveleniremo": "svelenire",
    "svelenireste": "svelenire",
    "sveleniresti": "svelenire",
    "svelenirete": "svelenire",
    "sveleniron": "svelenire",
    "svelenirono": "svelenire",
    "svelenirà": "svelenire",
    "svelenirò": "svelenire",
    "svelenisca": "svelenire",
    "sveleniscan": "svelenire",
    "sveleniscano": "svelenire",
    "svelenisce": "svelenire",
    "svelenisci": "svelenire",
    "svelenisco": "svelenire",
    "sveleniscon": "svelenire",
    "sveleniscono": "svelenire",
    "svelenisse": "svelenire",
    "svelenisser": "svelenire",
    "svelenissero": "svelenire",
    "svelenissi": "svelenire",
    "svelenissimo": "svelenire",
    "sveleniste": "svelenire",
    "svelenisti": "svelenire",
    "svelenita": "svelenire",
    "svelenite": "svelenire",
    "sveleniti": "svelenire",
    "svelenito": "svelenire",
    "sveleniva": "svelenire",
    "svelenivamo": "svelenire",
    "svelenivan": "svelenire",
    "svelenivano": "svelenire",
    "svelenivate": "svelenire",
    "svelenivi": "svelenire",
    "svelenivo": "svelenire",
    "svelenì": "svelenire",
    "svelerai": "svelare",
    "sveleran": "svelare",
    "sveleranno": "svelare",
    "svelerebbe": "svelare",
    "svelerebber": "svelare",
    "svelerebbero": "svelare",
    "svelerei": "svelare",
    "sveleremmo": "svelare",
    "sveleremo": "svelare",
    "svelereste": "svelare",
    "sveleresti": "svelare",
    "svelerete": "svelare",
    "svelerà": "svelare",
    "svelerò": "svelare",
    "sveli": "svelare",
    "sveliamo": "svelare",
    "sveliate": "svelare",
    "svelin": "svelare",
    "svelino": "svelare",
    "svella": "svellere",
    "svellan": "svellere",
    "svellano": "svellere",
    "svelle": "svellere",
    "svellemmo": "svellere",
    "svellendo": "svellere",
    "svellente": "svellere",
    "svellenti": "svellere",
    "sveller": "svellere",
    "svellerai": "svellere",
    "svelleran": "svellere",
    "svelleranno": "svellere",
    "svellerebbe": "svellere",
    "svellerebber": "svellere",
    "svellerebbero": "svellere",
    "svellerei": "svellere",
    "svelleremmo": "svellere",
    "svelleremo": "svellere",
    "svellereste": "svellere",
    "svelleresti": "svellere",
    "svellerete": "svellere",
    "svellerà": "svellere",
    "svellerò": "svellere",
    "svellesse": "svellere",
    "svellesser": "svellere",
    "svellessero": "svellere",
    "svellessi": "svellere",
    "svellessimo": "svellere",
    "svelleste": "svellere",
    "svellesti": "svellere",
    "svellete": "svellere",
    "svelleva": "svellere",
    "svellevamo": "svellere",
    "svellevan": "svellere",
    "svellevano": "svellere",
    "svellevate": "svellere",
    "svellevi": "svellere",
    "svellevo": "svellere",
    "svelli": "svellere",
    "svelliamo": "svellere",
    "svelliate": "svellere",
    "svello": "svellere",
    "svellon": "svellere",
    "svellono": "svellere",
    "svelo": "svelare",
    "svelse": "svellere",
    "svelser": "svellere",
    "svelsero": "svellere",
    "svelsi": "svellere",
    "svelta": "svelto",
    "sveltan": "sveltire",
    "sveltano": "sveltire",
    "svelte": "svelto",
    "sveltendo": "sveltire",
    "sveltente": "sveltire",
    "sveltenti": "sveltire",
    "svelti": "svelto",
    "sveltiamo": "sveltire",
    "sveltiate": "sveltire",
    "sveltii": "sveltire",
    "sveltimmo": "sveltire",
    "sveltir": "sveltire",
    "sveltirai": "sveltire",
    "sveltiran": "sveltire",
    "sveltiranno": "sveltire",
    "sveltirebbe": "sveltire",
    "sveltirebber": "sveltire",
    "sveltirebbero": "sveltire",
    "sveltirei": "sveltire",
    "sveltiremmo": "sveltire",
    "sveltiremo": "sveltire",
    "sveltireste": "sveltire",
    "sveltiresti": "sveltire",
    "sveltirete": "sveltire",
    "sveltiron": "sveltire",
    "sveltirono": "sveltire",
    "sveltirà": "sveltire",
    "sveltirò": "sveltire",
    "sveltisse": "sveltire",
    "sveltisser": "sveltire",
    "sveltissero": "sveltire",
    "sveltissi": "sveltire",
    "sveltissimo": "sveltire",
    "sveltiste": "sveltire",
    "sveltisti": "sveltire",
    "sveltita": "sveltire",
    "sveltite": "sveltire",
    "sveltiti": "sveltire",
    "sveltito": "sveltire",
    "sveltiva": "sveltire",
    "sveltivamo": "sveltire",
    "sveltivan": "sveltire",
    "sveltivano": "sveltire",
    "sveltivate": "sveltire",
    "sveltivi": "sveltire",
    "sveltivo": "sveltire",
    "svelto": "sveltire",
    "svelton": "sveltire",
    "sveltono": "sveltire",
    "sveltì": "sveltire",
    "svelò": "svelare",
    "svena": "svenare",
    "svenai": "svenare",
    "svenammo": "svenare",
    "svenan": "svenare",
    "svenando": "svenare",
    "svenano": "svenare",
    "svenante": "svenare",
    "svenanti": "svenare",
    "svenar": "svenare",
    "svenaron": "svenare",
    "svenarono": "svenare",
    "svenasse": "svenare",
    "svenasser": "svenare",
    "svenassero": "svenare",
    "svenassi": "svenare",
    "svenassimo": "svenare",
    "svenaste": "svenare",
    "svenasti": "svenare",
    "svenata": "svenare",
    "svenate": "svenare",
    "svenati": "svenare",
    "svenato": "svenare",
    "svenava": "svenare",
    "svenavamo": "svenare",
    "svenavan": "svenare",
    "svenavano": "svenare",
    "svenavate": "svenare",
    "svenavi": "svenare",
    "svenavo": "svenare",
    "svenda": "svendere",
    "svendan": "svendere",
    "svendano": "svendere",
    "svende": "svendere",
    "svendemmo": "svendere",
    "svendendo": "svendere",
    "svendente": "svendere",
    "svendenti": "svendere",
    "svender": "svendere",
    "svenderai": "svendere",
    "svenderan": "svendere",
    "svenderanno": "svendere",
    "svenderebbe": "svendere",
    "svenderebber": "svendere",
    "svenderebbero": "svendere",
    "svenderei": "svendere",
    "svenderemmo": "svendere",
    "svenderemo": "svendere",
    "svendereste": "svendere",
    "svenderesti": "svendere",
    "svenderete": "svendere",
    "svenderà": "svendere",
    "svenderò": "svendere",
    "svendesse": "svendere",
    "svendesser": "svendere",
    "svendessero": "svendere",
    "svendessi": "svendere",
    "svendessimo": "svendere",
    "svendeste": "svendere",
    "svendesti": "svendere",
    "svendete": "svendere",
    "svendette": "svendere",
    "svendetter": "svendere",
    "svendettero": "svendere",
    "svendetti": "svendere",
    "svendeva": "svendere",
    "svendevamo": "svendere",
    "svendevan": "svendere",
    "svendevano": "svendere",
    "svendevate": "svendere",
    "svendevi": "svendere",
    "svendevo": "svendere",
    "svendi": "svendere",
    "svendiamo": "svendere",
    "svendiate": "svendere",
    "svendite": "svendita",
    "svendo": "svendere",
    "svendon": "svendere",
    "svendono": "svendere",
    "svenduta": "svendere",
    "svendute": "svendere",
    "svenduti": "svendere",
    "svenduto": "svendere",
    "svenendo": "svenire",
    "svenente": "svenire",
    "svenenti": "svenire",
    "svenerai": "svenare",
    "sveneran": "svenare",
    "sveneranno": "svenare",
    "svenerebbe": "svenare",
    "svenerebber": "svenare",
    "svenerebbero": "svenare",
    "svenerei": "svenare",
    "sveneremmo": "svenare",
    "sveneremo": "svenare",
    "svenereste": "svenare",
    "sveneresti": "svenare",
    "svenerete": "svenare",
    "svenerà": "svenare",
    "svenerò": "svenare",
    "svenevolezze": "svenevolezza",
    "svenevoli": "svenevole",
    "svenga": "svenire",
    "svengan": "svenire",
    "svengano": "svenire",
    "svengo": "svenire",
    "svengon": "svenire",
    "svengono": "svenire",
    "sveni": "svenare",
    "sveniamo": "svenire",
    "sveniate": "svenire",
    "svenimenti": "svenimento",
    "svenimmo": "svenire",
    "svenin": "svenare",
    "svenino": "svenare",
    "svenir": "svenire",
    "svenisse": "svenire",
    "svenisser": "svenire",
    "svenissero": "svenire",
    "svenissi": "svenire",
    "svenissimo": "svenire",
    "sveniste": "svenire",
    "svenisti": "svenire",
    "svenite": "svenire",
    "sveniva": "svenire",
    "svenivamo": "svenire",
    "svenivan": "svenire",
    "svenivano": "svenire",
    "svenivate": "svenire",
    "svenivi": "svenire",
    "svenivo": "svenire",
    "svenne": "svenire",
    "svenner": "svenire",
    "svennero": "svenire",
    "svenni": "svenire",
    "sveno": "svenare",
    "sventa": "sventare",
    "sventagli": "sventagliare",
    "sventaglia": "sventagliare",
    "sventagliai": "sventagliare",
    "sventagliammo": "sventagliare",
    "sventagliamo": "sventagliare",
    "sventaglian": "sventagliare",
    "sventagliando": "sventagliare",
    "sventagliano": "sventagliare",
    "sventagliante": "sventagliare",
    "sventaglianti": "sventagliare",
    "sventagliar": "sventagliare",
    "sventagliaron": "sventagliare",
    "sventagliarono": "sventagliare",
    "sventagliasse": "sventagliare",
    "sventagliasser": "sventagliare",
    "sventagliassero": "sventagliare",
    "sventagliassi": "sventagliare",
    "sventagliassimo": "sventagliare",
    "sventagliaste": "sventagliare",
    "sventagliasti": "sventagliare",
    "sventagliata": "sventagliare",
    "sventagliate": "sventagliata",
    "sventagliati": "sventagliare",
    "sventagliato": "sventagliare",
    "sventagliava": "sventagliare",
    "sventagliavamo": "sventagliare",
    "sventagliavan": "sventagliare",
    "sventagliavano": "sventagliare",
    "sventagliavate": "sventagliare",
    "sventagliavi": "sventagliare",
    "sventagliavo": "sventagliare",
    "sventaglierai": "sventagliare",
    "sventaglieran": "sventagliare",
    "sventaglieranno": "sventagliare",
    "sventaglierebbe": "sventagliare",
    "sventaglierebber": "sventagliare",
    "sventaglierebbero": "sventagliare",
    "sventaglierei": "sventagliare",
    "sventaglieremmo": "sventagliare",
    "sventaglieremo": "sventagliare",
    "sventagliereste": "sventagliare",
    "sventaglieresti": "sventagliare",
    "sventaglierete": "sventagliare",
    "sventaglierà": "sventagliare",
    "sventaglierò": "sventagliare",
    "sventaglin": "sventagliare",
    "sventaglino": "sventagliare",
    "sventaglio": "sventagliare",
    "sventagliò": "sventagliare",
    "sventai": "sventare",
    "sventammo": "sventare",
    "sventan": "sventare",
    "sventando": "sventare",
    "sventano": "sventare",
    "sventante": "sventare",
    "sventanti": "sventare",
    "sventar": "sventare",
    "sventaron": "sventare",
    "sventarono": "sventare",
    "sventasse": "sventare",
    "sventasser": "sventare",
    "sventassero": "sventare",
    "sventassi": "sventare",
    "sventassimo": "sventare",
    "sventaste": "sventare",
    "sventasti": "sventare",
    "sventata": "sventato",
    "sventate": "sventato",
    "sventatezze": "sventatezza",
    "sventati": "sventato",
    "sventato": "sventare",
    "sventava": "sventare",
    "sventavamo": "sventare",
    "sventavan": "sventare",
    "sventavano": "sventare",
    "sventavate": "sventare",
    "sventavi": "sventare",
    "sventavo": "sventare",
    "sventerai": "sventare",
    "sventeran": "sventare",
    "sventeranno": "sventare",
    "sventerebbe": "sventare",
    "sventerebber": "sventare",
    "sventerebbero": "sventare",
    "sventerei": "sventare",
    "sventeremmo": "sventare",
    "sventeremo": "sventare",
    "sventereste": "sventare",
    "sventeresti": "sventare",
    "sventerete": "sventare",
    "sventerà": "sventare",
    "sventerò": "sventare",
    "sventi": "sventare",
    "sventiamo": "sventare",
    "sventiate": "sventare",
    "sventin": "sventare",
    "sventino": "sventare",
    "svento": "sventare",
    "sventola": "sventolare",
    "sventolai": "sventolare",
    "sventolammo": "sventolare",
    "sventolan": "sventolare",
    "sventolando": "sventolare",
    "sventolano": "sventolare",
    "sventolante": "sventolare",
    "sventolanti": "sventolare",
    "sventolar": "sventolare",
    "sventolaron": "sventolare",
    "sventolarono": "sventolare",
    "sventolasse": "sventolare",
    "sventolasser": "sventolare",
    "sventolassero": "sventolare",
    "sventolassi": "sventolare",
    "sventolassimo": "sventolare",
    "sventolaste": "sventolare",
    "sventolasti": "sventolare",
    "sventolata": "sventolare",
    "sventolate": "sventolare",
    "sventolati": "sventolare",
    "sventolato": "sventolare",
    "sventolava": "sventolare",
    "sventolavamo": "sventolare",
    "sventolavan": "sventolare",
    "sventolavano": "sventolare",
    "sventolavate": "sventolare",
    "sventolavi": "sventolare",
    "sventolavo": "sventolare",
    "sventole": "sventola",
    "sventolerai": "sventolare",
    "sventoleran": "sventolare",
    "sventoleranno": "sventolare",
    "sventolerebbe": "sventolare",
    "sventolerebber": "sventolare",
    "sventolerebbero": "sventolare",
    "sventolerei": "sventolare",
    "sventoleremmo": "sventolare",
    "sventoleremo": "sventolare",
    "sventolereste": "sventolare",
    "sventoleresti": "sventolare",
    "sventolerete": "sventolare",
    "sventolerà": "sventolare",
    "sventolerò": "sventolare",
    "sventoli": "sventolare",
    "sventoliamo": "sventolare",
    "sventoliate": "sventolare",
    "sventolii": "sventolio",
    "sventolin": "sventolare",
    "sventolino": "sventolare",
    "sventolo": "sventolare",
    "sventolò": "sventolare",
    "sventra": "sventrare",
    "sventrai": "sventrare",
    "sventramenti": "sventramento",
    "sventrammo": "sventrare",
    "sventran": "sventrare",
    "sventrando": "sventrare",
    "sventrano": "sventrare",
    "sventrante": "sventrare",
    "sventranti": "sventrare",
    "sventrar": "sventrare",
    "sventraron": "sventrare",
    "sventrarono": "sventrare",
    "sventrasse": "sventrare",
    "sventrasser": "sventrare",
    "sventrassero": "sventrare",
    "sventrassi": "sventrare",
    "sventrassimo": "sventrare",
    "sventraste": "sventrare",
    "sventrasti": "sventrare",
    "sventrata": "sventrare",
    "sventrate": "sventrare",
    "sventrati": "sventrare",
    "sventrato": "sventrare",
    "sventrava": "sventrare",
    "sventravamo": "sventrare",
    "sventravan": "sventrare",
    "sventravano": "sventrare",
    "sventravate": "sventrare",
    "sventravi": "sventrare",
    "sventravo": "sventrare",
    "sventrerai": "sventrare",
    "sventreran": "sventrare",
    "sventreranno": "sventrare",
    "sventrerebbe": "sventrare",
    "sventrerebber": "sventrare",
    "sventrerebbero": "sventrare",
    "sventrerei": "sventrare",
    "sventreremmo": "sventrare",
    "sventreremo": "sventrare",
    "sventrereste": "sventrare",
    "sventreresti": "sventrare",
    "sventrerete": "sventrare",
    "sventrerà": "sventrare",
    "sventrerò": "sventrare",
    "sventri": "sventrare",
    "sventriamo": "sventrare",
    "sventriate": "sventrare",
    "sventrin": "sventrare",
    "sventrino": "sventrare",
    "sventro": "sventrare",
    "sventrò": "sventrare",
    "sventurata": "sventurato",
    "sventurate": "sventurato",
    "sventurati": "sventurato",
    "sventure": "sventura",
    "sventò": "sventare",
    "svenuta": "svenire",
    "svenute": "svenire",
    "svenuti": "svenire",
    "svenuto": "svenire",
    "svenò": "svenare",
    "svergina": "sverginare",
    "sverginai": "sverginare",
    "sverginammo": "sverginare",
    "sverginan": "sverginare",
    "sverginando": "sverginare",
    "sverginano": "sverginare",
    "sverginante": "sverginare",
    "sverginanti": "sverginare",
    "sverginar": "sverginare",
    "sverginaron": "sverginare",
    "sverginarono": "sverginare",
    "sverginasse": "sverginare",
    "sverginasser": "sverginare",
    "sverginassero": "sverginare",
    "sverginassi": "sverginare",
    "sverginassimo": "sverginare",
    "sverginaste": "sverginare",
    "sverginasti": "sverginare",
    "sverginata": "sverginare",
    "sverginate": "sverginare",
    "sverginati": "sverginare",
    "sverginato": "sverginare",
    "sverginava": "sverginare",
    "sverginavamo": "sverginare",
    "sverginavan": "sverginare",
    "sverginavano": "sverginare",
    "sverginavate": "sverginare",
    "sverginavi": "sverginare",
    "sverginavo": "sverginare",
    "sverginerai": "sverginare",
    "svergineran": "sverginare",
    "svergineranno": "sverginare",
    "sverginerebbe": "sverginare",
    "sverginerebber": "sverginare",
    "sverginerebbero": "sverginare",
    "sverginerei": "sverginare",
    "svergineremmo": "sverginare",
    "svergineremo": "sverginare",
    "sverginereste": "sverginare",
    "svergineresti": "sverginare",
    "sverginerete": "sverginare",
    "sverginerà": "sverginare",
    "sverginerò": "sverginare",
    "svergini": "sverginare",
    "sverginiamo": "sverginare",
    "sverginiate": "sverginare",
    "sverginin": "sverginare",
    "sverginino": "sverginare",
    "svergino": "sverginare",
    "sverginò": "sverginare",
    "svergogna": "svergognare",
    "svergognai": "svergognare",
    "svergognammo": "svergognare",
    "svergognan": "svergognare",
    "svergognando": "svergognare",
    "svergognano": "svergognare",
    "svergognante": "svergognare",
    "svergognanti": "svergognare",
    "svergognar": "svergognare",
    "svergognaron": "svergognare",
    "svergognarono": "svergognare",
    "svergognasse": "svergognare",
    "svergognasser": "svergognare",
    "svergognassero": "svergognare",
    "svergognassi": "svergognare",
    "svergognassimo": "svergognare",
    "svergognaste": "svergognare",
    "svergognasti": "svergognare",
    "svergognata": "svergognare",
    "svergognate": "svergognare",
    "svergognati": "svergognare",
    "svergognato": "svergognare",
    "svergognava": "svergognare",
    "svergognavamo": "svergognare",
    "svergognavan": "svergognare",
    "svergognavano": "svergognare",
    "svergognavate": "svergognare",
    "svergognavi": "svergognare",
    "svergognavo": "svergognare",
    "svergognerai": "svergognare",
    "svergogneran": "svergognare",
    "svergogneranno": "svergognare",
    "svergognerebbe": "svergognare",
    "svergognerebber": "svergognare",
    "svergognerebbero": "svergognare",
    "svergognerei": "svergognare",
    "svergogneremmo": "svergognare",
    "svergogneremo": "svergognare",
    "svergognereste": "svergognare",
    "svergogneresti": "svergognare",
    "svergognerete": "svergognare",
    "svergognerà": "svergognare",
    "svergognerò": "svergognare",
    "svergogni": "svergognare",
    "svergogniamo": "svergognare",
    "svergogniate": "svergognare",
    "svergognin": "svergognare",
    "svergognino": "svergognare",
    "svergogno": "svergognare",
    "svergognò": "svergognare",
    "sverna": "svernare",
    "svernai": "svernare",
    "svernammo": "svernare",
    "svernan": "svernare",
    "svernando": "svernare",
    "svernano": "svernare",
    "svernante": "svernare",
    "svernanti": "svernare",
    "svernar": "svernare",
    "svernaron": "svernare",
    "svernarono": "svernare",
    "svernasse": "svernare",
    "svernasser": "svernare",
    "svernassero": "svernare",
    "svernassi": "svernare",
    "svernassimo": "svernare",
    "svernaste": "svernare",
    "svernasti": "svernare",
    "svernata": "svernare",
    "svernate": "svernare",
    "svernati": "svernare",
    "svernato": "svernare",
    "svernava": "svernare",
    "svernavamo": "svernare",
    "svernavan": "svernare",
    "svernavano": "svernare",
    "svernavate": "svernare",
    "svernavi": "svernare",
    "svernavo": "svernare",
    "svernerai": "svernare",
    "sverneran": "svernare",
    "sverneranno": "svernare",
    "svernerebbe": "svernare",
    "svernerebber": "svernare",
    "svernerebbero": "svernare",
    "svernerei": "svernare",
    "sverneremmo": "svernare",
    "sverneremo": "svernare",
    "svernereste": "svernare",
    "sverneresti": "svernare",
    "svernerete": "svernare",
    "svernerà": "svernare",
    "svernerò": "svernare",
    "sverni": "svernare",
    "sverniamo": "svernare",
    "sverniate": "svernare",
    "svernin": "svernare",
    "svernino": "svernare",
    "sverno": "svernare",
    "svernò": "svernare",
    "sverrai": "svenire",
    "sverran": "svenire",
    "sverranno": "svenire",
    "sverrebbe": "svenire",
    "sverrebber": "svenire",
    "sverrebbero": "svenire",
    "sverrei": "svenire",
    "sverremmo": "svenire",
    "sverremo": "svenire",
    "sverreste": "svenire",
    "sverresti": "svenire",
    "sverrete": "svenire",
    "sverrà": "svenire",
    "sverrò": "svenire",
    "svesta": "svestire",
    "svestan": "svestire",
    "svestano": "svestire",
    "sveste": "svestire",
    "svestendo": "svestire",
    "svestente": "svestire",
    "svestenti": "svestire",
    "svesti": "svestire",
    "svestiamo": "svestire",
    "svestiate": "svestire",
    "svestii": "svestire",
    "svestimmo": "svestire",
    "svestir": "svestire",
    "svestirai": "svestire",
    "svestiran": "svestire",
    "svestiranno": "svestire",
    "svestirebbe": "svestire",
    "svestirebber": "svestire",
    "svestirebbero": "svestire",
    "svestirei": "svestire",
    "svestiremmo": "svestire",
    "svestiremo": "svestire",
    "svestireste": "svestire",
    "svestiresti": "svestire",
    "svestirete": "svestire",
    "svestiron": "svestire",
    "svestirono": "svestire",
    "svestirà": "svestire",
    "svestirò": "svestire",
    "svestisse": "svestire",
    "svestisser": "svestire",
    "svestissero": "svestire",
    "svestissi": "svestire",
    "svestissimo": "svestire",
    "svestiste": "svestire",
    "svestisti": "svestire",
    "svestita": "svestire",
    "svestite": "svestire",
    "svestiti": "svestire",
    "svestito": "svestire",
    "svestiva": "svestire",
    "svestivamo": "svestire",
    "svestivan": "svestire",
    "svestivano": "svestire",
    "svestivate": "svestire",
    "svestivi": "svestire",
    "svestivo": "svestire",
    "svesto": "svestire",
    "sveston": "svestire",
    "svestono": "svestire",
    "svestì": "svestire",
    "svetta": "svettare",
    "svettai": "svettare",
    "svettammo": "svettare",
    "svettan": "svettare",
    "svettando": "svettare",
    "svettano": "svettare",
    "svettante": "svettare",
    "svettanti": "svettare",
    "svettar": "svettare",
    "svettaron": "svettare",
    "svettarono": "svettare",
    "svettasse": "svettare",
    "svettasser": "svettare",
    "svettassero": "svettare",
    "svettassi": "svettare",
    "svettassimo": "svettare",
    "svettaste": "svettare",
    "svettasti": "svettare",
    "svettata": "svettare",
    "svettate": "svettare",
    "svettati": "svettare",
    "svettato": "svettare",
    "svettava": "svettare",
    "svettavamo": "svettare",
    "svettavan": "svettare",
    "svettavano": "svettare",
    "svettavate": "svettare",
    "svettavi": "svettare",
    "svettavo": "svettare",
    "svetterai": "svettare",
    "svetteran": "svettare",
    "svetteranno": "svettare",
    "svetterebbe": "svettare",
    "svetterebber": "svettare",
    "svetterebbero": "svettare",
    "svetterei": "svettare",
    "svetteremmo": "svettare",
    "svetteremo": "svettare",
    "svettereste": "svettare",
    "svetteresti": "svettare",
    "svetterete": "svettare",
    "svetterà": "svettare",
    "svetterò": "svettare",
    "svetti": "svettare",
    "svettiamo": "svettare",
    "svettiate": "svettare",
    "svettin": "svettare",
    "svettino": "svettare",
    "svetto": "svettare",
    "svettò": "svettare",
    "sveviana": "sveviano",
    "sveviane": "sveviano",
    "sveviani": "sveviano",
    "svezza": "svezzare",
    "svezzai": "svezzare",
    "svezzammo": "svezzare",
    "svezzan": "svezzare",
    "svezzando": "svezzare",
    "svezzano": "svezzare",
    "svezzante": "svezzare",
    "svezzanti": "svezzare",
    "svezzar": "svezzare",
    "svezzaron": "svezzare",
    "svezzarono": "svezzare",
    "svezzasse": "svezzare",
    "svezzasser": "svezzare",
    "svezzassero": "svezzare",
    "svezzassi": "svezzare",
    "svezzassimo": "svezzare",
    "svezzaste": "svezzare",
    "svezzasti": "svezzare",
    "svezzata": "svezzare",
    "svezzate": "svezzare",
    "svezzati": "svezzare",
    "svezzato": "svezzare",
    "svezzava": "svezzare",
    "svezzavamo": "svezzare",
    "svezzavan": "svezzare",
    "svezzavano": "svezzare",
    "svezzavate": "svezzare",
    "svezzavi": "svezzare",
    "svezzavo": "svezzare",
    "svezzerai": "svezzare",
    "svezzeran": "svezzare",
    "svezzeranno": "svezzare",
    "svezzerebbe": "svezzare",
    "svezzerebber": "svezzare",
    "svezzerebbero": "svezzare",
    "svezzerei": "svezzare",
    "svezzeremmo": "svezzare",
    "svezzeremo": "svezzare",
    "svezzereste": "svezzare",
    "svezzeresti": "svezzare",
    "svezzerete": "svezzare",
    "svezzerà": "svezzare",
    "svezzerò": "svezzare",
    "svezzi": "svezzare",
    "svezziamo": "svezzare",
    "svezziate": "svezzare",
    "svezzin": "svezzare",
    "svezzino": "svezzare",
    "svezzo": "svezzare",
    "svezzò": "svezzare",
    "svi": "sviare",
    "svia": "sviare",
    "sviai": "sviare",
    "sviammo": "sviare",
    "sviamo": "sviare",
    "svian": "sviare",
    "sviando": "sviare",
    "sviano": "sviare",
    "sviante": "sviare",
    "svianti": "sviare",
    "sviar": "sviare",
    "sviaron": "sviare",
    "sviarono": "sviare",
    "sviasse": "sviare",
    "sviasser": "sviare",
    "sviassero": "sviare",
    "sviassi": "sviare",
    "sviassimo": "sviare",
    "sviaste": "sviare",
    "sviasti": "sviare",
    "sviata": "sviare",
    "sviate": "sviare",
    "sviati": "sviare",
    "sviato": "sviare",
    "sviava": "sviare",
    "sviavamo": "sviare",
    "sviavan": "sviare",
    "sviavano": "sviare",
    "sviavate": "sviare",
    "sviavi": "sviare",
    "sviavo": "sviare",
    "svicola": "svicolare",
    "svicolai": "svicolare",
    "svicolammo": "svicolare",
    "svicolan": "svicolare",
    "svicolando": "svicolare",
    "svicolano": "svicolare",
    "svicolante": "svicolare",
    "svicolanti": "svicolare",
    "svicolar": "svicolare",
    "svicolaron": "svicolare",
    "svicolarono": "svicolare",
    "svicolasse": "svicolare",
    "svicolasser": "svicolare",
    "svicolassero": "svicolare",
    "svicolassi": "svicolare",
    "svicolassimo": "svicolare",
    "svicolaste": "svicolare",
    "svicolasti": "svicolare",
    "svicolata": "svicolare",
    "svicolate": "svicolare",
    "svicolati": "svicolare",
    "svicolato": "svicolare",
    "svicolava": "svicolare",
    "svicolavamo": "svicolare",
    "svicolavan": "svicolare",
    "svicolavano": "svicolare",
    "svicolavate": "svicolare",
    "svicolavi": "svicolare",
    "svicolavo": "svicolare",
    "svicolerai": "svicolare",
    "svicoleran": "svicolare",
    "svicoleranno": "svicolare",
    "svicolerebbe": "svicolare",
    "svicolerebber": "svicolare",
    "svicolerebbero": "svicolare",
    "svicolerei": "svicolare",
    "svicoleremmo": "svicolare",
    "svicoleremo": "svicolare",
    "svicolereste": "svicolare",
    "svicoleresti": "svicolare",
    "svicolerete": "svicolare",
    "svicolerà": "svicolare",
    "svicolerò": "svicolare",
    "svicoli": "svicolare",
    "svicoliamo": "svicolare",
    "svicoliate": "svicolare",
    "svicolin": "svicolare",
    "svicolino": "svicolare",
    "svicolo": "svicolare",
    "svicolò": "svicolare",
    "sviene": "svenire",
    "svieni": "svenire",
    "svierai": "sviare",
    "svieran": "sviare",
    "svieranno": "sviare",
    "svierebbe": "sviare",
    "svierebber": "sviare",
    "svierebbero": "sviare",
    "svierei": "sviare",
    "svieremmo": "sviare",
    "svieremo": "sviare",
    "sviereste": "sviare",
    "svieresti": "sviare",
    "svierete": "sviare",
    "svierà": "sviare",
    "svierò": "sviare",
    "svigna": "svignare",
    "svignai": "svignare",
    "svignammo": "svignare",
    "svignan": "svignare",
    "svignando": "svignare",
    "svignano": "svignare",
    "svignante": "svignare",
    "svignanti": "svignare",
    "svignar": "svignare",
    "svignaron": "svignare",
    "svignarono": "svignare",
    "svignasse": "svignare",
    "svignasser": "svignare",
    "svignassero": "svignare",
    "svignassi": "svignare",
    "svignassimo": "svignare",
    "svignaste": "svignare",
    "svignasti": "svignare",
    "svignata": "svignare",
    "svignate": "svignare",
    "svignati": "svignare",
    "svignato": "svignare",
    "svignava": "svignare",
    "svignavamo": "svignare",
    "svignavan": "svignare",
    "svignavano": "svignare",
    "svignavate": "svignare",
    "svignavi": "svignare",
    "svignavo": "svignare",
    "svignerai": "svignare",
    "svigneran": "svignare",
    "svigneranno": "svignare",
    "svignerebbe": "svignare",
    "svignerebber": "svignare",
    "svignerebbero": "svignare",
    "svignerei": "svignare",
    "svigneremmo": "svignare",
    "svigneremo": "svignare",
    "svignereste": "svignare",
    "svigneresti": "svignare",
    "svignerete": "svignare",
    "svignerà": "svignare",
    "svignerò": "svignare",
    "svigni": "svignare",
    "svigniamo": "svignare",
    "svigniate": "svignare",
    "svignin": "svignare",
    "svignino": "svignare",
    "svigno": "svignare",
    "svignò": "svignare",
    "svigora": "svigorire",
    "svigoran": "svigorire",
    "svigorano": "svigorire",
    "svigore": "svigorire",
    "svigorendo": "svigorire",
    "svigorente": "svigorire",
    "svigorenti": "svigorire",
    "svigori": "svigorire",
    "svigoriamo": "svigorire",
    "svigoriate": "svigorire",
    "svigorii": "svigorire",
    "svigorimmo": "svigorire",
    "svigorir": "svigorire",
    "svigorirai": "svigorire",
    "svigoriran": "svigorire",
    "svigoriranno": "svigorire",
    "svigorirebbe": "svigorire",
    "svigorirebber": "svigorire",
    "svigorirebbero": "svigorire",
    "svigorirei": "svigorire",
    "svigoriremmo": "svigorire",
    "svigoriremo": "svigorire",
    "svigorireste": "svigorire",
    "svigoriresti": "svigorire",
    "svigorirete": "svigorire",
    "svigoriron": "svigorire",
    "svigorirono": "svigorire",
    "svigorirà": "svigorire",
    "svigorirò": "svigorire",
    "svigorisse": "svigorire",
    "svigorisser": "svigorire",
    "svigorissero": "svigorire",
    "svigorissi": "svigorire",
    "svigorissimo": "svigorire",
    "svigoriste": "svigorire",
    "svigoristi": "svigorire",
    "svigorita": "svigorire",
    "svigorite": "svigorire",
    "svigoriti": "svigorire",
    "svigorito": "svigorire",
    "svigoriva": "svigorire",
    "svigorivamo": "svigorire",
    "svigorivan": "svigorire",
    "svigorivano": "svigorire",
    "svigorivate": "svigorire",
    "svigorivi": "svigorire",
    "svigorivo": "svigorire",
    "svigoro": "svigorire",
    "svigoron": "svigorire",
    "svigorono": "svigorire",
    "svigorì": "svigorire",
    "svilendo": "svilire",
    "svilente": "svilire",
    "svilenti": "svilire",
    "sviliamo": "svilire",
    "sviliate": "svilire",
    "svilii": "svilire",
    "svilimmo": "svilire",
    "svilir": "svilire",
    "svilirai": "svilire",
    "sviliran": "svilire",
    "sviliranno": "svilire",
    "svilirebbe": "svilire",
    "svilirebber": "svilire",
    "svilirebbero": "svilire",
    "svilirei": "svilire",
    "sviliremmo": "svilire",
    "sviliremo": "svilire",
    "svilireste": "svilire",
    "sviliresti": "svilire",
    "svilirete": "svilire",
    "sviliron": "svilire",
    "svilirono": "svilire",
    "svilirà": "svilire",
    "svilirò": "svilire",
    "svilisca": "svilire",
    "sviliscan": "svilire",
    "sviliscano": "svilire",
    "svilisce": "svilire",
    "svilisci": "svilire",
    "svilisco": "svilire",
    "sviliscon": "svilire",
    "sviliscono": "svilire",
    "svilisse": "svilire",
    "svilisser": "svilire",
    "svilissero": "svilire",
    "svilissi": "svilire",
    "svilissimo": "svilire",
    "sviliste": "svilire",
    "svilisti": "svilire",
    "svilita": "svilire",
    "svilite": "svilire",
    "sviliti": "svilire",
    "svilito": "svilire",
    "sviliva": "svilire",
    "svilivamo": "svilire",
    "svilivan": "svilire",
    "svilivano": "svilire",
    "svilivate": "svilire",
    "svilivi": "svilire",
    "svilivo": "svilire",
    "svillaneggerai": "svillaneggiare",
    "svillaneggeran": "svillaneggiare",
    "svillaneggeranno": "svillaneggiare",
    "svillaneggerebbe": "svillaneggiare",
    "svillaneggerebber": "svillaneggiare",
    "svillaneggerebbero": "svillaneggiare",
    "svillaneggerei": "svillaneggiare",
    "svillaneggeremmo": "svillaneggiare",
    "svillaneggeremo": "svillaneggiare",
    "svillaneggereste": "svillaneggiare",
    "svillaneggeresti": "svillaneggiare",
    "svillaneggerete": "svillaneggiare",
    "svillaneggerà": "svillaneggiare",
    "svillaneggerò": "svillaneggiare",
    "svillaneggi": "svillaneggiare",
    "svillaneggia": "svillaneggiare",
    "svillaneggiai": "svillaneggiare",
    "svillaneggiammo": "svillaneggiare",
    "svillaneggiamo": "svillaneggiare",
    "svillaneggian": "svillaneggiare",
    "svillaneggiando": "svillaneggiare",
    "svillaneggiano": "svillaneggiare",
    "svillaneggiante": "svillaneggiare",
    "svillaneggianti": "svillaneggiare",
    "svillaneggiar": "svillaneggiare",
    "svillaneggiaron": "svillaneggiare",
    "svillaneggiarono": "svillaneggiare",
    "svillaneggiasse": "svillaneggiare",
    "svillaneggiasser": "svillaneggiare",
    "svillaneggiassero": "svillaneggiare",
    "svillaneggiassi": "svillaneggiare",
    "svillaneggiassimo": "svillaneggiare",
    "svillaneggiaste": "svillaneggiare",
    "svillaneggiasti": "svillaneggiare",
    "svillaneggiata": "svillaneggiare",
    "svillaneggiate": "svillaneggiare",
    "svillaneggiati": "svillaneggiare",
    "svillaneggiato": "svillaneggiare",
    "svillaneggiava": "svillaneggiare",
    "svillaneggiavamo": "svillaneggiare",
    "svillaneggiavan": "svillaneggiare",
    "svillaneggiavano": "svillaneggiare",
    "svillaneggiavate": "svillaneggiare",
    "svillaneggiavi": "svillaneggiare",
    "svillaneggiavo": "svillaneggiare",
    "svillaneggin": "svillaneggiare",
    "svillaneggino": "svillaneggiare",
    "svillaneggio": "svillaneggiare",
    "svillaneggiò": "svillaneggiare",
    "sviluppa": "sviluppare",
    "sviluppai": "sviluppare",
    "sviluppammo": "sviluppare",
    "sviluppan": "sviluppare",
    "sviluppando": "sviluppare",
    "sviluppano": "sviluppare",
    "sviluppante": "sviluppare",
    "sviluppanti": "sviluppare",
    "sviluppar": "sviluppare",
    "svilupparon": "sviluppare",
    "svilupparono": "sviluppare",
    "sviluppasse": "sviluppare",
    "sviluppasser": "sviluppare",
    "sviluppassero": "sviluppare",
    "sviluppassi": "sviluppare",
    "sviluppassimo": "sviluppare",
    "sviluppaste": "sviluppare",
    "sviluppasti": "sviluppare",
    "sviluppata": "sviluppato",
    "sviluppate": "sviluppato",
    "sviluppati": "sviluppato",
    "sviluppato": "sviluppare",
    "sviluppava": "sviluppare",
    "sviluppavamo": "sviluppare",
    "sviluppavan": "sviluppare",
    "sviluppavano": "sviluppare",
    "sviluppavate": "sviluppare",
    "sviluppavi": "sviluppare",
    "sviluppavo": "sviluppare",
    "svilupperai": "sviluppare",
    "svilupperan": "sviluppare",
    "svilupperanno": "sviluppare",
    "svilupperebbe": "sviluppare",
    "svilupperebber": "sviluppare",
    "svilupperebbero": "sviluppare",
    "svilupperei": "sviluppare",
    "svilupperemmo": "sviluppare",
    "svilupperemo": "sviluppare",
    "sviluppereste": "sviluppare",
    "svilupperesti": "sviluppare",
    "svilupperete": "sviluppare",
    "svilupperà": "sviluppare",
    "svilupperò": "sviluppare",
    "sviluppi": "sviluppo",
    "sviluppiamo": "sviluppare",
    "sviluppiate": "sviluppare",
    "sviluppin": "sviluppare",
    "sviluppino": "sviluppare",
    "sviluppo": "sviluppare",
    "sviluppò": "sviluppare",
    "svilì": "svilire",
    "svin": "sviare",
    "svina": "svinare",
    "svinai": "svinare",
    "svinammo": "svinare",
    "svinan": "svinare",
    "svinando": "svinare",
    "svinano": "svinare",
    "svinante": "svinare",
    "svinanti": "svinare",
    "svinar": "svinare",
    "svinaron": "svinare",
    "svinarono": "svinare",
    "svinasse": "svinare",
    "svinasser": "svinare",
    "svinassero": "svinare",
    "svinassi": "svinare",
    "svinassimo": "svinare",
    "svinaste": "svinare",
    "svinasti": "svinare",
    "svinata": "svinare",
    "svinate": "svinare",
    "svinati": "svinare",
    "svinato": "svinare",
    "svinava": "svinare",
    "svinavamo": "svinare",
    "svinavan": "svinare",
    "svinavano": "svinare",
    "svinavate": "svinare",
    "svinavi": "svinare",
    "svinavo": "svinare",
    "svincola": "svincolare",
    "svincolai": "svincolare",
    "svincolammo": "svincolare",
    "svincolan": "svincolare",
    "svincolando": "svincolare",
    "svincolano": "svincolare",
    "svincolante": "svincolare",
    "svincolanti": "svincolare",
    "svincolar": "svincolare",
    "svincolaron": "svincolare",
    "svincolarono": "svincolare",
    "svincolasse": "svincolare",
    "svincolasser": "svincolare",
    "svincolassero": "svincolare",
    "svincolassi": "svincolare",
    "svincolassimo": "svincolare",
    "svincolaste": "svincolare",
    "svincolasti": "svincolare",
    "svincolata": "svincolare",
    "svincolate": "svincolare",
    "svincolati": "svincolare",
    "svincolato": "svincolare",
    "svincolava": "svincolare",
    "svincolavamo": "svincolare",
    "svincolavan": "svincolare",
    "svincolavano": "svincolare",
    "svincolavate": "svincolare",
    "svincolavi": "svincolare",
    "svincolavo": "svincolare",
    "svincolerai": "svincolare",
    "svincoleran": "svincolare",
    "svincoleranno": "svincolare",
    "svincolerebbe": "svincolare",
    "svincolerebber": "svincolare",
    "svincolerebbero": "svincolare",
    "svincolerei": "svincolare",
    "svincoleremmo": "svincolare",
    "svincoleremo": "svincolare",
    "svincolereste": "svincolare",
    "svincoleresti": "svincolare",
    "svincolerete": "svincolare",
    "svincolerà": "svincolare",
    "svincolerò": "svincolare",
    "svincoli": "svincolo",
    "svincoliamo": "svincolare",
    "svincoliate": "svincolare",
    "svincolin": "svincolare",
    "svincolino": "svincolare",
    "svincolo": "svincolare",
    "svincolò": "svincolare",
    "svinerai": "svinare",
    "svineran": "svinare",
    "svineranno": "svinare",
    "svinerebbe": "svinare",
    "svinerebber": "svinare",
    "svinerebbero": "svinare",
    "svinerei": "svinare",
    "svineremmo": "svinare",
    "svineremo": "svinare",
    "svinereste": "svinare",
    "svineresti": "svinare",
    "svinerete": "svinare",
    "svinerà": "svinare",
    "svinerò": "svinare",
    "svini": "svinare",
    "sviniamo": "svinare",
    "sviniate": "svinare",
    "svinin": "svinare",
    "svinino": "svinare",
    "svino": "svinare",
    "svinò": "svinare",
    "svio": "sviare",
    "sviolina": "sviolinare",
    "sviolinai": "sviolinare",
    "sviolinammo": "sviolinare",
    "sviolinan": "sviolinare",
    "sviolinando": "sviolinare",
    "sviolinano": "sviolinare",
    "sviolinante": "sviolinare",
    "sviolinanti": "sviolinare",
    "sviolinar": "sviolinare",
    "sviolinaron": "sviolinare",
    "sviolinarono": "sviolinare",
    "sviolinasse": "sviolinare",
    "sviolinasser": "sviolinare",
    "sviolinassero": "sviolinare",
    "sviolinassi": "sviolinare",
    "sviolinassimo": "sviolinare",
    "sviolinaste": "sviolinare",
    "sviolinasti": "sviolinare",
    "sviolinata": "sviolinare",
    "sviolinate": "sviolinare",
    "sviolinati": "sviolinare",
    "sviolinato": "sviolinare",
    "sviolinava": "sviolinare",
    "sviolinavamo": "sviolinare",
    "sviolinavan": "sviolinare",
    "sviolinavano": "sviolinare",
    "sviolinavate": "sviolinare",
    "sviolinavi": "sviolinare",
    "sviolinavo": "sviolinare",
    "sviolinerai": "sviolinare",
    "sviolineran": "sviolinare",
    "sviolineranno": "sviolinare",
    "sviolinerebbe": "sviolinare",
    "sviolinerebber": "sviolinare",
    "sviolinerebbero": "sviolinare",
    "sviolinerei": "sviolinare",
    "sviolineremmo": "sviolinare",
    "sviolineremo": "sviolinare",
    "sviolinereste": "sviolinare",
    "sviolineresti": "sviolinare",
    "sviolinerete": "sviolinare",
    "sviolinerà": "sviolinare",
    "sviolinerò": "sviolinare",
    "sviolini": "sviolinare",
    "svioliniamo": "sviolinare",
    "svioliniate": "sviolinare",
    "sviolinin": "sviolinare",
    "sviolinino": "sviolinare",
    "sviolino": "sviolinare",
    "sviolinò": "sviolinare",
    "svirilizza": "svirilizzare",
    "svirilizzai": "svirilizzare",
    "svirilizzammo": "svirilizzare",
    "svirilizzan": "svirilizzare",
    "svirilizzando": "svirilizzare",
    "svirilizzano": "svirilizzare",
    "svirilizzante": "svirilizzare",
    "svirilizzanti": "svirilizzare",
    "svirilizzar": "svirilizzare",
    "svirilizzaron": "svirilizzare",
    "svirilizzarono": "svirilizzare",
    "svirilizzasse": "svirilizzare",
    "svirilizzasser": "svirilizzare",
    "svirilizzassero": "svirilizzare",
    "svirilizzassi": "svirilizzare",
    "svirilizzassimo": "svirilizzare",
    "svirilizzaste": "svirilizzare",
    "svirilizzasti": "svirilizzare",
    "svirilizzata": "svirilizzare",
    "svirilizzate": "svirilizzare",
    "svirilizzati": "svirilizzare",
    "svirilizzato": "svirilizzare",
    "svirilizzava": "svirilizzare",
    "svirilizzavamo": "svirilizzare",
    "svirilizzavan": "svirilizzare",
    "svirilizzavano": "svirilizzare",
    "svirilizzavate": "svirilizzare",
    "svirilizzavi": "svirilizzare",
    "svirilizzavo": "svirilizzare",
    "svirilizzerai": "svirilizzare",
    "svirilizzeran": "svirilizzare",
    "svirilizzeranno": "svirilizzare",
    "svirilizzerebbe": "svirilizzare",
    "svirilizzerebber": "svirilizzare",
    "svirilizzerebbero": "svirilizzare",
    "svirilizzerei": "svirilizzare",
    "svirilizzeremmo": "svirilizzare",
    "svirilizzeremo": "svirilizzare",
    "svirilizzereste": "svirilizzare",
    "svirilizzeresti": "svirilizzare",
    "svirilizzerete": "svirilizzare",
    "svirilizzerà": "svirilizzare",
    "svirilizzerò": "svirilizzare",
    "svirilizzi": "svirilizzare",
    "svirilizziamo": "svirilizzare",
    "svirilizziate": "svirilizzare",
    "svirilizzin": "svirilizzare",
    "svirilizzino": "svirilizzare",
    "svirilizzo": "svirilizzare",
    "svirilizzò": "svirilizzare",
    "svisa": "svisare",
    "svisai": "svisare",
    "svisammo": "svisare",
    "svisan": "svisare",
    "svisando": "svisare",
    "svisano": "svisare",
    "svisante": "svisare",
    "svisanti": "svisare",
    "svisar": "svisare",
    "svisaron": "svisare",
    "svisarono": "svisare",
    "svisasse": "svisare",
    "svisasser": "svisare",
    "svisassero": "svisare",
    "svisassi": "svisare",
    "svisassimo": "svisare",
    "svisaste": "svisare",
    "svisasti": "svisare",
    "svisata": "svisare",
    "svisate": "svisare",
    "svisati": "svisare",
    "svisato": "svisare",
    "svisava": "svisare",
    "svisavamo": "svisare",
    "svisavan": "svisare",
    "svisavano": "svisare",
    "svisavate": "svisare",
    "svisavi": "svisare",
    "svisavo": "svisare",
    "sviscera": "sviscerare",
    "sviscerai": "sviscerare",
    "sviscerammo": "sviscerare",
    "svisceran": "sviscerare",
    "sviscerando": "sviscerare",
    "sviscerano": "sviscerare",
    "sviscerante": "sviscerare",
    "svisceranti": "sviscerare",
    "sviscerar": "sviscerare",
    "svisceraron": "sviscerare",
    "sviscerarono": "sviscerare",
    "sviscerasse": "sviscerare",
    "sviscerasser": "sviscerare",
    "sviscerassero": "sviscerare",
    "sviscerassi": "sviscerare",
    "sviscerassimo": "sviscerare",
    "svisceraste": "sviscerare",
    "sviscerasti": "sviscerare",
    "sviscerata": "sviscerare",
    "sviscerate": "sviscerare",
    "sviscerati": "sviscerare",
    "sviscerato": "sviscerare",
    "sviscerava": "sviscerare",
    "svisceravamo": "sviscerare",
    "svisceravan": "sviscerare",
    "svisceravano": "sviscerare",
    "svisceravate": "sviscerare",
    "svisceravi": "sviscerare",
    "svisceravo": "sviscerare",
    "sviscererai": "sviscerare",
    "sviscereran": "sviscerare",
    "sviscereranno": "sviscerare",
    "sviscererebbe": "sviscerare",
    "sviscererebber": "sviscerare",
    "sviscererebbero": "sviscerare",
    "sviscererei": "sviscerare",
    "sviscereremmo": "sviscerare",
    "sviscereremo": "sviscerare",
    "sviscerereste": "sviscerare",
    "sviscereresti": "sviscerare",
    "sviscererete": "sviscerare",
    "sviscererà": "sviscerare",
    "sviscererò": "sviscerare",
    "svisceri": "sviscerare",
    "svisceriamo": "sviscerare",
    "svisceriate": "sviscerare",
    "sviscerin": "sviscerare",
    "sviscerino": "sviscerare",
    "sviscero": "sviscerare",
    "sviscerò": "sviscerare",
    "sviserai": "svisare",
    "sviseran": "svisare",
    "sviseranno": "svisare",
    "sviserebbe": "svisare",
    "sviserebber": "svisare",
    "sviserebbero": "svisare",
    "sviserei": "svisare",
    "sviseremmo": "svisare",
    "sviseremo": "svisare",
    "svisereste": "svisare",
    "sviseresti": "svisare",
    "sviserete": "svisare",
    "sviserà": "svisare",
    "sviserò": "svisare",
    "svisi": "svisare",
    "svisiamo": "svisare",
    "svisiate": "svisare",
    "svisin": "svisare",
    "svisino": "svisare",
    "sviso": "svisare",
    "sviste": "svista",
    "svisò": "svisare",
    "svita": "svitare",
    "svitai": "svitare",
    "svitammo": "svitare",
    "svitan": "svitare",
    "svitando": "svitare",
    "svitano": "svitare",
    "svitante": "svitare",
    "svitanti": "svitare",
    "svitar": "svitare",
    "svitaron": "svitare",
    "svitarono": "svitare",
    "svitasse": "svitare",
    "svitasser": "svitare",
    "svitassero": "svitare",
    "svitassi": "svitare",
    "svitassimo": "svitare",
    "svitaste": "svitare",
    "svitasti": "svitare",
    "svitata": "svitato",
    "svitate": "svitato",
    "svitati": "svitato",
    "svitato": "svitare",
    "svitava": "svitare",
    "svitavamo": "svitare",
    "svitavan": "svitare",
    "svitavano": "svitare",
    "svitavate": "svitare",
    "svitavi": "svitare",
    "svitavo": "svitare",
    "sviterai": "svitare",
    "sviteran": "svitare",
    "sviteranno": "svitare",
    "sviterebbe": "svitare",
    "sviterebber": "svitare",
    "sviterebbero": "svitare",
    "sviterei": "svitare",
    "sviteremmo": "svitare",
    "sviteremo": "svitare",
    "svitereste": "svitare",
    "sviteresti": "svitare",
    "sviterete": "svitare",
    "sviterà": "svitare",
    "sviterò": "svitare",
    "sviti": "svitare",
    "svitiamo": "svitare",
    "svitiate": "svitare",
    "svitin": "svitare",
    "svitino": "svitare",
    "svito": "svitare",
    "svitò": "svitare",
    "svizzera": "svizzero",
    "svizzere": "svizzero",
    "svizzeri": "svizzero",
    "sviò": "sviare",
    "svogliata": "svogliato",
    "svogliate": "svogliato",
    "svogliatezze": "svogliatezza",
    "svogliati": "svogliato",
    "svolazza": "svolazzare",
    "svolazzai": "svolazzare",
    "svolazzammo": "svolazzare",
    "svolazzan": "svolazzare",
    "svolazzando": "svolazzare",
    "svolazzano": "svolazzare",
    "svolazzante": "svolazzare",
    "svolazzanti": "svolazzare",
    "svolazzar": "svolazzare",
    "svolazzaron": "svolazzare",
    "svolazzarono": "svolazzare",
    "svolazzasse": "svolazzare",
    "svolazzasser": "svolazzare",
    "svolazzassero": "svolazzare",
    "svolazzassi": "svolazzare",
    "svolazzassimo": "svolazzare",
    "svolazzaste": "svolazzare",
    "svolazzasti": "svolazzare",
    "svolazzata": "svolazzare",
    "svolazzate": "svolazzare",
    "svolazzati": "svolazzare",
    "svolazzato": "svolazzare",
    "svolazzava": "svolazzare",
    "svolazzavamo": "svolazzare",
    "svolazzavan": "svolazzare",
    "svolazzavano": "svolazzare",
    "svolazzavate": "svolazzare",
    "svolazzavi": "svolazzare",
    "svolazzavo": "svolazzare",
    "svolazzerai": "svolazzare",
    "svolazzeran": "svolazzare",
    "svolazzeranno": "svolazzare",
    "svolazzerebbe": "svolazzare",
    "svolazzerebber": "svolazzare",
    "svolazzerebbero": "svolazzare",
    "svolazzerei": "svolazzare",
    "svolazzeremmo": "svolazzare",
    "svolazzeremo": "svolazzare",
    "svolazzereste": "svolazzare",
    "svolazzeresti": "svolazzare",
    "svolazzerete": "svolazzare",
    "svolazzerà": "svolazzare",
    "svolazzerò": "svolazzare",
    "svolazzi": "svolazzo",
    "svolazziamo": "svolazzare",
    "svolazziate": "svolazzare",
    "svolazzin": "svolazzare",
    "svolazzino": "svolazzare",
    "svolazzo": "svolazzare",
    "svolazzò": "svolazzare",
    "svolga": "svolgere",
    "svolgan": "svolgere",
    "svolgano": "svolgere",
    "svolge": "svolgere",
    "svolgemmo": "svolgere",
    "svolgendo": "svolgere",
    "svolgente": "svolgere",
    "svolgenti": "svolgere",
    "svolger": "svolgere",
    "svolgerai": "svolgere",
    "svolgeran": "svolgere",
    "svolgeranno": "svolgere",
    "svolgerebbe": "svolgere",
    "svolgerebber": "svolgere",
    "svolgerebbero": "svolgere",
    "svolgerei": "svolgere",
    "svolgeremmo": "svolgere",
    "svolgeremo": "svolgere",
    "svolgereste": "svolgere",
    "svolgeresti": "svolgere",
    "svolgerete": "svolgere",
    "svolgerà": "svolgere",
    "svolgerò": "svolgere",
    "svolgesse": "svolgere",
    "svolgesser": "svolgere",
    "svolgessero": "svolgere",
    "svolgessi": "svolgere",
    "svolgessimo": "svolgere",
    "svolgeste": "svolgere",
    "svolgesti": "svolgere",
    "svolgete": "svolgere",
    "svolgeva": "svolgere",
    "svolgevamo": "svolgere",
    "svolgevan": "svolgere",
    "svolgevano": "svolgere",
    "svolgevate": "svolgere",
    "svolgevi": "svolgere",
    "svolgevo": "svolgere",
    "svolgi": "svolgere",
    "svolgiamo": "svolgere",
    "svolgiate": "svolgere",
    "svolgimenti": "svolgimento",
    "svolgo": "svolgere",
    "svolgon": "svolgere",
    "svolgono": "svolgere",
    "svolse": "svolgere",
    "svolser": "svolgere",
    "svolsero": "svolgere",
    "svolsi": "svolgere",
    "svolta": "svolto",
    "svoltai": "svoltare",
    "svoltammo": "svoltare",
    "svoltan": "svoltare",
    "svoltando": "svoltare",
    "svoltano": "svoltare",
    "svoltante": "svoltare",
    "svoltanti": "svoltare",
    "svoltar": "svoltare",
    "svoltaron": "svoltare",
    "svoltarono": "svoltare",
    "svoltasse": "svoltare",
    "svoltasser": "svoltare",
    "svoltassero": "svoltare",
    "svoltassi": "svoltare",
    "svoltassimo": "svoltare",
    "svoltaste": "svoltare",
    "svoltasti": "svoltare",
    "svoltata": "svoltare",
    "svoltate": "svoltare",
    "svoltati": "svoltare",
    "svoltato": "svoltare",
    "svoltava": "svoltare",
    "svoltavamo": "svoltare",
    "svoltavan": "svoltare",
    "svoltavano": "svoltare",
    "svoltavate": "svoltare",
    "svoltavi": "svoltare",
    "svoltavo": "svoltare",
    "svolte": "svolto",
    "svolterai": "svoltare",
    "svolteran": "svoltare",
    "svolteranno": "svoltare",
    "svolterebbe": "svoltare",
    "svolterebber": "svoltare",
    "svolterebbero": "svoltare",
    "svolterei": "svoltare",
    "svolteremmo": "svoltare",
    "svolteremo": "svoltare",
    "svoltereste": "svoltare",
    "svolteresti": "svoltare",
    "svolterete": "svoltare",
    "svolterà": "svoltare",
    "svolterò": "svoltare",
    "svolti": "svolto",
    "svoltiamo": "svoltare",
    "svoltiate": "svoltare",
    "svoltin": "svoltare",
    "svoltino": "svoltare",
    "svolto": "svoltare",
    "svoltò": "svoltare",
    "svuota": "svuotare",
    "svuotai": "svuotare",
    "svuotamenti": "svuotamento",
    "svuotammo": "svuotare",
    "svuotan": "svuotare",
    "svuotando": "svuotare",
    "svuotano": "svuotare",
    "svuotante": "svuotare",
    "svuotanti": "svuotare",
    "svuotar": "svuotare",
    "svuotaron": "svuotare",
    "svuotarono": "svuotare",
    "svuotasse": "svuotare",
    "svuotasser": "svuotare",
    "svuotassero": "svuotare",
    "svuotassi": "svuotare",
    "svuotassimo": "svuotare",
    "svuotaste": "svuotare",
    "svuotasti": "svuotare",
    "svuotata": "svuotare",
    "svuotate": "svuotare",
    "svuotati": "svuotare",
    "svuotato": "svuotare",
    "svuotava": "svuotare",
    "svuotavamo": "svuotare",
    "svuotavan": "svuotare",
    "svuotavano": "svuotare",
    "svuotavate": "svuotare",
    "svuotavi": "svuotare",
    "svuotavo": "svuotare",
    "svuoterai": "svuotare",
    "svuoteran": "svuotare",
    "svuoteranno": "svuotare",
    "svuoterebbe": "svuotare",
    "svuoterebber": "svuotare",
    "svuoterebbero": "svuotare",
    "svuoterei": "svuotare",
    "svuoteremmo": "svuotare",
    "svuoteremo": "svuotare",
    "svuotereste": "svuotare",
    "svuoteresti": "svuotare",
    "svuoterete": "svuotare",
    "svuoterà": "svuotare",
    "svuoterò": "svuotare",
    "svuoti": "svuotare",
    "svuotiamo": "svuotare",
    "svuotiate": "svuotare",
    "svuotin": "svuotare",
    "svuotino": "svuotare",
    "svuoto": "svuotare",
    "svuotò": "svuotare",
    "swinga": "swingare",
    "swingai": "swingare",
    "swingammo": "swingare",
    "swingan": "swingare",
    "swingando": "swingare",
    "swingano": "swingare",
    "swingante": "swingare",
    "swinganti": "swingare",
    "swingar": "swingare",
    "swingaron": "swingare",
    "swingarono": "swingare",
    "swingasse": "swingare",
    "swingasser": "swingare",
    "swingassero": "swingare",
    "swingassi": "swingare",
    "swingassimo": "swingare",
    "swingaste": "swingare",
    "swingasti": "swingare",
    "swingata": "swingare",
    "swingate": "swingare",
    "swingati": "swingare",
    "swingato": "swingare",
    "swingava": "swingare",
    "swingavamo": "swingare",
    "swingavan": "swingare",
    "swingavano": "swingare",
    "swingavate": "swingare",
    "swingavi": "swingare",
    "swingavo": "swingare",
    "swingherai": "swingare",
    "swingheran": "swingare",
    "swingheranno": "swingare",
    "swingherebbe": "swingare",
    "swingherebber": "swingare",
    "swingherebbero": "swingare",
    "swingherei": "swingare",
    "swingheremmo": "swingare",
    "swingheremo": "swingare",
    "swinghereste": "swingare",
    "swingheresti": "swingare",
    "swingherete": "swingare",
    "swingherà": "swingare",
    "swingherò": "swingare",
    "swinghi": "swingare",
    "swinghiamo": "swingare",
    "swinghiate": "swingare",
    "swinghin": "swingare",
    "swinghino": "swingare",
    "swingo": "swingare",
    "swingò": "swingare",
    "sètte": "sètta",
    "t'": "ti",
    "tabacca": "tabaccare",
    "tabaccai": "tabaccare",
    "tabaccaie": "tabaccaia",
    "tabaccammo": "tabaccare",
    "tabaccan": "tabaccare",
    "tabaccando": "tabaccare",
    "tabaccano": "tabaccare",
    "tabaccante": "tabaccare",
    "tabaccanti": "tabaccare",
    "tabaccar": "tabaccare",
    "tabaccaron": "tabaccare",
    "tabaccarono": "tabaccare",
    "tabaccasse": "tabaccare",
    "tabaccasser": "tabaccare",
    "tabaccassero": "tabaccare",
    "tabaccassi": "tabaccare",
    "tabaccassimo": "tabaccare",
    "tabaccaste": "tabaccare",
    "tabaccasti": "tabaccare",
    "tabaccata": "tabaccare",
    "tabaccate": "tabaccare",
    "tabaccati": "tabaccare",
    "tabaccato": "tabaccare",
    "tabaccava": "tabaccare",
    "tabaccavamo": "tabaccare",
    "tabaccavan": "tabaccare",
    "tabaccavano": "tabaccare",
    "tabaccavate": "tabaccare",
    "tabaccavi": "tabaccare",
    "tabaccavo": "tabaccare",
    "tabaccherai": "tabaccare",
    "tabaccheran": "tabaccare",
    "tabaccheranno": "tabaccare",
    "tabaccherebbe": "tabaccare",
    "tabaccherebber": "tabaccare",
    "tabaccherebbero": "tabaccare",
    "tabaccherei": "tabaccare",
    "tabaccheremmo": "tabaccare",
    "tabaccheremo": "tabaccare",
    "tabacchereste": "tabaccare",
    "tabaccheresti": "tabaccare",
    "tabaccherete": "tabaccare",
    "tabaccherie": "tabaccheria",
    "tabaccherà": "tabaccare",
    "tabaccherò": "tabaccare",
    "tabacchi": "tabacco",
    "tabacchiamo": "tabaccare",
    "tabacchiate": "tabaccare",
    "tabacchiere": "tabacchiera",
    "tabacchin": "tabaccare",
    "tabacchino": "tabaccare",
    "tabacco": "tabaccare",
    "tabaccosa": "tabaccoso",
    "tabaccose": "tabaccoso",
    "tabaccosi": "tabaccoso",
    "tabaccò": "tabaccare",
    "tabagismi": "tabagismo",
    "tabagisti": "tabagista",
    "tabelle": "tabella",
    "tabelline": "tabellina",
    "tabellini": "tabellino",
    "tabelloni": "tabellone",
    "tabernacoli": "tabernacolo",
    "tabula": "tabulare",
    "tabulai": "tabulare",
    "tabulammo": "tabulare",
    "tabulan": "tabulare",
    "tabulando": "tabulare",
    "tabulano": "tabulare",
    "tabulante": "tabulare",
    "tabulanti": "tabulare",
    "tabular": "tabulare",
    "tabularon": "tabulare",
    "tabularono": "tabulare",
    "tabulasse": "tabulare",
    "tabulasser": "tabulare",
    "tabulassero": "tabulare",
    "tabulassi": "tabulare",
    "tabulassimo": "tabulare",
    "tabulaste": "tabulare",
    "tabulasti": "tabulare",
    "tabulata": "tabulare",
    "tabulate": "tabulare",
    "tabulati": "tabulato",
    "tabulato": "tabulare",
    "tabulava": "tabulare",
    "tabulavamo": "tabulare",
    "tabulavan": "tabulare",
    "tabulavano": "tabulare",
    "tabulavate": "tabulare",
    "tabulavi": "tabulare",
    "tabulavo": "tabulare",
    "tabule": "tabula",
    "tabulerai": "tabulare",
    "tabuleran": "tabulare",
    "tabuleranno": "tabulare",
    "tabulerebbe": "tabulare",
    "tabulerebber": "tabulare",
    "tabulerebbero": "tabulare",
    "tabulerei": "tabulare",
    "tabuleremmo": "tabulare",
    "tabuleremo": "tabulare",
    "tabulereste": "tabulare",
    "tabuleresti": "tabulare",
    "tabulerete": "tabulare",
    "tabulerà": "tabulare",
    "tabulerò": "tabulare",
    "tabuli": "tabulare",
    "tabuliamo": "tabulare",
    "tabuliate": "tabulare",
    "tabulin": "tabulare",
    "tabulino": "tabulare",
    "tabulo": "tabulare",
    "tabulò": "tabulare",
    "taccagni": "taccagno",
    "taccerai": "tacciare",
    "tacceran": "tacciare",
    "tacceranno": "tacciare",
    "taccerebbe": "tacciare",
    "taccerebber": "tacciare",
    "taccerebbero": "tacciare",
    "taccerei": "tacciare",
    "tacceremmo": "tacciare",
    "tacceremo": "tacciare",
    "taccereste": "tacciare",
    "tacceresti": "tacciare",
    "taccerete": "tacciare",
    "taccerà": "tacciare",
    "taccerò": "tacciare",
    "tacche": "tacca",
    "tacchetti": "tacchetto",
    "tacchi": "tacco",
    "tacchini": "tacchino",
    "tacci": "tacciare",
    "taccia": "tacere",
    "tacciai": "tacciare",
    "tacciammo": "tacciare",
    "tacciamo": "tacciare",
    "taccian": "tacciare",
    "tacciando": "tacciare",
    "tacciano": "tacere",
    "tacciante": "tacciare",
    "taccianti": "tacciare",
    "tacciar": "tacciare",
    "tacciaron": "tacciare",
    "tacciarono": "tacciare",
    "tacciasse": "tacciare",
    "tacciasser": "tacciare",
    "tacciassero": "tacciare",
    "tacciassi": "tacciare",
    "tacciassimo": "tacciare",
    "tacciaste": "tacciare",
    "tacciasti": "tacciare",
    "tacciata": "tacciare",
    "tacciate": "tacciare",
    "tacciati": "tacciare",
    "tacciato": "tacciare",
    "tacciava": "tacciare",
    "tacciavamo": "tacciare",
    "tacciavan": "tacciare",
    "tacciavano": "tacciare",
    "tacciavate": "tacciare",
    "tacciavi": "tacciare",
    "tacciavo": "tacciare",
    "taccin": "tacciare",
    "taccino": "tacciare",
    "taccio": "tacere",
    "tacciono": "tacere",
    "tacciò": "tacciare",
    "taccuini": "taccuino",
    "tace": "tacere",
    "tacemmo": "tacere",
    "tacente": "tacere",
    "tacenti": "tacere",
    "tacerai": "tacere",
    "taceranno": "tacere",
    "tacerebbe": "tacere",
    "tacerebbero": "tacere",
    "tacerei": "tacere",
    "taceremmo": "tacere",
    "taceremo": "tacere",
    "tacereste": "tacere",
    "taceresti": "tacere",
    "tacerete": "tacere",
    "tacerà": "tacere",
    "tacerò": "tacere",
    "tacesse": "tacere",
    "tacessero": "tacere",
    "tacessi": "tacere",
    "tacessimo": "tacere",
    "taceste": "tacere",
    "tacesti": "tacere",
    "tacete": "tacere",
    "taceva": "tacere",
    "tacevamo": "tacere",
    "tacevano": "tacere",
    "tacevate": "tacere",
    "tacevi": "tacere",
    "tacevo": "tacere",
    "tachicardie": "tachicardia",
    "tachimetri": "tachimetro",
    "taci": "tacere",
    "taciamo": "tacere",
    "taciate": "tacere",
    "tacita": "tacito",
    "tacitai": "tacitare",
    "tacitammo": "tacitare",
    "tacitan": "tacitare",
    "tacitando": "tacitare",
    "tacitano": "tacitare",
    "tacitante": "tacitare",
    "tacitanti": "tacitare",
    "tacitar": "tacitare",
    "tacitaron": "tacitare",
    "tacitarono": "tacitare",
    "tacitasse": "tacitare",
    "tacitasser": "tacitare",
    "tacitassero": "tacitare",
    "tacitassi": "tacitare",
    "tacitassimo": "tacitare",
    "tacitaste": "tacitare",
    "tacitasti": "tacitare",
    "tacitata": "tacitare",
    "tacitate": "tacitare",
    "tacitati": "tacitare",
    "tacitato": "tacitare",
    "tacitava": "tacitare",
    "tacitavamo": "tacitare",
    "tacitavan": "tacitare",
    "tacitavano": "tacitare",
    "tacitavate": "tacitare",
    "tacitavi": "tacitare",
    "tacitavo": "tacitare",
    "tacite": "tacito",
    "taciterai": "tacitare",
    "taciteran": "tacitare",
    "taciteranno": "tacitare",
    "taciterebbe": "tacitare",
    "taciterebber": "tacitare",
    "taciterebbero": "tacitare",
    "taciterei": "tacitare",
    "taciteremmo": "tacitare",
    "taciteremo": "tacitare",
    "tacitereste": "tacitare",
    "taciteresti": "tacitare",
    "taciterete": "tacitare",
    "taciterà": "tacitare",
    "taciterò": "tacitare",
    "taciti": "tacito",
    "tacitiamo": "tacitare",
    "tacitiate": "tacitare",
    "tacitin": "tacitare",
    "tacitino": "tacitare",
    "tacito": "tacitare",
    "taciturna": "taciturno",
    "taciturne": "taciturno",
    "taciturni": "taciturno",
    "tacitò": "tacitare",
    "taciuta": "tacere",
    "taciute": "tacere",
    "taciuti": "tacere",
    "taciuto": "tacere",
    "tacque": "tacere",
    "tacquero": "tacere",
    "tacqui": "tacere",
    "tafani": "tafano",
    "tafferugli": "tafferuglio",
    "tagiki": "tagiko",
    "tagli": "taglio",
    "taglia": "tagliare",
    "tagliai": "tagliare",
    "tagliammo": "tagliare",
    "tagliamo": "tagliare",
    "taglian": "tagliare",
    "tagliandi": "tagliando",
    "tagliando": "tagliare",
    "tagliano": "tagliare",
    "tagliante": "tagliare",
    "taglianti": "tagliare",
    "tagliar": "tagliare",
    "tagliaron": "tagliare",
    "tagliarono": "tagliare",
    "tagliasse": "tagliare",
    "tagliasser": "tagliare",
    "tagliassero": "tagliare",
    "tagliassi": "tagliare",
    "tagliassimo": "tagliare",
    "tagliaste": "tagliare",
    "tagliasti": "tagliare",
    "tagliata": "tagliato",
    "tagliate": "tagliato",
    "tagliatelle": "tagliatella",
    "tagliati": "tagliato",
    "tagliato": "tagliare",
    "tagliatori": "tagliatore",
    "tagliava": "tagliare",
    "tagliavamo": "tagliare",
    "tagliavan": "tagliare",
    "tagliavano": "tagliare",
    "tagliavate": "tagliare",
    "tagliavi": "tagliare",
    "tagliavo": "tagliare",
    "taglie": "taglia",
    "taglieggerai": "taglieggiare",
    "taglieggeran": "taglieggiare",
    "taglieggeranno": "taglieggiare",
    "taglieggerebbe": "taglieggiare",
    "taglieggerebber": "taglieggiare",
    "taglieggerebbero": "taglieggiare",
    "taglieggerei": "taglieggiare",
    "taglieggeremmo": "taglieggiare",
    "taglieggeremo": "taglieggiare",
    "taglieggereste": "taglieggiare",
    "taglieggeresti": "taglieggiare",
    "taglieggerete": "taglieggiare",
    "taglieggerà": "taglieggiare",
    "taglieggerò": "taglieggiare",
    "taglieggi": "taglieggiare",
    "taglieggia": "taglieggiare",
    "taglieggiai": "taglieggiare",
    "taglieggiamenti": "taglieggiamento",
    "taglieggiammo": "taglieggiare",
    "taglieggiamo": "taglieggiare",
    "taglieggian": "taglieggiare",
    "taglieggiando": "taglieggiare",
    "taglieggiano": "taglieggiare",
    "taglieggiante": "taglieggiare",
    "taglieggianti": "taglieggiare",
    "taglieggiar": "taglieggiare",
    "taglieggiaron": "taglieggiare",
    "taglieggiarono": "taglieggiare",
    "taglieggiasse": "taglieggiare",
    "taglieggiasser": "taglieggiare",
    "taglieggiassero": "taglieggiare",
    "taglieggiassi": "taglieggiare",
    "taglieggiassimo": "taglieggiare",
    "taglieggiaste": "taglieggiare",
    "taglieggiasti": "taglieggiare",
    "taglieggiata": "taglieggiare",
    "taglieggiate": "taglieggiare",
    "taglieggiati": "taglieggiare",
    "taglieggiato": "taglieggiare",
    "taglieggiatori": "taglieggiatore",
    "taglieggiava": "taglieggiare",
    "taglieggiavamo": "taglieggiare",
    "taglieggiavan": "taglieggiare",
    "taglieggiavano": "taglieggiare",
    "taglieggiavate": "taglieggiare",
    "taglieggiavi": "taglieggiare",
    "taglieggiavo": "taglieggiare",
    "taglieggin": "taglieggiare",
    "taglieggino": "taglieggiare",
    "taglieggio": "taglieggiare",
    "taglieggiò": "taglieggiare",
    "taglienti": "tagliente",
    "taglierai": "tagliare",
    "taglieran": "tagliare",
    "taglieranno": "tagliare",
    "taglierebbe": "tagliare",
    "taglierebber": "tagliare",
    "taglierebbero": "tagliare",
    "taglierei": "tagliare",
    "taglieremmo": "tagliare",
    "taglieremo": "tagliare",
    "tagliereste": "tagliare",
    "taglieresti": "tagliare",
    "taglierete": "tagliare",
    "taglierini": "taglierino",
    "taglierà": "tagliare",
    "taglierò": "tagliare",
    "taglin": "tagliare",
    "taglino": "tagliare",
    "taglio": "tagliare",
    "tagliole": "tagliola",
    "taglioni": "taglione",
    "tagliuzza": "tagliuzzare",
    "tagliuzzai": "tagliuzzare",
    "tagliuzzammo": "tagliuzzare",
    "tagliuzzan": "tagliuzzare",
    "tagliuzzando": "tagliuzzare",
    "tagliuzzano": "tagliuzzare",
    "tagliuzzante": "tagliuzzare",
    "tagliuzzanti": "tagliuzzare",
    "tagliuzzar": "tagliuzzare",
    "tagliuzzaron": "tagliuzzare",
    "tagliuzzarono": "tagliuzzare",
    "tagliuzzasse": "tagliuzzare",
    "tagliuzzasser": "tagliuzzare",
    "tagliuzzassero": "tagliuzzare",
    "tagliuzzassi": "tagliuzzare",
    "tagliuzzassimo": "tagliuzzare",
    "tagliuzzaste": "tagliuzzare",
    "tagliuzzasti": "tagliuzzare",
    "tagliuzzata": "tagliuzzare",
    "tagliuzzate": "tagliuzzare",
    "tagliuzzati": "tagliuzzare",
    "tagliuzzato": "tagliuzzare",
    "tagliuzzava": "tagliuzzare",
    "tagliuzzavamo": "tagliuzzare",
    "tagliuzzavan": "tagliuzzare",
    "tagliuzzavano": "tagliuzzare",
    "tagliuzzavate": "tagliuzzare",
    "tagliuzzavi": "tagliuzzare",
    "tagliuzzavo": "tagliuzzare",
    "tagliuzzerai": "tagliuzzare",
    "tagliuzzeran": "tagliuzzare",
    "tagliuzzeranno": "tagliuzzare",
    "tagliuzzerebbe": "tagliuzzare",
    "tagliuzzerebber": "tagliuzzare",
    "tagliuzzerebbero": "tagliuzzare",
    "tagliuzzerei": "tagliuzzare",
    "tagliuzzeremmo": "tagliuzzare",
    "tagliuzzeremo": "tagliuzzare",
    "tagliuzzereste": "tagliuzzare",
    "tagliuzzeresti": "tagliuzzare",
    "tagliuzzerete": "tagliuzzare",
    "tagliuzzerà": "tagliuzzare",
    "tagliuzzerò": "tagliuzzare",
    "tagliuzzi": "tagliuzzare",
    "tagliuzziamo": "tagliuzzare",
    "tagliuzziate": "tagliuzzare",
    "tagliuzzin": "tagliuzzare",
    "tagliuzzino": "tagliuzzare",
    "tagliuzzo": "tagliuzzare",
    "tagliuzzò": "tagliuzzare",
    "tagliò": "tagliare",
    "tailandesi": "tailandese",
    "tailleurini": "tailleurino",
    "taiwanesi": "taiwanese",
    "tal": "tale",
    "talami": "talamo",
    "talari": "talare",
    "talassemici": "talassemico",
    "talenta": "talentare",
    "talentai": "talentare",
    "talentammo": "talentare",
    "talentan": "talentare",
    "talentando": "talentare",
    "talentano": "talentare",
    "talentante": "talentare",
    "talentanti": "talentare",
    "talentar": "talentare",
    "talentaron": "talentare",
    "talentarono": "talentare",
    "talentasse": "talentare",
    "talentasser": "talentare",
    "talentassero": "talentare",
    "talentassi": "talentare",
    "talentassimo": "talentare",
    "talentaste": "talentare",
    "talentasti": "talentare",
    "talentata": "talentare",
    "talentate": "talentare",
    "talentati": "talentare",
    "talentato": "talentare",
    "talentava": "talentare",
    "talentavamo": "talentare",
    "talentavan": "talentare",
    "talentavano": "talentare",
    "talentavate": "talentare",
    "talentavi": "talentare",
    "talentavo": "talentare",
    "talenterai": "talentare",
    "talenteran": "talentare",
    "talenteranno": "talentare",
    "talenterebbe": "talentare",
    "talenterebber": "talentare",
    "talenterebbero": "talentare",
    "talenterei": "talentare",
    "talenteremmo": "talentare",
    "talenteremo": "talentare",
    "talentereste": "talentare",
    "talenteresti": "talentare",
    "talenterete": "talentare",
    "talenterà": "talentare",
    "talenterò": "talentare",
    "talenti": "talento",
    "talentiamo": "talentare",
    "talentiate": "talentare",
    "talentin": "talentare",
    "talentino": "talentare",
    "talento": "talentare",
    "talentuosa": "talentuoso",
    "talentuose": "talentuoso",
    "talentuosi": "talentuoso",
    "talentò": "talentare",
    "tali": "tale",
    "talismani": "talismano",
    "tallona": "tallonare",
    "tallonai": "tallonare",
    "tallonammo": "tallonare",
    "tallonan": "tallonare",
    "tallonando": "tallonare",
    "tallonano": "tallonare",
    "tallonante": "tallonare",
    "tallonanti": "tallonare",
    "tallonar": "tallonare",
    "tallonaron": "tallonare",
    "tallonarono": "tallonare",
    "tallonasse": "tallonare",
    "tallonasser": "tallonare",
    "tallonassero": "tallonare",
    "tallonassi": "tallonare",
    "tallonassimo": "tallonare",
    "tallonaste": "tallonare",
    "tallonasti": "tallonare",
    "tallonata": "tallonare",
    "tallonate": "tallonare",
    "tallonati": "tallonare",
    "tallonato": "tallonare",
    "tallonava": "tallonare",
    "tallonavamo": "tallonare",
    "tallonavan": "tallonare",
    "tallonavano": "tallonare",
    "tallonavate": "tallonare",
    "tallonavi": "tallonare",
    "tallonavo": "tallonare",
    "talloncini": "talloncino",
    "tallonerai": "tallonare",
    "talloneran": "tallonare",
    "talloneranno": "tallonare",
    "tallonerebbe": "tallonare",
    "tallonerebber": "tallonare",
    "tallonerebbero": "tallonare",
    "tallonerei": "tallonare",
    "talloneremmo": "tallonare",
    "talloneremo": "tallonare",
    "tallonereste": "tallonare",
    "talloneresti": "tallonare",
    "tallonerete": "tallonare",
    "tallonerà": "tallonare",
    "tallonerò": "tallonare",
    "talloni": "tallone",
    "talloniamo": "tallonare",
    "talloniate": "tallonare",
    "tallonin": "tallonare",
    "tallonino": "tallonare",
    "tallono": "tallonare",
    "tallonò": "tallonare",
    "talpe": "talpa",
    "talune": "talun",
    "tambura": "tamburare",
    "tamburai": "tamburare",
    "tamburammo": "tamburare",
    "tamburan": "tamburare",
    "tamburando": "tamburare",
    "tamburano": "tamburare",
    "tamburante": "tamburare",
    "tamburanti": "tamburare",
    "tamburar": "tamburare",
    "tamburaron": "tamburare",
    "tamburarono": "tamburare",
    "tamburasse": "tamburare",
    "tamburasser": "tamburare",
    "tamburassero": "tamburare",
    "tamburassi": "tamburare",
    "tamburassimo": "tamburare",
    "tamburaste": "tamburare",
    "tamburasti": "tamburare",
    "tamburata": "tamburare",
    "tamburate": "tamburare",
    "tamburati": "tamburare",
    "tamburato": "tamburare",
    "tamburava": "tamburare",
    "tamburavamo": "tamburare",
    "tamburavan": "tamburare",
    "tamburavano": "tamburare",
    "tamburavate": "tamburare",
    "tamburavi": "tamburare",
    "tamburavo": "tamburare",
    "tambureggerai": "tambureggiare",
    "tambureggeran": "tambureggiare",
    "tambureggeranno": "tambureggiare",
    "tambureggerebbe": "tambureggiare",
    "tambureggerebber": "tambureggiare",
    "tambureggerebbero": "tambureggiare",
    "tambureggerei": "tambureggiare",
    "tambureggeremmo": "tambureggiare",
    "tambureggeremo": "tambureggiare",
    "tambureggereste": "tambureggiare",
    "tambureggeresti": "tambureggiare",
    "tambureggerete": "tambureggiare",
    "tambureggerà": "tambureggiare",
    "tambureggerò": "tambureggiare",
    "tambureggi": "tambureggiare",
    "tambureggia": "tambureggiare",
    "tambureggiai": "tambureggiare",
    "tambureggiammo": "tambureggiare",
    "tambureggiamo": "tambureggiare",
    "tambureggian": "tambureggiare",
    "tambureggiando": "tambureggiare",
    "tambureggiano": "tambureggiare",
    "tambureggiante": "tambureggiare",
    "tambureggianti": "tambureggiare",
    "tambureggiar": "tambureggiare",
    "tambureggiaron": "tambureggiare",
    "tambureggiarono": "tambureggiare",
    "tambureggiasse": "tambureggiare",
    "tambureggiasser": "tambureggiare",
    "tambureggiassero": "tambureggiare",
    "tambureggiassi": "tambureggiare",
    "tambureggiassimo": "tambureggiare",
    "tambureggiaste": "tambureggiare",
    "tambureggiasti": "tambureggiare",
    "tambureggiata": "tambureggiare",
    "tambureggiate": "tambureggiare",
    "tambureggiati": "tambureggiare",
    "tambureggiato": "tambureggiare",
    "tambureggiava": "tambureggiare",
    "tambureggiavamo": "tambureggiare",
    "tambureggiavan": "tambureggiare",
    "tambureggiavano": "tambureggiare",
    "tambureggiavate": "tambureggiare",
    "tambureggiavi": "tambureggiare",
    "tambureggiavo": "tambureggiare",
    "tambureggin": "tambureggiare",
    "tambureggino": "tambureggiare",
    "tambureggio": "tambureggiare",
    "tambureggiò": "tambureggiare",
    "tamburella": "tamburellare",
    "tamburellai": "tamburellare",
    "tamburellammo": "tamburellare",
    "tamburellan": "tamburellare",
    "tamburellando": "tamburellare",
    "tamburellano": "tamburellare",
    "tamburellante": "tamburellare",
    "tamburellanti": "tamburellare",
    "tamburellar": "tamburellare",
    "tamburellaron": "tamburellare",
    "tamburellarono": "tamburellare",
    "tamburellasse": "tamburellare",
    "tamburellasser": "tamburellare",
    "tamburellassero": "tamburellare",
    "tamburellassi": "tamburellare",
    "tamburellassimo": "tamburellare",
    "tamburellaste": "tamburellare",
    "tamburellasti": "tamburellare",
    "tamburellata": "tamburellare",
    "tamburellate": "tamburellare",
    "tamburellati": "tamburellare",
    "tamburellato": "tamburellare",
    "tamburellava": "tamburellare",
    "tamburellavamo": "tamburellare",
    "tamburellavan": "tamburellare",
    "tamburellavano": "tamburellare",
    "tamburellavate": "tamburellare",
    "tamburellavi": "tamburellare",
    "tamburellavo": "tamburellare",
    "tamburellerai": "tamburellare",
    "tamburelleran": "tamburellare",
    "tamburelleranno": "tamburellare",
    "tamburellerebbe": "tamburellare",
    "tamburellerebber": "tamburellare",
    "tamburellerebbero": "tamburellare",
    "tamburellerei": "tamburellare",
    "tamburelleremmo": "tamburellare",
    "tamburelleremo": "tamburellare",
    "tamburellereste": "tamburellare",
    "tamburelleresti": "tamburellare",
    "tamburellerete": "tamburellare",
    "tamburellerà": "tamburellare",
    "tamburellerò": "tamburellare",
    "tamburelli": "tamburello",
    "tamburelliamo": "tamburellare",
    "tamburelliate": "tamburellare",
    "tamburellin": "tamburellare",
    "tamburellino": "tamburellare",
    "tamburello": "tamburellare",
    "tamburellò": "tamburellare",
    "tamburerai": "tamburare",
    "tambureran": "tamburare",
    "tambureranno": "tamburare",
    "tamburerebbe": "tamburare",
    "tamburerebber": "tamburare",
    "tamburerebbero": "tamburare",
    "tamburerei": "tamburare",
    "tambureremmo": "tamburare",
    "tambureremo": "tamburare",
    "tamburereste": "tamburare",
    "tambureresti": "tamburare",
    "tamburerete": "tamburare",
    "tamburerà": "tamburare",
    "tamburerò": "tamburare",
    "tamburi": "tamburare",
    "tamburiamo": "tamburare",
    "tamburiate": "tamburare",
    "tamburin": "tamburare",
    "tamburini": "tamburino",
    "tamburino": "tamburare",
    "tamburo": "tamburare",
    "tamburò": "tamburare",
    "tampina": "tampinare",
    "tampinai": "tampinare",
    "tampinammo": "tampinare",
    "tampinan": "tampinare",
    "tampinando": "tampinare",
    "tampinano": "tampinare",
    "tampinante": "tampinare",
    "tampinanti": "tampinare",
    "tampinar": "tampinare",
    "tampinaron": "tampinare",
    "tampinarono": "tampinare",
    "tampinasse": "tampinare",
    "tampinasser": "tampinare",
    "tampinassero": "tampinare",
    "tampinassi": "tampinare",
    "tampinassimo": "tampinare",
    "tampinaste": "tampinare",
    "tampinasti": "tampinare",
    "tampinata": "tampinare",
    "tampinate": "tampinare",
    "tampinati": "tampinare",
    "tampinato": "tampinare",
    "tampinava": "tampinare",
    "tampinavamo": "tampinare",
    "tampinavan": "tampinare",
    "tampinavano": "tampinare",
    "tampinavate": "tampinare",
    "tampinavi": "tampinare",
    "tampinavo": "tampinare",
    "tampinerai": "tampinare",
    "tampineran": "tampinare",
    "tampineranno": "tampinare",
    "tampinerebbe": "tampinare",
    "tampinerebber": "tampinare",
    "tampinerebbero": "tampinare",
    "tampinerei": "tampinare",
    "tampineremmo": "tampinare",
    "tampineremo": "tampinare",
    "tampinereste": "tampinare",
    "tampineresti": "tampinare",
    "tampinerete": "tampinare",
    "tampinerà": "tampinare",
    "tampinerò": "tampinare",
    "tampini": "tampinare",
    "tampiniamo": "tampinare",
    "tampiniate": "tampinare",
    "tampinin": "tampinare",
    "tampinino": "tampinare",
    "tampino": "tampinare",
    "tampinò": "tampinare",
    "tampona": "tamponare",
    "tamponai": "tamponare",
    "tamponamenti": "tamponamento",
    "tamponammo": "tamponare",
    "tamponan": "tamponare",
    "tamponando": "tamponare",
    "tamponano": "tamponare",
    "tamponante": "tamponare",
    "tamponanti": "tamponare",
    "tamponar": "tamponare",
    "tamponaron": "tamponare",
    "tamponarono": "tamponare",
    "tamponasse": "tamponare",
    "tamponasser": "tamponare",
    "tamponassero": "tamponare",
    "tamponassi": "tamponare",
    "tamponassimo": "tamponare",
    "tamponaste": "tamponare",
    "tamponasti": "tamponare",
    "tamponata": "tamponare",
    "tamponate": "tamponare",
    "tamponati": "tamponare",
    "tamponato": "tamponare",
    "tamponava": "tamponare",
    "tamponavamo": "tamponare",
    "tamponavan": "tamponare",
    "tamponavano": "tamponare",
    "tamponavate": "tamponare",
    "tamponavi": "tamponare",
    "tamponavo": "tamponare",
    "tamponerai": "tamponare",
    "tamponeran": "tamponare",
    "tamponeranno": "tamponare",
    "tamponerebbe": "tamponare",
    "tamponerebber": "tamponare",
    "tamponerebbero": "tamponare",
    "tamponerei": "tamponare",
    "tamponeremmo": "tamponare",
    "tamponeremo": "tamponare",
    "tamponereste": "tamponare",
    "tamponeresti": "tamponare",
    "tamponerete": "tamponare",
    "tamponerà": "tamponare",
    "tamponerò": "tamponare",
    "tamponi": "tampone",
    "tamponiamo": "tamponare",
    "tamponiate": "tamponare",
    "tamponin": "tamponare",
    "tamponino": "tamponare",
    "tampono": "tamponare",
    "tamponò": "tamponare",
    "tane": "tana",
    "tanfi": "tanfo",
    "tanga": "tangere",
    "tangan": "tangere",
    "tangano": "tangere",
    "tange": "tangere",
    "tangemmo": "tangere",
    "tangendo": "tangere",
    "tangentari": "tangentaro",
    "tangente": "tangere",
    "tangenti": "tangere",
    "tangentisti": "tangentista",
    "tangenziali": "tangenziale",
    "tanger": "tangere",
    "tangerai": "tangere",
    "tangeran": "tangere",
    "tangeranno": "tangere",
    "tangerebbe": "tangere",
    "tangerebber": "tangere",
    "tangerebbero": "tangere",
    "tangerei": "tangere",
    "tangeremmo": "tangere",
    "tangeremo": "tangere",
    "tangereste": "tangere",
    "tangeresti": "tangere",
    "tangerete": "tangere",
    "tangerà": "tangere",
    "tangerò": "tangere",
    "tangesse": "tangere",
    "tangesser": "tangere",
    "tangessero": "tangere",
    "tangessi": "tangere",
    "tangessimo": "tangere",
    "tangeste": "tangere",
    "tangesti": "tangere",
    "tangete": "tangere",
    "tangeva": "tangere",
    "tangevamo": "tangere",
    "tangevan": "tangere",
    "tangevano": "tangere",
    "tangevate": "tangere",
    "tangevi": "tangere",
    "tangevo": "tangere",
    "tanghi": "tango",
    "tangi": "tangere",
    "tangiamo": "tangere",
    "tangiate": "tangere",
    "tangibili": "tangibile",
    "tango": "tangere",
    "tangon": "tangere",
    "tangono": "tangere",
    "taniche": "tanica",
    "tanser": "tangere",
    "tansero": "tangere",
    "tansi": "tangere",
    "tansè": "tangere",
    "tanta": "tanto",
    "tante": "tanto",
    "tanti": "tanto",
    "tantina": "tantino",
    "tantine": "tantino",
    "tantini": "tantino",
    "tanto": "tangere",
    "tapina": "tapino",
    "tapine": "tapino",
    "tapini": "tapino",
    "tapiri": "tapiro",
    "tappa": "tappare",
    "tappai": "tappare",
    "tappammo": "tappare",
    "tappan": "tappare",
    "tappando": "tappare",
    "tappano": "tappare",
    "tappante": "tappare",
    "tappanti": "tappare",
    "tappar": "tappare",
    "tapparelle": "tapparella",
    "tapparon": "tappare",
    "tapparono": "tappare",
    "tappasse": "tappare",
    "tappasser": "tappare",
    "tappassero": "tappare",
    "tappassi": "tappare",
    "tappassimo": "tappare",
    "tappaste": "tappare",
    "tappasti": "tappare",
    "tappata": "tappare",
    "tappate": "tappare",
    "tappati": "tappare",
    "tappato": "tappare",
    "tappava": "tappare",
    "tappavamo": "tappare",
    "tappavan": "tappare",
    "tappavano": "tappare",
    "tappavate": "tappare",
    "tappavi": "tappare",
    "tappavo": "tappare",
    "tappe": "tappa",
    "tapperai": "tappare",
    "tapperan": "tappare",
    "tapperanno": "tappare",
    "tapperebbe": "tappare",
    "tapperebber": "tappare",
    "tapperebbero": "tappare",
    "tapperei": "tappare",
    "tapperemmo": "tappare",
    "tapperemo": "tappare",
    "tappereste": "tappare",
    "tapperesti": "tappare",
    "tapperete": "tappare",
    "tapperà": "tappare",
    "tapperò": "tappare",
    "tappeti": "tappeto",
    "tappetini": "tappetino",
    "tappezza": "tappezzare",
    "tappezzai": "tappezzare",
    "tappezzammo": "tappezzare",
    "tappezzan": "tappezzare",
    "tappezzando": "tappezzare",
    "tappezzano": "tappezzare",
    "tappezzante": "tappezzare",
    "tappezzanti": "tappezzare",
    "tappezzar": "tappezzare",
    "tappezzaron": "tappezzare",
    "tappezzarono": "tappezzare",
    "tappezzasse": "tappezzare",
    "tappezzasser": "tappezzare",
    "tappezzassero": "tappezzare",
    "tappezzassi": "tappezzare",
    "tappezzassimo": "tappezzare",
    "tappezzaste": "tappezzare",
    "tappezzasti": "tappezzare",
    "tappezzata": "tappezzare",
    "tappezzate": "tappezzare",
    "tappezzati": "tappezzare",
    "tappezzato": "tappezzare",
    "tappezzava": "tappezzare",
    "tappezzavamo": "tappezzare",
    "tappezzavan": "tappezzare",
    "tappezzavano": "tappezzare",
    "tappezzavate": "tappezzare",
    "tappezzavi": "tappezzare",
    "tappezzavo": "tappezzare",
    "tappezzerai": "tappezzare",
    "tappezzeran": "tappezzare",
    "tappezzeranno": "tappezzare",
    "tappezzerebbe": "tappezzare",
    "tappezzerebber": "tappezzare",
    "tappezzerebbero": "tappezzare",
    "tappezzerei": "tappezzare",
    "tappezzeremmo": "tappezzare",
    "tappezzeremo": "tappezzare",
    "tappezzereste": "tappezzare",
    "tappezzeresti": "tappezzare",
    "tappezzerete": "tappezzare",
    "tappezzerie": "tappezzeria",
    "tappezzerà": "tappezzare",
    "tappezzerò": "tappezzare",
    "tappezzi": "tappezzare",
    "tappezziamo": "tappezzare",
    "tappezziate": "tappezzare",
    "tappezzieri": "tappezziere",
    "tappezzin": "tappezzare",
    "tappezzino": "tappezzare",
    "tappezzo": "tappezzare",
    "tappezzò": "tappezzare",
    "tappi": "tappo",
    "tappiamo": "tappare",
    "tappiate": "tappare",
    "tappin": "tappare",
    "tappino": "tappare",
    "tappo": "tappare",
    "tapponi": "tappone",
    "tappò": "tappare",
    "tara": "tarare",
    "tarai": "tarare",
    "tarammo": "tarare",
    "taran": "tarare",
    "tarando": "tarare",
    "tarano": "tarare",
    "tarante": "tarare",
    "tarantelle": "tarantella",
    "taranti": "tarare",
    "tarantini": "tarantino",
    "tarantolati": "tarantolato",
    "tarantole": "tarantola",
    "tarar": "tarare",
    "tararon": "tarare",
    "tararono": "tarare",
    "tarassachi": "tarassaco",
    "tarasse": "tarare",
    "tarasser": "tarare",
    "tarassero": "tarare",
    "tarassi": "tarare",
    "tarassimo": "tarare",
    "taraste": "tarare",
    "tarasti": "tarare",
    "tarata": "tarato",
    "tarate": "tarato",
    "tarati": "tarato",
    "tarato": "tarare",
    "tarava": "tarare",
    "taravamo": "tarare",
    "taravan": "tarare",
    "taravano": "tarare",
    "taravate": "tarare",
    "taravi": "tarare",
    "taravo": "tarare",
    "tarchiata": "tarchiato",
    "tarchiate": "tarchiato",
    "tarchiati": "tarchiato",
    "tarda": "tardo",
    "tardai": "tardare",
    "tardammo": "tardare",
    "tardan": "tardare",
    "tardando": "tardare",
    "tardano": "tardare",
    "tardante": "tardare",
    "tardanti": "tardare",
    "tardar": "tardare",
    "tardaron": "tardare",
    "tardarono": "tardare",
    "tardasse": "tardare",
    "tardasser": "tardare",
    "tardassero": "tardare",
    "tardassi": "tardare",
    "tardassimo": "tardare",
    "tardaste": "tardare",
    "tardasti": "tardare",
    "tardata": "tardare",
    "tardate": "tardare",
    "tardati": "tardare",
    "tardato": "tardare",
    "tardava": "tardare",
    "tardavamo": "tardare",
    "tardavan": "tardare",
    "tardavano": "tardare",
    "tardavate": "tardare",
    "tardavi": "tardare",
    "tardavo": "tardare",
    "tarde": "tardo",
    "tarderai": "tardare",
    "tarderan": "tardare",
    "tarderanno": "tardare",
    "tarderebbe": "tardare",
    "tarderebber": "tardare",
    "tarderebbero": "tardare",
    "tarderei": "tardare",
    "tarderemmo": "tardare",
    "tarderemo": "tardare",
    "tardereste": "tardare",
    "tarderesti": "tardare",
    "tarderete": "tardare",
    "tarderà": "tardare",
    "tarderò": "tardare",
    "tardi": "tardo",
    "tardiamo": "tardare",
    "tardiate": "tardare",
    "tardin": "tardare",
    "tardino": "tardare",
    "tardiva": "tardivo",
    "tardive": "tardivo",
    "tardivi": "tardivo",
    "tardo": "tardare",
    "tardò": "tardare",
    "tare": "tara",
    "tarerai": "tarare",
    "tareran": "tarare",
    "tareranno": "tarare",
    "tarerebbe": "tarare",
    "tarerebber": "tarare",
    "tarerebbero": "tarare",
    "tarerei": "tarare",
    "tareremmo": "tarare",
    "tareremo": "tarare",
    "tarereste": "tarare",
    "tareresti": "tarare",
    "tarerete": "tarare",
    "tarerà": "tarare",
    "tarerò": "tarare",
    "targa": "targare",
    "targai": "targare",
    "targammo": "targare",
    "targan": "targare",
    "targando": "targare",
    "targano": "targare",
    "targante": "targare",
    "targanti": "targare",
    "targar": "targare",
    "targaron": "targare",
    "targarono": "targare",
    "targasse": "targare",
    "targasser": "targare",
    "targassero": "targare",
    "targassi": "targare",
    "targassimo": "targare",
    "targaste": "targare",
    "targasti": "targare",
    "targata": "targare",
    "targate": "targare",
    "targati": "targare",
    "targato": "targare",
    "targava": "targare",
    "targavamo": "targare",
    "targavan": "targare",
    "targavano": "targare",
    "targavate": "targare",
    "targavi": "targare",
    "targavo": "targare",
    "targhe": "targa",
    "targherai": "targare",
    "targheran": "targare",
    "targheranno": "targare",
    "targherebbe": "targare",
    "targherebber": "targare",
    "targherebbero": "targare",
    "targherei": "targare",
    "targheremmo": "targare",
    "targheremo": "targare",
    "targhereste": "targare",
    "targheresti": "targare",
    "targherete": "targare",
    "targherà": "targare",
    "targherò": "targare",
    "targhette": "targhetta",
    "targhi": "targare",
    "targhiamo": "targare",
    "targhiate": "targare",
    "targhin": "targare",
    "targhino": "targare",
    "targo": "targare",
    "targò": "targare",
    "tari": "tarare",
    "tariamo": "tarare",
    "tariate": "tarare",
    "tariffa": "tariffare",
    "tariffai": "tariffare",
    "tariffammo": "tariffare",
    "tariffan": "tariffare",
    "tariffando": "tariffare",
    "tariffano": "tariffare",
    "tariffante": "tariffare",
    "tariffanti": "tariffare",
    "tariffar": "tariffare",
    "tariffari": "tariffario",
    "tariffaria": "tariffario",
    "tariffarie": "tariffario",
    "tariffaron": "tariffare",
    "tariffarono": "tariffare",
    "tariffasse": "tariffare",
    "tariffasser": "tariffare",
    "tariffassero": "tariffare",
    "tariffassi": "tariffare",
    "tariffassimo": "tariffare",
    "tariffaste": "tariffare",
    "tariffasti": "tariffare",
    "tariffata": "tariffare",
    "tariffate": "tariffare",
    "tariffati": "tariffare",
    "tariffato": "tariffare",
    "tariffava": "tariffare",
    "tariffavamo": "tariffare",
    "tariffavan": "tariffare",
    "tariffavano": "tariffare",
    "tariffavate": "tariffare",
    "tariffavi": "tariffare",
    "tariffavo": "tariffare",
    "tariffazioni": "tariffazione",
    "tariffe": "tariffa",
    "tarifferai": "tariffare",
    "tarifferan": "tariffare",
    "tarifferanno": "tariffare",
    "tarifferebbe": "tariffare",
    "tarifferebber": "tariffare",
    "tarifferebbero": "tariffare",
    "tarifferei": "tariffare",
    "tarifferemmo": "tariffare",
    "tarifferemo": "tariffare",
    "tariffereste": "tariffare",
    "tarifferesti": "tariffare",
    "tarifferete": "tariffare",
    "tarifferà": "tariffare",
    "tarifferò": "tariffare",
    "tariffi": "tariffare",
    "tariffiamo": "tariffare",
    "tariffiate": "tariffare",
    "tariffin": "tariffare",
    "tariffino": "tariffare",
    "tariffo": "tariffare",
    "tariffò": "tariffare",
    "tarin": "tarare",
    "tarino": "tarare",
    "tarla": "tarlare",
    "tarlai": "tarlare",
    "tarlammo": "tarlare",
    "tarlan": "tarlare",
    "tarlando": "tarlare",
    "tarlano": "tarlare",
    "tarlante": "tarlare",
    "tarlanti": "tarlare",
    "tarlar": "tarlare",
    "tarlaron": "tarlare",
    "tarlarono": "tarlare",
    "tarlasse": "tarlare",
    "tarlasser": "tarlare",
    "tarlassero": "tarlare",
    "tarlassi": "tarlare",
    "tarlassimo": "tarlare",
    "tarlaste": "tarlare",
    "tarlasti": "tarlare",
    "tarlata": "tarlare",
    "tarlate": "tarlare",
    "tarlati": "tarlare",
    "tarlato": "tarlare",
    "tarlava": "tarlare",
    "tarlavamo": "tarlare",
    "tarlavan": "tarlare",
    "tarlavano": "tarlare",
    "tarlavate": "tarlare",
    "tarlavi": "tarlare",
    "tarlavo": "tarlare",
    "tarlerai": "tarlare",
    "tarleran": "tarlare",
    "tarleranno": "tarlare",
    "tarlerebbe": "tarlare",
    "tarlerebber": "tarlare",
    "tarlerebbero": "tarlare",
    "tarlerei": "tarlare",
    "tarleremmo": "tarlare",
    "tarleremo": "tarlare",
    "tarlereste": "tarlare",
    "tarleresti": "tarlare",
    "tarlerete": "tarlare",
    "tarlerà": "tarlare",
    "tarlerò": "tarlare",
    "tarli": "tarlare",
    "tarliamo": "tarlare",
    "tarliate": "tarlare",
    "tarlin": "tarlare",
    "tarlino": "tarlare",
    "tarlo": "tarlare",
    "tarlò": "tarlare",
    "tarma": "tarmare",
    "tarmai": "tarmare",
    "tarmammo": "tarmare",
    "tarman": "tarmare",
    "tarmando": "tarmare",
    "tarmano": "tarmare",
    "tarmante": "tarmare",
    "tarmanti": "tarmare",
    "tarmar": "tarmare",
    "tarmaron": "tarmare",
    "tarmarono": "tarmare",
    "tarmasse": "tarmare",
    "tarmasser": "tarmare",
    "tarmassero": "tarmare",
    "tarmassi": "tarmare",
    "tarmassimo": "tarmare",
    "tarmaste": "tarmare",
    "tarmasti": "tarmare",
    "tarmata": "tarmare",
    "tarmate": "tarmare",
    "tarmati": "tarmare",
    "tarmato": "tarmare",
    "tarmava": "tarmare",
    "tarmavamo": "tarmare",
    "tarmavan": "tarmare",
    "tarmavano": "tarmare",
    "tarmavate": "tarmare",
    "tarmavi": "tarmare",
    "tarmavo": "tarmare",
    "tarme": "tarma",
    "tarmerai": "tarmare",
    "tarmeran": "tarmare",
    "tarmeranno": "tarmare",
    "tarmerebbe": "tarmare",
    "tarmerebber": "tarmare",
    "tarmerebbero": "tarmare",
    "tarmerei": "tarmare",
    "tarmeremmo": "tarmare",
    "tarmeremo": "tarmare",
    "tarmereste": "tarmare",
    "tarmeresti": "tarmare",
    "tarmerete": "tarmare",
    "tarmerà": "tarmare",
    "tarmerò": "tarmare",
    "tarmi": "tarmare",
    "tarmiamo": "tarmare",
    "tarmiate": "tarmare",
    "tarmin": "tarmare",
    "tarmino": "tarmare",
    "tarmo": "tarmare",
    "tarmò": "tarmare",
    "taro": "tarare",
    "tarocchi": "tarocco",
    "tarpa": "tarpare",
    "tarpai": "tarpare",
    "tarpammo": "tarpare",
    "tarpan": "tarpare",
    "tarpando": "tarpare",
    "tarpano": "tarpare",
    "tarpante": "tarpare",
    "tarpanti": "tarpare",
    "tarpar": "tarpare",
    "tarparon": "tarpare",
    "tarparono": "tarpare",
    "tarpasse": "tarpare",
    "tarpasser": "tarpare",
    "tarpassero": "tarpare",
    "tarpassi": "tarpare",
    "tarpassimo": "tarpare",
    "tarpaste": "tarpare",
    "tarpasti": "tarpare",
    "tarpata": "tarpare",
    "tarpate": "tarpare",
    "tarpati": "tarpare",
    "tarpato": "tarpare",
    "tarpava": "tarpare",
    "tarpavamo": "tarpare",
    "tarpavan": "tarpare",
    "tarpavano": "tarpare",
    "tarpavate": "tarpare",
    "tarpavi": "tarpare",
    "tarpavo": "tarpare",
    "tarperai": "tarpare",
    "tarperan": "tarpare",
    "tarperanno": "tarpare",
    "tarperebbe": "tarpare",
    "tarperebber": "tarpare",
    "tarperebbero": "tarpare",
    "tarperei": "tarpare",
    "tarperemmo": "tarpare",
    "tarperemo": "tarpare",
    "tarpereste": "tarpare",
    "tarperesti": "tarpare",
    "tarperete": "tarpare",
    "tarperà": "tarpare",
    "tarperò": "tarpare",
    "tarpi": "tarpare",
    "tarpiamo": "tarpare",
    "tarpiate": "tarpare",
    "tarpin": "tarpare",
    "tarpino": "tarpare",
    "tarpo": "tarpare",
    "tarpò": "tarpare",
    "tarsie": "tarsia",
    "tartagli": "tartagliare",
    "tartaglia": "tartagliare",
    "tartagliai": "tartagliare",
    "tartagliammo": "tartagliare",
    "tartagliamo": "tartagliare",
    "tartaglian": "tartagliare",
    "tartagliando": "tartagliare",
    "tartagliano": "tartagliare",
    "tartagliante": "tartagliare",
    "tartaglianti": "tartagliare",
    "tartagliar": "tartagliare",
    "tartagliaron": "tartagliare",
    "tartagliarono": "tartagliare",
    "tartagliasse": "tartagliare",
    "tartagliasser": "tartagliare",
    "tartagliassero": "tartagliare",
    "tartagliassi": "tartagliare",
    "tartagliassimo": "tartagliare",
    "tartagliaste": "tartagliare",
    "tartagliasti": "tartagliare",
    "tartagliata": "tartagliare",
    "tartagliate": "tartagliare",
    "tartagliati": "tartagliare",
    "tartagliato": "tartagliare",
    "tartagliava": "tartagliare",
    "tartagliavamo": "tartagliare",
    "tartagliavan": "tartagliare",
    "tartagliavano": "tartagliare",
    "tartagliavate": "tartagliare",
    "tartagliavi": "tartagliare",
    "tartagliavo": "tartagliare",
    "tartaglierai": "tartagliare",
    "tartaglieran": "tartagliare",
    "tartaglieranno": "tartagliare",
    "tartaglierebbe": "tartagliare",
    "tartaglierebber": "tartagliare",
    "tartaglierebbero": "tartagliare",
    "tartaglierei": "tartagliare",
    "tartaglieremmo": "tartagliare",
    "tartaglieremo": "tartagliare",
    "tartagliereste": "tartagliare",
    "tartaglieresti": "tartagliare",
    "tartaglierete": "tartagliare",
    "tartaglierà": "tartagliare",
    "tartaglierò": "tartagliare",
    "tartaglin": "tartagliare",
    "tartaglino": "tartagliare",
    "tartaglio": "tartagliare",
    "tartagliò": "tartagliare",
    "tartara": "tartaro",
    "tartare": "tartaro",
    "tartarea": "tartareo",
    "tartaree": "tartareo",
    "tartarei": "tartareo",
    "tartari": "tartaro",
    "tartarughe": "tartaruga",
    "tartassa": "tartassare",
    "tartassai": "tartassare",
    "tartassammo": "tartassare",
    "tartassan": "tartassare",
    "tartassando": "tartassare",
    "tartassano": "tartassare",
    "tartassante": "tartassare",
    "tartassanti": "tartassare",
    "tartassar": "tartassare",
    "tartassaron": "tartassare",
    "tartassarono": "tartassare",
    "tartassasse": "tartassare",
    "tartassasser": "tartassare",
    "tartassassero": "tartassare",
    "tartassassi": "tartassare",
    "tartassassimo": "tartassare",
    "tartassaste": "tartassare",
    "tartassasti": "tartassare",
    "tartassata": "tartassare",
    "tartassate": "tartassare",
    "tartassati": "tartassare",
    "tartassato": "tartassare",
    "tartassava": "tartassare",
    "tartassavamo": "tartassare",
    "tartassavan": "tartassare",
    "tartassavano": "tartassare",
    "tartassavate": "tartassare",
    "tartassavi": "tartassare",
    "tartassavo": "tartassare",
    "tartasserai": "tartassare",
    "tartasseran": "tartassare",
    "tartasseranno": "tartassare",
    "tartasserebbe": "tartassare",
    "tartasserebber": "tartassare",
    "tartasserebbero": "tartassare",
    "tartasserei": "tartassare",
    "tartasseremmo": "tartassare",
    "tartasseremo": "tartassare",
    "tartassereste": "tartassare",
    "tartasseresti": "tartassare",
    "tartasserete": "tartassare",
    "tartasserà": "tartassare",
    "tartasserò": "tartassare",
    "tartassi": "tartassare",
    "tartassiamo": "tartassare",
    "tartassiate": "tartassare",
    "tartassin": "tartassare",
    "tartassino": "tartassare",
    "tartasso": "tartassare",
    "tartassò": "tartassare",
    "tartine": "tartina",
    "tartufa": "tartufare",
    "tartufai": "tartufare",
    "tartufammo": "tartufare",
    "tartufan": "tartufare",
    "tartufando": "tartufare",
    "tartufano": "tartufare",
    "tartufante": "tartufare",
    "tartufanti": "tartufare",
    "tartufar": "tartufare",
    "tartufaron": "tartufare",
    "tartufarono": "tartufare",
    "tartufasse": "tartufare",
    "tartufasser": "tartufare",
    "tartufassero": "tartufare",
    "tartufassi": "tartufare",
    "tartufassimo": "tartufare",
    "tartufaste": "tartufare",
    "tartufasti": "tartufare",
    "tartufata": "tartufare",
    "tartufate": "tartufare",
    "tartufati": "tartufare",
    "tartufato": "tartufare",
    "tartufava": "tartufare",
    "tartufavamo": "tartufare",
    "tartufavan": "tartufare",
    "tartufavano": "tartufare",
    "tartufavate": "tartufare",
    "tartufavi": "tartufare",
    "tartufavo": "tartufare",
    "tartuferai": "tartufare",
    "tartuferan": "tartufare",
    "tartuferanno": "tartufare",
    "tartuferebbe": "tartufare",
    "tartuferebber": "tartufare",
    "tartuferebbero": "tartufare",
    "tartuferei": "tartufare",
    "tartuferemmo": "tartufare",
    "tartuferemo": "tartufare",
    "tartufereste": "tartufare",
    "tartuferesti": "tartufare",
    "tartuferete": "tartufare",
    "tartuferà": "tartufare",
    "tartuferò": "tartufare",
    "tartufi": "tartufo",
    "tartufiamo": "tartufare",
    "tartufiate": "tartufare",
    "tartufin": "tartufare",
    "tartufino": "tartufare",
    "tartufo": "tartufare",
    "tartufò": "tartufare",
    "tarò": "tarare",
    "tascabili": "tascabile",
    "tasche": "tasca",
    "taschini": "taschino",
    "task-forces": "task-force",
    "tassa": "tassare",
    "tassabili": "tassabile",
    "tassai": "tassare",
    "tassametri": "tassametro",
    "tassammo": "tassare",
    "tassan": "tassare",
    "tassando": "tassare",
    "tassano": "tassare",
    "tassante": "tassare",
    "tassanti": "tassare",
    "tassar": "tassare",
    "tassaron": "tassare",
    "tassarono": "tassare",
    "tassasse": "tassare",
    "tassasser": "tassare",
    "tassassero": "tassare",
    "tassassi": "tassare",
    "tassassimo": "tassare",
    "tassaste": "tassare",
    "tassasti": "tassare",
    "tassata": "tassare",
    "tassate": "tassare",
    "tassati": "tassare",
    "tassativa": "tassativo",
    "tassative": "tassativo",
    "tassativi": "tassativo",
    "tassato": "tassare",
    "tassava": "tassare",
    "tassavamo": "tassare",
    "tassavan": "tassare",
    "tassavano": "tassare",
    "tassavate": "tassare",
    "tassavi": "tassare",
    "tassavo": "tassare",
    "tassazioni": "tassazione",
    "tasse": "tassa",
    "tasselli": "tassello",
    "tasserai": "tassare",
    "tasseran": "tassare",
    "tasseranno": "tassare",
    "tasserebbe": "tassare",
    "tasserebber": "tassare",
    "tasserebbero": "tassare",
    "tasserei": "tassare",
    "tasseremmo": "tassare",
    "tasseremo": "tassare",
    "tassereste": "tassare",
    "tasseresti": "tassare",
    "tasserete": "tassare",
    "tasserà": "tassare",
    "tasserò": "tassare",
    "tassi": "tasso",
    "tassiamo": "tassare",
    "tassiate": "tassare",
    "tassin": "tassare",
    "tassinari": "tassinaro",
    "tassino": "tassare",
    "tassisti": "tassista",
    "tasso": "tassare",
    "tassò": "tassare",
    "tasta": "tastare",
    "tastai": "tastare",
    "tastammo": "tastare",
    "tastan": "tastare",
    "tastando": "tastare",
    "tastano": "tastare",
    "tastante": "tastare",
    "tastanti": "tastare",
    "tastar": "tastare",
    "tastaron": "tastare",
    "tastarono": "tastare",
    "tastasse": "tastare",
    "tastasser": "tastare",
    "tastassero": "tastare",
    "tastassi": "tastare",
    "tastassimo": "tastare",
    "tastaste": "tastare",
    "tastasti": "tastare",
    "tastata": "tastare",
    "tastate": "tastare",
    "tastati": "tastare",
    "tastato": "tastare",
    "tastava": "tastare",
    "tastavamo": "tastare",
    "tastavan": "tastare",
    "tastavano": "tastare",
    "tastavate": "tastare",
    "tastavi": "tastare",
    "tastavo": "tastare",
    "tasterai": "tastare",
    "tasteran": "tastare",
    "tasteranno": "tastare",
    "tasterebbe": "tastare",
    "tasterebber": "tastare",
    "tasterebbero": "tastare",
    "tasterei": "tastare",
    "tasteremmo": "tastare",
    "tasteremo": "tastare",
    "tastereste": "tastare",
    "tasteresti": "tastare",
    "tasterete": "tastare",
    "tasterà": "tastare",
    "tasterò": "tastare",
    "tasti": "tasto",
    "tastiamo": "tastare",
    "tastiate": "tastare",
    "tastiere": "tastiera",
    "tastieristi": "tastierista",
    "tastin": "tastare",
    "tastino": "tastare",
    "tasto": "tastare",
    "tastò": "tastare",
    "tate": "tata",
    "tatti": "tatto",
    "tattica": "tattico",
    "tattiche": "tattico",
    "tattici": "tattico",
    "tatticismi": "tatticismo",
    "tattili": "tattile",
    "tatua": "tatuare",
    "tatuaggi": "tatuaggio",
    "tatuai": "tatuare",
    "tatuammo": "tatuare",
    "tatuan": "tatuare",
    "tatuando": "tatuare",
    "tatuano": "tatuare",
    "tatuante": "tatuare",
    "tatuanti": "tatuare",
    "tatuar": "tatuare",
    "tatuaron": "tatuare",
    "tatuarono": "tatuare",
    "tatuasse": "tatuare",
    "tatuasser": "tatuare",
    "tatuassero": "tatuare",
    "tatuassi": "tatuare",
    "tatuassimo": "tatuare",
    "tatuaste": "tatuare",
    "tatuasti": "tatuare",
    "tatuata": "tatuare",
    "tatuate": "tatuare",
    "tatuati": "tatuare",
    "tatuato": "tatuare",
    "tatuava": "tatuare",
    "tatuavamo": "tatuare",
    "tatuavan": "tatuare",
    "tatuavano": "tatuare",
    "tatuavate": "tatuare",
    "tatuavi": "tatuare",
    "tatuavo": "tatuare",
    "tatuerai": "tatuare",
    "tatueran": "tatuare",
    "tatueranno": "tatuare",
    "tatuerebbe": "tatuare",
    "tatuerebber": "tatuare",
    "tatuerebbero": "tatuare",
    "tatuerei": "tatuare",
    "tatueremmo": "tatuare",
    "tatueremo": "tatuare",
    "tatuereste": "tatuare",
    "tatueresti": "tatuare",
    "tatuerete": "tatuare",
    "tatuerà": "tatuare",
    "tatuerò": "tatuare",
    "tatui": "tatuare",
    "tatuiamo": "tatuare",
    "tatuiate": "tatuare",
    "tatuin": "tatuare",
    "tatuino": "tatuare",
    "tatuo": "tatuare",
    "tatuò": "tatuare",
    "taumaturghi": "taumaturgo",
    "taumaturgica": "taumaturgico",
    "taumaturgiche": "taumaturgico",
    "taumaturgici": "taumaturgico",
    "taurina": "taurino",
    "taurine": "taurino",
    "taurini": "taurino",
    "tautologica": "tautologico",
    "tautologiche": "tautologico",
    "tautologici": "tautologico",
    "tautologie": "tautologia",
    "tavolacci": "tavolaccio",
    "tavolate": "tavolata",
    "tavole": "tavola",
    "tavolette": "tavoletta",
    "tavoli": "tavolo",
    "tavolinetti": "tavolinetto",
    "tavolini": "tavolino",
    "tavoloni": "tavolone",
    "tavolozze": "tavolozza",
    "taxisti": "taxista",
    "tazze": "tazza",
    "tazzine": "tazzina",
    "teatrali": "teatrale",
    "teatranti": "teatrante",
    "teatri": "teatro",
    "teatridanza": "teatrodanza",
    "teatrini": "teatrino",
    "teche": "teca",
    "techna": "techno",
    "techne": "techno",
    "techni": "techno",
    "tecnica": "tecnico",
    "tecniche": "tecnico",
    "tecnici": "tecnico",
    "tecnicismi": "tecnicismo",
    "tecnicizza": "tecnicizzare",
    "tecnicizzai": "tecnicizzare",
    "tecnicizzammo": "tecnicizzare",
    "tecnicizzan": "tecnicizzare",
    "tecnicizzando": "tecnicizzare",
    "tecnicizzano": "tecnicizzare",
    "tecnicizzante": "tecnicizzare",
    "tecnicizzanti": "tecnicizzare",
    "tecnicizzar": "tecnicizzare",
    "tecnicizzaron": "tecnicizzare",
    "tecnicizzarono": "tecnicizzare",
    "tecnicizzasse": "tecnicizzare",
    "tecnicizzasser": "tecnicizzare",
    "tecnicizzassero": "tecnicizzare",
    "tecnicizzassi": "tecnicizzare",
    "tecnicizzassimo": "tecnicizzare",
    "tecnicizzaste": "tecnicizzare",
    "tecnicizzasti": "tecnicizzare",
    "tecnicizzata": "tecnicizzare",
    "tecnicizzate": "tecnicizzare",
    "tecnicizzati": "tecnicizzare",
    "tecnicizzato": "tecnicizzare",
    "tecnicizzava": "tecnicizzare",
    "tecnicizzavamo": "tecnicizzare",
    "tecnicizzavan": "tecnicizzare",
    "tecnicizzavano": "tecnicizzare",
    "tecnicizzavate": "tecnicizzare",
    "tecnicizzavi": "tecnicizzare",
    "tecnicizzavo": "tecnicizzare",
    "tecnicizzerai": "tecnicizzare",
    "tecnicizzeran": "tecnicizzare",
    "tecnicizzeranno": "tecnicizzare",
    "tecnicizzerebbe": "tecnicizzare",
    "tecnicizzerebber": "tecnicizzare",
    "tecnicizzerebbero": "tecnicizzare",
    "tecnicizzerei": "tecnicizzare",
    "tecnicizzeremmo": "tecnicizzare",
    "tecnicizzeremo": "tecnicizzare",
    "tecnicizzereste": "tecnicizzare",
    "tecnicizzeresti": "tecnicizzare",
    "tecnicizzerete": "tecnicizzare",
    "tecnicizzerà": "tecnicizzare",
    "tecnicizzerò": "tecnicizzare",
    "tecnicizzi": "tecnicizzare",
    "tecnicizziamo": "tecnicizzare",
    "tecnicizziate": "tecnicizzare",
    "tecnicizzin": "tecnicizzare",
    "tecnicizzino": "tecnicizzare",
    "tecnicizzo": "tecnicizzare",
    "tecnicizzò": "tecnicizzare",
    "tecnico-amministrativa": "tecnico-amministrativo",
    "tecnico-amministrative": "tecnico-amministrativo",
    "tecnico-amministrativi": "tecnico-amministrativo",
    "tecnico-giuridica": "tecnico-giuridico",
    "tecnico-giuridiche": "tecnico-giuridico",
    "tecnico-giuridici": "tecnico-giuridico",
    "tecnico-scientifica": "tecnico-scientifico",
    "tecnico-scientifiche": "tecnico-scientifico",
    "tecnico-scientifici": "tecnico-scientifico",
    "tecnico-tattica": "tecnico-tattico",
    "tecnico-tattiche": "tecnico-tattico",
    "tecnico-tattici": "tecnico-tattico",
    "tecnocrati": "tecnocrate",
    "tecnocrazie": "tecnocrazia",
    "tecnologi": "tecnologo",
    "tecnologica": "tecnologico",
    "tecnologiche": "tecnologico",
    "tecnologici": "tecnologico",
    "tecnologie": "tecnologia",
    "tecnostrutture": "tecnostruttura",
    "teconologie": "teconologia",
    "tedesca": "tedesco",
    "tedesche": "tedesco",
    "tedeschi": "tedesco",
    "tedesco-federali": "tedesco-federale",
    "tedesco-occidentali": "tedesco-occidentale",
    "tedesco-orientali": "tedesco-orientale",
    "tedesconi": "tedescone",
    "tedi": "tediare",
    "tedia": "tediare",
    "tediai": "tediare",
    "tediammo": "tediare",
    "tediamo": "tediare",
    "tedian": "tediare",
    "tediando": "tediare",
    "tediano": "tediare",
    "tediante": "tediare",
    "tedianti": "tediare",
    "tediar": "tediare",
    "tediaron": "tediare",
    "tediarono": "tediare",
    "tediasse": "tediare",
    "tediasser": "tediare",
    "tediassero": "tediare",
    "tediassi": "tediare",
    "tediassimo": "tediare",
    "tediaste": "tediare",
    "tediasti": "tediare",
    "tediata": "tediare",
    "tediate": "tediare",
    "tediati": "tediare",
    "tediato": "tediare",
    "tediava": "tediare",
    "tediavamo": "tediare",
    "tediavan": "tediare",
    "tediavano": "tediare",
    "tediavate": "tediare",
    "tediavi": "tediare",
    "tediavo": "tediare",
    "tedierai": "tediare",
    "tedieran": "tediare",
    "tedieranno": "tediare",
    "tedierebbe": "tediare",
    "tedierebber": "tediare",
    "tedierebbero": "tediare",
    "tedierei": "tediare",
    "tedieremmo": "tediare",
    "tedieremo": "tediare",
    "tediereste": "tediare",
    "tedieresti": "tediare",
    "tedierete": "tediare",
    "tedierà": "tediare",
    "tedierò": "tediare",
    "tedii": "tedio",
    "tedin": "tediare",
    "tedino": "tediare",
    "tedio": "tediare",
    "tediosa": "tedioso",
    "tediose": "tedioso",
    "tediosi": "tedioso",
    "tediò": "tediare",
    "tedofori": "tedoforo",
    "teen-agers": "teen-ager",
    "teenagers": "teenager",
    "tegami": "tegame",
    "tegole": "tegola",
    "teiere": "teiera",
    "telai": "telaio",
    "tele": "tela",
    "telecamere": "telecamera",
    "telecomanda": "telecomandare",
    "telecomandai": "telecomandare",
    "telecomandammo": "telecomandare",
    "telecomandan": "telecomandare",
    "telecomandando": "telecomandare",
    "telecomandano": "telecomandare",
    "telecomandante": "telecomandare",
    "telecomandanti": "telecomandare",
    "telecomandar": "telecomandare",
    "telecomandaron": "telecomandare",
    "telecomandarono": "telecomandare",
    "telecomandasse": "telecomandare",
    "telecomandasser": "telecomandare",
    "telecomandassero": "telecomandare",
    "telecomandassi": "telecomandare",
    "telecomandassimo": "telecomandare",
    "telecomandaste": "telecomandare",
    "telecomandasti": "telecomandare",
    "telecomandata": "telecomandato",
    "telecomandate": "telecomandato",
    "telecomandati": "telecomandato",
    "telecomandato": "telecomandare",
    "telecomandava": "telecomandare",
    "telecomandavamo": "telecomandare",
    "telecomandavan": "telecomandare",
    "telecomandavano": "telecomandare",
    "telecomandavate": "telecomandare",
    "telecomandavi": "telecomandare",
    "telecomandavo": "telecomandare",
    "telecomanderai": "telecomandare",
    "telecomanderan": "telecomandare",
    "telecomanderanno": "telecomandare",
    "telecomanderebbe": "telecomandare",
    "telecomanderebber": "telecomandare",
    "telecomanderebbero": "telecomandare",
    "telecomanderei": "telecomandare",
    "telecomanderemmo": "telecomandare",
    "telecomanderemo": "telecomandare",
    "telecomandereste": "telecomandare",
    "telecomanderesti": "telecomandare",
    "telecomanderete": "telecomandare",
    "telecomanderà": "telecomandare",
    "telecomanderò": "telecomandare",
    "telecomandi": "telecomando",
    "telecomandiamo": "telecomandare",
    "telecomandiate": "telecomandare",
    "telecomandin": "telecomandare",
    "telecomandino": "telecomandare",
    "telecomando": "telecomandare",
    "telecomandò": "telecomandare",
    "telecomunica": "telecomunicare",
    "telecomunicai": "telecomunicare",
    "telecomunicammo": "telecomunicare",
    "telecomunican": "telecomunicare",
    "telecomunicando": "telecomunicare",
    "telecomunicano": "telecomunicare",
    "telecomunicante": "telecomunicare",
    "telecomunicanti": "telecomunicare",
    "telecomunicar": "telecomunicare",
    "telecomunicaron": "telecomunicare",
    "telecomunicarono": "telecomunicare",
    "telecomunicasse": "telecomunicare",
    "telecomunicasser": "telecomunicare",
    "telecomunicassero": "telecomunicare",
    "telecomunicassi": "telecomunicare",
    "telecomunicassimo": "telecomunicare",
    "telecomunicaste": "telecomunicare",
    "telecomunicasti": "telecomunicare",
    "telecomunicata": "telecomunicare",
    "telecomunicate": "telecomunicare",
    "telecomunicati": "telecomunicare",
    "telecomunicato": "telecomunicare",
    "telecomunicava": "telecomunicare",
    "telecomunicavamo": "telecomunicare",
    "telecomunicavan": "telecomunicare",
    "telecomunicavano": "telecomunicare",
    "telecomunicavate": "telecomunicare",
    "telecomunicavi": "telecomunicare",
    "telecomunicavo": "telecomunicare",
    "telecomunicazioni": "telecomunicazione",
    "telecomunicherai": "telecomunicare",
    "telecomunicheran": "telecomunicare",
    "telecomunicheranno": "telecomunicare",
    "telecomunicherebbe": "telecomunicare",
    "telecomunicherebber": "telecomunicare",
    "telecomunicherebbero": "telecomunicare",
    "telecomunicherei": "telecomunicare",
    "telecomunicheremmo": "telecomunicare",
    "telecomunicheremo": "telecomunicare",
    "telecomunichereste": "telecomunicare",
    "telecomunicheresti": "telecomunicare",
    "telecomunicherete": "telecomunicare",
    "telecomunicherà": "telecomunicare",
    "telecomunicherò": "telecomunicare",
    "telecomunichi": "telecomunicare",
    "telecomunichiamo": "telecomunicare",
    "telecomunichiate": "telecomunicare",
    "telecomunichin": "telecomunicare",
    "telecomunichino": "telecomunicare",
    "telecomunico": "telecomunicare",
    "telecomunicò": "telecomunicare",
    "teleconferenze": "teleconferenza",
    "telecrazie": "telecrazia",
    "telecronache": "telecronaca",
    "telecronisti": "telecronista",
    "teledipendenti": "teledipendente",
    "teledivi": "teledivo",
    "telefinanzieri": "telefinanziere",
    "telefona": "telefonare",
    "telefonai": "telefonare",
    "telefonammo": "telefonare",
    "telefonan": "telefonare",
    "telefonando": "telefonare",
    "telefonano": "telefonare",
    "telefonante": "telefonare",
    "telefonanti": "telefonare",
    "telefonar": "telefonare",
    "telefonaron": "telefonare",
    "telefonarono": "telefonare",
    "telefonasse": "telefonare",
    "telefonasser": "telefonare",
    "telefonassero": "telefonare",
    "telefonassi": "telefonare",
    "telefonassimo": "telefonare",
    "telefonaste": "telefonare",
    "telefonasti": "telefonare",
    "telefonata": "telefonare",
    "telefonate": "telefonata",
    "telefonati": "telefonare",
    "telefonato": "telefonare",
    "telefonava": "telefonare",
    "telefonavamo": "telefonare",
    "telefonavan": "telefonare",
    "telefonavano": "telefonare",
    "telefonavate": "telefonare",
    "telefonavi": "telefonare",
    "telefonavo": "telefonare",
    "telefonerai": "telefonare",
    "telefoneran": "telefonare",
    "telefoneranno": "telefonare",
    "telefonerebbe": "telefonare",
    "telefonerebber": "telefonare",
    "telefonerebbero": "telefonare",
    "telefonerei": "telefonare",
    "telefoneremmo": "telefonare",
    "telefoneremo": "telefonare",
    "telefonereste": "telefonare",
    "telefoneresti": "telefonare",
    "telefonerete": "telefonare",
    "telefonerà": "telefonare",
    "telefonerò": "telefonare",
    "telefoni": "telefono",
    "telefoniamo": "telefonare",
    "telefoniate": "telefonare",
    "telefonica": "telefonico",
    "telefoniche": "telefonico",
    "telefonici": "telefonico",
    "telefonie": "telefonia",
    "telefonin": "telefonare",
    "telefonini": "telefonino",
    "telefonino": "telefonare",
    "telefoniste": "telefonista",
    "telefonisti": "telefonista",
    "telefono": "telefonare",
    "telefonò": "telefonare",
    "telegenica": "telegenico",
    "telegeniche": "telegenico",
    "telegenici": "telegenico",
    "telegiornali": "telegiornale",
    "telegiornaliste": "telegiornalista",
    "telegiornalisti": "telegiornalista",
    "telegrafa": "telegrafare",
    "telegrafai": "telegrafare",
    "telegrafammo": "telegrafare",
    "telegrafan": "telegrafare",
    "telegrafando": "telegrafare",
    "telegrafano": "telegrafare",
    "telegrafante": "telegrafare",
    "telegrafanti": "telegrafare",
    "telegrafar": "telegrafare",
    "telegrafaron": "telegrafare",
    "telegrafarono": "telegrafare",
    "telegrafasse": "telegrafare",
    "telegrafasser": "telegrafare",
    "telegrafassero": "telegrafare",
    "telegrafassi": "telegrafare",
    "telegrafassimo": "telegrafare",
    "telegrafaste": "telegrafare",
    "telegrafasti": "telegrafare",
    "telegrafata": "telegrafare",
    "telegrafate": "telegrafare",
    "telegrafati": "telegrafare",
    "telegrafato": "telegrafare",
    "telegrafava": "telegrafare",
    "telegrafavamo": "telegrafare",
    "telegrafavan": "telegrafare",
    "telegrafavano": "telegrafare",
    "telegrafavate": "telegrafare",
    "telegrafavi": "telegrafare",
    "telegrafavo": "telegrafare",
    "telegraferai": "telegrafare",
    "telegraferan": "telegrafare",
    "telegraferanno": "telegrafare",
    "telegraferebbe": "telegrafare",
    "telegraferebber": "telegrafare",
    "telegraferebbero": "telegrafare",
    "telegraferei": "telegrafare",
    "telegraferemmo": "telegrafare",
    "telegraferemo": "telegrafare",
    "telegrafereste": "telegrafare",
    "telegraferesti": "telegrafare",
    "telegraferete": "telegrafare",
    "telegraferà": "telegrafare",
    "telegraferò": "telegrafare",
    "telegrafi": "telegrafo",
    "telegrafiamo": "telegrafare",
    "telegrafiate": "telegrafare",
    "telegrafica": "telegrafico",
    "telegrafiche": "telegrafico",
    "telegrafici": "telegrafico",
    "telegrafin": "telegrafare",
    "telegrafino": "telegrafare",
    "telegrafo": "telegrafare",
    "telegrafò": "telegrafare",
    "telegrammi": "telegramma",
    "teleguida": "teleguidare",
    "teleguidai": "teleguidare",
    "teleguidammo": "teleguidare",
    "teleguidan": "teleguidare",
    "teleguidando": "teleguidare",
    "teleguidano": "teleguidare",
    "teleguidante": "teleguidare",
    "teleguidanti": "teleguidare",
    "teleguidar": "teleguidare",
    "teleguidaron": "teleguidare",
    "teleguidarono": "teleguidare",
    "teleguidasse": "teleguidare",
    "teleguidasser": "teleguidare",
    "teleguidassero": "teleguidare",
    "teleguidassi": "teleguidare",
    "teleguidassimo": "teleguidare",
    "teleguidaste": "teleguidare",
    "teleguidasti": "teleguidare",
    "teleguidata": "teleguidato",
    "teleguidate": "teleguidato",
    "teleguidati": "teleguidato",
    "teleguidato": "teleguidare",
    "teleguidava": "teleguidare",
    "teleguidavamo": "teleguidare",
    "teleguidavan": "teleguidare",
    "teleguidavano": "teleguidare",
    "teleguidavate": "teleguidare",
    "teleguidavi": "teleguidare",
    "teleguidavo": "teleguidare",
    "teleguiderai": "teleguidare",
    "teleguideran": "teleguidare",
    "teleguideranno": "teleguidare",
    "teleguiderebbe": "teleguidare",
    "teleguiderebber": "teleguidare",
    "teleguiderebbero": "teleguidare",
    "teleguiderei": "teleguidare",
    "teleguideremmo": "teleguidare",
    "teleguideremo": "teleguidare",
    "teleguidereste": "teleguidare",
    "teleguideresti": "teleguidare",
    "teleguiderete": "teleguidare",
    "teleguiderà": "teleguidare",
    "teleguiderò": "teleguidare",
    "teleguidi": "teleguidare",
    "teleguidiamo": "teleguidare",
    "teleguidiate": "teleguidare",
    "teleguidin": "teleguidare",
    "teleguidino": "teleguidare",
    "teleguido": "teleguidare",
    "teleguidò": "teleguidare",
    "teleimbonitori": "teleimbonitore",
    "telelavora": "telelavorare",
    "telelavorai": "telelavorare",
    "telelavorammo": "telelavorare",
    "telelavoran": "telelavorare",
    "telelavorando": "telelavorare",
    "telelavorano": "telelavorare",
    "telelavorante": "telelavorare",
    "telelavoranti": "telelavorare",
    "telelavorar": "telelavorare",
    "telelavoraron": "telelavorare",
    "telelavorarono": "telelavorare",
    "telelavorasse": "telelavorare",
    "telelavorasser": "telelavorare",
    "telelavorassero": "telelavorare",
    "telelavorassi": "telelavorare",
    "telelavorassimo": "telelavorare",
    "telelavoraste": "telelavorare",
    "telelavorasti": "telelavorare",
    "telelavorata": "telelavorare",
    "telelavorate": "telelavorare",
    "telelavorati": "telelavorare",
    "telelavorato": "telelavorare",
    "telelavorava": "telelavorare",
    "telelavoravamo": "telelavorare",
    "telelavoravan": "telelavorare",
    "telelavoravano": "telelavorare",
    "telelavoravate": "telelavorare",
    "telelavoravi": "telelavorare",
    "telelavoravo": "telelavorare",
    "telelavorerai": "telelavorare",
    "telelavoreran": "telelavorare",
    "telelavoreranno": "telelavorare",
    "telelavorerebbe": "telelavorare",
    "telelavorerebber": "telelavorare",
    "telelavorerebbero": "telelavorare",
    "telelavorerei": "telelavorare",
    "telelavoreremmo": "telelavorare",
    "telelavoreremo": "telelavorare",
    "telelavorereste": "telelavorare",
    "telelavoreresti": "telelavorare",
    "telelavorerete": "telelavorare",
    "telelavorerà": "telelavorare",
    "telelavorerò": "telelavorare",
    "telelavori": "telelavoro",
    "telelavoriamo": "telelavorare",
    "telelavoriate": "telelavorare",
    "telelavorin": "telelavorare",
    "telelavorino": "telelavorare",
    "telelavoro": "telelavorare",
    "telelavorò": "telelavorare",
    "telematica": "telematico",
    "telematiche": "telematico",
    "telematici": "telematico",
    "telemetrie": "telemetria",
    "telenovelas": "telenovela",
    "telenovele": "telenovela",
    "teleobiettivi": "teleobiettivo",
    "teleoperatori": "teleoperatore",
    "telepatica": "telepatico",
    "telepatiche": "telepatico",
    "telepatici": "telepatico",
    "teleporti": "teleporto",
    "telepredicatori": "telepredicatore",
    "telepromozioni": "telepromozione",
    "teleromanzi": "teleromanzo",
    "teleschermi": "teleschermo",
    "telescopi": "telescopio",
    "telescopica": "telescopico",
    "telescopiche": "telescopico",
    "telescopici": "telescopico",
    "telescriventi": "telescrivente",
    "teleselezioni": "teleselezione",
    "telespettatori": "telespettatore",
    "telespettatrici": "telespettatrice",
    "teletrasmessa": "teletrasmettere",
    "teletrasmesse": "teletrasmettere",
    "teletrasmessi": "teletrasmettere",
    "teletrasmesso": "teletrasmettere",
    "teletrasmetta": "teletrasmettere",
    "teletrasmettan": "teletrasmettere",
    "teletrasmettano": "teletrasmettere",
    "teletrasmette": "teletrasmettere",
    "teletrasmettemmo": "teletrasmettere",
    "teletrasmettendo": "teletrasmettere",
    "teletrasmettente": "teletrasmettere",
    "teletrasmettenti": "teletrasmettere",
    "teletrasmetter": "teletrasmettere",
    "teletrasmetterai": "teletrasmettere",
    "teletrasmetteran": "teletrasmettere",
    "teletrasmetteranno": "teletrasmettere",
    "teletrasmetterebbe": "teletrasmettere",
    "teletrasmetterebber": "teletrasmettere",
    "teletrasmetterebbero": "teletrasmettere",
    "teletrasmetterei": "teletrasmettere",
    "teletrasmetteremmo": "teletrasmettere",
    "teletrasmetteremo": "teletrasmettere",
    "teletrasmettereste": "teletrasmettere",
    "teletrasmetteresti": "teletrasmettere",
    "teletrasmetterete": "teletrasmettere",
    "teletrasmetterà": "teletrasmettere",
    "teletrasmetterò": "teletrasmettere",
    "teletrasmettesse": "teletrasmettere",
    "teletrasmettesser": "teletrasmettere",
    "teletrasmettessero": "teletrasmettere",
    "teletrasmettessi": "teletrasmettere",
    "teletrasmettessimo": "teletrasmettere",
    "teletrasmetteste": "teletrasmettere",
    "teletrasmettesti": "teletrasmettere",
    "teletrasmettete": "teletrasmettere",
    "teletrasmetteva": "teletrasmettere",
    "teletrasmettevamo": "teletrasmettere",
    "teletrasmettevan": "teletrasmettere",
    "teletrasmettevano": "teletrasmettere",
    "teletrasmettevate": "teletrasmettere",
    "teletrasmettevi": "teletrasmettere",
    "teletrasmettevo": "teletrasmettere",
    "teletrasmetti": "teletrasmettere",
    "teletrasmettiamo": "teletrasmettere",
    "teletrasmettiate": "teletrasmettere",
    "teletrasmetto": "teletrasmettere",
    "teletrasmetton": "teletrasmettere",
    "teletrasmettono": "teletrasmettere",
    "teletrasmise": "teletrasmettere",
    "teletrasmiser": "teletrasmettere",
    "teletrasmisero": "teletrasmettere",
    "teletrasmisi": "teletrasmettere",
    "teletrasmissioni": "teletrasmissione",
    "teleutenti": "teleutente",
    "televendite": "televendita",
    "televisioni": "televisione",
    "televisiva": "televisivo",
    "televisive": "televisivo",
    "televisivi": "televisivo",
    "televisori": "televisore",
    "televisorini": "televisorino",
    "televoti": "televoto",
    "teli": "telo",
    "tellurica": "tellurico",
    "telluriche": "tellurico",
    "tellurici": "tellurico",
    "teloni": "telone",
    "tema": "temere",
    "teman": "temere",
    "temano": "temere",
    "tematica": "tematico",
    "tematiche": "tematico",
    "tematici": "tematico",
    "teme": "temere",
    "temei": "temere",
    "tememmo": "temere",
    "temendo": "temere",
    "temente": "temere",
    "tementi": "temere",
    "temer": "temere",
    "temerai": "temere",
    "temeran": "temere",
    "temeranno": "temere",
    "temerari": "temerario",
    "temeraria": "temerario",
    "temerarie": "temerario",
    "temerebbe": "temere",
    "temerebber": "temere",
    "temerebbero": "temere",
    "temerei": "temere",
    "temeremmo": "temere",
    "temeremo": "temere",
    "temereste": "temere",
    "temeresti": "temere",
    "temerete": "temere",
    "temeron": "temere",
    "temerono": "temere",
    "temerà": "temere",
    "temerò": "temere",
    "temesse": "temere",
    "temesser": "temere",
    "temessero": "temere",
    "temessi": "temere",
    "temessimo": "temere",
    "temeste": "temere",
    "temesti": "temere",
    "temete": "temere",
    "temeva": "temere",
    "temevamo": "temere",
    "temevan": "temere",
    "temevano": "temere",
    "temevate": "temere",
    "temevi": "temere",
    "temevo": "temere",
    "temi": "temere",
    "temiamo": "temere",
    "temiate": "temere",
    "temibili": "temibile",
    "temini": "temino",
    "temo": "temere",
    "temon": "temere",
    "temono": "temere",
    "tempera": "temperare",
    "temperai": "temperare",
    "temperamenti": "temperamento",
    "temperammo": "temperare",
    "temperan": "temperare",
    "temperando": "temperare",
    "temperano": "temperare",
    "temperante": "temperare",
    "temperanti": "temperare",
    "temperar": "temperare",
    "temperaron": "temperare",
    "temperarono": "temperare",
    "temperasse": "temperare",
    "temperasser": "temperare",
    "temperassero": "temperare",
    "temperassi": "temperare",
    "temperassimo": "temperare",
    "temperaste": "temperare",
    "temperasti": "temperare",
    "temperata": "temperato",
    "temperate": "temperato",
    "temperati": "temperato",
    "temperato": "temperare",
    "temperature": "temperatura",
    "temperava": "temperare",
    "temperavamo": "temperare",
    "temperavan": "temperare",
    "temperavano": "temperare",
    "temperavate": "temperare",
    "temperavi": "temperare",
    "temperavo": "temperare",
    "tempere": "tempera",
    "tempererai": "temperare",
    "tempereran": "temperare",
    "tempereranno": "temperare",
    "tempererebbe": "temperare",
    "tempererebber": "temperare",
    "tempererebbero": "temperare",
    "tempererei": "temperare",
    "tempereremmo": "temperare",
    "tempereremo": "temperare",
    "temperereste": "temperare",
    "tempereresti": "temperare",
    "tempererete": "temperare",
    "tempererà": "temperare",
    "tempererò": "temperare",
    "temperi": "temperare",
    "temperiamo": "temperare",
    "temperiate": "temperare",
    "temperin": "temperare",
    "temperini": "temperino",
    "temperino": "temperare",
    "tempero": "temperare",
    "temperò": "temperare",
    "tempesta": "tempestare",
    "tempestai": "tempestare",
    "tempestammo": "tempestare",
    "tempestan": "tempestare",
    "tempestando": "tempestare",
    "tempestano": "tempestare",
    "tempestante": "tempestare",
    "tempestanti": "tempestare",
    "tempestar": "tempestare",
    "tempestaron": "tempestare",
    "tempestarono": "tempestare",
    "tempestasse": "tempestare",
    "tempestasser": "tempestare",
    "tempestassero": "tempestare",
    "tempestassi": "tempestare",
    "tempestassimo": "tempestare",
    "tempestaste": "tempestare",
    "tempestasti": "tempestare",
    "tempestata": "tempestare",
    "tempestate": "tempestare",
    "tempestati": "tempestare",
    "tempestato": "tempestare",
    "tempestava": "tempestare",
    "tempestavamo": "tempestare",
    "tempestavan": "tempestare",
    "tempestavano": "tempestare",
    "tempestavate": "tempestare",
    "tempestavi": "tempestare",
    "tempestavo": "tempestare",
    "tempeste": "tempesta",
    "tempesterai": "tempestare",
    "tempesteran": "tempestare",
    "tempesteranno": "tempestare",
    "tempesterebbe": "tempestare",
    "tempesterebber": "tempestare",
    "tempesterebbero": "tempestare",
    "tempesterei": "tempestare",
    "tempesteremmo": "tempestare",
    "tempesteremo": "tempestare",
    "tempestereste": "tempestare",
    "tempesteresti": "tempestare",
    "tempesterete": "tempestare",
    "tempesterà": "tempestare",
    "tempesterò": "tempestare",
    "tempesti": "tempestare",
    "tempestiamo": "tempestare",
    "tempestiate": "tempestare",
    "tempestin": "tempestare",
    "tempestino": "tempestare",
    "tempestiva": "tempestivo",
    "tempestive": "tempestivo",
    "tempestivi": "tempestivo",
    "tempesto": "tempestare",
    "tempestosa": "tempestoso",
    "tempestose": "tempestoso",
    "tempestosi": "tempestoso",
    "tempestò": "tempestare",
    "tempi": "tempo",
    "tempie": "tempia",
    "tempietti": "tempietto",
    "tempismi": "tempismo",
    "tempistiche": "tempistica",
    "templa": "templare",
    "templai": "templare",
    "templammo": "templare",
    "templan": "templare",
    "templando": "templare",
    "templano": "templare",
    "templante": "templare",
    "templanti": "templare",
    "templar": "templare",
    "templaron": "templare",
    "templarono": "templare",
    "templasse": "templare",
    "templasser": "templare",
    "templassero": "templare",
    "templassi": "templare",
    "templassimo": "templare",
    "templaste": "templare",
    "templasti": "templare",
    "templata": "templare",
    "template": "templare",
    "templati": "templare",
    "templato": "templare",
    "templava": "templare",
    "templavamo": "templare",
    "templavan": "templare",
    "templavano": "templare",
    "templavate": "templare",
    "templavi": "templare",
    "templavo": "templare",
    "templerai": "templare",
    "templeran": "templare",
    "templeranno": "templare",
    "templerebbe": "templare",
    "templerebber": "templare",
    "templerebbero": "templare",
    "templerei": "templare",
    "templeremmo": "templare",
    "templeremo": "templare",
    "templereste": "templare",
    "templeresti": "templare",
    "templerete": "templare",
    "templerà": "templare",
    "templerò": "templare",
    "templi": "templare",
    "templiamo": "templare",
    "templiate": "templare",
    "templin": "templare",
    "templino": "templare",
    "templo": "templare",
    "templò": "templare",
    "temporalesca": "temporalesco",
    "temporalesche": "temporalesco",
    "temporaleschi": "temporalesco",
    "temporali": "temporale",
    "temporanea": "temporaneo",
    "temporanee": "temporaneo",
    "temporanei": "temporaneo",
    "temporeggerai": "temporeggiare",
    "temporeggeran": "temporeggiare",
    "temporeggeranno": "temporeggiare",
    "temporeggerebbe": "temporeggiare",
    "temporeggerebber": "temporeggiare",
    "temporeggerebbero": "temporeggiare",
    "temporeggerei": "temporeggiare",
    "temporeggeremmo": "temporeggiare",
    "temporeggeremo": "temporeggiare",
    "temporeggereste": "temporeggiare",
    "temporeggeresti": "temporeggiare",
    "temporeggerete": "temporeggiare",
    "temporeggerà": "temporeggiare",
    "temporeggerò": "temporeggiare",
    "temporeggi": "temporeggiare",
    "temporeggia": "temporeggiare",
    "temporeggiai": "temporeggiare",
    "temporeggiamenti": "temporeggiamento",
    "temporeggiammo": "temporeggiare",
    "temporeggiamo": "temporeggiare",
    "temporeggian": "temporeggiare",
    "temporeggiando": "temporeggiare",
    "temporeggiano": "temporeggiare",
    "temporeggiante": "temporeggiare",
    "temporeggianti": "temporeggiare",
    "temporeggiar": "temporeggiare",
    "temporeggiaron": "temporeggiare",
    "temporeggiarono": "temporeggiare",
    "temporeggiasse": "temporeggiare",
    "temporeggiasser": "temporeggiare",
    "temporeggiassero": "temporeggiare",
    "temporeggiassi": "temporeggiare",
    "temporeggiassimo": "temporeggiare",
    "temporeggiaste": "temporeggiare",
    "temporeggiasti": "temporeggiare",
    "temporeggiata": "temporeggiare",
    "temporeggiate": "temporeggiare",
    "temporeggiati": "temporeggiare",
    "temporeggiato": "temporeggiare",
    "temporeggiava": "temporeggiare",
    "temporeggiavamo": "temporeggiare",
    "temporeggiavan": "temporeggiare",
    "temporeggiavano": "temporeggiare",
    "temporeggiavate": "temporeggiare",
    "temporeggiavi": "temporeggiare",
    "temporeggiavo": "temporeggiare",
    "temporeggin": "temporeggiare",
    "temporeggino": "temporeggiare",
    "temporeggio": "temporeggiare",
    "temporeggiò": "temporeggiare",
    "tempra": "temprare",
    "temprai": "temprare",
    "temprammo": "temprare",
    "tempran": "temprare",
    "temprando": "temprare",
    "temprano": "temprare",
    "temprante": "temprare",
    "tempranti": "temprare",
    "temprar": "temprare",
    "tempraron": "temprare",
    "temprarono": "temprare",
    "temprasse": "temprare",
    "temprasser": "temprare",
    "temprassero": "temprare",
    "temprassi": "temprare",
    "temprassimo": "temprare",
    "tempraste": "temprare",
    "temprasti": "temprare",
    "temprata": "temprare",
    "temprate": "temprare",
    "temprati": "temprare",
    "temprato": "temprare",
    "temprava": "temprare",
    "tempravamo": "temprare",
    "tempravan": "temprare",
    "tempravano": "temprare",
    "tempravate": "temprare",
    "tempravi": "temprare",
    "tempravo": "temprare",
    "tempre": "tempra",
    "temprerai": "temprare",
    "tempreran": "temprare",
    "tempreranno": "temprare",
    "temprerebbe": "temprare",
    "temprerebber": "temprare",
    "temprerebbero": "temprare",
    "temprerei": "temprare",
    "tempreremmo": "temprare",
    "tempreremo": "temprare",
    "temprereste": "temprare",
    "tempreresti": "temprare",
    "temprerete": "temprare",
    "temprerà": "temprare",
    "temprerò": "temprare",
    "tempri": "temprare",
    "tempriamo": "temprare",
    "tempriate": "temprare",
    "temprin": "temprare",
    "temprino": "temprare",
    "tempro": "temprare",
    "temprò": "temprare",
    "temuta": "temuto",
    "temute": "temuto",
    "temuti": "temuto",
    "temuto": "temere",
    "temè": "temere",
    "tenaci": "tenace",
    "tenacie": "tenacia",
    "tenaglie": "tenaglia",
    "tenda": "tendere",
    "tendaggi": "tendaggio",
    "tendan": "tendere",
    "tendano": "tendere",
    "tende": "tendere",
    "tendemmo": "tendere",
    "tendendo": "tendere",
    "tendente": "tendere",
    "tendenti": "tendere",
    "tendenze": "tendenza",
    "tendenziali": "tendenziale",
    "tendenziosa": "tendenzioso",
    "tendenziose": "tendenzioso",
    "tendenziosi": "tendenzioso",
    "tender": "tendere",
    "tenderai": "tendere",
    "tenderan": "tendere",
    "tenderanno": "tendere",
    "tenderebbe": "tendere",
    "tenderebber": "tendere",
    "tenderebbero": "tendere",
    "tenderei": "tendere",
    "tenderemmo": "tendere",
    "tenderemo": "tendere",
    "tendereste": "tendere",
    "tenderesti": "tendere",
    "tenderete": "tendere",
    "tenderà": "tendere",
    "tenderò": "tendere",
    "tendesse": "tendere",
    "tendesser": "tendere",
    "tendessero": "tendere",
    "tendessi": "tendere",
    "tendessimo": "tendere",
    "tendeste": "tendere",
    "tendesti": "tendere",
    "tendete": "tendere",
    "tendeva": "tendere",
    "tendevamo": "tendere",
    "tendevan": "tendere",
    "tendevano": "tendere",
    "tendevate": "tendere",
    "tendevi": "tendere",
    "tendevo": "tendere",
    "tendi": "tendere",
    "tendiamo": "tendere",
    "tendiate": "tendere",
    "tendine": "tendina",
    "tendini": "tendine",
    "tendiniti": "tendinite",
    "tendo": "tendere",
    "tendon": "tendere",
    "tendoni": "tendone",
    "tendono": "tendere",
    "tenebre": "tenebra",
    "tenebrosa": "tenebroso",
    "tenebrose": "tenebroso",
    "tenebrosi": "tenebroso",
    "tenemmo": "tenere",
    "tenendo": "tenere",
    "tenente": "tenere",
    "tenenti": "tenere",
    "tener": "tenere",
    "tenera": "tenero",
    "tenere": "tenero",
    "tenerezze": "tenerezza",
    "teneri": "tenero",
    "tenesse": "tenere",
    "tenesser": "tenere",
    "tenessero": "tenere",
    "tenessi": "tenere",
    "tenessimo": "tenere",
    "teneste": "tenere",
    "tenesti": "tenere",
    "tenete": "tenere",
    "teneva": "tenere",
    "tenevamo": "tenere",
    "tenevan": "tenere",
    "tenevano": "tenere",
    "tenevate": "tenere",
    "tenevi": "tenere",
    "tenevo": "tenere",
    "tenga": "tenere",
    "tengan": "tenere",
    "tengano": "tenere",
    "tengo": "tenere",
    "tengon": "tenere",
    "tengono": "tenere",
    "teniamo": "tenere",
    "teniate": "tenere",
    "teniture": "tenitura",
    "tenne": "tenere",
    "tenner": "tenere",
    "tennero": "tenere",
    "tenni": "tenere",
    "tenniste": "tennista",
    "tennisti": "tennista",
    "tennistica": "tennistico",
    "tennistiche": "tennistico",
    "tennistici": "tennistico",
    "tenori": "tenore",
    "tenorili": "tenorile",
    "tenorini": "tenorino",
    "tensioni": "tensione",
    "tenta": "tentare",
    "tentacola": "tentacolare",
    "tentacolai": "tentacolare",
    "tentacolammo": "tentacolare",
    "tentacolan": "tentacolare",
    "tentacolando": "tentacolare",
    "tentacolano": "tentacolare",
    "tentacolante": "tentacolare",
    "tentacolanti": "tentacolare",
    "tentacolar": "tentacolare",
    "tentacolari": "tentacolare",
    "tentacolaron": "tentacolare",
    "tentacolarono": "tentacolare",
    "tentacolasse": "tentacolare",
    "tentacolasser": "tentacolare",
    "tentacolassero": "tentacolare",
    "tentacolassi": "tentacolare",
    "tentacolassimo": "tentacolare",
    "tentacolaste": "tentacolare",
    "tentacolasti": "tentacolare",
    "tentacolata": "tentacolare",
    "tentacolate": "tentacolare",
    "tentacolati": "tentacolare",
    "tentacolato": "tentacolare",
    "tentacolava": "tentacolare",
    "tentacolavamo": "tentacolare",
    "tentacolavan": "tentacolare",
    "tentacolavano": "tentacolare",
    "tentacolavate": "tentacolare",
    "tentacolavi": "tentacolare",
    "tentacolavo": "tentacolare",
    "tentacolerai": "tentacolare",
    "tentacoleran": "tentacolare",
    "tentacoleranno": "tentacolare",
    "tentacolerebbe": "tentacolare",
    "tentacolerebber": "tentacolare",
    "tentacolerebbero": "tentacolare",
    "tentacolerei": "tentacolare",
    "tentacoleremmo": "tentacolare",
    "tentacoleremo": "tentacolare",
    "tentacolereste": "tentacolare",
    "tentacoleresti": "tentacolare",
    "tentacolerete": "tentacolare",
    "tentacolerà": "tentacolare",
    "tentacolerò": "tentacolare",
    "tentacoli": "tentacolo",
    "tentacoliamo": "tentacolare",
    "tentacoliate": "tentacolare",
    "tentacolin": "tentacolare",
    "tentacolino": "tentacolare",
    "tentacolo": "tentacolare",
    "tentacolò": "tentacolare",
    "tentai": "tentare",
    "tentammo": "tentare",
    "tentan": "tentare",
    "tentando": "tentare",
    "tentano": "tentare",
    "tentante": "tentare",
    "tentanti": "tentare",
    "tentar": "tentare",
    "tentaron": "tentare",
    "tentarono": "tentare",
    "tentasse": "tentare",
    "tentasser": "tentare",
    "tentassero": "tentare",
    "tentassi": "tentare",
    "tentassimo": "tentare",
    "tentaste": "tentare",
    "tentasti": "tentare",
    "tentata": "tentare",
    "tentate": "tentare",
    "tentati": "tentare",
    "tentativi": "tentativo",
    "tentato": "tentare",
    "tentatori": "tentatore",
    "tentatrice": "tentatore",
    "tentatrici": "tentatore",
    "tentava": "tentare",
    "tentavamo": "tentare",
    "tentavan": "tentare",
    "tentavano": "tentare",
    "tentavate": "tentare",
    "tentavi": "tentare",
    "tentavo": "tentare",
    "tentazioni": "tentazione",
    "tentenna": "tentennare",
    "tentennai": "tentennare",
    "tentennamenti": "tentennamento",
    "tentennammo": "tentennare",
    "tentennan": "tentennare",
    "tentennando": "tentennare",
    "tentennano": "tentennare",
    "tentennante": "tentennare",
    "tentennanti": "tentennare",
    "tentennar": "tentennare",
    "tentennaron": "tentennare",
    "tentennarono": "tentennare",
    "tentennasse": "tentennare",
    "tentennasser": "tentennare",
    "tentennassero": "tentennare",
    "tentennassi": "tentennare",
    "tentennassimo": "tentennare",
    "tentennaste": "tentennare",
    "tentennasti": "tentennare",
    "tentennata": "tentennare",
    "tentennate": "tentennare",
    "tentennati": "tentennare",
    "tentennato": "tentennare",
    "tentennava": "tentennare",
    "tentennavamo": "tentennare",
    "tentennavan": "tentennare",
    "tentennavano": "tentennare",
    "tentennavate": "tentennare",
    "tentennavi": "tentennare",
    "tentennavo": "tentennare",
    "tentennerai": "tentennare",
    "tentenneran": "tentennare",
    "tentenneranno": "tentennare",
    "tentennerebbe": "tentennare",
    "tentennerebber": "tentennare",
    "tentennerebbero": "tentennare",
    "tentennerei": "tentennare",
    "tentenneremmo": "tentennare",
    "tentenneremo": "tentennare",
    "tentennereste": "tentennare",
    "tentenneresti": "tentennare",
    "tentennerete": "tentennare",
    "tentennerà": "tentennare",
    "tentennerò": "tentennare",
    "tentenni": "tentennare",
    "tentenniamo": "tentennare",
    "tentenniate": "tentennare",
    "tentennin": "tentennare",
    "tentennino": "tentennare",
    "tentenno": "tentennare",
    "tentennò": "tentennare",
    "tenterai": "tentare",
    "tenteran": "tentare",
    "tenteranno": "tentare",
    "tenterebbe": "tentare",
    "tenterebber": "tentare",
    "tenterebbero": "tentare",
    "tenterei": "tentare",
    "tenteremmo": "tentare",
    "tenteremo": "tentare",
    "tentereste": "tentare",
    "tenteresti": "tentare",
    "tenterete": "tentare",
    "tenterà": "tentare",
    "tenterò": "tentare",
    "tenti": "tentare",
    "tentiamo": "tentare",
    "tentiate": "tentare",
    "tentin": "tentare",
    "tentino": "tentare",
    "tento": "tentare",
    "tentò": "tentare",
    "tenui": "tenue",
    "tenuta": "tenere",
    "tenutari": "tenutario",
    "tenutarie": "tenutaria",
    "tenute": "tenuta",
    "tenuti": "tenere",
    "tenuto": "tenere",
    "tenzoni": "tenzone",
    "teocratica": "teocratico",
    "teocratiche": "teocratico",
    "teocratici": "teocratico",
    "teocrazie": "teocrazia",
    "teologali": "teologale",
    "teologhe": "teologa",
    "teologi": "teologo",
    "teologica": "teologico",
    "teologiche": "teologico",
    "teologici": "teologico",
    "teologie": "teologia",
    "teoremi": "teorema",
    "teoretica": "teoretico",
    "teoretiche": "teoretico",
    "teoretici": "teoretico",
    "teorica": "teorico",
    "teoriche": "teorico",
    "teorici": "teorico",
    "teorie": "teoria",
    "teorizza": "teorizzare",
    "teorizzai": "teorizzare",
    "teorizzammo": "teorizzare",
    "teorizzan": "teorizzare",
    "teorizzando": "teorizzare",
    "teorizzano": "teorizzare",
    "teorizzante": "teorizzare",
    "teorizzanti": "teorizzare",
    "teorizzar": "teorizzare",
    "teorizzaron": "teorizzare",
    "teorizzarono": "teorizzare",
    "teorizzasse": "teorizzare",
    "teorizzasser": "teorizzare",
    "teorizzassero": "teorizzare",
    "teorizzassi": "teorizzare",
    "teorizzassimo": "teorizzare",
    "teorizzaste": "teorizzare",
    "teorizzasti": "teorizzare",
    "teorizzata": "teorizzare",
    "teorizzate": "teorizzare",
    "teorizzati": "teorizzare",
    "teorizzato": "teorizzare",
    "teorizzatori": "teorizzatore",
    "teorizzava": "teorizzare",
    "teorizzavamo": "teorizzare",
    "teorizzavan": "teorizzare",
    "teorizzavano": "teorizzare",
    "teorizzavate": "teorizzare",
    "teorizzavi": "teorizzare",
    "teorizzavo": "teorizzare",
    "teorizzazioni": "teorizzazione",
    "teorizzerai": "teorizzare",
    "teorizzeran": "teorizzare",
    "teorizzeranno": "teorizzare",
    "teorizzerebbe": "teorizzare",
    "teorizzerebber": "teorizzare",
    "teorizzerebbero": "teorizzare",
    "teorizzerei": "teorizzare",
    "teorizzeremmo": "teorizzare",
    "teorizzeremo": "teorizzare",
    "teorizzereste": "teorizzare",
    "teorizzeresti": "teorizzare",
    "teorizzerete": "teorizzare",
    "teorizzerà": "teorizzare",
    "teorizzerò": "teorizzare",
    "teorizzi": "teorizzare",
    "teorizziamo": "teorizzare",
    "teorizziate": "teorizzare",
    "teorizzin": "teorizzare",
    "teorizzino": "teorizzare",
    "teorizzo": "teorizzare",
    "teorizzò": "teorizzare",
    "teosofica": "teosofico",
    "teosofiche": "teosofico",
    "teosofici": "teosofico",
    "tepori": "tepore",
    "teppismi": "teppismo",
    "teppisti": "teppista",
    "terapeuti": "terapeuta",
    "terapeutica": "terapeutico",
    "terapeutiche": "terapeutico",
    "terapeutici": "terapeutico",
    "terapie": "terapia",
    "terapisti": "terapista",
    "terga": "tergere",
    "tergan": "tergere",
    "tergano": "tergere",
    "terge": "tergere",
    "tergemmo": "tergere",
    "tergendo": "tergere",
    "tergente": "tergere",
    "tergenti": "tergere",
    "terger": "tergere",
    "tergerai": "tergere",
    "tergeran": "tergere",
    "tergeranno": "tergere",
    "tergerebbe": "tergere",
    "tergerebber": "tergere",
    "tergerebbero": "tergere",
    "tergerei": "tergere",
    "tergeremmo": "tergere",
    "tergeremo": "tergere",
    "tergereste": "tergere",
    "tergeresti": "tergere",
    "tergerete": "tergere",
    "tergerà": "tergere",
    "tergerò": "tergere",
    "tergesse": "tergere",
    "tergesser": "tergere",
    "tergessero": "tergere",
    "tergessi": "tergere",
    "tergessimo": "tergere",
    "tergeste": "tergere",
    "tergesti": "tergere",
    "tergete": "tergere",
    "tergeva": "tergere",
    "tergevamo": "tergere",
    "tergevan": "tergere",
    "tergevano": "tergere",
    "tergevate": "tergere",
    "tergevi": "tergere",
    "tergevo": "tergere",
    "tergi": "tergere",
    "tergiamo": "tergere",
    "tergiate": "tergere",
    "tergicristalli": "tergicristallo",
    "tergiversa": "tergiversare",
    "tergiversai": "tergiversare",
    "tergiversammo": "tergiversare",
    "tergiversan": "tergiversare",
    "tergiversando": "tergiversare",
    "tergiversano": "tergiversare",
    "tergiversante": "tergiversare",
    "tergiversanti": "tergiversare",
    "tergiversar": "tergiversare",
    "tergiversaron": "tergiversare",
    "tergiversarono": "tergiversare",
    "tergiversasse": "tergiversare",
    "tergiversasser": "tergiversare",
    "tergiversassero": "tergiversare",
    "tergiversassi": "tergiversare",
    "tergiversassimo": "tergiversare",
    "tergiversaste": "tergiversare",
    "tergiversasti": "tergiversare",
    "tergiversata": "tergiversare",
    "tergiversate": "tergiversare",
    "tergiversati": "tergiversare",
    "tergiversato": "tergiversare",
    "tergiversava": "tergiversare",
    "tergiversavamo": "tergiversare",
    "tergiversavan": "tergiversare",
    "tergiversavano": "tergiversare",
    "tergiversavate": "tergiversare",
    "tergiversavi": "tergiversare",
    "tergiversavo": "tergiversare",
    "tergiversazioni": "tergiversazione",
    "tergiverserai": "tergiversare",
    "tergiverseran": "tergiversare",
    "tergiverseranno": "tergiversare",
    "tergiverserebbe": "tergiversare",
    "tergiverserebber": "tergiversare",
    "tergiverserebbero": "tergiversare",
    "tergiverserei": "tergiversare",
    "tergiverseremmo": "tergiversare",
    "tergiverseremo": "tergiversare",
    "tergiversereste": "tergiversare",
    "tergiverseresti": "tergiversare",
    "tergiverserete": "tergiversare",
    "tergiverserà": "tergiversare",
    "tergiverserò": "tergiversare",
    "tergiversi": "tergiversare",
    "tergiversiamo": "tergiversare",
    "tergiversiate": "tergiversare",
    "tergiversin": "tergiversare",
    "tergiversino": "tergiversare",
    "tergiverso": "tergiversare",
    "tergiversò": "tergiversare",
    "tergo": "tergere",
    "tergon": "tergere",
    "tergono": "tergere",
    "termali": "termale",
    "termica": "termico",
    "termiche": "termico",
    "termici": "termico",
    "termina": "terminare",
    "terminai": "terminare",
    "terminali": "terminale",
    "terminalisti": "terminalista",
    "terminammo": "terminare",
    "terminan": "terminare",
    "terminando": "terminare",
    "terminano": "terminare",
    "terminante": "terminare",
    "terminanti": "terminare",
    "terminar": "terminare",
    "terminaron": "terminare",
    "terminarono": "terminare",
    "terminasse": "terminare",
    "terminasser": "terminare",
    "terminassero": "terminare",
    "terminassi": "terminare",
    "terminassimo": "terminare",
    "terminaste": "terminare",
    "terminasti": "terminare",
    "terminata": "terminare",
    "terminate": "terminare",
    "terminati": "terminare",
    "terminato": "terminare",
    "terminava": "terminare",
    "terminavamo": "terminare",
    "terminavan": "terminare",
    "terminavano": "terminare",
    "terminavate": "terminare",
    "terminavi": "terminare",
    "terminavo": "terminare",
    "terminazioni": "terminazione",
    "terminerai": "terminare",
    "termineran": "terminare",
    "termineranno": "terminare",
    "terminerebbe": "terminare",
    "terminerebber": "terminare",
    "terminerebbero": "terminare",
    "terminerei": "terminare",
    "termineremmo": "terminare",
    "termineremo": "terminare",
    "terminereste": "terminare",
    "termineresti": "terminare",
    "terminerete": "terminare",
    "terminerà": "terminare",
    "terminerò": "terminare",
    "termini": "termine",
    "terminiamo": "terminare",
    "terminiate": "terminare",
    "terminin": "terminare",
    "terminino": "terminare",
    "termino": "terminare",
    "terminologie": "terminologia",
    "terminò": "terminare",
    "termitai": "termitaio",
    "termiti": "termite",
    "termoelettrica": "termoelettrico",
    "termoelettriche": "termoelettrico",
    "termoelettrici": "termoelettrico",
    "termoindurenti": "termoindurente",
    "termolabili": "termolabile",
    "termometri": "termometro",
    "termonucleari": "termonucleare",
    "termoplastica": "termoplastico",
    "termoplastiche": "termoplastico",
    "termoplastici": "termoplastico",
    "termosifoni": "termosifone",
    "ternani": "ternano",
    "terni": "terno",
    "terracotte": "terracotta",
    "terracquea": "terracqueo",
    "terracquee": "terracqueo",
    "terracquei": "terracqueo",
    "terrai": "tenere",
    "terraioli": "terraiolo",
    "terran": "tenere",
    "terranno": "tenere",
    "terrapieni": "terrapieno",
    "terrazza": "terrazzare",
    "terrazzai": "terrazzare",
    "terrazzammo": "terrazzare",
    "terrazzan": "terrazzare",
    "terrazzando": "terrazzare",
    "terrazzano": "terrazzare",
    "terrazzante": "terrazzare",
    "terrazzanti": "terrazzare",
    "terrazzar": "terrazzare",
    "terrazzaron": "terrazzare",
    "terrazzarono": "terrazzare",
    "terrazzasse": "terrazzare",
    "terrazzasser": "terrazzare",
    "terrazzassero": "terrazzare",
    "terrazzassi": "terrazzare",
    "terrazzassimo": "terrazzare",
    "terrazzaste": "terrazzare",
    "terrazzasti": "terrazzare",
    "terrazzata": "terrazzare",
    "terrazzate": "terrazzare",
    "terrazzati": "terrazzare",
    "terrazzato": "terrazzare",
    "terrazzava": "terrazzare",
    "terrazzavamo": "terrazzare",
    "terrazzavan": "terrazzare",
    "terrazzavano": "terrazzare",
    "terrazzavate": "terrazzare",
    "terrazzavi": "terrazzare",
    "terrazzavo": "terrazzare",
    "terrazze": "terrazza",
    "terrazzerai": "terrazzare",
    "terrazzeran": "terrazzare",
    "terrazzeranno": "terrazzare",
    "terrazzerebbe": "terrazzare",
    "terrazzerebber": "terrazzare",
    "terrazzerebbero": "terrazzare",
    "terrazzerei": "terrazzare",
    "terrazzeremmo": "terrazzare",
    "terrazzeremo": "terrazzare",
    "terrazzereste": "terrazzare",
    "terrazzeresti": "terrazzare",
    "terrazzerete": "terrazzare",
    "terrazzerà": "terrazzare",
    "terrazzerò": "terrazzare",
    "terrazzi": "terrazzo",
    "terrazziamo": "terrazzare",
    "terrazziate": "terrazzare",
    "terrazzin": "terrazzare",
    "terrazzini": "terrazzino",
    "terrazzino": "terrazzare",
    "terrazzo": "terrazzare",
    "terrazzò": "terrazzare",
    "terre": "terra",
    "terrea": "terreo",
    "terrebbe": "tenere",
    "terrebber": "tenere",
    "terrebbero": "tenere",
    "terree": "terreo",
    "terreferme": "terraferma",
    "terrei": "terreo",
    "terremmo": "tenere",
    "terremo": "tenere",
    "terremotata": "terremotato",
    "terremotate": "terremotato",
    "terremotati": "terremotato",
    "terremoti": "terremoto",
    "terrena": "terreno",
    "terrene": "terreno",
    "terreni": "terreno",
    "terreste": "tenere",
    "terresti": "tenere",
    "terrestri": "terrestre",
    "terrete": "tenere",
    "terribili": "terribile",
    "terricci": "terriccio",
    "terricola": "terricolo",
    "terricole": "terricolo",
    "terricoli": "terricolo",
    "terriera": "terriero",
    "terriere": "terriero",
    "terrieri": "terriero",
    "terrifica": "terrificare",
    "terrificai": "terrificare",
    "terrificammo": "terrificare",
    "terrifican": "terrificare",
    "terrificando": "terrificare",
    "terrificano": "terrificare",
    "terrificante": "terrificare",
    "terrificanti": "terrificare",
    "terrificar": "terrificare",
    "terrificaron": "terrificare",
    "terrificarono": "terrificare",
    "terrificasse": "terrificare",
    "terrificasser": "terrificare",
    "terrificassero": "terrificare",
    "terrificassi": "terrificare",
    "terrificassimo": "terrificare",
    "terrificaste": "terrificare",
    "terrificasti": "terrificare",
    "terrificata": "terrificare",
    "terrificate": "terrificare",
    "terrificati": "terrificare",
    "terrificato": "terrificare",
    "terrificava": "terrificare",
    "terrificavamo": "terrificare",
    "terrificavan": "terrificare",
    "terrificavano": "terrificare",
    "terrificavate": "terrificare",
    "terrificavi": "terrificare",
    "terrificavo": "terrificare",
    "terrificherai": "terrificare",
    "terrificheran": "terrificare",
    "terrificheranno": "terrificare",
    "terrificherebbe": "terrificare",
    "terrificherebber": "terrificare",
    "terrificherebbero": "terrificare",
    "terrificherei": "terrificare",
    "terrificheremmo": "terrificare",
    "terrificheremo": "terrificare",
    "terrifichereste": "terrificare",
    "terrificheresti": "terrificare",
    "terrificherete": "terrificare",
    "terrificherà": "terrificare",
    "terrificherò": "terrificare",
    "terrifichi": "terrificare",
    "terrifichiamo": "terrificare",
    "terrifichiate": "terrificare",
    "terrifichin": "terrificare",
    "terrifichino": "terrificare",
    "terrifico": "terrificare",
    "terrificò": "terrificare",
    "territori": "territorio",
    "territoriali": "territoriale",
    "terroni": "terrone",
    "terrori": "terrore",
    "terrorismi": "terrorismo",
    "terroriste": "terrorista",
    "terroristi": "terrorista",
    "terroristica": "terroristico",
    "terroristiche": "terroristico",
    "terroristici": "terroristico",
    "terrorizza": "terrorizzare",
    "terrorizzai": "terrorizzare",
    "terrorizzammo": "terrorizzare",
    "terrorizzan": "terrorizzare",
    "terrorizzando": "terrorizzare",
    "terrorizzano": "terrorizzare",
    "terrorizzante": "terrorizzare",
    "terrorizzanti": "terrorizzare",
    "terrorizzar": "terrorizzare",
    "terrorizzaron": "terrorizzare",
    "terrorizzarono": "terrorizzare",
    "terrorizzasse": "terrorizzare",
    "terrorizzasser": "terrorizzare",
    "terrorizzassero": "terrorizzare",
    "terrorizzassi": "terrorizzare",
    "terrorizzassimo": "terrorizzare",
    "terrorizzaste": "terrorizzare",
    "terrorizzasti": "terrorizzare",
    "terrorizzata": "terrorizzare",
    "terrorizzate": "terrorizzare",
    "terrorizzati": "terrorizzato",
    "terrorizzato": "terrorizzare",
    "terrorizzava": "terrorizzare",
    "terrorizzavamo": "terrorizzare",
    "terrorizzavan": "terrorizzare",
    "terrorizzavano": "terrorizzare",
    "terrorizzavate": "terrorizzare",
    "terrorizzavi": "terrorizzare",
    "terrorizzavo": "terrorizzare",
    "terrorizzerai": "terrorizzare",
    "terrorizzeran": "terrorizzare",
    "terrorizzeranno": "terrorizzare",
    "terrorizzerebbe": "terrorizzare",
    "terrorizzerebber": "terrorizzare",
    "terrorizzerebbero": "terrorizzare",
    "terrorizzerei": "terrorizzare",
    "terrorizzeremmo": "terrorizzare",
    "terrorizzeremo": "terrorizzare",
    "terrorizzereste": "terrorizzare",
    "terrorizzeresti": "terrorizzare",
    "terrorizzerete": "terrorizzare",
    "terrorizzerà": "terrorizzare",
    "terrorizzerò": "terrorizzare",
    "terrorizzi": "terrorizzare",
    "terrorizziamo": "terrorizzare",
    "terrorizziate": "terrorizzare",
    "terrorizzin": "terrorizzare",
    "terrorizzino": "terrorizzare",
    "terrorizzo": "terrorizzare",
    "terrorizzò": "terrorizzare",
    "terrosa": "terroso",
    "terrose": "terroso",
    "terrosi": "terroso",
    "terrà": "tenere",
    "terrò": "tenere",
    "tersa": "terso",
    "terse": "terso",
    "terser": "tergere",
    "tersero": "tergere",
    "tersi": "terso",
    "tersè": "tergere",
    "terta": "tergere",
    "terte": "tergere",
    "terti": "tergere",
    "terto": "tergere",
    "terza": "terzo",
    "terzarola": "terzarolare",
    "terzarolai": "terzarolare",
    "terzarolammo": "terzarolare",
    "terzarolan": "terzarolare",
    "terzarolando": "terzarolare",
    "terzarolano": "terzarolare",
    "terzarolante": "terzarolare",
    "terzarolanti": "terzarolare",
    "terzarolar": "terzarolare",
    "terzarolaron": "terzarolare",
    "terzarolarono": "terzarolare",
    "terzarolasse": "terzarolare",
    "terzarolasser": "terzarolare",
    "terzarolassero": "terzarolare",
    "terzarolassi": "terzarolare",
    "terzarolassimo": "terzarolare",
    "terzarolaste": "terzarolare",
    "terzarolasti": "terzarolare",
    "terzarolata": "terzarolare",
    "terzarolate": "terzarolare",
    "terzarolati": "terzarolare",
    "terzarolato": "terzarolare",
    "terzarolava": "terzarolare",
    "terzarolavamo": "terzarolare",
    "terzarolavan": "terzarolare",
    "terzarolavano": "terzarolare",
    "terzarolavate": "terzarolare",
    "terzarolavi": "terzarolare",
    "terzarolavo": "terzarolare",
    "terzarolerai": "terzarolare",
    "terzaroleran": "terzarolare",
    "terzaroleranno": "terzarolare",
    "terzarolerebbe": "terzarolare",
    "terzarolerebber": "terzarolare",
    "terzarolerebbero": "terzarolare",
    "terzarolerei": "terzarolare",
    "terzaroleremmo": "terzarolare",
    "terzaroleremo": "terzarolare",
    "terzarolereste": "terzarolare",
    "terzaroleresti": "terzarolare",
    "terzarolerete": "terzarolare",
    "terzarolerà": "terzarolare",
    "terzarolerò": "terzarolare",
    "terzaroli": "terzarolare",
    "terzaroliamo": "terzarolare",
    "terzaroliate": "terzarolare",
    "terzarolin": "terzarolare",
    "terzarolino": "terzarolare",
    "terzarolo": "terzarolare",
    "terzarolò": "terzarolare",
    "terze": "terzo",
    "terzetti": "terzetto",
    "terzi": "terzo",
    "terziari": "terziario",
    "terziaria": "terziario",
    "terziarie": "terziario",
    "terziarizzazioni": "terziarizzazione",
    "terzina": "terzinare",
    "terzinai": "terzinare",
    "terzinammo": "terzinare",
    "terzinan": "terzinare",
    "terzinando": "terzinare",
    "terzinano": "terzinare",
    "terzinante": "terzinare",
    "terzinanti": "terzinare",
    "terzinar": "terzinare",
    "terzinaron": "terzinare",
    "terzinarono": "terzinare",
    "terzinasse": "terzinare",
    "terzinasser": "terzinare",
    "terzinassero": "terzinare",
    "terzinassi": "terzinare",
    "terzinassimo": "terzinare",
    "terzinaste": "terzinare",
    "terzinasti": "terzinare",
    "terzinata": "terzinare",
    "terzinate": "terzinare",
    "terzinati": "terzinare",
    "terzinato": "terzinare",
    "terzinava": "terzinare",
    "terzinavamo": "terzinare",
    "terzinavan": "terzinare",
    "terzinavano": "terzinare",
    "terzinavate": "terzinare",
    "terzinavi": "terzinare",
    "terzinavo": "terzinare",
    "terzine": "terzina",
    "terzinerai": "terzinare",
    "terzineran": "terzinare",
    "terzineranno": "terzinare",
    "terzinerebbe": "terzinare",
    "terzinerebber": "terzinare",
    "terzinerebbero": "terzinare",
    "terzinerei": "terzinare",
    "terzineremmo": "terzinare",
    "terzineremo": "terzinare",
    "terzinereste": "terzinare",
    "terzineresti": "terzinare",
    "terzinerete": "terzinare",
    "terzinerà": "terzinare",
    "terzinerò": "terzinare",
    "terzini": "terzino",
    "terziniamo": "terzinare",
    "terziniate": "terzinare",
    "terzinin": "terzinare",
    "terzinino": "terzinare",
    "terzino": "terzinare",
    "terzinò": "terzinare",
    "terzogeniti": "terzogenito",
    "terzomondismi": "terzomondismo",
    "terzomondisti": "terzomondista",
    "tesa": "teso",
    "tesai": "tesare",
    "tesammo": "tesare",
    "tesan": "tesare",
    "tesando": "tesare",
    "tesano": "tesare",
    "tesante": "tesare",
    "tesanti": "tesare",
    "tesar": "tesare",
    "tesaron": "tesare",
    "tesarono": "tesare",
    "tesasse": "tesare",
    "tesasser": "tesare",
    "tesassero": "tesare",
    "tesassi": "tesare",
    "tesassimo": "tesare",
    "tesaste": "tesare",
    "tesasti": "tesare",
    "tesata": "tesare",
    "tesate": "tesare",
    "tesati": "tesare",
    "tesato": "tesare",
    "tesaurizza": "tesaurizzare",
    "tesaurizzai": "tesaurizzare",
    "tesaurizzammo": "tesaurizzare",
    "tesaurizzan": "tesaurizzare",
    "tesaurizzando": "tesaurizzare",
    "tesaurizzano": "tesaurizzare",
    "tesaurizzante": "tesaurizzare",
    "tesaurizzanti": "tesaurizzare",
    "tesaurizzar": "tesaurizzare",
    "tesaurizzaron": "tesaurizzare",
    "tesaurizzarono": "tesaurizzare",
    "tesaurizzasse": "tesaurizzare",
    "tesaurizzasser": "tesaurizzare",
    "tesaurizzassero": "tesaurizzare",
    "tesaurizzassi": "tesaurizzare",
    "tesaurizzassimo": "tesaurizzare",
    "tesaurizzaste": "tesaurizzare",
    "tesaurizzasti": "tesaurizzare",
    "tesaurizzata": "tesaurizzare",
    "tesaurizzate": "tesaurizzare",
    "tesaurizzati": "tesaurizzare",
    "tesaurizzato": "tesaurizzare",
    "tesaurizzava": "tesaurizzare",
    "tesaurizzavamo": "tesaurizzare",
    "tesaurizzavan": "tesaurizzare",
    "tesaurizzavano": "tesaurizzare",
    "tesaurizzavate": "tesaurizzare",
    "tesaurizzavi": "tesaurizzare",
    "tesaurizzavo": "tesaurizzare",
    "tesaurizzerai": "tesaurizzare",
    "tesaurizzeran": "tesaurizzare",
    "tesaurizzeranno": "tesaurizzare",
    "tesaurizzerebbe": "tesaurizzare",
    "tesaurizzerebber": "tesaurizzare",
    "tesaurizzerebbero": "tesaurizzare",
    "tesaurizzerei": "tesaurizzare",
    "tesaurizzeremmo": "tesaurizzare",
    "tesaurizzeremo": "tesaurizzare",
    "tesaurizzereste": "tesaurizzare",
    "tesaurizzeresti": "tesaurizzare",
    "tesaurizzerete": "tesaurizzare",
    "tesaurizzerà": "tesaurizzare",
    "tesaurizzerò": "tesaurizzare",
    "tesaurizzi": "tesaurizzare",
    "tesaurizziamo": "tesaurizzare",
    "tesaurizziate": "tesaurizzare",
    "tesaurizzin": "tesaurizzare",
    "tesaurizzino": "tesaurizzare",
    "tesaurizzo": "tesaurizzare",
    "tesaurizzò": "tesaurizzare",
    "tesava": "tesare",
    "tesavamo": "tesare",
    "tesavan": "tesare",
    "tesavano": "tesare",
    "tesavate": "tesare",
    "tesavi": "tesare",
    "tesavo": "tesare",
    "teschi": "teschio",
    "tese": "teso",
    "teser": "tendere",
    "teserai": "tesare",
    "teseran": "tesare",
    "teseranno": "tesare",
    "teserebbe": "tesare",
    "teserebber": "tesare",
    "teserebbero": "tesare",
    "teserei": "tesare",
    "teseremmo": "tesare",
    "teseremo": "tesare",
    "tesereste": "tesare",
    "teseresti": "tesare",
    "teserete": "tesare",
    "tesero": "tendere",
    "teserà": "tesare",
    "teserò": "tesare",
    "tesi": "teso",
    "tesiamo": "tesare",
    "tesiate": "tesare",
    "tesin": "tesare",
    "tesine": "tesina",
    "tesino": "tesare",
    "teso": "tesare",
    "tesorerie": "tesoreria",
    "tesori": "tesoro",
    "tesorieri": "tesoriere",
    "tessa": "tessere",
    "tessan": "tessere",
    "tessano": "tessere",
    "tesse": "tessere",
    "tessei": "tessere",
    "tessemmo": "tessere",
    "tessendo": "tessere",
    "tessente": "tessere",
    "tessenti": "tessere",
    "tesser": "tessere",
    "tessera": "tesserare",
    "tesserai": "tessere",
    "tesseramenti": "tesseramento",
    "tesserammo": "tesserare",
    "tesseran": "tessere",
    "tesserando": "tesserare",
    "tesseranno": "tessere",
    "tesserano": "tesserare",
    "tesserante": "tesserare",
    "tesseranti": "tesserare",
    "tesserar": "tesserare",
    "tesseraron": "tesserare",
    "tesserarono": "tesserare",
    "tesserasse": "tesserare",
    "tesserasser": "tesserare",
    "tesserassero": "tesserare",
    "tesserassi": "tesserare",
    "tesserassimo": "tesserare",
    "tesseraste": "tesserare",
    "tesserasti": "tesserare",
    "tesserata": "tesserato",
    "tesserate": "tesserato",
    "tesserati": "tesserato",
    "tesserato": "tesserare",
    "tesserava": "tesserare",
    "tesseravamo": "tesserare",
    "tesseravan": "tesserare",
    "tesseravano": "tesserare",
    "tesseravate": "tesserare",
    "tesseravi": "tesserare",
    "tesseravo": "tesserare",
    "tessere": "tessera",
    "tesserebbe": "tessere",
    "tesserebber": "tessere",
    "tesserebbero": "tessere",
    "tesserei": "tessere",
    "tesseremmo": "tessere",
    "tesseremo": "tessere",
    "tessererai": "tesserare",
    "tessereran": "tesserare",
    "tessereranno": "tesserare",
    "tessererebbe": "tesserare",
    "tessererebber": "tesserare",
    "tessererebbero": "tesserare",
    "tessererei": "tesserare",
    "tessereremmo": "tesserare",
    "tessereremo": "tesserare",
    "tesserereste": "tesserare",
    "tessereresti": "tesserare",
    "tessererete": "tesserare",
    "tessererà": "tesserare",
    "tessererò": "tesserare",
    "tessereste": "tessere",
    "tesseresti": "tessere",
    "tesserete": "tessere",
    "tesseri": "tesserare",
    "tesseriamo": "tesserare",
    "tesseriate": "tesserare",
    "tesserin": "tesserare",
    "tesserine": "tesserina",
    "tesserini": "tesserino",
    "tesserino": "tesserare",
    "tessero": "tesserare",
    "tesseron": "tessere",
    "tesserono": "tessere",
    "tesserà": "tessere",
    "tesserò": "tessere",
    "tessesse": "tessere",
    "tessesser": "tessere",
    "tessessero": "tessere",
    "tessessi": "tessere",
    "tessessimo": "tessere",
    "tesseste": "tessere",
    "tessesti": "tessere",
    "tessete": "tessere",
    "tesseva": "tessere",
    "tessevamo": "tessere",
    "tessevan": "tessere",
    "tessevano": "tessere",
    "tessevate": "tessere",
    "tessevi": "tessere",
    "tessevo": "tessere",
    "tessi": "tessere",
    "tessiamo": "tessere",
    "tessiate": "tessere",
    "tessili": "tessile",
    "tessitori": "tessitore",
    "tessiture": "tessitura",
    "tesso": "tessere",
    "tesson": "tessere",
    "tessono": "tessere",
    "tessuta": "tessere",
    "tessutai": "tessutaio",
    "tessute": "tessere",
    "tessuti": "tessuto",
    "tessuto": "tessere",
    "tessè": "tessere",
    "testa": "testare",
    "testai": "testare",
    "testamentari": "testamentario",
    "testamentaria": "testamentario",
    "testamentarie": "testamentario",
    "testamenti": "testamento",
    "testammo": "testare",
    "testan": "testare",
    "testando": "testare",
    "testano": "testare",
    "testante": "testare",
    "testanti": "testare",
    "testar": "testare",
    "testarda": "testardo",
    "testardaggini": "testardaggine",
    "testarde": "testardo",
    "testardi": "testardo",
    "testaron": "testare",
    "testarono": "testare",
    "testasse": "testare",
    "testasser": "testare",
    "testassero": "testare",
    "testassi": "testare",
    "testassimo": "testare",
    "testaste": "testare",
    "testasti": "testare",
    "testata": "testare",
    "testate": "testata",
    "testati": "testare",
    "testatica": "testatico",
    "testatiche": "testatico",
    "testatici": "testatico",
    "testato": "testare",
    "testava": "testare",
    "testavamo": "testare",
    "testavan": "testare",
    "testavano": "testare",
    "testavate": "testare",
    "testavi": "testare",
    "testavo": "testare",
    "teste": "testa",
    "testerai": "testare",
    "testeran": "testare",
    "testeranno": "testare",
    "testerebbe": "testare",
    "testerebber": "testare",
    "testerebbero": "testare",
    "testerei": "testare",
    "testeremmo": "testare",
    "testeremo": "testare",
    "testereste": "testare",
    "testeresti": "testare",
    "testerete": "testare",
    "testerà": "testare",
    "testerò": "testare",
    "testi": "testo",
    "testiamo": "testare",
    "testiate": "testare",
    "testicoli": "testicolo",
    "testifica": "testificare",
    "testificai": "testificare",
    "testificammo": "testificare",
    "testifican": "testificare",
    "testificando": "testificare",
    "testificano": "testificare",
    "testificante": "testificare",
    "testificanti": "testificare",
    "testificar": "testificare",
    "testificaron": "testificare",
    "testificarono": "testificare",
    "testificasse": "testificare",
    "testificasser": "testificare",
    "testificassero": "testificare",
    "testificassi": "testificare",
    "testificassimo": "testificare",
    "testificaste": "testificare",
    "testificasti": "testificare",
    "testificata": "testificare",
    "testificate": "testificare",
    "testificati": "testificare",
    "testificato": "testificare",
    "testificava": "testificare",
    "testificavamo": "testificare",
    "testificavan": "testificare",
    "testificavano": "testificare",
    "testificavate": "testificare",
    "testificavi": "testificare",
    "testificavo": "testificare",
    "testificherai": "testificare",
    "testificheran": "testificare",
    "testificheranno": "testificare",
    "testificherebbe": "testificare",
    "testificherebber": "testificare",
    "testificherebbero": "testificare",
    "testificherei": "testificare",
    "testificheremmo": "testificare",
    "testificheremo": "testificare",
    "testifichereste": "testificare",
    "testificheresti": "testificare",
    "testificherete": "testificare",
    "testificherà": "testificare",
    "testificherò": "testificare",
    "testifichi": "testificare",
    "testifichiamo": "testificare",
    "testifichiate": "testificare",
    "testifichin": "testificare",
    "testifichino": "testificare",
    "testifico": "testificare",
    "testificò": "testificare",
    "testimoni": "testimoniare",
    "testimonia": "testimoniare",
    "testimoniai": "testimoniare",
    "testimoniali": "testimoniale",
    "testimoniammo": "testimoniare",
    "testimoniamo": "testimoniare",
    "testimonian": "testimoniare",
    "testimoniando": "testimoniare",
    "testimoniano": "testimoniare",
    "testimoniante": "testimoniare",
    "testimonianti": "testimoniare",
    "testimonianze": "testimonianza",
    "testimoniar": "testimoniare",
    "testimoniaron": "testimoniare",
    "testimoniarono": "testimoniare",
    "testimoniasse": "testimoniare",
    "testimoniasser": "testimoniare",
    "testimoniassero": "testimoniare",
    "testimoniassi": "testimoniare",
    "testimoniassimo": "testimoniare",
    "testimoniaste": "testimoniare",
    "testimoniasti": "testimoniare",
    "testimoniata": "testimoniare",
    "testimoniate": "testimoniare",
    "testimoniati": "testimoniare",
    "testimoniato": "testimoniare",
    "testimoniava": "testimoniare",
    "testimoniavamo": "testimoniare",
    "testimoniavan": "testimoniare",
    "testimoniavano": "testimoniare",
    "testimoniavate": "testimoniare",
    "testimoniavi": "testimoniare",
    "testimoniavo": "testimoniare",
    "testimonierai": "testimoniare",
    "testimonieran": "testimoniare",
    "testimonieranno": "testimoniare",
    "testimonierebbe": "testimoniare",
    "testimonierebber": "testimoniare",
    "testimonierebbero": "testimoniare",
    "testimonierei": "testimoniare",
    "testimonieremmo": "testimoniare",
    "testimonieremo": "testimoniare",
    "testimoniereste": "testimoniare",
    "testimonieresti": "testimoniare",
    "testimonierete": "testimoniare",
    "testimonierà": "testimoniare",
    "testimonierò": "testimoniare",
    "testimonin": "testimoniare",
    "testimonino": "testimoniare",
    "testimonio": "testimoniare",
    "testimoniò": "testimoniare",
    "testin": "testare",
    "testine": "testina",
    "testino": "testare",
    "testo": "testare",
    "testoline": "testolina",
    "testoni": "testone",
    "testosteroni": "testosterone",
    "testuali": "testuale",
    "testuggini": "testuggine",
    "testò": "testare",
    "tesè": "tendere",
    "tesò": "tesare",
    "tetra": "tetro",
    "tetraetili": "tetraetile",
    "tetraggini": "tetraggine",
    "tetragona": "tetragono",
    "tetragone": "tetragono",
    "tetragoni": "tetragono",
    "tetralogie": "tetralogia",
    "tetre": "tetro",
    "tetri": "tetro",
    "tette": "tetta",
    "tetti": "tetto",
    "tettoie": "tettoia",
    "tettone": "tettona",
    "tettucci": "tettuccio",
    "teutonica": "teutonico",
    "teutoniche": "teutonico",
    "teutonici": "teutonico",
    "texana": "texano",
    "texane": "texano",
    "texani": "texano",
    "thailandesi": "thailandese",
    "thatcherismi": "thatcherismo",
    "tiare": "tiara",
    "tiberina": "tiberino",
    "tiberine": "tiberino",
    "tiberini": "tiberino",
    "tibetana": "tibetano",
    "tibetane": "tibetano",
    "tibetani": "tibetano",
    "tibie": "tibia",
    "ticchetta": "ticchettare",
    "ticchettai": "ticchettare",
    "ticchettammo": "ticchettare",
    "ticchettan": "ticchettare",
    "ticchettando": "ticchettare",
    "ticchettano": "ticchettare",
    "ticchettante": "ticchettare",
    "ticchettanti": "ticchettare",
    "ticchettar": "ticchettare",
    "ticchettaron": "ticchettare",
    "ticchettarono": "ticchettare",
    "ticchettasse": "ticchettare",
    "ticchettasser": "ticchettare",
    "ticchettassero": "ticchettare",
    "ticchettassi": "ticchettare",
    "ticchettassimo": "ticchettare",
    "ticchettaste": "ticchettare",
    "ticchettasti": "ticchettare",
    "ticchettata": "ticchettare",
    "ticchettate": "ticchettare",
    "ticchettati": "ticchettare",
    "ticchettato": "ticchettare",
    "ticchettava": "ticchettare",
    "ticchettavamo": "ticchettare",
    "ticchettavan": "ticchettare",
    "ticchettavano": "ticchettare",
    "ticchettavate": "ticchettare",
    "ticchettavi": "ticchettare",
    "ticchettavo": "ticchettare",
    "ticchetterai": "ticchettare",
    "ticchetteran": "ticchettare",
    "ticchetteranno": "ticchettare",
    "ticchetterebbe": "ticchettare",
    "ticchetterebber": "ticchettare",
    "ticchetterebbero": "ticchettare",
    "ticchetterei": "ticchettare",
    "ticchetteremmo": "ticchettare",
    "ticchetteremo": "ticchettare",
    "ticchettereste": "ticchettare",
    "ticchetteresti": "ticchettare",
    "ticchetterete": "ticchettare",
    "ticchetterà": "ticchettare",
    "ticchetterò": "ticchettare",
    "ticchetti": "ticchettare",
    "ticchettiamo": "ticchettare",
    "ticchettiate": "ticchettare",
    "ticchettii": "ticchettio",
    "ticchettin": "ticchettare",
    "ticchettino": "ticchettare",
    "ticchetto": "ticchettare",
    "ticchettò": "ticchettare",
    "ticinesi": "ticinese",
    "tiene": "tenere",
    "tieni": "tenere",
    "tiepida": "tiepido",
    "tiepide": "tiepido",
    "tiepidezze": "tiepidezza",
    "tiepidi": "tiepido",
    "tifa": "tifare",
    "tifai": "tifare",
    "tifammo": "tifare",
    "tifan": "tifare",
    "tifando": "tifare",
    "tifano": "tifare",
    "tifante": "tifare",
    "tifanti": "tifare",
    "tifar": "tifare",
    "tifaron": "tifare",
    "tifarono": "tifare",
    "tifasse": "tifare",
    "tifasser": "tifare",
    "tifassero": "tifare",
    "tifassi": "tifare",
    "tifassimo": "tifare",
    "tifaste": "tifare",
    "tifasti": "tifare",
    "tifata": "tifare",
    "tifate": "tifare",
    "tifati": "tifare",
    "tifato": "tifare",
    "tifava": "tifare",
    "tifavamo": "tifare",
    "tifavan": "tifare",
    "tifavano": "tifare",
    "tifavate": "tifare",
    "tifavi": "tifare",
    "tifavo": "tifare",
    "tiferai": "tifare",
    "tiferan": "tifare",
    "tiferanno": "tifare",
    "tiferebbe": "tifare",
    "tiferebber": "tifare",
    "tiferebbero": "tifare",
    "tiferei": "tifare",
    "tiferemmo": "tifare",
    "tiferemo": "tifare",
    "tifereste": "tifare",
    "tiferesti": "tifare",
    "tiferete": "tifare",
    "tiferà": "tifare",
    "tiferò": "tifare",
    "tifi": "tifare",
    "tifiamo": "tifare",
    "tifiate": "tifare",
    "tifin": "tifare",
    "tifino": "tifare",
    "tifo": "tifare",
    "tifoidea": "tifoideo",
    "tifoidee": "tifoideo",
    "tifoidei": "tifoideo",
    "tifoni": "tifone",
    "tifosa": "tifoso",
    "tifose": "tifoso",
    "tifoserie": "tifoseria",
    "tifosi": "tifoso",
    "tifò": "tifare",
    "tigli": "tiglio",
    "tignosa": "tignoso",
    "tignose": "tignoso",
    "tignosi": "tignoso",
    "tigrata": "tigrato",
    "tigrate": "tigrato",
    "tigrati": "tigrato",
    "tigri": "tigre",
    "tigrotti": "tigrotto",
    "timbra": "timbrare",
    "timbrai": "timbrare",
    "timbrammo": "timbrare",
    "timbran": "timbrare",
    "timbrando": "timbrare",
    "timbrano": "timbrare",
    "timbrante": "timbrare",
    "timbranti": "timbrare",
    "timbrar": "timbrare",
    "timbraron": "timbrare",
    "timbrarono": "timbrare",
    "timbrasse": "timbrare",
    "timbrasser": "timbrare",
    "timbrassero": "timbrare",
    "timbrassi": "timbrare",
    "timbrassimo": "timbrare",
    "timbraste": "timbrare",
    "timbrasti": "timbrare",
    "timbrata": "timbrare",
    "timbrate": "timbrare",
    "timbrati": "timbrare",
    "timbrato": "timbrare",
    "timbrava": "timbrare",
    "timbravamo": "timbrare",
    "timbravan": "timbrare",
    "timbravano": "timbrare",
    "timbravate": "timbrare",
    "timbravi": "timbrare",
    "timbravo": "timbrare",
    "timbrerai": "timbrare",
    "timbreran": "timbrare",
    "timbreranno": "timbrare",
    "timbrerebbe": "timbrare",
    "timbrerebber": "timbrare",
    "timbrerebbero": "timbrare",
    "timbrerei": "timbrare",
    "timbreremmo": "timbrare",
    "timbreremo": "timbrare",
    "timbrereste": "timbrare",
    "timbreresti": "timbrare",
    "timbrerete": "timbrare",
    "timbrerà": "timbrare",
    "timbrerò": "timbrare",
    "timbri": "timbro",
    "timbriamo": "timbrare",
    "timbriate": "timbrare",
    "timbrica": "timbrico",
    "timbriche": "timbrico",
    "timbrici": "timbrico",
    "timbrin": "timbrare",
    "timbrino": "timbrare",
    "timbro": "timbrare",
    "timbrò": "timbrare",
    "timida": "timido",
    "timide": "timido",
    "timidezze": "timidezza",
    "timidi": "timido",
    "timona": "timonare",
    "timonai": "timonare",
    "timonammo": "timonare",
    "timonan": "timonare",
    "timonando": "timonare",
    "timonano": "timonare",
    "timonante": "timonare",
    "timonanti": "timonare",
    "timonar": "timonare",
    "timonaron": "timonare",
    "timonarono": "timonare",
    "timonasse": "timonare",
    "timonasser": "timonare",
    "timonassero": "timonare",
    "timonassi": "timonare",
    "timonassimo": "timonare",
    "timonaste": "timonare",
    "timonasti": "timonare",
    "timonata": "timonare",
    "timonate": "timonare",
    "timonati": "timonare",
    "timonato": "timonare",
    "timonava": "timonare",
    "timonavamo": "timonare",
    "timonavan": "timonare",
    "timonavano": "timonare",
    "timonavate": "timonare",
    "timonavi": "timonare",
    "timonavo": "timonare",
    "timonerai": "timonare",
    "timoneran": "timonare",
    "timoneranno": "timonare",
    "timonerebbe": "timonare",
    "timonerebber": "timonare",
    "timonerebbero": "timonare",
    "timonerei": "timonare",
    "timoneremmo": "timonare",
    "timoneremo": "timonare",
    "timonereste": "timonare",
    "timoneresti": "timonare",
    "timonerete": "timonare",
    "timonerà": "timonare",
    "timonerò": "timonare",
    "timoni": "timone",
    "timoniamo": "timonare",
    "timoniate": "timonare",
    "timoniera": "timoniero",
    "timoniere": "timoniero",
    "timonieri": "timoniero",
    "timonin": "timonare",
    "timonino": "timonare",
    "timono": "timonare",
    "timonò": "timonare",
    "timor": "timore",
    "timorata": "timorato",
    "timorate": "timorato",
    "timorati": "timorato",
    "timori": "timore",
    "timorosa": "timoroso",
    "timorose": "timoroso",
    "timorosi": "timoroso",
    "timpani": "timpano",
    "timpanica": "timpanico",
    "timpaniche": "timpanico",
    "timpanici": "timpanico",
    "tinelli": "tinello",
    "tinga": "tingere",
    "tingan": "tingere",
    "tingano": "tingere",
    "tinge": "tingere",
    "tingemmo": "tingere",
    "tingendo": "tingere",
    "tingente": "tingere",
    "tingenti": "tingere",
    "tinger": "tingere",
    "tingerai": "tingere",
    "tingeran": "tingere",
    "tingeranno": "tingere",
    "tingerebbe": "tingere",
    "tingerebber": "tingere",
    "tingerebbero": "tingere",
    "tingerei": "tingere",
    "tingeremmo": "tingere",
    "tingeremo": "tingere",
    "tingereste": "tingere",
    "tingeresti": "tingere",
    "tingerete": "tingere",
    "tingerà": "tingere",
    "tingerò": "tingere",
    "tingesse": "tingere",
    "tingesser": "tingere",
    "tingessero": "tingere",
    "tingessi": "tingere",
    "tingessimo": "tingere",
    "tingeste": "tingere",
    "tingesti": "tingere",
    "tingete": "tingere",
    "tingeva": "tingere",
    "tingevamo": "tingere",
    "tingevan": "tingere",
    "tingevano": "tingere",
    "tingevate": "tingere",
    "tingevi": "tingere",
    "tingevo": "tingere",
    "tingi": "tingere",
    "tingiamo": "tingere",
    "tingiate": "tingere",
    "tingo": "tingere",
    "tingon": "tingere",
    "tingono": "tingere",
    "tini": "tino",
    "tinna": "tinnire",
    "tinnan": "tinnire",
    "tinnano": "tinnire",
    "tinne": "tinnire",
    "tinnendo": "tinnire",
    "tinnente": "tinnire",
    "tinnenti": "tinnire",
    "tinni": "tinnire",
    "tinniamo": "tinnire",
    "tinniate": "tinnire",
    "tinnii": "tinnire",
    "tinnimmo": "tinnire",
    "tinnir": "tinnire",
    "tinnirai": "tinnire",
    "tinniran": "tinnire",
    "tinniranno": "tinnire",
    "tinnirebbe": "tinnire",
    "tinnirebber": "tinnire",
    "tinnirebbero": "tinnire",
    "tinnirei": "tinnire",
    "tinniremmo": "tinnire",
    "tinniremo": "tinnire",
    "tinnireste": "tinnire",
    "tinniresti": "tinnire",
    "tinnirete": "tinnire",
    "tinniron": "tinnire",
    "tinnirono": "tinnire",
    "tinnirà": "tinnire",
    "tinnirò": "tinnire",
    "tinnisse": "tinnire",
    "tinnisser": "tinnire",
    "tinnissero": "tinnire",
    "tinnissi": "tinnire",
    "tinnissimo": "tinnire",
    "tinniste": "tinnire",
    "tinnisti": "tinnire",
    "tinnita": "tinnire",
    "tinnite": "tinnire",
    "tinniti": "tinnire",
    "tinnito": "tinnire",
    "tinniva": "tinnire",
    "tinnivamo": "tinnire",
    "tinnivan": "tinnire",
    "tinnivano": "tinnire",
    "tinnivate": "tinnire",
    "tinnivi": "tinnire",
    "tinnivo": "tinnire",
    "tinno": "tinnire",
    "tinnon": "tinnire",
    "tinnono": "tinnire",
    "tinnì": "tinnire",
    "tinozze": "tinozza",
    "tinse": "tingere",
    "tinser": "tingere",
    "tinsero": "tingere",
    "tinsi": "tingere",
    "tinta": "tinto",
    "tintarelle": "tintarella",
    "tinte": "tinto",
    "tinteggerai": "tinteggiare",
    "tinteggeran": "tinteggiare",
    "tinteggeranno": "tinteggiare",
    "tinteggerebbe": "tinteggiare",
    "tinteggerebber": "tinteggiare",
    "tinteggerebbero": "tinteggiare",
    "tinteggerei": "tinteggiare",
    "tinteggeremmo": "tinteggiare",
    "tinteggeremo": "tinteggiare",
    "tinteggereste": "tinteggiare",
    "tinteggeresti": "tinteggiare",
    "tinteggerete": "tinteggiare",
    "tinteggerà": "tinteggiare",
    "tinteggerò": "tinteggiare",
    "tinteggi": "tinteggiare",
    "tinteggia": "tinteggiare",
    "tinteggiai": "tinteggiare",
    "tinteggiammo": "tinteggiare",
    "tinteggiamo": "tinteggiare",
    "tinteggian": "tinteggiare",
    "tinteggiando": "tinteggiare",
    "tinteggiano": "tinteggiare",
    "tinteggiante": "tinteggiare",
    "tinteggianti": "tinteggiare",
    "tinteggiar": "tinteggiare",
    "tinteggiaron": "tinteggiare",
    "tinteggiarono": "tinteggiare",
    "tinteggiasse": "tinteggiare",
    "tinteggiasser": "tinteggiare",
    "tinteggiassero": "tinteggiare",
    "tinteggiassi": "tinteggiare",
    "tinteggiassimo": "tinteggiare",
    "tinteggiaste": "tinteggiare",
    "tinteggiasti": "tinteggiare",
    "tinteggiata": "tinteggiare",
    "tinteggiate": "tinteggiare",
    "tinteggiati": "tinteggiare",
    "tinteggiato": "tinteggiare",
    "tinteggiava": "tinteggiare",
    "tinteggiavamo": "tinteggiare",
    "tinteggiavan": "tinteggiare",
    "tinteggiavano": "tinteggiare",
    "tinteggiavate": "tinteggiare",
    "tinteggiavi": "tinteggiare",
    "tinteggiavo": "tinteggiare",
    "tinteggin": "tinteggiare",
    "tinteggino": "tinteggiare",
    "tinteggio": "tinteggiare",
    "tinteggiò": "tinteggiare",
    "tinti": "tinto",
    "tintinna": "tintinnare",
    "tintinnai": "tintinnare",
    "tintinnammo": "tintinnare",
    "tintinnan": "tintinnare",
    "tintinnando": "tintinnare",
    "tintinnano": "tintinnare",
    "tintinnante": "tintinnare",
    "tintinnanti": "tintinnare",
    "tintinnar": "tintinnare",
    "tintinnaron": "tintinnare",
    "tintinnarono": "tintinnare",
    "tintinnasse": "tintinnare",
    "tintinnasser": "tintinnare",
    "tintinnassero": "tintinnare",
    "tintinnassi": "tintinnare",
    "tintinnassimo": "tintinnare",
    "tintinnaste": "tintinnare",
    "tintinnasti": "tintinnare",
    "tintinnata": "tintinnare",
    "tintinnate": "tintinnare",
    "tintinnati": "tintinnare",
    "tintinnato": "tintinnare",
    "tintinnava": "tintinnare",
    "tintinnavamo": "tintinnare",
    "tintinnavan": "tintinnare",
    "tintinnavano": "tintinnare",
    "tintinnavate": "tintinnare",
    "tintinnavi": "tintinnare",
    "tintinnavo": "tintinnare",
    "tintinnerai": "tintinnare",
    "tintinneran": "tintinnare",
    "tintinneranno": "tintinnare",
    "tintinnerebbe": "tintinnare",
    "tintinnerebber": "tintinnare",
    "tintinnerebbero": "tintinnare",
    "tintinnerei": "tintinnare",
    "tintinneremmo": "tintinnare",
    "tintinneremo": "tintinnare",
    "tintinnereste": "tintinnare",
    "tintinneresti": "tintinnare",
    "tintinnerete": "tintinnare",
    "tintinnerà": "tintinnare",
    "tintinnerò": "tintinnare",
    "tintinni": "tintinnare",
    "tintinniamo": "tintinnare",
    "tintinniate": "tintinnare",
    "tintinnii": "tintinnio",
    "tintinnin": "tintinnare",
    "tintinnino": "tintinnare",
    "tintinno": "tintinnare",
    "tintinnò": "tintinnare",
    "tinto": "tingere",
    "tintori": "tintorio",
    "tintoria": "tintorio",
    "tintorie": "tintorio",
    "tinture": "tintura",
    "tipa": "tipo",
    "tipacci": "tipaccio",
    "tipe": "tipo",
    "tipetti": "tipetto",
    "tipi": "tipo",
    "tipica": "tipico",
    "tipiche": "tipico",
    "tipici": "tipico",
    "tipizza": "tipizzare",
    "tipizzai": "tipizzare",
    "tipizzammo": "tipizzare",
    "tipizzan": "tipizzare",
    "tipizzando": "tipizzare",
    "tipizzano": "tipizzare",
    "tipizzante": "tipizzare",
    "tipizzanti": "tipizzare",
    "tipizzar": "tipizzare",
    "tipizzaron": "tipizzare",
    "tipizzarono": "tipizzare",
    "tipizzasse": "tipizzare",
    "tipizzasser": "tipizzare",
    "tipizzassero": "tipizzare",
    "tipizzassi": "tipizzare",
    "tipizzassimo": "tipizzare",
    "tipizzaste": "tipizzare",
    "tipizzasti": "tipizzare",
    "tipizzata": "tipizzare",
    "tipizzate": "tipizzare",
    "tipizzati": "tipizzare",
    "tipizzato": "tipizzare",
    "tipizzava": "tipizzare",
    "tipizzavamo": "tipizzare",
    "tipizzavan": "tipizzare",
    "tipizzavano": "tipizzare",
    "tipizzavate": "tipizzare",
    "tipizzavi": "tipizzare",
    "tipizzavo": "tipizzare",
    "tipizzerai": "tipizzare",
    "tipizzeran": "tipizzare",
    "tipizzeranno": "tipizzare",
    "tipizzerebbe": "tipizzare",
    "tipizzerebber": "tipizzare",
    "tipizzerebbero": "tipizzare",
    "tipizzerei": "tipizzare",
    "tipizzeremmo": "tipizzare",
    "tipizzeremo": "tipizzare",
    "tipizzereste": "tipizzare",
    "tipizzeresti": "tipizzare",
    "tipizzerete": "tipizzare",
    "tipizzerà": "tipizzare",
    "tipizzerò": "tipizzare",
    "tipizzi": "tipizzare",
    "tipizziamo": "tipizzare",
    "tipizziate": "tipizzare",
    "tipizzin": "tipizzare",
    "tipizzino": "tipizzare",
    "tipizzo": "tipizzare",
    "tipizzò": "tipizzare",
    "tipografi": "tipografo",
    "tipografica": "tipografico",
    "tipografiche": "tipografico",
    "tipografici": "tipografico",
    "tipografie": "tipografia",
    "tipologica": "tipologico",
    "tipologiche": "tipologico",
    "tipologici": "tipologico",
    "tipologie": "tipologia",
    "tira": "tirare",
    "tiracci": "tiraccio",
    "tiraggi": "tiraggio",
    "tirai": "tirare",
    "tirammo": "tirare",
    "tiran": "tirare",
    "tirando": "tirare",
    "tiranna": "tiranno",
    "tiranne": "tiranno",
    "tiranneggerai": "tiranneggiare",
    "tiranneggeran": "tiranneggiare",
    "tiranneggeranno": "tiranneggiare",
    "tiranneggerebbe": "tiranneggiare",
    "tiranneggerebber": "tiranneggiare",
    "tiranneggerebbero": "tiranneggiare",
    "tiranneggerei": "tiranneggiare",
    "tiranneggeremmo": "tiranneggiare",
    "tiranneggeremo": "tiranneggiare",
    "tiranneggereste": "tiranneggiare",
    "tiranneggeresti": "tiranneggiare",
    "tiranneggerete": "tiranneggiare",
    "tiranneggerà": "tiranneggiare",
    "tiranneggerò": "tiranneggiare",
    "tiranneggi": "tiranneggiare",
    "tiranneggia": "tiranneggiare",
    "tiranneggiai": "tiranneggiare",
    "tiranneggiammo": "tiranneggiare",
    "tiranneggiamo": "tiranneggiare",
    "tiranneggian": "tiranneggiare",
    "tiranneggiando": "tiranneggiare",
    "tiranneggiano": "tiranneggiare",
    "tiranneggiante": "tiranneggiare",
    "tiranneggianti": "tiranneggiare",
    "tiranneggiar": "tiranneggiare",
    "tiranneggiaron": "tiranneggiare",
    "tiranneggiarono": "tiranneggiare",
    "tiranneggiasse": "tiranneggiare",
    "tiranneggiasser": "tiranneggiare",
    "tiranneggiassero": "tiranneggiare",
    "tiranneggiassi": "tiranneggiare",
    "tiranneggiassimo": "tiranneggiare",
    "tiranneggiaste": "tiranneggiare",
    "tiranneggiasti": "tiranneggiare",
    "tiranneggiata": "tiranneggiare",
    "tiranneggiate": "tiranneggiare",
    "tiranneggiati": "tiranneggiare",
    "tiranneggiato": "tiranneggiare",
    "tiranneggiava": "tiranneggiare",
    "tiranneggiavamo": "tiranneggiare",
    "tiranneggiavan": "tiranneggiare",
    "tiranneggiavano": "tiranneggiare",
    "tiranneggiavate": "tiranneggiare",
    "tiranneggiavi": "tiranneggiare",
    "tiranneggiavo": "tiranneggiare",
    "tiranneggin": "tiranneggiare",
    "tiranneggino": "tiranneggiare",
    "tiranneggio": "tiranneggiare",
    "tiranneggiò": "tiranneggiare",
    "tirannesca": "tirannesco",
    "tirannesche": "tirannesco",
    "tiranneschi": "tirannesco",
    "tiranni": "tiranno",
    "tirannica": "tirannico",
    "tiranniche": "tirannico",
    "tirannici": "tirannico",
    "tirannidi": "tirannide",
    "tirannie": "tirannia",
    "tirano": "tirare",
    "tirante": "tirare",
    "tiranti": "tirare",
    "tirar": "tirare",
    "tiraron": "tirare",
    "tirarono": "tirare",
    "tirasse": "tirare",
    "tirasser": "tirare",
    "tirassero": "tirare",
    "tirassi": "tirare",
    "tirassimo": "tirare",
    "tiraste": "tirare",
    "tirasti": "tirare",
    "tirata": "tirato",
    "tirate": "tirato",
    "tirati": "tirato",
    "tiratine": "tiratina",
    "tirato": "tirare",
    "tiratori": "tiratore",
    "tirature": "tiratura",
    "tirava": "tirare",
    "tiravamo": "tirare",
    "tiravan": "tirare",
    "tiravano": "tirare",
    "tiravate": "tirare",
    "tiravi": "tirare",
    "tiravo": "tirare",
    "tireostatica": "tireostatico",
    "tireostatiche": "tireostatico",
    "tireostatici": "tireostatico",
    "tirerai": "tirare",
    "tireran": "tirare",
    "tireranno": "tirare",
    "tirerebbe": "tirare",
    "tirerebber": "tirare",
    "tirerebbero": "tirare",
    "tirerei": "tirare",
    "tireremmo": "tirare",
    "tireremo": "tirare",
    "tirereste": "tirare",
    "tireresti": "tirare",
    "tirerete": "tirare",
    "tirerà": "tirare",
    "tirerò": "tirare",
    "tiri": "tiro",
    "tiriamo": "tirare",
    "tiriate": "tirare",
    "tirin": "tirare",
    "tirino": "tirare",
    "tiritere": "tiritera",
    "tiro": "tirare",
    "tirocinanti": "tirocinante",
    "tirocini": "tirocinio",
    "tirolesi": "tirolese",
    "tirrena": "tirreno",
    "tirrene": "tirreno",
    "tirreni": "tirreno",
    "tirrenica": "tirrenico",
    "tirreniche": "tirrenico",
    "tirrenici": "tirrenico",
    "tirò": "tirare",
    "tisane": "tisana",
    "titani": "titano",
    "titanica": "titanico",
    "titaniche": "titanico",
    "titanici": "titanico",
    "titanii": "titanio",
    "titilla": "titillare",
    "titillai": "titillare",
    "titillammo": "titillare",
    "titillan": "titillare",
    "titillando": "titillare",
    "titillano": "titillare",
    "titillante": "titillare",
    "titillanti": "titillare",
    "titillar": "titillare",
    "titillaron": "titillare",
    "titillarono": "titillare",
    "titillasse": "titillare",
    "titillasser": "titillare",
    "titillassero": "titillare",
    "titillassi": "titillare",
    "titillassimo": "titillare",
    "titillaste": "titillare",
    "titillasti": "titillare",
    "titillata": "titillare",
    "titillate": "titillare",
    "titillati": "titillare",
    "titillato": "titillare",
    "titillava": "titillare",
    "titillavamo": "titillare",
    "titillavan": "titillare",
    "titillavano": "titillare",
    "titillavate": "titillare",
    "titillavi": "titillare",
    "titillavo": "titillare",
    "titillerai": "titillare",
    "titilleran": "titillare",
    "titilleranno": "titillare",
    "titillerebbe": "titillare",
    "titillerebber": "titillare",
    "titillerebbero": "titillare",
    "titillerei": "titillare",
    "titilleremmo": "titillare",
    "titilleremo": "titillare",
    "titillereste": "titillare",
    "titilleresti": "titillare",
    "titillerete": "titillare",
    "titillerà": "titillare",
    "titillerò": "titillare",
    "titilli": "titillare",
    "titilliamo": "titillare",
    "titilliate": "titillare",
    "titillin": "titillare",
    "titillino": "titillare",
    "titillo": "titillare",
    "titillò": "titillare",
    "titola": "titolare",
    "titolai": "titolare",
    "titolammo": "titolare",
    "titolan": "titolare",
    "titolando": "titolare",
    "titolano": "titolare",
    "titolante": "titolare",
    "titolanti": "titolare",
    "titolar": "titolare",
    "titolari": "titolare",
    "titolaron": "titolare",
    "titolarono": "titolare",
    "titolasse": "titolare",
    "titolasser": "titolare",
    "titolassero": "titolare",
    "titolassi": "titolare",
    "titolassimo": "titolare",
    "titolaste": "titolare",
    "titolasti": "titolare",
    "titolata": "titolato",
    "titolate": "titolato",
    "titolati": "titolato",
    "titolato": "titolare",
    "titolava": "titolare",
    "titolavamo": "titolare",
    "titolavan": "titolare",
    "titolavano": "titolare",
    "titolavate": "titolare",
    "titolavi": "titolare",
    "titolavo": "titolare",
    "titolazioni": "titolazione",
    "titolerai": "titolare",
    "titoleran": "titolare",
    "titoleranno": "titolare",
    "titolerebbe": "titolare",
    "titolerebber": "titolare",
    "titolerebbero": "titolare",
    "titolerei": "titolare",
    "titoleremmo": "titolare",
    "titoleremo": "titolare",
    "titolereste": "titolare",
    "titoleresti": "titolare",
    "titolerete": "titolare",
    "titolerà": "titolare",
    "titolerò": "titolare",
    "titoli": "titolo",
    "titoliamo": "titolare",
    "titoliate": "titolare",
    "titolin": "titolare",
    "titolini": "titolino",
    "titolino": "titolare",
    "titolisti": "titolista",
    "titolo": "titolare",
    "titoloni": "titolone",
    "titolò": "titolare",
    "tituba": "titubare",
    "titubai": "titubare",
    "titubammo": "titubare",
    "tituban": "titubare",
    "titubando": "titubare",
    "titubano": "titubare",
    "titubante": "titubare",
    "titubanti": "titubare",
    "titubanze": "titubanza",
    "titubar": "titubare",
    "titubaron": "titubare",
    "titubarono": "titubare",
    "titubasse": "titubare",
    "titubasser": "titubare",
    "titubassero": "titubare",
    "titubassi": "titubare",
    "titubassimo": "titubare",
    "titubaste": "titubare",
    "titubasti": "titubare",
    "titubata": "titubare",
    "titubate": "titubare",
    "titubati": "titubare",
    "titubato": "titubare",
    "titubava": "titubare",
    "titubavamo": "titubare",
    "titubavan": "titubare",
    "titubavano": "titubare",
    "titubavate": "titubare",
    "titubavi": "titubare",
    "titubavo": "titubare",
    "tituberai": "titubare",
    "tituberan": "titubare",
    "tituberanno": "titubare",
    "tituberebbe": "titubare",
    "tituberebber": "titubare",
    "tituberebbero": "titubare",
    "tituberei": "titubare",
    "tituberemmo": "titubare",
    "tituberemo": "titubare",
    "titubereste": "titubare",
    "tituberesti": "titubare",
    "tituberete": "titubare",
    "tituberà": "titubare",
    "tituberò": "titubare",
    "titubi": "titubare",
    "titubiamo": "titubare",
    "titubiate": "titubare",
    "titubin": "titubare",
    "titubino": "titubare",
    "titubo": "titubare",
    "titubò": "titubare",
    "tizi": "tizio",
    "tizianesca": "tizianesco",
    "tizianesche": "tizianesco",
    "tizianeschi": "tizianesco",
    "tizzoni": "tizzone",
    "tocca": "tocco",
    "toccai": "toccare",
    "toccamenti": "toccamento",
    "toccammo": "toccare",
    "toccan": "toccare",
    "toccando": "toccare",
    "toccano": "toccare",
    "toccante": "toccare",
    "toccanti": "toccare",
    "toccar": "toccare",
    "toccaron": "toccare",
    "toccarono": "toccare",
    "toccasse": "toccare",
    "toccasser": "toccare",
    "toccassero": "toccare",
    "toccassi": "toccare",
    "toccassimo": "toccare",
    "toccaste": "toccare",
    "toccasti": "toccare",
    "toccata": "toccato",
    "toccate": "toccato",
    "toccati": "toccato",
    "toccato": "toccare",
    "toccava": "toccare",
    "toccavamo": "toccare",
    "toccavan": "toccare",
    "toccavano": "toccare",
    "toccavate": "toccare",
    "toccavi": "toccare",
    "toccavo": "toccare",
    "tocche": "tocco",
    "toccherai": "toccare",
    "toccheran": "toccare",
    "toccheranno": "toccare",
    "toccherebbe": "toccare",
    "toccherebber": "toccare",
    "toccherebbero": "toccare",
    "toccherei": "toccare",
    "toccheremmo": "toccare",
    "toccheremo": "toccare",
    "tocchereste": "toccare",
    "toccheresti": "toccare",
    "toccherete": "toccare",
    "toccherà": "toccare",
    "toccherò": "toccare",
    "tocchetti": "tocchetto",
    "tocchi": "tocco",
    "tocchiamo": "toccare",
    "tocchiate": "toccare",
    "tocchin": "toccare",
    "tocchino": "toccare",
    "tocco": "toccare",
    "toccò": "toccare",
    "togata": "togato",
    "togate": "togato",
    "togati": "togato",
    "toghe": "toga",
    "togli": "togliere",
    "togliamo": "togliere",
    "togliate": "togliere",
    "toglie": "togliere",
    "togliemmo": "togliere",
    "togliendo": "togliere",
    "togliente": "togliere",
    "toglienti": "togliere",
    "toglier": "togliere",
    "toglierai": "togliere",
    "toglieran": "togliere",
    "toglieranno": "togliere",
    "toglierebbe": "togliere",
    "toglierebber": "togliere",
    "toglierebbero": "togliere",
    "toglierei": "togliere",
    "toglieremmo": "togliere",
    "toglieremo": "togliere",
    "togliereste": "togliere",
    "toglieresti": "togliere",
    "toglierete": "togliere",
    "toglierà": "togliere",
    "toglierò": "togliere",
    "togliesse": "togliere",
    "togliesser": "togliere",
    "togliessero": "togliere",
    "togliessi": "togliere",
    "togliessimo": "togliere",
    "toglieste": "togliere",
    "togliesti": "togliere",
    "togliete": "togliere",
    "toglieva": "togliere",
    "toglievamo": "togliere",
    "toglievan": "togliere",
    "toglievano": "togliere",
    "toglievate": "togliere",
    "toglievi": "togliere",
    "toglievo": "togliere",
    "toilettes": "toilette",
    "tolde": "tolda",
    "tolga": "togliere",
    "tolgan": "togliere",
    "tolgano": "togliere",
    "tolgo": "togliere",
    "tolgon": "togliere",
    "tolgono": "togliere",
    "tollera": "tollerare",
    "tollerabili": "tollerabile",
    "tollerai": "tollerare",
    "tollerammo": "tollerare",
    "tolleran": "tollerare",
    "tollerando": "tollerare",
    "tollerano": "tollerare",
    "tollerante": "tollerare",
    "tolleranti": "tollerare",
    "tolleranze": "tolleranza",
    "tollerar": "tollerare",
    "tolleraron": "tollerare",
    "tollerarono": "tollerare",
    "tollerasse": "tollerare",
    "tollerasser": "tollerare",
    "tollerassero": "tollerare",
    "tollerassi": "tollerare",
    "tollerassimo": "tollerare",
    "tolleraste": "tollerare",
    "tollerasti": "tollerare",
    "tollerata": "tollerare",
    "tollerate": "tollerare",
    "tollerati": "tollerare",
    "tollerato": "tollerare",
    "tollerava": "tollerare",
    "tolleravamo": "tollerare",
    "tolleravan": "tollerare",
    "tolleravano": "tollerare",
    "tolleravate": "tollerare",
    "tolleravi": "tollerare",
    "tolleravo": "tollerare",
    "tollererai": "tollerare",
    "tollereran": "tollerare",
    "tollereranno": "tollerare",
    "tollererebbe": "tollerare",
    "tollererebber": "tollerare",
    "tollererebbero": "tollerare",
    "tollererei": "tollerare",
    "tollereremmo": "tollerare",
    "tollereremo": "tollerare",
    "tollerereste": "tollerare",
    "tollereresti": "tollerare",
    "tollererete": "tollerare",
    "tollererà": "tollerare",
    "tollererò": "tollerare",
    "tolleri": "tollerare",
    "tolleriamo": "tollerare",
    "tolleriate": "tollerare",
    "tollerin": "tollerare",
    "tollerino": "tollerare",
    "tollero": "tollerare",
    "tollerò": "tollerare",
    "tolse": "togliere",
    "tolser": "togliere",
    "tolsero": "togliere",
    "tolsi": "togliere",
    "tolta": "tolto",
    "tolte": "tolto",
    "tolti": "tolto",
    "tolto": "togliere",
    "tombali": "tombale",
    "tombaroli": "tombarolo",
    "tombe": "tomba",
    "tombini": "tombino",
    "tombola": "tombolare",
    "tombolai": "tombolare",
    "tombolammo": "tombolare",
    "tombolan": "tombolare",
    "tombolando": "tombolare",
    "tombolano": "tombolare",
    "tombolante": "tombolare",
    "tombolanti": "tombolare",
    "tombolar": "tombolare",
    "tombolaron": "tombolare",
    "tombolarono": "tombolare",
    "tombolasse": "tombolare",
    "tombolasser": "tombolare",
    "tombolassero": "tombolare",
    "tombolassi": "tombolare",
    "tombolassimo": "tombolare",
    "tombolaste": "tombolare",
    "tombolasti": "tombolare",
    "tombolata": "tombolare",
    "tombolate": "tombolare",
    "tombolati": "tombolare",
    "tombolato": "tombolare",
    "tombolava": "tombolare",
    "tombolavamo": "tombolare",
    "tombolavan": "tombolare",
    "tombolavano": "tombolare",
    "tombolavate": "tombolare",
    "tombolavi": "tombolare",
    "tombolavo": "tombolare",
    "tombole": "tombola",
    "tombolerai": "tombolare",
    "tomboleran": "tombolare",
    "tomboleranno": "tombolare",
    "tombolerebbe": "tombolare",
    "tombolerebber": "tombolare",
    "tombolerebbero": "tombolare",
    "tombolerei": "tombolare",
    "tomboleremmo": "tombolare",
    "tomboleremo": "tombolare",
    "tombolereste": "tombolare",
    "tomboleresti": "tombolare",
    "tombolerete": "tombolare",
    "tombolerà": "tombolare",
    "tombolerò": "tombolare",
    "tomboli": "tombolare",
    "tomboliamo": "tombolare",
    "tomboliate": "tombolare",
    "tombolin": "tombolare",
    "tombolino": "tombolare",
    "tombolo": "tombolare",
    "tombolò": "tombolare",
    "tomi": "tomo",
    "tomografie": "tomografia",
    "tona": "tonare",
    "tonache": "tonaca",
    "tonai": "tonare",
    "tonali": "tonale",
    "tonammo": "tonare",
    "tonan": "tonare",
    "tonando": "tonare",
    "tonano": "tonare",
    "tonante": "tonare",
    "tonanti": "tonare",
    "tonar": "tonare",
    "tonaron": "tonare",
    "tonarono": "tonare",
    "tonasse": "tonare",
    "tonasser": "tonare",
    "tonassero": "tonare",
    "tonassi": "tonare",
    "tonassimo": "tonare",
    "tonaste": "tonare",
    "tonasti": "tonare",
    "tonata": "tonare",
    "tonate": "tonare",
    "tonati": "tonare",
    "tonato": "tonare",
    "tonava": "tonare",
    "tonavamo": "tonare",
    "tonavan": "tonare",
    "tonavano": "tonare",
    "tonavate": "tonare",
    "tonavi": "tonare",
    "tonavo": "tonare",
    "tonda": "tondo",
    "tonde": "tondo",
    "tondeggerai": "tondeggiare",
    "tondeggeran": "tondeggiare",
    "tondeggeranno": "tondeggiare",
    "tondeggerebbe": "tondeggiare",
    "tondeggerebber": "tondeggiare",
    "tondeggerebbero": "tondeggiare",
    "tondeggerei": "tondeggiare",
    "tondeggeremmo": "tondeggiare",
    "tondeggeremo": "tondeggiare",
    "tondeggereste": "tondeggiare",
    "tondeggeresti": "tondeggiare",
    "tondeggerete": "tondeggiare",
    "tondeggerà": "tondeggiare",
    "tondeggerò": "tondeggiare",
    "tondeggi": "tondeggiare",
    "tondeggia": "tondeggiare",
    "tondeggiai": "tondeggiare",
    "tondeggiammo": "tondeggiare",
    "tondeggiamo": "tondeggiare",
    "tondeggian": "tondeggiare",
    "tondeggiando": "tondeggiare",
    "tondeggiano": "tondeggiare",
    "tondeggiante": "tondeggiare",
    "tondeggianti": "tondeggiare",
    "tondeggiar": "tondeggiare",
    "tondeggiaron": "tondeggiare",
    "tondeggiarono": "tondeggiare",
    "tondeggiasse": "tondeggiare",
    "tondeggiasser": "tondeggiare",
    "tondeggiassero": "tondeggiare",
    "tondeggiassi": "tondeggiare",
    "tondeggiassimo": "tondeggiare",
    "tondeggiaste": "tondeggiare",
    "tondeggiasti": "tondeggiare",
    "tondeggiata": "tondeggiare",
    "tondeggiate": "tondeggiare",
    "tondeggiati": "tondeggiare",
    "tondeggiato": "tondeggiare",
    "tondeggiava": "tondeggiare",
    "tondeggiavamo": "tondeggiare",
    "tondeggiavan": "tondeggiare",
    "tondeggiavano": "tondeggiare",
    "tondeggiavate": "tondeggiare",
    "tondeggiavi": "tondeggiare",
    "tondeggiavo": "tondeggiare",
    "tondeggin": "tondeggiare",
    "tondeggino": "tondeggiare",
    "tondeggio": "tondeggiare",
    "tondeggiò": "tondeggiare",
    "tondi": "tondo",
    "tondini": "tondino",
    "tonerai": "tonare",
    "toneran": "tonare",
    "toneranno": "tonare",
    "tonerebbe": "tonare",
    "tonerebber": "tonare",
    "tonerebbero": "tonare",
    "tonerei": "tonare",
    "toneremmo": "tonare",
    "toneremo": "tonare",
    "tonereste": "tonare",
    "toneresti": "tonare",
    "tonerete": "tonare",
    "tonerà": "tonare",
    "tonerò": "tonare",
    "tonfa": "tonfare",
    "tonfai": "tonfare",
    "tonfammo": "tonfare",
    "tonfan": "tonfare",
    "tonfando": "tonfare",
    "tonfano": "tonfare",
    "tonfante": "tonfare",
    "tonfanti": "tonfare",
    "tonfar": "tonfare",
    "tonfaron": "tonfare",
    "tonfarono": "tonfare",
    "tonfasse": "tonfare",
    "tonfasser": "tonfare",
    "tonfassero": "tonfare",
    "tonfassi": "tonfare",
    "tonfassimo": "tonfare",
    "tonfaste": "tonfare",
    "tonfasti": "tonfare",
    "tonfata": "tonfare",
    "tonfate": "tonfare",
    "tonfati": "tonfare",
    "tonfato": "tonfare",
    "tonfava": "tonfare",
    "tonfavamo": "tonfare",
    "tonfavan": "tonfare",
    "tonfavano": "tonfare",
    "tonfavate": "tonfare",
    "tonfavi": "tonfare",
    "tonfavo": "tonfare",
    "tonferai": "tonfare",
    "tonferan": "tonfare",
    "tonferanno": "tonfare",
    "tonferebbe": "tonfare",
    "tonferebber": "tonfare",
    "tonferebbero": "tonfare",
    "tonferei": "tonfare",
    "tonferemmo": "tonfare",
    "tonferemo": "tonfare",
    "tonfereste": "tonfare",
    "tonferesti": "tonfare",
    "tonferete": "tonfare",
    "tonferà": "tonfare",
    "tonferò": "tonfare",
    "tonfi": "tonfo",
    "tonfiamo": "tonfare",
    "tonfiate": "tonfare",
    "tonfin": "tonfare",
    "tonfino": "tonfare",
    "tonfo": "tonfare",
    "tonfò": "tonfare",
    "toni": "tono",
    "toniamo": "tonare",
    "toniate": "tonare",
    "tonica": "tonico",
    "toniche": "tonico",
    "tonici": "tonico",
    "tonifica": "tonificare",
    "tonificai": "tonificare",
    "tonificammo": "tonificare",
    "tonifican": "tonificare",
    "tonificando": "tonificare",
    "tonificano": "tonificare",
    "tonificante": "tonificare",
    "tonificanti": "tonificare",
    "tonificar": "tonificare",
    "tonificaron": "tonificare",
    "tonificarono": "tonificare",
    "tonificasse": "tonificare",
    "tonificasser": "tonificare",
    "tonificassero": "tonificare",
    "tonificassi": "tonificare",
    "tonificassimo": "tonificare",
    "tonificaste": "tonificare",
    "tonificasti": "tonificare",
    "tonificata": "tonificare",
    "tonificate": "tonificare",
    "tonificati": "tonificare",
    "tonificato": "tonificare",
    "tonificava": "tonificare",
    "tonificavamo": "tonificare",
    "tonificavan": "tonificare",
    "tonificavano": "tonificare",
    "tonificavate": "tonificare",
    "tonificavi": "tonificare",
    "tonificavo": "tonificare",
    "tonificherai": "tonificare",
    "tonificheran": "tonificare",
    "tonificheranno": "tonificare",
    "tonificherebbe": "tonificare",
    "tonificherebber": "tonificare",
    "tonificherebbero": "tonificare",
    "tonificherei": "tonificare",
    "tonificheremmo": "tonificare",
    "tonificheremo": "tonificare",
    "tonifichereste": "tonificare",
    "tonificheresti": "tonificare",
    "tonificherete": "tonificare",
    "tonificherà": "tonificare",
    "tonificherò": "tonificare",
    "tonifichi": "tonificare",
    "tonifichiamo": "tonificare",
    "tonifichiate": "tonificare",
    "tonifichin": "tonificare",
    "tonifichino": "tonificare",
    "tonifico": "tonificare",
    "tonificò": "tonificare",
    "tonin": "tonare",
    "tonino": "tonare",
    "tonnare": "tonnara",
    "tonnellaggi": "tonnellaggio",
    "tonnellate": "tonnellata",
    "tonni": "tonno",
    "tono": "tonare",
    "tonsille": "tonsilla",
    "tonsilliti": "tonsillite",
    "tonsura": "tonsurare",
    "tonsurai": "tonsurare",
    "tonsurammo": "tonsurare",
    "tonsuran": "tonsurare",
    "tonsurando": "tonsurare",
    "tonsurano": "tonsurare",
    "tonsurante": "tonsurare",
    "tonsuranti": "tonsurare",
    "tonsurar": "tonsurare",
    "tonsuraron": "tonsurare",
    "tonsurarono": "tonsurare",
    "tonsurasse": "tonsurare",
    "tonsurasser": "tonsurare",
    "tonsurassero": "tonsurare",
    "tonsurassi": "tonsurare",
    "tonsurassimo": "tonsurare",
    "tonsuraste": "tonsurare",
    "tonsurasti": "tonsurare",
    "tonsurata": "tonsurare",
    "tonsurate": "tonsurare",
    "tonsurati": "tonsurare",
    "tonsurato": "tonsurare",
    "tonsurava": "tonsurare",
    "tonsuravamo": "tonsurare",
    "tonsuravan": "tonsurare",
    "tonsuravano": "tonsurare",
    "tonsuravate": "tonsurare",
    "tonsuravi": "tonsurare",
    "tonsuravo": "tonsurare",
    "tonsurerai": "tonsurare",
    "tonsureran": "tonsurare",
    "tonsureranno": "tonsurare",
    "tonsurerebbe": "tonsurare",
    "tonsurerebber": "tonsurare",
    "tonsurerebbero": "tonsurare",
    "tonsurerei": "tonsurare",
    "tonsureremmo": "tonsurare",
    "tonsureremo": "tonsurare",
    "tonsurereste": "tonsurare",
    "tonsureresti": "tonsurare",
    "tonsurerete": "tonsurare",
    "tonsurerà": "tonsurare",
    "tonsurerò": "tonsurare",
    "tonsuri": "tonsurare",
    "tonsuriamo": "tonsurare",
    "tonsuriate": "tonsurare",
    "tonsurin": "tonsurare",
    "tonsurino": "tonsurare",
    "tonsuro": "tonsurare",
    "tonsurò": "tonsurare",
    "tonta": "tonto",
    "tonte": "tonto",
    "tonti": "tonto",
    "tonò": "tonare",
    "topaie": "topaia",
    "topi": "topo",
    "topica": "topico",
    "topiche": "topico",
    "topici": "topico",
    "topini": "topino",
    "topografica": "topografico",
    "topografiche": "topografico",
    "topografici": "topografico",
    "topografie": "topografia",
    "topoi": "topos",
    "topolini": "topolino",
    "toponimi": "toponimo",
    "toponomastiche": "toponomastica",
    "toppe": "toppa",
    "toraci": "torace",
    "toracica": "toracico",
    "toraciche": "toracico",
    "toracici": "toracico",
    "torbida": "torbido",
    "torbide": "torbido",
    "torbidi": "torbido",
    "torca": "torcere",
    "torcan": "torcere",
    "torcano": "torcere",
    "torce": "torcia",
    "torcemmo": "torcere",
    "torcendo": "torcere",
    "torcente": "torcere",
    "torcenti": "torcere",
    "torcer": "torcere",
    "torcerai": "torcere",
    "torceran": "torcere",
    "torceranno": "torcere",
    "torcerebbe": "torcere",
    "torcerebber": "torcere",
    "torcerebbero": "torcere",
    "torcerei": "torcere",
    "torceremmo": "torcere",
    "torceremo": "torcere",
    "torcereste": "torcere",
    "torceresti": "torcere",
    "torcerete": "torcere",
    "torcerà": "torcere",
    "torcerò": "torcere",
    "torcesse": "torcere",
    "torcesser": "torcere",
    "torcessero": "torcere",
    "torcessi": "torcere",
    "torcessimo": "torcere",
    "torceste": "torcere",
    "torcesti": "torcere",
    "torcete": "torcere",
    "torceva": "torcere",
    "torcevamo": "torcere",
    "torcevan": "torcere",
    "torcevano": "torcere",
    "torcevate": "torcere",
    "torcevi": "torcere",
    "torcevo": "torcere",
    "torchi": "torchio",
    "torchia": "torchiare",
    "torchiai": "torchiare",
    "torchiammo": "torchiare",
    "torchiamo": "torchiare",
    "torchian": "torchiare",
    "torchiando": "torchiare",
    "torchiano": "torchiare",
    "torchiante": "torchiare",
    "torchianti": "torchiare",
    "torchiar": "torchiare",
    "torchiaron": "torchiare",
    "torchiarono": "torchiare",
    "torchiasse": "torchiare",
    "torchiasser": "torchiare",
    "torchiassero": "torchiare",
    "torchiassi": "torchiare",
    "torchiassimo": "torchiare",
    "torchiaste": "torchiare",
    "torchiasti": "torchiare",
    "torchiata": "torchiare",
    "torchiate": "torchiare",
    "torchiati": "torchiare",
    "torchiato": "torchiare",
    "torchiature": "torchiatura",
    "torchiava": "torchiare",
    "torchiavamo": "torchiare",
    "torchiavan": "torchiare",
    "torchiavano": "torchiare",
    "torchiavate": "torchiare",
    "torchiavi": "torchiare",
    "torchiavo": "torchiare",
    "torchierai": "torchiare",
    "torchieran": "torchiare",
    "torchieranno": "torchiare",
    "torchierebbe": "torchiare",
    "torchierebber": "torchiare",
    "torchierebbero": "torchiare",
    "torchierei": "torchiare",
    "torchieremmo": "torchiare",
    "torchieremo": "torchiare",
    "torchiereste": "torchiare",
    "torchieresti": "torchiare",
    "torchierete": "torchiare",
    "torchierà": "torchiare",
    "torchierò": "torchiare",
    "torchin": "torchiare",
    "torchino": "torchiare",
    "torchio": "torchiare",
    "torchiò": "torchiare",
    "torci": "torcere",
    "torciamo": "torcere",
    "torciate": "torcere",
    "torcicolli": "torcicollo",
    "torco": "torcere",
    "torcon": "torcere",
    "torcono": "torcere",
    "tordi": "tordo",
    "torea": "toreare",
    "toreai": "toreare",
    "toreammo": "toreare",
    "torean": "toreare",
    "toreando": "toreare",
    "toreano": "toreare",
    "toreante": "toreare",
    "toreanti": "toreare",
    "torear": "toreare",
    "torearon": "toreare",
    "torearono": "toreare",
    "toreasse": "toreare",
    "toreasser": "toreare",
    "toreassero": "toreare",
    "toreassi": "toreare",
    "toreassimo": "toreare",
    "toreaste": "toreare",
    "toreasti": "toreare",
    "toreata": "toreare",
    "toreate": "toreare",
    "toreati": "toreare",
    "toreato": "toreare",
    "toreava": "toreare",
    "toreavamo": "toreare",
    "toreavan": "toreare",
    "toreavano": "toreare",
    "toreavate": "toreare",
    "toreavi": "toreare",
    "toreavo": "toreare",
    "toreerai": "toreare",
    "toreeran": "toreare",
    "toreeranno": "toreare",
    "toreerebbe": "toreare",
    "toreerebber": "toreare",
    "toreerebbero": "toreare",
    "toreerei": "toreare",
    "toreeremmo": "toreare",
    "toreeremo": "toreare",
    "toreereste": "toreare",
    "toreeresti": "toreare",
    "toreerete": "toreare",
    "toreerà": "toreare",
    "toreerò": "toreare",
    "torei": "toreare",
    "toreiamo": "toreare",
    "toreiate": "toreare",
    "torein": "toreare",
    "toreino": "toreare",
    "torelli": "torello",
    "toreo": "toreare",
    "toreri": "torero",
    "toreò": "toreare",
    "tori": "toro",
    "tories": "tory",
    "torinesi": "torinese",
    "torinisti": "torinista",
    "torme": "torma",
    "tormenta": "tormentare",
    "tormentai": "tormentare",
    "tormentammo": "tormentare",
    "tormentan": "tormentare",
    "tormentando": "tormentare",
    "tormentano": "tormentare",
    "tormentante": "tormentare",
    "tormentanti": "tormentare",
    "tormentar": "tormentare",
    "tormentaron": "tormentare",
    "tormentarono": "tormentare",
    "tormentasse": "tormentare",
    "tormentasser": "tormentare",
    "tormentassero": "tormentare",
    "tormentassi": "tormentare",
    "tormentassimo": "tormentare",
    "tormentaste": "tormentare",
    "tormentasti": "tormentare",
    "tormentata": "tormentato",
    "tormentate": "tormentato",
    "tormentati": "tormentato",
    "tormentato": "tormentare",
    "tormentatori": "tormentatore",
    "tormentava": "tormentare",
    "tormentavamo": "tormentare",
    "tormentavan": "tormentare",
    "tormentavano": "tormentare",
    "tormentavate": "tormentare",
    "tormentavi": "tormentare",
    "tormentavo": "tormentare",
    "tormente": "tormenta",
    "tormenterai": "tormentare",
    "tormenteran": "tormentare",
    "tormenteranno": "tormentare",
    "tormenterebbe": "tormentare",
    "tormenterebber": "tormentare",
    "tormenterebbero": "tormentare",
    "tormenterei": "tormentare",
    "tormenteremmo": "tormentare",
    "tormenteremo": "tormentare",
    "tormentereste": "tormentare",
    "tormenteresti": "tormentare",
    "tormenterete": "tormentare",
    "tormenterà": "tormentare",
    "tormenterò": "tormentare",
    "tormenti": "tormento",
    "tormentiamo": "tormentare",
    "tormentiate": "tormentare",
    "tormentin": "tormentare",
    "tormentino": "tormentare",
    "tormento": "tormentare",
    "tormentoni": "tormentone",
    "tormentosa": "tormentoso",
    "tormentose": "tormentoso",
    "tormentosi": "tormentoso",
    "tormentò": "tormentare",
    "torna": "tornire",
    "tornaconti": "tornaconto",
    "tornai": "tornare",
    "tornammo": "tornare",
    "tornan": "tornire",
    "tornando": "tornare",
    "tornano": "tornire",
    "tornante": "tornare",
    "tornanti": "tornare",
    "tornar": "tornare",
    "tornaron": "tornare",
    "tornarono": "tornare",
    "tornasse": "tornare",
    "tornasser": "tornare",
    "tornassero": "tornare",
    "tornassi": "tornare",
    "tornassimo": "tornare",
    "tornaste": "tornare",
    "tornasti": "tornare",
    "tornata": "tornare",
    "tornate": "tornata",
    "tornati": "tornare",
    "tornato": "tornare",
    "tornava": "tornare",
    "tornavamo": "tornare",
    "tornavan": "tornare",
    "tornavano": "tornare",
    "tornavate": "tornare",
    "tornavi": "tornare",
    "tornavo": "tornare",
    "torne": "tornire",
    "tornea": "torneare",
    "torneai": "torneare",
    "torneammo": "torneare",
    "tornean": "torneare",
    "torneando": "torneare",
    "torneano": "torneare",
    "torneante": "torneare",
    "torneanti": "torneare",
    "tornear": "torneare",
    "tornearon": "torneare",
    "tornearono": "torneare",
    "torneasse": "torneare",
    "torneasser": "torneare",
    "torneassero": "torneare",
    "torneassi": "torneare",
    "torneassimo": "torneare",
    "torneaste": "torneare",
    "torneasti": "torneare",
    "torneata": "torneare",
    "torneate": "torneare",
    "torneati": "torneare",
    "torneato": "torneare",
    "torneava": "torneare",
    "torneavamo": "torneare",
    "torneavan": "torneare",
    "torneavano": "torneare",
    "torneavate": "torneare",
    "torneavi": "torneare",
    "torneavo": "torneare",
    "torneerai": "torneare",
    "torneeran": "torneare",
    "torneeranno": "torneare",
    "torneerebbe": "torneare",
    "torneerebber": "torneare",
    "torneerebbero": "torneare",
    "torneerei": "torneare",
    "torneeremmo": "torneare",
    "torneeremo": "torneare",
    "torneereste": "torneare",
    "torneeresti": "torneare",
    "torneerete": "torneare",
    "torneerà": "torneare",
    "torneerò": "torneare",
    "tornei": "torneo",
    "torneiamo": "torneare",
    "torneiate": "torneare",
    "tornein": "torneare",
    "torneini": "torneino",
    "torneino": "torneare",
    "tornendo": "tornire",
    "tornente": "tornire",
    "tornenti": "tornire",
    "torneo": "torneare",
    "tornerai": "tornare",
    "torneran": "tornare",
    "torneranno": "tornare",
    "tornerebbe": "tornare",
    "tornerebber": "tornare",
    "tornerebbero": "tornare",
    "tornerei": "tornare",
    "torneremmo": "tornare",
    "torneremo": "tornare",
    "tornereste": "tornare",
    "torneresti": "tornare",
    "tornerete": "tornare",
    "tornerà": "tornare",
    "tornerò": "tornare",
    "torneò": "torneare",
    "torni": "torno",
    "torniamo": "tornire",
    "torniate": "tornire",
    "tornii": "tornire",
    "tornimmo": "tornire",
    "tornin": "tornare",
    "tornino": "tornare",
    "tornir": "tornire",
    "tornirai": "tornire",
    "torniran": "tornire",
    "torniranno": "tornire",
    "tornirebbe": "tornire",
    "tornirebber": "tornire",
    "tornirebbero": "tornire",
    "tornirei": "tornire",
    "torniremmo": "tornire",
    "torniremo": "tornire",
    "tornireste": "tornire",
    "torniresti": "tornire",
    "tornirete": "tornire",
    "torniron": "tornire",
    "tornirono": "tornire",
    "tornirà": "tornire",
    "tornirò": "tornire",
    "tornisse": "tornire",
    "tornisser": "tornire",
    "tornissero": "tornire",
    "tornissi": "tornire",
    "tornissimo": "tornire",
    "torniste": "tornire",
    "tornisti": "tornire",
    "tornita": "tornito",
    "tornite": "tornito",
    "torniti": "tornito",
    "tornito": "tornire",
    "tornitori": "tornitore",
    "torniva": "tornire",
    "tornivamo": "tornire",
    "tornivan": "tornire",
    "tornivano": "tornire",
    "tornivate": "tornire",
    "tornivi": "tornire",
    "tornivo": "tornire",
    "torno": "tornire",
    "tornon": "tornire",
    "tornono": "tornire",
    "tornì": "tornire",
    "tornò": "tornare",
    "torpedoni": "torpedone",
    "torpida": "torpido",
    "torpide": "torpido",
    "torpidi": "torpido",
    "torpori": "torpore",
    "torrefa": "torrefare",
    "torrefai": "torrefare",
    "torrefammo": "torrefare",
    "torrefan": "torrefare",
    "torrefando": "torrefare",
    "torrefano": "torrefare",
    "torrefante": "torrefare",
    "torrefanti": "torrefare",
    "torrefar": "torrefare",
    "torrefaron": "torrefare",
    "torrefarono": "torrefare",
    "torrefasse": "torrefare",
    "torrefasser": "torrefare",
    "torrefassero": "torrefare",
    "torrefassi": "torrefare",
    "torrefassimo": "torrefare",
    "torrefaste": "torrefare",
    "torrefasti": "torrefare",
    "torrefata": "torrefare",
    "torrefate": "torrefare",
    "torrefati": "torrefare",
    "torrefato": "torrefare",
    "torrefattori": "torrefattore",
    "torrefava": "torrefare",
    "torrefavamo": "torrefare",
    "torrefavan": "torrefare",
    "torrefavano": "torrefare",
    "torrefavate": "torrefare",
    "torrefavi": "torrefare",
    "torrefavo": "torrefare",
    "torreferai": "torrefare",
    "torreferan": "torrefare",
    "torreferanno": "torrefare",
    "torreferebbe": "torrefare",
    "torreferebber": "torrefare",
    "torreferebbero": "torrefare",
    "torreferei": "torrefare",
    "torreferemmo": "torrefare",
    "torreferemo": "torrefare",
    "torrefereste": "torrefare",
    "torreferesti": "torrefare",
    "torreferete": "torrefare",
    "torreferà": "torrefare",
    "torreferò": "torrefare",
    "torrefi": "torrefare",
    "torrefiamo": "torrefare",
    "torrefiate": "torrefare",
    "torrefin": "torrefare",
    "torrefino": "torrefare",
    "torrefo": "torrefare",
    "torrefò": "torrefare",
    "torreggerai": "torreggiare",
    "torreggeran": "torreggiare",
    "torreggeranno": "torreggiare",
    "torreggerebbe": "torreggiare",
    "torreggerebber": "torreggiare",
    "torreggerebbero": "torreggiare",
    "torreggerei": "torreggiare",
    "torreggeremmo": "torreggiare",
    "torreggeremo": "torreggiare",
    "torreggereste": "torreggiare",
    "torreggeresti": "torreggiare",
    "torreggerete": "torreggiare",
    "torreggerà": "torreggiare",
    "torreggerò": "torreggiare",
    "torreggi": "torreggiare",
    "torreggia": "torreggiare",
    "torreggiai": "torreggiare",
    "torreggiammo": "torreggiare",
    "torreggiamo": "torreggiare",
    "torreggian": "torreggiare",
    "torreggiando": "torreggiare",
    "torreggiano": "torreggiare",
    "torreggiante": "torreggiare",
    "torreggianti": "torreggiare",
    "torreggiar": "torreggiare",
    "torreggiaron": "torreggiare",
    "torreggiarono": "torreggiare",
    "torreggiasse": "torreggiare",
    "torreggiasser": "torreggiare",
    "torreggiassero": "torreggiare",
    "torreggiassi": "torreggiare",
    "torreggiassimo": "torreggiare",
    "torreggiaste": "torreggiare",
    "torreggiasti": "torreggiare",
    "torreggiata": "torreggiare",
    "torreggiate": "torreggiare",
    "torreggiati": "torreggiare",
    "torreggiato": "torreggiare",
    "torreggiava": "torreggiare",
    "torreggiavamo": "torreggiare",
    "torreggiavan": "torreggiare",
    "torreggiavano": "torreggiare",
    "torreggiavate": "torreggiare",
    "torreggiavi": "torreggiare",
    "torreggiavo": "torreggiare",
    "torreggin": "torreggiare",
    "torreggino": "torreggiare",
    "torreggio": "torreggiare",
    "torreggiò": "torreggiare",
    "torrenti": "torrente",
    "torrentizi": "torrentizio",
    "torrentizia": "torrentizio",
    "torrentizie": "torrentizio",
    "torrenziali": "torrenziale",
    "torrette": "torretta",
    "torri": "torre",
    "torrida": "torrido",
    "torride": "torrido",
    "torridi": "torrido",
    "torrioni": "torrione",
    "torroni": "torrone",
    "torse": "torcere",
    "torser": "torcere",
    "torsero": "torcere",
    "torsi": "torso",
    "torsionali": "torsionale",
    "torsioni": "torsione",
    "torta": "torto",
    "torte": "torto",
    "tortelli": "tortello",
    "tortellini": "tortellino",
    "torti": "torto",
    "tortili": "tortile",
    "torto": "torcere",
    "tortore": "tortora",
    "tortuosa": "tortuoso",
    "tortuose": "tortuoso",
    "tortuosi": "tortuoso",
    "tortura": "torturare",
    "torturai": "torturare",
    "torturammo": "torturare",
    "torturan": "torturare",
    "torturando": "torturare",
    "torturano": "torturare",
    "torturante": "torturare",
    "torturanti": "torturare",
    "torturar": "torturare",
    "torturaron": "torturare",
    "torturarono": "torturare",
    "torturasse": "torturare",
    "torturasser": "torturare",
    "torturassero": "torturare",
    "torturassi": "torturare",
    "torturassimo": "torturare",
    "torturaste": "torturare",
    "torturasti": "torturare",
    "torturata": "torturare",
    "torturate": "torturare",
    "torturati": "torturato",
    "torturato": "torturare",
    "torturatori": "torturatore",
    "torturava": "torturare",
    "torturavamo": "torturare",
    "torturavan": "torturare",
    "torturavano": "torturare",
    "torturavate": "torturare",
    "torturavi": "torturare",
    "torturavo": "torturare",
    "torture": "tortura",
    "torturerai": "torturare",
    "tortureran": "torturare",
    "tortureranno": "torturare",
    "torturerebbe": "torturare",
    "torturerebber": "torturare",
    "torturerebbero": "torturare",
    "torturerei": "torturare",
    "tortureremmo": "torturare",
    "tortureremo": "torturare",
    "torturereste": "torturare",
    "tortureresti": "torturare",
    "torturerete": "torturare",
    "torturerà": "torturare",
    "torturerò": "torturare",
    "torturi": "torturare",
    "torturiamo": "torturare",
    "torturiate": "torturare",
    "torturin": "torturare",
    "torturino": "torturare",
    "torturo": "torturare",
    "torturò": "torturare",
    "torva": "torvo",
    "torve": "torvo",
    "torvi": "torvo",
    "tosa": "tosare",
    "tosai": "tosare",
    "tosammo": "tosare",
    "tosan": "tosare",
    "tosando": "tosare",
    "tosano": "tosare",
    "tosante": "tosare",
    "tosanti": "tosare",
    "tosar": "tosare",
    "tosaron": "tosare",
    "tosarono": "tosare",
    "tosasse": "tosare",
    "tosasser": "tosare",
    "tosassero": "tosare",
    "tosassi": "tosare",
    "tosassimo": "tosare",
    "tosaste": "tosare",
    "tosasti": "tosare",
    "tosata": "tosare",
    "tosate": "tosare",
    "tosati": "tosare",
    "tosato": "tosare",
    "tosava": "tosare",
    "tosavamo": "tosare",
    "tosavan": "tosare",
    "tosavano": "tosare",
    "tosavate": "tosare",
    "tosavi": "tosare",
    "tosavo": "tosare",
    "tosca": "tosco",
    "toscana": "toscano",
    "toscane": "toscano",
    "toscaneggerai": "toscaneggiare",
    "toscaneggeran": "toscaneggiare",
    "toscaneggeranno": "toscaneggiare",
    "toscaneggerebbe": "toscaneggiare",
    "toscaneggerebber": "toscaneggiare",
    "toscaneggerebbero": "toscaneggiare",
    "toscaneggerei": "toscaneggiare",
    "toscaneggeremmo": "toscaneggiare",
    "toscaneggeremo": "toscaneggiare",
    "toscaneggereste": "toscaneggiare",
    "toscaneggeresti": "toscaneggiare",
    "toscaneggerete": "toscaneggiare",
    "toscaneggerà": "toscaneggiare",
    "toscaneggerò": "toscaneggiare",
    "toscaneggi": "toscaneggiare",
    "toscaneggia": "toscaneggiare",
    "toscaneggiai": "toscaneggiare",
    "toscaneggiammo": "toscaneggiare",
    "toscaneggiamo": "toscaneggiare",
    "toscaneggian": "toscaneggiare",
    "toscaneggiando": "toscaneggiare",
    "toscaneggiano": "toscaneggiare",
    "toscaneggiante": "toscaneggiare",
    "toscaneggianti": "toscaneggiare",
    "toscaneggiar": "toscaneggiare",
    "toscaneggiaron": "toscaneggiare",
    "toscaneggiarono": "toscaneggiare",
    "toscaneggiasse": "toscaneggiare",
    "toscaneggiasser": "toscaneggiare",
    "toscaneggiassero": "toscaneggiare",
    "toscaneggiassi": "toscaneggiare",
    "toscaneggiassimo": "toscaneggiare",
    "toscaneggiaste": "toscaneggiare",
    "toscaneggiasti": "toscaneggiare",
    "toscaneggiata": "toscaneggiare",
    "toscaneggiate": "toscaneggiare",
    "toscaneggiati": "toscaneggiare",
    "toscaneggiato": "toscaneggiare",
    "toscaneggiava": "toscaneggiare",
    "toscaneggiavamo": "toscaneggiare",
    "toscaneggiavan": "toscaneggiare",
    "toscaneggiavano": "toscaneggiare",
    "toscaneggiavate": "toscaneggiare",
    "toscaneggiavi": "toscaneggiare",
    "toscaneggiavo": "toscaneggiare",
    "toscaneggin": "toscaneggiare",
    "toscaneggino": "toscaneggiare",
    "toscaneggio": "toscaneggiare",
    "toscaneggiò": "toscaneggiare",
    "toscani": "toscano",
    "toscanizza": "toscanizzare",
    "toscanizzai": "toscanizzare",
    "toscanizzammo": "toscanizzare",
    "toscanizzan": "toscanizzare",
    "toscanizzando": "toscanizzare",
    "toscanizzano": "toscanizzare",
    "toscanizzante": "toscanizzare",
    "toscanizzanti": "toscanizzare",
    "toscanizzar": "toscanizzare",
    "toscanizzaron": "toscanizzare",
    "toscanizzarono": "toscanizzare",
    "toscanizzasse": "toscanizzare",
    "toscanizzasser": "toscanizzare",
    "toscanizzassero": "toscanizzare",
    "toscanizzassi": "toscanizzare",
    "toscanizzassimo": "toscanizzare",
    "toscanizzaste": "toscanizzare",
    "toscanizzasti": "toscanizzare",
    "toscanizzata": "toscanizzare",
    "toscanizzate": "toscanizzare",
    "toscanizzati": "toscanizzare",
    "toscanizzato": "toscanizzare",
    "toscanizzava": "toscanizzare",
    "toscanizzavamo": "toscanizzare",
    "toscanizzavan": "toscanizzare",
    "toscanizzavano": "toscanizzare",
    "toscanizzavate": "toscanizzare",
    "toscanizzavi": "toscanizzare",
    "toscanizzavo": "toscanizzare",
    "toscanizzerai": "toscanizzare",
    "toscanizzeran": "toscanizzare",
    "toscanizzeranno": "toscanizzare",
    "toscanizzerebbe": "toscanizzare",
    "toscanizzerebber": "toscanizzare",
    "toscanizzerebbero": "toscanizzare",
    "toscanizzerei": "toscanizzare",
    "toscanizzeremmo": "toscanizzare",
    "toscanizzeremo": "toscanizzare",
    "toscanizzereste": "toscanizzare",
    "toscanizzeresti": "toscanizzare",
    "toscanizzerete": "toscanizzare",
    "toscanizzerà": "toscanizzare",
    "toscanizzerò": "toscanizzare",
    "toscanizzi": "toscanizzare",
    "toscanizziamo": "toscanizzare",
    "toscanizziate": "toscanizzare",
    "toscanizzin": "toscanizzare",
    "toscanizzino": "toscanizzare",
    "toscanizzo": "toscanizzare",
    "toscanizzò": "toscanizzare",
    "tosche": "tosco",
    "toschi": "tosco",
    "tosco-emiliana": "tosco-emiliano",
    "tosco-emiliane": "tosco-emiliano",
    "tosco-emiliani": "tosco-emiliano",
    "toserai": "tosare",
    "toseran": "tosare",
    "toseranno": "tosare",
    "toserebbe": "tosare",
    "toserebber": "tosare",
    "toserebbero": "tosare",
    "toserei": "tosare",
    "toseremmo": "tosare",
    "toseremo": "tosare",
    "tosereste": "tosare",
    "toseresti": "tosare",
    "toserete": "tosare",
    "toserà": "tosare",
    "toserò": "tosare",
    "tosi": "tosare",
    "tosiamo": "tosare",
    "tosiate": "tosare",
    "tosin": "tosare",
    "tosino": "tosare",
    "toso": "tosare",
    "tossendo": "tossire",
    "tossente": "tossire",
    "tossenti": "tossire",
    "tossi": "tosse",
    "tossiamo": "tossire",
    "tossiate": "tossire",
    "tossica": "tossico",
    "tossicchi": "tossicchiare",
    "tossicchia": "tossicchiare",
    "tossicchiai": "tossicchiare",
    "tossicchiammo": "tossicchiare",
    "tossicchiamo": "tossicchiare",
    "tossicchian": "tossicchiare",
    "tossicchiando": "tossicchiare",
    "tossicchiano": "tossicchiare",
    "tossicchiante": "tossicchiare",
    "tossicchianti": "tossicchiare",
    "tossicchiar": "tossicchiare",
    "tossicchiaron": "tossicchiare",
    "tossicchiarono": "tossicchiare",
    "tossicchiasse": "tossicchiare",
    "tossicchiasser": "tossicchiare",
    "tossicchiassero": "tossicchiare",
    "tossicchiassi": "tossicchiare",
    "tossicchiassimo": "tossicchiare",
    "tossicchiaste": "tossicchiare",
    "tossicchiasti": "tossicchiare",
    "tossicchiata": "tossicchiare",
    "tossicchiate": "tossicchiare",
    "tossicchiati": "tossicchiare",
    "tossicchiato": "tossicchiare",
    "tossicchiava": "tossicchiare",
    "tossicchiavamo": "tossicchiare",
    "tossicchiavan": "tossicchiare",
    "tossicchiavano": "tossicchiare",
    "tossicchiavate": "tossicchiare",
    "tossicchiavi": "tossicchiare",
    "tossicchiavo": "tossicchiare",
    "tossicchierai": "tossicchiare",
    "tossicchieran": "tossicchiare",
    "tossicchieranno": "tossicchiare",
    "tossicchierebbe": "tossicchiare",
    "tossicchierebber": "tossicchiare",
    "tossicchierebbero": "tossicchiare",
    "tossicchierei": "tossicchiare",
    "tossicchieremmo": "tossicchiare",
    "tossicchieremo": "tossicchiare",
    "tossicchiereste": "tossicchiare",
    "tossicchieresti": "tossicchiare",
    "tossicchierete": "tossicchiare",
    "tossicchierà": "tossicchiare",
    "tossicchierò": "tossicchiare",
    "tossicchin": "tossicchiare",
    "tossicchino": "tossicchiare",
    "tossicchio": "tossicchiare",
    "tossicchiò": "tossicchiare",
    "tossiche": "tossico",
    "tossici": "tossico",
    "tossicodipendenti": "tossicodipendente",
    "tossicodipendenze": "tossicodipendenza",
    "tossicologi": "tossicologo",
    "tossicologica": "tossicologico",
    "tossicologiche": "tossicologico",
    "tossicologici": "tossicologico",
    "tossicomani": "tossicomane",
    "tossicomanie": "tossicomania",
    "tossii": "tossire",
    "tossimmo": "tossire",
    "tossine": "tossina",
    "tossinfezioni": "tossinfezione",
    "tossir": "tossire",
    "tossirai": "tossire",
    "tossiran": "tossire",
    "tossiranno": "tossire",
    "tossirebbe": "tossire",
    "tossirebber": "tossire",
    "tossirebbero": "tossire",
    "tossirei": "tossire",
    "tossiremmo": "tossire",
    "tossiremo": "tossire",
    "tossireste": "tossire",
    "tossiresti": "tossire",
    "tossirete": "tossire",
    "tossiron": "tossire",
    "tossirono": "tossire",
    "tossirà": "tossire",
    "tossirò": "tossire",
    "tossisca": "tossire",
    "tossiscan": "tossire",
    "tossiscano": "tossire",
    "tossisce": "tossire",
    "tossisci": "tossire",
    "tossisco": "tossire",
    "tossiscon": "tossire",
    "tossiscono": "tossire",
    "tossisse": "tossire",
    "tossisser": "tossire",
    "tossissero": "tossire",
    "tossissi": "tossire",
    "tossissimo": "tossire",
    "tossiste": "tossire",
    "tossisti": "tossire",
    "tossita": "tossire",
    "tossite": "tossire",
    "tossiti": "tossire",
    "tossito": "tossire",
    "tossiva": "tossire",
    "tossivamo": "tossire",
    "tossivan": "tossire",
    "tossivano": "tossire",
    "tossivate": "tossire",
    "tossivi": "tossire",
    "tossivo": "tossire",
    "tossì": "tossire",
    "tosta": "tosto",
    "tostai": "tostare",
    "tostammo": "tostare",
    "tostan": "tostare",
    "tostando": "tostare",
    "tostano": "tostare",
    "tostante": "tostare",
    "tostanti": "tostare",
    "tostar": "tostare",
    "tostaron": "tostare",
    "tostarono": "tostare",
    "tostasse": "tostare",
    "tostasser": "tostare",
    "tostassero": "tostare",
    "tostassi": "tostare",
    "tostassimo": "tostare",
    "tostaste": "tostare",
    "tostasti": "tostare",
    "tostata": "tostare",
    "tostate": "tostare",
    "tostati": "tostare",
    "tostato": "tostare",
    "tostava": "tostare",
    "tostavamo": "tostare",
    "tostavan": "tostare",
    "tostavano": "tostare",
    "tostavate": "tostare",
    "tostavi": "tostare",
    "tostavo": "tostare",
    "toste": "tosto",
    "tosterai": "tostare",
    "tosteran": "tostare",
    "tosteranno": "tostare",
    "tosterebbe": "tostare",
    "tosterebber": "tostare",
    "tosterebbero": "tostare",
    "tosterei": "tostare",
    "tosteremmo": "tostare",
    "tosteremo": "tostare",
    "tostereste": "tostare",
    "tosteresti": "tostare",
    "tosterete": "tostare",
    "tosterà": "tostare",
    "tosterò": "tostare",
    "tosti": "tosto",
    "tostiamo": "tostare",
    "tostiate": "tostare",
    "tostin": "tostare",
    "tostino": "tostare",
    "tosto": "tostare",
    "tostò": "tostare",
    "tosò": "tosare",
    "totali": "totale",
    "totalitari": "totalitario",
    "totalitaria": "totalitario",
    "totalitarie": "totalitario",
    "totalitarismi": "totalitarismo",
    "totalizza": "totalizzare",
    "totalizzai": "totalizzare",
    "totalizzammo": "totalizzare",
    "totalizzan": "totalizzare",
    "totalizzando": "totalizzare",
    "totalizzano": "totalizzare",
    "totalizzante": "totalizzare",
    "totalizzanti": "totalizzare",
    "totalizzar": "totalizzare",
    "totalizzaron": "totalizzare",
    "totalizzarono": "totalizzare",
    "totalizzasse": "totalizzare",
    "totalizzasser": "totalizzare",
    "totalizzassero": "totalizzare",
    "totalizzassi": "totalizzare",
    "totalizzassimo": "totalizzare",
    "totalizzaste": "totalizzare",
    "totalizzasti": "totalizzare",
    "totalizzata": "totalizzare",
    "totalizzate": "totalizzare",
    "totalizzati": "totalizzare",
    "totalizzato": "totalizzare",
    "totalizzatori": "totalizzatore",
    "totalizzava": "totalizzare",
    "totalizzavamo": "totalizzare",
    "totalizzavan": "totalizzare",
    "totalizzavano": "totalizzare",
    "totalizzavate": "totalizzare",
    "totalizzavi": "totalizzare",
    "totalizzavo": "totalizzare",
    "totalizzerai": "totalizzare",
    "totalizzeran": "totalizzare",
    "totalizzeranno": "totalizzare",
    "totalizzerebbe": "totalizzare",
    "totalizzerebber": "totalizzare",
    "totalizzerebbero": "totalizzare",
    "totalizzerei": "totalizzare",
    "totalizzeremmo": "totalizzare",
    "totalizzeremo": "totalizzare",
    "totalizzereste": "totalizzare",
    "totalizzeresti": "totalizzare",
    "totalizzerete": "totalizzare",
    "totalizzerà": "totalizzare",
    "totalizzerò": "totalizzare",
    "totalizzi": "totalizzare",
    "totalizziamo": "totalizzare",
    "totalizziate": "totalizzare",
    "totalizzin": "totalizzare",
    "totalizzino": "totalizzare",
    "totalizzo": "totalizzare",
    "totalizzò": "totalizzare",
    "totemica": "totemico",
    "totemiche": "totemico",
    "totemici": "totemico",
    "totoneri": "totonero",
    "tovaglie": "tovaglia",
    "tovaglioli": "tovagliolo",
    "tovagliolini": "tovagliolino",
    "tozza": "tozzo",
    "tozze": "tozzo",
    "tozzi": "tozzo",
    "traballa": "traballare",
    "traballai": "traballare",
    "traballammo": "traballare",
    "traballan": "traballare",
    "traballando": "traballare",
    "traballano": "traballare",
    "traballante": "traballare",
    "traballanti": "traballare",
    "traballar": "traballare",
    "traballaron": "traballare",
    "traballarono": "traballare",
    "traballasse": "traballare",
    "traballasser": "traballare",
    "traballassero": "traballare",
    "traballassi": "traballare",
    "traballassimo": "traballare",
    "traballaste": "traballare",
    "traballasti": "traballare",
    "traballata": "traballare",
    "traballate": "traballare",
    "traballati": "traballare",
    "traballato": "traballare",
    "traballava": "traballare",
    "traballavamo": "traballare",
    "traballavan": "traballare",
    "traballavano": "traballare",
    "traballavate": "traballare",
    "traballavi": "traballare",
    "traballavo": "traballare",
    "traballerai": "traballare",
    "traballeran": "traballare",
    "traballeranno": "traballare",
    "traballerebbe": "traballare",
    "traballerebber": "traballare",
    "traballerebbero": "traballare",
    "traballerei": "traballare",
    "traballeremmo": "traballare",
    "traballeremo": "traballare",
    "traballereste": "traballare",
    "traballeresti": "traballare",
    "traballerete": "traballare",
    "traballerà": "traballare",
    "traballerò": "traballare",
    "traballi": "traballare",
    "traballiamo": "traballare",
    "traballiate": "traballare",
    "traballin": "traballare",
    "traballino": "traballare",
    "traballo": "traballare",
    "traballò": "traballare",
    "trabalza": "trabalzare",
    "trabalzai": "trabalzare",
    "trabalzammo": "trabalzare",
    "trabalzan": "trabalzare",
    "trabalzando": "trabalzare",
    "trabalzano": "trabalzare",
    "trabalzante": "trabalzare",
    "trabalzanti": "trabalzare",
    "trabalzar": "trabalzare",
    "trabalzaron": "trabalzare",
    "trabalzarono": "trabalzare",
    "trabalzasse": "trabalzare",
    "trabalzasser": "trabalzare",
    "trabalzassero": "trabalzare",
    "trabalzassi": "trabalzare",
    "trabalzassimo": "trabalzare",
    "trabalzaste": "trabalzare",
    "trabalzasti": "trabalzare",
    "trabalzata": "trabalzare",
    "trabalzate": "trabalzare",
    "trabalzati": "trabalzare",
    "trabalzato": "trabalzare",
    "trabalzava": "trabalzare",
    "trabalzavamo": "trabalzare",
    "trabalzavan": "trabalzare",
    "trabalzavano": "trabalzare",
    "trabalzavate": "trabalzare",
    "trabalzavi": "trabalzare",
    "trabalzavo": "trabalzare",
    "trabalzerai": "trabalzare",
    "trabalzeran": "trabalzare",
    "trabalzeranno": "trabalzare",
    "trabalzerebbe": "trabalzare",
    "trabalzerebber": "trabalzare",
    "trabalzerebbero": "trabalzare",
    "trabalzerei": "trabalzare",
    "trabalzeremmo": "trabalzare",
    "trabalzeremo": "trabalzare",
    "trabalzereste": "trabalzare",
    "trabalzeresti": "trabalzare",
    "trabalzerete": "trabalzare",
    "trabalzerà": "trabalzare",
    "trabalzerò": "trabalzare",
    "trabalzi": "trabalzare",
    "trabalziamo": "trabalzare",
    "trabalziate": "trabalzare",
    "trabalzin": "trabalzare",
    "trabalzino": "trabalzare",
    "trabalzo": "trabalzare",
    "trabalzò": "trabalzare",
    "trabiccoli": "trabiccolo",
    "trabocca": "traboccare",
    "traboccai": "traboccare",
    "traboccammo": "traboccare",
    "traboccan": "traboccare",
    "traboccando": "traboccare",
    "traboccano": "traboccare",
    "traboccante": "traboccare",
    "traboccanti": "traboccare",
    "traboccar": "traboccare",
    "traboccaron": "traboccare",
    "traboccarono": "traboccare",
    "traboccasse": "traboccare",
    "traboccasser": "traboccare",
    "traboccassero": "traboccare",
    "traboccassi": "traboccare",
    "traboccassimo": "traboccare",
    "traboccaste": "traboccare",
    "traboccasti": "traboccare",
    "traboccata": "traboccare",
    "traboccate": "traboccare",
    "traboccati": "traboccare",
    "traboccato": "traboccare",
    "traboccava": "traboccare",
    "traboccavamo": "traboccare",
    "traboccavan": "traboccare",
    "traboccavano": "traboccare",
    "traboccavate": "traboccare",
    "traboccavi": "traboccare",
    "traboccavo": "traboccare",
    "traboccherai": "traboccare",
    "traboccheran": "traboccare",
    "traboccheranno": "traboccare",
    "traboccherebbe": "traboccare",
    "traboccherebber": "traboccare",
    "traboccherebbero": "traboccare",
    "traboccherei": "traboccare",
    "traboccheremmo": "traboccare",
    "traboccheremo": "traboccare",
    "trabocchereste": "traboccare",
    "traboccheresti": "traboccare",
    "traboccherete": "traboccare",
    "traboccherà": "traboccare",
    "traboccherò": "traboccare",
    "trabocchetta": "trabocchetto",
    "trabocchette": "trabocchetto",
    "trabocchetti": "trabocchetto",
    "trabocchi": "traboccare",
    "trabocchiamo": "traboccare",
    "trabocchiate": "traboccare",
    "trabocchin": "traboccare",
    "trabocchino": "traboccare",
    "trabocco": "traboccare",
    "traboccò": "traboccare",
    "tracagnotta": "tracagnotto",
    "tracagnotte": "tracagnotto",
    "tracagnotti": "tracagnotto",
    "tracce": "traccia",
    "traccerai": "tracciare",
    "tracceran": "tracciare",
    "tracceranno": "tracciare",
    "traccerebbe": "tracciare",
    "traccerebber": "tracciare",
    "traccerebbero": "tracciare",
    "traccerei": "tracciare",
    "tracceremmo": "tracciare",
    "tracceremo": "tracciare",
    "traccereste": "tracciare",
    "tracceresti": "tracciare",
    "traccerete": "tracciare",
    "traccerà": "tracciare",
    "traccerò": "tracciare",
    "traccheggerai": "traccheggiare",
    "traccheggeran": "traccheggiare",
    "traccheggeranno": "traccheggiare",
    "traccheggerebbe": "traccheggiare",
    "traccheggerebber": "traccheggiare",
    "traccheggerebbero": "traccheggiare",
    "traccheggerei": "traccheggiare",
    "traccheggeremmo": "traccheggiare",
    "traccheggeremo": "traccheggiare",
    "traccheggereste": "traccheggiare",
    "traccheggeresti": "traccheggiare",
    "traccheggerete": "traccheggiare",
    "traccheggerà": "traccheggiare",
    "traccheggerò": "traccheggiare",
    "traccheggi": "traccheggiare",
    "traccheggia": "traccheggiare",
    "traccheggiai": "traccheggiare",
    "traccheggiamenti": "traccheggiamento",
    "traccheggiammo": "traccheggiare",
    "traccheggiamo": "traccheggiare",
    "traccheggian": "traccheggiare",
    "traccheggiando": "traccheggiare",
    "traccheggiano": "traccheggiare",
    "traccheggiante": "traccheggiare",
    "traccheggianti": "traccheggiare",
    "traccheggiar": "traccheggiare",
    "traccheggiaron": "traccheggiare",
    "traccheggiarono": "traccheggiare",
    "traccheggiasse": "traccheggiare",
    "traccheggiasser": "traccheggiare",
    "traccheggiassero": "traccheggiare",
    "traccheggiassi": "traccheggiare",
    "traccheggiassimo": "traccheggiare",
    "traccheggiaste": "traccheggiare",
    "traccheggiasti": "traccheggiare",
    "traccheggiata": "traccheggiare",
    "traccheggiate": "traccheggiare",
    "traccheggiati": "traccheggiare",
    "traccheggiato": "traccheggiare",
    "traccheggiava": "traccheggiare",
    "traccheggiavamo": "traccheggiare",
    "traccheggiavan": "traccheggiare",
    "traccheggiavano": "traccheggiare",
    "traccheggiavate": "traccheggiare",
    "traccheggiavi": "traccheggiare",
    "traccheggiavo": "traccheggiare",
    "traccheggin": "traccheggiare",
    "traccheggino": "traccheggiare",
    "traccheggio": "traccheggiare",
    "traccheggiò": "traccheggiare",
    "tracci": "tracciare",
    "traccia": "tracciare",
    "tracciai": "tracciare",
    "tracciammo": "tracciare",
    "tracciamo": "tracciare",
    "traccian": "tracciare",
    "tracciando": "tracciare",
    "tracciano": "tracciare",
    "tracciante": "tracciare",
    "traccianti": "tracciare",
    "tracciar": "tracciare",
    "tracciaron": "tracciare",
    "tracciarono": "tracciare",
    "tracciasse": "tracciare",
    "tracciasser": "tracciare",
    "tracciassero": "tracciare",
    "tracciassi": "tracciare",
    "tracciassimo": "tracciare",
    "tracciaste": "tracciare",
    "tracciasti": "tracciare",
    "tracciata": "tracciato",
    "tracciate": "tracciato",
    "tracciati": "tracciato",
    "tracciato": "tracciare",
    "tracciatori": "tracciatore",
    "tracciava": "tracciare",
    "tracciavamo": "tracciare",
    "tracciavan": "tracciare",
    "tracciavano": "tracciare",
    "tracciavate": "tracciare",
    "tracciavi": "tracciare",
    "tracciavo": "tracciare",
    "traccie": "traccia",
    "traccin": "tracciare",
    "traccino": "tracciare",
    "traccio": "tracciare",
    "tracciò": "tracciare",
    "trachee": "trachea",
    "tracima": "tracimare",
    "tracimai": "tracimare",
    "tracimammo": "tracimare",
    "traciman": "tracimare",
    "tracimando": "tracimare",
    "tracimano": "tracimare",
    "tracimante": "tracimare",
    "tracimanti": "tracimare",
    "tracimar": "tracimare",
    "tracimaron": "tracimare",
    "tracimarono": "tracimare",
    "tracimasse": "tracimare",
    "tracimasser": "tracimare",
    "tracimassero": "tracimare",
    "tracimassi": "tracimare",
    "tracimassimo": "tracimare",
    "tracimaste": "tracimare",
    "tracimasti": "tracimare",
    "tracimata": "tracimare",
    "tracimate": "tracimare",
    "tracimati": "tracimare",
    "tracimato": "tracimare",
    "tracimava": "tracimare",
    "tracimavamo": "tracimare",
    "tracimavan": "tracimare",
    "tracimavano": "tracimare",
    "tracimavate": "tracimare",
    "tracimavi": "tracimare",
    "tracimavo": "tracimare",
    "tracimazioni": "tracimazione",
    "tracimerai": "tracimare",
    "tracimeran": "tracimare",
    "tracimeranno": "tracimare",
    "tracimerebbe": "tracimare",
    "tracimerebber": "tracimare",
    "tracimerebbero": "tracimare",
    "tracimerei": "tracimare",
    "tracimeremmo": "tracimare",
    "tracimeremo": "tracimare",
    "tracimereste": "tracimare",
    "tracimeresti": "tracimare",
    "tracimerete": "tracimare",
    "tracimerà": "tracimare",
    "tracimerò": "tracimare",
    "tracimi": "tracimare",
    "tracimiamo": "tracimare",
    "tracimiate": "tracimare",
    "tracimin": "tracimare",
    "tracimino": "tracimare",
    "tracimo": "tracimare",
    "tracimò": "tracimare",
    "tracolla": "tracollare",
    "tracollai": "tracollare",
    "tracollammo": "tracollare",
    "tracollan": "tracollare",
    "tracollando": "tracollare",
    "tracollano": "tracollare",
    "tracollante": "tracollare",
    "tracollanti": "tracollare",
    "tracollar": "tracollare",
    "tracollaron": "tracollare",
    "tracollarono": "tracollare",
    "tracollasse": "tracollare",
    "tracollasser": "tracollare",
    "tracollassero": "tracollare",
    "tracollassi": "tracollare",
    "tracollassimo": "tracollare",
    "tracollaste": "tracollare",
    "tracollasti": "tracollare",
    "tracollata": "tracollare",
    "tracollate": "tracollare",
    "tracollati": "tracollare",
    "tracollato": "tracollare",
    "tracollava": "tracollare",
    "tracollavamo": "tracollare",
    "tracollavan": "tracollare",
    "tracollavano": "tracollare",
    "tracollavate": "tracollare",
    "tracollavi": "tracollare",
    "tracollavo": "tracollare",
    "tracollerai": "tracollare",
    "tracolleran": "tracollare",
    "tracolleranno": "tracollare",
    "tracollerebbe": "tracollare",
    "tracollerebber": "tracollare",
    "tracollerebbero": "tracollare",
    "tracollerei": "tracollare",
    "tracolleremmo": "tracollare",
    "tracolleremo": "tracollare",
    "tracollereste": "tracollare",
    "tracolleresti": "tracollare",
    "tracollerete": "tracollare",
    "tracollerà": "tracollare",
    "tracollerò": "tracollare",
    "tracolli": "tracollo",
    "tracolliamo": "tracollare",
    "tracolliate": "tracollare",
    "tracollin": "tracollare",
    "tracollino": "tracollare",
    "tracollo": "tracollare",
    "tracollò": "tracollare",
    "tracotanti": "tracotante",
    "tracotanze": "tracotanza",
    "tradendo": "tradire",
    "tradente": "tradire",
    "tradenti": "tradire",
    "tradiamo": "tradire",
    "tradiate": "tradire",
    "tradii": "tradire",
    "tradimenti": "tradimento",
    "tradimmo": "tradire",
    "tradir": "tradire",
    "tradirai": "tradire",
    "tradiran": "tradire",
    "tradiranno": "tradire",
    "tradirebbe": "tradire",
    "tradirebber": "tradire",
    "tradirebbero": "tradire",
    "tradirei": "tradire",
    "tradiremmo": "tradire",
    "tradiremo": "tradire",
    "tradireste": "tradire",
    "tradiresti": "tradire",
    "tradirete": "tradire",
    "tradiron": "tradire",
    "tradirono": "tradire",
    "tradirà": "tradire",
    "tradirò": "tradire",
    "tradisca": "tradire",
    "tradiscan": "tradire",
    "tradiscano": "tradire",
    "tradisce": "tradire",
    "tradisci": "tradire",
    "tradisco": "tradire",
    "tradiscon": "tradire",
    "tradiscono": "tradire",
    "tradisse": "tradire",
    "tradisser": "tradire",
    "tradissero": "tradire",
    "tradissi": "tradire",
    "tradissimo": "tradire",
    "tradiste": "tradire",
    "tradisti": "tradire",
    "tradita": "tradire",
    "tradite": "tradire",
    "traditi": "tradito",
    "tradito": "tradire",
    "traditori": "traditore",
    "traditrice": "traditore",
    "traditrici": "traditore",
    "tradiva": "tradire",
    "tradivamo": "tradire",
    "tradivan": "tradire",
    "tradivano": "tradire",
    "tradivate": "tradire",
    "tradivi": "tradire",
    "tradivo": "tradire",
    "tradizionali": "tradizionale",
    "tradizionalismi": "tradizionalismo",
    "tradizionaliste": "tradizionalista",
    "tradizionalisti": "tradizionalista",
    "tradizioni": "tradizione",
    "tradotta": "tradurre",
    "tradotte": "tradurre",
    "tradotti": "tradurre",
    "tradotto": "tradurre",
    "traduca": "tradurre",
    "traducan": "tradurre",
    "traducano": "tradurre",
    "traduce": "tradurre",
    "traducemmo": "tradurre",
    "traducendo": "tradurre",
    "traducente": "tradurre",
    "traducenti": "tradurre",
    "traducesse": "tradurre",
    "traducesser": "tradurre",
    "traducessero": "tradurre",
    "traducessi": "tradurre",
    "traducessimo": "tradurre",
    "traduceste": "tradurre",
    "traducesti": "tradurre",
    "traducete": "tradurre",
    "traduceva": "tradurre",
    "traducevamo": "tradurre",
    "traducevan": "tradurre",
    "traducevano": "tradurre",
    "traducevate": "tradurre",
    "traducevi": "tradurre",
    "traducevo": "tradurre",
    "traduci": "tradurre",
    "traduciamo": "tradurre",
    "traduciate": "tradurre",
    "traducibili": "traducibile",
    "traduco": "tradurre",
    "traducon": "tradurre",
    "traducono": "tradurre",
    "tradurr": "tradurre",
    "tradurrai": "tradurre",
    "tradurran": "tradurre",
    "tradurranno": "tradurre",
    "tradurrebbe": "tradurre",
    "tradurrebber": "tradurre",
    "tradurrebbero": "tradurre",
    "tradurrei": "tradurre",
    "tradurremmo": "tradurre",
    "tradurremo": "tradurre",
    "tradurreste": "tradurre",
    "tradurresti": "tradurre",
    "tradurrete": "tradurre",
    "tradurrà": "tradurre",
    "tradurrò": "tradurre",
    "tradusse": "tradurre",
    "tradusser": "tradurre",
    "tradussero": "tradurre",
    "tradussi": "tradurre",
    "traduttori": "traduttore",
    "traduttrici": "traduttrice",
    "traduzioni": "traduzione",
    "tradì": "tradire",
    "trae": "trarre",
    "traemmo": "trarre",
    "traendo": "trarre",
    "traente": "trarre",
    "traenti": "trarre",
    "traesse": "trarre",
    "traesser": "trarre",
    "traessero": "trarre",
    "traessi": "trarre",
    "traessimo": "trarre",
    "traeste": "trarre",
    "traesti": "trarre",
    "traete": "trarre",
    "traeva": "trarre",
    "traevamo": "trarre",
    "traevan": "trarre",
    "traevano": "trarre",
    "traevate": "trarre",
    "traevi": "trarre",
    "traevo": "trarre",
    "trafelata": "trafelato",
    "trafelate": "trafelato",
    "trafelati": "trafelato",
    "traferimenti": "traferimento",
    "traffica": "trafficare",
    "trafficai": "trafficare",
    "trafficammo": "trafficare",
    "traffican": "trafficare",
    "trafficando": "trafficare",
    "trafficano": "trafficare",
    "trafficante": "trafficare",
    "trafficanti": "trafficare",
    "trafficar": "trafficare",
    "trafficaron": "trafficare",
    "trafficarono": "trafficare",
    "trafficasse": "trafficare",
    "trafficasser": "trafficare",
    "trafficassero": "trafficare",
    "trafficassi": "trafficare",
    "trafficassimo": "trafficare",
    "trafficaste": "trafficare",
    "trafficasti": "trafficare",
    "trafficata": "trafficare",
    "trafficate": "trafficare",
    "trafficati": "trafficare",
    "trafficato": "trafficare",
    "trafficava": "trafficare",
    "trafficavamo": "trafficare",
    "trafficavan": "trafficare",
    "trafficavano": "trafficare",
    "trafficavate": "trafficare",
    "trafficavi": "trafficare",
    "trafficavo": "trafficare",
    "trafficherai": "trafficare",
    "trafficheran": "trafficare",
    "trafficheranno": "trafficare",
    "trafficherebbe": "trafficare",
    "trafficherebber": "trafficare",
    "trafficherebbero": "trafficare",
    "trafficherei": "trafficare",
    "trafficheremmo": "trafficare",
    "trafficheremo": "trafficare",
    "traffichereste": "trafficare",
    "trafficheresti": "trafficare",
    "trafficherete": "trafficare",
    "trafficherà": "trafficare",
    "trafficherò": "trafficare",
    "traffichi": "trafficare",
    "traffichiamo": "trafficare",
    "traffichiate": "trafficare",
    "traffichin": "trafficare",
    "traffichino": "trafficare",
    "traffici": "traffico",
    "traffico": "trafficare",
    "trafficò": "trafficare",
    "trafigga": "trafiggere",
    "trafiggan": "trafiggere",
    "trafiggano": "trafiggere",
    "trafigge": "trafiggere",
    "trafiggemmo": "trafiggere",
    "trafiggendo": "trafiggere",
    "trafiggente": "trafiggere",
    "trafiggenti": "trafiggere",
    "trafigger": "trafiggere",
    "trafiggerai": "trafiggere",
    "trafiggeran": "trafiggere",
    "trafiggeranno": "trafiggere",
    "trafiggerebbe": "trafiggere",
    "trafiggerebber": "trafiggere",
    "trafiggerebbero": "trafiggere",
    "trafiggerei": "trafiggere",
    "trafiggeremmo": "trafiggere",
    "trafiggeremo": "trafiggere",
    "trafiggereste": "trafiggere",
    "trafiggeresti": "trafiggere",
    "trafiggerete": "trafiggere",
    "trafiggerà": "trafiggere",
    "trafiggerò": "trafiggere",
    "trafiggesse": "trafiggere",
    "trafiggesser": "trafiggere",
    "trafiggessero": "trafiggere",
    "trafiggessi": "trafiggere",
    "trafiggessimo": "trafiggere",
    "trafiggeste": "trafiggere",
    "trafiggesti": "trafiggere",
    "trafiggete": "trafiggere",
    "trafiggeva": "trafiggere",
    "trafiggevamo": "trafiggere",
    "trafiggevan": "trafiggere",
    "trafiggevano": "trafiggere",
    "trafiggevate": "trafiggere",
    "trafiggevi": "trafiggere",
    "trafiggevo": "trafiggere",
    "trafiggi": "trafiggere",
    "trafiggiamo": "trafiggere",
    "trafiggiate": "trafiggere",
    "trafiggo": "trafiggere",
    "trafiggon": "trafiggere",
    "trafiggono": "trafiggere",
    "trafila": "trafilare",
    "trafilai": "trafilare",
    "trafilammo": "trafilare",
    "trafilan": "trafilare",
    "trafilando": "trafilare",
    "trafilano": "trafilare",
    "trafilante": "trafilare",
    "trafilanti": "trafilare",
    "trafilar": "trafilare",
    "trafilaron": "trafilare",
    "trafilarono": "trafilare",
    "trafilasse": "trafilare",
    "trafilasser": "trafilare",
    "trafilassero": "trafilare",
    "trafilassi": "trafilare",
    "trafilassimo": "trafilare",
    "trafilaste": "trafilare",
    "trafilasti": "trafilare",
    "trafilata": "trafilare",
    "trafilate": "trafilare",
    "trafilati": "trafilare",
    "trafilato": "trafilare",
    "trafilava": "trafilare",
    "trafilavamo": "trafilare",
    "trafilavan": "trafilare",
    "trafilavano": "trafilare",
    "trafilavate": "trafilare",
    "trafilavi": "trafilare",
    "trafilavo": "trafilare",
    "trafile": "trafila",
    "trafilerai": "trafilare",
    "trafileran": "trafilare",
    "trafileranno": "trafilare",
    "trafilerebbe": "trafilare",
    "trafilerebber": "trafilare",
    "trafilerebbero": "trafilare",
    "trafilerei": "trafilare",
    "trafileremmo": "trafilare",
    "trafileremo": "trafilare",
    "trafilereste": "trafilare",
    "trafileresti": "trafilare",
    "trafilerete": "trafilare",
    "trafilerà": "trafilare",
    "trafilerò": "trafilare",
    "trafiletti": "trafiletto",
    "trafili": "trafilare",
    "trafiliamo": "trafilare",
    "trafiliate": "trafilare",
    "trafilin": "trafilare",
    "trafilino": "trafilare",
    "trafilo": "trafilare",
    "trafilò": "trafilare",
    "trafisser": "trafiggere",
    "trafissero": "trafiggere",
    "trafissi": "trafiggere",
    "trafissè": "trafiggere",
    "trafitta": "trafiggere",
    "trafitte": "trafiggere",
    "trafitti": "trafiggere",
    "trafitto": "trafiggere",
    "trafori": "traforo",
    "trafuga": "trafugare",
    "trafugai": "trafugare",
    "trafugamenti": "trafugamento",
    "trafugammo": "trafugare",
    "trafugan": "trafugare",
    "trafugando": "trafugare",
    "trafugano": "trafugare",
    "trafugante": "trafugare",
    "trafuganti": "trafugare",
    "trafugar": "trafugare",
    "trafugaron": "trafugare",
    "trafugarono": "trafugare",
    "trafugasse": "trafugare",
    "trafugasser": "trafugare",
    "trafugassero": "trafugare",
    "trafugassi": "trafugare",
    "trafugassimo": "trafugare",
    "trafugaste": "trafugare",
    "trafugasti": "trafugare",
    "trafugata": "trafugare",
    "trafugate": "trafugare",
    "trafugati": "trafugare",
    "trafugato": "trafugare",
    "trafugava": "trafugare",
    "trafugavamo": "trafugare",
    "trafugavan": "trafugare",
    "trafugavano": "trafugare",
    "trafugavate": "trafugare",
    "trafugavi": "trafugare",
    "trafugavo": "trafugare",
    "trafugherai": "trafugare",
    "trafugheran": "trafugare",
    "trafugheranno": "trafugare",
    "trafugherebbe": "trafugare",
    "trafugherebber": "trafugare",
    "trafugherebbero": "trafugare",
    "trafugherei": "trafugare",
    "trafugheremmo": "trafugare",
    "trafugheremo": "trafugare",
    "trafughereste": "trafugare",
    "trafugheresti": "trafugare",
    "trafugherete": "trafugare",
    "trafugherà": "trafugare",
    "trafugherò": "trafugare",
    "trafughi": "trafugare",
    "trafughiamo": "trafugare",
    "trafughiate": "trafugare",
    "trafughin": "trafugare",
    "trafughino": "trafugare",
    "trafugo": "trafugare",
    "trafugò": "trafugare",
    "tragedie": "tragedia",
    "tragga": "trarre",
    "traggan": "trarre",
    "traggano": "trarre",
    "traggo": "trarre",
    "traggon": "trarre",
    "traggono": "trarre",
    "traghetta": "traghetto",
    "traghettai": "traghettare",
    "traghettammo": "traghettare",
    "traghettan": "traghettare",
    "traghettando": "traghettare",
    "traghettano": "traghettare",
    "traghettante": "traghettare",
    "traghettanti": "traghettare",
    "traghettar": "traghettare",
    "traghettaron": "traghettare",
    "traghettarono": "traghettare",
    "traghettasse": "traghettare",
    "traghettasser": "traghettare",
    "traghettassero": "traghettare",
    "traghettassi": "traghettare",
    "traghettassimo": "traghettare",
    "traghettaste": "traghettare",
    "traghettasti": "traghettare",
    "traghettata": "traghettare",
    "traghettate": "traghettare",
    "traghettati": "traghettare",
    "traghettato": "traghettare",
    "traghettatori": "traghettatore",
    "traghettava": "traghettare",
    "traghettavamo": "traghettare",
    "traghettavan": "traghettare",
    "traghettavano": "traghettare",
    "traghettavate": "traghettare",
    "traghettavi": "traghettare",
    "traghettavo": "traghettare",
    "traghette": "traghetto",
    "traghetterai": "traghettare",
    "traghetteran": "traghettare",
    "traghetteranno": "traghettare",
    "traghetterebbe": "traghettare",
    "traghetterebber": "traghettare",
    "traghetterebbero": "traghettare",
    "traghetterei": "traghettare",
    "traghetteremmo": "traghettare",
    "traghetteremo": "traghettare",
    "traghettereste": "traghettare",
    "traghetteresti": "traghettare",
    "traghetterete": "traghettare",
    "traghetterà": "traghettare",
    "traghetterò": "traghettare",
    "traghetti": "traghetto",
    "traghettiamo": "traghettare",
    "traghettiate": "traghettare",
    "traghettin": "traghettare",
    "traghettino": "traghettare",
    "traghetto": "traghettare",
    "traghettò": "traghettare",
    "tragica": "tragico",
    "tragiche": "tragico",
    "tragici": "tragico",
    "tragicomica": "tragicomico",
    "tragicomiche": "tragicomico",
    "tragicomici": "tragicomico",
    "tragicommedie": "tragicommedia",
    "tragitti": "tragitto",
    "traguardi": "traguardo",
    "trai": "trarre",
    "traiamo": "trarre",
    "traiate": "trarre",
    "traiettorie": "traiettoria",
    "traina": "trainare",
    "trainai": "trainare",
    "trainammo": "trainare",
    "trainan": "trainare",
    "trainando": "trainare",
    "trainano": "trainare",
    "trainante": "trainare",
    "trainanti": "trainare",
    "trainar": "trainare",
    "trainaron": "trainare",
    "trainarono": "trainare",
    "trainasse": "trainare",
    "trainasser": "trainare",
    "trainassero": "trainare",
    "trainassi": "trainare",
    "trainassimo": "trainare",
    "trainaste": "trainare",
    "trainasti": "trainare",
    "trainata": "trainare",
    "trainate": "trainare",
    "trainati": "trainare",
    "trainato": "trainare",
    "trainava": "trainare",
    "trainavamo": "trainare",
    "trainavan": "trainare",
    "trainavano": "trainare",
    "trainavate": "trainare",
    "trainavi": "trainare",
    "trainavo": "trainare",
    "trainerai": "trainare",
    "traineran": "trainare",
    "traineranno": "trainare",
    "trainerebbe": "trainare",
    "trainerebber": "trainare",
    "trainerebbero": "trainare",
    "trainerei": "trainare",
    "traineremmo": "trainare",
    "traineremo": "trainare",
    "trainereste": "trainare",
    "traineresti": "trainare",
    "trainerete": "trainare",
    "trainerà": "trainare",
    "trainerò": "trainare",
    "traini": "traino",
    "trainiamo": "trainare",
    "trainiate": "trainare",
    "trainin": "trainare",
    "trainino": "trainare",
    "traino": "trainare",
    "trainò": "trainare",
    "tralascerai": "tralasciare",
    "tralasceran": "tralasciare",
    "tralasceranno": "tralasciare",
    "tralascerebbe": "tralasciare",
    "tralascerebber": "tralasciare",
    "tralascerebbero": "tralasciare",
    "tralascerei": "tralasciare",
    "tralasceremmo": "tralasciare",
    "tralasceremo": "tralasciare",
    "tralascereste": "tralasciare",
    "tralasceresti": "tralasciare",
    "tralascerete": "tralasciare",
    "tralascerà": "tralasciare",
    "tralascerò": "tralasciare",
    "tralasci": "tralasciare",
    "tralascia": "tralasciare",
    "tralasciai": "tralasciare",
    "tralasciammo": "tralasciare",
    "tralasciamo": "tralasciare",
    "tralascian": "tralasciare",
    "tralasciando": "tralasciare",
    "tralasciano": "tralasciare",
    "tralasciante": "tralasciare",
    "tralascianti": "tralasciare",
    "tralasciar": "tralasciare",
    "tralasciaron": "tralasciare",
    "tralasciarono": "tralasciare",
    "tralasciasse": "tralasciare",
    "tralasciasser": "tralasciare",
    "tralasciassero": "tralasciare",
    "tralasciassi": "tralasciare",
    "tralasciassimo": "tralasciare",
    "tralasciaste": "tralasciare",
    "tralasciasti": "tralasciare",
    "tralasciata": "tralasciare",
    "tralasciate": "tralasciare",
    "tralasciati": "tralasciare",
    "tralasciato": "tralasciare",
    "tralasciava": "tralasciare",
    "tralasciavamo": "tralasciare",
    "tralasciavan": "tralasciare",
    "tralasciavano": "tralasciare",
    "tralasciavate": "tralasciare",
    "tralasciavi": "tralasciare",
    "tralasciavo": "tralasciare",
    "tralascin": "tralasciare",
    "tralascino": "tralasciare",
    "tralascio": "tralasciare",
    "tralasciò": "tralasciare",
    "tralicci": "traliccio",
    "traligna": "tralignare",
    "tralignai": "tralignare",
    "tralignammo": "tralignare",
    "tralignan": "tralignare",
    "tralignando": "tralignare",
    "tralignano": "tralignare",
    "tralignante": "tralignare",
    "tralignanti": "tralignare",
    "tralignar": "tralignare",
    "tralignaron": "tralignare",
    "tralignarono": "tralignare",
    "tralignasse": "tralignare",
    "tralignasser": "tralignare",
    "tralignassero": "tralignare",
    "tralignassi": "tralignare",
    "tralignassimo": "tralignare",
    "tralignaste": "tralignare",
    "tralignasti": "tralignare",
    "tralignata": "tralignare",
    "tralignate": "tralignare",
    "tralignati": "tralignare",
    "tralignato": "tralignare",
    "tralignava": "tralignare",
    "tralignavamo": "tralignare",
    "tralignavan": "tralignare",
    "tralignavano": "tralignare",
    "tralignavate": "tralignare",
    "tralignavi": "tralignare",
    "tralignavo": "tralignare",
    "tralignerai": "tralignare",
    "traligneran": "tralignare",
    "traligneranno": "tralignare",
    "tralignerebbe": "tralignare",
    "tralignerebber": "tralignare",
    "tralignerebbero": "tralignare",
    "tralignerei": "tralignare",
    "traligneremmo": "tralignare",
    "traligneremo": "tralignare",
    "tralignereste": "tralignare",
    "traligneresti": "tralignare",
    "tralignerete": "tralignare",
    "tralignerà": "tralignare",
    "tralignerò": "tralignare",
    "traligni": "tralignare",
    "traligniamo": "tralignare",
    "traligniate": "tralignare",
    "tralignin": "tralignare",
    "tralignino": "tralignare",
    "traligno": "tralignare",
    "tralignò": "tralignare",
    "traluca": "tralucere",
    "tralucan": "tralucere",
    "tralucano": "tralucere",
    "traluce": "tralucere",
    "tralucei": "tralucere",
    "tralucemmo": "tralucere",
    "tralucendo": "tralucere",
    "tralucente": "tralucere",
    "tralucenti": "tralucere",
    "tralucer": "tralucere",
    "tralucerai": "tralucere",
    "traluceran": "tralucere",
    "traluceranno": "tralucere",
    "tralucerebbe": "tralucere",
    "tralucerebber": "tralucere",
    "tralucerebbero": "tralucere",
    "tralucerei": "tralucere",
    "traluceremmo": "tralucere",
    "traluceremo": "tralucere",
    "tralucereste": "tralucere",
    "traluceresti": "tralucere",
    "tralucerete": "tralucere",
    "traluceron": "tralucere",
    "tralucerono": "tralucere",
    "tralucerà": "tralucere",
    "tralucerò": "tralucere",
    "tralucesse": "tralucere",
    "tralucesser": "tralucere",
    "tralucessero": "tralucere",
    "tralucessi": "tralucere",
    "tralucessimo": "tralucere",
    "traluceste": "tralucere",
    "tralucesti": "tralucere",
    "tralucete": "tralucere",
    "traluceva": "tralucere",
    "tralucevamo": "tralucere",
    "tralucevan": "tralucere",
    "tralucevano": "tralucere",
    "tralucevate": "tralucere",
    "tralucevi": "tralucere",
    "tralucevo": "tralucere",
    "traluci": "tralucere",
    "traluciamo": "tralucere",
    "traluciate": "tralucere",
    "traluciuta": "tralucere",
    "traluciute": "tralucere",
    "traluciuti": "tralucere",
    "traluciuto": "tralucere",
    "traluco": "tralucere",
    "tralucon": "tralucere",
    "tralucono": "tralucere",
    "tralucè": "tralucere",
    "trama": "tramare",
    "tramai": "tramare",
    "tramammo": "tramare",
    "traman": "tramare",
    "tramanda": "tramandare",
    "tramandai": "tramandare",
    "tramandammo": "tramandare",
    "tramandan": "tramandare",
    "tramandando": "tramandare",
    "tramandano": "tramandare",
    "tramandante": "tramandare",
    "tramandanti": "tramandare",
    "tramandar": "tramandare",
    "tramandaron": "tramandare",
    "tramandarono": "tramandare",
    "tramandasse": "tramandare",
    "tramandasser": "tramandare",
    "tramandassero": "tramandare",
    "tramandassi": "tramandare",
    "tramandassimo": "tramandare",
    "tramandaste": "tramandare",
    "tramandasti": "tramandare",
    "tramandata": "tramandare",
    "tramandate": "tramandare",
    "tramandati": "tramandare",
    "tramandato": "tramandare",
    "tramandava": "tramandare",
    "tramandavamo": "tramandare",
    "tramandavan": "tramandare",
    "tramandavano": "tramandare",
    "tramandavate": "tramandare",
    "tramandavi": "tramandare",
    "tramandavo": "tramandare",
    "tramanderai": "tramandare",
    "tramanderan": "tramandare",
    "tramanderanno": "tramandare",
    "tramanderebbe": "tramandare",
    "tramanderebber": "tramandare",
    "tramanderebbero": "tramandare",
    "tramanderei": "tramandare",
    "tramanderemmo": "tramandare",
    "tramanderemo": "tramandare",
    "tramandereste": "tramandare",
    "tramanderesti": "tramandare",
    "tramanderete": "tramandare",
    "tramanderà": "tramandare",
    "tramanderò": "tramandare",
    "tramandi": "tramandare",
    "tramandiamo": "tramandare",
    "tramandiate": "tramandare",
    "tramandin": "tramandare",
    "tramandino": "tramandare",
    "tramando": "tramare",
    "tramandò": "tramandare",
    "tramano": "tramare",
    "tramante": "tramare",
    "tramanti": "tramare",
    "tramar": "tramare",
    "tramaron": "tramare",
    "tramarono": "tramare",
    "tramasse": "tramare",
    "tramasser": "tramare",
    "tramassero": "tramare",
    "tramassi": "tramare",
    "tramassimo": "tramare",
    "tramaste": "tramare",
    "tramasti": "tramare",
    "tramata": "tramare",
    "tramate": "tramare",
    "tramati": "tramare",
    "tramato": "tramare",
    "tramava": "tramare",
    "tramavamo": "tramare",
    "tramavan": "tramare",
    "tramavano": "tramare",
    "tramavate": "tramare",
    "tramavi": "tramare",
    "tramavo": "tramare",
    "trambusti": "trambusto",
    "trame": "trama",
    "tramerai": "tramare",
    "trameran": "tramare",
    "trameranno": "tramare",
    "tramerebbe": "tramare",
    "tramerebber": "tramare",
    "tramerebbero": "tramare",
    "tramerei": "tramare",
    "trameremmo": "tramare",
    "trameremo": "tramare",
    "tramereste": "tramare",
    "trameresti": "tramare",
    "tramerete": "tramare",
    "tramerà": "tramare",
    "tramerò": "tramare",
    "tramesta": "tramestare",
    "tramestai": "tramestare",
    "tramestammo": "tramestare",
    "tramestan": "tramestare",
    "tramestando": "tramestare",
    "tramestano": "tramestare",
    "tramestante": "tramestare",
    "tramestanti": "tramestare",
    "tramestar": "tramestare",
    "tramestaron": "tramestare",
    "tramestarono": "tramestare",
    "tramestasse": "tramestare",
    "tramestasser": "tramestare",
    "tramestassero": "tramestare",
    "tramestassi": "tramestare",
    "tramestassimo": "tramestare",
    "tramestaste": "tramestare",
    "tramestasti": "tramestare",
    "tramestata": "tramestare",
    "tramestate": "tramestare",
    "tramestati": "tramestare",
    "tramestato": "tramestare",
    "tramestava": "tramestare",
    "tramestavamo": "tramestare",
    "tramestavan": "tramestare",
    "tramestavano": "tramestare",
    "tramestavate": "tramestare",
    "tramestavi": "tramestare",
    "tramestavo": "tramestare",
    "tramesterai": "tramestare",
    "tramesteran": "tramestare",
    "tramesteranno": "tramestare",
    "tramesterebbe": "tramestare",
    "tramesterebber": "tramestare",
    "tramesterebbero": "tramestare",
    "tramesterei": "tramestare",
    "tramesteremmo": "tramestare",
    "tramesteremo": "tramestare",
    "tramestereste": "tramestare",
    "tramesteresti": "tramestare",
    "tramesterete": "tramestare",
    "tramesterà": "tramestare",
    "tramesterò": "tramestare",
    "tramesti": "tramestare",
    "tramestiamo": "tramestare",
    "tramestiate": "tramestare",
    "tramestin": "tramestare",
    "tramestino": "tramestare",
    "tramesto": "tramestare",
    "tramestò": "tramestare",
    "tramezza": "tramezzare",
    "tramezzai": "tramezzare",
    "tramezzammo": "tramezzare",
    "tramezzan": "tramezzare",
    "tramezzando": "tramezzare",
    "tramezzano": "tramezzare",
    "tramezzante": "tramezzare",
    "tramezzanti": "tramezzare",
    "tramezzar": "tramezzare",
    "tramezzaron": "tramezzare",
    "tramezzarono": "tramezzare",
    "tramezzasse": "tramezzare",
    "tramezzasser": "tramezzare",
    "tramezzassero": "tramezzare",
    "tramezzassi": "tramezzare",
    "tramezzassimo": "tramezzare",
    "tramezzaste": "tramezzare",
    "tramezzasti": "tramezzare",
    "tramezzata": "tramezzare",
    "tramezzate": "tramezzare",
    "tramezzati": "tramezzare",
    "tramezzato": "tramezzare",
    "tramezzava": "tramezzare",
    "tramezzavamo": "tramezzare",
    "tramezzavan": "tramezzare",
    "tramezzavano": "tramezzare",
    "tramezzavate": "tramezzare",
    "tramezzavi": "tramezzare",
    "tramezzavo": "tramezzare",
    "tramezzerai": "tramezzare",
    "tramezzeran": "tramezzare",
    "tramezzeranno": "tramezzare",
    "tramezzerebbe": "tramezzare",
    "tramezzerebber": "tramezzare",
    "tramezzerebbero": "tramezzare",
    "tramezzerei": "tramezzare",
    "tramezzeremmo": "tramezzare",
    "tramezzeremo": "tramezzare",
    "tramezzereste": "tramezzare",
    "tramezzeresti": "tramezzare",
    "tramezzerete": "tramezzare",
    "tramezzerà": "tramezzare",
    "tramezzerò": "tramezzare",
    "tramezzi": "tramezzo",
    "tramezziamo": "tramezzare",
    "tramezziate": "tramezzare",
    "tramezzin": "tramezzare",
    "tramezzini": "tramezzino",
    "tramezzino": "tramezzare",
    "tramezzo": "tramezzare",
    "tramezzò": "tramezzare",
    "trami": "tramare",
    "tramiamo": "tramare",
    "tramiate": "tramare",
    "tramin": "tramare",
    "tramino": "tramare",
    "tramissioni": "tramissione",
    "tramo": "tramare",
    "tramonta": "tramontare",
    "tramontai": "tramontare",
    "tramontammo": "tramontare",
    "tramontan": "tramontare",
    "tramontando": "tramontare",
    "tramontane": "tramontana",
    "tramontano": "tramontare",
    "tramontante": "tramontare",
    "tramontanti": "tramontare",
    "tramontar": "tramontare",
    "tramontaron": "tramontare",
    "tramontarono": "tramontare",
    "tramontasse": "tramontare",
    "tramontasser": "tramontare",
    "tramontassero": "tramontare",
    "tramontassi": "tramontare",
    "tramontassimo": "tramontare",
    "tramontaste": "tramontare",
    "tramontasti": "tramontare",
    "tramontata": "tramontare",
    "tramontate": "tramontare",
    "tramontati": "tramontare",
    "tramontato": "tramontare",
    "tramontava": "tramontare",
    "tramontavamo": "tramontare",
    "tramontavan": "tramontare",
    "tramontavano": "tramontare",
    "tramontavate": "tramontare",
    "tramontavi": "tramontare",
    "tramontavo": "tramontare",
    "tramonterai": "tramontare",
    "tramonteran": "tramontare",
    "tramonteranno": "tramontare",
    "tramonterebbe": "tramontare",
    "tramonterebber": "tramontare",
    "tramonterebbero": "tramontare",
    "tramonterei": "tramontare",
    "tramonteremmo": "tramontare",
    "tramonteremo": "tramontare",
    "tramontereste": "tramontare",
    "tramonteresti": "tramontare",
    "tramonterete": "tramontare",
    "tramonterà": "tramontare",
    "tramonterò": "tramontare",
    "tramonti": "tramonto",
    "tramontiamo": "tramontare",
    "tramontiate": "tramontare",
    "tramontin": "tramontare",
    "tramontino": "tramontare",
    "tramonto": "tramontare",
    "tramontò": "tramontare",
    "tramorta": "tramortire",
    "tramortan": "tramortire",
    "tramortano": "tramortire",
    "tramorte": "tramortire",
    "tramortendo": "tramortire",
    "tramortente": "tramortire",
    "tramortenti": "tramortire",
    "tramorti": "tramortire",
    "tramortiamo": "tramortire",
    "tramortiate": "tramortire",
    "tramortii": "tramortire",
    "tramortimmo": "tramortire",
    "tramortir": "tramortire",
    "tramortirai": "tramortire",
    "tramortiran": "tramortire",
    "tramortiranno": "tramortire",
    "tramortirebbe": "tramortire",
    "tramortirebber": "tramortire",
    "tramortirebbero": "tramortire",
    "tramortirei": "tramortire",
    "tramortiremmo": "tramortire",
    "tramortiremo": "tramortire",
    "tramortireste": "tramortire",
    "tramortiresti": "tramortire",
    "tramortirete": "tramortire",
    "tramortiron": "tramortire",
    "tramortirono": "tramortire",
    "tramortirà": "tramortire",
    "tramortirò": "tramortire",
    "tramortisse": "tramortire",
    "tramortisser": "tramortire",
    "tramortissero": "tramortire",
    "tramortissi": "tramortire",
    "tramortissimo": "tramortire",
    "tramortiste": "tramortire",
    "tramortisti": "tramortire",
    "tramortita": "tramortire",
    "tramortite": "tramortire",
    "tramortiti": "tramortire",
    "tramortito": "tramortire",
    "tramortiva": "tramortire",
    "tramortivamo": "tramortire",
    "tramortivan": "tramortire",
    "tramortivano": "tramortire",
    "tramortivate": "tramortire",
    "tramortivi": "tramortire",
    "tramortivo": "tramortire",
    "tramorto": "tramortire",
    "tramorton": "tramortire",
    "tramortono": "tramortire",
    "tramortì": "tramortire",
    "trampoli": "trampolo",
    "trampolieri": "trampoliere",
    "trampolini": "trampolino",
    "tramuta": "tramutare",
    "tramutai": "tramutare",
    "tramutammo": "tramutare",
    "tramutan": "tramutare",
    "tramutando": "tramutare",
    "tramutano": "tramutare",
    "tramutante": "tramutare",
    "tramutanti": "tramutare",
    "tramutar": "tramutare",
    "tramutaron": "tramutare",
    "tramutarono": "tramutare",
    "tramutasse": "tramutare",
    "tramutasser": "tramutare",
    "tramutassero": "tramutare",
    "tramutassi": "tramutare",
    "tramutassimo": "tramutare",
    "tramutaste": "tramutare",
    "tramutasti": "tramutare",
    "tramutata": "tramutare",
    "tramutate": "tramutare",
    "tramutati": "tramutare",
    "tramutato": "tramutare",
    "tramutava": "tramutare",
    "tramutavamo": "tramutare",
    "tramutavan": "tramutare",
    "tramutavano": "tramutare",
    "tramutavate": "tramutare",
    "tramutavi": "tramutare",
    "tramutavo": "tramutare",
    "tramuterai": "tramutare",
    "tramuteran": "tramutare",
    "tramuteranno": "tramutare",
    "tramuterebbe": "tramutare",
    "tramuterebber": "tramutare",
    "tramuterebbero": "tramutare",
    "tramuterei": "tramutare",
    "tramuteremmo": "tramutare",
    "tramuteremo": "tramutare",
    "tramutereste": "tramutare",
    "tramuteresti": "tramutare",
    "tramuterete": "tramutare",
    "tramuterà": "tramutare",
    "tramuterò": "tramutare",
    "tramuti": "tramutare",
    "tramutiamo": "tramutare",
    "tramutiate": "tramutare",
    "tramutin": "tramutare",
    "tramutino": "tramutare",
    "tramuto": "tramutare",
    "tramutò": "tramutare",
    "tramvieri": "tramviere",
    "tramò": "tramare",
    "trancerai": "tranciare",
    "tranceran": "tranciare",
    "tranceranno": "tranciare",
    "trancerebbe": "tranciare",
    "trancerebber": "tranciare",
    "trancerebbero": "tranciare",
    "trancerei": "tranciare",
    "tranceremmo": "tranciare",
    "tranceremo": "tranciare",
    "trancereste": "tranciare",
    "tranceresti": "tranciare",
    "trancerete": "tranciare",
    "trancerà": "tranciare",
    "trancerò": "tranciare",
    "tranches": "tranche",
    "tranci": "tranciare",
    "trancia": "tranciare",
    "tranciai": "tranciare",
    "tranciammo": "tranciare",
    "tranciamo": "tranciare",
    "trancian": "tranciare",
    "tranciando": "tranciare",
    "tranciano": "tranciare",
    "tranciante": "tranciare",
    "trancianti": "tranciare",
    "tranciar": "tranciare",
    "tranciaron": "tranciare",
    "tranciarono": "tranciare",
    "tranciasse": "tranciare",
    "tranciasser": "tranciare",
    "tranciassero": "tranciare",
    "tranciassi": "tranciare",
    "tranciassimo": "tranciare",
    "tranciaste": "tranciare",
    "tranciasti": "tranciare",
    "tranciata": "tranciare",
    "tranciate": "tranciare",
    "tranciati": "tranciare",
    "tranciato": "tranciare",
    "tranciava": "tranciare",
    "tranciavamo": "tranciare",
    "tranciavan": "tranciare",
    "tranciavano": "tranciare",
    "tranciavate": "tranciare",
    "tranciavi": "tranciare",
    "tranciavo": "tranciare",
    "trancin": "tranciare",
    "trancino": "tranciare",
    "trancio": "tranciare",
    "tranciò": "tranciare",
    "tranelli": "tranello",
    "trangugerai": "trangugiare",
    "trangugeran": "trangugiare",
    "trangugeranno": "trangugiare",
    "trangugerebbe": "trangugiare",
    "trangugerebber": "trangugiare",
    "trangugerebbero": "trangugiare",
    "trangugerei": "trangugiare",
    "trangugeremmo": "trangugiare",
    "trangugeremo": "trangugiare",
    "trangugereste": "trangugiare",
    "trangugeresti": "trangugiare",
    "trangugerete": "trangugiare",
    "trangugerà": "trangugiare",
    "trangugerò": "trangugiare",
    "trangugi": "trangugiare",
    "trangugia": "trangugiare",
    "trangugiai": "trangugiare",
    "trangugiammo": "trangugiare",
    "trangugiamo": "trangugiare",
    "trangugian": "trangugiare",
    "trangugiando": "trangugiare",
    "trangugiano": "trangugiare",
    "trangugiante": "trangugiare",
    "trangugianti": "trangugiare",
    "trangugiar": "trangugiare",
    "trangugiaron": "trangugiare",
    "trangugiarono": "trangugiare",
    "trangugiasse": "trangugiare",
    "trangugiasser": "trangugiare",
    "trangugiassero": "trangugiare",
    "trangugiassi": "trangugiare",
    "trangugiassimo": "trangugiare",
    "trangugiaste": "trangugiare",
    "trangugiasti": "trangugiare",
    "trangugiata": "trangugiare",
    "trangugiate": "trangugiare",
    "trangugiati": "trangugiare",
    "trangugiato": "trangugiare",
    "trangugiava": "trangugiare",
    "trangugiavamo": "trangugiare",
    "trangugiavan": "trangugiare",
    "trangugiavano": "trangugiare",
    "trangugiavate": "trangugiare",
    "trangugiavi": "trangugiare",
    "trangugiavo": "trangugiare",
    "trangugin": "trangugiare",
    "trangugino": "trangugiare",
    "trangugio": "trangugiare",
    "trangugiò": "trangugiare",
    "tranquilla": "tranquillo",
    "tranquillai": "tranquillare",
    "tranquillammo": "tranquillare",
    "tranquillan": "tranquillare",
    "tranquillando": "tranquillare",
    "tranquillano": "tranquillare",
    "tranquillante": "tranquillare",
    "tranquillanti": "tranquillare",
    "tranquillar": "tranquillare",
    "tranquillaron": "tranquillare",
    "tranquillarono": "tranquillare",
    "tranquillasse": "tranquillare",
    "tranquillasser": "tranquillare",
    "tranquillassero": "tranquillare",
    "tranquillassi": "tranquillare",
    "tranquillassimo": "tranquillare",
    "tranquillaste": "tranquillare",
    "tranquillasti": "tranquillare",
    "tranquillata": "tranquillare",
    "tranquillate": "tranquillare",
    "tranquillati": "tranquillare",
    "tranquillato": "tranquillare",
    "tranquillava": "tranquillare",
    "tranquillavamo": "tranquillare",
    "tranquillavan": "tranquillare",
    "tranquillavano": "tranquillare",
    "tranquillavate": "tranquillare",
    "tranquillavi": "tranquillare",
    "tranquillavo": "tranquillare",
    "tranquille": "tranquillo",
    "tranquillerai": "tranquillare",
    "tranquilleran": "tranquillare",
    "tranquilleranno": "tranquillare",
    "tranquillerebbe": "tranquillare",
    "tranquillerebber": "tranquillare",
    "tranquillerebbero": "tranquillare",
    "tranquillerei": "tranquillare",
    "tranquilleremmo": "tranquillare",
    "tranquilleremo": "tranquillare",
    "tranquillereste": "tranquillare",
    "tranquilleresti": "tranquillare",
    "tranquillerete": "tranquillare",
    "tranquillerà": "tranquillare",
    "tranquillerò": "tranquillare",
    "tranquilli": "tranquillo",
    "tranquilliamo": "tranquillare",
    "tranquilliate": "tranquillare",
    "tranquillin": "tranquillare",
    "tranquillino": "tranquillare",
    "tranquillizza": "tranquillizzare",
    "tranquillizzai": "tranquillizzare",
    "tranquillizzammo": "tranquillizzare",
    "tranquillizzan": "tranquillizzare",
    "tranquillizzando": "tranquillizzare",
    "tranquillizzano": "tranquillizzare",
    "tranquillizzante": "tranquillizzare",
    "tranquillizzanti": "tranquillizzare",
    "tranquillizzar": "tranquillizzare",
    "tranquillizzaron": "tranquillizzare",
    "tranquillizzarono": "tranquillizzare",
    "tranquillizzasse": "tranquillizzare",
    "tranquillizzasser": "tranquillizzare",
    "tranquillizzassero": "tranquillizzare",
    "tranquillizzassi": "tranquillizzare",
    "tranquillizzassimo": "tranquillizzare",
    "tranquillizzaste": "tranquillizzare",
    "tranquillizzasti": "tranquillizzare",
    "tranquillizzata": "tranquillizzare",
    "tranquillizzate": "tranquillizzare",
    "tranquillizzati": "tranquillizzare",
    "tranquillizzato": "tranquillizzare",
    "tranquillizzava": "tranquillizzare",
    "tranquillizzavamo": "tranquillizzare",
    "tranquillizzavan": "tranquillizzare",
    "tranquillizzavano": "tranquillizzare",
    "tranquillizzavate": "tranquillizzare",
    "tranquillizzavi": "tranquillizzare",
    "tranquillizzavo": "tranquillizzare",
    "tranquillizzerai": "tranquillizzare",
    "tranquillizzeran": "tranquillizzare",
    "tranquillizzeranno": "tranquillizzare",
    "tranquillizzerebbe": "tranquillizzare",
    "tranquillizzerebber": "tranquillizzare",
    "tranquillizzerebbero": "tranquillizzare",
    "tranquillizzerei": "tranquillizzare",
    "tranquillizzeremmo": "tranquillizzare",
    "tranquillizzeremo": "tranquillizzare",
    "tranquillizzereste": "tranquillizzare",
    "tranquillizzeresti": "tranquillizzare",
    "tranquillizzerete": "tranquillizzare",
    "tranquillizzerà": "tranquillizzare",
    "tranquillizzerò": "tranquillizzare",
    "tranquillizzi": "tranquillizzare",
    "tranquillizziamo": "tranquillizzare",
    "tranquillizziate": "tranquillizzare",
    "tranquillizzin": "tranquillizzare",
    "tranquillizzino": "tranquillizzare",
    "tranquillizzo": "tranquillizzare",
    "tranquillizzò": "tranquillizzare",
    "tranquillo": "tranquillare",
    "tranquillò": "tranquillare",
    "trans-nazionali": "trans-nazionale",
    "transalpina": "transalpino",
    "transalpine": "transalpino",
    "transalpini": "transalpino",
    "transatlantica": "transatlantico",
    "transatlantiche": "transatlantico",
    "transatlantici": "transatlantico",
    "transavanguardie": "transavanguardia",
    "transazioni": "transazione",
    "transcontinentali": "transcontinentale",
    "transenna": "transennare",
    "transennai": "transennare",
    "transennammo": "transennare",
    "transennan": "transennare",
    "transennando": "transennare",
    "transennano": "transennare",
    "transennante": "transennare",
    "transennanti": "transennare",
    "transennar": "transennare",
    "transennaron": "transennare",
    "transennarono": "transennare",
    "transennasse": "transennare",
    "transennasser": "transennare",
    "transennassero": "transennare",
    "transennassi": "transennare",
    "transennassimo": "transennare",
    "transennaste": "transennare",
    "transennasti": "transennare",
    "transennata": "transennare",
    "transennate": "transennare",
    "transennati": "transennare",
    "transennato": "transennare",
    "transennava": "transennare",
    "transennavamo": "transennare",
    "transennavan": "transennare",
    "transennavano": "transennare",
    "transennavate": "transennare",
    "transennavi": "transennare",
    "transennavo": "transennare",
    "transenne": "transenna",
    "transennerai": "transennare",
    "transenneran": "transennare",
    "transenneranno": "transennare",
    "transennerebbe": "transennare",
    "transennerebber": "transennare",
    "transennerebbero": "transennare",
    "transennerei": "transennare",
    "transenneremmo": "transennare",
    "transenneremo": "transennare",
    "transennereste": "transennare",
    "transenneresti": "transennare",
    "transennerete": "transennare",
    "transennerà": "transennare",
    "transennerò": "transennare",
    "transenni": "transennare",
    "transenniamo": "transennare",
    "transenniate": "transennare",
    "transennin": "transennare",
    "transennino": "transennare",
    "transenno": "transennare",
    "transennò": "transennare",
    "transessuali": "transessuale",
    "transetti": "transetto",
    "transeunti": "transeunte",
    "transfughi": "transfuga",
    "transiberiana": "transiberiano",
    "transiberiane": "transiberiano",
    "transiberiani": "transiberiano",
    "transiga": "transigere",
    "transigan": "transigere",
    "transigano": "transigere",
    "transige": "transigere",
    "transigei": "transigere",
    "transigemmo": "transigere",
    "transigendo": "transigere",
    "transigente": "transigere",
    "transigenti": "transigere",
    "transiger": "transigere",
    "transigerai": "transigere",
    "transigeran": "transigere",
    "transigeranno": "transigere",
    "transigerebbe": "transigere",
    "transigerebber": "transigere",
    "transigerebbero": "transigere",
    "transigerei": "transigere",
    "transigeremmo": "transigere",
    "transigeremo": "transigere",
    "transigereste": "transigere",
    "transigeresti": "transigere",
    "transigerete": "transigere",
    "transigeron": "transigere",
    "transigerono": "transigere",
    "transigerà": "transigere",
    "transigerò": "transigere",
    "transigesse": "transigere",
    "transigesser": "transigere",
    "transigessero": "transigere",
    "transigessi": "transigere",
    "transigessimo": "transigere",
    "transigeste": "transigere",
    "transigesti": "transigere",
    "transigete": "transigere",
    "transigeva": "transigere",
    "transigevamo": "transigere",
    "transigevan": "transigere",
    "transigevano": "transigere",
    "transigevate": "transigere",
    "transigevi": "transigere",
    "transigevo": "transigere",
    "transigi": "transigere",
    "transigiamo": "transigere",
    "transigiate": "transigere",
    "transigiuta": "transigere",
    "transigiute": "transigere",
    "transigiuti": "transigere",
    "transigiuto": "transigere",
    "transigo": "transigere",
    "transigon": "transigere",
    "transigono": "transigere",
    "transigè": "transigere",
    "transistorizza": "transistorizzare",
    "transistorizzai": "transistorizzare",
    "transistorizzammo": "transistorizzare",
    "transistorizzan": "transistorizzare",
    "transistorizzando": "transistorizzare",
    "transistorizzano": "transistorizzare",
    "transistorizzante": "transistorizzare",
    "transistorizzanti": "transistorizzare",
    "transistorizzar": "transistorizzare",
    "transistorizzaron": "transistorizzare",
    "transistorizzarono": "transistorizzare",
    "transistorizzasse": "transistorizzare",
    "transistorizzasser": "transistorizzare",
    "transistorizzassero": "transistorizzare",
    "transistorizzassi": "transistorizzare",
    "transistorizzassimo": "transistorizzare",
    "transistorizzaste": "transistorizzare",
    "transistorizzasti": "transistorizzare",
    "transistorizzata": "transistorizzare",
    "transistorizzate": "transistorizzare",
    "transistorizzati": "transistorizzare",
    "transistorizzato": "transistorizzare",
    "transistorizzava": "transistorizzare",
    "transistorizzavamo": "transistorizzare",
    "transistorizzavan": "transistorizzare",
    "transistorizzavano": "transistorizzare",
    "transistorizzavate": "transistorizzare",
    "transistorizzavi": "transistorizzare",
    "transistorizzavo": "transistorizzare",
    "transistorizzerai": "transistorizzare",
    "transistorizzeran": "transistorizzare",
    "transistorizzeranno": "transistorizzare",
    "transistorizzerebbe": "transistorizzare",
    "transistorizzerebber": "transistorizzare",
    "transistorizzerebbero": "transistorizzare",
    "transistorizzerei": "transistorizzare",
    "transistorizzeremmo": "transistorizzare",
    "transistorizzeremo": "transistorizzare",
    "transistorizzereste": "transistorizzare",
    "transistorizzeresti": "transistorizzare",
    "transistorizzerete": "transistorizzare",
    "transistorizzerà": "transistorizzare",
    "transistorizzerò": "transistorizzare",
    "transistorizzi": "transistorizzare",
    "transistorizziamo": "transistorizzare",
    "transistorizziate": "transistorizzare",
    "transistorizzin": "transistorizzare",
    "transistorizzino": "transistorizzare",
    "transistorizzo": "transistorizzare",
    "transistorizzò": "transistorizzare",
    "transita": "transitare",
    "transitabili": "transitabile",
    "transitai": "transitare",
    "transitammo": "transitare",
    "transitan": "transitare",
    "transitando": "transitare",
    "transitano": "transitare",
    "transitante": "transitare",
    "transitanti": "transitare",
    "transitar": "transitare",
    "transitaron": "transitare",
    "transitarono": "transitare",
    "transitasse": "transitare",
    "transitasser": "transitare",
    "transitassero": "transitare",
    "transitassi": "transitare",
    "transitassimo": "transitare",
    "transitaste": "transitare",
    "transitasti": "transitare",
    "transitata": "transitare",
    "transitate": "transitare",
    "transitati": "transitare",
    "transitato": "transitare",
    "transitava": "transitare",
    "transitavamo": "transitare",
    "transitavan": "transitare",
    "transitavano": "transitare",
    "transitavate": "transitare",
    "transitavi": "transitare",
    "transitavo": "transitare",
    "transiterai": "transitare",
    "transiteran": "transitare",
    "transiteranno": "transitare",
    "transiterebbe": "transitare",
    "transiterebber": "transitare",
    "transiterebbero": "transitare",
    "transiterei": "transitare",
    "transiteremmo": "transitare",
    "transiteremo": "transitare",
    "transitereste": "transitare",
    "transiteresti": "transitare",
    "transiterete": "transitare",
    "transiterà": "transitare",
    "transiterò": "transitare",
    "transiti": "transito",
    "transitiamo": "transitare",
    "transitiate": "transitare",
    "transitin": "transitare",
    "transitino": "transitare",
    "transitiva": "transitivo",
    "transitive": "transitivo",
    "transitivi": "transitivo",
    "transito": "transitare",
    "transitori": "transitorio",
    "transitoria": "transitorio",
    "transitorie": "transitorio",
    "transitò": "transitare",
    "transizioni": "transizione",
    "transnazionali": "transnazionale",
    "transoceanica": "transoceanico",
    "transoceaniche": "transoceanico",
    "transoceanici": "transoceanico",
    "transuma": "transumare",
    "transumai": "transumare",
    "transumammo": "transumare",
    "transuman": "transumare",
    "transumando": "transumare",
    "transumano": "transumare",
    "transumante": "transumare",
    "transumanti": "transumare",
    "transumanze": "transumanza",
    "transumar": "transumare",
    "transumaron": "transumare",
    "transumarono": "transumare",
    "transumasse": "transumare",
    "transumasser": "transumare",
    "transumassero": "transumare",
    "transumassi": "transumare",
    "transumassimo": "transumare",
    "transumaste": "transumare",
    "transumasti": "transumare",
    "transumata": "transumare",
    "transumate": "transumare",
    "transumati": "transumare",
    "transumato": "transumare",
    "transumava": "transumare",
    "transumavamo": "transumare",
    "transumavan": "transumare",
    "transumavano": "transumare",
    "transumavate": "transumare",
    "transumavi": "transumare",
    "transumavo": "transumare",
    "transumerai": "transumare",
    "transumeran": "transumare",
    "transumeranno": "transumare",
    "transumerebbe": "transumare",
    "transumerebber": "transumare",
    "transumerebbero": "transumare",
    "transumerei": "transumare",
    "transumeremmo": "transumare",
    "transumeremo": "transumare",
    "transumereste": "transumare",
    "transumeresti": "transumare",
    "transumerete": "transumare",
    "transumerà": "transumare",
    "transumerò": "transumare",
    "transumi": "transumare",
    "transumiamo": "transumare",
    "transumiate": "transumare",
    "transumin": "transumare",
    "transumino": "transumare",
    "transumo": "transumare",
    "transumò": "transumare",
    "tranviari": "tranviario",
    "tranviaria": "tranviario",
    "tranviarie": "tranviario",
    "tranvieri": "tranviere",
    "trapana": "trapanare",
    "trapanai": "trapanare",
    "trapanammo": "trapanare",
    "trapanan": "trapanare",
    "trapanando": "trapanare",
    "trapanano": "trapanare",
    "trapanante": "trapanare",
    "trapananti": "trapanare",
    "trapanar": "trapanare",
    "trapanaron": "trapanare",
    "trapanarono": "trapanare",
    "trapanasse": "trapanare",
    "trapanasser": "trapanare",
    "trapanassero": "trapanare",
    "trapanassi": "trapanare",
    "trapanassimo": "trapanare",
    "trapanaste": "trapanare",
    "trapanasti": "trapanare",
    "trapanata": "trapanare",
    "trapanate": "trapanare",
    "trapanati": "trapanare",
    "trapanato": "trapanare",
    "trapanava": "trapanare",
    "trapanavamo": "trapanare",
    "trapanavan": "trapanare",
    "trapanavano": "trapanare",
    "trapanavate": "trapanare",
    "trapanavi": "trapanare",
    "trapanavo": "trapanare",
    "trapanerai": "trapanare",
    "trapaneran": "trapanare",
    "trapaneranno": "trapanare",
    "trapanerebbe": "trapanare",
    "trapanerebber": "trapanare",
    "trapanerebbero": "trapanare",
    "trapanerei": "trapanare",
    "trapaneremmo": "trapanare",
    "trapaneremo": "trapanare",
    "trapanereste": "trapanare",
    "trapaneresti": "trapanare",
    "trapanerete": "trapanare",
    "trapanerà": "trapanare",
    "trapanerò": "trapanare",
    "trapanesi": "trapanese",
    "trapani": "trapano",
    "trapaniamo": "trapanare",
    "trapaniate": "trapanare",
    "trapanin": "trapanare",
    "trapanino": "trapanare",
    "trapano": "trapanare",
    "trapanò": "trapanare",
    "trapassa": "trapassare",
    "trapassai": "trapassare",
    "trapassammo": "trapassare",
    "trapassan": "trapassare",
    "trapassando": "trapassare",
    "trapassano": "trapassare",
    "trapassante": "trapassare",
    "trapassanti": "trapassare",
    "trapassar": "trapassare",
    "trapassaron": "trapassare",
    "trapassarono": "trapassare",
    "trapassasse": "trapassare",
    "trapassasser": "trapassare",
    "trapassassero": "trapassare",
    "trapassassi": "trapassare",
    "trapassassimo": "trapassare",
    "trapassaste": "trapassare",
    "trapassasti": "trapassare",
    "trapassata": "trapassare",
    "trapassate": "trapassare",
    "trapassati": "trapassato",
    "trapassato": "trapassare",
    "trapassava": "trapassare",
    "trapassavamo": "trapassare",
    "trapassavan": "trapassare",
    "trapassavano": "trapassare",
    "trapassavate": "trapassare",
    "trapassavi": "trapassare",
    "trapassavo": "trapassare",
    "trapasserai": "trapassare",
    "trapasseran": "trapassare",
    "trapasseranno": "trapassare",
    "trapasserebbe": "trapassare",
    "trapasserebber": "trapassare",
    "trapasserebbero": "trapassare",
    "trapasserei": "trapassare",
    "trapasseremmo": "trapassare",
    "trapasseremo": "trapassare",
    "trapassereste": "trapassare",
    "trapasseresti": "trapassare",
    "trapasserete": "trapassare",
    "trapasserà": "trapassare",
    "trapasserò": "trapassare",
    "trapassi": "trapasso",
    "trapassiamo": "trapassare",
    "trapassiate": "trapassare",
    "trapassin": "trapassare",
    "trapassino": "trapassare",
    "trapasso": "trapassare",
    "trapassò": "trapassare",
    "trapela": "trapelare",
    "trapelai": "trapelare",
    "trapelammo": "trapelare",
    "trapelan": "trapelare",
    "trapelando": "trapelare",
    "trapelano": "trapelare",
    "trapelante": "trapelare",
    "trapelanti": "trapelare",
    "trapelar": "trapelare",
    "trapelaron": "trapelare",
    "trapelarono": "trapelare",
    "trapelasse": "trapelare",
    "trapelasser": "trapelare",
    "trapelassero": "trapelare",
    "trapelassi": "trapelare",
    "trapelassimo": "trapelare",
    "trapelaste": "trapelare",
    "trapelasti": "trapelare",
    "trapelata": "trapelare",
    "trapelate": "trapelare",
    "trapelati": "trapelare",
    "trapelato": "trapelare",
    "trapelava": "trapelare",
    "trapelavamo": "trapelare",
    "trapelavan": "trapelare",
    "trapelavano": "trapelare",
    "trapelavate": "trapelare",
    "trapelavi": "trapelare",
    "trapelavo": "trapelare",
    "trapelerai": "trapelare",
    "trapeleran": "trapelare",
    "trapeleranno": "trapelare",
    "trapelerebbe": "trapelare",
    "trapelerebber": "trapelare",
    "trapelerebbero": "trapelare",
    "trapelerei": "trapelare",
    "trapeleremmo": "trapelare",
    "trapeleremo": "trapelare",
    "trapelereste": "trapelare",
    "trapeleresti": "trapelare",
    "trapelerete": "trapelare",
    "trapelerà": "trapelare",
    "trapelerò": "trapelare",
    "trapeli": "trapelare",
    "trapeliamo": "trapelare",
    "trapeliate": "trapelare",
    "trapelin": "trapelare",
    "trapelino": "trapelare",
    "trapelo": "trapelare",
    "trapelò": "trapelare",
    "trapezi": "trapezio",
    "trapezisti": "trapezista",
    "trapianta": "trapiantare",
    "trapiantai": "trapiantare",
    "trapiantammo": "trapiantare",
    "trapiantan": "trapiantare",
    "trapiantando": "trapiantare",
    "trapiantano": "trapiantare",
    "trapiantante": "trapiantare",
    "trapiantanti": "trapiantare",
    "trapiantar": "trapiantare",
    "trapiantaron": "trapiantare",
    "trapiantarono": "trapiantare",
    "trapiantasse": "trapiantare",
    "trapiantasser": "trapiantare",
    "trapiantassero": "trapiantare",
    "trapiantassi": "trapiantare",
    "trapiantassimo": "trapiantare",
    "trapiantaste": "trapiantare",
    "trapiantasti": "trapiantare",
    "trapiantata": "trapiantare",
    "trapiantate": "trapiantare",
    "trapiantati": "trapiantato",
    "trapiantato": "trapiantare",
    "trapiantava": "trapiantare",
    "trapiantavamo": "trapiantare",
    "trapiantavan": "trapiantare",
    "trapiantavano": "trapiantare",
    "trapiantavate": "trapiantare",
    "trapiantavi": "trapiantare",
    "trapiantavo": "trapiantare",
    "trapianterai": "trapiantare",
    "trapianteran": "trapiantare",
    "trapianteranno": "trapiantare",
    "trapianterebbe": "trapiantare",
    "trapianterebber": "trapiantare",
    "trapianterebbero": "trapiantare",
    "trapianterei": "trapiantare",
    "trapianteremmo": "trapiantare",
    "trapianteremo": "trapiantare",
    "trapiantereste": "trapiantare",
    "trapianteresti": "trapiantare",
    "trapianterete": "trapiantare",
    "trapianterà": "trapiantare",
    "trapianterò": "trapiantare",
    "trapianti": "trapianto",
    "trapiantiamo": "trapiantare",
    "trapiantiate": "trapiantare",
    "trapiantin": "trapiantare",
    "trapiantino": "trapiantare",
    "trapianto": "trapiantare",
    "trapiantò": "trapiantare",
    "trappole": "trappola",
    "trapunga": "trapungere",
    "trapungan": "trapungere",
    "trapungano": "trapungere",
    "trapunge": "trapungere",
    "trapungemmo": "trapungere",
    "trapungendo": "trapungere",
    "trapungente": "trapungere",
    "trapungenti": "trapungere",
    "trapunger": "trapungere",
    "trapungerai": "trapungere",
    "trapungeran": "trapungere",
    "trapungeranno": "trapungere",
    "trapungerebbe": "trapungere",
    "trapungerebber": "trapungere",
    "trapungerebbero": "trapungere",
    "trapungerei": "trapungere",
    "trapungeremmo": "trapungere",
    "trapungeremo": "trapungere",
    "trapungereste": "trapungere",
    "trapungeresti": "trapungere",
    "trapungerete": "trapungere",
    "trapungerà": "trapungere",
    "trapungerò": "trapungere",
    "trapungesse": "trapungere",
    "trapungesser": "trapungere",
    "trapungessero": "trapungere",
    "trapungessi": "trapungere",
    "trapungessimo": "trapungere",
    "trapungeste": "trapungere",
    "trapungesti": "trapungere",
    "trapungete": "trapungere",
    "trapungeva": "trapungere",
    "trapungevamo": "trapungere",
    "trapungevan": "trapungere",
    "trapungevano": "trapungere",
    "trapungevate": "trapungere",
    "trapungevi": "trapungere",
    "trapungevo": "trapungere",
    "trapungi": "trapungere",
    "trapungiamo": "trapungere",
    "trapungiate": "trapungere",
    "trapungo": "trapungere",
    "trapungon": "trapungere",
    "trapungono": "trapungere",
    "trapunser": "trapungere",
    "trapunsero": "trapungere",
    "trapunsi": "trapungere",
    "trapunsè": "trapungere",
    "trapunta": "trapuntare",
    "trapuntai": "trapuntare",
    "trapuntammo": "trapuntare",
    "trapuntan": "trapuntare",
    "trapuntando": "trapuntare",
    "trapuntano": "trapuntare",
    "trapuntante": "trapuntare",
    "trapuntanti": "trapuntare",
    "trapuntar": "trapuntare",
    "trapuntaron": "trapuntare",
    "trapuntarono": "trapuntare",
    "trapuntasse": "trapuntare",
    "trapuntasser": "trapuntare",
    "trapuntassero": "trapuntare",
    "trapuntassi": "trapuntare",
    "trapuntassimo": "trapuntare",
    "trapuntaste": "trapuntare",
    "trapuntasti": "trapuntare",
    "trapuntata": "trapuntare",
    "trapuntate": "trapuntare",
    "trapuntati": "trapuntare",
    "trapuntato": "trapuntare",
    "trapuntava": "trapuntare",
    "trapuntavamo": "trapuntare",
    "trapuntavan": "trapuntare",
    "trapuntavano": "trapuntare",
    "trapuntavate": "trapuntare",
    "trapuntavi": "trapuntare",
    "trapuntavo": "trapuntare",
    "trapunte": "trapungere",
    "trapunterai": "trapuntare",
    "trapunteran": "trapuntare",
    "trapunteranno": "trapuntare",
    "trapunterebbe": "trapuntare",
    "trapunterebber": "trapuntare",
    "trapunterebbero": "trapuntare",
    "trapunterei": "trapuntare",
    "trapunteremmo": "trapuntare",
    "trapunteremo": "trapuntare",
    "trapuntereste": "trapuntare",
    "trapunteresti": "trapuntare",
    "trapunterete": "trapuntare",
    "trapunterà": "trapuntare",
    "trapunterò": "trapuntare",
    "trapunti": "trapuntare",
    "trapuntiamo": "trapuntare",
    "trapuntiate": "trapuntare",
    "trapuntin": "trapuntare",
    "trapuntino": "trapuntare",
    "trapunto": "trapuntare",
    "trapuntò": "trapuntare",
    "trarr": "trarre",
    "trarrai": "trarre",
    "trarran": "trarre",
    "trarranno": "trarre",
    "trarrebbe": "trarre",
    "trarrebber": "trarre",
    "trarrebbero": "trarre",
    "trarrei": "trarre",
    "trarremmo": "trarre",
    "trarremo": "trarre",
    "trarreste": "trarre",
    "trarresti": "trarre",
    "trarrete": "trarre",
    "trarrà": "trarre",
    "trarrò": "trarre",
    "trasala": "trasalire",
    "trasalan": "trasalire",
    "trasalano": "trasalire",
    "trasale": "trasalire",
    "trasalendo": "trasalire",
    "trasalente": "trasalire",
    "trasalenti": "trasalire",
    "trasali": "trasalire",
    "trasaliamo": "trasalire",
    "trasaliate": "trasalire",
    "trasalii": "trasalire",
    "trasalimenti": "trasalimento",
    "trasalimmo": "trasalire",
    "trasalir": "trasalire",
    "trasalirai": "trasalire",
    "trasaliran": "trasalire",
    "trasaliranno": "trasalire",
    "trasalirebbe": "trasalire",
    "trasalirebber": "trasalire",
    "trasalirebbero": "trasalire",
    "trasalirei": "trasalire",
    "trasaliremmo": "trasalire",
    "trasaliremo": "trasalire",
    "trasalireste": "trasalire",
    "trasaliresti": "trasalire",
    "trasalirete": "trasalire",
    "trasaliron": "trasalire",
    "trasalirono": "trasalire",
    "trasalirà": "trasalire",
    "trasalirò": "trasalire",
    "trasalisse": "trasalire",
    "trasalisser": "trasalire",
    "trasalissero": "trasalire",
    "trasalissi": "trasalire",
    "trasalissimo": "trasalire",
    "trasaliste": "trasalire",
    "trasalisti": "trasalire",
    "trasalita": "trasalire",
    "trasalite": "trasalire",
    "trasaliti": "trasalire",
    "trasalito": "trasalire",
    "trasaliva": "trasalire",
    "trasalivamo": "trasalire",
    "trasalivan": "trasalire",
    "trasalivano": "trasalire",
    "trasalivate": "trasalire",
    "trasalivi": "trasalire",
    "trasalivo": "trasalire",
    "trasalo": "trasalire",
    "trasalon": "trasalire",
    "trasalono": "trasalire",
    "trasalì": "trasalire",
    "trasandata": "trasandato",
    "trasandate": "trasandato",
    "trasandatezze": "trasandatezza",
    "trasandati": "trasandato",
    "trasborda": "trasbordare",
    "trasbordai": "trasbordare",
    "trasbordammo": "trasbordare",
    "trasbordan": "trasbordare",
    "trasbordando": "trasbordare",
    "trasbordano": "trasbordare",
    "trasbordante": "trasbordare",
    "trasbordanti": "trasbordare",
    "trasbordar": "trasbordare",
    "trasbordaron": "trasbordare",
    "trasbordarono": "trasbordare",
    "trasbordasse": "trasbordare",
    "trasbordasser": "trasbordare",
    "trasbordassero": "trasbordare",
    "trasbordassi": "trasbordare",
    "trasbordassimo": "trasbordare",
    "trasbordaste": "trasbordare",
    "trasbordasti": "trasbordare",
    "trasbordata": "trasbordare",
    "trasbordate": "trasbordare",
    "trasbordati": "trasbordare",
    "trasbordato": "trasbordare",
    "trasbordava": "trasbordare",
    "trasbordavamo": "trasbordare",
    "trasbordavan": "trasbordare",
    "trasbordavano": "trasbordare",
    "trasbordavate": "trasbordare",
    "trasbordavi": "trasbordare",
    "trasbordavo": "trasbordare",
    "trasborderai": "trasbordare",
    "trasborderan": "trasbordare",
    "trasborderanno": "trasbordare",
    "trasborderebbe": "trasbordare",
    "trasborderebber": "trasbordare",
    "trasborderebbero": "trasbordare",
    "trasborderei": "trasbordare",
    "trasborderemmo": "trasbordare",
    "trasborderemo": "trasbordare",
    "trasbordereste": "trasbordare",
    "trasborderesti": "trasbordare",
    "trasborderete": "trasbordare",
    "trasborderà": "trasbordare",
    "trasborderò": "trasbordare",
    "trasbordi": "trasbordo",
    "trasbordiamo": "trasbordare",
    "trasbordiate": "trasbordare",
    "trasbordin": "trasbordare",
    "trasbordino": "trasbordare",
    "trasbordo": "trasbordare",
    "trasbordò": "trasbordare",
    "trascegli": "trascegliere",
    "trascegliamo": "trascegliere",
    "trascegliate": "trascegliere",
    "trasceglie": "trascegliere",
    "trascegliemmo": "trascegliere",
    "trascegliendo": "trascegliere",
    "trascegliente": "trascegliere",
    "trasceglienti": "trascegliere",
    "trasceglier": "trascegliere",
    "trasceglierai": "trascegliere",
    "trasceglieran": "trascegliere",
    "trasceglieranno": "trascegliere",
    "trasceglierebbe": "trascegliere",
    "trasceglierebber": "trascegliere",
    "trasceglierebbero": "trascegliere",
    "trasceglierei": "trascegliere",
    "trasceglieremmo": "trascegliere",
    "trasceglieremo": "trascegliere",
    "trascegliereste": "trascegliere",
    "trasceglieresti": "trascegliere",
    "trasceglierete": "trascegliere",
    "trasceglierà": "trascegliere",
    "trasceglierò": "trascegliere",
    "trascegliesse": "trascegliere",
    "trascegliesser": "trascegliere",
    "trascegliessero": "trascegliere",
    "trascegliessi": "trascegliere",
    "trascegliessimo": "trascegliere",
    "trasceglieste": "trascegliere",
    "trascegliesti": "trascegliere",
    "trascegliete": "trascegliere",
    "trasceglieva": "trascegliere",
    "trasceglievamo": "trascegliere",
    "trasceglievan": "trascegliere",
    "trasceglievano": "trascegliere",
    "trasceglievate": "trascegliere",
    "trasceglievi": "trascegliere",
    "trasceglievo": "trascegliere",
    "trascelga": "trascegliere",
    "trascelgan": "trascegliere",
    "trascelgano": "trascegliere",
    "trascelgo": "trascegliere",
    "trascelgon": "trascegliere",
    "trascelgono": "trascegliere",
    "trascelser": "trascegliere",
    "trascelsero": "trascegliere",
    "trascelsi": "trascegliere",
    "trascelsè": "trascegliere",
    "trascelta": "trascegliere",
    "trascelte": "trascegliere",
    "trascelti": "trascegliere",
    "trascelto": "trascegliere",
    "trascenda": "trascendere",
    "trascendan": "trascendere",
    "trascendano": "trascendere",
    "trascende": "trascendere",
    "trascendemmo": "trascendere",
    "trascendendo": "trascendere",
    "trascendentali": "trascendentale",
    "trascendente": "trascendere",
    "trascendenti": "trascendere",
    "trascendenze": "trascendenza",
    "trascender": "trascendere",
    "trascenderai": "trascendere",
    "trascenderan": "trascendere",
    "trascenderanno": "trascendere",
    "trascenderebbe": "trascendere",
    "trascenderebber": "trascendere",
    "trascenderebbero": "trascendere",
    "trascenderei": "trascendere",
    "trascenderemmo": "trascendere",
    "trascenderemo": "trascendere",
    "trascendereste": "trascendere",
    "trascenderesti": "trascendere",
    "trascenderete": "trascendere",
    "trascenderà": "trascendere",
    "trascenderò": "trascendere",
    "trascendesse": "trascendere",
    "trascendesser": "trascendere",
    "trascendessero": "trascendere",
    "trascendessi": "trascendere",
    "trascendessimo": "trascendere",
    "trascendeste": "trascendere",
    "trascendesti": "trascendere",
    "trascendete": "trascendere",
    "trascendeva": "trascendere",
    "trascendevamo": "trascendere",
    "trascendevan": "trascendere",
    "trascendevano": "trascendere",
    "trascendevate": "trascendere",
    "trascendevi": "trascendere",
    "trascendevo": "trascendere",
    "trascendi": "trascendere",
    "trascendiamo": "trascendere",
    "trascendiate": "trascendere",
    "trascendo": "trascendere",
    "trascendon": "trascendere",
    "trascendono": "trascendere",
    "trascesa": "trascendere",
    "trascese": "trascendere",
    "trasceser": "trascendere",
    "trascesero": "trascendere",
    "trascesi": "trascendere",
    "trasceso": "trascendere",
    "trascesè": "trascendere",
    "trascina": "trascinare",
    "trascinai": "trascinare",
    "trascinamenti": "trascinamento",
    "trascinammo": "trascinare",
    "trascinan": "trascinare",
    "trascinando": "trascinare",
    "trascinano": "trascinare",
    "trascinante": "trascinare",
    "trascinanti": "trascinare",
    "trascinar": "trascinare",
    "trascinaron": "trascinare",
    "trascinarono": "trascinare",
    "trascinasse": "trascinare",
    "trascinasser": "trascinare",
    "trascinassero": "trascinare",
    "trascinassi": "trascinare",
    "trascinassimo": "trascinare",
    "trascinaste": "trascinare",
    "trascinasti": "trascinare",
    "trascinata": "trascinare",
    "trascinate": "trascinare",
    "trascinati": "trascinare",
    "trascinato": "trascinare",
    "trascinatori": "trascinatore",
    "trascinava": "trascinare",
    "trascinavamo": "trascinare",
    "trascinavan": "trascinare",
    "trascinavano": "trascinare",
    "trascinavate": "trascinare",
    "trascinavi": "trascinare",
    "trascinavo": "trascinare",
    "trascinerai": "trascinare",
    "trascineran": "trascinare",
    "trascineranno": "trascinare",
    "trascinerebbe": "trascinare",
    "trascinerebber": "trascinare",
    "trascinerebbero": "trascinare",
    "trascinerei": "trascinare",
    "trascineremmo": "trascinare",
    "trascineremo": "trascinare",
    "trascinereste": "trascinare",
    "trascineresti": "trascinare",
    "trascinerete": "trascinare",
    "trascinerà": "trascinare",
    "trascinerò": "trascinare",
    "trascini": "trascinare",
    "trasciniamo": "trascinare",
    "trasciniate": "trascinare",
    "trascinin": "trascinare",
    "trascinino": "trascinare",
    "trascino": "trascinare",
    "trascinò": "trascinare",
    "trascolora": "trascolorare",
    "trascolorai": "trascolorare",
    "trascolorammo": "trascolorare",
    "trascoloran": "trascolorare",
    "trascolorando": "trascolorare",
    "trascolorano": "trascolorare",
    "trascolorante": "trascolorare",
    "trascoloranti": "trascolorare",
    "trascolorar": "trascolorare",
    "trascoloraron": "trascolorare",
    "trascolorarono": "trascolorare",
    "trascolorasse": "trascolorare",
    "trascolorasser": "trascolorare",
    "trascolorassero": "trascolorare",
    "trascolorassi": "trascolorare",
    "trascolorassimo": "trascolorare",
    "trascoloraste": "trascolorare",
    "trascolorasti": "trascolorare",
    "trascolorata": "trascolorare",
    "trascolorate": "trascolorare",
    "trascolorati": "trascolorare",
    "trascolorato": "trascolorare",
    "trascolorava": "trascolorare",
    "trascoloravamo": "trascolorare",
    "trascoloravan": "trascolorare",
    "trascoloravano": "trascolorare",
    "trascoloravate": "trascolorare",
    "trascoloravi": "trascolorare",
    "trascoloravo": "trascolorare",
    "trascolorerai": "trascolorare",
    "trascoloreran": "trascolorare",
    "trascoloreranno": "trascolorare",
    "trascolorerebbe": "trascolorare",
    "trascolorerebber": "trascolorare",
    "trascolorerebbero": "trascolorare",
    "trascolorerei": "trascolorare",
    "trascoloreremmo": "trascolorare",
    "trascoloreremo": "trascolorare",
    "trascolorereste": "trascolorare",
    "trascoloreresti": "trascolorare",
    "trascolorerete": "trascolorare",
    "trascolorerà": "trascolorare",
    "trascolorerò": "trascolorare",
    "trascolori": "trascolorare",
    "trascoloriamo": "trascolorare",
    "trascoloriate": "trascolorare",
    "trascolorin": "trascolorare",
    "trascolorino": "trascolorare",
    "trascoloro": "trascolorare",
    "trascolorò": "trascolorare",
    "trascorra": "trascorrere",
    "trascorran": "trascorrere",
    "trascorrano": "trascorrere",
    "trascorre": "trascorrere",
    "trascorremmo": "trascorrere",
    "trascorrendo": "trascorrere",
    "trascorrente": "trascorrere",
    "trascorrenti": "trascorrere",
    "trascorrer": "trascorrere",
    "trascorrerai": "trascorrere",
    "trascorreran": "trascorrere",
    "trascorreranno": "trascorrere",
    "trascorrerebbe": "trascorrere",
    "trascorrerebber": "trascorrere",
    "trascorrerebbero": "trascorrere",
    "trascorrerei": "trascorrere",
    "trascorreremmo": "trascorrere",
    "trascorreremo": "trascorrere",
    "trascorrereste": "trascorrere",
    "trascorreresti": "trascorrere",
    "trascorrerete": "trascorrere",
    "trascorrerà": "trascorrere",
    "trascorrerò": "trascorrere",
    "trascorresse": "trascorrere",
    "trascorresser": "trascorrere",
    "trascorressero": "trascorrere",
    "trascorressi": "trascorrere",
    "trascorressimo": "trascorrere",
    "trascorreste": "trascorrere",
    "trascorresti": "trascorrere",
    "trascorrete": "trascorrere",
    "trascorreva": "trascorrere",
    "trascorrevamo": "trascorrere",
    "trascorrevan": "trascorrere",
    "trascorrevano": "trascorrere",
    "trascorrevate": "trascorrere",
    "trascorrevi": "trascorrere",
    "trascorrevo": "trascorrere",
    "trascorri": "trascorrere",
    "trascorriamo": "trascorrere",
    "trascorriate": "trascorrere",
    "trascorro": "trascorrere",
    "trascorron": "trascorrere",
    "trascorrono": "trascorrere",
    "trascorsa": "trascorso",
    "trascorse": "trascorso",
    "trascorser": "trascorrere",
    "trascorsero": "trascorrere",
    "trascorsi": "trascorso",
    "trascorso": "trascorrere",
    "trascrisse": "trascrivere",
    "trascrisser": "trascrivere",
    "trascrissero": "trascrivere",
    "trascrissi": "trascrivere",
    "trascritta": "trascrivere",
    "trascritte": "trascrivere",
    "trascritti": "trascrivere",
    "trascritto": "trascrivere",
    "trascriva": "trascrivere",
    "trascrivan": "trascrivere",
    "trascrivano": "trascrivere",
    "trascrive": "trascrivere",
    "trascrivemmo": "trascrivere",
    "trascrivendo": "trascrivere",
    "trascrivente": "trascrivere",
    "trascriventi": "trascrivere",
    "trascriver": "trascrivere",
    "trascriverai": "trascrivere",
    "trascriveran": "trascrivere",
    "trascriveranno": "trascrivere",
    "trascriverebbe": "trascrivere",
    "trascriverebber": "trascrivere",
    "trascriverebbero": "trascrivere",
    "trascriverei": "trascrivere",
    "trascriveremmo": "trascrivere",
    "trascriveremo": "trascrivere",
    "trascrivereste": "trascrivere",
    "trascriveresti": "trascrivere",
    "trascriverete": "trascrivere",
    "trascriverà": "trascrivere",
    "trascriverò": "trascrivere",
    "trascrivesse": "trascrivere",
    "trascrivesser": "trascrivere",
    "trascrivessero": "trascrivere",
    "trascrivessi": "trascrivere",
    "trascrivessimo": "trascrivere",
    "trascriveste": "trascrivere",
    "trascrivesti": "trascrivere",
    "trascrivete": "trascrivere",
    "trascriveva": "trascrivere",
    "trascrivevamo": "trascrivere",
    "trascrivevan": "trascrivere",
    "trascrivevano": "trascrivere",
    "trascrivevate": "trascrivere",
    "trascrivevi": "trascrivere",
    "trascrivevo": "trascrivere",
    "trascrivi": "trascrivere",
    "trascriviamo": "trascrivere",
    "trascriviate": "trascrivere",
    "trascrivo": "trascrivere",
    "trascrivon": "trascrivere",
    "trascrivono": "trascrivere",
    "trascrizioni": "trascrizione",
    "trascura": "trascurare",
    "trascurabili": "trascurabile",
    "trascurai": "trascurare",
    "trascurammo": "trascurare",
    "trascuran": "trascurare",
    "trascurando": "trascurare",
    "trascurano": "trascurare",
    "trascurante": "trascurare",
    "trascuranti": "trascurare",
    "trascurar": "trascurare",
    "trascuraron": "trascurare",
    "trascurarono": "trascurare",
    "trascurasse": "trascurare",
    "trascurasser": "trascurare",
    "trascurassero": "trascurare",
    "trascurassi": "trascurare",
    "trascurassimo": "trascurare",
    "trascuraste": "trascurare",
    "trascurasti": "trascurare",
    "trascurata": "trascurato",
    "trascurate": "trascurato",
    "trascuratezze": "trascuratezza",
    "trascurati": "trascurato",
    "trascurato": "trascurare",
    "trascurava": "trascurare",
    "trascuravamo": "trascurare",
    "trascuravan": "trascurare",
    "trascuravano": "trascurare",
    "trascuravate": "trascurare",
    "trascuravi": "trascurare",
    "trascuravo": "trascurare",
    "trascurerai": "trascurare",
    "trascureran": "trascurare",
    "trascureranno": "trascurare",
    "trascurerebbe": "trascurare",
    "trascurerebber": "trascurare",
    "trascurerebbero": "trascurare",
    "trascurerei": "trascurare",
    "trascureremmo": "trascurare",
    "trascureremo": "trascurare",
    "trascurereste": "trascurare",
    "trascureresti": "trascurare",
    "trascurerete": "trascurare",
    "trascurerà": "trascurare",
    "trascurerò": "trascurare",
    "trascuri": "trascurare",
    "trascuriamo": "trascurare",
    "trascuriate": "trascurare",
    "trascurin": "trascurare",
    "trascurino": "trascurare",
    "trascuro": "trascurare",
    "trascurò": "trascurare",
    "trasduca": "trasdurre",
    "trasducan": "trasdurre",
    "trasducano": "trasdurre",
    "trasduce": "trasdurre",
    "trasducei": "trasdurre",
    "trasducemmo": "trasdurre",
    "trasducendo": "trasdurre",
    "trasducente": "trasdurre",
    "trasducenti": "trasdurre",
    "trasducerai": "trasdurre",
    "trasduceran": "trasdurre",
    "trasduceranno": "trasdurre",
    "trasducerebbe": "trasdurre",
    "trasducerebber": "trasdurre",
    "trasducerebbero": "trasdurre",
    "trasducerei": "trasdurre",
    "trasduceremmo": "trasdurre",
    "trasduceremo": "trasdurre",
    "trasducereste": "trasdurre",
    "trasduceresti": "trasdurre",
    "trasducerete": "trasdurre",
    "trasduceron": "trasdurre",
    "trasducerono": "trasdurre",
    "trasducerà": "trasdurre",
    "trasducerò": "trasdurre",
    "trasducesse": "trasdurre",
    "trasducesser": "trasdurre",
    "trasducessero": "trasdurre",
    "trasducessi": "trasdurre",
    "trasducessimo": "trasdurre",
    "trasduceste": "trasdurre",
    "trasducesti": "trasdurre",
    "trasducete": "trasdurre",
    "trasduceva": "trasdurre",
    "trasducevamo": "trasdurre",
    "trasducevan": "trasdurre",
    "trasducevano": "trasdurre",
    "trasducevate": "trasdurre",
    "trasducevi": "trasdurre",
    "trasducevo": "trasdurre",
    "trasduci": "trasdurre",
    "trasduciamo": "trasdurre",
    "trasduciate": "trasdurre",
    "trasduciuta": "trasdurre",
    "trasduciute": "trasdurre",
    "trasduciuti": "trasdurre",
    "trasduciuto": "trasdurre",
    "trasduco": "trasdurre",
    "trasducon": "trasdurre",
    "trasducono": "trasdurre",
    "trasducè": "trasdurre",
    "trasdurr": "trasdurre",
    "trasecola": "trasecolare",
    "trasecolai": "trasecolare",
    "trasecolammo": "trasecolare",
    "trasecolan": "trasecolare",
    "trasecolando": "trasecolare",
    "trasecolano": "trasecolare",
    "trasecolante": "trasecolare",
    "trasecolanti": "trasecolare",
    "trasecolar": "trasecolare",
    "trasecolaron": "trasecolare",
    "trasecolarono": "trasecolare",
    "trasecolasse": "trasecolare",
    "trasecolasser": "trasecolare",
    "trasecolassero": "trasecolare",
    "trasecolassi": "trasecolare",
    "trasecolassimo": "trasecolare",
    "trasecolaste": "trasecolare",
    "trasecolasti": "trasecolare",
    "trasecolata": "trasecolare",
    "trasecolate": "trasecolare",
    "trasecolati": "trasecolare",
    "trasecolato": "trasecolare",
    "trasecolava": "trasecolare",
    "trasecolavamo": "trasecolare",
    "trasecolavan": "trasecolare",
    "trasecolavano": "trasecolare",
    "trasecolavate": "trasecolare",
    "trasecolavi": "trasecolare",
    "trasecolavo": "trasecolare",
    "trasecolerai": "trasecolare",
    "trasecoleran": "trasecolare",
    "trasecoleranno": "trasecolare",
    "trasecolerebbe": "trasecolare",
    "trasecolerebber": "trasecolare",
    "trasecolerebbero": "trasecolare",
    "trasecolerei": "trasecolare",
    "trasecoleremmo": "trasecolare",
    "trasecoleremo": "trasecolare",
    "trasecolereste": "trasecolare",
    "trasecoleresti": "trasecolare",
    "trasecolerete": "trasecolare",
    "trasecolerà": "trasecolare",
    "trasecolerò": "trasecolare",
    "trasecoli": "trasecolare",
    "trasecoliamo": "trasecolare",
    "trasecoliate": "trasecolare",
    "trasecolin": "trasecolare",
    "trasecolino": "trasecolare",
    "trasecolo": "trasecolare",
    "trasecolò": "trasecolare",
    "trasferendo": "trasferire",
    "trasferente": "trasferire",
    "trasferenti": "trasferire",
    "trasferiamo": "trasferire",
    "trasferiate": "trasferire",
    "trasferibili": "trasferibile",
    "trasferii": "trasferire",
    "trasferimenti": "trasferimento",
    "trasferimmo": "trasferire",
    "trasferir": "trasferire",
    "trasferirai": "trasferire",
    "trasferiran": "trasferire",
    "trasferiranno": "trasferire",
    "trasferirebbe": "trasferire",
    "trasferirebber": "trasferire",
    "trasferirebbero": "trasferire",
    "trasferirei": "trasferire",
    "trasferiremmo": "trasferire",
    "trasferiremo": "trasferire",
    "trasferireste": "trasferire",
    "trasferiresti": "trasferire",
    "trasferirete": "trasferire",
    "trasferiron": "trasferire",
    "trasferirono": "trasferire",
    "trasferirà": "trasferire",
    "trasferirò": "trasferire",
    "trasferisca": "trasferire",
    "trasferiscan": "trasferire",
    "trasferiscano": "trasferire",
    "trasferisce": "trasferire",
    "trasferisci": "trasferire",
    "trasferisco": "trasferire",
    "trasferiscon": "trasferire",
    "trasferiscono": "trasferire",
    "trasferisse": "trasferire",
    "trasferisser": "trasferire",
    "trasferissero": "trasferire",
    "trasferissi": "trasferire",
    "trasferissimo": "trasferire",
    "trasferiste": "trasferire",
    "trasferisti": "trasferire",
    "trasferita": "trasferire",
    "trasferite": "trasferire",
    "trasferiti": "trasferire",
    "trasferito": "trasferire",
    "trasferiva": "trasferire",
    "trasferivamo": "trasferire",
    "trasferivan": "trasferire",
    "trasferivano": "trasferire",
    "trasferivate": "trasferire",
    "trasferivi": "trasferire",
    "trasferivo": "trasferire",
    "trasferte": "trasferta",
    "trasferì": "trasferire",
    "trasfigura": "trasfigurare",
    "trasfigurai": "trasfigurare",
    "trasfigurammo": "trasfigurare",
    "trasfiguran": "trasfigurare",
    "trasfigurando": "trasfigurare",
    "trasfigurano": "trasfigurare",
    "trasfigurante": "trasfigurare",
    "trasfiguranti": "trasfigurare",
    "trasfigurar": "trasfigurare",
    "trasfiguraron": "trasfigurare",
    "trasfigurarono": "trasfigurare",
    "trasfigurasse": "trasfigurare",
    "trasfigurasser": "trasfigurare",
    "trasfigurassero": "trasfigurare",
    "trasfigurassi": "trasfigurare",
    "trasfigurassimo": "trasfigurare",
    "trasfiguraste": "trasfigurare",
    "trasfigurasti": "trasfigurare",
    "trasfigurata": "trasfigurare",
    "trasfigurate": "trasfigurare",
    "trasfigurati": "trasfigurare",
    "trasfigurato": "trasfigurare",
    "trasfigurava": "trasfigurare",
    "trasfiguravamo": "trasfigurare",
    "trasfiguravan": "trasfigurare",
    "trasfiguravano": "trasfigurare",
    "trasfiguravate": "trasfigurare",
    "trasfiguravi": "trasfigurare",
    "trasfiguravo": "trasfigurare",
    "trasfigurazioni": "trasfigurazione",
    "trasfigurerai": "trasfigurare",
    "trasfigureran": "trasfigurare",
    "trasfigureranno": "trasfigurare",
    "trasfigurerebbe": "trasfigurare",
    "trasfigurerebber": "trasfigurare",
    "trasfigurerebbero": "trasfigurare",
    "trasfigurerei": "trasfigurare",
    "trasfigureremmo": "trasfigurare",
    "trasfigureremo": "trasfigurare",
    "trasfigurereste": "trasfigurare",
    "trasfigureresti": "trasfigurare",
    "trasfigurerete": "trasfigurare",
    "trasfigurerà": "trasfigurare",
    "trasfigurerò": "trasfigurare",
    "trasfiguri": "trasfigurare",
    "trasfiguriamo": "trasfigurare",
    "trasfiguriate": "trasfigurare",
    "trasfigurin": "trasfigurare",
    "trasfigurino": "trasfigurare",
    "trasfiguro": "trasfigurare",
    "trasfigurò": "trasfigurare",
    "trasfonda": "trasfondere",
    "trasfondan": "trasfondere",
    "trasfondano": "trasfondere",
    "trasfonde": "trasfondere",
    "trasfondemmo": "trasfondere",
    "trasfondendo": "trasfondere",
    "trasfondente": "trasfondere",
    "trasfondenti": "trasfondere",
    "trasfonder": "trasfondere",
    "trasfonderai": "trasfondere",
    "trasfonderan": "trasfondere",
    "trasfonderanno": "trasfondere",
    "trasfonderebbe": "trasfondere",
    "trasfonderebber": "trasfondere",
    "trasfonderebbero": "trasfondere",
    "trasfonderei": "trasfondere",
    "trasfonderemmo": "trasfondere",
    "trasfonderemo": "trasfondere",
    "trasfondereste": "trasfondere",
    "trasfonderesti": "trasfondere",
    "trasfonderete": "trasfondere",
    "trasfonderà": "trasfondere",
    "trasfonderò": "trasfondere",
    "trasfondesse": "trasfondere",
    "trasfondesser": "trasfondere",
    "trasfondessero": "trasfondere",
    "trasfondessi": "trasfondere",
    "trasfondessimo": "trasfondere",
    "trasfondeste": "trasfondere",
    "trasfondesti": "trasfondere",
    "trasfondete": "trasfondere",
    "trasfondeva": "trasfondere",
    "trasfondevamo": "trasfondere",
    "trasfondevan": "trasfondere",
    "trasfondevano": "trasfondere",
    "trasfondevate": "trasfondere",
    "trasfondevi": "trasfondere",
    "trasfondevo": "trasfondere",
    "trasfondi": "trasfondere",
    "trasfondiamo": "trasfondere",
    "trasfondiate": "trasfondere",
    "trasfondo": "trasfondere",
    "trasfondon": "trasfondere",
    "trasfondono": "trasfondere",
    "trasforma": "trasformare",
    "trasformai": "trasformare",
    "trasformammo": "trasformare",
    "trasforman": "trasformare",
    "trasformando": "trasformare",
    "trasformano": "trasformare",
    "trasformante": "trasformare",
    "trasformanti": "trasformare",
    "trasformar": "trasformare",
    "trasformaron": "trasformare",
    "trasformarono": "trasformare",
    "trasformasse": "trasformare",
    "trasformasser": "trasformare",
    "trasformassero": "trasformare",
    "trasformassi": "trasformare",
    "trasformassimo": "trasformare",
    "trasformaste": "trasformare",
    "trasformasti": "trasformare",
    "trasformata": "trasformato",
    "trasformate": "trasformato",
    "trasformati": "trasformato",
    "trasformato": "trasformare",
    "trasformatori": "trasformatore",
    "trasformava": "trasformare",
    "trasformavamo": "trasformare",
    "trasformavan": "trasformare",
    "trasformavano": "trasformare",
    "trasformavate": "trasformare",
    "trasformavi": "trasformare",
    "trasformavo": "trasformare",
    "trasformazioni": "trasformazione",
    "trasformerai": "trasformare",
    "trasformeran": "trasformare",
    "trasformeranno": "trasformare",
    "trasformerebbe": "trasformare",
    "trasformerebber": "trasformare",
    "trasformerebbero": "trasformare",
    "trasformerei": "trasformare",
    "trasformeremmo": "trasformare",
    "trasformeremo": "trasformare",
    "trasformereste": "trasformare",
    "trasformeresti": "trasformare",
    "trasformerete": "trasformare",
    "trasformerà": "trasformare",
    "trasformerò": "trasformare",
    "trasformi": "trasformare",
    "trasformiamo": "trasformare",
    "trasformiate": "trasformare",
    "trasformin": "trasformare",
    "trasformino": "trasformare",
    "trasformismi": "trasformismo",
    "trasformiste": "trasformista",
    "trasformisti": "trasformista",
    "trasformo": "trasformare",
    "trasformò": "trasformare",
    "trasfusa": "trasfondere",
    "trasfuse": "trasfondere",
    "trasfuser": "trasfondere",
    "trasfusero": "trasfondere",
    "trasfusi": "trasfondere",
    "trasfusionali": "trasfusionale",
    "trasfusioni": "trasfusione",
    "trasfuso": "trasfondere",
    "trasgredendo": "trasgredire",
    "trasgredente": "trasgredire",
    "trasgredenti": "trasgredire",
    "trasgrediamo": "trasgredire",
    "trasgrediate": "trasgredire",
    "trasgredii": "trasgredire",
    "trasgredimmo": "trasgredire",
    "trasgredir": "trasgredire",
    "trasgredirai": "trasgredire",
    "trasgrediran": "trasgredire",
    "trasgrediranno": "trasgredire",
    "trasgredirebbe": "trasgredire",
    "trasgredirebber": "trasgredire",
    "trasgredirebbero": "trasgredire",
    "trasgredirei": "trasgredire",
    "trasgrediremmo": "trasgredire",
    "trasgrediremo": "trasgredire",
    "trasgredireste": "trasgredire",
    "trasgrediresti": "trasgredire",
    "trasgredirete": "trasgredire",
    "trasgrediron": "trasgredire",
    "trasgredirono": "trasgredire",
    "trasgredirà": "trasgredire",
    "trasgredirò": "trasgredire",
    "trasgredisca": "trasgredire",
    "trasgrediscan": "trasgredire",
    "trasgrediscano": "trasgredire",
    "trasgredisce": "trasgredire",
    "trasgredisci": "trasgredire",
    "trasgredisco": "trasgredire",
    "trasgrediscon": "trasgredire",
    "trasgrediscono": "trasgredire",
    "trasgredisse": "trasgredire",
    "trasgredisser": "trasgredire",
    "trasgredissero": "trasgredire",
    "trasgredissi": "trasgredire",
    "trasgredissimo": "trasgredire",
    "trasgrediste": "trasgredire",
    "trasgredisti": "trasgredire",
    "trasgredita": "trasgredire",
    "trasgredite": "trasgredire",
    "trasgrediti": "trasgredire",
    "trasgredito": "trasgredire",
    "trasgrediva": "trasgredire",
    "trasgredivamo": "trasgredire",
    "trasgredivan": "trasgredire",
    "trasgredivano": "trasgredire",
    "trasgredivate": "trasgredire",
    "trasgredivi": "trasgredire",
    "trasgredivo": "trasgredire",
    "trasgredì": "trasgredire",
    "trasgressioni": "trasgressione",
    "trasgressori": "trasgressore",
    "trasla": "traslare",
    "traslai": "traslare",
    "traslammo": "traslare",
    "traslan": "traslare",
    "traslando": "traslare",
    "traslano": "traslare",
    "traslante": "traslare",
    "traslanti": "traslare",
    "traslar": "traslare",
    "traslaron": "traslare",
    "traslarono": "traslare",
    "traslasse": "traslare",
    "traslasser": "traslare",
    "traslassero": "traslare",
    "traslassi": "traslare",
    "traslassimo": "traslare",
    "traslaste": "traslare",
    "traslasti": "traslare",
    "traslata": "traslare",
    "traslate": "traslare",
    "traslati": "traslare",
    "traslato": "traslare",
    "traslava": "traslare",
    "traslavamo": "traslare",
    "traslavan": "traslare",
    "traslavano": "traslare",
    "traslavate": "traslare",
    "traslavi": "traslare",
    "traslavo": "traslare",
    "traslazioni": "traslazione",
    "traslerai": "traslare",
    "trasleran": "traslare",
    "trasleranno": "traslare",
    "traslerebbe": "traslare",
    "traslerebber": "traslare",
    "traslerebbero": "traslare",
    "traslerei": "traslare",
    "trasleremmo": "traslare",
    "trasleremo": "traslare",
    "traslereste": "traslare",
    "trasleresti": "traslare",
    "traslerete": "traslare",
    "traslerà": "traslare",
    "traslerò": "traslare",
    "trasli": "traslare",
    "trasliamo": "traslare",
    "trasliate": "traslare",
    "traslin": "traslare",
    "traslino": "traslare",
    "traslittera": "traslitterare",
    "traslitterai": "traslitterare",
    "traslitterammo": "traslitterare",
    "traslitteran": "traslitterare",
    "traslitterando": "traslitterare",
    "traslitterano": "traslitterare",
    "traslitterante": "traslitterare",
    "traslitteranti": "traslitterare",
    "traslitterar": "traslitterare",
    "traslitteraron": "traslitterare",
    "traslitterarono": "traslitterare",
    "traslitterasse": "traslitterare",
    "traslitterasser": "traslitterare",
    "traslitterassero": "traslitterare",
    "traslitterassi": "traslitterare",
    "traslitterassimo": "traslitterare",
    "traslitteraste": "traslitterare",
    "traslitterasti": "traslitterare",
    "traslitterata": "traslitterare",
    "traslitterate": "traslitterare",
    "traslitterati": "traslitterare",
    "traslitterato": "traslitterare",
    "traslitterava": "traslitterare",
    "traslitteravamo": "traslitterare",
    "traslitteravan": "traslitterare",
    "traslitteravano": "traslitterare",
    "traslitteravate": "traslitterare",
    "traslitteravi": "traslitterare",
    "traslitteravo": "traslitterare",
    "traslittererai": "traslitterare",
    "traslittereran": "traslitterare",
    "traslittereranno": "traslitterare",
    "traslittererebbe": "traslitterare",
    "traslittererebber": "traslitterare",
    "traslittererebbero": "traslitterare",
    "traslittererei": "traslitterare",
    "traslittereremmo": "traslitterare",
    "traslittereremo": "traslitterare",
    "traslitterereste": "traslitterare",
    "traslittereresti": "traslitterare",
    "traslittererete": "traslitterare",
    "traslittererà": "traslitterare",
    "traslittererò": "traslitterare",
    "traslitteri": "traslitterare",
    "traslitteriamo": "traslitterare",
    "traslitteriate": "traslitterare",
    "traslitterin": "traslitterare",
    "traslitterino": "traslitterare",
    "traslittero": "traslitterare",
    "traslitterò": "traslitterare",
    "traslo": "traslare",
    "trasloca": "traslocare",
    "traslocai": "traslocare",
    "traslocammo": "traslocare",
    "traslocan": "traslocare",
    "traslocando": "traslocare",
    "traslocano": "traslocare",
    "traslocante": "traslocare",
    "traslocanti": "traslocare",
    "traslocar": "traslocare",
    "traslocaron": "traslocare",
    "traslocarono": "traslocare",
    "traslocasse": "traslocare",
    "traslocasser": "traslocare",
    "traslocassero": "traslocare",
    "traslocassi": "traslocare",
    "traslocassimo": "traslocare",
    "traslocaste": "traslocare",
    "traslocasti": "traslocare",
    "traslocata": "traslocare",
    "traslocate": "traslocare",
    "traslocati": "traslocare",
    "traslocato": "traslocare",
    "traslocava": "traslocare",
    "traslocavamo": "traslocare",
    "traslocavan": "traslocare",
    "traslocavano": "traslocare",
    "traslocavate": "traslocare",
    "traslocavi": "traslocare",
    "traslocavo": "traslocare",
    "traslocherai": "traslocare",
    "traslocheran": "traslocare",
    "traslocheranno": "traslocare",
    "traslocherebbe": "traslocare",
    "traslocherebber": "traslocare",
    "traslocherebbero": "traslocare",
    "traslocherei": "traslocare",
    "traslocheremmo": "traslocare",
    "traslocheremo": "traslocare",
    "traslochereste": "traslocare",
    "traslocheresti": "traslocare",
    "traslocherete": "traslocare",
    "traslocherà": "traslocare",
    "traslocherò": "traslocare",
    "traslochi": "trasloco",
    "traslochiamo": "traslocare",
    "traslochiate": "traslocare",
    "traslochin": "traslocare",
    "traslochino": "traslocare",
    "trasloco": "traslocare",
    "traslocò": "traslocare",
    "traslò": "traslare",
    "trasmessa": "trasmettere",
    "trasmesse": "trasmettere",
    "trasmessi": "trasmettere",
    "trasmesso": "trasmettere",
    "trasmetta": "trasmettere",
    "trasmettan": "trasmettere",
    "trasmettano": "trasmettere",
    "trasmette": "trasmettere",
    "trasmettemmo": "trasmettere",
    "trasmettendo": "trasmettere",
    "trasmettente": "trasmettere",
    "trasmettenti": "trasmettere",
    "trasmetter": "trasmettere",
    "trasmetterai": "trasmettere",
    "trasmetteran": "trasmettere",
    "trasmetteranno": "trasmettere",
    "trasmetterebbe": "trasmettere",
    "trasmetterebber": "trasmettere",
    "trasmetterebbero": "trasmettere",
    "trasmetterei": "trasmettere",
    "trasmetteremmo": "trasmettere",
    "trasmetteremo": "trasmettere",
    "trasmettereste": "trasmettere",
    "trasmetteresti": "trasmettere",
    "trasmetterete": "trasmettere",
    "trasmetterà": "trasmettere",
    "trasmetterò": "trasmettere",
    "trasmettesse": "trasmettere",
    "trasmettesser": "trasmettere",
    "trasmettessero": "trasmettere",
    "trasmettessi": "trasmettere",
    "trasmettessimo": "trasmettere",
    "trasmetteste": "trasmettere",
    "trasmettesti": "trasmettere",
    "trasmettete": "trasmettere",
    "trasmetteva": "trasmettere",
    "trasmettevamo": "trasmettere",
    "trasmettevan": "trasmettere",
    "trasmettevano": "trasmettere",
    "trasmettevate": "trasmettere",
    "trasmettevi": "trasmettere",
    "trasmettevo": "trasmettere",
    "trasmetti": "trasmettere",
    "trasmettiamo": "trasmettere",
    "trasmettiate": "trasmettere",
    "trasmettitori": "trasmettitore",
    "trasmetto": "trasmettere",
    "trasmetton": "trasmettere",
    "trasmettono": "trasmettere",
    "trasmigra": "trasmigrare",
    "trasmigrai": "trasmigrare",
    "trasmigrammo": "trasmigrare",
    "trasmigran": "trasmigrare",
    "trasmigrando": "trasmigrare",
    "trasmigrano": "trasmigrare",
    "trasmigrante": "trasmigrare",
    "trasmigranti": "trasmigrare",
    "trasmigrar": "trasmigrare",
    "trasmigraron": "trasmigrare",
    "trasmigrarono": "trasmigrare",
    "trasmigrasse": "trasmigrare",
    "trasmigrasser": "trasmigrare",
    "trasmigrassero": "trasmigrare",
    "trasmigrassi": "trasmigrare",
    "trasmigrassimo": "trasmigrare",
    "trasmigraste": "trasmigrare",
    "trasmigrasti": "trasmigrare",
    "trasmigrata": "trasmigrare",
    "trasmigrate": "trasmigrare",
    "trasmigrati": "trasmigrare",
    "trasmigrato": "trasmigrare",
    "trasmigrava": "trasmigrare",
    "trasmigravamo": "trasmigrare",
    "trasmigravan": "trasmigrare",
    "trasmigravano": "trasmigrare",
    "trasmigravate": "trasmigrare",
    "trasmigravi": "trasmigrare",
    "trasmigravo": "trasmigrare",
    "trasmigrazioni": "trasmigrazione",
    "trasmigrerai": "trasmigrare",
    "trasmigreran": "trasmigrare",
    "trasmigreranno": "trasmigrare",
    "trasmigrerebbe": "trasmigrare",
    "trasmigrerebber": "trasmigrare",
    "trasmigrerebbero": "trasmigrare",
    "trasmigrerei": "trasmigrare",
    "trasmigreremmo": "trasmigrare",
    "trasmigreremo": "trasmigrare",
    "trasmigrereste": "trasmigrare",
    "trasmigreresti": "trasmigrare",
    "trasmigrerete": "trasmigrare",
    "trasmigrerà": "trasmigrare",
    "trasmigrerò": "trasmigrare",
    "trasmigri": "trasmigrare",
    "trasmigriamo": "trasmigrare",
    "trasmigriate": "trasmigrare",
    "trasmigrin": "trasmigrare",
    "trasmigrino": "trasmigrare",
    "trasmigro": "trasmigrare",
    "trasmigrò": "trasmigrare",
    "trasmise": "trasmettere",
    "trasmiser": "trasmettere",
    "trasmisero": "trasmettere",
    "trasmisi": "trasmettere",
    "trasmissibili": "trasmissibile",
    "trasmissioni": "trasmissione",
    "trasmittenti": "trasmittente",
    "trasmoda": "trasmodare",
    "trasmodai": "trasmodare",
    "trasmodammo": "trasmodare",
    "trasmodan": "trasmodare",
    "trasmodando": "trasmodare",
    "trasmodano": "trasmodare",
    "trasmodante": "trasmodare",
    "trasmodanti": "trasmodare",
    "trasmodar": "trasmodare",
    "trasmodaron": "trasmodare",
    "trasmodarono": "trasmodare",
    "trasmodasse": "trasmodare",
    "trasmodasser": "trasmodare",
    "trasmodassero": "trasmodare",
    "trasmodassi": "trasmodare",
    "trasmodassimo": "trasmodare",
    "trasmodaste": "trasmodare",
    "trasmodasti": "trasmodare",
    "trasmodata": "trasmodare",
    "trasmodate": "trasmodare",
    "trasmodati": "trasmodare",
    "trasmodato": "trasmodare",
    "trasmodava": "trasmodare",
    "trasmodavamo": "trasmodare",
    "trasmodavan": "trasmodare",
    "trasmodavano": "trasmodare",
    "trasmodavate": "trasmodare",
    "trasmodavi": "trasmodare",
    "trasmodavo": "trasmodare",
    "trasmoderai": "trasmodare",
    "trasmoderan": "trasmodare",
    "trasmoderanno": "trasmodare",
    "trasmoderebbe": "trasmodare",
    "trasmoderebber": "trasmodare",
    "trasmoderebbero": "trasmodare",
    "trasmoderei": "trasmodare",
    "trasmoderemmo": "trasmodare",
    "trasmoderemo": "trasmodare",
    "trasmodereste": "trasmodare",
    "trasmoderesti": "trasmodare",
    "trasmoderete": "trasmodare",
    "trasmoderà": "trasmodare",
    "trasmoderò": "trasmodare",
    "trasmodi": "trasmodare",
    "trasmodiamo": "trasmodare",
    "trasmodiate": "trasmodare",
    "trasmodin": "trasmodare",
    "trasmodino": "trasmodare",
    "trasmodo": "trasmodare",
    "trasmodò": "trasmodare",
    "trasmutazioni": "trasmutazione",
    "trasogna": "trasognare",
    "trasognai": "trasognare",
    "trasognammo": "trasognare",
    "trasognan": "trasognare",
    "trasognando": "trasognare",
    "trasognano": "trasognare",
    "trasognante": "trasognare",
    "trasognanti": "trasognare",
    "trasognar": "trasognare",
    "trasognaron": "trasognare",
    "trasognarono": "trasognare",
    "trasognasse": "trasognare",
    "trasognasser": "trasognare",
    "trasognassero": "trasognare",
    "trasognassi": "trasognare",
    "trasognassimo": "trasognare",
    "trasognaste": "trasognare",
    "trasognasti": "trasognare",
    "trasognata": "trasognato",
    "trasognate": "trasognato",
    "trasognati": "trasognato",
    "trasognato": "trasognare",
    "trasognava": "trasognare",
    "trasognavamo": "trasognare",
    "trasognavan": "trasognare",
    "trasognavano": "trasognare",
    "trasognavate": "trasognare",
    "trasognavi": "trasognare",
    "trasognavo": "trasognare",
    "trasognerai": "trasognare",
    "trasogneran": "trasognare",
    "trasogneranno": "trasognare",
    "trasognerebbe": "trasognare",
    "trasognerebber": "trasognare",
    "trasognerebbero": "trasognare",
    "trasognerei": "trasognare",
    "trasogneremmo": "trasognare",
    "trasogneremo": "trasognare",
    "trasognereste": "trasognare",
    "trasogneresti": "trasognare",
    "trasognerete": "trasognare",
    "trasognerà": "trasognare",
    "trasognerò": "trasognare",
    "trasogni": "trasognare",
    "trasogniamo": "trasognare",
    "trasogniate": "trasognare",
    "trasognin": "trasognare",
    "trasognino": "trasognare",
    "trasogno": "trasognare",
    "trasognò": "trasognare",
    "traspara": "trasparire",
    "trasparan": "trasparire",
    "trasparano": "trasparire",
    "traspare": "trasparire",
    "trasparendo": "trasparire",
    "trasparente": "trasparire",
    "trasparenti": "trasparire",
    "trasparenze": "trasparenza",
    "traspari": "trasparire",
    "traspariamo": "trasparire",
    "traspariate": "trasparire",
    "trasparii": "trasparire",
    "trasparimmo": "trasparire",
    "trasparir": "trasparire",
    "trasparirai": "trasparire",
    "traspariran": "trasparire",
    "traspariranno": "trasparire",
    "trasparirebbe": "trasparire",
    "trasparirebber": "trasparire",
    "trasparirebbero": "trasparire",
    "trasparirei": "trasparire",
    "traspariremmo": "trasparire",
    "traspariremo": "trasparire",
    "trasparireste": "trasparire",
    "traspariresti": "trasparire",
    "trasparirete": "trasparire",
    "traspariron": "trasparire",
    "trasparirono": "trasparire",
    "trasparirà": "trasparire",
    "trasparirò": "trasparire",
    "trasparisse": "trasparire",
    "trasparisser": "trasparire",
    "trasparissero": "trasparire",
    "trasparissi": "trasparire",
    "trasparissimo": "trasparire",
    "traspariste": "trasparire",
    "trasparisti": "trasparire",
    "trasparita": "trasparire",
    "trasparite": "trasparire",
    "traspariti": "trasparire",
    "trasparito": "trasparire",
    "traspariva": "trasparire",
    "trasparivamo": "trasparire",
    "trasparivan": "trasparire",
    "trasparivano": "trasparire",
    "trasparivate": "trasparire",
    "trasparivi": "trasparire",
    "trasparivo": "trasparire",
    "trasparo": "trasparire",
    "trasparon": "trasparire",
    "trasparono": "trasparire",
    "trasparì": "trasparire",
    "traspira": "traspirare",
    "traspirai": "traspirare",
    "traspirammo": "traspirare",
    "traspiran": "traspirare",
    "traspirando": "traspirare",
    "traspirano": "traspirare",
    "traspirante": "traspirare",
    "traspiranti": "traspirare",
    "traspirar": "traspirare",
    "traspiraron": "traspirare",
    "traspirarono": "traspirare",
    "traspirasse": "traspirare",
    "traspirasser": "traspirare",
    "traspirassero": "traspirare",
    "traspirassi": "traspirare",
    "traspirassimo": "traspirare",
    "traspiraste": "traspirare",
    "traspirasti": "traspirare",
    "traspirata": "traspirare",
    "traspirate": "traspirare",
    "traspirati": "traspirare",
    "traspirato": "traspirare",
    "traspirava": "traspirare",
    "traspiravamo": "traspirare",
    "traspiravan": "traspirare",
    "traspiravano": "traspirare",
    "traspiravate": "traspirare",
    "traspiravi": "traspirare",
    "traspiravo": "traspirare",
    "traspirerai": "traspirare",
    "traspireran": "traspirare",
    "traspireranno": "traspirare",
    "traspirerebbe": "traspirare",
    "traspirerebber": "traspirare",
    "traspirerebbero": "traspirare",
    "traspirerei": "traspirare",
    "traspireremmo": "traspirare",
    "traspireremo": "traspirare",
    "traspirereste": "traspirare",
    "traspireresti": "traspirare",
    "traspirerete": "traspirare",
    "traspirerà": "traspirare",
    "traspirerò": "traspirare",
    "traspiri": "traspirare",
    "traspiriamo": "traspirare",
    "traspiriate": "traspirare",
    "traspirin": "traspirare",
    "traspirino": "traspirare",
    "traspiro": "traspirare",
    "traspirò": "traspirare",
    "traspone": "trasporre",
    "trasponemmo": "trasporre",
    "trasponendo": "trasporre",
    "trasponente": "trasporre",
    "trasponenti": "trasporre",
    "trasponesse": "trasporre",
    "trasponesser": "trasporre",
    "trasponessero": "trasporre",
    "trasponessi": "trasporre",
    "trasponessimo": "trasporre",
    "trasponeste": "trasporre",
    "trasponesti": "trasporre",
    "trasponete": "trasporre",
    "trasponeva": "trasporre",
    "trasponevamo": "trasporre",
    "trasponevan": "trasporre",
    "trasponevano": "trasporre",
    "trasponevate": "trasporre",
    "trasponevi": "trasporre",
    "trasponevo": "trasporre",
    "trasponga": "trasporre",
    "traspongan": "trasporre",
    "traspongano": "trasporre",
    "traspongo": "trasporre",
    "traspongon": "trasporre",
    "traspongono": "trasporre",
    "trasponi": "trasporre",
    "trasponiamo": "trasporre",
    "trasponiate": "trasporre",
    "trasporr": "trasporre",
    "trasporrai": "trasporre",
    "trasporran": "trasporre",
    "trasporranno": "trasporre",
    "trasporrebbe": "trasporre",
    "trasporrebber": "trasporre",
    "trasporrebbero": "trasporre",
    "trasporrei": "trasporre",
    "trasporremmo": "trasporre",
    "trasporremo": "trasporre",
    "trasporreste": "trasporre",
    "trasporresti": "trasporre",
    "trasporrete": "trasporre",
    "trasporrà": "trasporre",
    "trasporrò": "trasporre",
    "trasporta": "trasportare",
    "trasportabili": "trasportabile",
    "trasportai": "trasportare",
    "trasportammo": "trasportare",
    "trasportan": "trasportare",
    "trasportando": "trasportare",
    "trasportano": "trasportare",
    "trasportante": "trasportare",
    "trasportanti": "trasportare",
    "trasportar": "trasportare",
    "trasportaron": "trasportare",
    "trasportarono": "trasportare",
    "trasportasse": "trasportare",
    "trasportasser": "trasportare",
    "trasportassero": "trasportare",
    "trasportassi": "trasportare",
    "trasportassimo": "trasportare",
    "trasportaste": "trasportare",
    "trasportasti": "trasportare",
    "trasportata": "trasportato",
    "trasportate": "trasportato",
    "trasportati": "trasportato",
    "trasportato": "trasportare",
    "trasportatori": "trasportatore",
    "trasportatrice": "trasportatore",
    "trasportatrici": "trasportatore",
    "trasportava": "trasportare",
    "trasportavamo": "trasportare",
    "trasportavan": "trasportare",
    "trasportavano": "trasportare",
    "trasportavate": "trasportare",
    "trasportavi": "trasportare",
    "trasportavo": "trasportare",
    "trasporterai": "trasportare",
    "trasporteran": "trasportare",
    "trasporteranno": "trasportare",
    "trasporterebbe": "trasportare",
    "trasporterebber": "trasportare",
    "trasporterebbero": "trasportare",
    "trasporterei": "trasportare",
    "trasporteremmo": "trasportare",
    "trasporteremo": "trasportare",
    "trasportereste": "trasportare",
    "trasporteresti": "trasportare",
    "trasporterete": "trasportare",
    "trasporterà": "trasportare",
    "trasporterò": "trasportare",
    "trasporti": "trasporto",
    "trasportiamo": "trasportare",
    "trasportiate": "trasportare",
    "trasportin": "trasportare",
    "trasportino": "trasportare",
    "trasporto": "trasportare",
    "trasportò": "trasportare",
    "traspose": "trasporre",
    "trasposer": "trasporre",
    "trasposero": "trasporre",
    "trasposi": "trasporre",
    "trasposizioni": "trasposizione",
    "trasposta": "trasporre",
    "trasposte": "trasporre",
    "trasposti": "trasporre",
    "trasposto": "trasporre",
    "trasse": "trarre",
    "trasser": "trarre",
    "trassero": "trarre",
    "trassi": "trarre",
    "trastulla": "trastullare",
    "trastullai": "trastullare",
    "trastullammo": "trastullare",
    "trastullan": "trastullare",
    "trastullando": "trastullare",
    "trastullano": "trastullare",
    "trastullante": "trastullare",
    "trastullanti": "trastullare",
    "trastullar": "trastullare",
    "trastullaron": "trastullare",
    "trastullarono": "trastullare",
    "trastullasse": "trastullare",
    "trastullasser": "trastullare",
    "trastullassero": "trastullare",
    "trastullassi": "trastullare",
    "trastullassimo": "trastullare",
    "trastullaste": "trastullare",
    "trastullasti": "trastullare",
    "trastullata": "trastullare",
    "trastullate": "trastullare",
    "trastullati": "trastullare",
    "trastullato": "trastullare",
    "trastullava": "trastullare",
    "trastullavamo": "trastullare",
    "trastullavan": "trastullare",
    "trastullavano": "trastullare",
    "trastullavate": "trastullare",
    "trastullavi": "trastullare",
    "trastullavo": "trastullare",
    "trastullerai": "trastullare",
    "trastulleran": "trastullare",
    "trastulleranno": "trastullare",
    "trastullerebbe": "trastullare",
    "trastullerebber": "trastullare",
    "trastullerebbero": "trastullare",
    "trastullerei": "trastullare",
    "trastulleremmo": "trastullare",
    "trastulleremo": "trastullare",
    "trastullereste": "trastullare",
    "trastulleresti": "trastullare",
    "trastullerete": "trastullare",
    "trastullerà": "trastullare",
    "trastullerò": "trastullare",
    "trastulli": "trastullo",
    "trastulliamo": "trastullare",
    "trastulliate": "trastullare",
    "trastullin": "trastullare",
    "trastullino": "trastullare",
    "trastullo": "trastullare",
    "trastullò": "trastullare",
    "trasuda": "trasudare",
    "trasudai": "trasudare",
    "trasudammo": "trasudare",
    "trasudan": "trasudare",
    "trasudando": "trasudare",
    "trasudano": "trasudare",
    "trasudante": "trasudare",
    "trasudanti": "trasudare",
    "trasudar": "trasudare",
    "trasudaron": "trasudare",
    "trasudarono": "trasudare",
    "trasudasse": "trasudare",
    "trasudasser": "trasudare",
    "trasudassero": "trasudare",
    "trasudassi": "trasudare",
    "trasudassimo": "trasudare",
    "trasudaste": "trasudare",
    "trasudasti": "trasudare",
    "trasudata": "trasudare",
    "trasudate": "trasudare",
    "trasudati": "trasudare",
    "trasudato": "trasudare",
    "trasudava": "trasudare",
    "trasudavamo": "trasudare",
    "trasudavan": "trasudare",
    "trasudavano": "trasudare",
    "trasudavate": "trasudare",
    "trasudavi": "trasudare",
    "trasudavo": "trasudare",
    "trasuderai": "trasudare",
    "trasuderan": "trasudare",
    "trasuderanno": "trasudare",
    "trasuderebbe": "trasudare",
    "trasuderebber": "trasudare",
    "trasuderebbero": "trasudare",
    "trasuderei": "trasudare",
    "trasuderemmo": "trasudare",
    "trasuderemo": "trasudare",
    "trasudereste": "trasudare",
    "trasuderesti": "trasudare",
    "trasuderete": "trasudare",
    "trasuderà": "trasudare",
    "trasuderò": "trasudare",
    "trasudi": "trasudare",
    "trasudiamo": "trasudare",
    "trasudiate": "trasudare",
    "trasudin": "trasudare",
    "trasudino": "trasudare",
    "trasudo": "trasudare",
    "trasudò": "trasudare",
    "trasumana": "trasumanare",
    "trasumanai": "trasumanare",
    "trasumanammo": "trasumanare",
    "trasumanan": "trasumanare",
    "trasumanando": "trasumanare",
    "trasumanano": "trasumanare",
    "trasumanante": "trasumanare",
    "trasumananti": "trasumanare",
    "trasumanar": "trasumanare",
    "trasumanaron": "trasumanare",
    "trasumanarono": "trasumanare",
    "trasumanasse": "trasumanare",
    "trasumanasser": "trasumanare",
    "trasumanassero": "trasumanare",
    "trasumanassi": "trasumanare",
    "trasumanassimo": "trasumanare",
    "trasumanaste": "trasumanare",
    "trasumanasti": "trasumanare",
    "trasumanata": "trasumanare",
    "trasumanate": "trasumanare",
    "trasumanati": "trasumanare",
    "trasumanato": "trasumanare",
    "trasumanava": "trasumanare",
    "trasumanavamo": "trasumanare",
    "trasumanavan": "trasumanare",
    "trasumanavano": "trasumanare",
    "trasumanavate": "trasumanare",
    "trasumanavi": "trasumanare",
    "trasumanavo": "trasumanare",
    "trasumanerai": "trasumanare",
    "trasumaneran": "trasumanare",
    "trasumaneranno": "trasumanare",
    "trasumanerebbe": "trasumanare",
    "trasumanerebber": "trasumanare",
    "trasumanerebbero": "trasumanare",
    "trasumanerei": "trasumanare",
    "trasumaneremmo": "trasumanare",
    "trasumaneremo": "trasumanare",
    "trasumanereste": "trasumanare",
    "trasumaneresti": "trasumanare",
    "trasumanerete": "trasumanare",
    "trasumanerà": "trasumanare",
    "trasumanerò": "trasumanare",
    "trasumani": "trasumanare",
    "trasumaniamo": "trasumanare",
    "trasumaniate": "trasumanare",
    "trasumanin": "trasumanare",
    "trasumanino": "trasumanare",
    "trasumano": "trasumanare",
    "trasumanò": "trasumanare",
    "trasversali": "trasversale",
    "trasversalismi": "trasversalismo",
    "trasvola": "trasvolare",
    "trasvolai": "trasvolare",
    "trasvolammo": "trasvolare",
    "trasvolan": "trasvolare",
    "trasvolando": "trasvolare",
    "trasvolano": "trasvolare",
    "trasvolante": "trasvolare",
    "trasvolanti": "trasvolare",
    "trasvolar": "trasvolare",
    "trasvolaron": "trasvolare",
    "trasvolarono": "trasvolare",
    "trasvolasse": "trasvolare",
    "trasvolasser": "trasvolare",
    "trasvolassero": "trasvolare",
    "trasvolassi": "trasvolare",
    "trasvolassimo": "trasvolare",
    "trasvolaste": "trasvolare",
    "trasvolasti": "trasvolare",
    "trasvolata": "trasvolare",
    "trasvolate": "trasvolata",
    "trasvolati": "trasvolare",
    "trasvolato": "trasvolare",
    "trasvolava": "trasvolare",
    "trasvolavamo": "trasvolare",
    "trasvolavan": "trasvolare",
    "trasvolavano": "trasvolare",
    "trasvolavate": "trasvolare",
    "trasvolavi": "trasvolare",
    "trasvolavo": "trasvolare",
    "trasvolerai": "trasvolare",
    "trasvoleran": "trasvolare",
    "trasvoleranno": "trasvolare",
    "trasvolerebbe": "trasvolare",
    "trasvolerebber": "trasvolare",
    "trasvolerebbero": "trasvolare",
    "trasvolerei": "trasvolare",
    "trasvoleremmo": "trasvolare",
    "trasvoleremo": "trasvolare",
    "trasvolereste": "trasvolare",
    "trasvoleresti": "trasvolare",
    "trasvolerete": "trasvolare",
    "trasvolerà": "trasvolare",
    "trasvolerò": "trasvolare",
    "trasvoli": "trasvolare",
    "trasvoliamo": "trasvolare",
    "trasvoliate": "trasvolare",
    "trasvolin": "trasvolare",
    "trasvolino": "trasvolare",
    "trasvolo": "trasvolare",
    "trasvolò": "trasvolare",
    "tratta": "trattare",
    "trattabili": "trattabile",
    "trattai": "trattare",
    "trattamenti": "trattamento",
    "trattammo": "trattare",
    "trattan": "trattare",
    "trattando": "trattare",
    "trattano": "trattare",
    "trattante": "trattare",
    "trattanti": "trattare",
    "trattar": "trattare",
    "trattaron": "trattare",
    "trattarono": "trattare",
    "trattasse": "trattare",
    "trattasser": "trattare",
    "trattassero": "trattare",
    "trattassi": "trattare",
    "trattassimo": "trattare",
    "trattaste": "trattare",
    "trattasti": "trattare",
    "trattata": "trattare",
    "trattate": "trattare",
    "trattatelli": "trattatello",
    "trattati": "trattato",
    "trattatisti": "trattatista",
    "trattative": "trattativa",
    "trattato": "trattare",
    "trattava": "trattare",
    "trattavamo": "trattare",
    "trattavan": "trattare",
    "trattavano": "trattare",
    "trattavate": "trattare",
    "trattavi": "trattare",
    "trattavo": "trattare",
    "trattazioni": "trattazione",
    "tratte": "tratta",
    "tratteggerai": "tratteggiare",
    "tratteggeran": "tratteggiare",
    "tratteggeranno": "tratteggiare",
    "tratteggerebbe": "tratteggiare",
    "tratteggerebber": "tratteggiare",
    "tratteggerebbero": "tratteggiare",
    "tratteggerei": "tratteggiare",
    "tratteggeremmo": "tratteggiare",
    "tratteggeremo": "tratteggiare",
    "tratteggereste": "tratteggiare",
    "tratteggeresti": "tratteggiare",
    "tratteggerete": "tratteggiare",
    "tratteggerà": "tratteggiare",
    "tratteggerò": "tratteggiare",
    "tratteggi": "tratteggiare",
    "tratteggia": "tratteggiare",
    "tratteggiai": "tratteggiare",
    "tratteggiammo": "tratteggiare",
    "tratteggiamo": "tratteggiare",
    "tratteggian": "tratteggiare",
    "tratteggiando": "tratteggiare",
    "tratteggiano": "tratteggiare",
    "tratteggiante": "tratteggiare",
    "tratteggianti": "tratteggiare",
    "tratteggiar": "tratteggiare",
    "tratteggiaron": "tratteggiare",
    "tratteggiarono": "tratteggiare",
    "tratteggiasse": "tratteggiare",
    "tratteggiasser": "tratteggiare",
    "tratteggiassero": "tratteggiare",
    "tratteggiassi": "tratteggiare",
    "tratteggiassimo": "tratteggiare",
    "tratteggiaste": "tratteggiare",
    "tratteggiasti": "tratteggiare",
    "tratteggiata": "tratteggiare",
    "tratteggiate": "tratteggiare",
    "tratteggiati": "tratteggiare",
    "tratteggiato": "tratteggiare",
    "tratteggiava": "tratteggiare",
    "tratteggiavamo": "tratteggiare",
    "tratteggiavan": "tratteggiare",
    "tratteggiavano": "tratteggiare",
    "tratteggiavate": "tratteggiare",
    "tratteggiavi": "tratteggiare",
    "tratteggiavo": "tratteggiare",
    "tratteggin": "tratteggiare",
    "tratteggino": "tratteggiare",
    "tratteggio": "tratteggiare",
    "tratteggiò": "tratteggiare",
    "trattenemmo": "trattenere",
    "trattenendo": "trattenere",
    "trattenente": "trattenere",
    "trattenenti": "trattenere",
    "trattener": "trattenere",
    "trattenesse": "trattenere",
    "trattenesser": "trattenere",
    "trattenessero": "trattenere",
    "trattenessi": "trattenere",
    "trattenessimo": "trattenere",
    "tratteneste": "trattenere",
    "trattenesti": "trattenere",
    "trattenete": "trattenere",
    "tratteneva": "trattenere",
    "trattenevamo": "trattenere",
    "trattenevan": "trattenere",
    "trattenevano": "trattenere",
    "trattenevate": "trattenere",
    "trattenevi": "trattenere",
    "trattenevo": "trattenere",
    "trattenga": "trattenere",
    "trattengan": "trattenere",
    "trattengano": "trattenere",
    "trattengo": "trattenere",
    "trattengon": "trattenere",
    "trattengono": "trattenere",
    "tratteniamo": "trattenere",
    "tratteniate": "trattenere",
    "trattenimenti": "trattenimento",
    "trattenne": "trattenere",
    "trattenner": "trattenere",
    "trattennero": "trattenere",
    "trattenni": "trattenere",
    "trattenuta": "trattenere",
    "trattenute": "trattenuta",
    "trattenuti": "trattenere",
    "trattenuto": "trattenere",
    "tratterai": "trattare",
    "tratteran": "trattare",
    "tratteranno": "trattare",
    "tratterebbe": "trattare",
    "tratterebber": "trattare",
    "tratterebbero": "trattare",
    "tratterei": "trattare",
    "tratteremmo": "trattare",
    "tratteremo": "trattare",
    "trattereste": "trattare",
    "tratteresti": "trattare",
    "tratterete": "trattare",
    "tratterrai": "trattenere",
    "tratterran": "trattenere",
    "tratterranno": "trattenere",
    "tratterrebbe": "trattenere",
    "tratterrebber": "trattenere",
    "tratterrebbero": "trattenere",
    "tratterrei": "trattenere",
    "tratterremmo": "trattenere",
    "tratterremo": "trattenere",
    "tratterreste": "trattenere",
    "tratterresti": "trattenere",
    "tratterrete": "trattenere",
    "tratterrà": "trattenere",
    "tratterrò": "trattenere",
    "tratterà": "trattare",
    "tratterò": "trattare",
    "tratti": "tratto",
    "trattiamo": "trattare",
    "trattiate": "trattare",
    "trattiene": "trattenere",
    "trattieni": "trattenere",
    "trattin": "trattare",
    "trattini": "trattino",
    "trattino": "trattare",
    "trattive": "trattiva",
    "tratto": "trattare",
    "trattori": "trattore",
    "trattorie": "trattoria",
    "trattò": "trattare",
    "traumatica": "traumatico",
    "traumatiche": "traumatico",
    "traumatici": "traumatico",
    "traumatizza": "traumatizzare",
    "traumatizzai": "traumatizzare",
    "traumatizzammo": "traumatizzare",
    "traumatizzan": "traumatizzare",
    "traumatizzando": "traumatizzare",
    "traumatizzano": "traumatizzare",
    "traumatizzante": "traumatizzare",
    "traumatizzanti": "traumatizzare",
    "traumatizzar": "traumatizzare",
    "traumatizzaron": "traumatizzare",
    "traumatizzarono": "traumatizzare",
    "traumatizzasse": "traumatizzare",
    "traumatizzasser": "traumatizzare",
    "traumatizzassero": "traumatizzare",
    "traumatizzassi": "traumatizzare",
    "traumatizzassimo": "traumatizzare",
    "traumatizzaste": "traumatizzare",
    "traumatizzasti": "traumatizzare",
    "traumatizzata": "traumatizzato",
    "traumatizzate": "traumatizzato",
    "traumatizzati": "traumatizzato",
    "traumatizzato": "traumatizzare",
    "traumatizzava": "traumatizzare",
    "traumatizzavamo": "traumatizzare",
    "traumatizzavan": "traumatizzare",
    "traumatizzavano": "traumatizzare",
    "traumatizzavate": "traumatizzare",
    "traumatizzavi": "traumatizzare",
    "traumatizzavo": "traumatizzare",
    "traumatizzerai": "traumatizzare",
    "traumatizzeran": "traumatizzare",
    "traumatizzeranno": "traumatizzare",
    "traumatizzerebbe": "traumatizzare",
    "traumatizzerebber": "traumatizzare",
    "traumatizzerebbero": "traumatizzare",
    "traumatizzerei": "traumatizzare",
    "traumatizzeremmo": "traumatizzare",
    "traumatizzeremo": "traumatizzare",
    "traumatizzereste": "traumatizzare",
    "traumatizzeresti": "traumatizzare",
    "traumatizzerete": "traumatizzare",
    "traumatizzerà": "traumatizzare",
    "traumatizzerò": "traumatizzare",
    "traumatizzi": "traumatizzare",
    "traumatizziamo": "traumatizzare",
    "traumatizziate": "traumatizzare",
    "traumatizzin": "traumatizzare",
    "traumatizzino": "traumatizzare",
    "traumatizzo": "traumatizzare",
    "traumatizzò": "traumatizzare",
    "traumatologica": "traumatologico",
    "traumatologiche": "traumatologico",
    "traumatologici": "traumatologico",
    "traumi": "trauma",
    "travagli": "travaglio",
    "travaglia": "travagliare",
    "travagliai": "travagliare",
    "travagliammo": "travagliare",
    "travagliamo": "travagliare",
    "travaglian": "travagliare",
    "travagliando": "travagliare",
    "travagliano": "travagliare",
    "travagliante": "travagliare",
    "travaglianti": "travagliare",
    "travagliar": "travagliare",
    "travagliaron": "travagliare",
    "travagliarono": "travagliare",
    "travagliasse": "travagliare",
    "travagliasser": "travagliare",
    "travagliassero": "travagliare",
    "travagliassi": "travagliare",
    "travagliassimo": "travagliare",
    "travagliaste": "travagliare",
    "travagliasti": "travagliare",
    "travagliata": "travagliato",
    "travagliate": "travagliato",
    "travagliati": "travagliato",
    "travagliato": "travagliare",
    "travagliava": "travagliare",
    "travagliavamo": "travagliare",
    "travagliavan": "travagliare",
    "travagliavano": "travagliare",
    "travagliavate": "travagliare",
    "travagliavi": "travagliare",
    "travagliavo": "travagliare",
    "travaglierai": "travagliare",
    "travaglieran": "travagliare",
    "travaglieranno": "travagliare",
    "travaglierebbe": "travagliare",
    "travaglierebber": "travagliare",
    "travaglierebbero": "travagliare",
    "travaglierei": "travagliare",
    "travaglieremmo": "travagliare",
    "travaglieremo": "travagliare",
    "travagliereste": "travagliare",
    "travaglieresti": "travagliare",
    "travaglierete": "travagliare",
    "travaglierà": "travagliare",
    "travaglierò": "travagliare",
    "travaglin": "travagliare",
    "travaglino": "travagliare",
    "travaglio": "travagliare",
    "travagliò": "travagliare",
    "travalica": "travalicare",
    "travalicai": "travalicare",
    "travalicammo": "travalicare",
    "travalican": "travalicare",
    "travalicando": "travalicare",
    "travalicano": "travalicare",
    "travalicante": "travalicare",
    "travalicanti": "travalicare",
    "travalicar": "travalicare",
    "travalicaron": "travalicare",
    "travalicarono": "travalicare",
    "travalicasse": "travalicare",
    "travalicasser": "travalicare",
    "travalicassero": "travalicare",
    "travalicassi": "travalicare",
    "travalicassimo": "travalicare",
    "travalicaste": "travalicare",
    "travalicasti": "travalicare",
    "travalicata": "travalicare",
    "travalicate": "travalicare",
    "travalicati": "travalicare",
    "travalicato": "travalicare",
    "travalicava": "travalicare",
    "travalicavamo": "travalicare",
    "travalicavan": "travalicare",
    "travalicavano": "travalicare",
    "travalicavate": "travalicare",
    "travalicavi": "travalicare",
    "travalicavo": "travalicare",
    "travalicherai": "travalicare",
    "travalicheran": "travalicare",
    "travalicheranno": "travalicare",
    "travalicherebbe": "travalicare",
    "travalicherebber": "travalicare",
    "travalicherebbero": "travalicare",
    "travalicherei": "travalicare",
    "travalicheremmo": "travalicare",
    "travalicheremo": "travalicare",
    "travalichereste": "travalicare",
    "travalicheresti": "travalicare",
    "travalicherete": "travalicare",
    "travalicherà": "travalicare",
    "travalicherò": "travalicare",
    "travalichi": "travalicare",
    "travalichiamo": "travalicare",
    "travalichiate": "travalicare",
    "travalichin": "travalicare",
    "travalichino": "travalicare",
    "travalico": "travalicare",
    "travalicò": "travalicare",
    "travasa": "travasare",
    "travasai": "travasare",
    "travasammo": "travasare",
    "travasan": "travasare",
    "travasando": "travasare",
    "travasano": "travasare",
    "travasante": "travasare",
    "travasanti": "travasare",
    "travasar": "travasare",
    "travasaron": "travasare",
    "travasarono": "travasare",
    "travasasse": "travasare",
    "travasasser": "travasare",
    "travasassero": "travasare",
    "travasassi": "travasare",
    "travasassimo": "travasare",
    "travasaste": "travasare",
    "travasasti": "travasare",
    "travasata": "travasare",
    "travasate": "travasare",
    "travasati": "travasare",
    "travasato": "travasare",
    "travasava": "travasare",
    "travasavamo": "travasare",
    "travasavan": "travasare",
    "travasavano": "travasare",
    "travasavate": "travasare",
    "travasavi": "travasare",
    "travasavo": "travasare",
    "travaserai": "travasare",
    "travaseran": "travasare",
    "travaseranno": "travasare",
    "travaserebbe": "travasare",
    "travaserebber": "travasare",
    "travaserebbero": "travasare",
    "travaserei": "travasare",
    "travaseremmo": "travasare",
    "travaseremo": "travasare",
    "travasereste": "travasare",
    "travaseresti": "travasare",
    "travaserete": "travasare",
    "travaserà": "travasare",
    "travaserò": "travasare",
    "travasi": "travaso",
    "travasiamo": "travasare",
    "travasiate": "travasare",
    "travasin": "travasare",
    "travasino": "travasare",
    "travaso": "travasare",
    "travasò": "travasare",
    "traveda": "travedere",
    "travedan": "travedere",
    "travedano": "travedere",
    "travede": "travedere",
    "travedei": "travedere",
    "travedemmo": "travedere",
    "travedendo": "travedere",
    "travedente": "travedere",
    "travedenti": "travedere",
    "traveder": "travedere",
    "travederai": "travedere",
    "travederan": "travedere",
    "travederanno": "travedere",
    "travederebbe": "travedere",
    "travederebber": "travedere",
    "travederebbero": "travedere",
    "travederei": "travedere",
    "travederemmo": "travedere",
    "travederemo": "travedere",
    "travedereste": "travedere",
    "travederesti": "travedere",
    "travederete": "travedere",
    "travederon": "travedere",
    "travederono": "travedere",
    "travederà": "travedere",
    "travederò": "travedere",
    "travedesse": "travedere",
    "travedesser": "travedere",
    "travedessero": "travedere",
    "travedessi": "travedere",
    "travedessimo": "travedere",
    "travedeste": "travedere",
    "travedesti": "travedere",
    "travedete": "travedere",
    "travedeva": "travedere",
    "travedevamo": "travedere",
    "travedevan": "travedere",
    "travedevano": "travedere",
    "travedevate": "travedere",
    "travedevi": "travedere",
    "travedevo": "travedere",
    "travedi": "travedere",
    "travediamo": "travedere",
    "travediate": "travedere",
    "travedo": "travedere",
    "travedon": "travedere",
    "travedono": "travedere",
    "traveduta": "travedere",
    "travedute": "travedere",
    "traveduti": "travedere",
    "traveduto": "travedere",
    "travedè": "travedere",
    "traversa": "traverso",
    "traversai": "traversare",
    "traversammo": "traversare",
    "traversan": "traversare",
    "traversando": "traversare",
    "traversano": "traversare",
    "traversante": "traversare",
    "traversanti": "traversare",
    "traversar": "traversare",
    "traversaron": "traversare",
    "traversarono": "traversare",
    "traversasse": "traversare",
    "traversasser": "traversare",
    "traversassero": "traversare",
    "traversassi": "traversare",
    "traversassimo": "traversare",
    "traversaste": "traversare",
    "traversasti": "traversare",
    "traversata": "traversare",
    "traversate": "traversata",
    "traversati": "traversare",
    "traversato": "traversare",
    "traversava": "traversare",
    "traversavamo": "traversare",
    "traversavan": "traversare",
    "traversavano": "traversare",
    "traversavate": "traversare",
    "traversavi": "traversare",
    "traversavo": "traversare",
    "traverse": "traverso",
    "traverserai": "traversare",
    "traverseran": "traversare",
    "traverseranno": "traversare",
    "traverserebbe": "traversare",
    "traverserebber": "traversare",
    "traverserebbero": "traversare",
    "traverserei": "traversare",
    "traverseremmo": "traversare",
    "traverseremo": "traversare",
    "traversereste": "traversare",
    "traverseresti": "traversare",
    "traverserete": "traversare",
    "traverserà": "traversare",
    "traverserò": "traversare",
    "traversi": "traverso",
    "traversiamo": "traversare",
    "traversiate": "traversare",
    "traversie": "traversia",
    "traversin": "traversare",
    "traversine": "traversina",
    "traversino": "traversare",
    "traverso": "traversare",
    "traversoni": "traversone",
    "traversò": "traversare",
    "travertini": "travertino",
    "travesta": "travestire",
    "travestan": "travestire",
    "travestano": "travestire",
    "traveste": "travestire",
    "travestendo": "travestire",
    "travestente": "travestire",
    "travestenti": "travestire",
    "travesti": "travestire",
    "travestiamo": "travestire",
    "travestiate": "travestire",
    "travestii": "travestire",
    "travestimenti": "travestimento",
    "travestimmo": "travestire",
    "travestir": "travestire",
    "travestirai": "travestire",
    "travestiran": "travestire",
    "travestiranno": "travestire",
    "travestirebbe": "travestire",
    "travestirebber": "travestire",
    "travestirebbero": "travestire",
    "travestirei": "travestire",
    "travestiremmo": "travestire",
    "travestiremo": "travestire",
    "travestireste": "travestire",
    "travestiresti": "travestire",
    "travestirete": "travestire",
    "travestiron": "travestire",
    "travestirono": "travestire",
    "travestirà": "travestire",
    "travestirò": "travestire",
    "travestisse": "travestire",
    "travestisser": "travestire",
    "travestissero": "travestire",
    "travestissi": "travestire",
    "travestissimo": "travestire",
    "travestiste": "travestire",
    "travestisti": "travestire",
    "travestita": "travestito",
    "travestite": "travestito",
    "travestiti": "travestito",
    "travestitismi": "travestitismo",
    "travestito": "travestire",
    "travestiva": "travestire",
    "travestivamo": "travestire",
    "travestivan": "travestire",
    "travestivano": "travestire",
    "travestivate": "travestire",
    "travestivi": "travestire",
    "travestivo": "travestire",
    "travesto": "travestire",
    "traveston": "travestire",
    "travestono": "travestire",
    "travestì": "travestire",
    "travi": "traviare",
    "travia": "traviare",
    "traviai": "traviare",
    "traviammo": "traviare",
    "traviamo": "traviare",
    "travian": "traviare",
    "traviando": "traviare",
    "traviano": "traviare",
    "traviante": "traviare",
    "travianti": "traviare",
    "traviar": "traviare",
    "traviaron": "traviare",
    "traviarono": "traviare",
    "traviasse": "traviare",
    "traviasser": "traviare",
    "traviassero": "traviare",
    "traviassi": "traviare",
    "traviassimo": "traviare",
    "traviaste": "traviare",
    "traviasti": "traviare",
    "traviata": "traviare",
    "traviate": "traviata",
    "traviati": "traviare",
    "traviato": "traviare",
    "traviava": "traviare",
    "traviavamo": "traviare",
    "traviavan": "traviare",
    "traviavano": "traviare",
    "traviavate": "traviare",
    "traviavi": "traviare",
    "traviavo": "traviare",
    "travierai": "traviare",
    "travieran": "traviare",
    "travieranno": "traviare",
    "travierebbe": "traviare",
    "travierebber": "traviare",
    "travierebbero": "traviare",
    "travierei": "traviare",
    "travieremmo": "traviare",
    "travieremo": "traviare",
    "traviereste": "traviare",
    "travieresti": "traviare",
    "travierete": "traviare",
    "travierà": "traviare",
    "travierò": "traviare",
    "travin": "traviare",
    "travino": "traviare",
    "travio": "traviare",
    "travisa": "travisare",
    "travisai": "travisare",
    "travisamenti": "travisamento",
    "travisammo": "travisare",
    "travisan": "travisare",
    "travisando": "travisare",
    "travisano": "travisare",
    "travisante": "travisare",
    "travisanti": "travisare",
    "travisar": "travisare",
    "travisaron": "travisare",
    "travisarono": "travisare",
    "travisasse": "travisare",
    "travisasser": "travisare",
    "travisassero": "travisare",
    "travisassi": "travisare",
    "travisassimo": "travisare",
    "travisaste": "travisare",
    "travisasti": "travisare",
    "travisata": "travisare",
    "travisate": "travisare",
    "travisati": "travisare",
    "travisato": "travisare",
    "travisava": "travisare",
    "travisavamo": "travisare",
    "travisavan": "travisare",
    "travisavano": "travisare",
    "travisavate": "travisare",
    "travisavi": "travisare",
    "travisavo": "travisare",
    "traviserai": "travisare",
    "traviseran": "travisare",
    "traviseranno": "travisare",
    "traviserebbe": "travisare",
    "traviserebber": "travisare",
    "traviserebbero": "travisare",
    "traviserei": "travisare",
    "traviseremmo": "travisare",
    "traviseremo": "travisare",
    "travisereste": "travisare",
    "traviseresti": "travisare",
    "traviserete": "travisare",
    "traviserà": "travisare",
    "traviserò": "travisare",
    "travisi": "travisare",
    "travisiamo": "travisare",
    "travisiate": "travisare",
    "travisin": "travisare",
    "travisino": "travisare",
    "traviso": "travisare",
    "travisò": "travisare",
    "traviò": "traviare",
    "travolga": "travolgere",
    "travolgan": "travolgere",
    "travolgano": "travolgere",
    "travolge": "travolgere",
    "travolgemmo": "travolgere",
    "travolgendo": "travolgere",
    "travolgente": "travolgere",
    "travolgenti": "travolgere",
    "travolger": "travolgere",
    "travolgerai": "travolgere",
    "travolgeran": "travolgere",
    "travolgeranno": "travolgere",
    "travolgerebbe": "travolgere",
    "travolgerebber": "travolgere",
    "travolgerebbero": "travolgere",
    "travolgerei": "travolgere",
    "travolgeremmo": "travolgere",
    "travolgeremo": "travolgere",
    "travolgereste": "travolgere",
    "travolgeresti": "travolgere",
    "travolgerete": "travolgere",
    "travolgerà": "travolgere",
    "travolgerò": "travolgere",
    "travolgesse": "travolgere",
    "travolgesser": "travolgere",
    "travolgessero": "travolgere",
    "travolgessi": "travolgere",
    "travolgessimo": "travolgere",
    "travolgeste": "travolgere",
    "travolgesti": "travolgere",
    "travolgete": "travolgere",
    "travolgeva": "travolgere",
    "travolgevamo": "travolgere",
    "travolgevan": "travolgere",
    "travolgevano": "travolgere",
    "travolgevate": "travolgere",
    "travolgevi": "travolgere",
    "travolgevo": "travolgere",
    "travolgi": "travolgere",
    "travolgiamo": "travolgere",
    "travolgiate": "travolgere",
    "travolgo": "travolgere",
    "travolgon": "travolgere",
    "travolgono": "travolgere",
    "travolse": "travolgere",
    "travolser": "travolgere",
    "travolsero": "travolgere",
    "travolsi": "travolgere",
    "travolta": "travolgere",
    "travolte": "travolgere",
    "travolti": "travolgere",
    "travolto": "travolgere",
    "trazioni": "trazione",
    "trebbi": "trebbiare",
    "trebbia": "trebbiare",
    "trebbiai": "trebbiare",
    "trebbiammo": "trebbiare",
    "trebbiamo": "trebbiare",
    "trebbian": "trebbiare",
    "trebbiando": "trebbiare",
    "trebbiano": "trebbiare",
    "trebbiante": "trebbiare",
    "trebbianti": "trebbiare",
    "trebbiar": "trebbiare",
    "trebbiaron": "trebbiare",
    "trebbiarono": "trebbiare",
    "trebbiasse": "trebbiare",
    "trebbiasser": "trebbiare",
    "trebbiassero": "trebbiare",
    "trebbiassi": "trebbiare",
    "trebbiassimo": "trebbiare",
    "trebbiaste": "trebbiare",
    "trebbiasti": "trebbiare",
    "trebbiata": "trebbiare",
    "trebbiate": "trebbiare",
    "trebbiati": "trebbiare",
    "trebbiato": "trebbiare",
    "trebbiatrici": "trebbiatrice",
    "trebbiava": "trebbiare",
    "trebbiavamo": "trebbiare",
    "trebbiavan": "trebbiare",
    "trebbiavano": "trebbiare",
    "trebbiavate": "trebbiare",
    "trebbiavi": "trebbiare",
    "trebbiavo": "trebbiare",
    "trebbierai": "trebbiare",
    "trebbieran": "trebbiare",
    "trebbieranno": "trebbiare",
    "trebbierebbe": "trebbiare",
    "trebbierebber": "trebbiare",
    "trebbierebbero": "trebbiare",
    "trebbierei": "trebbiare",
    "trebbieremmo": "trebbiare",
    "trebbieremo": "trebbiare",
    "trebbiereste": "trebbiare",
    "trebbieresti": "trebbiare",
    "trebbierete": "trebbiare",
    "trebbierà": "trebbiare",
    "trebbierò": "trebbiare",
    "trebbin": "trebbiare",
    "trebbino": "trebbiare",
    "trebbio": "trebbiare",
    "trebbiò": "trebbiare",
    "trecce": "treccia",
    "trecentesca": "trecentesco",
    "trecentesche": "trecentesco",
    "trecenteschi": "trecentesco",
    "trecentesima": "trecentesimo",
    "trecentesime": "trecentesimo",
    "trecentesimi": "trecentesimo",
    "trecentocinquantesima": "trecentocinquantesimo",
    "trecentocinquantesime": "trecentocinquantesimo",
    "trecentocinquantesimi": "trecentocinquantesimo",
    "trecentodecima": "trecentodecimo",
    "trecentodecime": "trecentodecimo",
    "trecentodecimi": "trecentodecimo",
    "trecentonovantesima": "trecentonovantesimo",
    "trecentonovantesime": "trecentonovantesimo",
    "trecentonovantesimi": "trecentonovantesimo",
    "trecentoquarantesima": "trecentoquarantesimo",
    "trecentoquarantesime": "trecentoquarantesimo",
    "trecentoquarantesimi": "trecentoquarantesimo",
    "trecentosessantesima": "trecentosessantesimo",
    "trecentosessantesime": "trecentosessantesimo",
    "trecentosessantesimi": "trecentosessantesimo",
    "trecentosettantesima": "trecentosettantesimo",
    "trecentosettantesime": "trecentosettantesimo",
    "trecentosettantesimi": "trecentosettantesimo",
    "trecentotrentesima": "trecentotrentesimo",
    "trecentotrentesime": "trecentotrentesimo",
    "trecentotrentesimi": "trecentotrentesimo",
    "trecentottantesima": "trecentottantesimo",
    "trecentottantesime": "trecentottantesimo",
    "trecentottantesimi": "trecentottantesimo",
    "trecentoventesima": "trecentoventesimo",
    "trecentoventesime": "trecentoventesimo",
    "trecentoventesimi": "trecentoventesimo",
    "tredicenni": "tredicenne",
    "tredicesima": "tredicesimo",
    "tredicesime": "tredicesimo",
    "tredicesimi": "tredicesimo",
    "tregue": "tregua",
    "trema": "tremare",
    "tremai": "tremare",
    "tremammo": "tremare",
    "treman": "tremare",
    "tremando": "tremare",
    "tremano": "tremare",
    "tremante": "tremare",
    "tremanti": "tremare",
    "tremar": "tremare",
    "tremaron": "tremare",
    "tremarono": "tremare",
    "tremasse": "tremare",
    "tremasser": "tremare",
    "tremassero": "tremare",
    "tremassi": "tremare",
    "tremassimo": "tremare",
    "tremaste": "tremare",
    "tremasti": "tremare",
    "tremata": "tremare",
    "tremate": "tremare",
    "tremati": "tremare",
    "tremato": "tremare",
    "tremava": "tremare",
    "tremavamo": "tremare",
    "tremavan": "tremare",
    "tremavano": "tremare",
    "tremavate": "tremare",
    "tremavi": "tremare",
    "tremavo": "tremare",
    "tremebonda": "tremebondo",
    "tremebonde": "tremebondo",
    "tremebondi": "tremebondo",
    "tremenda": "tremendo",
    "tremende": "tremendo",
    "tremendi": "tremendo",
    "tremerai": "tremare",
    "tremeran": "tremare",
    "tremeranno": "tremare",
    "tremerebbe": "tremare",
    "tremerebber": "tremare",
    "tremerebbero": "tremare",
    "tremerei": "tremare",
    "tremeremmo": "tremare",
    "tremeremo": "tremare",
    "tremereste": "tremare",
    "tremeresti": "tremare",
    "tremerete": "tremare",
    "tremerà": "tremare",
    "tremerò": "tremare",
    "tremi": "tremare",
    "tremiamo": "tremare",
    "tremiate": "tremare",
    "tremillesima": "tremillesimo",
    "tremillesime": "tremillesimo",
    "tremillesimi": "tremillesimo",
    "tremin": "tremare",
    "tremino": "tremare",
    "tremiti": "tremito",
    "tremo": "tremare",
    "tremola": "tremolare",
    "tremolacchianti": "tremolacchiante",
    "tremolai": "tremolare",
    "tremolammo": "tremolare",
    "tremolan": "tremolare",
    "tremolando": "tremolare",
    "tremolano": "tremolare",
    "tremolante": "tremolare",
    "tremolanti": "tremolare",
    "tremolar": "tremolare",
    "tremolaron": "tremolare",
    "tremolarono": "tremolare",
    "tremolasse": "tremolare",
    "tremolasser": "tremolare",
    "tremolassero": "tremolare",
    "tremolassi": "tremolare",
    "tremolassimo": "tremolare",
    "tremolaste": "tremolare",
    "tremolasti": "tremolare",
    "tremolata": "tremolare",
    "tremolate": "tremolare",
    "tremolati": "tremolare",
    "tremolato": "tremolare",
    "tremolava": "tremolare",
    "tremolavamo": "tremolare",
    "tremolavan": "tremolare",
    "tremolavano": "tremolare",
    "tremolavate": "tremolare",
    "tremolavi": "tremolare",
    "tremolavo": "tremolare",
    "tremolerai": "tremolare",
    "tremoleran": "tremolare",
    "tremoleranno": "tremolare",
    "tremolerebbe": "tremolare",
    "tremolerebber": "tremolare",
    "tremolerebbero": "tremolare",
    "tremolerei": "tremolare",
    "tremoleremmo": "tremolare",
    "tremoleremo": "tremolare",
    "tremolereste": "tremolare",
    "tremoleresti": "tremolare",
    "tremolerete": "tremolare",
    "tremolerà": "tremolare",
    "tremolerò": "tremolare",
    "tremoli": "tremolare",
    "tremoliamo": "tremolare",
    "tremoliate": "tremolare",
    "tremolii": "tremolio",
    "tremolin": "tremolare",
    "tremolino": "tremolare",
    "tremolo": "tremolare",
    "tremolò": "tremolare",
    "tremori": "tremore",
    "tremula": "tremulo",
    "tremule": "tremulo",
    "tremuli": "tremulo",
    "tremò": "tremare",
    "treni": "treno",
    "trenini": "trenino",
    "trentacinquenni": "trentacinquenne",
    "trentacinquesima": "trentacinquesimo",
    "trentacinquesime": "trentacinquesimo",
    "trentacinquesimi": "trentacinquesimo",
    "trentaduesima": "trentaduesimo",
    "trentaduesime": "trentaduesimo",
    "trentaduesimi": "trentaduesimo",
    "trentanovesima": "trentanovesimo",
    "trentanovesime": "trentanovesimo",
    "trentanovesimi": "trentanovesimo",
    "trentaquattresima": "trentaquattresimo",
    "trentaquattresime": "trentaquattresimo",
    "trentaquattresimi": "trentaquattresimo",
    "trentaseiesima": "trentaseiesimo",
    "trentaseiesime": "trentaseiesimo",
    "trentaseiesimi": "trentaseiesimo",
    "trentasettesima": "trentasettesimo",
    "trentasettesime": "trentasettesimo",
    "trentasettesimi": "trentasettesimo",
    "trentatreesima": "trentatreesimo",
    "trentatreesime": "trentatreesimo",
    "trentatreesimi": "trentatreesimo",
    "trentennali": "trentennale",
    "trentenni": "trentenne",
    "trentennii": "trentennio",
    "trentesima": "trentesimo",
    "trentesime": "trentesimo",
    "trentesimi": "trentesimo",
    "trentina": "trentino",
    "trentine": "trentino",
    "trentini": "trentino",
    "trentottesima": "trentottesimo",
    "trentottesime": "trentottesimo",
    "trentottesimi": "trentottesimo",
    "trentunesima": "trentunesimo",
    "trentunesime": "trentunesimo",
    "trentunesimi": "trentunesimo",
    "trepida": "trepido",
    "trepidai": "trepidare",
    "trepidammo": "trepidare",
    "trepidan": "trepidare",
    "trepidando": "trepidare",
    "trepidano": "trepidare",
    "trepidante": "trepidare",
    "trepidanti": "trepidare",
    "trepidar": "trepidare",
    "trepidaron": "trepidare",
    "trepidarono": "trepidare",
    "trepidasse": "trepidare",
    "trepidasser": "trepidare",
    "trepidassero": "trepidare",
    "trepidassi": "trepidare",
    "trepidassimo": "trepidare",
    "trepidaste": "trepidare",
    "trepidasti": "trepidare",
    "trepidata": "trepidare",
    "trepidate": "trepidare",
    "trepidati": "trepidare",
    "trepidato": "trepidare",
    "trepidava": "trepidare",
    "trepidavamo": "trepidare",
    "trepidavan": "trepidare",
    "trepidavano": "trepidare",
    "trepidavate": "trepidare",
    "trepidavi": "trepidare",
    "trepidavo": "trepidare",
    "trepidazioni": "trepidazione",
    "trepide": "trepido",
    "trepiderai": "trepidare",
    "trepideran": "trepidare",
    "trepideranno": "trepidare",
    "trepiderebbe": "trepidare",
    "trepiderebber": "trepidare",
    "trepiderebbero": "trepidare",
    "trepiderei": "trepidare",
    "trepideremmo": "trepidare",
    "trepideremo": "trepidare",
    "trepidereste": "trepidare",
    "trepideresti": "trepidare",
    "trepiderete": "trepidare",
    "trepiderà": "trepidare",
    "trepiderò": "trepidare",
    "trepidi": "trepido",
    "trepidiamo": "trepidare",
    "trepidiate": "trepidare",
    "trepidin": "trepidare",
    "trepidino": "trepidare",
    "trepido": "trepidare",
    "trepidò": "trepidare",
    "treppiedi": "treppiede",
    "trequartisti": "trequartista",
    "tresca": "trescare",
    "trescai": "trescare",
    "trescammo": "trescare",
    "trescan": "trescare",
    "trescando": "trescare",
    "trescano": "trescare",
    "trescante": "trescare",
    "trescanti": "trescare",
    "trescar": "trescare",
    "trescaron": "trescare",
    "trescarono": "trescare",
    "trescasse": "trescare",
    "trescasser": "trescare",
    "trescassero": "trescare",
    "trescassi": "trescare",
    "trescassimo": "trescare",
    "trescaste": "trescare",
    "trescasti": "trescare",
    "trescata": "trescare",
    "trescate": "trescare",
    "trescati": "trescare",
    "trescato": "trescare",
    "trescava": "trescare",
    "trescavamo": "trescare",
    "trescavan": "trescare",
    "trescavano": "trescare",
    "trescavate": "trescare",
    "trescavi": "trescare",
    "trescavo": "trescare",
    "tresche": "tresca",
    "trescherai": "trescare",
    "trescheran": "trescare",
    "trescheranno": "trescare",
    "trescherebbe": "trescare",
    "trescherebber": "trescare",
    "trescherebbero": "trescare",
    "trescherei": "trescare",
    "trescheremmo": "trescare",
    "trescheremo": "trescare",
    "treschereste": "trescare",
    "trescheresti": "trescare",
    "trescherete": "trescare",
    "trescherà": "trescare",
    "trescherò": "trescare",
    "treschi": "trescare",
    "treschiamo": "trescare",
    "treschiate": "trescare",
    "treschin": "trescare",
    "treschino": "trescare",
    "tresco": "trescare",
    "trescò": "trescare",
    "trespoli": "trespolo",
    "trevigiani": "trevigiano",
    "triadi": "triade",
    "triangola": "triangolare",
    "triangolai": "triangolare",
    "triangolammo": "triangolare",
    "triangolan": "triangolare",
    "triangolando": "triangolare",
    "triangolano": "triangolare",
    "triangolante": "triangolare",
    "triangolanti": "triangolare",
    "triangolar": "triangolare",
    "triangolari": "triangolare",
    "triangolaron": "triangolare",
    "triangolarono": "triangolare",
    "triangolasse": "triangolare",
    "triangolasser": "triangolare",
    "triangolassero": "triangolare",
    "triangolassi": "triangolare",
    "triangolassimo": "triangolare",
    "triangolaste": "triangolare",
    "triangolasti": "triangolare",
    "triangolata": "triangolare",
    "triangolate": "triangolare",
    "triangolati": "triangolare",
    "triangolato": "triangolare",
    "triangolava": "triangolare",
    "triangolavamo": "triangolare",
    "triangolavan": "triangolare",
    "triangolavano": "triangolare",
    "triangolavate": "triangolare",
    "triangolavi": "triangolare",
    "triangolavo": "triangolare",
    "triangolazioni": "triangolazione",
    "triangolerai": "triangolare",
    "triangoleran": "triangolare",
    "triangoleranno": "triangolare",
    "triangolerebbe": "triangolare",
    "triangolerebber": "triangolare",
    "triangolerebbero": "triangolare",
    "triangolerei": "triangolare",
    "triangoleremmo": "triangolare",
    "triangoleremo": "triangolare",
    "triangolereste": "triangolare",
    "triangoleresti": "triangolare",
    "triangolerete": "triangolare",
    "triangolerà": "triangolare",
    "triangolerò": "triangolare",
    "triangoli": "triangolo",
    "triangoliamo": "triangolare",
    "triangoliate": "triangolare",
    "triangolin": "triangolare",
    "triangolino": "triangolare",
    "triangolo": "triangolare",
    "triangolò": "triangolare",
    "tribali": "tribale",
    "tribalismi": "tribalismo",
    "tribola": "tribolare",
    "tribolai": "tribolare",
    "tribolammo": "tribolare",
    "tribolan": "tribolare",
    "tribolando": "tribolare",
    "tribolano": "tribolare",
    "tribolante": "tribolare",
    "tribolanti": "tribolare",
    "tribolar": "tribolare",
    "tribolaron": "tribolare",
    "tribolarono": "tribolare",
    "tribolasse": "tribolare",
    "tribolasser": "tribolare",
    "tribolassero": "tribolare",
    "tribolassi": "tribolare",
    "tribolassimo": "tribolare",
    "tribolaste": "tribolare",
    "tribolasti": "tribolare",
    "tribolata": "tribolato",
    "tribolate": "tribolato",
    "tribolati": "tribolato",
    "tribolato": "tribolare",
    "tribolava": "tribolare",
    "tribolavamo": "tribolare",
    "tribolavan": "tribolare",
    "tribolavano": "tribolare",
    "tribolavate": "tribolare",
    "tribolavi": "tribolare",
    "tribolavo": "tribolare",
    "tribolazioni": "tribolazione",
    "tribolerai": "tribolare",
    "triboleran": "tribolare",
    "triboleranno": "tribolare",
    "tribolerebbe": "tribolare",
    "tribolerebber": "tribolare",
    "tribolerebbero": "tribolare",
    "tribolerei": "tribolare",
    "triboleremmo": "tribolare",
    "triboleremo": "tribolare",
    "tribolereste": "tribolare",
    "triboleresti": "tribolare",
    "tribolerete": "tribolare",
    "tribolerà": "tribolare",
    "tribolerò": "tribolare",
    "triboli": "tribolare",
    "triboliamo": "tribolare",
    "triboliate": "tribolare",
    "tribolin": "tribolare",
    "tribolino": "tribolare",
    "tribolo": "tribolare",
    "tribolò": "tribolare",
    "tribunali": "tribunale",
    "tribune": "tribuna",
    "tribunette": "tribunetta",
    "tribuni": "tribuno",
    "tributa": "tributare",
    "tributai": "tributare",
    "tributammo": "tributare",
    "tributan": "tributare",
    "tributando": "tributare",
    "tributano": "tributare",
    "tributante": "tributare",
    "tributanti": "tributare",
    "tributar": "tributare",
    "tributari": "tributario",
    "tributaria": "tributario",
    "tributarie": "tributario",
    "tributaristi": "tributarista",
    "tributaron": "tributare",
    "tributarono": "tributare",
    "tributasse": "tributare",
    "tributasser": "tributare",
    "tributassero": "tributare",
    "tributassi": "tributare",
    "tributassimo": "tributare",
    "tributaste": "tributare",
    "tributasti": "tributare",
    "tributata": "tributare",
    "tributate": "tributare",
    "tributati": "tributare",
    "tributato": "tributare",
    "tributava": "tributare",
    "tributavamo": "tributare",
    "tributavan": "tributare",
    "tributavano": "tributare",
    "tributavate": "tributare",
    "tributavi": "tributare",
    "tributavo": "tributare",
    "tributerai": "tributare",
    "tributeran": "tributare",
    "tributeranno": "tributare",
    "tributerebbe": "tributare",
    "tributerebber": "tributare",
    "tributerebbero": "tributare",
    "tributerei": "tributare",
    "tributeremmo": "tributare",
    "tributeremo": "tributare",
    "tributereste": "tributare",
    "tributeresti": "tributare",
    "tributerete": "tributare",
    "tributerà": "tributare",
    "tributerò": "tributare",
    "tributi": "tributo",
    "tributiamo": "tributare",
    "tributiate": "tributare",
    "tributin": "tributare",
    "tributino": "tributare",
    "tributo": "tributare",
    "tributò": "tributare",
    "trichechi": "tricheco",
    "tricicli": "triciclo",
    "tricolori": "tricolore",
    "tridenti": "tridente",
    "tridimensionali": "tridimensionale",
    "triennali": "triennale",
    "trienni": "triennio",
    "triestina": "triestino",
    "triestine": "triestino",
    "triestini": "triestino",
    "triglie": "triglia",
    "trii": "trio",
    "trilaterali": "trilaterale",
    "trilingui": "trilingue",
    "trilioni": "trilione",
    "trilla": "trillare",
    "trillai": "trillare",
    "trillammo": "trillare",
    "trillan": "trillare",
    "trillando": "trillare",
    "trillano": "trillare",
    "trillante": "trillare",
    "trillanti": "trillare",
    "trillar": "trillare",
    "trillaron": "trillare",
    "trillarono": "trillare",
    "trillasse": "trillare",
    "trillasser": "trillare",
    "trillassero": "trillare",
    "trillassi": "trillare",
    "trillassimo": "trillare",
    "trillaste": "trillare",
    "trillasti": "trillare",
    "trillata": "trillare",
    "trillate": "trillare",
    "trillati": "trillare",
    "trillato": "trillare",
    "trillava": "trillare",
    "trillavamo": "trillare",
    "trillavan": "trillare",
    "trillavano": "trillare",
    "trillavate": "trillare",
    "trillavi": "trillare",
    "trillavo": "trillare",
    "trillerai": "trillare",
    "trilleran": "trillare",
    "trilleranno": "trillare",
    "trillerebbe": "trillare",
    "trillerebber": "trillare",
    "trillerebbero": "trillare",
    "trillerei": "trillare",
    "trilleremmo": "trillare",
    "trilleremo": "trillare",
    "trillereste": "trillare",
    "trilleresti": "trillare",
    "trillerete": "trillare",
    "trillerà": "trillare",
    "trillerò": "trillare",
    "trilli": "trillo",
    "trilliamo": "trillare",
    "trilliate": "trillare",
    "trillin": "trillare",
    "trillino": "trillare",
    "trillo": "trillare",
    "trillò": "trillare",
    "trilogie": "trilogia",
    "trimestrali": "trimestrale",
    "trimestralizza": "trimestralizzare",
    "trimestralizzai": "trimestralizzare",
    "trimestralizzammo": "trimestralizzare",
    "trimestralizzan": "trimestralizzare",
    "trimestralizzando": "trimestralizzare",
    "trimestralizzano": "trimestralizzare",
    "trimestralizzante": "trimestralizzare",
    "trimestralizzanti": "trimestralizzare",
    "trimestralizzar": "trimestralizzare",
    "trimestralizzaron": "trimestralizzare",
    "trimestralizzarono": "trimestralizzare",
    "trimestralizzasse": "trimestralizzare",
    "trimestralizzasser": "trimestralizzare",
    "trimestralizzassero": "trimestralizzare",
    "trimestralizzassi": "trimestralizzare",
    "trimestralizzassimo": "trimestralizzare",
    "trimestralizzaste": "trimestralizzare",
    "trimestralizzasti": "trimestralizzare",
    "trimestralizzata": "trimestralizzare",
    "trimestralizzate": "trimestralizzare",
    "trimestralizzati": "trimestralizzare",
    "trimestralizzato": "trimestralizzare",
    "trimestralizzava": "trimestralizzare",
    "trimestralizzavamo": "trimestralizzare",
    "trimestralizzavan": "trimestralizzare",
    "trimestralizzavano": "trimestralizzare",
    "trimestralizzavate": "trimestralizzare",
    "trimestralizzavi": "trimestralizzare",
    "trimestralizzavo": "trimestralizzare",
    "trimestralizzerai": "trimestralizzare",
    "trimestralizzeran": "trimestralizzare",
    "trimestralizzeranno": "trimestralizzare",
    "trimestralizzerebbe": "trimestralizzare",
    "trimestralizzerebber": "trimestralizzare",
    "trimestralizzerebbero": "trimestralizzare",
    "trimestralizzerei": "trimestralizzare",
    "trimestralizzeremmo": "trimestralizzare",
    "trimestralizzeremo": "trimestralizzare",
    "trimestralizzereste": "trimestralizzare",
    "trimestralizzeresti": "trimestralizzare",
    "trimestralizzerete": "trimestralizzare",
    "trimestralizzerà": "trimestralizzare",
    "trimestralizzerò": "trimestralizzare",
    "trimestralizzi": "trimestralizzare",
    "trimestralizziamo": "trimestralizzare",
    "trimestralizziate": "trimestralizzare",
    "trimestralizzin": "trimestralizzare",
    "trimestralizzino": "trimestralizzare",
    "trimestralizzo": "trimestralizzare",
    "trimestralizzò": "trimestralizzare",
    "trimestri": "trimestre",
    "trina": "trino",
    "trinca": "trincare",
    "trincai": "trincare",
    "trincammo": "trincare",
    "trincan": "trincare",
    "trincando": "trincare",
    "trincano": "trincare",
    "trincante": "trincare",
    "trincanti": "trincare",
    "trincar": "trincare",
    "trincaron": "trincare",
    "trincarono": "trincare",
    "trincasse": "trincare",
    "trincasser": "trincare",
    "trincassero": "trincare",
    "trincassi": "trincare",
    "trincassimo": "trincare",
    "trincaste": "trincare",
    "trincasti": "trincare",
    "trincata": "trincare",
    "trincate": "trincare",
    "trincati": "trincare",
    "trincato": "trincare",
    "trincava": "trincare",
    "trincavamo": "trincare",
    "trincavan": "trincare",
    "trincavano": "trincare",
    "trincavate": "trincare",
    "trincavi": "trincare",
    "trincavo": "trincare",
    "trincee": "trincea",
    "trincera": "trincerare",
    "trincerai": "trinciare",
    "trincerammo": "trincerare",
    "trinceran": "trinciare",
    "trincerando": "trincerare",
    "trinceranno": "trinciare",
    "trincerano": "trincerare",
    "trincerante": "trincerare",
    "trinceranti": "trincerare",
    "trincerar": "trincerare",
    "trinceraron": "trincerare",
    "trincerarono": "trincerare",
    "trincerasse": "trincerare",
    "trincerasser": "trincerare",
    "trincerassero": "trincerare",
    "trincerassi": "trincerare",
    "trincerassimo": "trincerare",
    "trinceraste": "trincerare",
    "trincerasti": "trincerare",
    "trincerata": "trincerare",
    "trincerate": "trincerare",
    "trincerati": "trincerare",
    "trincerato": "trincerare",
    "trincerava": "trincerare",
    "trinceravamo": "trincerare",
    "trinceravan": "trincerare",
    "trinceravano": "trincerare",
    "trinceravate": "trincerare",
    "trinceravi": "trincerare",
    "trinceravo": "trincerare",
    "trincerebbe": "trinciare",
    "trincerebber": "trinciare",
    "trincerebbero": "trinciare",
    "trincerei": "trinciare",
    "trinceremmo": "trinciare",
    "trinceremo": "trinciare",
    "trincererai": "trincerare",
    "trincereran": "trincerare",
    "trincereranno": "trincerare",
    "trincererebbe": "trincerare",
    "trincererebber": "trincerare",
    "trincererebbero": "trincerare",
    "trincererei": "trincerare",
    "trincereremmo": "trincerare",
    "trincereremo": "trincerare",
    "trincerereste": "trincerare",
    "trincereresti": "trincerare",
    "trincererete": "trincerare",
    "trincererà": "trincerare",
    "trincererò": "trincerare",
    "trincereste": "trinciare",
    "trinceresti": "trinciare",
    "trincerete": "trinciare",
    "trinceri": "trincerare",
    "trinceriamo": "trincerare",
    "trinceriate": "trincerare",
    "trincerin": "trincerare",
    "trincerino": "trincerare",
    "trincero": "trincerare",
    "trincerà": "trinciare",
    "trincerò": "trinciare",
    "trincherai": "trincare",
    "trincheran": "trincare",
    "trincheranno": "trincare",
    "trincherebbe": "trincare",
    "trincherebber": "trincare",
    "trincherebbero": "trincare",
    "trincherei": "trincare",
    "trincheremmo": "trincare",
    "trincheremo": "trincare",
    "trinchereste": "trincare",
    "trincheresti": "trincare",
    "trincherete": "trincare",
    "trincherà": "trincare",
    "trincherò": "trincare",
    "trinchi": "trincare",
    "trinchiamo": "trincare",
    "trinchiate": "trincare",
    "trinchin": "trincare",
    "trinchino": "trincare",
    "trinci": "trinciare",
    "trincia": "trinciare",
    "trinciai": "trinciare",
    "trinciammo": "trinciare",
    "trinciamo": "trinciare",
    "trincian": "trinciare",
    "trinciando": "trinciare",
    "trinciano": "trinciare",
    "trinciante": "trinciare",
    "trincianti": "trinciare",
    "trinciar": "trinciare",
    "trinciaron": "trinciare",
    "trinciarono": "trinciare",
    "trinciasse": "trinciare",
    "trinciasser": "trinciare",
    "trinciassero": "trinciare",
    "trinciassi": "trinciare",
    "trinciassimo": "trinciare",
    "trinciaste": "trinciare",
    "trinciasti": "trinciare",
    "trinciata": "trinciare",
    "trinciate": "trinciare",
    "trinciati": "trinciare",
    "trinciato": "trinciare",
    "trinciava": "trinciare",
    "trinciavamo": "trinciare",
    "trinciavan": "trinciare",
    "trinciavano": "trinciare",
    "trinciavate": "trinciare",
    "trinciavi": "trinciare",
    "trinciavo": "trinciare",
    "trincin": "trinciare",
    "trincino": "trinciare",
    "trincio": "trinciare",
    "trinciò": "trinciare",
    "trinco": "trincare",
    "trincò": "trincare",
    "trine": "trino",
    "trini": "trino",
    "trionfa": "trionfare",
    "trionfai": "trionfare",
    "trionfali": "trionfale",
    "trionfalismi": "trionfalismo",
    "trionfalistica": "trionfalistico",
    "trionfalistiche": "trionfalistico",
    "trionfalistici": "trionfalistico",
    "trionfammo": "trionfare",
    "trionfan": "trionfare",
    "trionfando": "trionfare",
    "trionfano": "trionfare",
    "trionfante": "trionfare",
    "trionfanti": "trionfare",
    "trionfar": "trionfare",
    "trionfaron": "trionfare",
    "trionfarono": "trionfare",
    "trionfasse": "trionfare",
    "trionfasser": "trionfare",
    "trionfassero": "trionfare",
    "trionfassi": "trionfare",
    "trionfassimo": "trionfare",
    "trionfaste": "trionfare",
    "trionfasti": "trionfare",
    "trionfata": "trionfare",
    "trionfate": "trionfare",
    "trionfati": "trionfare",
    "trionfato": "trionfare",
    "trionfatori": "trionfatore",
    "trionfava": "trionfare",
    "trionfavamo": "trionfare",
    "trionfavan": "trionfare",
    "trionfavano": "trionfare",
    "trionfavate": "trionfare",
    "trionfavi": "trionfare",
    "trionfavo": "trionfare",
    "trionferai": "trionfare",
    "trionferan": "trionfare",
    "trionferanno": "trionfare",
    "trionferebbe": "trionfare",
    "trionferebber": "trionfare",
    "trionferebbero": "trionfare",
    "trionferei": "trionfare",
    "trionferemmo": "trionfare",
    "trionferemo": "trionfare",
    "trionfereste": "trionfare",
    "trionferesti": "trionfare",
    "trionferete": "trionfare",
    "trionferà": "trionfare",
    "trionferò": "trionfare",
    "trionfi": "trionfo",
    "trionfiamo": "trionfare",
    "trionfiate": "trionfare",
    "trionfin": "trionfare",
    "trionfino": "trionfare",
    "trionfo": "trionfare",
    "trionfò": "trionfare",
    "triparta": "tripartire",
    "tripartan": "tripartire",
    "tripartano": "tripartire",
    "triparte": "tripartire",
    "tripartendo": "tripartire",
    "tripartente": "tripartire",
    "tripartenti": "tripartire",
    "triparti": "tripartire",
    "tripartiamo": "tripartire",
    "tripartiate": "tripartire",
    "tripartii": "tripartire",
    "tripartimmo": "tripartire",
    "tripartir": "tripartire",
    "tripartirai": "tripartire",
    "tripartiran": "tripartire",
    "tripartiranno": "tripartire",
    "tripartirebbe": "tripartire",
    "tripartirebber": "tripartire",
    "tripartirebbero": "tripartire",
    "tripartirei": "tripartire",
    "tripartiremmo": "tripartire",
    "tripartiremo": "tripartire",
    "tripartireste": "tripartire",
    "tripartiresti": "tripartire",
    "tripartirete": "tripartire",
    "tripartiron": "tripartire",
    "tripartirono": "tripartire",
    "tripartirà": "tripartire",
    "tripartirò": "tripartire",
    "tripartisse": "tripartire",
    "tripartisser": "tripartire",
    "tripartissero": "tripartire",
    "tripartissi": "tripartire",
    "tripartissimo": "tripartire",
    "tripartiste": "tripartire",
    "tripartisti": "tripartire",
    "tripartita": "tripartito",
    "tripartite": "tripartito",
    "tripartiti": "tripartito",
    "tripartito": "tripartire",
    "tripartiva": "tripartire",
    "tripartivamo": "tripartire",
    "tripartivan": "tripartire",
    "tripartivano": "tripartire",
    "tripartivate": "tripartire",
    "tripartivi": "tripartire",
    "tripartivo": "tripartire",
    "tripartizioni": "tripartizione",
    "triparto": "tripartire",
    "triparton": "tripartire",
    "tripartono": "tripartire",
    "tripartì": "tripartire",
    "tripla": "triplo",
    "triple": "triplo",
    "triplette": "tripletta",
    "tripli": "triplo",
    "triplica": "triplicare",
    "triplicai": "triplicare",
    "triplicammo": "triplicare",
    "triplican": "triplicare",
    "triplicando": "triplicare",
    "triplicano": "triplicare",
    "triplicante": "triplicare",
    "triplicanti": "triplicare",
    "triplicar": "triplicare",
    "triplicaron": "triplicare",
    "triplicarono": "triplicare",
    "triplicasse": "triplicare",
    "triplicasser": "triplicare",
    "triplicassero": "triplicare",
    "triplicassi": "triplicare",
    "triplicassimo": "triplicare",
    "triplicaste": "triplicare",
    "triplicasti": "triplicare",
    "triplicata": "triplicare",
    "triplicate": "triplicare",
    "triplicati": "triplicare",
    "triplicato": "triplicare",
    "triplicava": "triplicare",
    "triplicavamo": "triplicare",
    "triplicavan": "triplicare",
    "triplicavano": "triplicare",
    "triplicavate": "triplicare",
    "triplicavi": "triplicare",
    "triplicavo": "triplicare",
    "triplicherai": "triplicare",
    "triplicheran": "triplicare",
    "triplicheranno": "triplicare",
    "triplicherebbe": "triplicare",
    "triplicherebber": "triplicare",
    "triplicherebbero": "triplicare",
    "triplicherei": "triplicare",
    "triplicheremmo": "triplicare",
    "triplicheremo": "triplicare",
    "triplichereste": "triplicare",
    "triplicheresti": "triplicare",
    "triplicherete": "triplicare",
    "triplicherà": "triplicare",
    "triplicherò": "triplicare",
    "triplichi": "triplicare",
    "triplichiamo": "triplicare",
    "triplichiate": "triplicare",
    "triplichin": "triplicare",
    "triplichino": "triplicare",
    "triplici": "triplice",
    "triplico": "triplicare",
    "triplicò": "triplicare",
    "tripodi": "tripode",
    "tripola": "tripolare",
    "tripolai": "tripolare",
    "tripolammo": "tripolare",
    "tripolan": "tripolare",
    "tripolando": "tripolare",
    "tripolano": "tripolare",
    "tripolante": "tripolare",
    "tripolanti": "tripolare",
    "tripolar": "tripolare",
    "tripolaron": "tripolare",
    "tripolarono": "tripolare",
    "tripolasse": "tripolare",
    "tripolasser": "tripolare",
    "tripolassero": "tripolare",
    "tripolassi": "tripolare",
    "tripolassimo": "tripolare",
    "tripolaste": "tripolare",
    "tripolasti": "tripolare",
    "tripolata": "tripolare",
    "tripolate": "tripolare",
    "tripolati": "tripolare",
    "tripolato": "tripolare",
    "tripolava": "tripolare",
    "tripolavamo": "tripolare",
    "tripolavan": "tripolare",
    "tripolavano": "tripolare",
    "tripolavate": "tripolare",
    "tripolavi": "tripolare",
    "tripolavo": "tripolare",
    "tripolerai": "tripolare",
    "tripoleran": "tripolare",
    "tripoleranno": "tripolare",
    "tripolerebbe": "tripolare",
    "tripolerebber": "tripolare",
    "tripolerebbero": "tripolare",
    "tripolerei": "tripolare",
    "tripoleremmo": "tripolare",
    "tripoleremo": "tripolare",
    "tripolereste": "tripolare",
    "tripoleresti": "tripolare",
    "tripolerete": "tripolare",
    "tripolerà": "tripolare",
    "tripolerò": "tripolare",
    "tripoli": "tripolare",
    "tripoliamo": "tripolare",
    "tripoliate": "tripolare",
    "tripolin": "tripolare",
    "tripolina": "tripolino",
    "tripoline": "tripolino",
    "tripolini": "tripolino",
    "tripolino": "tripolare",
    "tripolo": "tripolare",
    "tripolò": "tripolare",
    "trippe": "trippa",
    "tripudi": "tripudio",
    "tripudia": "tripudiare",
    "tripudiai": "tripudiare",
    "tripudiammo": "tripudiare",
    "tripudiamo": "tripudiare",
    "tripudian": "tripudiare",
    "tripudiando": "tripudiare",
    "tripudiano": "tripudiare",
    "tripudiante": "tripudiare",
    "tripudianti": "tripudiare",
    "tripudiar": "tripudiare",
    "tripudiaron": "tripudiare",
    "tripudiarono": "tripudiare",
    "tripudiasse": "tripudiare",
    "tripudiasser": "tripudiare",
    "tripudiassero": "tripudiare",
    "tripudiassi": "tripudiare",
    "tripudiassimo": "tripudiare",
    "tripudiaste": "tripudiare",
    "tripudiasti": "tripudiare",
    "tripudiata": "tripudiare",
    "tripudiate": "tripudiare",
    "tripudiati": "tripudiare",
    "tripudiato": "tripudiare",
    "tripudiava": "tripudiare",
    "tripudiavamo": "tripudiare",
    "tripudiavan": "tripudiare",
    "tripudiavano": "tripudiare",
    "tripudiavate": "tripudiare",
    "tripudiavi": "tripudiare",
    "tripudiavo": "tripudiare",
    "tripudierai": "tripudiare",
    "tripudieran": "tripudiare",
    "tripudieranno": "tripudiare",
    "tripudierebbe": "tripudiare",
    "tripudierebber": "tripudiare",
    "tripudierebbero": "tripudiare",
    "tripudierei": "tripudiare",
    "tripudieremmo": "tripudiare",
    "tripudieremo": "tripudiare",
    "tripudiereste": "tripudiare",
    "tripudieresti": "tripudiare",
    "tripudierete": "tripudiare",
    "tripudierà": "tripudiare",
    "tripudierò": "tripudiare",
    "tripudin": "tripudiare",
    "tripudino": "tripudiare",
    "tripudio": "tripudiare",
    "tripudiò": "tripudiare",
    "trista": "tristo",
    "triste": "tristo",
    "tristezze": "tristezza",
    "tristi": "tristo",
    "trita": "trito",
    "tritai": "tritare",
    "tritammo": "tritare",
    "tritan": "tritare",
    "tritando": "tritare",
    "tritano": "tritare",
    "tritante": "tritare",
    "tritanti": "tritare",
    "tritar": "tritare",
    "tritaron": "tritare",
    "tritarono": "tritare",
    "tritasse": "tritare",
    "tritasser": "tritare",
    "tritassero": "tritare",
    "tritassi": "tritare",
    "tritassimo": "tritare",
    "tritaste": "tritare",
    "tritasti": "tritare",
    "tritata": "tritare",
    "tritate": "tritare",
    "tritati": "tritare",
    "tritato": "tritare",
    "tritava": "tritare",
    "tritavamo": "tritare",
    "tritavan": "tritare",
    "tritavano": "tritare",
    "tritavate": "tritare",
    "tritavi": "tritare",
    "tritavo": "tritare",
    "trite": "trito",
    "triterai": "tritare",
    "triteran": "tritare",
    "triteranno": "tritare",
    "triterebbe": "tritare",
    "triterebber": "tritare",
    "triterebbero": "tritare",
    "triterei": "tritare",
    "triteremmo": "tritare",
    "triteremo": "tritare",
    "tritereste": "tritare",
    "triteresti": "tritare",
    "triterete": "tritare",
    "triterà": "tritare",
    "triterò": "tritare",
    "triti": "trito",
    "tritiamo": "tritare",
    "tritiate": "tritare",
    "tritin": "tritare",
    "tritino": "tritare",
    "trito": "tritare",
    "tritoli": "tritolo",
    "tritoni": "tritone",
    "tritura": "triturare",
    "triturai": "triturare",
    "triturammo": "triturare",
    "trituran": "triturare",
    "triturando": "triturare",
    "triturano": "triturare",
    "triturante": "triturare",
    "trituranti": "triturare",
    "triturar": "triturare",
    "trituraron": "triturare",
    "triturarono": "triturare",
    "triturasse": "triturare",
    "triturasser": "triturare",
    "triturassero": "triturare",
    "triturassi": "triturare",
    "triturassimo": "triturare",
    "trituraste": "triturare",
    "triturasti": "triturare",
    "triturata": "triturare",
    "triturate": "triturare",
    "triturati": "triturare",
    "triturato": "triturare",
    "triturava": "triturare",
    "trituravamo": "triturare",
    "trituravan": "triturare",
    "trituravano": "triturare",
    "trituravate": "triturare",
    "trituravi": "triturare",
    "trituravo": "triturare",
    "triturerai": "triturare",
    "tritureran": "triturare",
    "tritureranno": "triturare",
    "triturerebbe": "triturare",
    "triturerebber": "triturare",
    "triturerebbero": "triturare",
    "triturerei": "triturare",
    "tritureremmo": "triturare",
    "tritureremo": "triturare",
    "triturereste": "triturare",
    "tritureresti": "triturare",
    "triturerete": "triturare",
    "triturerà": "triturare",
    "triturerò": "triturare",
    "trituri": "triturare",
    "trituriamo": "triturare",
    "trituriate": "triturare",
    "triturin": "triturare",
    "triturino": "triturare",
    "trituro": "triturare",
    "triturò": "triturare",
    "tritò": "tritare",
    "triumvirati": "triumvirato",
    "triumviri": "triumviro",
    "trivalenti": "trivalente",
    "trivella": "trivellare",
    "trivellai": "trivellare",
    "trivellammo": "trivellare",
    "trivellan": "trivellare",
    "trivellando": "trivellare",
    "trivellano": "trivellare",
    "trivellante": "trivellare",
    "trivellanti": "trivellare",
    "trivellar": "trivellare",
    "trivellaron": "trivellare",
    "trivellarono": "trivellare",
    "trivellasse": "trivellare",
    "trivellasser": "trivellare",
    "trivellassero": "trivellare",
    "trivellassi": "trivellare",
    "trivellassimo": "trivellare",
    "trivellaste": "trivellare",
    "trivellasti": "trivellare",
    "trivellata": "trivellare",
    "trivellate": "trivellare",
    "trivellati": "trivellare",
    "trivellato": "trivellare",
    "trivellava": "trivellare",
    "trivellavamo": "trivellare",
    "trivellavan": "trivellare",
    "trivellavano": "trivellare",
    "trivellavate": "trivellare",
    "trivellavi": "trivellare",
    "trivellavo": "trivellare",
    "trivellazioni": "trivellazione",
    "trivelle": "trivella",
    "trivellerai": "trivellare",
    "trivelleran": "trivellare",
    "trivelleranno": "trivellare",
    "trivellerebbe": "trivellare",
    "trivellerebber": "trivellare",
    "trivellerebbero": "trivellare",
    "trivellerei": "trivellare",
    "trivelleremmo": "trivellare",
    "trivelleremo": "trivellare",
    "trivellereste": "trivellare",
    "trivelleresti": "trivellare",
    "trivellerete": "trivellare",
    "trivellerà": "trivellare",
    "trivellerò": "trivellare",
    "trivelli": "trivellare",
    "trivelliamo": "trivellare",
    "trivelliate": "trivellare",
    "trivellin": "trivellare",
    "trivellino": "trivellare",
    "trivello": "trivellare",
    "trivellò": "trivellare",
    "triveneta": "triveneto",
    "trivenete": "triveneto",
    "triveneti": "triveneto",
    "triviali": "triviale",
    "trofei": "trofeo",
    "troike": "troika",
    "trojke": "trojka",
    "tromba": "trombare",
    "trombai": "trombare",
    "trombammo": "trombare",
    "tromban": "trombare",
    "trombando": "trombare",
    "trombano": "trombare",
    "trombante": "trombare",
    "trombanti": "trombare",
    "trombar": "trombare",
    "trombaron": "trombare",
    "trombarono": "trombare",
    "trombasse": "trombare",
    "trombasser": "trombare",
    "trombassero": "trombare",
    "trombassi": "trombare",
    "trombassimo": "trombare",
    "trombaste": "trombare",
    "trombasti": "trombare",
    "trombata": "trombare",
    "trombate": "trombare",
    "trombati": "trombato",
    "trombato": "trombare",
    "trombava": "trombare",
    "trombavamo": "trombare",
    "trombavan": "trombare",
    "trombavano": "trombare",
    "trombavate": "trombare",
    "trombavi": "trombare",
    "trombavo": "trombare",
    "trombe": "tromba",
    "tromberai": "trombare",
    "tromberan": "trombare",
    "tromberanno": "trombare",
    "tromberebbe": "trombare",
    "tromberebber": "trombare",
    "tromberebbero": "trombare",
    "tromberei": "trombare",
    "tromberemmo": "trombare",
    "tromberemo": "trombare",
    "trombereste": "trombare",
    "tromberesti": "trombare",
    "tromberete": "trombare",
    "tromberà": "trombare",
    "tromberò": "trombare",
    "trombette": "trombetta",
    "trombettieri": "trombettiere",
    "trombettisti": "trombettista",
    "trombi": "trombare",
    "trombiamo": "trombare",
    "trombiate": "trombare",
    "trombin": "trombare",
    "trombino": "trombare",
    "trombo": "trombare",
    "tromboni": "trombone",
    "trombò": "trombare",
    "tronca": "tronco",
    "troncai": "troncare",
    "troncammo": "troncare",
    "troncan": "troncare",
    "troncando": "troncare",
    "troncano": "troncare",
    "troncante": "troncare",
    "troncanti": "troncare",
    "troncar": "troncare",
    "troncaron": "troncare",
    "troncarono": "troncare",
    "troncasse": "troncare",
    "troncasser": "troncare",
    "troncassero": "troncare",
    "troncassi": "troncare",
    "troncassimo": "troncare",
    "troncaste": "troncare",
    "troncasti": "troncare",
    "troncata": "troncato",
    "troncate": "troncato",
    "troncati": "troncato",
    "troncato": "troncare",
    "troncava": "troncare",
    "troncavamo": "troncare",
    "troncavan": "troncare",
    "troncavano": "troncare",
    "troncavate": "troncare",
    "troncavi": "troncare",
    "troncavo": "troncare",
    "tronche": "tronco",
    "troncherai": "troncare",
    "troncheran": "troncare",
    "troncheranno": "troncare",
    "troncherebbe": "troncare",
    "troncherebber": "troncare",
    "troncherebbero": "troncare",
    "troncherei": "troncare",
    "troncheremmo": "troncare",
    "troncheremo": "troncare",
    "tronchereste": "troncare",
    "troncheresti": "troncare",
    "troncherete": "troncare",
    "troncherà": "troncare",
    "troncherò": "troncare",
    "tronchi": "tronco",
    "tronchiamo": "troncare",
    "tronchiate": "troncare",
    "tronchin": "troncare",
    "tronchino": "troncare",
    "tronco": "troncare",
    "tronconi": "troncone",
    "troncò": "troncare",
    "troneggerai": "troneggiare",
    "troneggeran": "troneggiare",
    "troneggeranno": "troneggiare",
    "troneggerebbe": "troneggiare",
    "troneggerebber": "troneggiare",
    "troneggerebbero": "troneggiare",
    "troneggerei": "troneggiare",
    "troneggeremmo": "troneggiare",
    "troneggeremo": "troneggiare",
    "troneggereste": "troneggiare",
    "troneggeresti": "troneggiare",
    "troneggerete": "troneggiare",
    "troneggerà": "troneggiare",
    "troneggerò": "troneggiare",
    "troneggi": "troneggiare",
    "troneggia": "troneggiare",
    "troneggiai": "troneggiare",
    "troneggiammo": "troneggiare",
    "troneggiamo": "troneggiare",
    "troneggian": "troneggiare",
    "troneggiando": "troneggiare",
    "troneggiano": "troneggiare",
    "troneggiante": "troneggiare",
    "troneggianti": "troneggiare",
    "troneggiar": "troneggiare",
    "troneggiaron": "troneggiare",
    "troneggiarono": "troneggiare",
    "troneggiasse": "troneggiare",
    "troneggiasser": "troneggiare",
    "troneggiassero": "troneggiare",
    "troneggiassi": "troneggiare",
    "troneggiassimo": "troneggiare",
    "troneggiaste": "troneggiare",
    "troneggiasti": "troneggiare",
    "troneggiata": "troneggiare",
    "troneggiate": "troneggiare",
    "troneggiati": "troneggiare",
    "troneggiato": "troneggiare",
    "troneggiava": "troneggiare",
    "troneggiavamo": "troneggiare",
    "troneggiavan": "troneggiare",
    "troneggiavano": "troneggiare",
    "troneggiavate": "troneggiare",
    "troneggiavi": "troneggiare",
    "troneggiavo": "troneggiare",
    "troneggin": "troneggiare",
    "troneggino": "troneggiare",
    "troneggio": "troneggiare",
    "troneggiò": "troneggiare",
    "tronfi": "tronfio",
    "tronfia": "tronfio",
    "tronfie": "tronfio",
    "troni": "trono",
    "tropicali": "tropicale",
    "tropici": "tropico",
    "troppa": "troppo",
    "troppe": "troppo",
    "troppi": "troppo",
    "trote": "trota",
    "trotta": "trottare",
    "trottai": "trottare",
    "trottammo": "trottare",
    "trottan": "trottare",
    "trottando": "trottare",
    "trottano": "trottare",
    "trottante": "trottare",
    "trottanti": "trottare",
    "trottar": "trottare",
    "trottaron": "trottare",
    "trottarono": "trottare",
    "trottasse": "trottare",
    "trottasser": "trottare",
    "trottassero": "trottare",
    "trottassi": "trottare",
    "trottassimo": "trottare",
    "trottaste": "trottare",
    "trottasti": "trottare",
    "trottata": "trottare",
    "trottate": "trottare",
    "trottati": "trottare",
    "trottato": "trottare",
    "trottatori": "trottatore",
    "trottava": "trottare",
    "trottavamo": "trottare",
    "trottavan": "trottare",
    "trottavano": "trottare",
    "trottavate": "trottare",
    "trottavi": "trottare",
    "trottavo": "trottare",
    "trotterai": "trottare",
    "trotteran": "trottare",
    "trotteranno": "trottare",
    "trotterebbe": "trottare",
    "trotterebber": "trottare",
    "trotterebbero": "trottare",
    "trotterei": "trottare",
    "trotterella": "trotterellare",
    "trotterellai": "trotterellare",
    "trotterellammo": "trotterellare",
    "trotterellan": "trotterellare",
    "trotterellando": "trotterellare",
    "trotterellano": "trotterellare",
    "trotterellante": "trotterellare",
    "trotterellanti": "trotterellare",
    "trotterellar": "trotterellare",
    "trotterellaron": "trotterellare",
    "trotterellarono": "trotterellare",
    "trotterellasse": "trotterellare",
    "trotterellasser": "trotterellare",
    "trotterellassero": "trotterellare",
    "trotterellassi": "trotterellare",
    "trotterellassimo": "trotterellare",
    "trotterellaste": "trotterellare",
    "trotterellasti": "trotterellare",
    "trotterellata": "trotterellare",
    "trotterellate": "trotterellare",
    "trotterellati": "trotterellare",
    "trotterellato": "trotterellare",
    "trotterellava": "trotterellare",
    "trotterellavamo": "trotterellare",
    "trotterellavan": "trotterellare",
    "trotterellavano": "trotterellare",
    "trotterellavate": "trotterellare",
    "trotterellavi": "trotterellare",
    "trotterellavo": "trotterellare",
    "trotterellerai": "trotterellare",
    "trotterelleran": "trotterellare",
    "trotterelleranno": "trotterellare",
    "trotterellerebbe": "trotterellare",
    "trotterellerebber": "trotterellare",
    "trotterellerebbero": "trotterellare",
    "trotterellerei": "trotterellare",
    "trotterelleremmo": "trotterellare",
    "trotterelleremo": "trotterellare",
    "trotterellereste": "trotterellare",
    "trotterelleresti": "trotterellare",
    "trotterellerete": "trotterellare",
    "trotterellerà": "trotterellare",
    "trotterellerò": "trotterellare",
    "trotterelli": "trotterellare",
    "trotterelliamo": "trotterellare",
    "trotterelliate": "trotterellare",
    "trotterellin": "trotterellare",
    "trotterellino": "trotterellare",
    "trotterello": "trotterellare",
    "trotterellò": "trotterellare",
    "trotteremmo": "trottare",
    "trotteremo": "trottare",
    "trottereste": "trottare",
    "trotteresti": "trottare",
    "trotterete": "trottare",
    "trotterà": "trottare",
    "trotterò": "trottare",
    "trotti": "trotto",
    "trottiamo": "trottare",
    "trottiate": "trottare",
    "trottin": "trottare",
    "trottino": "trottare",
    "trotto": "trottare",
    "trottole": "trottola",
    "trottò": "trottare",
    "trotzkiste": "trotzkista",
    "trotzkisti": "trotzkista",
    "troupes": "troupe",
    "trova": "trovare",
    "trovai": "trovare",
    "trovammo": "trovare",
    "trovan": "trovare",
    "trovando": "trovare",
    "trovano": "trovare",
    "trovante": "trovare",
    "trovanti": "trovare",
    "trovar": "trovare",
    "trovarobati": "trovarobato",
    "trovaron": "trovare",
    "trovarono": "trovare",
    "trovasse": "trovare",
    "trovasser": "trovare",
    "trovassero": "trovare",
    "trovassi": "trovare",
    "trovassimo": "trovare",
    "trovaste": "trovare",
    "trovasti": "trovare",
    "trovata": "trovare",
    "trovate": "trovare",
    "trovatelli": "trovatello",
    "trovati": "trovare",
    "trovatine": "trovatina",
    "trovato": "trovare",
    "trovatori": "trovatore",
    "trovava": "trovare",
    "trovavamo": "trovare",
    "trovavan": "trovare",
    "trovavano": "trovare",
    "trovavate": "trovare",
    "trovavi": "trovare",
    "trovavo": "trovare",
    "troverai": "trovare",
    "troveran": "trovare",
    "troveranno": "trovare",
    "troverebbe": "trovare",
    "troverebber": "trovare",
    "troverebbero": "trovare",
    "troverei": "trovare",
    "troveremmo": "trovare",
    "troveremo": "trovare",
    "trovereste": "trovare",
    "troveresti": "trovare",
    "troverete": "trovare",
    "troverà": "trovare",
    "troverò": "trovare",
    "trovi": "trovare",
    "troviamo": "trovare",
    "troviate": "trovare",
    "trovin": "trovare",
    "trovino": "trovare",
    "trovo": "trovare",
    "trovò": "trovare",
    "trozkisti": "trozkista",
    "trucca": "truccare",
    "truccai": "truccare",
    "truccammo": "truccare",
    "truccan": "truccare",
    "truccando": "truccare",
    "truccano": "truccare",
    "truccante": "truccare",
    "truccanti": "truccare",
    "truccar": "truccare",
    "truccaron": "truccare",
    "truccarono": "truccare",
    "truccasse": "truccare",
    "truccasser": "truccare",
    "truccassero": "truccare",
    "truccassi": "truccare",
    "truccassimo": "truccare",
    "truccaste": "truccare",
    "truccasti": "truccare",
    "truccata": "truccare",
    "truccate": "truccare",
    "truccati": "truccare",
    "truccato": "truccare",
    "truccatori": "truccatore",
    "truccature": "truccatura",
    "truccava": "truccare",
    "truccavamo": "truccare",
    "truccavan": "truccare",
    "truccavano": "truccare",
    "truccavate": "truccare",
    "truccavi": "truccare",
    "truccavo": "truccare",
    "truccherai": "truccare",
    "truccheran": "truccare",
    "truccheranno": "truccare",
    "truccherebbe": "truccare",
    "truccherebber": "truccare",
    "truccherebbero": "truccare",
    "truccherei": "truccare",
    "truccheremmo": "truccare",
    "truccheremo": "truccare",
    "trucchereste": "truccare",
    "truccheresti": "truccare",
    "truccherete": "truccare",
    "truccherà": "truccare",
    "truccherò": "truccare",
    "trucchetti": "trucchetto",
    "trucchi": "trucco",
    "trucchiamo": "truccare",
    "trucchiate": "truccare",
    "trucchin": "truccare",
    "trucchino": "truccare",
    "trucco": "truccare",
    "truccò": "truccare",
    "truci": "truce",
    "trucida": "trucidare",
    "trucidai": "trucidare",
    "trucidammo": "trucidare",
    "trucidan": "trucidare",
    "trucidando": "trucidare",
    "trucidano": "trucidare",
    "trucidante": "trucidare",
    "trucidanti": "trucidare",
    "trucidar": "trucidare",
    "trucidaron": "trucidare",
    "trucidarono": "trucidare",
    "trucidasse": "trucidare",
    "trucidasser": "trucidare",
    "trucidassero": "trucidare",
    "trucidassi": "trucidare",
    "trucidassimo": "trucidare",
    "trucidaste": "trucidare",
    "trucidasti": "trucidare",
    "trucidata": "trucidare",
    "trucidate": "trucidare",
    "trucidati": "trucidare",
    "trucidato": "trucidare",
    "trucidava": "trucidare",
    "trucidavamo": "trucidare",
    "trucidavan": "trucidare",
    "trucidavano": "trucidare",
    "trucidavate": "trucidare",
    "trucidavi": "trucidare",
    "trucidavo": "trucidare",
    "truciderai": "trucidare",
    "trucideran": "trucidare",
    "trucideranno": "trucidare",
    "truciderebbe": "trucidare",
    "truciderebber": "trucidare",
    "truciderebbero": "trucidare",
    "truciderei": "trucidare",
    "trucideremmo": "trucidare",
    "trucideremo": "trucidare",
    "trucidereste": "trucidare",
    "trucideresti": "trucidare",
    "truciderete": "trucidare",
    "truciderà": "trucidare",
    "truciderò": "trucidare",
    "trucidi": "trucidare",
    "trucidiamo": "trucidare",
    "trucidiate": "trucidare",
    "trucidin": "trucidare",
    "trucidino": "trucidare",
    "trucido": "trucidare",
    "trucidò": "trucidare",
    "truculenta": "truculento",
    "truculente": "truculento",
    "truculenti": "truculento",
    "truculenze": "truculenza",
    "truffa": "truffare",
    "truffai": "truffare",
    "truffaldina": "truffaldino",
    "truffaldine": "truffaldino",
    "truffaldini": "truffaldino",
    "truffammo": "truffare",
    "truffan": "truffare",
    "truffando": "truffare",
    "truffano": "truffare",
    "truffante": "truffare",
    "truffanti": "truffare",
    "truffar": "truffare",
    "truffaron": "truffare",
    "truffarono": "truffare",
    "truffasse": "truffare",
    "truffasser": "truffare",
    "truffassero": "truffare",
    "truffassi": "truffare",
    "truffassimo": "truffare",
    "truffaste": "truffare",
    "truffasti": "truffare",
    "truffata": "truffare",
    "truffate": "truffare",
    "truffati": "truffato",
    "truffato": "truffare",
    "truffatori": "truffatore",
    "truffava": "truffare",
    "truffavamo": "truffare",
    "truffavan": "truffare",
    "truffavano": "truffare",
    "truffavate": "truffare",
    "truffavi": "truffare",
    "truffavo": "truffare",
    "truffe": "truffa",
    "trufferai": "truffare",
    "trufferan": "truffare",
    "trufferanno": "truffare",
    "trufferebbe": "truffare",
    "trufferebber": "truffare",
    "trufferebbero": "truffare",
    "trufferei": "truffare",
    "trufferemmo": "truffare",
    "trufferemo": "truffare",
    "truffereste": "truffare",
    "trufferesti": "truffare",
    "trufferete": "truffare",
    "trufferà": "truffare",
    "trufferò": "truffare",
    "truffi": "truffare",
    "truffiamo": "truffare",
    "truffiate": "truffare",
    "truffin": "truffare",
    "truffino": "truffare",
    "truffo": "truffare",
    "truffò": "truffare",
    "trulli": "trullo",
    "truppe": "truppa",
    "tua": "tuo",
    "tuba": "tubare",
    "tubai": "tubare",
    "tubammo": "tubare",
    "tuban": "tubare",
    "tubando": "tubare",
    "tubano": "tubare",
    "tubante": "tubare",
    "tubanti": "tubare",
    "tubar": "tubare",
    "tubaron": "tubare",
    "tubarono": "tubare",
    "tubasse": "tubare",
    "tubasser": "tubare",
    "tubassero": "tubare",
    "tubassi": "tubare",
    "tubassimo": "tubare",
    "tubaste": "tubare",
    "tubasti": "tubare",
    "tubata": "tubare",
    "tubate": "tubare",
    "tubati": "tubare",
    "tubato": "tubare",
    "tubature": "tubatura",
    "tubava": "tubare",
    "tubavamo": "tubare",
    "tubavan": "tubare",
    "tubavano": "tubare",
    "tubavate": "tubare",
    "tubavi": "tubare",
    "tubavo": "tubare",
    "tubazioni": "tubazione",
    "tube": "tuba",
    "tuberai": "tubare",
    "tuberan": "tubare",
    "tuberanno": "tubare",
    "tubercolari": "tubercolare",
    "tubercolosa": "tubercoloso",
    "tubercolose": "tubercoloso",
    "tubercolosi": "tubercoloso",
    "tuberebbe": "tubare",
    "tuberebber": "tubare",
    "tuberebbero": "tubare",
    "tuberei": "tubare",
    "tuberemmo": "tubare",
    "tuberemo": "tubare",
    "tubereste": "tubare",
    "tuberesti": "tubare",
    "tuberete": "tubare",
    "tuberi": "tubero",
    "tuberà": "tubare",
    "tuberò": "tubare",
    "tubetti": "tubetto",
    "tubi": "tubo",
    "tubiamo": "tubare",
    "tubiate": "tubare",
    "tubicini": "tubicino",
    "tubifici": "tubificio",
    "tubin": "tubare",
    "tubini": "tubino",
    "tubino": "tubare",
    "tubo": "tubare",
    "tubolari": "tubolare",
    "tubò": "tubare",
    "tue": "tuo",
    "tufacea": "tufaceo",
    "tufacee": "tufaceo",
    "tufacei": "tufaceo",
    "tuffa": "tuffare",
    "tuffai": "tuffare",
    "tuffammo": "tuffare",
    "tuffan": "tuffare",
    "tuffando": "tuffare",
    "tuffano": "tuffare",
    "tuffante": "tuffare",
    "tuffanti": "tuffare",
    "tuffar": "tuffare",
    "tuffaron": "tuffare",
    "tuffarono": "tuffare",
    "tuffasse": "tuffare",
    "tuffasser": "tuffare",
    "tuffassero": "tuffare",
    "tuffassi": "tuffare",
    "tuffassimo": "tuffare",
    "tuffaste": "tuffare",
    "tuffasti": "tuffare",
    "tuffata": "tuffare",
    "tuffate": "tuffare",
    "tuffati": "tuffare",
    "tuffato": "tuffare",
    "tuffatori": "tuffatore",
    "tuffava": "tuffare",
    "tuffavamo": "tuffare",
    "tuffavan": "tuffare",
    "tuffavano": "tuffare",
    "tuffavate": "tuffare",
    "tuffavi": "tuffare",
    "tuffavo": "tuffare",
    "tufferai": "tuffare",
    "tufferan": "tuffare",
    "tufferanno": "tuffare",
    "tufferebbe": "tuffare",
    "tufferebber": "tuffare",
    "tufferebbero": "tuffare",
    "tufferei": "tuffare",
    "tufferemmo": "tuffare",
    "tufferemo": "tuffare",
    "tuffereste": "tuffare",
    "tufferesti": "tuffare",
    "tufferete": "tuffare",
    "tufferà": "tuffare",
    "tufferò": "tuffare",
    "tuffi": "tuffo",
    "tuffiamo": "tuffare",
    "tuffiate": "tuffare",
    "tuffin": "tuffare",
    "tuffino": "tuffare",
    "tuffo": "tuffare",
    "tuffò": "tuffare",
    "tufi": "tufo",
    "tuguri": "tugurio",
    "tulipani": "tulipano",
    "tumefa": "tumefare",
    "tumefai": "tumefare",
    "tumefammo": "tumefare",
    "tumefan": "tumefare",
    "tumefando": "tumefare",
    "tumefano": "tumefare",
    "tumefante": "tumefare",
    "tumefanti": "tumefare",
    "tumefar": "tumefare",
    "tumefaron": "tumefare",
    "tumefarono": "tumefare",
    "tumefasse": "tumefare",
    "tumefasser": "tumefare",
    "tumefassero": "tumefare",
    "tumefassi": "tumefare",
    "tumefassimo": "tumefare",
    "tumefaste": "tumefare",
    "tumefasti": "tumefare",
    "tumefata": "tumefare",
    "tumefate": "tumefare",
    "tumefati": "tumefare",
    "tumefato": "tumefare",
    "tumefatta": "tumefatto",
    "tumefatte": "tumefatto",
    "tumefatti": "tumefatto",
    "tumefava": "tumefare",
    "tumefavamo": "tumefare",
    "tumefavan": "tumefare",
    "tumefavano": "tumefare",
    "tumefavate": "tumefare",
    "tumefavi": "tumefare",
    "tumefavo": "tumefare",
    "tumefazioni": "tumefazione",
    "tumeferai": "tumefare",
    "tumeferan": "tumefare",
    "tumeferanno": "tumefare",
    "tumeferebbe": "tumefare",
    "tumeferebber": "tumefare",
    "tumeferebbero": "tumefare",
    "tumeferei": "tumefare",
    "tumeferemmo": "tumefare",
    "tumeferemo": "tumefare",
    "tumefereste": "tumefare",
    "tumeferesti": "tumefare",
    "tumeferete": "tumefare",
    "tumeferà": "tumefare",
    "tumeferò": "tumefare",
    "tumefi": "tumefare",
    "tumefiamo": "tumefare",
    "tumefiate": "tumefare",
    "tumefin": "tumefare",
    "tumefino": "tumefare",
    "tumefo": "tumefare",
    "tumefò": "tumefare",
    "tumida": "tumido",
    "tumide": "tumido",
    "tumidi": "tumido",
    "tumorali": "tumorale",
    "tumori": "tumore",
    "tumula": "tumulare",
    "tumulai": "tumulare",
    "tumulammo": "tumulare",
    "tumulan": "tumulare",
    "tumulando": "tumulare",
    "tumulano": "tumulare",
    "tumulante": "tumulare",
    "tumulanti": "tumulare",
    "tumular": "tumulare",
    "tumularon": "tumulare",
    "tumularono": "tumulare",
    "tumulasse": "tumulare",
    "tumulasser": "tumulare",
    "tumulassero": "tumulare",
    "tumulassi": "tumulare",
    "tumulassimo": "tumulare",
    "tumulaste": "tumulare",
    "tumulasti": "tumulare",
    "tumulata": "tumulare",
    "tumulate": "tumulare",
    "tumulati": "tumulare",
    "tumulato": "tumulare",
    "tumulava": "tumulare",
    "tumulavamo": "tumulare",
    "tumulavan": "tumulare",
    "tumulavano": "tumulare",
    "tumulavate": "tumulare",
    "tumulavi": "tumulare",
    "tumulavo": "tumulare",
    "tumulazioni": "tumulazione",
    "tumulerai": "tumulare",
    "tumuleran": "tumulare",
    "tumuleranno": "tumulare",
    "tumulerebbe": "tumulare",
    "tumulerebber": "tumulare",
    "tumulerebbero": "tumulare",
    "tumulerei": "tumulare",
    "tumuleremmo": "tumulare",
    "tumuleremo": "tumulare",
    "tumulereste": "tumulare",
    "tumuleresti": "tumulare",
    "tumulerete": "tumulare",
    "tumulerà": "tumulare",
    "tumulerò": "tumulare",
    "tumuli": "tumulo",
    "tumuliamo": "tumulare",
    "tumuliate": "tumulare",
    "tumulin": "tumulare",
    "tumulino": "tumulare",
    "tumulo": "tumulare",
    "tumulti": "tumulto",
    "tumultua": "tumultuare",
    "tumultuai": "tumultuare",
    "tumultuammo": "tumultuare",
    "tumultuan": "tumultuare",
    "tumultuando": "tumultuare",
    "tumultuano": "tumultuare",
    "tumultuante": "tumultuare",
    "tumultuanti": "tumultuare",
    "tumultuar": "tumultuare",
    "tumultuaron": "tumultuare",
    "tumultuarono": "tumultuare",
    "tumultuasse": "tumultuare",
    "tumultuasser": "tumultuare",
    "tumultuassero": "tumultuare",
    "tumultuassi": "tumultuare",
    "tumultuassimo": "tumultuare",
    "tumultuaste": "tumultuare",
    "tumultuasti": "tumultuare",
    "tumultuata": "tumultuare",
    "tumultuate": "tumultuare",
    "tumultuati": "tumultuare",
    "tumultuato": "tumultuare",
    "tumultuava": "tumultuare",
    "tumultuavamo": "tumultuare",
    "tumultuavan": "tumultuare",
    "tumultuavano": "tumultuare",
    "tumultuavate": "tumultuare",
    "tumultuavi": "tumultuare",
    "tumultuavo": "tumultuare",
    "tumultuerai": "tumultuare",
    "tumultueran": "tumultuare",
    "tumultueranno": "tumultuare",
    "tumultuerebbe": "tumultuare",
    "tumultuerebber": "tumultuare",
    "tumultuerebbero": "tumultuare",
    "tumultuerei": "tumultuare",
    "tumultueremmo": "tumultuare",
    "tumultueremo": "tumultuare",
    "tumultuereste": "tumultuare",
    "tumultueresti": "tumultuare",
    "tumultuerete": "tumultuare",
    "tumultuerà": "tumultuare",
    "tumultuerò": "tumultuare",
    "tumultui": "tumultuare",
    "tumultuiamo": "tumultuare",
    "tumultuiate": "tumultuare",
    "tumultuin": "tumultuare",
    "tumultuino": "tumultuare",
    "tumultuo": "tumultuare",
    "tumultuosa": "tumultuoso",
    "tumultuose": "tumultuoso",
    "tumultuosi": "tumultuoso",
    "tumultuò": "tumultuare",
    "tumulò": "tumulare",
    "tundre": "tundra",
    "tuniche": "tunica",
    "tunisina": "tunisino",
    "tunisine": "tunisino",
    "tunisini": "tunisino",
    "tuoi": "tuo",
    "tuona": "tuonare",
    "tuonai": "tuonare",
    "tuonammo": "tuonare",
    "tuonan": "tuonare",
    "tuonando": "tuonare",
    "tuonano": "tuonare",
    "tuonante": "tuonare",
    "tuonanti": "tuonare",
    "tuonar": "tuonare",
    "tuonaron": "tuonare",
    "tuonarono": "tuonare",
    "tuonasse": "tuonare",
    "tuonasser": "tuonare",
    "tuonassero": "tuonare",
    "tuonassi": "tuonare",
    "tuonassimo": "tuonare",
    "tuonaste": "tuonare",
    "tuonasti": "tuonare",
    "tuonata": "tuonare",
    "tuonate": "tuonare",
    "tuonati": "tuonare",
    "tuonato": "tuonare",
    "tuonava": "tuonare",
    "tuonavamo": "tuonare",
    "tuonavan": "tuonare",
    "tuonavano": "tuonare",
    "tuonavate": "tuonare",
    "tuonavi": "tuonare",
    "tuonavo": "tuonare",
    "tuonerai": "tuonare",
    "tuoneran": "tuonare",
    "tuoneranno": "tuonare",
    "tuonerebbe": "tuonare",
    "tuonerebber": "tuonare",
    "tuonerebbero": "tuonare",
    "tuonerei": "tuonare",
    "tuoneremmo": "tuonare",
    "tuoneremo": "tuonare",
    "tuonereste": "tuonare",
    "tuoneresti": "tuonare",
    "tuonerete": "tuonare",
    "tuonerà": "tuonare",
    "tuonerò": "tuonare",
    "tuoni": "tuono",
    "tuoniamo": "tuonare",
    "tuoniate": "tuonare",
    "tuonin": "tuonare",
    "tuonino": "tuonare",
    "tuono": "tuonare",
    "tuonò": "tuonare",
    "tura": "turare",
    "turaccioli": "turacciolo",
    "turai": "turare",
    "turammo": "turare",
    "turan": "turare",
    "turando": "turare",
    "turano": "turare",
    "turante": "turare",
    "turanti": "turare",
    "turar": "turare",
    "turaron": "turare",
    "turarono": "turare",
    "turasse": "turare",
    "turasser": "turare",
    "turassero": "turare",
    "turassi": "turare",
    "turassimo": "turare",
    "turaste": "turare",
    "turasti": "turare",
    "turata": "turare",
    "turate": "turare",
    "turati": "turare",
    "turato": "turare",
    "turava": "turare",
    "turavamo": "turare",
    "turavan": "turare",
    "turavano": "turare",
    "turavate": "turare",
    "turavi": "turare",
    "turavo": "turare",
    "turba": "turbare",
    "turbai": "turbare",
    "turbamenti": "turbamento",
    "turbammo": "turbare",
    "turban": "turbare",
    "turbando": "turbare",
    "turbano": "turbare",
    "turbante": "turbare",
    "turbanti": "turbare",
    "turbar": "turbare",
    "turbaron": "turbare",
    "turbarono": "turbare",
    "turbasse": "turbare",
    "turbasser": "turbare",
    "turbassero": "turbare",
    "turbassi": "turbare",
    "turbassimo": "turbare",
    "turbaste": "turbare",
    "turbasti": "turbare",
    "turbata": "turbato",
    "turbate": "turbato",
    "turbati": "turbato",
    "turbativa": "turbativo",
    "turbative": "turbativo",
    "turbativi": "turbativo",
    "turbato": "turbare",
    "turbava": "turbare",
    "turbavamo": "turbare",
    "turbavan": "turbare",
    "turbavano": "turbare",
    "turbavate": "turbare",
    "turbavi": "turbare",
    "turbavo": "turbare",
    "turbe": "turba",
    "turberai": "turbare",
    "turberan": "turbare",
    "turberanno": "turbare",
    "turberebbe": "turbare",
    "turberebber": "turbare",
    "turberebbero": "turbare",
    "turberei": "turbare",
    "turberemmo": "turbare",
    "turberemo": "turbare",
    "turbereste": "turbare",
    "turberesti": "turbare",
    "turberete": "turbare",
    "turberà": "turbare",
    "turberò": "turbare",
    "turbi": "turbare",
    "turbiamo": "turbare",
    "turbiate": "turbare",
    "turbin": "turbare",
    "turbina": "turbinare",
    "turbinai": "turbinare",
    "turbinammo": "turbinare",
    "turbinan": "turbinare",
    "turbinando": "turbinare",
    "turbinano": "turbinare",
    "turbinante": "turbinare",
    "turbinanti": "turbinare",
    "turbinar": "turbinare",
    "turbinaron": "turbinare",
    "turbinarono": "turbinare",
    "turbinasse": "turbinare",
    "turbinasser": "turbinare",
    "turbinassero": "turbinare",
    "turbinassi": "turbinare",
    "turbinassimo": "turbinare",
    "turbinaste": "turbinare",
    "turbinasti": "turbinare",
    "turbinata": "turbinare",
    "turbinate": "turbinare",
    "turbinati": "turbinare",
    "turbinato": "turbinare",
    "turbinava": "turbinare",
    "turbinavamo": "turbinare",
    "turbinavan": "turbinare",
    "turbinavano": "turbinare",
    "turbinavate": "turbinare",
    "turbinavi": "turbinare",
    "turbinavo": "turbinare",
    "turbine": "turbina",
    "turbinerai": "turbinare",
    "turbineran": "turbinare",
    "turbineranno": "turbinare",
    "turbinerebbe": "turbinare",
    "turbinerebber": "turbinare",
    "turbinerebbero": "turbinare",
    "turbinerei": "turbinare",
    "turbineremmo": "turbinare",
    "turbineremo": "turbinare",
    "turbinereste": "turbinare",
    "turbineresti": "turbinare",
    "turbinerete": "turbinare",
    "turbinerà": "turbinare",
    "turbinerò": "turbinare",
    "turbini": "turbine",
    "turbiniamo": "turbinare",
    "turbiniate": "turbinare",
    "turbinii": "turbinio",
    "turbinin": "turbinare",
    "turbinino": "turbinare",
    "turbino": "turbinare",
    "turbinosa": "turbinoso",
    "turbinose": "turbinoso",
    "turbinosi": "turbinoso",
    "turbinò": "turbinare",
    "turbo": "turbare",
    "turbocomprima": "turbocomprimere",
    "turbocompriman": "turbocomprimere",
    "turbocomprimano": "turbocomprimere",
    "turbocomprime": "turbocomprimere",
    "turbocomprimei": "turbocomprimere",
    "turbocomprimemmo": "turbocomprimere",
    "turbocomprimendo": "turbocomprimere",
    "turbocomprimente": "turbocomprimere",
    "turbocomprimenti": "turbocomprimere",
    "turbocomprimer": "turbocomprimere",
    "turbocomprimerai": "turbocomprimere",
    "turbocomprimeran": "turbocomprimere",
    "turbocomprimeranno": "turbocomprimere",
    "turbocomprimerebbe": "turbocomprimere",
    "turbocomprimerebber": "turbocomprimere",
    "turbocomprimerebbero": "turbocomprimere",
    "turbocomprimerei": "turbocomprimere",
    "turbocomprimeremmo": "turbocomprimere",
    "turbocomprimeremo": "turbocomprimere",
    "turbocomprimereste": "turbocomprimere",
    "turbocomprimeresti": "turbocomprimere",
    "turbocomprimerete": "turbocomprimere",
    "turbocomprimeron": "turbocomprimere",
    "turbocomprimerono": "turbocomprimere",
    "turbocomprimerà": "turbocomprimere",
    "turbocomprimerò": "turbocomprimere",
    "turbocomprimesse": "turbocomprimere",
    "turbocomprimesser": "turbocomprimere",
    "turbocomprimessero": "turbocomprimere",
    "turbocomprimessi": "turbocomprimere",
    "turbocomprimessimo": "turbocomprimere",
    "turbocomprimeste": "turbocomprimere",
    "turbocomprimesti": "turbocomprimere",
    "turbocomprimete": "turbocomprimere",
    "turbocomprimeva": "turbocomprimere",
    "turbocomprimevamo": "turbocomprimere",
    "turbocomprimevan": "turbocomprimere",
    "turbocomprimevano": "turbocomprimere",
    "turbocomprimevate": "turbocomprimere",
    "turbocomprimevi": "turbocomprimere",
    "turbocomprimevo": "turbocomprimere",
    "turbocomprimi": "turbocomprimere",
    "turbocomprimiamo": "turbocomprimere",
    "turbocomprimiate": "turbocomprimere",
    "turbocomprimo": "turbocomprimere",
    "turbocomprimon": "turbocomprimere",
    "turbocomprimono": "turbocomprimere",
    "turbocomprimuta": "turbocomprimere",
    "turbocomprimute": "turbocomprimere",
    "turbocomprimuti": "turbocomprimere",
    "turbocomprimuto": "turbocomprimere",
    "turbocomprimè": "turbocomprimere",
    "turbolenta": "turbolento",
    "turbolente": "turbolento",
    "turbolenti": "turbolento",
    "turbolenze": "turbolenza",
    "turbò": "turbare",
    "turca": "turco",
    "turche": "turco",
    "turcherie": "turcheria",
    "turchesi": "turchese",
    "turchi": "turco",
    "turchina": "turchino",
    "turchine": "turchino",
    "turchini": "turchino",
    "turerai": "turare",
    "tureran": "turare",
    "tureranno": "turare",
    "turerebbe": "turare",
    "turerebber": "turare",
    "turerebbero": "turare",
    "turerei": "turare",
    "tureremmo": "turare",
    "tureremo": "turare",
    "turereste": "turare",
    "tureresti": "turare",
    "turerete": "turare",
    "turerà": "turare",
    "turerò": "turare",
    "turgida": "turgido",
    "turgide": "turgido",
    "turgidi": "turgido",
    "turgori": "turgore",
    "turi": "turare",
    "turiamo": "turare",
    "turiate": "turare",
    "turiboli": "turibolo",
    "turin": "turare",
    "turino": "turare",
    "turismi": "turismo",
    "turiste": "turista",
    "turisti": "turista",
    "turistica": "turistico",
    "turistiche": "turistico",
    "turistici": "turistico",
    "turlupina": "turlupinare",
    "turlupinai": "turlupinare",
    "turlupinammo": "turlupinare",
    "turlupinan": "turlupinare",
    "turlupinando": "turlupinare",
    "turlupinano": "turlupinare",
    "turlupinante": "turlupinare",
    "turlupinanti": "turlupinare",
    "turlupinar": "turlupinare",
    "turlupinaron": "turlupinare",
    "turlupinarono": "turlupinare",
    "turlupinasse": "turlupinare",
    "turlupinasser": "turlupinare",
    "turlupinassero": "turlupinare",
    "turlupinassi": "turlupinare",
    "turlupinassimo": "turlupinare",
    "turlupinaste": "turlupinare",
    "turlupinasti": "turlupinare",
    "turlupinata": "turlupinare",
    "turlupinate": "turlupinare",
    "turlupinati": "turlupinare",
    "turlupinato": "turlupinare",
    "turlupinava": "turlupinare",
    "turlupinavamo": "turlupinare",
    "turlupinavan": "turlupinare",
    "turlupinavano": "turlupinare",
    "turlupinavate": "turlupinare",
    "turlupinavi": "turlupinare",
    "turlupinavo": "turlupinare",
    "turlupinerai": "turlupinare",
    "turlupineran": "turlupinare",
    "turlupineranno": "turlupinare",
    "turlupinerebbe": "turlupinare",
    "turlupinerebber": "turlupinare",
    "turlupinerebbero": "turlupinare",
    "turlupinerei": "turlupinare",
    "turlupineremmo": "turlupinare",
    "turlupineremo": "turlupinare",
    "turlupinereste": "turlupinare",
    "turlupineresti": "turlupinare",
    "turlupinerete": "turlupinare",
    "turlupinerà": "turlupinare",
    "turlupinerò": "turlupinare",
    "turlupini": "turlupinare",
    "turlupiniamo": "turlupinare",
    "turlupiniate": "turlupinare",
    "turlupinin": "turlupinare",
    "turlupinino": "turlupinare",
    "turlupino": "turlupinare",
    "turlupinò": "turlupinare",
    "turnazioni": "turnazione",
    "turni": "turno",
    "turnisti": "turnista",
    "turo": "turare",
    "turpi": "turpe",
    "turpiloqui": "turpiloquio",
    "turpitudini": "turpitudine",
    "turrita": "turrito",
    "turrite": "turrito",
    "turriti": "turrito",
    "turò": "turare",
    "tuscana": "tuscano",
    "tuscane": "tuscano",
    "tuscani": "tuscano",
    "tuscania": "tuscanio",
    "tuscanie": "tuscanio",
    "tute": "tuta",
    "tutela": "tutelare",
    "tutelai": "tutelare",
    "tutelammo": "tutelare",
    "tutelan": "tutelare",
    "tutelando": "tutelare",
    "tutelano": "tutelare",
    "tutelante": "tutelare",
    "tutelanti": "tutelare",
    "tutelar": "tutelare",
    "tutelari": "tutelare",
    "tutelaron": "tutelare",
    "tutelarono": "tutelare",
    "tutelasse": "tutelare",
    "tutelasser": "tutelare",
    "tutelassero": "tutelare",
    "tutelassi": "tutelare",
    "tutelassimo": "tutelare",
    "tutelaste": "tutelare",
    "tutelasti": "tutelare",
    "tutelata": "tutelare",
    "tutelate": "tutelare",
    "tutelati": "tutelare",
    "tutelato": "tutelare",
    "tutelava": "tutelare",
    "tutelavamo": "tutelare",
    "tutelavan": "tutelare",
    "tutelavano": "tutelare",
    "tutelavate": "tutelare",
    "tutelavi": "tutelare",
    "tutelavo": "tutelare",
    "tutele": "tutela",
    "tutelerai": "tutelare",
    "tuteleran": "tutelare",
    "tuteleranno": "tutelare",
    "tutelerebbe": "tutelare",
    "tutelerebber": "tutelare",
    "tutelerebbero": "tutelare",
    "tutelerei": "tutelare",
    "tuteleremmo": "tutelare",
    "tuteleremo": "tutelare",
    "tutelereste": "tutelare",
    "tuteleresti": "tutelare",
    "tutelerete": "tutelare",
    "tutelerà": "tutelare",
    "tutelerò": "tutelare",
    "tuteli": "tutelare",
    "tuteliamo": "tutelare",
    "tuteliate": "tutelare",
    "tutelin": "tutelare",
    "tutelino": "tutelare",
    "tutelo": "tutelare",
    "tutelò": "tutelare",
    "tutine": "tutina",
    "tutori": "tutorio",
    "tutoria": "tutorio",
    "tutorie": "tutorio",
    "tutrice": "tutore",
    "tutrici": "tutore",
    "tutta": "tutto",
    "tutte": "tutto",
    "tutti": "tutto",
    "tuttologi": "tuttologo",
    "tzigana": "tzigano",
    "tzigane": "tzigano",
    "tzigani": "tzigano",
    "ubbidendo": "ubbidire",
    "ubbidente": "ubbidire",
    "ubbidenti": "ubbidire",
    "ubbidiamo": "ubbidire",
    "ubbidiate": "ubbidire",
    "ubbidienti": "ubbidiente",
    "ubbidii": "ubbidire",
    "ubbidimmo": "ubbidire",
    "ubbidir": "ubbidire",
    "ubbidirai": "ubbidire",
    "ubbidiran": "ubbidire",
    "ubbidiranno": "ubbidire",
    "ubbidirebbe": "ubbidire",
    "ubbidirebber": "ubbidire",
    "ubbidirebbero": "ubbidire",
    "ubbidirei": "ubbidire",
    "ubbidiremmo": "ubbidire",
    "ubbidiremo": "ubbidire",
    "ubbidireste": "ubbidire",
    "ubbidiresti": "ubbidire",
    "ubbidirete": "ubbidire",
    "ubbidiron": "ubbidire",
    "ubbidirono": "ubbidire",
    "ubbidirà": "ubbidire",
    "ubbidirò": "ubbidire",
    "ubbidisca": "ubbidire",
    "ubbidiscan": "ubbidire",
    "ubbidiscano": "ubbidire",
    "ubbidisce": "ubbidire",
    "ubbidisci": "ubbidire",
    "ubbidisco": "ubbidire",
    "ubbidiscon": "ubbidire",
    "ubbidiscono": "ubbidire",
    "ubbidisse": "ubbidire",
    "ubbidisser": "ubbidire",
    "ubbidissero": "ubbidire",
    "ubbidissi": "ubbidire",
    "ubbidissimo": "ubbidire",
    "ubbidiste": "ubbidire",
    "ubbidisti": "ubbidire",
    "ubbidita": "ubbidire",
    "ubbidite": "ubbidire",
    "ubbiditi": "ubbidire",
    "ubbidito": "ubbidire",
    "ubbidiva": "ubbidire",
    "ubbidivamo": "ubbidire",
    "ubbidivan": "ubbidire",
    "ubbidivano": "ubbidire",
    "ubbidivate": "ubbidire",
    "ubbidivi": "ubbidire",
    "ubbidivo": "ubbidire",
    "ubbidì": "ubbidire",
    "ubbie": "ubbia",
    "ubertosa": "ubertoso",
    "ubertose": "ubertoso",
    "ubertosi": "ubertoso",
    "ubica": "ubicare",
    "ubicai": "ubicare",
    "ubicammo": "ubicare",
    "ubican": "ubicare",
    "ubicando": "ubicare",
    "ubicano": "ubicare",
    "ubicante": "ubicare",
    "ubicanti": "ubicare",
    "ubicar": "ubicare",
    "ubicaron": "ubicare",
    "ubicarono": "ubicare",
    "ubicasse": "ubicare",
    "ubicasser": "ubicare",
    "ubicassero": "ubicare",
    "ubicassi": "ubicare",
    "ubicassimo": "ubicare",
    "ubicaste": "ubicare",
    "ubicasti": "ubicare",
    "ubicata": "ubicare",
    "ubicate": "ubicare",
    "ubicati": "ubicare",
    "ubicato": "ubicare",
    "ubicava": "ubicare",
    "ubicavamo": "ubicare",
    "ubicavan": "ubicare",
    "ubicavano": "ubicare",
    "ubicavate": "ubicare",
    "ubicavi": "ubicare",
    "ubicavo": "ubicare",
    "ubicazioni": "ubicazione",
    "ubicherai": "ubicare",
    "ubicheran": "ubicare",
    "ubicheranno": "ubicare",
    "ubicherebbe": "ubicare",
    "ubicherebber": "ubicare",
    "ubicherebbero": "ubicare",
    "ubicherei": "ubicare",
    "ubicheremmo": "ubicare",
    "ubicheremo": "ubicare",
    "ubichereste": "ubicare",
    "ubicheresti": "ubicare",
    "ubicherete": "ubicare",
    "ubicherà": "ubicare",
    "ubicherò": "ubicare",
    "ubichi": "ubicare",
    "ubichiamo": "ubicare",
    "ubichiate": "ubicare",
    "ubichin": "ubicare",
    "ubichino": "ubicare",
    "ubico": "ubicare",
    "ubicò": "ubicare",
    "ubiqua": "ubiquo",
    "ubique": "ubiquo",
    "ubiqui": "ubiquo",
    "ubriaca": "ubriaco",
    "ubriacai": "ubriacare",
    "ubriacammo": "ubriacare",
    "ubriacan": "ubriacare",
    "ubriacando": "ubriacare",
    "ubriacano": "ubriacare",
    "ubriacante": "ubriacare",
    "ubriacanti": "ubriacare",
    "ubriacar": "ubriacare",
    "ubriacaron": "ubriacare",
    "ubriacarono": "ubriacare",
    "ubriacasse": "ubriacare",
    "ubriacasser": "ubriacare",
    "ubriacassero": "ubriacare",
    "ubriacassi": "ubriacare",
    "ubriacassimo": "ubriacare",
    "ubriacaste": "ubriacare",
    "ubriacasti": "ubriacare",
    "ubriacata": "ubriacare",
    "ubriacate": "ubriacare",
    "ubriacati": "ubriacare",
    "ubriacato": "ubriacare",
    "ubriacature": "ubriacatura",
    "ubriacava": "ubriacare",
    "ubriacavamo": "ubriacare",
    "ubriacavan": "ubriacare",
    "ubriacavano": "ubriacare",
    "ubriacavate": "ubriacare",
    "ubriacavi": "ubriacare",
    "ubriacavo": "ubriacare",
    "ubriache": "ubriaco",
    "ubriacherai": "ubriacare",
    "ubriacheran": "ubriacare",
    "ubriacheranno": "ubriacare",
    "ubriacherebbe": "ubriacare",
    "ubriacherebber": "ubriacare",
    "ubriacherebbero": "ubriacare",
    "ubriacherei": "ubriacare",
    "ubriacheremmo": "ubriacare",
    "ubriacheremo": "ubriacare",
    "ubriachereste": "ubriacare",
    "ubriacheresti": "ubriacare",
    "ubriacherete": "ubriacare",
    "ubriacherà": "ubriacare",
    "ubriacherò": "ubriacare",
    "ubriachi": "ubriaco",
    "ubriachiamo": "ubriacare",
    "ubriachiate": "ubriacare",
    "ubriachin": "ubriacare",
    "ubriachino": "ubriacare",
    "ubriaco": "ubriacare",
    "ubriaconi": "ubriacone",
    "ubriacò": "ubriacare",
    "uccella": "uccellare",
    "uccellacci": "uccellaccio",
    "uccellai": "uccellare",
    "uccellammo": "uccellare",
    "uccellan": "uccellare",
    "uccellando": "uccellare",
    "uccellano": "uccellare",
    "uccellante": "uccellare",
    "uccellanti": "uccellare",
    "uccellar": "uccellare",
    "uccellaron": "uccellare",
    "uccellarono": "uccellare",
    "uccellasse": "uccellare",
    "uccellasser": "uccellare",
    "uccellassero": "uccellare",
    "uccellassi": "uccellare",
    "uccellassimo": "uccellare",
    "uccellaste": "uccellare",
    "uccellasti": "uccellare",
    "uccellata": "uccellare",
    "uccellate": "uccellare",
    "uccellati": "uccellare",
    "uccellato": "uccellare",
    "uccellava": "uccellare",
    "uccellavamo": "uccellare",
    "uccellavan": "uccellare",
    "uccellavano": "uccellare",
    "uccellavate": "uccellare",
    "uccellavi": "uccellare",
    "uccellavo": "uccellare",
    "uccellerai": "uccellare",
    "uccelleran": "uccellare",
    "uccelleranno": "uccellare",
    "uccellerebbe": "uccellare",
    "uccellerebber": "uccellare",
    "uccellerebbero": "uccellare",
    "uccellerei": "uccellare",
    "uccelleremmo": "uccellare",
    "uccelleremo": "uccellare",
    "uccellereste": "uccellare",
    "uccelleresti": "uccellare",
    "uccellerete": "uccellare",
    "uccellerà": "uccellare",
    "uccellerò": "uccellare",
    "uccelli": "uccello",
    "uccelliamo": "uccellare",
    "uccelliate": "uccellare",
    "uccellin": "uccellare",
    "uccellini": "uccellino",
    "uccellino": "uccellare",
    "uccello": "uccellare",
    "uccellò": "uccellare",
    "uccida": "uccidere",
    "uccidan": "uccidere",
    "uccidano": "uccidere",
    "uccide": "uccidere",
    "uccidemmo": "uccidere",
    "uccidendo": "uccidere",
    "uccidente": "uccidere",
    "uccidenti": "uccidere",
    "uccider": "uccidere",
    "ucciderai": "uccidere",
    "uccideran": "uccidere",
    "uccideranno": "uccidere",
    "ucciderebbe": "uccidere",
    "ucciderebber": "uccidere",
    "ucciderebbero": "uccidere",
    "ucciderei": "uccidere",
    "uccideremmo": "uccidere",
    "uccideremo": "uccidere",
    "uccidereste": "uccidere",
    "uccideresti": "uccidere",
    "ucciderete": "uccidere",
    "ucciderà": "uccidere",
    "ucciderò": "uccidere",
    "uccidesse": "uccidere",
    "uccidesser": "uccidere",
    "uccidessero": "uccidere",
    "uccidessi": "uccidere",
    "uccidessimo": "uccidere",
    "uccideste": "uccidere",
    "uccidesti": "uccidere",
    "uccidete": "uccidere",
    "uccideva": "uccidere",
    "uccidevamo": "uccidere",
    "uccidevan": "uccidere",
    "uccidevano": "uccidere",
    "uccidevate": "uccidere",
    "uccidevi": "uccidere",
    "uccidevo": "uccidere",
    "uccidi": "uccidere",
    "uccidiamo": "uccidere",
    "uccidiate": "uccidere",
    "uccido": "uccidere",
    "uccidon": "uccidere",
    "uccidono": "uccidere",
    "uccisa": "ucciso",
    "uccise": "ucciso",
    "ucciser": "uccidere",
    "uccisero": "uccidere",
    "uccisi": "ucciso",
    "uccisioni": "uccisione",
    "ucciso": "uccidere",
    "uccisori": "uccisore",
    "ucraina": "ucraino",
    "ucraine": "ucraino",
    "ucraini": "ucraino",
    "udendo": "udire",
    "udente": "udire",
    "udenti": "udire",
    "udiamo": "udire",
    "udiate": "udire",
    "udibili": "udibile",
    "udienze": "udienza",
    "udii": "udire",
    "udimmo": "udire",
    "udinesi": "udinese",
    "udir": "udire",
    "udirai": "udire",
    "udiran": "udire",
    "udiranno": "udire",
    "udirebbe": "udire",
    "udirebber": "udire",
    "udirebbero": "udire",
    "udirei": "udire",
    "udiremmo": "udire",
    "udiremo": "udire",
    "udireste": "udire",
    "udiresti": "udire",
    "udirete": "udire",
    "udiron": "udire",
    "udirono": "udire",
    "udirà": "udire",
    "udirò": "udire",
    "udisse": "udire",
    "udisser": "udire",
    "udissero": "udire",
    "udissi": "udire",
    "udissimo": "udire",
    "udiste": "udire",
    "udisti": "udire",
    "udita": "udire",
    "udite": "udire",
    "uditi": "udire",
    "uditiva": "uditivo",
    "uditive": "uditivo",
    "uditivi": "uditivo",
    "udito": "udire",
    "uditori": "uditorio",
    "uditoria": "uditorio",
    "uditorie": "uditorio",
    "uditrice": "uditore",
    "uditrici": "uditore",
    "udiva": "udire",
    "udivamo": "udire",
    "udivan": "udire",
    "udivano": "udire",
    "udivate": "udire",
    "udivi": "udire",
    "udivo": "udire",
    "udì": "udire",
    "ufficerai": "ufficiare",
    "ufficeran": "ufficiare",
    "ufficeranno": "ufficiare",
    "ufficerebbe": "ufficiare",
    "ufficerebber": "ufficiare",
    "ufficerebbero": "ufficiare",
    "ufficerei": "ufficiare",
    "ufficeremmo": "ufficiare",
    "ufficeremo": "ufficiare",
    "ufficereste": "ufficiare",
    "ufficeresti": "ufficiare",
    "ufficerete": "ufficiare",
    "ufficerà": "ufficiare",
    "ufficerò": "ufficiare",
    "ufficetti": "ufficetto",
    "uffici": "ufficio",
    "ufficia": "ufficiare",
    "ufficiai": "ufficiare",
    "ufficialetti": "ufficialetto",
    "ufficiali": "ufficiale",
    "ufficializza": "ufficializzare",
    "ufficializzai": "ufficializzare",
    "ufficializzammo": "ufficializzare",
    "ufficializzan": "ufficializzare",
    "ufficializzando": "ufficializzare",
    "ufficializzano": "ufficializzare",
    "ufficializzante": "ufficializzare",
    "ufficializzanti": "ufficializzare",
    "ufficializzar": "ufficializzare",
    "ufficializzaron": "ufficializzare",
    "ufficializzarono": "ufficializzare",
    "ufficializzasse": "ufficializzare",
    "ufficializzasser": "ufficializzare",
    "ufficializzassero": "ufficializzare",
    "ufficializzassi": "ufficializzare",
    "ufficializzassimo": "ufficializzare",
    "ufficializzaste": "ufficializzare",
    "ufficializzasti": "ufficializzare",
    "ufficializzata": "ufficializzare",
    "ufficializzate": "ufficializzare",
    "ufficializzati": "ufficializzare",
    "ufficializzato": "ufficializzare",
    "ufficializzava": "ufficializzare",
    "ufficializzavamo": "ufficializzare",
    "ufficializzavan": "ufficializzare",
    "ufficializzavano": "ufficializzare",
    "ufficializzavate": "ufficializzare",
    "ufficializzavi": "ufficializzare",
    "ufficializzavo": "ufficializzare",
    "ufficializzazioni": "ufficializzazione",
    "ufficializzerai": "ufficializzare",
    "ufficializzeran": "ufficializzare",
    "ufficializzeranno": "ufficializzare",
    "ufficializzerebbe": "ufficializzare",
    "ufficializzerebber": "ufficializzare",
    "ufficializzerebbero": "ufficializzare",
    "ufficializzerei": "ufficializzare",
    "ufficializzeremmo": "ufficializzare",
    "ufficializzeremo": "ufficializzare",
    "ufficializzereste": "ufficializzare",
    "ufficializzeresti": "ufficializzare",
    "ufficializzerete": "ufficializzare",
    "ufficializzerà": "ufficializzare",
    "ufficializzerò": "ufficializzare",
    "ufficializzi": "ufficializzare",
    "ufficializziamo": "ufficializzare",
    "ufficializziate": "ufficializzare",
    "ufficializzin": "ufficializzare",
    "ufficializzino": "ufficializzare",
    "ufficializzo": "ufficializzare",
    "ufficializzò": "ufficializzare",
    "ufficiammo": "ufficiare",
    "ufficiamo": "ufficiare",
    "uffician": "ufficiare",
    "ufficiando": "ufficiare",
    "ufficiano": "ufficiare",
    "ufficiante": "ufficiare",
    "ufficianti": "ufficiare",
    "ufficiar": "ufficiare",
    "ufficiaron": "ufficiare",
    "ufficiarono": "ufficiare",
    "ufficiasse": "ufficiare",
    "ufficiasser": "ufficiare",
    "ufficiassero": "ufficiare",
    "ufficiassi": "ufficiare",
    "ufficiassimo": "ufficiare",
    "ufficiaste": "ufficiare",
    "ufficiasti": "ufficiare",
    "ufficiata": "ufficiare",
    "ufficiate": "ufficiare",
    "ufficiati": "ufficiare",
    "ufficiato": "ufficiare",
    "ufficiava": "ufficiare",
    "ufficiavamo": "ufficiare",
    "ufficiavan": "ufficiare",
    "ufficiavano": "ufficiare",
    "ufficiavate": "ufficiare",
    "ufficiavi": "ufficiare",
    "ufficiavo": "ufficiare",
    "ufficin": "ufficiare",
    "ufficino": "ufficiare",
    "ufficio": "ufficiare",
    "ufficiosa": "ufficioso",
    "ufficiose": "ufficioso",
    "ufficiosi": "ufficioso",
    "ufficiò": "ufficiare",
    "uggiola": "uggiolare",
    "uggiolai": "uggiolare",
    "uggiolammo": "uggiolare",
    "uggiolan": "uggiolare",
    "uggiolando": "uggiolare",
    "uggiolano": "uggiolare",
    "uggiolante": "uggiolare",
    "uggiolanti": "uggiolare",
    "uggiolar": "uggiolare",
    "uggiolaron": "uggiolare",
    "uggiolarono": "uggiolare",
    "uggiolasse": "uggiolare",
    "uggiolasser": "uggiolare",
    "uggiolassero": "uggiolare",
    "uggiolassi": "uggiolare",
    "uggiolassimo": "uggiolare",
    "uggiolaste": "uggiolare",
    "uggiolasti": "uggiolare",
    "uggiolata": "uggiolare",
    "uggiolate": "uggiolare",
    "uggiolati": "uggiolare",
    "uggiolato": "uggiolare",
    "uggiolava": "uggiolare",
    "uggiolavamo": "uggiolare",
    "uggiolavan": "uggiolare",
    "uggiolavano": "uggiolare",
    "uggiolavate": "uggiolare",
    "uggiolavi": "uggiolare",
    "uggiolavo": "uggiolare",
    "uggiolerai": "uggiolare",
    "uggioleran": "uggiolare",
    "uggioleranno": "uggiolare",
    "uggiolerebbe": "uggiolare",
    "uggiolerebber": "uggiolare",
    "uggiolerebbero": "uggiolare",
    "uggiolerei": "uggiolare",
    "uggioleremmo": "uggiolare",
    "uggioleremo": "uggiolare",
    "uggiolereste": "uggiolare",
    "uggioleresti": "uggiolare",
    "uggiolerete": "uggiolare",
    "uggiolerà": "uggiolare",
    "uggiolerò": "uggiolare",
    "uggioli": "uggiolare",
    "uggioliamo": "uggiolare",
    "uggioliate": "uggiolare",
    "uggiolin": "uggiolare",
    "uggiolino": "uggiolare",
    "uggiolo": "uggiolare",
    "uggiolò": "uggiolare",
    "uggiosa": "uggioso",
    "uggiose": "uggioso",
    "uggiosi": "uggioso",
    "ugole": "ugola",
    "ugonotta": "ugonotto",
    "ugonotte": "ugonotto",
    "ugonotti": "ugonotto",
    "uguagli": "uguagliare",
    "uguaglia": "uguagliare",
    "uguagliai": "uguagliare",
    "uguagliammo": "uguagliare",
    "uguagliamo": "uguagliare",
    "uguaglian": "uguagliare",
    "uguagliando": "uguagliare",
    "uguagliano": "uguagliare",
    "uguagliante": "uguagliare",
    "uguaglianti": "uguagliare",
    "uguaglianze": "uguaglianza",
    "uguagliar": "uguagliare",
    "uguagliaron": "uguagliare",
    "uguagliarono": "uguagliare",
    "uguagliasse": "uguagliare",
    "uguagliasser": "uguagliare",
    "uguagliassero": "uguagliare",
    "uguagliassi": "uguagliare",
    "uguagliassimo": "uguagliare",
    "uguagliaste": "uguagliare",
    "uguagliasti": "uguagliare",
    "uguagliata": "uguagliare",
    "uguagliate": "uguagliare",
    "uguagliati": "uguagliare",
    "uguagliato": "uguagliare",
    "uguagliava": "uguagliare",
    "uguagliavamo": "uguagliare",
    "uguagliavan": "uguagliare",
    "uguagliavano": "uguagliare",
    "uguagliavate": "uguagliare",
    "uguagliavi": "uguagliare",
    "uguagliavo": "uguagliare",
    "uguaglierai": "uguagliare",
    "uguaglieran": "uguagliare",
    "uguaglieranno": "uguagliare",
    "uguaglierebbe": "uguagliare",
    "uguaglierebber": "uguagliare",
    "uguaglierebbero": "uguagliare",
    "uguaglierei": "uguagliare",
    "uguaglieremmo": "uguagliare",
    "uguaglieremo": "uguagliare",
    "uguagliereste": "uguagliare",
    "uguaglieresti": "uguagliare",
    "uguaglierete": "uguagliare",
    "uguaglierà": "uguagliare",
    "uguaglierò": "uguagliare",
    "uguaglin": "uguagliare",
    "uguaglino": "uguagliare",
    "uguaglio": "uguagliare",
    "uguagliò": "uguagliare",
    "uguali": "uguale",
    "ugualitari": "ugualitario",
    "ugualitaria": "ugualitario",
    "ugualitarie": "ugualitario",
    "ulani": "ulano",
    "ulcera": "ulcerare",
    "ulcerai": "ulcerare",
    "ulcerammo": "ulcerare",
    "ulceran": "ulcerare",
    "ulcerando": "ulcerare",
    "ulcerano": "ulcerare",
    "ulcerante": "ulcerare",
    "ulceranti": "ulcerare",
    "ulcerar": "ulcerare",
    "ulceraron": "ulcerare",
    "ulcerarono": "ulcerare",
    "ulcerasse": "ulcerare",
    "ulcerasser": "ulcerare",
    "ulcerassero": "ulcerare",
    "ulcerassi": "ulcerare",
    "ulcerassimo": "ulcerare",
    "ulceraste": "ulcerare",
    "ulcerasti": "ulcerare",
    "ulcerata": "ulcerare",
    "ulcerate": "ulcerare",
    "ulcerati": "ulcerare",
    "ulcerato": "ulcerare",
    "ulcerava": "ulcerare",
    "ulceravamo": "ulcerare",
    "ulceravan": "ulcerare",
    "ulceravano": "ulcerare",
    "ulceravate": "ulcerare",
    "ulceravi": "ulcerare",
    "ulceravo": "ulcerare",
    "ulcere": "ulcera",
    "ulcererai": "ulcerare",
    "ulcereran": "ulcerare",
    "ulcereranno": "ulcerare",
    "ulcererebbe": "ulcerare",
    "ulcererebber": "ulcerare",
    "ulcererebbero": "ulcerare",
    "ulcererei": "ulcerare",
    "ulcereremmo": "ulcerare",
    "ulcereremo": "ulcerare",
    "ulcerereste": "ulcerare",
    "ulcereresti": "ulcerare",
    "ulcererete": "ulcerare",
    "ulcererà": "ulcerare",
    "ulcererò": "ulcerare",
    "ulceri": "ulcerare",
    "ulceriamo": "ulcerare",
    "ulceriate": "ulcerare",
    "ulcerin": "ulcerare",
    "ulcerino": "ulcerare",
    "ulcero": "ulcerare",
    "ulcerosa": "ulceroso",
    "ulcerose": "ulceroso",
    "ulcerosi": "ulceroso",
    "ulcerò": "ulcerare",
    "uliveti": "uliveto",
    "ulivi": "ulivo",
    "ulivisti": "ulivista",
    "ulta": "ulto",
    "ulte": "ulto",
    "ulteriori": "ulteriore",
    "ulti": "ulto",
    "ultima": "ultimo",
    "ultimai": "ultimare",
    "ultimammo": "ultimare",
    "ultiman": "ultimare",
    "ultimando": "ultimare",
    "ultimano": "ultimare",
    "ultimante": "ultimare",
    "ultimanti": "ultimare",
    "ultimar": "ultimare",
    "ultimaron": "ultimare",
    "ultimarono": "ultimare",
    "ultimasse": "ultimare",
    "ultimasser": "ultimare",
    "ultimassero": "ultimare",
    "ultimassi": "ultimare",
    "ultimassimo": "ultimare",
    "ultimaste": "ultimare",
    "ultimasti": "ultimare",
    "ultimata": "ultimare",
    "ultimate": "ultimare",
    "ultimati": "ultimare",
    "ultimativa": "ultimativo",
    "ultimative": "ultimativo",
    "ultimativi": "ultimativo",
    "ultimato": "ultimare",
    "ultimava": "ultimare",
    "ultimavamo": "ultimare",
    "ultimavan": "ultimare",
    "ultimavano": "ultimare",
    "ultimavate": "ultimare",
    "ultimavi": "ultimare",
    "ultimavo": "ultimare",
    "ultime": "ultimo",
    "ultimerai": "ultimare",
    "ultimeran": "ultimare",
    "ultimeranno": "ultimare",
    "ultimerebbe": "ultimare",
    "ultimerebber": "ultimare",
    "ultimerebbero": "ultimare",
    "ultimerei": "ultimare",
    "ultimeremmo": "ultimare",
    "ultimeremo": "ultimare",
    "ultimereste": "ultimare",
    "ultimeresti": "ultimare",
    "ultimerete": "ultimare",
    "ultimerà": "ultimare",
    "ultimerò": "ultimare",
    "ultimi": "ultimo",
    "ultimiamo": "ultimare",
    "ultimiate": "ultimare",
    "ultimin": "ultimare",
    "ultimino": "ultimare",
    "ultimo": "ultimare",
    "ultimò": "ultimare",
    "ultra": "ultro",
    "ultra-europeizzata": "ultra-europeizzato",
    "ultra-europeizzate": "ultra-europeizzato",
    "ultra-europeizzati": "ultra-europeizzato",
    "ultra-nazionaliste": "ultra-nazionalista",
    "ultra-nazionalisti": "ultra-nazionalista",
    "ultraconservatori": "ultraconservatore",
    "ultracorta": "ultracorto",
    "ultracorte": "ultracorto",
    "ultracorti": "ultracorto",
    "ultramoderna": "ultramoderno",
    "ultramoderne": "ultramoderno",
    "ultramoderni": "ultramoderno",
    "ultranazionalisti": "ultranazionalista",
    "ultraortodossi": "ultraortodosso",
    "ultrarapida": "ultrarapido",
    "ultrarapide": "ultrarapido",
    "ultrarapidi": "ultrarapido",
    "ultrasensibili": "ultrasensibile",
    "ultrasuoni": "ultrasuono",
    "ultraterrena": "ultraterreno",
    "ultraterrene": "ultraterreno",
    "ultraterreni": "ultraterreno",
    "ultravioletta": "ultravioletto",
    "ultraviolette": "ultravioletto",
    "ultravioletti": "ultravioletto",
    "ultre": "ultro",
    "ultri": "ultro",
    "ulula": "ululare",
    "ululai": "ululare",
    "ululammo": "ululare",
    "ululan": "ululare",
    "ululando": "ululare",
    "ululano": "ululare",
    "ululante": "ululare",
    "ululanti": "ululare",
    "ulular": "ululare",
    "ulularon": "ululare",
    "ulularono": "ululare",
    "ululasse": "ululare",
    "ululasser": "ululare",
    "ululassero": "ululare",
    "ululassi": "ululare",
    "ululassimo": "ululare",
    "ululaste": "ululare",
    "ululasti": "ululare",
    "ululata": "ululare",
    "ululate": "ululare",
    "ululati": "ululato",
    "ululato": "ululare",
    "ululava": "ululare",
    "ululavamo": "ululare",
    "ululavan": "ululare",
    "ululavano": "ululare",
    "ululavate": "ululare",
    "ululavi": "ululare",
    "ululavo": "ululare",
    "ululerai": "ululare",
    "ululeran": "ululare",
    "ululeranno": "ululare",
    "ululerebbe": "ululare",
    "ululerebber": "ululare",
    "ululerebbero": "ululare",
    "ululerei": "ululare",
    "ululeremmo": "ululare",
    "ululeremo": "ululare",
    "ululereste": "ululare",
    "ululeresti": "ululare",
    "ululerete": "ululare",
    "ululerà": "ululare",
    "ululerò": "ululare",
    "ululi": "ululare",
    "ululiamo": "ululare",
    "ululiate": "ululare",
    "ululin": "ululare",
    "ululino": "ululare",
    "ululo": "ululare",
    "ululò": "ululare",
    "umana": "umano",
    "umane": "umano",
    "umanesimi": "umanesimo",
    "umani": "umano",
    "umaniste": "umanista",
    "umanisti": "umanista",
    "umanistica": "umanistico",
    "umanistiche": "umanistico",
    "umanistici": "umanistico",
    "umanitari": "umanitario",
    "umanitaria": "umanitario",
    "umanitarie": "umanitario",
    "umanizza": "umanizzare",
    "umanizzai": "umanizzare",
    "umanizzammo": "umanizzare",
    "umanizzan": "umanizzare",
    "umanizzando": "umanizzare",
    "umanizzano": "umanizzare",
    "umanizzante": "umanizzare",
    "umanizzanti": "umanizzare",
    "umanizzar": "umanizzare",
    "umanizzaron": "umanizzare",
    "umanizzarono": "umanizzare",
    "umanizzasse": "umanizzare",
    "umanizzasser": "umanizzare",
    "umanizzassero": "umanizzare",
    "umanizzassi": "umanizzare",
    "umanizzassimo": "umanizzare",
    "umanizzaste": "umanizzare",
    "umanizzasti": "umanizzare",
    "umanizzata": "umanizzare",
    "umanizzate": "umanizzare",
    "umanizzati": "umanizzare",
    "umanizzato": "umanizzare",
    "umanizzava": "umanizzare",
    "umanizzavamo": "umanizzare",
    "umanizzavan": "umanizzare",
    "umanizzavano": "umanizzare",
    "umanizzavate": "umanizzare",
    "umanizzavi": "umanizzare",
    "umanizzavo": "umanizzare",
    "umanizzazioni": "umanizzazione",
    "umanizzerai": "umanizzare",
    "umanizzeran": "umanizzare",
    "umanizzeranno": "umanizzare",
    "umanizzerebbe": "umanizzare",
    "umanizzerebber": "umanizzare",
    "umanizzerebbero": "umanizzare",
    "umanizzerei": "umanizzare",
    "umanizzeremmo": "umanizzare",
    "umanizzeremo": "umanizzare",
    "umanizzereste": "umanizzare",
    "umanizzeresti": "umanizzare",
    "umanizzerete": "umanizzare",
    "umanizzerà": "umanizzare",
    "umanizzerò": "umanizzare",
    "umanizzi": "umanizzare",
    "umanizziamo": "umanizzare",
    "umanizziate": "umanizzare",
    "umanizzin": "umanizzare",
    "umanizzino": "umanizzare",
    "umanizzo": "umanizzare",
    "umanizzò": "umanizzare",
    "umanoidi": "umanoide",
    "umbertina": "umbertino",
    "umbertine": "umbertino",
    "umbertini": "umbertino",
    "umbra": "umbro",
    "umbratili": "umbratile",
    "umbre": "umbro",
    "umbri": "umbro",
    "umetta": "umettare",
    "umettai": "umettare",
    "umettammo": "umettare",
    "umettan": "umettare",
    "umettando": "umettare",
    "umettano": "umettare",
    "umettante": "umettare",
    "umettanti": "umettare",
    "umettar": "umettare",
    "umettaron": "umettare",
    "umettarono": "umettare",
    "umettasse": "umettare",
    "umettasser": "umettare",
    "umettassero": "umettare",
    "umettassi": "umettare",
    "umettassimo": "umettare",
    "umettaste": "umettare",
    "umettasti": "umettare",
    "umettata": "umettare",
    "umettate": "umettare",
    "umettati": "umettare",
    "umettato": "umettare",
    "umettava": "umettare",
    "umettavamo": "umettare",
    "umettavan": "umettare",
    "umettavano": "umettare",
    "umettavate": "umettare",
    "umettavi": "umettare",
    "umettavo": "umettare",
    "umetterai": "umettare",
    "umetteran": "umettare",
    "umetteranno": "umettare",
    "umetterebbe": "umettare",
    "umetterebber": "umettare",
    "umetterebbero": "umettare",
    "umetterei": "umettare",
    "umetteremmo": "umettare",
    "umetteremo": "umettare",
    "umettereste": "umettare",
    "umetteresti": "umettare",
    "umetterete": "umettare",
    "umetterà": "umettare",
    "umetterò": "umettare",
    "umetti": "umettare",
    "umettiamo": "umettare",
    "umettiate": "umettare",
    "umettin": "umettare",
    "umettino": "umettare",
    "umetto": "umettare",
    "umettò": "umettare",
    "umida": "umido",
    "umide": "umido",
    "umidi": "umido",
    "umidicce": "umidiccio",
    "umidicci": "umidiccio",
    "umidiccia": "umidiccio",
    "umidifica": "umidificare",
    "umidificai": "umidificare",
    "umidificammo": "umidificare",
    "umidifican": "umidificare",
    "umidificando": "umidificare",
    "umidificano": "umidificare",
    "umidificante": "umidificare",
    "umidificanti": "umidificare",
    "umidificar": "umidificare",
    "umidificaron": "umidificare",
    "umidificarono": "umidificare",
    "umidificasse": "umidificare",
    "umidificasser": "umidificare",
    "umidificassero": "umidificare",
    "umidificassi": "umidificare",
    "umidificassimo": "umidificare",
    "umidificaste": "umidificare",
    "umidificasti": "umidificare",
    "umidificata": "umidificare",
    "umidificate": "umidificare",
    "umidificati": "umidificare",
    "umidificato": "umidificare",
    "umidificava": "umidificare",
    "umidificavamo": "umidificare",
    "umidificavan": "umidificare",
    "umidificavano": "umidificare",
    "umidificavate": "umidificare",
    "umidificavi": "umidificare",
    "umidificavo": "umidificare",
    "umidificherai": "umidificare",
    "umidificheran": "umidificare",
    "umidificheranno": "umidificare",
    "umidificherebbe": "umidificare",
    "umidificherebber": "umidificare",
    "umidificherebbero": "umidificare",
    "umidificherei": "umidificare",
    "umidificheremmo": "umidificare",
    "umidificheremo": "umidificare",
    "umidifichereste": "umidificare",
    "umidificheresti": "umidificare",
    "umidificherete": "umidificare",
    "umidificherà": "umidificare",
    "umidificherò": "umidificare",
    "umidifichi": "umidificare",
    "umidifichiamo": "umidificare",
    "umidifichiate": "umidificare",
    "umidifichin": "umidificare",
    "umidifichino": "umidificare",
    "umidifico": "umidificare",
    "umidificò": "umidificare",
    "umili": "umiliare",
    "umilia": "umiliare",
    "umiliai": "umiliare",
    "umiliammo": "umiliare",
    "umiliamo": "umiliare",
    "umilian": "umiliare",
    "umiliando": "umiliare",
    "umiliano": "umiliare",
    "umiliante": "umiliare",
    "umilianti": "umiliare",
    "umiliar": "umiliare",
    "umiliaron": "umiliare",
    "umiliarono": "umiliare",
    "umiliasse": "umiliare",
    "umiliasser": "umiliare",
    "umiliassero": "umiliare",
    "umiliassi": "umiliare",
    "umiliassimo": "umiliare",
    "umiliaste": "umiliare",
    "umiliasti": "umiliare",
    "umiliata": "umiliare",
    "umiliate": "umiliare",
    "umiliati": "umiliare",
    "umiliato": "umiliare",
    "umiliava": "umiliare",
    "umiliavamo": "umiliare",
    "umiliavan": "umiliare",
    "umiliavano": "umiliare",
    "umiliavate": "umiliare",
    "umiliavi": "umiliare",
    "umiliavo": "umiliare",
    "umiliazioni": "umiliazione",
    "umilierai": "umiliare",
    "umilieran": "umiliare",
    "umilieranno": "umiliare",
    "umilierebbe": "umiliare",
    "umilierebber": "umiliare",
    "umilierebbero": "umiliare",
    "umilierei": "umiliare",
    "umilieremmo": "umiliare",
    "umilieremo": "umiliare",
    "umiliereste": "umiliare",
    "umilieresti": "umiliare",
    "umilierete": "umiliare",
    "umilierà": "umiliare",
    "umilierò": "umiliare",
    "umilin": "umiliare",
    "umilino": "umiliare",
    "umilio": "umiliare",
    "umiliò": "umiliare",
    "umori": "umore",
    "umorismi": "umorismo",
    "umoristi": "umorista",
    "umoristica": "umoristico",
    "umoristiche": "umoristico",
    "umoristici": "umoristico",
    "un'": "una",
    "unanimi": "unanime",
    "unanimismi": "unanimismo",
    "uncina": "uncinare",
    "uncinai": "uncinare",
    "uncinammo": "uncinare",
    "uncinan": "uncinare",
    "uncinando": "uncinare",
    "uncinano": "uncinare",
    "uncinante": "uncinare",
    "uncinanti": "uncinare",
    "uncinar": "uncinare",
    "uncinaron": "uncinare",
    "uncinarono": "uncinare",
    "uncinasse": "uncinare",
    "uncinasser": "uncinare",
    "uncinassero": "uncinare",
    "uncinassi": "uncinare",
    "uncinassimo": "uncinare",
    "uncinaste": "uncinare",
    "uncinasti": "uncinare",
    "uncinata": "uncinato",
    "uncinate": "uncinato",
    "uncinati": "uncinato",
    "uncinato": "uncinare",
    "uncinava": "uncinare",
    "uncinavamo": "uncinare",
    "uncinavan": "uncinare",
    "uncinavano": "uncinare",
    "uncinavate": "uncinare",
    "uncinavi": "uncinare",
    "uncinavo": "uncinare",
    "uncinerai": "uncinare",
    "uncineran": "uncinare",
    "uncineranno": "uncinare",
    "uncinerebbe": "uncinare",
    "uncinerebber": "uncinare",
    "uncinerebbero": "uncinare",
    "uncinerei": "uncinare",
    "uncineremmo": "uncinare",
    "uncineremo": "uncinare",
    "uncinereste": "uncinare",
    "uncineresti": "uncinare",
    "uncinerete": "uncinare",
    "uncinerà": "uncinare",
    "uncinerò": "uncinare",
    "uncini": "uncino",
    "unciniamo": "uncinare",
    "unciniate": "uncinare",
    "uncinin": "uncinare",
    "uncinino": "uncinare",
    "uncino": "uncinare",
    "uncinò": "uncinare",
    "undecima": "undecimo",
    "undecime": "undecimo",
    "undecimi": "undecimo",
    "undicenni": "undicenne",
    "undicesima": "undicesimo",
    "undicesime": "undicesimo",
    "undicesimi": "undicesimo",
    "undicimillesima": "undicimillesimo",
    "undicimillesime": "undicimillesimo",
    "undicimillesimi": "undicimillesimo",
    "unendo": "unire",
    "unente": "unire",
    "unenti": "unire",
    "unga": "ungere",
    "ungan": "ungere",
    "ungano": "ungere",
    "ungarettiana": "ungarettiano",
    "ungarettiane": "ungarettiano",
    "ungarettiani": "ungarettiano",
    "unge": "ungere",
    "ungemmo": "ungere",
    "ungendo": "ungere",
    "ungente": "ungere",
    "ungenti": "ungere",
    "unger": "ungere",
    "ungerai": "ungere",
    "ungeran": "ungere",
    "ungeranno": "ungere",
    "ungerebbe": "ungere",
    "ungerebber": "ungere",
    "ungerebbero": "ungere",
    "ungerei": "ungere",
    "ungeremmo": "ungere",
    "ungeremo": "ungere",
    "ungereste": "ungere",
    "ungeresti": "ungere",
    "ungerete": "ungere",
    "ungerà": "ungere",
    "ungerò": "ungere",
    "ungesse": "ungere",
    "ungesser": "ungere",
    "ungessero": "ungere",
    "ungessi": "ungere",
    "ungessimo": "ungere",
    "ungeste": "ungere",
    "ungesti": "ungere",
    "ungete": "ungere",
    "ungeva": "ungere",
    "ungevamo": "ungere",
    "ungevan": "ungere",
    "ungevano": "ungere",
    "ungevate": "ungere",
    "ungevi": "ungere",
    "ungevo": "ungere",
    "ungheresi": "ungherese",
    "unghiate": "unghiata",
    "unghie": "unghia",
    "ungi": "ungere",
    "ungiamo": "ungere",
    "ungiate": "ungere",
    "ungo": "ungere",
    "ungon": "ungere",
    "ungono": "ungere",
    "unguenti": "unguento",
    "uni": "uno",
    "uniamo": "unire",
    "uniate": "unire",
    "unica": "unico",
    "unicamerali": "unicamerale",
    "unicellulari": "unicellulare",
    "uniche": "unico",
    "unici": "unico",
    "unidirezionali": "unidirezionale",
    "unifamiliari": "unifamiliare",
    "unifica": "unificare",
    "unificai": "unificare",
    "unificammo": "unificare",
    "unifican": "unificare",
    "unificando": "unificare",
    "unificano": "unificare",
    "unificante": "unificare",
    "unificanti": "unificare",
    "unificar": "unificare",
    "unificaron": "unificare",
    "unificarono": "unificare",
    "unificasse": "unificare",
    "unificasser": "unificare",
    "unificassero": "unificare",
    "unificassi": "unificare",
    "unificassimo": "unificare",
    "unificaste": "unificare",
    "unificasti": "unificare",
    "unificata": "unificato",
    "unificate": "unificato",
    "unificati": "unificato",
    "unificato": "unificare",
    "unificatori": "unificatore",
    "unificatrice": "unificatore",
    "unificatrici": "unificatore",
    "unificava": "unificare",
    "unificavamo": "unificare",
    "unificavan": "unificare",
    "unificavano": "unificare",
    "unificavate": "unificare",
    "unificavi": "unificare",
    "unificavo": "unificare",
    "unificazioni": "unificazione",
    "unificherai": "unificare",
    "unificheran": "unificare",
    "unificheranno": "unificare",
    "unificherebbe": "unificare",
    "unificherebber": "unificare",
    "unificherebbero": "unificare",
    "unificherei": "unificare",
    "unificheremmo": "unificare",
    "unificheremo": "unificare",
    "unifichereste": "unificare",
    "unificheresti": "unificare",
    "unificherete": "unificare",
    "unificherà": "unificare",
    "unificherò": "unificare",
    "unifichi": "unificare",
    "unifichiamo": "unificare",
    "unifichiate": "unificare",
    "unifichin": "unificare",
    "unifichino": "unificare",
    "unifico": "unificare",
    "unificò": "unificare",
    "uniforma": "uniformare",
    "uniformai": "uniformare",
    "uniformammo": "uniformare",
    "uniforman": "uniformare",
    "uniformando": "uniformare",
    "uniformano": "uniformare",
    "uniformante": "uniformare",
    "uniformanti": "uniformare",
    "uniformar": "uniformare",
    "uniformaron": "uniformare",
    "uniformarono": "uniformare",
    "uniformasse": "uniformare",
    "uniformasser": "uniformare",
    "uniformassero": "uniformare",
    "uniformassi": "uniformare",
    "uniformassimo": "uniformare",
    "uniformaste": "uniformare",
    "uniformasti": "uniformare",
    "uniformata": "uniformare",
    "uniformate": "uniformare",
    "uniformati": "uniformare",
    "uniformato": "uniformare",
    "uniformava": "uniformare",
    "uniformavamo": "uniformare",
    "uniformavan": "uniformare",
    "uniformavano": "uniformare",
    "uniformavate": "uniformare",
    "uniformavi": "uniformare",
    "uniformavo": "uniformare",
    "uniformerai": "uniformare",
    "uniformeran": "uniformare",
    "uniformeranno": "uniformare",
    "uniformerebbe": "uniformare",
    "uniformerebber": "uniformare",
    "uniformerebbero": "uniformare",
    "uniformerei": "uniformare",
    "uniformeremmo": "uniformare",
    "uniformeremo": "uniformare",
    "uniformereste": "uniformare",
    "uniformeresti": "uniformare",
    "uniformerete": "uniformare",
    "uniformerà": "uniformare",
    "uniformerò": "uniformare",
    "uniformi": "uniforme",
    "uniformiamo": "uniformare",
    "uniformiate": "uniformare",
    "uniformin": "uniformare",
    "uniformino": "uniformare",
    "uniformo": "uniformare",
    "uniformò": "uniformare",
    "unii": "unire",
    "unilaterali": "unilaterale",
    "unimmo": "unire",
    "uninominali": "uninominale",
    "unioni": "unione",
    "unionista": "unionisto",
    "unioniste": "unionisto",
    "unionisti": "unionisto",
    "unir": "unire",
    "unirai": "unire",
    "uniran": "unire",
    "uniranno": "unire",
    "unirebbe": "unire",
    "unirebber": "unire",
    "unirebbero": "unire",
    "unirei": "unire",
    "uniremmo": "unire",
    "uniremo": "unire",
    "unireste": "unire",
    "uniresti": "unire",
    "unirete": "unire",
    "uniron": "unire",
    "unirono": "unire",
    "unirà": "unire",
    "unirò": "unire",
    "unisca": "unire",
    "uniscan": "unire",
    "uniscano": "unire",
    "unisce": "unire",
    "unisci": "unire",
    "unisco": "unire",
    "uniscon": "unire",
    "uniscono": "unire",
    "unisona": "unisono",
    "unisone": "unisono",
    "unisoni": "unisono",
    "unisse": "unire",
    "unisser": "unire",
    "unissero": "unire",
    "unissi": "unire",
    "unissimo": "unire",
    "uniste": "unire",
    "unisti": "unire",
    "unita": "unito",
    "unitari": "unitario",
    "unitaria": "unitario",
    "unitarie": "unitario",
    "unite": "unito",
    "uniti": "unito",
    "unito": "unire",
    "univa": "unire",
    "univamo": "unire",
    "univan": "unire",
    "univano": "unire",
    "univate": "unire",
    "universa": "universo",
    "universali": "universale",
    "universalistica": "universalistico",
    "universalistiche": "universalistico",
    "universalistici": "universalistico",
    "universalizza": "universalizzare",
    "universalizzai": "universalizzare",
    "universalizzammo": "universalizzare",
    "universalizzan": "universalizzare",
    "universalizzando": "universalizzare",
    "universalizzano": "universalizzare",
    "universalizzante": "universalizzare",
    "universalizzanti": "universalizzare",
    "universalizzar": "universalizzare",
    "universalizzaron": "universalizzare",
    "universalizzarono": "universalizzare",
    "universalizzasse": "universalizzare",
    "universalizzasser": "universalizzare",
    "universalizzassero": "universalizzare",
    "universalizzassi": "universalizzare",
    "universalizzassimo": "universalizzare",
    "universalizzaste": "universalizzare",
    "universalizzasti": "universalizzare",
    "universalizzata": "universalizzare",
    "universalizzate": "universalizzare",
    "universalizzati": "universalizzare",
    "universalizzato": "universalizzare",
    "universalizzava": "universalizzare",
    "universalizzavamo": "universalizzare",
    "universalizzavan": "universalizzare",
    "universalizzavano": "universalizzare",
    "universalizzavate": "universalizzare",
    "universalizzavi": "universalizzare",
    "universalizzavo": "universalizzare",
    "universalizzerai": "universalizzare",
    "universalizzeran": "universalizzare",
    "universalizzeranno": "universalizzare",
    "universalizzerebbe": "universalizzare",
    "universalizzerebber": "universalizzare",
    "universalizzerebbero": "universalizzare",
    "universalizzerei": "universalizzare",
    "universalizzeremmo": "universalizzare",
    "universalizzeremo": "universalizzare",
    "universalizzereste": "universalizzare",
    "universalizzeresti": "universalizzare",
    "universalizzerete": "universalizzare",
    "universalizzerà": "universalizzare",
    "universalizzerò": "universalizzare",
    "universalizzi": "universalizzare",
    "universalizziamo": "universalizzare",
    "universalizziate": "universalizzare",
    "universalizzin": "universalizzare",
    "universalizzino": "universalizzare",
    "universalizzo": "universalizzare",
    "universalizzò": "universalizzare",
    "universe": "universo",
    "universi": "universo",
    "universitari": "universitario",
    "universitaria": "universitario",
    "universitarie": "universitario",
    "univi": "unire",
    "univo": "unire",
    "univoca": "univoco",
    "univoche": "univoco",
    "univoci": "univoco",
    "uno": "un",
    "unser": "ungere",
    "unsero": "ungere",
    "unsi": "ungere",
    "unsè": "ungere",
    "unta": "unto",
    "unte": "unto",
    "unti": "unto",
    "unto": "ungere",
    "untori": "untore",
    "untuosa": "untuoso",
    "untuose": "untuoso",
    "untuosi": "untuoso",
    "unzioni": "unzione",
    "unì": "unire",
    "uomini-radar": "uomo-radar",
    "uova": "uovo",
    "uragani": "uragano",
    "urbana": "urbano",
    "urbane": "urbano",
    "urbani": "urbano",
    "urbanisti": "urbanista",
    "urbanistica": "urbanistico",
    "urbanistiche": "urbanistico",
    "urbanistici": "urbanistico",
    "urbanizza": "urbanizzare",
    "urbanizzai": "urbanizzare",
    "urbanizzammo": "urbanizzare",
    "urbanizzan": "urbanizzare",
    "urbanizzando": "urbanizzare",
    "urbanizzano": "urbanizzare",
    "urbanizzante": "urbanizzare",
    "urbanizzanti": "urbanizzare",
    "urbanizzar": "urbanizzare",
    "urbanizzaron": "urbanizzare",
    "urbanizzarono": "urbanizzare",
    "urbanizzasse": "urbanizzare",
    "urbanizzasser": "urbanizzare",
    "urbanizzassero": "urbanizzare",
    "urbanizzassi": "urbanizzare",
    "urbanizzassimo": "urbanizzare",
    "urbanizzaste": "urbanizzare",
    "urbanizzasti": "urbanizzare",
    "urbanizzata": "urbanizzare",
    "urbanizzate": "urbanizzare",
    "urbanizzati": "urbanizzare",
    "urbanizzato": "urbanizzare",
    "urbanizzava": "urbanizzare",
    "urbanizzavamo": "urbanizzare",
    "urbanizzavan": "urbanizzare",
    "urbanizzavano": "urbanizzare",
    "urbanizzavate": "urbanizzare",
    "urbanizzavi": "urbanizzare",
    "urbanizzavo": "urbanizzare",
    "urbanizzazioni": "urbanizzazione",
    "urbanizzerai": "urbanizzare",
    "urbanizzeran": "urbanizzare",
    "urbanizzeranno": "urbanizzare",
    "urbanizzerebbe": "urbanizzare",
    "urbanizzerebber": "urbanizzare",
    "urbanizzerebbero": "urbanizzare",
    "urbanizzerei": "urbanizzare",
    "urbanizzeremmo": "urbanizzare",
    "urbanizzeremo": "urbanizzare",
    "urbanizzereste": "urbanizzare",
    "urbanizzeresti": "urbanizzare",
    "urbanizzerete": "urbanizzare",
    "urbanizzerà": "urbanizzare",
    "urbanizzerò": "urbanizzare",
    "urbanizzi": "urbanizzare",
    "urbanizziamo": "urbanizzare",
    "urbanizziate": "urbanizzare",
    "urbanizzin": "urbanizzare",
    "urbanizzino": "urbanizzare",
    "urbanizzo": "urbanizzare",
    "urbanizzò": "urbanizzare",
    "urga": "urgere",
    "urgan": "urgere",
    "urgano": "urgere",
    "urge": "urgere",
    "urgemmo": "urgere",
    "urgendo": "urgere",
    "urgente": "urgere",
    "urgenti": "urgere",
    "urgenze": "urgenza",
    "urger": "urgere",
    "urgerai": "urgere",
    "urgeran": "urgere",
    "urgeranno": "urgere",
    "urgerebbe": "urgere",
    "urgerebber": "urgere",
    "urgerebbero": "urgere",
    "urgerei": "urgere",
    "urgeremmo": "urgere",
    "urgeremo": "urgere",
    "urgereste": "urgere",
    "urgeresti": "urgere",
    "urgerete": "urgere",
    "urgerà": "urgere",
    "urgerò": "urgere",
    "urgesse": "urgere",
    "urgesser": "urgere",
    "urgessero": "urgere",
    "urgessi": "urgere",
    "urgessimo": "urgere",
    "urgeste": "urgere",
    "urgesti": "urgere",
    "urgete": "urgere",
    "urgeva": "urgere",
    "urgevamo": "urgere",
    "urgevan": "urgere",
    "urgevano": "urgere",
    "urgevate": "urgere",
    "urgevi": "urgere",
    "urgevo": "urgere",
    "urgi": "urgere",
    "urgiamo": "urgere",
    "urgiate": "urgere",
    "urgo": "urgere",
    "urgon": "urgere",
    "urgono": "urgere",
    "urica": "urico",
    "uriche": "urico",
    "urici": "urico",
    "urina": "urinare",
    "urinai": "urinare",
    "urinammo": "urinare",
    "urinan": "urinare",
    "urinando": "urinare",
    "urinano": "urinare",
    "urinante": "urinare",
    "urinanti": "urinare",
    "urinar": "urinare",
    "urinari": "urinario",
    "urinaria": "urinario",
    "urinarie": "urinario",
    "urinaron": "urinare",
    "urinarono": "urinare",
    "urinasse": "urinare",
    "urinasser": "urinare",
    "urinassero": "urinare",
    "urinassi": "urinare",
    "urinassimo": "urinare",
    "urinaste": "urinare",
    "urinasti": "urinare",
    "urinata": "urinare",
    "urinate": "urinare",
    "urinati": "urinare",
    "urinato": "urinare",
    "urinava": "urinare",
    "urinavamo": "urinare",
    "urinavan": "urinare",
    "urinavano": "urinare",
    "urinavate": "urinare",
    "urinavi": "urinare",
    "urinavo": "urinare",
    "urine": "urina",
    "urinerai": "urinare",
    "urineran": "urinare",
    "urineranno": "urinare",
    "urinerebbe": "urinare",
    "urinerebber": "urinare",
    "urinerebbero": "urinare",
    "urinerei": "urinare",
    "urineremmo": "urinare",
    "urineremo": "urinare",
    "urinereste": "urinare",
    "urineresti": "urinare",
    "urinerete": "urinare",
    "urinerà": "urinare",
    "urinerò": "urinare",
    "urini": "urinare",
    "uriniamo": "urinare",
    "uriniate": "urinare",
    "urinin": "urinare",
    "urinino": "urinare",
    "urino": "urinare",
    "urinò": "urinare",
    "urla": "urlo",
    "urlacci": "urlaccio",
    "urlai": "urlare",
    "urlammo": "urlare",
    "urlan": "urlare",
    "urlando": "urlare",
    "urlano": "urlare",
    "urlante": "urlare",
    "urlanti": "urlare",
    "urlar": "urlare",
    "urlaron": "urlare",
    "urlarono": "urlare",
    "urlasse": "urlare",
    "urlasser": "urlare",
    "urlassero": "urlare",
    "urlassi": "urlare",
    "urlassimo": "urlare",
    "urlaste": "urlare",
    "urlasti": "urlare",
    "urlata": "urlare",
    "urlate": "urlare",
    "urlati": "urlare",
    "urlato": "urlare",
    "urlatori": "urlatore",
    "urlatrice": "urlatore",
    "urlatrici": "urlatore",
    "urlava": "urlare",
    "urlavamo": "urlare",
    "urlavan": "urlare",
    "urlavano": "urlare",
    "urlavate": "urlare",
    "urlavi": "urlare",
    "urlavo": "urlare",
    "urlerai": "urlare",
    "urleran": "urlare",
    "urleranno": "urlare",
    "urlerebbe": "urlare",
    "urlerebber": "urlare",
    "urlerebbero": "urlare",
    "urlerei": "urlare",
    "urleremmo": "urlare",
    "urleremo": "urlare",
    "urlereste": "urlare",
    "urleresti": "urlare",
    "urlerete": "urlare",
    "urlerà": "urlare",
    "urlerò": "urlare",
    "urletti": "urletto",
    "urli": "urlare",
    "urliamo": "urlare",
    "urliate": "urlare",
    "urlin": "urlare",
    "urlino": "urlare",
    "urlo": "urlare",
    "urlò": "urlare",
    "urne": "urna",
    "urogenitali": "urogenitale",
    "urologi": "urologo",
    "urologica": "urologico",
    "urologiche": "urologico",
    "urologici": "urologico",
    "urser": "urgere",
    "ursero": "urgere",
    "ursi": "urgere",
    "ursè": "urgere",
    "urta": "urto",
    "urtai": "urtare",
    "urtammo": "urtare",
    "urtan": "urtare",
    "urtando": "urtare",
    "urtano": "urtare",
    "urtante": "urtare",
    "urtanti": "urtare",
    "urtar": "urtare",
    "urtaron": "urtare",
    "urtarono": "urtare",
    "urtasse": "urtare",
    "urtasser": "urtare",
    "urtassero": "urtare",
    "urtassi": "urtare",
    "urtassimo": "urtare",
    "urtaste": "urtare",
    "urtasti": "urtare",
    "urtata": "urtare",
    "urtate": "urtare",
    "urtati": "urtare",
    "urtato": "urtare",
    "urtava": "urtare",
    "urtavamo": "urtare",
    "urtavan": "urtare",
    "urtavano": "urtare",
    "urtavate": "urtare",
    "urtavi": "urtare",
    "urtavo": "urtare",
    "urte": "urto",
    "urterai": "urtare",
    "urteran": "urtare",
    "urteranno": "urtare",
    "urterebbe": "urtare",
    "urterebber": "urtare",
    "urterebbero": "urtare",
    "urterei": "urtare",
    "urteremmo": "urtare",
    "urteremo": "urtare",
    "urtereste": "urtare",
    "urteresti": "urtare",
    "urterete": "urtare",
    "urterà": "urtare",
    "urterò": "urtare",
    "urti": "urto",
    "urtiamo": "urtare",
    "urtiate": "urtare",
    "urtin": "urtare",
    "urtino": "urtare",
    "urto": "urtare",
    "urtò": "urtare",
    "uruguagi": "uruguagio",
    "uruguagia": "uruguagio",
    "uruguagie": "uruguagio",
    "uruguayana": "uruguayano",
    "uruguayane": "uruguayano",
    "uruguayani": "uruguayano",
    "usa": "uso",
    "usai": "usare",
    "usammo": "usare",
    "usan": "usare",
    "usando": "usare",
    "usano": "usare",
    "usante": "usare",
    "usanti": "usare",
    "usanze": "usanza",
    "usar": "usare",
    "usaron": "usare",
    "usarono": "usare",
    "usasse": "usare",
    "usasser": "usare",
    "usassero": "usare",
    "usassi": "usare",
    "usassimo": "usare",
    "usaste": "usare",
    "usasti": "usare",
    "usata": "usato",
    "usate": "usato",
    "usati": "usato",
    "usato": "usare",
    "usava": "usare",
    "usavamo": "usare",
    "usavan": "usare",
    "usavano": "usare",
    "usavate": "usare",
    "usavi": "usare",
    "usavo": "usare",
    "uscendo": "uscire",
    "uscente": "uscire",
    "uscenti": "uscire",
    "usci": "uscio",
    "usciamo": "uscire",
    "usciate": "uscire",
    "uscieri": "usciere",
    "uscii": "uscire",
    "uscimmo": "uscire",
    "uscir": "uscire",
    "uscirai": "uscire",
    "usciran": "uscire",
    "usciranno": "uscire",
    "uscirebbe": "uscire",
    "uscirebber": "uscire",
    "uscirebbero": "uscire",
    "uscirei": "uscire",
    "usciremmo": "uscire",
    "usciremo": "uscire",
    "uscireste": "uscire",
    "usciresti": "uscire",
    "uscirete": "uscire",
    "usciron": "uscire",
    "uscirono": "uscire",
    "uscirà": "uscire",
    "uscirò": "uscire",
    "uscisse": "uscire",
    "uscisser": "uscire",
    "uscissero": "uscire",
    "uscissi": "uscire",
    "uscissimo": "uscire",
    "usciste": "uscire",
    "uscisti": "uscire",
    "uscita": "uscire",
    "uscite": "uscita",
    "usciti": "uscire",
    "uscito": "uscire",
    "usciva": "uscire",
    "uscivamo": "uscire",
    "uscivan": "uscire",
    "uscivano": "uscire",
    "uscivate": "uscire",
    "uscivi": "uscire",
    "uscivo": "uscire",
    "uscì": "uscire",
    "use": "uso",
    "userai": "usare",
    "useran": "usare",
    "useranno": "usare",
    "userebbe": "usare",
    "userebber": "usare",
    "userebbero": "usare",
    "userei": "usare",
    "useremmo": "usare",
    "useremo": "usare",
    "usereste": "usare",
    "useresti": "usare",
    "userete": "usare",
    "userà": "usare",
    "userò": "usare",
    "usi": "uso",
    "usiamo": "usare",
    "usiate": "usare",
    "usignoli": "usignolo",
    "usin": "usare",
    "usino": "usare",
    "uso": "usare",
    "ussari": "ussaro",
    "usta": "usto",
    "uste": "usto",
    "usti": "usto",
    "ustiona": "ustionare",
    "ustionai": "ustionare",
    "ustionammo": "ustionare",
    "ustionan": "ustionare",
    "ustionando": "ustionare",
    "ustionano": "ustionare",
    "ustionante": "ustionare",
    "ustionanti": "ustionare",
    "ustionar": "ustionare",
    "ustionaron": "ustionare",
    "ustionarono": "ustionare",
    "ustionasse": "ustionare",
    "ustionasser": "ustionare",
    "ustionassero": "ustionare",
    "ustionassi": "ustionare",
    "ustionassimo": "ustionare",
    "ustionaste": "ustionare",
    "ustionasti": "ustionare",
    "ustionata": "ustionato",
    "ustionate": "ustionato",
    "ustionati": "ustionato",
    "ustionato": "ustionare",
    "ustionava": "ustionare",
    "ustionavamo": "ustionare",
    "ustionavan": "ustionare",
    "ustionavano": "ustionare",
    "ustionavate": "ustionare",
    "ustionavi": "ustionare",
    "ustionavo": "ustionare",
    "ustionerai": "ustionare",
    "ustioneran": "ustionare",
    "ustioneranno": "ustionare",
    "ustionerebbe": "ustionare",
    "ustionerebber": "ustionare",
    "ustionerebbero": "ustionare",
    "ustionerei": "ustionare",
    "ustioneremmo": "ustionare",
    "ustioneremo": "ustionare",
    "ustionereste": "ustionare",
    "ustioneresti": "ustionare",
    "ustionerete": "ustionare",
    "ustionerà": "ustionare",
    "ustionerò": "ustionare",
    "ustioni": "ustione",
    "ustioniamo": "ustionare",
    "ustioniate": "ustionare",
    "ustionin": "ustionare",
    "ustionino": "ustionare",
    "ustiono": "ustionare",
    "ustionò": "ustionare",
    "usuali": "usuale",
    "usufruendo": "usufruire",
    "usufruente": "usufruire",
    "usufruenti": "usufruire",
    "usufruiamo": "usufruire",
    "usufruiate": "usufruire",
    "usufruii": "usufruire",
    "usufruimmo": "usufruire",
    "usufruir": "usufruire",
    "usufruirai": "usufruire",
    "usufruiran": "usufruire",
    "usufruiranno": "usufruire",
    "usufruirebbe": "usufruire",
    "usufruirebber": "usufruire",
    "usufruirebbero": "usufruire",
    "usufruirei": "usufruire",
    "usufruiremmo": "usufruire",
    "usufruiremo": "usufruire",
    "usufruireste": "usufruire",
    "usufruiresti": "usufruire",
    "usufruirete": "usufruire",
    "usufruiron": "usufruire",
    "usufruirono": "usufruire",
    "usufruirà": "usufruire",
    "usufruirò": "usufruire",
    "usufruisca": "usufruire",
    "usufruiscan": "usufruire",
    "usufruiscano": "usufruire",
    "usufruisce": "usufruire",
    "usufruisci": "usufruire",
    "usufruisco": "usufruire",
    "usufruiscon": "usufruire",
    "usufruiscono": "usufruire",
    "usufruisse": "usufruire",
    "usufruisser": "usufruire",
    "usufruissero": "usufruire",
    "usufruissi": "usufruire",
    "usufruissimo": "usufruire",
    "usufruiste": "usufruire",
    "usufruisti": "usufruire",
    "usufruita": "usufruire",
    "usufruite": "usufruire",
    "usufruiti": "usufruire",
    "usufruito": "usufruire",
    "usufruiva": "usufruire",
    "usufruivamo": "usufruire",
    "usufruivan": "usufruire",
    "usufruivano": "usufruire",
    "usufruivate": "usufruire",
    "usufruivi": "usufruire",
    "usufruivo": "usufruire",
    "usufruì": "usufruire",
    "usura": "usurare",
    "usurai": "usurare",
    "usurammo": "usurare",
    "usuran": "usurare",
    "usurando": "usurare",
    "usurano": "usurare",
    "usurante": "usurare",
    "usuranti": "usurare",
    "usurar": "usurare",
    "usuraron": "usurare",
    "usurarono": "usurare",
    "usurasse": "usurare",
    "usurasser": "usurare",
    "usurassero": "usurare",
    "usurassi": "usurare",
    "usurassimo": "usurare",
    "usuraste": "usurare",
    "usurasti": "usurare",
    "usurata": "usurare",
    "usurate": "usurare",
    "usurati": "usurare",
    "usurato": "usurare",
    "usurava": "usurare",
    "usuravamo": "usurare",
    "usuravan": "usurare",
    "usuravano": "usurare",
    "usuravate": "usurare",
    "usuravi": "usurare",
    "usuravo": "usurare",
    "usure": "usura",
    "usurerai": "usurare",
    "usureran": "usurare",
    "usureranno": "usurare",
    "usurerebbe": "usurare",
    "usurerebber": "usurare",
    "usurerebbero": "usurare",
    "usurerei": "usurare",
    "usureremmo": "usurare",
    "usureremo": "usurare",
    "usurereste": "usurare",
    "usureresti": "usurare",
    "usurerete": "usurare",
    "usurerà": "usurare",
    "usurerò": "usurare",
    "usuri": "usurare",
    "usuriamo": "usurare",
    "usuriate": "usurare",
    "usurin": "usurare",
    "usurino": "usurare",
    "usuro": "usurare",
    "usurpa": "usurpare",
    "usurpai": "usurpare",
    "usurpammo": "usurpare",
    "usurpan": "usurpare",
    "usurpando": "usurpare",
    "usurpano": "usurpare",
    "usurpante": "usurpare",
    "usurpanti": "usurpare",
    "usurpar": "usurpare",
    "usurparon": "usurpare",
    "usurparono": "usurpare",
    "usurpasse": "usurpare",
    "usurpasser": "usurpare",
    "usurpassero": "usurpare",
    "usurpassi": "usurpare",
    "usurpassimo": "usurpare",
    "usurpaste": "usurpare",
    "usurpasti": "usurpare",
    "usurpata": "usurpare",
    "usurpate": "usurpare",
    "usurpati": "usurpare",
    "usurpato": "usurpare",
    "usurpatori": "usurpatorio",
    "usurpatoria": "usurpatorio",
    "usurpatorie": "usurpatorio",
    "usurpatrice": "usurpatore",
    "usurpatrici": "usurpatore",
    "usurpava": "usurpare",
    "usurpavamo": "usurpare",
    "usurpavan": "usurpare",
    "usurpavano": "usurpare",
    "usurpavate": "usurpare",
    "usurpavi": "usurpare",
    "usurpavo": "usurpare",
    "usurpazioni": "usurpazione",
    "usurperai": "usurpare",
    "usurperan": "usurpare",
    "usurperanno": "usurpare",
    "usurperebbe": "usurpare",
    "usurperebber": "usurpare",
    "usurperebbero": "usurpare",
    "usurperei": "usurpare",
    "usurperemmo": "usurpare",
    "usurperemo": "usurpare",
    "usurpereste": "usurpare",
    "usurperesti": "usurpare",
    "usurperete": "usurpare",
    "usurperà": "usurpare",
    "usurperò": "usurpare",
    "usurpi": "usurpare",
    "usurpiamo": "usurpare",
    "usurpiate": "usurpare",
    "usurpin": "usurpare",
    "usurpino": "usurpare",
    "usurpo": "usurpare",
    "usurpò": "usurpare",
    "usurò": "usurare",
    "usò": "usare",
    "utensili": "utensile",
    "utenti": "utente",
    "utenze": "utenza",
    "uteri": "utero",
    "utili": "utile",
    "utilitari": "utilitario",
    "utilitaria": "utilitario",
    "utilitarie": "utilitario",
    "utilitaristica": "utilitaristico",
    "utilitaristiche": "utilitaristico",
    "utilitaristici": "utilitaristico",
    "utilizza": "utilizzare",
    "utilizzabili": "utilizzabile",
    "utilizzai": "utilizzare",
    "utilizzammo": "utilizzare",
    "utilizzan": "utilizzare",
    "utilizzando": "utilizzare",
    "utilizzano": "utilizzare",
    "utilizzante": "utilizzare",
    "utilizzanti": "utilizzare",
    "utilizzar": "utilizzare",
    "utilizzaron": "utilizzare",
    "utilizzarono": "utilizzare",
    "utilizzasse": "utilizzare",
    "utilizzasser": "utilizzare",
    "utilizzassero": "utilizzare",
    "utilizzassi": "utilizzare",
    "utilizzassimo": "utilizzare",
    "utilizzaste": "utilizzare",
    "utilizzasti": "utilizzare",
    "utilizzata": "utilizzare",
    "utilizzate": "utilizzare",
    "utilizzati": "utilizzare",
    "utilizzato": "utilizzare",
    "utilizzatori": "utilizzatore",
    "utilizzava": "utilizzare",
    "utilizzavamo": "utilizzare",
    "utilizzavan": "utilizzare",
    "utilizzavano": "utilizzare",
    "utilizzavate": "utilizzare",
    "utilizzavi": "utilizzare",
    "utilizzavo": "utilizzare",
    "utilizzazioni": "utilizzazione",
    "utilizzerai": "utilizzare",
    "utilizzeran": "utilizzare",
    "utilizzeranno": "utilizzare",
    "utilizzerebbe": "utilizzare",
    "utilizzerebber": "utilizzare",
    "utilizzerebbero": "utilizzare",
    "utilizzerei": "utilizzare",
    "utilizzeremmo": "utilizzare",
    "utilizzeremo": "utilizzare",
    "utilizzereste": "utilizzare",
    "utilizzeresti": "utilizzare",
    "utilizzerete": "utilizzare",
    "utilizzerà": "utilizzare",
    "utilizzerò": "utilizzare",
    "utilizzi": "utilizzo",
    "utilizziamo": "utilizzare",
    "utilizziate": "utilizzare",
    "utilizzin": "utilizzare",
    "utilizzino": "utilizzare",
    "utilizzo": "utilizzare",
    "utilizzò": "utilizzare",
    "utopica": "utopico",
    "utopiche": "utopico",
    "utopici": "utopico",
    "utopie": "utopia",
    "utopisti": "utopista",
    "utopistica": "utopistico",
    "utopistiche": "utopistico",
    "utopistici": "utopistico",
    "utracentenari": "utracentenario",
    "utracentenaria": "utracentenario",
    "utracentenarie": "utracentenario",
    "uve": "uva",
    "uzbeki": "uzbeko",
    "va": "andare",
    "va'": "andare",
    "vaca": "vacare",
    "vacai": "vacare",
    "vacammo": "vacare",
    "vacan": "vacare",
    "vacando": "vacare",
    "vacano": "vacare",
    "vacante": "vacare",
    "vacanti": "vacare",
    "vacanze": "vacanza",
    "vacanzieri": "vacanziero",
    "vacar": "vacare",
    "vacaron": "vacare",
    "vacarono": "vacare",
    "vacasse": "vacare",
    "vacasser": "vacare",
    "vacassero": "vacare",
    "vacassi": "vacare",
    "vacassimo": "vacare",
    "vacaste": "vacare",
    "vacasti": "vacare",
    "vacata": "vacare",
    "vacate": "vacare",
    "vacati": "vacare",
    "vacationes": "vacatio",
    "vacato": "vacare",
    "vacava": "vacare",
    "vacavamo": "vacare",
    "vacavan": "vacare",
    "vacavano": "vacare",
    "vacavate": "vacare",
    "vacavi": "vacare",
    "vacavo": "vacare",
    "vacche": "vacca",
    "vaccina": "vaccinare",
    "vaccinai": "vaccinare",
    "vaccinammo": "vaccinare",
    "vaccinan": "vaccinare",
    "vaccinando": "vaccinare",
    "vaccinano": "vaccinare",
    "vaccinante": "vaccinare",
    "vaccinanti": "vaccinare",
    "vaccinar": "vaccinare",
    "vaccinaron": "vaccinare",
    "vaccinarono": "vaccinare",
    "vaccinasse": "vaccinare",
    "vaccinasser": "vaccinare",
    "vaccinassero": "vaccinare",
    "vaccinassi": "vaccinare",
    "vaccinassimo": "vaccinare",
    "vaccinaste": "vaccinare",
    "vaccinasti": "vaccinare",
    "vaccinata": "vaccinare",
    "vaccinate": "vaccinare",
    "vaccinati": "vaccinare",
    "vaccinato": "vaccinare",
    "vaccinava": "vaccinare",
    "vaccinavamo": "vaccinare",
    "vaccinavan": "vaccinare",
    "vaccinavano": "vaccinare",
    "vaccinavate": "vaccinare",
    "vaccinavi": "vaccinare",
    "vaccinavo": "vaccinare",
    "vaccinazioni": "vaccinazione",
    "vaccinerai": "vaccinare",
    "vaccineran": "vaccinare",
    "vaccineranno": "vaccinare",
    "vaccinerebbe": "vaccinare",
    "vaccinerebber": "vaccinare",
    "vaccinerebbero": "vaccinare",
    "vaccinerei": "vaccinare",
    "vaccineremmo": "vaccinare",
    "vaccineremo": "vaccinare",
    "vaccinereste": "vaccinare",
    "vaccineresti": "vaccinare",
    "vaccinerete": "vaccinare",
    "vaccinerà": "vaccinare",
    "vaccinerò": "vaccinare",
    "vaccini": "vaccino",
    "vacciniamo": "vaccinare",
    "vacciniate": "vaccinare",
    "vaccinin": "vaccinare",
    "vaccinino": "vaccinare",
    "vaccino": "vaccinare",
    "vaccinò": "vaccinare",
    "vacherai": "vacare",
    "vacheran": "vacare",
    "vacheranno": "vacare",
    "vacherebbe": "vacare",
    "vacherebber": "vacare",
    "vacherebbero": "vacare",
    "vacherei": "vacare",
    "vacheremmo": "vacare",
    "vacheremo": "vacare",
    "vachereste": "vacare",
    "vacheresti": "vacare",
    "vacherete": "vacare",
    "vacherà": "vacare",
    "vacherò": "vacare",
    "vachi": "vacare",
    "vachiamo": "vacare",
    "vachiate": "vacare",
    "vachin": "vacare",
    "vachino": "vacare",
    "vacilla": "vacillare",
    "vacillai": "vacillare",
    "vacillammo": "vacillare",
    "vacillan": "vacillare",
    "vacillando": "vacillare",
    "vacillano": "vacillare",
    "vacillante": "vacillare",
    "vacillanti": "vacillare",
    "vacillar": "vacillare",
    "vacillaron": "vacillare",
    "vacillarono": "vacillare",
    "vacillasse": "vacillare",
    "vacillasser": "vacillare",
    "vacillassero": "vacillare",
    "vacillassi": "vacillare",
    "vacillassimo": "vacillare",
    "vacillaste": "vacillare",
    "vacillasti": "vacillare",
    "vacillata": "vacillare",
    "vacillate": "vacillare",
    "vacillati": "vacillare",
    "vacillato": "vacillare",
    "vacillava": "vacillare",
    "vacillavamo": "vacillare",
    "vacillavan": "vacillare",
    "vacillavano": "vacillare",
    "vacillavate": "vacillare",
    "vacillavi": "vacillare",
    "vacillavo": "vacillare",
    "vacillerai": "vacillare",
    "vacilleran": "vacillare",
    "vacilleranno": "vacillare",
    "vacillerebbe": "vacillare",
    "vacillerebber": "vacillare",
    "vacillerebbero": "vacillare",
    "vacillerei": "vacillare",
    "vacilleremmo": "vacillare",
    "vacilleremo": "vacillare",
    "vacillereste": "vacillare",
    "vacilleresti": "vacillare",
    "vacillerete": "vacillare",
    "vacillerà": "vacillare",
    "vacillerò": "vacillare",
    "vacilli": "vacillare",
    "vacilliamo": "vacillare",
    "vacilliate": "vacillare",
    "vacillin": "vacillare",
    "vacillino": "vacillare",
    "vacillo": "vacillare",
    "vacillò": "vacillare",
    "vaco": "vacare",
    "vacua": "vacuo",
    "vacue": "vacuo",
    "vacui": "vacuo",
    "vacò": "vacare",
    "vada": "andare",
    "vadan": "andare",
    "vadano": "andare",
    "vado": "andare",
    "vaffanculeggerai": "vaffanculeggiare",
    "vaffanculeggeran": "vaffanculeggiare",
    "vaffanculeggeranno": "vaffanculeggiare",
    "vaffanculeggerebbe": "vaffanculeggiare",
    "vaffanculeggerebber": "vaffanculeggiare",
    "vaffanculeggerebbero": "vaffanculeggiare",
    "vaffanculeggerei": "vaffanculeggiare",
    "vaffanculeggeremmo": "vaffanculeggiare",
    "vaffanculeggeremo": "vaffanculeggiare",
    "vaffanculeggereste": "vaffanculeggiare",
    "vaffanculeggeresti": "vaffanculeggiare",
    "vaffanculeggerete": "vaffanculeggiare",
    "vaffanculeggerà": "vaffanculeggiare",
    "vaffanculeggerò": "vaffanculeggiare",
    "vaffanculeggi": "vaffanculeggiare",
    "vaffanculeggia": "vaffanculeggiare",
    "vaffanculeggiai": "vaffanculeggiare",
    "vaffanculeggiammo": "vaffanculeggiare",
    "vaffanculeggiamo": "vaffanculeggiare",
    "vaffanculeggian": "vaffanculeggiare",
    "vaffanculeggiando": "vaffanculeggiare",
    "vaffanculeggiano": "vaffanculeggiare",
    "vaffanculeggiante": "vaffanculeggiare",
    "vaffanculeggianti": "vaffanculeggiare",
    "vaffanculeggiar": "vaffanculeggiare",
    "vaffanculeggiaron": "vaffanculeggiare",
    "vaffanculeggiarono": "vaffanculeggiare",
    "vaffanculeggiasse": "vaffanculeggiare",
    "vaffanculeggiasser": "vaffanculeggiare",
    "vaffanculeggiassero": "vaffanculeggiare",
    "vaffanculeggiassi": "vaffanculeggiare",
    "vaffanculeggiassimo": "vaffanculeggiare",
    "vaffanculeggiaste": "vaffanculeggiare",
    "vaffanculeggiasti": "vaffanculeggiare",
    "vaffanculeggiata": "vaffanculeggiare",
    "vaffanculeggiate": "vaffanculeggiare",
    "vaffanculeggiati": "vaffanculeggiare",
    "vaffanculeggiato": "vaffanculeggiare",
    "vaffanculeggiava": "vaffanculeggiare",
    "vaffanculeggiavamo": "vaffanculeggiare",
    "vaffanculeggiavan": "vaffanculeggiare",
    "vaffanculeggiavano": "vaffanculeggiare",
    "vaffanculeggiavate": "vaffanculeggiare",
    "vaffanculeggiavi": "vaffanculeggiare",
    "vaffanculeggiavo": "vaffanculeggiare",
    "vaffanculeggin": "vaffanculeggiare",
    "vaffanculeggino": "vaffanculeggiare",
    "vaffanculeggio": "vaffanculeggiare",
    "vaffanculeggiò": "vaffanculeggiare",
    "vaga": "vago",
    "vagabonda": "vagabondo",
    "vagabondaggi": "vagabondaggio",
    "vagabondai": "vagabondare",
    "vagabondammo": "vagabondare",
    "vagabondan": "vagabondare",
    "vagabondando": "vagabondare",
    "vagabondano": "vagabondare",
    "vagabondante": "vagabondare",
    "vagabondanti": "vagabondare",
    "vagabondar": "vagabondare",
    "vagabondaron": "vagabondare",
    "vagabondarono": "vagabondare",
    "vagabondasse": "vagabondare",
    "vagabondasser": "vagabondare",
    "vagabondassero": "vagabondare",
    "vagabondassi": "vagabondare",
    "vagabondassimo": "vagabondare",
    "vagabondaste": "vagabondare",
    "vagabondasti": "vagabondare",
    "vagabondata": "vagabondare",
    "vagabondate": "vagabondare",
    "vagabondati": "vagabondare",
    "vagabondato": "vagabondare",
    "vagabondava": "vagabondare",
    "vagabondavamo": "vagabondare",
    "vagabondavan": "vagabondare",
    "vagabondavano": "vagabondare",
    "vagabondavate": "vagabondare",
    "vagabondavi": "vagabondare",
    "vagabondavo": "vagabondare",
    "vagabonde": "vagabondo",
    "vagabonderai": "vagabondare",
    "vagabonderan": "vagabondare",
    "vagabonderanno": "vagabondare",
    "vagabonderebbe": "vagabondare",
    "vagabonderebber": "vagabondare",
    "vagabonderebbero": "vagabondare",
    "vagabonderei": "vagabondare",
    "vagabonderemmo": "vagabondare",
    "vagabonderemo": "vagabondare",
    "vagabondereste": "vagabondare",
    "vagabonderesti": "vagabondare",
    "vagabonderete": "vagabondare",
    "vagabonderà": "vagabondare",
    "vagabonderò": "vagabondare",
    "vagabondi": "vagabondo",
    "vagabondiamo": "vagabondare",
    "vagabondiate": "vagabondare",
    "vagabondin": "vagabondare",
    "vagabondino": "vagabondare",
    "vagabondo": "vagabondare",
    "vagabondò": "vagabondare",
    "vagai": "vagare",
    "vagammo": "vagare",
    "vagan": "vagire",
    "vagando": "vagare",
    "vagano": "vagire",
    "vagante": "vagare",
    "vaganti": "vagare",
    "vagar": "vagare",
    "vagaron": "vagare",
    "vagarono": "vagare",
    "vagasse": "vagare",
    "vagasser": "vagare",
    "vagassero": "vagare",
    "vagassi": "vagare",
    "vagassimo": "vagare",
    "vagaste": "vagare",
    "vagasti": "vagare",
    "vagata": "vagare",
    "vagate": "vagare",
    "vagati": "vagare",
    "vagato": "vagare",
    "vagava": "vagare",
    "vagavamo": "vagare",
    "vagavan": "vagare",
    "vagavano": "vagare",
    "vagavate": "vagare",
    "vagavi": "vagare",
    "vagavo": "vagare",
    "vage": "vagire",
    "vagendo": "vagire",
    "vagente": "vagire",
    "vagenti": "vagire",
    "vaghe": "vago",
    "vagheggerai": "vagheggiare",
    "vagheggeran": "vagheggiare",
    "vagheggeranno": "vagheggiare",
    "vagheggerebbe": "vagheggiare",
    "vagheggerebber": "vagheggiare",
    "vagheggerebbero": "vagheggiare",
    "vagheggerei": "vagheggiare",
    "vagheggeremmo": "vagheggiare",
    "vagheggeremo": "vagheggiare",
    "vagheggereste": "vagheggiare",
    "vagheggeresti": "vagheggiare",
    "vagheggerete": "vagheggiare",
    "vagheggerà": "vagheggiare",
    "vagheggerò": "vagheggiare",
    "vagheggi": "vagheggiare",
    "vagheggia": "vagheggiare",
    "vagheggiai": "vagheggiare",
    "vagheggiamenti": "vagheggiamento",
    "vagheggiammo": "vagheggiare",
    "vagheggiamo": "vagheggiare",
    "vagheggian": "vagheggiare",
    "vagheggiando": "vagheggiare",
    "vagheggiano": "vagheggiare",
    "vagheggiante": "vagheggiare",
    "vagheggianti": "vagheggiare",
    "vagheggiar": "vagheggiare",
    "vagheggiaron": "vagheggiare",
    "vagheggiarono": "vagheggiare",
    "vagheggiasse": "vagheggiare",
    "vagheggiasser": "vagheggiare",
    "vagheggiassero": "vagheggiare",
    "vagheggiassi": "vagheggiare",
    "vagheggiassimo": "vagheggiare",
    "vagheggiaste": "vagheggiare",
    "vagheggiasti": "vagheggiare",
    "vagheggiata": "vagheggiare",
    "vagheggiate": "vagheggiare",
    "vagheggiati": "vagheggiare",
    "vagheggiato": "vagheggiare",
    "vagheggiava": "vagheggiare",
    "vagheggiavamo": "vagheggiare",
    "vagheggiavan": "vagheggiare",
    "vagheggiavano": "vagheggiare",
    "vagheggiavate": "vagheggiare",
    "vagheggiavi": "vagheggiare",
    "vagheggiavo": "vagheggiare",
    "vagheggin": "vagheggiare",
    "vagheggino": "vagheggiare",
    "vagheggio": "vagheggiare",
    "vagheggiò": "vagheggiare",
    "vagherai": "vagare",
    "vagheran": "vagare",
    "vagheranno": "vagare",
    "vagherebbe": "vagare",
    "vagherebber": "vagare",
    "vagherebbero": "vagare",
    "vagherei": "vagare",
    "vagheremmo": "vagare",
    "vagheremo": "vagare",
    "vaghereste": "vagare",
    "vagheresti": "vagare",
    "vagherete": "vagare",
    "vagherà": "vagare",
    "vagherò": "vagare",
    "vaghezze": "vaghezza",
    "vaghi": "vago",
    "vaghiamo": "vagare",
    "vaghiate": "vagare",
    "vaghin": "vagare",
    "vaghino": "vagare",
    "vagi": "vagire",
    "vagiamo": "vagire",
    "vagiate": "vagire",
    "vagii": "vagire",
    "vagimmo": "vagire",
    "vaginali": "vaginale",
    "vagine": "vagina",
    "vagir": "vagire",
    "vagirai": "vagire",
    "vagiran": "vagire",
    "vagiranno": "vagire",
    "vagirebbe": "vagire",
    "vagirebber": "vagire",
    "vagirebbero": "vagire",
    "vagirei": "vagire",
    "vagiremmo": "vagire",
    "vagiremo": "vagire",
    "vagireste": "vagire",
    "vagiresti": "vagire",
    "vagirete": "vagire",
    "vagiron": "vagire",
    "vagirono": "vagire",
    "vagirà": "vagire",
    "vagirò": "vagire",
    "vagisse": "vagire",
    "vagisser": "vagire",
    "vagissero": "vagire",
    "vagissi": "vagire",
    "vagissimo": "vagire",
    "vagiste": "vagire",
    "vagisti": "vagire",
    "vagita": "vagire",
    "vagite": "vagire",
    "vagiti": "vagito",
    "vagito": "vagire",
    "vagiva": "vagire",
    "vagivamo": "vagire",
    "vagivan": "vagire",
    "vagivano": "vagire",
    "vagivate": "vagire",
    "vagivi": "vagire",
    "vagivo": "vagire",
    "vagli": "vaglio",
    "vaglia": "vagliare",
    "vagliai": "vagliare",
    "vagliammo": "vagliare",
    "vagliamo": "vagliare",
    "vaglian": "vagliare",
    "vagliando": "vagliare",
    "vagliano": "vagliare",
    "vagliante": "vagliare",
    "vaglianti": "vagliare",
    "vagliar": "vagliare",
    "vagliaron": "vagliare",
    "vagliarono": "vagliare",
    "vagliasse": "vagliare",
    "vagliasser": "vagliare",
    "vagliassero": "vagliare",
    "vagliassi": "vagliare",
    "vagliassimo": "vagliare",
    "vagliaste": "vagliare",
    "vagliasti": "vagliare",
    "vagliata": "vagliare",
    "vagliate": "vagliare",
    "vagliati": "vagliare",
    "vagliato": "vagliare",
    "vagliava": "vagliare",
    "vagliavamo": "vagliare",
    "vagliavan": "vagliare",
    "vagliavano": "vagliare",
    "vagliavate": "vagliare",
    "vagliavi": "vagliare",
    "vagliavo": "vagliare",
    "vaglierai": "vagliare",
    "vaglieran": "vagliare",
    "vaglieranno": "vagliare",
    "vaglierebbe": "vagliare",
    "vaglierebber": "vagliare",
    "vaglierebbero": "vagliare",
    "vaglierei": "vagliare",
    "vaglieremmo": "vagliare",
    "vaglieremo": "vagliare",
    "vagliereste": "vagliare",
    "vaglieresti": "vagliare",
    "vaglierete": "vagliare",
    "vaglierà": "vagliare",
    "vaglierò": "vagliare",
    "vaglin": "vagliare",
    "vaglino": "vagliare",
    "vaglio": "vagliare",
    "vagliò": "vagliare",
    "vago": "vagire",
    "vagola": "vagolare",
    "vagolai": "vagolare",
    "vagolammo": "vagolare",
    "vagolan": "vagolare",
    "vagolando": "vagolare",
    "vagolano": "vagolare",
    "vagolante": "vagolare",
    "vagolanti": "vagolare",
    "vagolar": "vagolare",
    "vagolaron": "vagolare",
    "vagolarono": "vagolare",
    "vagolasse": "vagolare",
    "vagolasser": "vagolare",
    "vagolassero": "vagolare",
    "vagolassi": "vagolare",
    "vagolassimo": "vagolare",
    "vagolaste": "vagolare",
    "vagolasti": "vagolare",
    "vagolata": "vagolare",
    "vagolate": "vagolare",
    "vagolati": "vagolare",
    "vagolato": "vagolare",
    "vagolava": "vagolare",
    "vagolavamo": "vagolare",
    "vagolavan": "vagolare",
    "vagolavano": "vagolare",
    "vagolavate": "vagolare",
    "vagolavi": "vagolare",
    "vagolavo": "vagolare",
    "vagolerai": "vagolare",
    "vagoleran": "vagolare",
    "vagoleranno": "vagolare",
    "vagolerebbe": "vagolare",
    "vagolerebber": "vagolare",
    "vagolerebbero": "vagolare",
    "vagolerei": "vagolare",
    "vagoleremmo": "vagolare",
    "vagoleremo": "vagolare",
    "vagolereste": "vagolare",
    "vagoleresti": "vagolare",
    "vagolerete": "vagolare",
    "vagolerà": "vagolare",
    "vagolerò": "vagolare",
    "vagoli": "vagolare",
    "vagoliamo": "vagolare",
    "vagoliate": "vagolare",
    "vagolin": "vagolare",
    "vagolino": "vagolare",
    "vagolo": "vagolare",
    "vagolò": "vagolare",
    "vagon": "vagire",
    "vagoncini": "vagoncino",
    "vagoni": "vagone",
    "vagono": "vagire",
    "vagì": "vagire",
    "vagò": "vagare",
    "vai": "vaio",
    "vaia": "vaio",
    "vaie": "vaio",
    "vaioli": "vaiolo",
    "val": "valle",
    "valanghe": "valanga",
    "valchirie": "valchiria",
    "valdese-metodiste": "valdese-metodista",
    "valdese-metodisti": "valdese-metodista",
    "valdesi": "valdese",
    "valdo-metodiste": "valdo-metodista",
    "valdo-metodisti": "valdo-metodista",
    "valdometodiste": "valdometodista",
    "valdometodisti": "valdometodista",
    "valdostani": "valdostano",
    "vale": "valere",
    "valemmo": "valere",
    "valendo": "valere",
    "valente": "valere",
    "valenti": "valere",
    "valenze": "valenza",
    "valenziana": "valenziano",
    "valenziane": "valenziano",
    "valenziani": "valenziano",
    "valer": "valere",
    "valesse": "valere",
    "valesser": "valere",
    "valessero": "valere",
    "valessi": "valere",
    "valessimo": "valere",
    "valeste": "valere",
    "valesti": "valere",
    "valete": "valere",
    "valeva": "valere",
    "valevamo": "valere",
    "valevan": "valere",
    "valevano": "valere",
    "valevate": "valere",
    "valevi": "valere",
    "valevo": "valere",
    "valevoli": "valevole",
    "valga": "valgo",
    "valgan": "valere",
    "valgano": "valere",
    "valghe": "valgo",
    "valghi": "valgo",
    "valgo": "valere",
    "valgon": "valere",
    "valgono": "valere",
    "vali": "valere",
    "valiamo": "valere",
    "valiate": "valere",
    "valica": "valicare",
    "valicabili": "valicabile",
    "valicai": "valicare",
    "valicammo": "valicare",
    "valican": "valicare",
    "valicando": "valicare",
    "valicano": "valicare",
    "valicante": "valicare",
    "valicanti": "valicare",
    "valicar": "valicare",
    "valicaron": "valicare",
    "valicarono": "valicare",
    "valicasse": "valicare",
    "valicasser": "valicare",
    "valicassero": "valicare",
    "valicassi": "valicare",
    "valicassimo": "valicare",
    "valicaste": "valicare",
    "valicasti": "valicare",
    "valicata": "valicare",
    "valicate": "valicare",
    "valicati": "valicare",
    "valicato": "valicare",
    "valicava": "valicare",
    "valicavamo": "valicare",
    "valicavan": "valicare",
    "valicavano": "valicare",
    "valicavate": "valicare",
    "valicavi": "valicare",
    "valicavo": "valicare",
    "valicherai": "valicare",
    "valicheran": "valicare",
    "valicheranno": "valicare",
    "valicherebbe": "valicare",
    "valicherebber": "valicare",
    "valicherebbero": "valicare",
    "valicherei": "valicare",
    "valicheremmo": "valicare",
    "valicheremo": "valicare",
    "valichereste": "valicare",
    "valicheresti": "valicare",
    "valicherete": "valicare",
    "valicherà": "valicare",
    "valicherò": "valicare",
    "valichi": "valico",
    "valichiamo": "valicare",
    "valichiate": "valicare",
    "valichin": "valicare",
    "valichino": "valicare",
    "valico": "valicare",
    "valicò": "valicare",
    "valida": "valido",
    "validai": "validare",
    "validammo": "validare",
    "validan": "validare",
    "validando": "validare",
    "validano": "validare",
    "validante": "validare",
    "validanti": "validare",
    "validar": "validare",
    "validaron": "validare",
    "validarono": "validare",
    "validasse": "validare",
    "validasser": "validare",
    "validassero": "validare",
    "validassi": "validare",
    "validassimo": "validare",
    "validaste": "validare",
    "validasti": "validare",
    "validata": "validare",
    "validate": "validare",
    "validati": "validare",
    "validato": "validare",
    "validava": "validare",
    "validavamo": "validare",
    "validavan": "validare",
    "validavano": "validare",
    "validavate": "validare",
    "validavi": "validare",
    "validavo": "validare",
    "valide": "valido",
    "validerai": "validare",
    "valideran": "validare",
    "valideranno": "validare",
    "validerebbe": "validare",
    "validerebber": "validare",
    "validerebbero": "validare",
    "validerei": "validare",
    "valideremmo": "validare",
    "valideremo": "validare",
    "validereste": "validare",
    "valideresti": "validare",
    "validerete": "validare",
    "validerà": "validare",
    "validerò": "validare",
    "validi": "valido",
    "validiamo": "validare",
    "validiate": "validare",
    "validin": "validare",
    "validino": "validare",
    "valido": "validare",
    "validò": "validare",
    "valige": "valigia",
    "valigette": "valigetta",
    "valigie": "valigia",
    "valla": "vallare",
    "vallai": "vallare",
    "vallammo": "vallare",
    "vallan": "vallare",
    "vallando": "vallare",
    "vallano": "vallare",
    "vallante": "vallare",
    "vallanti": "vallare",
    "vallar": "vallare",
    "vallaron": "vallare",
    "vallarono": "vallare",
    "vallasse": "vallare",
    "vallasser": "vallare",
    "vallassero": "vallare",
    "vallassi": "vallare",
    "vallassimo": "vallare",
    "vallaste": "vallare",
    "vallasti": "vallare",
    "vallata": "vallare",
    "vallate": "vallata",
    "vallati": "vallare",
    "vallato": "vallare",
    "vallava": "vallare",
    "vallavamo": "vallare",
    "vallavan": "vallare",
    "vallavano": "vallare",
    "vallavate": "vallare",
    "vallavi": "vallare",
    "vallavo": "vallare",
    "vallerai": "vallare",
    "valleran": "vallare",
    "valleranno": "vallare",
    "vallerebbe": "vallare",
    "vallerebber": "vallare",
    "vallerebbero": "vallare",
    "vallerei": "vallare",
    "valleremmo": "vallare",
    "valleremo": "vallare",
    "vallereste": "vallare",
    "valleresti": "vallare",
    "vallerete": "vallare",
    "vallerà": "vallare",
    "vallerò": "vallare",
    "vallesi": "vallese",
    "vallette": "valletta",
    "valletti": "valletto",
    "valli": "vallo",
    "valliamo": "vallare",
    "valliate": "vallare",
    "valligiana": "valligiano",
    "valligiane": "valligiano",
    "valligiani": "valligiano",
    "vallin": "vallare",
    "vallino": "vallare",
    "vallo": "vallare",
    "vallombrosiana": "vallombrosiano",
    "vallombrosiane": "vallombrosiano",
    "vallombrosiani": "vallombrosiano",
    "valloni": "vallone",
    "vallò": "vallare",
    "valor": "valore",
    "valori": "valore",
    "valorizza": "valorizzare",
    "valorizzai": "valorizzare",
    "valorizzammo": "valorizzare",
    "valorizzan": "valorizzare",
    "valorizzando": "valorizzare",
    "valorizzano": "valorizzare",
    "valorizzante": "valorizzare",
    "valorizzanti": "valorizzare",
    "valorizzar": "valorizzare",
    "valorizzaron": "valorizzare",
    "valorizzarono": "valorizzare",
    "valorizzasse": "valorizzare",
    "valorizzasser": "valorizzare",
    "valorizzassero": "valorizzare",
    "valorizzassi": "valorizzare",
    "valorizzassimo": "valorizzare",
    "valorizzaste": "valorizzare",
    "valorizzasti": "valorizzare",
    "valorizzata": "valorizzare",
    "valorizzate": "valorizzare",
    "valorizzati": "valorizzare",
    "valorizzato": "valorizzare",
    "valorizzava": "valorizzare",
    "valorizzavamo": "valorizzare",
    "valorizzavan": "valorizzare",
    "valorizzavano": "valorizzare",
    "valorizzavate": "valorizzare",
    "valorizzavi": "valorizzare",
    "valorizzavo": "valorizzare",
    "valorizzazioni": "valorizzazione",
    "valorizzerai": "valorizzare",
    "valorizzeran": "valorizzare",
    "valorizzeranno": "valorizzare",
    "valorizzerebbe": "valorizzare",
    "valorizzerebber": "valorizzare",
    "valorizzerebbero": "valorizzare",
    "valorizzerei": "valorizzare",
    "valorizzeremmo": "valorizzare",
    "valorizzeremo": "valorizzare",
    "valorizzereste": "valorizzare",
    "valorizzeresti": "valorizzare",
    "valorizzerete": "valorizzare",
    "valorizzerà": "valorizzare",
    "valorizzerò": "valorizzare",
    "valorizzi": "valorizzare",
    "valorizziamo": "valorizzare",
    "valorizziate": "valorizzare",
    "valorizzin": "valorizzare",
    "valorizzino": "valorizzare",
    "valorizzo": "valorizzare",
    "valorizzò": "valorizzare",
    "valorosa": "valoroso",
    "valorose": "valoroso",
    "valorosi": "valoroso",
    "valsa": "valere",
    "valse": "valere",
    "valser": "valere",
    "valsero": "valere",
    "valsi": "valere",
    "valso": "valere",
    "valtellinesi": "valtellinese",
    "valuta": "valutare",
    "valutabili": "valutabile",
    "valutai": "valutare",
    "valutammo": "valutare",
    "valutan": "valutare",
    "valutando": "valutare",
    "valutano": "valutare",
    "valutante": "valutare",
    "valutanti": "valutare",
    "valutar": "valutare",
    "valutari": "valutario",
    "valutaria": "valutario",
    "valutarie": "valutario",
    "valutaron": "valutare",
    "valutarono": "valutare",
    "valutasse": "valutare",
    "valutasser": "valutare",
    "valutassero": "valutare",
    "valutassi": "valutare",
    "valutassimo": "valutare",
    "valutaste": "valutare",
    "valutasti": "valutare",
    "valutata": "valutare",
    "valutate": "valutare",
    "valutati": "valutare",
    "valutato": "valutare",
    "valutatori": "valutatore",
    "valutava": "valutare",
    "valutavamo": "valutare",
    "valutavan": "valutare",
    "valutavano": "valutare",
    "valutavate": "valutare",
    "valutavi": "valutare",
    "valutavo": "valutare",
    "valutazioni": "valutazione",
    "valute": "valuta",
    "valuterai": "valutare",
    "valuteran": "valutare",
    "valuteranno": "valutare",
    "valuterebbe": "valutare",
    "valuterebber": "valutare",
    "valuterebbero": "valutare",
    "valuterei": "valutare",
    "valuteremmo": "valutare",
    "valuteremo": "valutare",
    "valutereste": "valutare",
    "valuteresti": "valutare",
    "valuterete": "valutare",
    "valuterà": "valutare",
    "valuterò": "valutare",
    "valuti": "valutare",
    "valutiamo": "valutare",
    "valutiate": "valutare",
    "valutin": "valutare",
    "valutino": "valutare",
    "valuto": "valutare",
    "valutò": "valutare",
    "valvassini": "valvassino",
    "valvassori": "valvassore",
    "valvole": "valvola",
    "valzerini": "valzerino",
    "vampate": "vampata",
    "vampe": "vampa",
    "vampeggerai": "vampeggiare",
    "vampeggeran": "vampeggiare",
    "vampeggeranno": "vampeggiare",
    "vampeggerebbe": "vampeggiare",
    "vampeggerebber": "vampeggiare",
    "vampeggerebbero": "vampeggiare",
    "vampeggerei": "vampeggiare",
    "vampeggeremmo": "vampeggiare",
    "vampeggeremo": "vampeggiare",
    "vampeggereste": "vampeggiare",
    "vampeggeresti": "vampeggiare",
    "vampeggerete": "vampeggiare",
    "vampeggerà": "vampeggiare",
    "vampeggerò": "vampeggiare",
    "vampeggi": "vampeggiare",
    "vampeggia": "vampeggiare",
    "vampeggiai": "vampeggiare",
    "vampeggiammo": "vampeggiare",
    "vampeggiamo": "vampeggiare",
    "vampeggian": "vampeggiare",
    "vampeggiando": "vampeggiare",
    "vampeggiano": "vampeggiare",
    "vampeggiante": "vampeggiare",
    "vampeggianti": "vampeggiare",
    "vampeggiar": "vampeggiare",
    "vampeggiaron": "vampeggiare",
    "vampeggiarono": "vampeggiare",
    "vampeggiasse": "vampeggiare",
    "vampeggiasser": "vampeggiare",
    "vampeggiassero": "vampeggiare",
    "vampeggiassi": "vampeggiare",
    "vampeggiassimo": "vampeggiare",
    "vampeggiaste": "vampeggiare",
    "vampeggiasti": "vampeggiare",
    "vampeggiata": "vampeggiare",
    "vampeggiate": "vampeggiare",
    "vampeggiati": "vampeggiare",
    "vampeggiato": "vampeggiare",
    "vampeggiava": "vampeggiare",
    "vampeggiavamo": "vampeggiare",
    "vampeggiavan": "vampeggiare",
    "vampeggiavano": "vampeggiare",
    "vampeggiavate": "vampeggiare",
    "vampeggiavi": "vampeggiare",
    "vampeggiavo": "vampeggiare",
    "vampeggin": "vampeggiare",
    "vampeggino": "vampeggiare",
    "vampeggio": "vampeggiare",
    "vampeggiò": "vampeggiare",
    "vampiri": "vampiro",
    "vampiristica": "vampiristico",
    "vampiristiche": "vampiristico",
    "vampiristici": "vampiristico",
    "van": "andare",
    "vana": "vano",
    "vanaglori": "vanagloriare",
    "vanagloria": "vanagloriare",
    "vanagloriai": "vanagloriare",
    "vanagloriammo": "vanagloriare",
    "vanagloriamo": "vanagloriare",
    "vanaglorian": "vanagloriare",
    "vanagloriando": "vanagloriare",
    "vanagloriano": "vanagloriare",
    "vanagloriar": "vanagloriare",
    "vanagloriaron": "vanagloriare",
    "vanagloriarono": "vanagloriare",
    "vanagloriasse": "vanagloriare",
    "vanagloriasser": "vanagloriare",
    "vanagloriassero": "vanagloriare",
    "vanagloriassi": "vanagloriare",
    "vanagloriassimo": "vanagloriare",
    "vanagloriaste": "vanagloriare",
    "vanagloriasti": "vanagloriare",
    "vanagloriata": "vanagloriare",
    "vanagloriate": "vanagloriare",
    "vanagloriati": "vanagloriare",
    "vanagloriato": "vanagloriare",
    "vanagloriava": "vanagloriare",
    "vanagloriavamo": "vanagloriare",
    "vanagloriavan": "vanagloriare",
    "vanagloriavano": "vanagloriare",
    "vanagloriavate": "vanagloriare",
    "vanagloriavi": "vanagloriare",
    "vanagloriavo": "vanagloriare",
    "vanaglorierai": "vanagloriare",
    "vanaglorieran": "vanagloriare",
    "vanaglorieranno": "vanagloriare",
    "vanaglorierebbe": "vanagloriare",
    "vanaglorierebber": "vanagloriare",
    "vanaglorierebbero": "vanagloriare",
    "vanaglorierei": "vanagloriare",
    "vanaglorieremmo": "vanagloriare",
    "vanaglorieremo": "vanagloriare",
    "vanagloriereste": "vanagloriare",
    "vanaglorieresti": "vanagloriare",
    "vanaglorierete": "vanagloriare",
    "vanaglorierà": "vanagloriare",
    "vanaglorierò": "vanagloriare",
    "vanaglorin": "vanagloriare",
    "vanaglorino": "vanagloriare",
    "vanaglorio": "vanagloriare",
    "vanagloriò": "vanagloriare",
    "vancanze": "vancanza",
    "vancaziera": "vancaziero",
    "vancaziere": "vancaziero",
    "vancazieri": "vancaziero",
    "vandala": "vandalo",
    "vandale": "vandalo",
    "vandali": "vandalo",
    "vandalica": "vandalico",
    "vandaliche": "vandalico",
    "vandalici": "vandalico",
    "vandalismi": "vandalismo",
    "vandalizza": "vandalizzare",
    "vandalizzai": "vandalizzare",
    "vandalizzammo": "vandalizzare",
    "vandalizzan": "vandalizzare",
    "vandalizzando": "vandalizzare",
    "vandalizzano": "vandalizzare",
    "vandalizzante": "vandalizzare",
    "vandalizzanti": "vandalizzare",
    "vandalizzar": "vandalizzare",
    "vandalizzaron": "vandalizzare",
    "vandalizzarono": "vandalizzare",
    "vandalizzasse": "vandalizzare",
    "vandalizzasser": "vandalizzare",
    "vandalizzassero": "vandalizzare",
    "vandalizzassi": "vandalizzare",
    "vandalizzassimo": "vandalizzare",
    "vandalizzaste": "vandalizzare",
    "vandalizzasti": "vandalizzare",
    "vandalizzata": "vandalizzare",
    "vandalizzate": "vandalizzare",
    "vandalizzati": "vandalizzare",
    "vandalizzato": "vandalizzare",
    "vandalizzava": "vandalizzare",
    "vandalizzavamo": "vandalizzare",
    "vandalizzavan": "vandalizzare",
    "vandalizzavano": "vandalizzare",
    "vandalizzavate": "vandalizzare",
    "vandalizzavi": "vandalizzare",
    "vandalizzavo": "vandalizzare",
    "vandalizzerai": "vandalizzare",
    "vandalizzeran": "vandalizzare",
    "vandalizzeranno": "vandalizzare",
    "vandalizzerebbe": "vandalizzare",
    "vandalizzerebber": "vandalizzare",
    "vandalizzerebbero": "vandalizzare",
    "vandalizzerei": "vandalizzare",
    "vandalizzeremmo": "vandalizzare",
    "vandalizzeremo": "vandalizzare",
    "vandalizzereste": "vandalizzare",
    "vandalizzeresti": "vandalizzare",
    "vandalizzerete": "vandalizzare",
    "vandalizzerà": "vandalizzare",
    "vandalizzerò": "vandalizzare",
    "vandalizzi": "vandalizzare",
    "vandalizziamo": "vandalizzare",
    "vandalizziate": "vandalizzare",
    "vandalizzin": "vandalizzare",
    "vandalizzino": "vandalizzare",
    "vandalizzo": "vandalizzare",
    "vandalizzò": "vandalizzare",
    "vane": "vano",
    "vaneggerai": "vaneggiare",
    "vaneggeran": "vaneggiare",
    "vaneggeranno": "vaneggiare",
    "vaneggerebbe": "vaneggiare",
    "vaneggerebber": "vaneggiare",
    "vaneggerebbero": "vaneggiare",
    "vaneggerei": "vaneggiare",
    "vaneggeremmo": "vaneggiare",
    "vaneggeremo": "vaneggiare",
    "vaneggereste": "vaneggiare",
    "vaneggeresti": "vaneggiare",
    "vaneggerete": "vaneggiare",
    "vaneggerà": "vaneggiare",
    "vaneggerò": "vaneggiare",
    "vaneggi": "vaneggiare",
    "vaneggia": "vaneggiare",
    "vaneggiai": "vaneggiare",
    "vaneggiamenti": "vaneggiamento",
    "vaneggiammo": "vaneggiare",
    "vaneggiamo": "vaneggiare",
    "vaneggian": "vaneggiare",
    "vaneggiando": "vaneggiare",
    "vaneggiano": "vaneggiare",
    "vaneggiante": "vaneggiare",
    "vaneggianti": "vaneggiare",
    "vaneggiar": "vaneggiare",
    "vaneggiaron": "vaneggiare",
    "vaneggiarono": "vaneggiare",
    "vaneggiasse": "vaneggiare",
    "vaneggiasser": "vaneggiare",
    "vaneggiassero": "vaneggiare",
    "vaneggiassi": "vaneggiare",
    "vaneggiassimo": "vaneggiare",
    "vaneggiaste": "vaneggiare",
    "vaneggiasti": "vaneggiare",
    "vaneggiata": "vaneggiare",
    "vaneggiate": "vaneggiare",
    "vaneggiati": "vaneggiare",
    "vaneggiato": "vaneggiare",
    "vaneggiava": "vaneggiare",
    "vaneggiavamo": "vaneggiare",
    "vaneggiavan": "vaneggiare",
    "vaneggiavano": "vaneggiare",
    "vaneggiavate": "vaneggiare",
    "vaneggiavi": "vaneggiare",
    "vaneggiavo": "vaneggiare",
    "vaneggin": "vaneggiare",
    "vaneggino": "vaneggiare",
    "vaneggio": "vaneggiare",
    "vaneggiò": "vaneggiare",
    "vanesi": "vanesio",
    "vanesia": "vanesio",
    "vanesie": "vanesio",
    "vanga": "vangare",
    "vangai": "vangare",
    "vangammo": "vangare",
    "vangan": "vangare",
    "vangando": "vangare",
    "vangano": "vangare",
    "vangante": "vangare",
    "vanganti": "vangare",
    "vangar": "vangare",
    "vangaron": "vangare",
    "vangarono": "vangare",
    "vangasse": "vangare",
    "vangasser": "vangare",
    "vangassero": "vangare",
    "vangassi": "vangare",
    "vangassimo": "vangare",
    "vangaste": "vangare",
    "vangasti": "vangare",
    "vangata": "vangare",
    "vangate": "vangare",
    "vangati": "vangare",
    "vangato": "vangare",
    "vangava": "vangare",
    "vangavamo": "vangare",
    "vangavan": "vangare",
    "vangavano": "vangare",
    "vangavate": "vangare",
    "vangavi": "vangare",
    "vangavo": "vangare",
    "vangeli": "vangelo",
    "vangherai": "vangare",
    "vangheran": "vangare",
    "vangheranno": "vangare",
    "vangherebbe": "vangare",
    "vangherebber": "vangare",
    "vangherebbero": "vangare",
    "vangherei": "vangare",
    "vangheremmo": "vangare",
    "vangheremo": "vangare",
    "vanghereste": "vangare",
    "vangheresti": "vangare",
    "vangherete": "vangare",
    "vangherà": "vangare",
    "vangherò": "vangare",
    "vanghi": "vangare",
    "vanghiamo": "vangare",
    "vanghiate": "vangare",
    "vanghin": "vangare",
    "vanghino": "vangare",
    "vango": "vangare",
    "vangò": "vangare",
    "vani": "vano",
    "vanifica": "vanificare",
    "vanificai": "vanificare",
    "vanificammo": "vanificare",
    "vanifican": "vanificare",
    "vanificando": "vanificare",
    "vanificano": "vanificare",
    "vanificante": "vanificare",
    "vanificanti": "vanificare",
    "vanificar": "vanificare",
    "vanificaron": "vanificare",
    "vanificarono": "vanificare",
    "vanificasse": "vanificare",
    "vanificasser": "vanificare",
    "vanificassero": "vanificare",
    "vanificassi": "vanificare",
    "vanificassimo": "vanificare",
    "vanificaste": "vanificare",
    "vanificasti": "vanificare",
    "vanificata": "vanificare",
    "vanificate": "vanificare",
    "vanificati": "vanificare",
    "vanificato": "vanificare",
    "vanificava": "vanificare",
    "vanificavamo": "vanificare",
    "vanificavan": "vanificare",
    "vanificavano": "vanificare",
    "vanificavate": "vanificare",
    "vanificavi": "vanificare",
    "vanificavo": "vanificare",
    "vanificherai": "vanificare",
    "vanificheran": "vanificare",
    "vanificheranno": "vanificare",
    "vanificherebbe": "vanificare",
    "vanificherebber": "vanificare",
    "vanificherebbero": "vanificare",
    "vanificherei": "vanificare",
    "vanificheremmo": "vanificare",
    "vanificheremo": "vanificare",
    "vanifichereste": "vanificare",
    "vanificheresti": "vanificare",
    "vanificherete": "vanificare",
    "vanificherà": "vanificare",
    "vanificherò": "vanificare",
    "vanifichi": "vanificare",
    "vanifichiamo": "vanificare",
    "vanifichiate": "vanificare",
    "vanifichin": "vanificare",
    "vanifichino": "vanificare",
    "vanifico": "vanificare",
    "vanificò": "vanificare",
    "vanitosa": "vanitoso",
    "vanitose": "vanitoso",
    "vanitosi": "vanitoso",
    "vanno": "andare",
    "vanta": "vantare",
    "vantaggi": "vantaggio",
    "vantaggiata": "vantaggiato",
    "vantaggiate": "vantaggiato",
    "vantaggiati": "vantaggiato",
    "vantaggiosa": "vantaggioso",
    "vantaggiose": "vantaggioso",
    "vantaggiosi": "vantaggioso",
    "vantai": "vantare",
    "vantammo": "vantare",
    "vantan": "vantare",
    "vantando": "vantare",
    "vantano": "vantare",
    "vantante": "vantare",
    "vantanti": "vantare",
    "vantar": "vantare",
    "vantaron": "vantare",
    "vantarono": "vantare",
    "vantasse": "vantare",
    "vantasser": "vantare",
    "vantassero": "vantare",
    "vantassi": "vantare",
    "vantassimo": "vantare",
    "vantaste": "vantare",
    "vantasti": "vantare",
    "vantata": "vantare",
    "vantate": "vantare",
    "vantati": "vantare",
    "vantato": "vantare",
    "vantava": "vantare",
    "vantavamo": "vantare",
    "vantavan": "vantare",
    "vantavano": "vantare",
    "vantavate": "vantare",
    "vantavi": "vantare",
    "vantavo": "vantare",
    "vanterai": "vantare",
    "vanteran": "vantare",
    "vanteranno": "vantare",
    "vanterebbe": "vantare",
    "vanterebber": "vantare",
    "vanterebbero": "vantare",
    "vanterei": "vantare",
    "vanteremmo": "vantare",
    "vanteremo": "vantare",
    "vantereste": "vantare",
    "vanteresti": "vantare",
    "vanterete": "vantare",
    "vanterie": "vanteria",
    "vanterà": "vantare",
    "vanterò": "vantare",
    "vanti": "vanto",
    "vantiamo": "vantare",
    "vantiate": "vantare",
    "vantin": "vantare",
    "vantino": "vantare",
    "vanto": "vantare",
    "vantò": "vantare",
    "vanvitelliana": "vanvitelliano",
    "vanvitelliane": "vanvitelliano",
    "vanvitelliani": "vanvitelliano",
    "vapora": "vaporare",
    "vaporai": "vaporare",
    "vaporammo": "vaporare",
    "vaporan": "vaporare",
    "vaporando": "vaporare",
    "vaporano": "vaporare",
    "vaporante": "vaporare",
    "vaporanti": "vaporare",
    "vaporar": "vaporare",
    "vaporaron": "vaporare",
    "vaporarono": "vaporare",
    "vaporasse": "vaporare",
    "vaporasser": "vaporare",
    "vaporassero": "vaporare",
    "vaporassi": "vaporare",
    "vaporassimo": "vaporare",
    "vaporaste": "vaporare",
    "vaporasti": "vaporare",
    "vaporata": "vaporare",
    "vaporate": "vaporare",
    "vaporati": "vaporare",
    "vaporato": "vaporare",
    "vaporava": "vaporare",
    "vaporavamo": "vaporare",
    "vaporavan": "vaporare",
    "vaporavano": "vaporare",
    "vaporavate": "vaporare",
    "vaporavi": "vaporare",
    "vaporavo": "vaporare",
    "vaporerai": "vaporare",
    "vaporeran": "vaporare",
    "vaporeranno": "vaporare",
    "vaporerebbe": "vaporare",
    "vaporerebber": "vaporare",
    "vaporerebbero": "vaporare",
    "vaporerei": "vaporare",
    "vaporeremmo": "vaporare",
    "vaporeremo": "vaporare",
    "vaporereste": "vaporare",
    "vaporeresti": "vaporare",
    "vaporerete": "vaporare",
    "vaporerà": "vaporare",
    "vaporerò": "vaporare",
    "vaporetti": "vaporetto",
    "vapori": "vapore",
    "vaporiamo": "vaporare",
    "vaporiate": "vaporare",
    "vaporiere": "vaporiera",
    "vaporin": "vaporare",
    "vaporino": "vaporare",
    "vaporizza": "vaporizzare",
    "vaporizzai": "vaporizzare",
    "vaporizzammo": "vaporizzare",
    "vaporizzan": "vaporizzare",
    "vaporizzando": "vaporizzare",
    "vaporizzano": "vaporizzare",
    "vaporizzante": "vaporizzare",
    "vaporizzanti": "vaporizzare",
    "vaporizzar": "vaporizzare",
    "vaporizzaron": "vaporizzare",
    "vaporizzarono": "vaporizzare",
    "vaporizzasse": "vaporizzare",
    "vaporizzasser": "vaporizzare",
    "vaporizzassero": "vaporizzare",
    "vaporizzassi": "vaporizzare",
    "vaporizzassimo": "vaporizzare",
    "vaporizzaste": "vaporizzare",
    "vaporizzasti": "vaporizzare",
    "vaporizzata": "vaporizzare",
    "vaporizzate": "vaporizzare",
    "vaporizzati": "vaporizzare",
    "vaporizzato": "vaporizzare",
    "vaporizzava": "vaporizzare",
    "vaporizzavamo": "vaporizzare",
    "vaporizzavan": "vaporizzare",
    "vaporizzavano": "vaporizzare",
    "vaporizzavate": "vaporizzare",
    "vaporizzavi": "vaporizzare",
    "vaporizzavo": "vaporizzare",
    "vaporizzerai": "vaporizzare",
    "vaporizzeran": "vaporizzare",
    "vaporizzeranno": "vaporizzare",
    "vaporizzerebbe": "vaporizzare",
    "vaporizzerebber": "vaporizzare",
    "vaporizzerebbero": "vaporizzare",
    "vaporizzerei": "vaporizzare",
    "vaporizzeremmo": "vaporizzare",
    "vaporizzeremo": "vaporizzare",
    "vaporizzereste": "vaporizzare",
    "vaporizzeresti": "vaporizzare",
    "vaporizzerete": "vaporizzare",
    "vaporizzerà": "vaporizzare",
    "vaporizzerò": "vaporizzare",
    "vaporizzi": "vaporizzare",
    "vaporizziamo": "vaporizzare",
    "vaporizziate": "vaporizzare",
    "vaporizzin": "vaporizzare",
    "vaporizzino": "vaporizzare",
    "vaporizzo": "vaporizzare",
    "vaporizzò": "vaporizzare",
    "vaporo": "vaporare",
    "vaporosa": "vaporoso",
    "vaporose": "vaporoso",
    "vaporosi": "vaporoso",
    "vaporò": "vaporare",
    "vara": "varo",
    "varai": "varare",
    "varammo": "varare",
    "varan": "varare",
    "varando": "varare",
    "varano": "varare",
    "varante": "varare",
    "varanti": "varare",
    "varar": "varare",
    "vararon": "varare",
    "vararono": "varare",
    "varasse": "varare",
    "varasser": "varare",
    "varassero": "varare",
    "varassi": "varare",
    "varassimo": "varare",
    "varaste": "varare",
    "varasti": "varare",
    "varata": "varare",
    "varate": "varare",
    "varati": "varare",
    "varato": "varare",
    "varava": "varare",
    "varavamo": "varare",
    "varavan": "varare",
    "varavano": "varare",
    "varavate": "varare",
    "varavi": "varare",
    "varavo": "varare",
    "varca": "varcare",
    "varcai": "varcare",
    "varcammo": "varcare",
    "varcan": "varcare",
    "varcando": "varcare",
    "varcano": "varcare",
    "varcante": "varcare",
    "varcanti": "varcare",
    "varcar": "varcare",
    "varcaron": "varcare",
    "varcarono": "varcare",
    "varcasse": "varcare",
    "varcasser": "varcare",
    "varcassero": "varcare",
    "varcassi": "varcare",
    "varcassimo": "varcare",
    "varcaste": "varcare",
    "varcasti": "varcare",
    "varcata": "varcare",
    "varcate": "varcare",
    "varcati": "varcare",
    "varcato": "varcare",
    "varcava": "varcare",
    "varcavamo": "varcare",
    "varcavan": "varcare",
    "varcavano": "varcare",
    "varcavate": "varcare",
    "varcavi": "varcare",
    "varcavo": "varcare",
    "varcherai": "varcare",
    "varcheran": "varcare",
    "varcheranno": "varcare",
    "varcherebbe": "varcare",
    "varcherebber": "varcare",
    "varcherebbero": "varcare",
    "varcherei": "varcare",
    "varcheremmo": "varcare",
    "varcheremo": "varcare",
    "varchereste": "varcare",
    "varcheresti": "varcare",
    "varcherete": "varcare",
    "varcherà": "varcare",
    "varcherò": "varcare",
    "varchi": "varco",
    "varchiamo": "varcare",
    "varchiate": "varcare",
    "varchin": "varcare",
    "varchino": "varcare",
    "varco": "varcare",
    "varcò": "varcare",
    "vare": "varo",
    "varerai": "varare",
    "vareran": "varare",
    "vareranno": "varare",
    "varerebbe": "varare",
    "varerebber": "varare",
    "varerebbero": "varare",
    "varerei": "varare",
    "vareremmo": "varare",
    "vareremo": "varare",
    "varereste": "varare",
    "vareresti": "varare",
    "varerete": "varare",
    "varerà": "varare",
    "varerò": "varare",
    "varesina": "varesino",
    "varesine": "varesino",
    "varesini": "varesino",
    "vari": "varo",
    "varia": "vario",
    "variabili": "variabile",
    "variai": "variare",
    "variammo": "variare",
    "variamo": "variare",
    "varian": "variare",
    "variando": "variare",
    "variano": "variare",
    "variante": "variare",
    "varianti": "variare",
    "variar": "variare",
    "variaron": "variare",
    "variarono": "variare",
    "variasse": "variare",
    "variasser": "variare",
    "variassero": "variare",
    "variassi": "variare",
    "variassimo": "variare",
    "variaste": "variare",
    "variasti": "variare",
    "variata": "variato",
    "variate": "variato",
    "variati": "variato",
    "variato": "variare",
    "variava": "variare",
    "variavamo": "variare",
    "variavan": "variare",
    "variavano": "variare",
    "variavate": "variare",
    "variavi": "variare",
    "variavo": "variare",
    "variazioni": "variazione",
    "varicelle": "varicella",
    "varicosa": "varicoso",
    "varicose": "varicoso",
    "varicosi": "varicoso",
    "varie": "vario",
    "variegata": "variegato",
    "variegate": "variegato",
    "variegati": "variegato",
    "varierai": "variare",
    "varieran": "variare",
    "varieranno": "variare",
    "varierebbe": "variare",
    "varierebber": "variare",
    "varierebbero": "variare",
    "varierei": "variare",
    "varieremmo": "variare",
    "varieremo": "variare",
    "variereste": "variare",
    "varieresti": "variare",
    "varierete": "variare",
    "varierà": "variare",
    "varierò": "variare",
    "varin": "variare",
    "varino": "variare",
    "vario": "variare",
    "variopinta": "variopinto",
    "variopinte": "variopinto",
    "variopinti": "variopinto",
    "variò": "variare",
    "varo": "varare",
    "varrai": "valere",
    "varran": "valere",
    "varranno": "valere",
    "varrebbe": "valere",
    "varrebber": "valere",
    "varrebbero": "valere",
    "varrei": "valere",
    "varremmo": "valere",
    "varremo": "valere",
    "varreste": "valere",
    "varresti": "valere",
    "varrete": "valere",
    "varrà": "valere",
    "varrò": "valere",
    "varò": "varare",
    "vasariana": "vasariano",
    "vasariane": "vasariano",
    "vasariani": "vasariano",
    "vascelli": "vascello",
    "vasche": "vasca",
    "vaschette": "vaschetta",
    "vascolari": "vascolare",
    "vasconi": "vascone",
    "vasellami": "vasellame",
    "vasetti": "vasetto",
    "vasi": "vaso",
    "vassalla": "vassallo",
    "vassalle": "vassallo",
    "vassalli": "vassallo",
    "vassoi": "vassoio",
    "vasta": "vasto",
    "vaste": "vasto",
    "vasti": "vasto",
    "vati": "vate",
    "vaticana": "vaticano",
    "vaticane": "vaticano",
    "vaticani": "vaticano",
    "vaticanisti": "vaticanista",
    "vaticanofila": "vaticanofilo",
    "vaticanofile": "vaticanofilo",
    "vaticanofili": "vaticanofilo",
    "vaticina": "vaticinare",
    "vaticinai": "vaticinare",
    "vaticinammo": "vaticinare",
    "vaticinan": "vaticinare",
    "vaticinando": "vaticinare",
    "vaticinano": "vaticinare",
    "vaticinante": "vaticinare",
    "vaticinanti": "vaticinare",
    "vaticinar": "vaticinare",
    "vaticinaron": "vaticinare",
    "vaticinarono": "vaticinare",
    "vaticinasse": "vaticinare",
    "vaticinasser": "vaticinare",
    "vaticinassero": "vaticinare",
    "vaticinassi": "vaticinare",
    "vaticinassimo": "vaticinare",
    "vaticinaste": "vaticinare",
    "vaticinasti": "vaticinare",
    "vaticinata": "vaticinare",
    "vaticinate": "vaticinare",
    "vaticinati": "vaticinare",
    "vaticinato": "vaticinare",
    "vaticinava": "vaticinare",
    "vaticinavamo": "vaticinare",
    "vaticinavan": "vaticinare",
    "vaticinavano": "vaticinare",
    "vaticinavate": "vaticinare",
    "vaticinavi": "vaticinare",
    "vaticinavo": "vaticinare",
    "vaticinerai": "vaticinare",
    "vaticineran": "vaticinare",
    "vaticineranno": "vaticinare",
    "vaticinerebbe": "vaticinare",
    "vaticinerebber": "vaticinare",
    "vaticinerebbero": "vaticinare",
    "vaticinerei": "vaticinare",
    "vaticineremmo": "vaticinare",
    "vaticineremo": "vaticinare",
    "vaticinereste": "vaticinare",
    "vaticineresti": "vaticinare",
    "vaticinerete": "vaticinare",
    "vaticinerà": "vaticinare",
    "vaticinerò": "vaticinare",
    "vaticini": "vaticinio",
    "vaticiniamo": "vaticinare",
    "vaticiniate": "vaticinare",
    "vaticinin": "vaticinare",
    "vaticinino": "vaticinare",
    "vaticino": "vaticinare",
    "vaticinò": "vaticinare",
    "vaudevilles": "vaudeville",
    "vecchi": "vecchio",
    "vecchia": "vecchio",
    "vecchiaie": "vecchiaia",
    "vecchie": "vecchio",
    "vecchiette": "vecchietta",
    "vecchietti": "vecchietto",
    "vecchiezze": "vecchiezza",
    "vecchine": "vecchina",
    "vecchioni": "vecchione",
    "vecchiotta": "vecchiotto",
    "vecchiotte": "vecchiotto",
    "vecchiotti": "vecchiotto",
    "veci": "vece",
    "veda": "vedere",
    "vedan": "vedere",
    "vedano": "vedere",
    "vede": "vedere",
    "vedemmo": "vedere",
    "vedendo": "vedere",
    "vedente": "vedere",
    "vedenti": "vedere",
    "veder": "vedere",
    "vedesse": "vedere",
    "vedesser": "vedere",
    "vedessero": "vedere",
    "vedessi": "vedere",
    "vedessimo": "vedere",
    "vedeste": "vedere",
    "vedesti": "vedere",
    "vedete": "vedere",
    "vedette": "vedetta",
    "vedeva": "vedere",
    "vedevamo": "vedere",
    "vedevan": "vedere",
    "vedevano": "vedere",
    "vedevate": "vedere",
    "vedevi": "vedere",
    "vedevo": "vedere",
    "vedi": "vedere",
    "vediamo": "vedere",
    "vediate": "vedere",
    "vedo": "vedere",
    "vedon": "vedere",
    "vedono": "vedere",
    "vedova": "vedovo",
    "vedovai": "vedovare",
    "vedovammo": "vedovare",
    "vedovan": "vedovare",
    "vedovando": "vedovare",
    "vedovano": "vedovare",
    "vedovante": "vedovare",
    "vedovanti": "vedovare",
    "vedovanze": "vedovanza",
    "vedovar": "vedovare",
    "vedovaron": "vedovare",
    "vedovarono": "vedovare",
    "vedovasse": "vedovare",
    "vedovasser": "vedovare",
    "vedovassero": "vedovare",
    "vedovassi": "vedovare",
    "vedovassimo": "vedovare",
    "vedovaste": "vedovare",
    "vedovasti": "vedovare",
    "vedovata": "vedovare",
    "vedovate": "vedovare",
    "vedovati": "vedovare",
    "vedovato": "vedovare",
    "vedovava": "vedovare",
    "vedovavamo": "vedovare",
    "vedovavan": "vedovare",
    "vedovavano": "vedovare",
    "vedovavate": "vedovare",
    "vedovavi": "vedovare",
    "vedovavo": "vedovare",
    "vedove": "vedovo",
    "vedoverai": "vedovare",
    "vedoveran": "vedovare",
    "vedoveranno": "vedovare",
    "vedoverebbe": "vedovare",
    "vedoverebber": "vedovare",
    "vedoverebbero": "vedovare",
    "vedoverei": "vedovare",
    "vedoveremmo": "vedovare",
    "vedoveremo": "vedovare",
    "vedovereste": "vedovare",
    "vedoveresti": "vedovare",
    "vedoverete": "vedovare",
    "vedoverà": "vedovare",
    "vedoverò": "vedovare",
    "vedovi": "vedovo",
    "vedoviamo": "vedovare",
    "vedoviate": "vedovare",
    "vedovili": "vedovile",
    "vedovin": "vedovare",
    "vedovino": "vedovare",
    "vedovo": "vedovare",
    "vedovò": "vedovare",
    "vedrai": "vedere",
    "vedran": "vedere",
    "vedranno": "vedere",
    "vedrebbe": "vedere",
    "vedrebber": "vedere",
    "vedrebbero": "vedere",
    "vedrei": "vedere",
    "vedremmo": "vedere",
    "vedremo": "vedere",
    "vedreste": "vedere",
    "vedresti": "vedere",
    "vedrete": "vedere",
    "vedrà": "vedere",
    "vedrò": "vedere",
    "veduta": "vedere",
    "vedute": "veduta",
    "veduti": "vedere",
    "vedutisti": "vedutista",
    "veduto": "vedere",
    "veementi": "veemente",
    "veemenze": "veemenza",
    "vegeta": "vegeto",
    "vegetai": "vegetare",
    "vegetali": "vegetale",
    "vegetammo": "vegetare",
    "vegetan": "vegetare",
    "vegetando": "vegetare",
    "vegetano": "vegetare",
    "vegetante": "vegetare",
    "vegetanti": "vegetare",
    "vegetar": "vegetare",
    "vegetariana": "vegetariano",
    "vegetariane": "vegetariano",
    "vegetariani": "vegetariano",
    "vegetaron": "vegetare",
    "vegetarono": "vegetare",
    "vegetasse": "vegetare",
    "vegetasser": "vegetare",
    "vegetassero": "vegetare",
    "vegetassi": "vegetare",
    "vegetassimo": "vegetare",
    "vegetaste": "vegetare",
    "vegetasti": "vegetare",
    "vegetata": "vegetare",
    "vegetate": "vegetare",
    "vegetati": "vegetare",
    "vegetativa": "vegetativo",
    "vegetative": "vegetativo",
    "vegetativi": "vegetativo",
    "vegetato": "vegetare",
    "vegetava": "vegetare",
    "vegetavamo": "vegetare",
    "vegetavan": "vegetare",
    "vegetavano": "vegetare",
    "vegetavate": "vegetare",
    "vegetavi": "vegetare",
    "vegetavo": "vegetare",
    "vegetazioni": "vegetazione",
    "vegete": "vegeto",
    "vegeterai": "vegetare",
    "vegeteran": "vegetare",
    "vegeteranno": "vegetare",
    "vegeterebbe": "vegetare",
    "vegeterebber": "vegetare",
    "vegeterebbero": "vegetare",
    "vegeterei": "vegetare",
    "vegeteremmo": "vegetare",
    "vegeteremo": "vegetare",
    "vegetereste": "vegetare",
    "vegeteresti": "vegetare",
    "vegeterete": "vegetare",
    "vegeterà": "vegetare",
    "vegeterò": "vegetare",
    "vegeti": "vegeto",
    "vegetiamo": "vegetare",
    "vegetiate": "vegetare",
    "vegetin": "vegetare",
    "vegetino": "vegetare",
    "vegeto": "vegetare",
    "vegetò": "vegetare",
    "veggenti": "veggente",
    "vegli": "vegliare",
    "veglia": "vegliare",
    "vegliai": "vegliare",
    "vegliammo": "vegliare",
    "vegliamo": "vegliare",
    "veglian": "vegliare",
    "vegliando": "vegliare",
    "vegliano": "vegliare",
    "vegliante": "vegliare",
    "veglianti": "vegliare",
    "vegliar": "vegliare",
    "vegliardi": "vegliardo",
    "vegliaron": "vegliare",
    "vegliarono": "vegliare",
    "vegliasse": "vegliare",
    "vegliasser": "vegliare",
    "vegliassero": "vegliare",
    "vegliassi": "vegliare",
    "vegliassimo": "vegliare",
    "vegliaste": "vegliare",
    "vegliasti": "vegliare",
    "vegliata": "vegliare",
    "vegliate": "vegliare",
    "vegliati": "vegliare",
    "vegliato": "vegliare",
    "vegliava": "vegliare",
    "vegliavamo": "vegliare",
    "vegliavan": "vegliare",
    "vegliavano": "vegliare",
    "vegliavate": "vegliare",
    "vegliavi": "vegliare",
    "vegliavo": "vegliare",
    "veglie": "veglia",
    "veglierai": "vegliare",
    "veglieran": "vegliare",
    "veglieranno": "vegliare",
    "veglierebbe": "vegliare",
    "veglierebber": "vegliare",
    "veglierebbero": "vegliare",
    "veglierei": "vegliare",
    "veglieremmo": "vegliare",
    "veglieremo": "vegliare",
    "vegliereste": "vegliare",
    "veglieresti": "vegliare",
    "veglierete": "vegliare",
    "veglierà": "vegliare",
    "veglierò": "vegliare",
    "veglin": "vegliare",
    "veglino": "vegliare",
    "veglio": "vegliare",
    "veglioni": "veglione",
    "vegliò": "vegliare",
    "veicola": "veicolare",
    "veicolai": "veicolare",
    "veicolammo": "veicolare",
    "veicolan": "veicolare",
    "veicolando": "veicolare",
    "veicolano": "veicolare",
    "veicolante": "veicolare",
    "veicolanti": "veicolare",
    "veicolar": "veicolare",
    "veicolari": "veicolare",
    "veicolaron": "veicolare",
    "veicolarono": "veicolare",
    "veicolasse": "veicolare",
    "veicolasser": "veicolare",
    "veicolassero": "veicolare",
    "veicolassi": "veicolare",
    "veicolassimo": "veicolare",
    "veicolaste": "veicolare",
    "veicolasti": "veicolare",
    "veicolata": "veicolare",
    "veicolate": "veicolare",
    "veicolati": "veicolare",
    "veicolato": "veicolare",
    "veicolava": "veicolare",
    "veicolavamo": "veicolare",
    "veicolavan": "veicolare",
    "veicolavano": "veicolare",
    "veicolavate": "veicolare",
    "veicolavi": "veicolare",
    "veicolavo": "veicolare",
    "veicolerai": "veicolare",
    "veicoleran": "veicolare",
    "veicoleranno": "veicolare",
    "veicolerebbe": "veicolare",
    "veicolerebber": "veicolare",
    "veicolerebbero": "veicolare",
    "veicolerei": "veicolare",
    "veicoleremmo": "veicolare",
    "veicoleremo": "veicolare",
    "veicolereste": "veicolare",
    "veicoleresti": "veicolare",
    "veicolerete": "veicolare",
    "veicolerà": "veicolare",
    "veicolerò": "veicolare",
    "veicoli": "veicolo",
    "veicoliamo": "veicolare",
    "veicoliate": "veicolare",
    "veicolin": "veicolare",
    "veicolino": "veicolare",
    "veicolo": "veicolare",
    "veicolò": "veicolare",
    "vela": "velare",
    "velai": "velare",
    "velammo": "velare",
    "velan": "velare",
    "velando": "velare",
    "velano": "velare",
    "velante": "velare",
    "velanti": "velare",
    "velar": "velare",
    "velari": "velario",
    "velaron": "velare",
    "velarono": "velare",
    "velasse": "velare",
    "velasser": "velare",
    "velassero": "velare",
    "velassi": "velare",
    "velassimo": "velare",
    "velaste": "velare",
    "velasti": "velare",
    "velata": "velato",
    "velate": "velato",
    "velati": "velato",
    "velatini": "velatino",
    "velato": "velare",
    "velature": "velatura",
    "velava": "velare",
    "velavamo": "velare",
    "velavan": "velare",
    "velavano": "velare",
    "velavate": "velare",
    "velavi": "velare",
    "velavo": "velare",
    "vele": "vela",
    "veleggerai": "veleggiare",
    "veleggeran": "veleggiare",
    "veleggeranno": "veleggiare",
    "veleggerebbe": "veleggiare",
    "veleggerebber": "veleggiare",
    "veleggerebbero": "veleggiare",
    "veleggerei": "veleggiare",
    "veleggeremmo": "veleggiare",
    "veleggeremo": "veleggiare",
    "veleggereste": "veleggiare",
    "veleggeresti": "veleggiare",
    "veleggerete": "veleggiare",
    "veleggerà": "veleggiare",
    "veleggerò": "veleggiare",
    "veleggi": "veleggiare",
    "veleggia": "veleggiare",
    "veleggiai": "veleggiare",
    "veleggiammo": "veleggiare",
    "veleggiamo": "veleggiare",
    "veleggian": "veleggiare",
    "veleggiando": "veleggiare",
    "veleggiano": "veleggiare",
    "veleggiante": "veleggiare",
    "veleggianti": "veleggiare",
    "veleggiar": "veleggiare",
    "veleggiaron": "veleggiare",
    "veleggiarono": "veleggiare",
    "veleggiasse": "veleggiare",
    "veleggiasser": "veleggiare",
    "veleggiassero": "veleggiare",
    "veleggiassi": "veleggiare",
    "veleggiassimo": "veleggiare",
    "veleggiaste": "veleggiare",
    "veleggiasti": "veleggiare",
    "veleggiata": "veleggiare",
    "veleggiate": "veleggiare",
    "veleggiati": "veleggiare",
    "veleggiato": "veleggiare",
    "veleggiava": "veleggiare",
    "veleggiavamo": "veleggiare",
    "veleggiavan": "veleggiare",
    "veleggiavano": "veleggiare",
    "veleggiavate": "veleggiare",
    "veleggiavi": "veleggiare",
    "veleggiavo": "veleggiare",
    "veleggin": "veleggiare",
    "veleggino": "veleggiare",
    "veleggio": "veleggiare",
    "veleggiò": "veleggiare",
    "veleni": "veleno",
    "velenosa": "velenoso",
    "velenose": "velenoso",
    "velenosi": "velenoso",
    "velerai": "velare",
    "veleran": "velare",
    "veleranno": "velare",
    "velerebbe": "velare",
    "velerebber": "velare",
    "velerebbero": "velare",
    "velerei": "velare",
    "veleremmo": "velare",
    "veleremo": "velare",
    "velereste": "velare",
    "veleresti": "velare",
    "velerete": "velare",
    "velerà": "velare",
    "velerò": "velare",
    "velette": "veletta",
    "veli": "velo",
    "veliamo": "velare",
    "veliate": "velare",
    "velica": "velico",
    "veliche": "velico",
    "velici": "velico",
    "veliera": "veliero",
    "veliere": "veliero",
    "velieri": "veliero",
    "velin": "velare",
    "veline": "velina",
    "velino": "velare",
    "velisti": "velista",
    "velivola": "velivolo",
    "velivole": "velivolo",
    "velivoli": "velivolo",
    "velleitari": "velleitario",
    "velleitaria": "velleitario",
    "velleitarie": "velleitario",
    "velleitarismi": "velleitarismo",
    "velli": "vello",
    "vellica": "vellicare",
    "vellicai": "vellicare",
    "vellicammo": "vellicare",
    "vellican": "vellicare",
    "vellicando": "vellicare",
    "vellicano": "vellicare",
    "vellicante": "vellicare",
    "vellicanti": "vellicare",
    "vellicar": "vellicare",
    "vellicaron": "vellicare",
    "vellicarono": "vellicare",
    "vellicasse": "vellicare",
    "vellicasser": "vellicare",
    "vellicassero": "vellicare",
    "vellicassi": "vellicare",
    "vellicassimo": "vellicare",
    "vellicaste": "vellicare",
    "vellicasti": "vellicare",
    "vellicata": "vellicare",
    "vellicate": "vellicare",
    "vellicati": "vellicare",
    "vellicato": "vellicare",
    "vellicava": "vellicare",
    "vellicavamo": "vellicare",
    "vellicavan": "vellicare",
    "vellicavano": "vellicare",
    "vellicavate": "vellicare",
    "vellicavi": "vellicare",
    "vellicavo": "vellicare",
    "vellicherai": "vellicare",
    "vellicheran": "vellicare",
    "vellicheranno": "vellicare",
    "vellicherebbe": "vellicare",
    "vellicherebber": "vellicare",
    "vellicherebbero": "vellicare",
    "vellicherei": "vellicare",
    "vellicheremmo": "vellicare",
    "vellicheremo": "vellicare",
    "vellichereste": "vellicare",
    "vellicheresti": "vellicare",
    "vellicherete": "vellicare",
    "vellicherà": "vellicare",
    "vellicherò": "vellicare",
    "vellichi": "vellicare",
    "vellichiamo": "vellicare",
    "vellichiate": "vellicare",
    "vellichin": "vellicare",
    "vellichino": "vellicare",
    "vellico": "vellicare",
    "vellicò": "vellicare",
    "velluta": "velluto",
    "vellutai": "vellutare",
    "vellutammo": "vellutare",
    "vellutan": "vellutare",
    "vellutando": "vellutare",
    "vellutano": "vellutare",
    "vellutante": "vellutare",
    "vellutanti": "vellutare",
    "vellutar": "vellutare",
    "vellutaron": "vellutare",
    "vellutarono": "vellutare",
    "vellutasse": "vellutare",
    "vellutasser": "vellutare",
    "vellutassero": "vellutare",
    "vellutassi": "vellutare",
    "vellutassimo": "vellutare",
    "vellutaste": "vellutare",
    "vellutasti": "vellutare",
    "vellutata": "vellutato",
    "vellutate": "vellutato",
    "vellutati": "vellutato",
    "vellutato": "vellutare",
    "vellutava": "vellutare",
    "vellutavamo": "vellutare",
    "vellutavan": "vellutare",
    "vellutavano": "vellutare",
    "vellutavate": "vellutare",
    "vellutavi": "vellutare",
    "vellutavo": "vellutare",
    "vellute": "velluto",
    "velluterai": "vellutare",
    "velluteran": "vellutare",
    "velluteranno": "vellutare",
    "velluterebbe": "vellutare",
    "velluterebber": "vellutare",
    "velluterebbero": "vellutare",
    "velluterei": "vellutare",
    "velluteremmo": "vellutare",
    "velluteremo": "vellutare",
    "vellutereste": "vellutare",
    "velluteresti": "vellutare",
    "velluterete": "vellutare",
    "velluterà": "vellutare",
    "velluterò": "vellutare",
    "velluti": "velluto",
    "vellutiamo": "vellutare",
    "vellutiate": "vellutare",
    "vellutin": "vellutare",
    "vellutino": "vellutare",
    "velluto": "vellutare",
    "vellutò": "vellutare",
    "velo": "velare",
    "veloci": "veloce",
    "velociste": "velocista",
    "velocisti": "velocista",
    "velodromi": "velodromo",
    "velò": "velare",
    "vena": "venare",
    "venai": "venare",
    "venali": "venale",
    "venammo": "venare",
    "venan": "venare",
    "venando": "venare",
    "venano": "venare",
    "venante": "venare",
    "venanti": "venare",
    "venar": "venare",
    "venaron": "venare",
    "venarono": "venare",
    "venasse": "venare",
    "venasser": "venare",
    "venassero": "venare",
    "venassi": "venare",
    "venassimo": "venare",
    "venaste": "venare",
    "venasti": "venare",
    "venata": "venato",
    "venate": "venato",
    "venati": "venato",
    "venato": "venare",
    "venatori": "venatorio",
    "venatoria": "venatorio",
    "venatorie": "venatorio",
    "venature": "venatura",
    "venava": "venare",
    "venavamo": "venare",
    "venavan": "venare",
    "venavano": "venare",
    "venavate": "venare",
    "venavi": "venare",
    "venavo": "venare",
    "venda": "vendere",
    "vendan": "vendere",
    "vendano": "vendere",
    "vende": "vendere",
    "vendemmi": "vendemmiare",
    "vendemmia": "vendemmiare",
    "vendemmiai": "vendemmiare",
    "vendemmiammo": "vendemmiare",
    "vendemmiamo": "vendemmiare",
    "vendemmian": "vendemmiare",
    "vendemmiando": "vendemmiare",
    "vendemmiano": "vendemmiare",
    "vendemmiante": "vendemmiare",
    "vendemmianti": "vendemmiare",
    "vendemmiar": "vendemmiare",
    "vendemmiaron": "vendemmiare",
    "vendemmiarono": "vendemmiare",
    "vendemmiasse": "vendemmiare",
    "vendemmiasser": "vendemmiare",
    "vendemmiassero": "vendemmiare",
    "vendemmiassi": "vendemmiare",
    "vendemmiassimo": "vendemmiare",
    "vendemmiaste": "vendemmiare",
    "vendemmiasti": "vendemmiare",
    "vendemmiata": "vendemmiare",
    "vendemmiate": "vendemmiare",
    "vendemmiati": "vendemmiare",
    "vendemmiato": "vendemmiare",
    "vendemmiava": "vendemmiare",
    "vendemmiavamo": "vendemmiare",
    "vendemmiavan": "vendemmiare",
    "vendemmiavano": "vendemmiare",
    "vendemmiavate": "vendemmiare",
    "vendemmiavi": "vendemmiare",
    "vendemmiavo": "vendemmiare",
    "vendemmie": "vendemmia",
    "vendemmierai": "vendemmiare",
    "vendemmieran": "vendemmiare",
    "vendemmieranno": "vendemmiare",
    "vendemmierebbe": "vendemmiare",
    "vendemmierebber": "vendemmiare",
    "vendemmierebbero": "vendemmiare",
    "vendemmierei": "vendemmiare",
    "vendemmieremmo": "vendemmiare",
    "vendemmieremo": "vendemmiare",
    "vendemmiereste": "vendemmiare",
    "vendemmieresti": "vendemmiare",
    "vendemmierete": "vendemmiare",
    "vendemmierà": "vendemmiare",
    "vendemmierò": "vendemmiare",
    "vendemmin": "vendemmiare",
    "vendemmino": "vendemmiare",
    "vendemmio": "vendemmiare",
    "vendemmiò": "vendemmiare",
    "vendemmo": "vendere",
    "vendendo": "vendere",
    "vendente": "vendere",
    "vendenti": "vendere",
    "vender": "vendere",
    "venderai": "vendere",
    "venderan": "vendere",
    "venderanno": "vendere",
    "venderebbe": "vendere",
    "venderebber": "vendere",
    "venderebbero": "vendere",
    "venderei": "vendere",
    "venderemmo": "vendere",
    "venderemo": "vendere",
    "vendereste": "vendere",
    "venderesti": "vendere",
    "venderete": "vendere",
    "venderà": "vendere",
    "venderò": "vendere",
    "vendesse": "vendere",
    "vendesser": "vendere",
    "vendessero": "vendere",
    "vendessi": "vendere",
    "vendessimo": "vendere",
    "vendeste": "vendere",
    "vendesti": "vendere",
    "vendete": "vendere",
    "vendette": "vendetta",
    "vendetter": "vendere",
    "vendettero": "vendere",
    "vendetti": "vendere",
    "vendeva": "vendere",
    "vendevamo": "vendere",
    "vendevan": "vendere",
    "vendevano": "vendere",
    "vendevate": "vendere",
    "vendevi": "vendere",
    "vendevo": "vendere",
    "vendi": "vendere",
    "vendiamo": "vendere",
    "vendiate": "vendere",
    "vendibili": "vendibile",
    "vendica": "vendicare",
    "vendicai": "vendicare",
    "vendicammo": "vendicare",
    "vendican": "vendicare",
    "vendicando": "vendicare",
    "vendicano": "vendicare",
    "vendicante": "vendicare",
    "vendicanti": "vendicare",
    "vendicar": "vendicare",
    "vendicaron": "vendicare",
    "vendicarono": "vendicare",
    "vendicasse": "vendicare",
    "vendicasser": "vendicare",
    "vendicassero": "vendicare",
    "vendicassi": "vendicare",
    "vendicassimo": "vendicare",
    "vendicaste": "vendicare",
    "vendicasti": "vendicare",
    "vendicata": "vendicare",
    "vendicate": "vendicare",
    "vendicati": "vendicare",
    "vendicativa": "vendicativo",
    "vendicative": "vendicativo",
    "vendicativi": "vendicativo",
    "vendicato": "vendicare",
    "vendicatori": "vendicatore",
    "vendicatrice": "vendicatore",
    "vendicatrici": "vendicatore",
    "vendicava": "vendicare",
    "vendicavamo": "vendicare",
    "vendicavan": "vendicare",
    "vendicavano": "vendicare",
    "vendicavate": "vendicare",
    "vendicavi": "vendicare",
    "vendicavo": "vendicare",
    "vendicherai": "vendicare",
    "vendicheran": "vendicare",
    "vendicheranno": "vendicare",
    "vendicherebbe": "vendicare",
    "vendicherebber": "vendicare",
    "vendicherebbero": "vendicare",
    "vendicherei": "vendicare",
    "vendicheremmo": "vendicare",
    "vendicheremo": "vendicare",
    "vendichereste": "vendicare",
    "vendicheresti": "vendicare",
    "vendicherete": "vendicare",
    "vendicherà": "vendicare",
    "vendicherò": "vendicare",
    "vendichi": "vendicare",
    "vendichiamo": "vendicare",
    "vendichiate": "vendicare",
    "vendichin": "vendicare",
    "vendichino": "vendicare",
    "vendico": "vendicare",
    "vendicò": "vendicare",
    "vendite": "vendita",
    "venditori": "venditore",
    "venditrice": "venditore",
    "venditrici": "venditrice",
    "vendo": "vendere",
    "vendon": "vendere",
    "vendono": "vendere",
    "venduta": "venduto",
    "vendute": "venduto",
    "venduti": "venduto",
    "venduto": "vendere",
    "vene": "vena",
    "venendo": "venire",
    "venente": "venire",
    "venenti": "venire",
    "venera": "venerare",
    "venerabili": "venerabile",
    "venerai": "venerare",
    "venerammo": "venerare",
    "veneran": "venerare",
    "veneranda": "venerando",
    "venerande": "venerando",
    "venerandi": "venerando",
    "venerando": "venerare",
    "veneranno": "venare",
    "venerano": "venerare",
    "venerante": "venerare",
    "veneranti": "venerare",
    "venerar": "venerare",
    "veneraron": "venerare",
    "venerarono": "venerare",
    "venerasse": "venerare",
    "venerasser": "venerare",
    "venerassero": "venerare",
    "venerassi": "venerare",
    "venerassimo": "venerare",
    "veneraste": "venerare",
    "venerasti": "venerare",
    "venerata": "venerare",
    "venerate": "venerare",
    "venerati": "venerato",
    "venerato": "venerare",
    "venerava": "venerare",
    "veneravamo": "venerare",
    "veneravan": "venerare",
    "veneravano": "venerare",
    "veneravate": "venerare",
    "veneravi": "venerare",
    "veneravo": "venerare",
    "venerazioni": "venerazione",
    "venerea": "venereo",
    "venerebbe": "venare",
    "venerebber": "venare",
    "venerebbero": "venare",
    "veneree": "venereo",
    "venerei": "venereo",
    "veneremmo": "venare",
    "veneremo": "venare",
    "venererai": "venerare",
    "venereran": "venerare",
    "venereranno": "venerare",
    "venererebbe": "venerare",
    "venererebber": "venerare",
    "venererebbero": "venerare",
    "venererei": "venerare",
    "venereremmo": "venerare",
    "venereremo": "venerare",
    "venerereste": "venerare",
    "venereresti": "venerare",
    "venererete": "venerare",
    "venererà": "venerare",
    "venererò": "venerare",
    "venereste": "venare",
    "veneresti": "venare",
    "venerete": "venare",
    "veneri": "venere",
    "veneriamo": "venerare",
    "veneriate": "venerare",
    "venerin": "venerare",
    "venerino": "venerare",
    "venero": "venerare",
    "venerà": "venare",
    "venerò": "venerare",
    "veneta": "veneto",
    "venete": "veneto",
    "veneti": "veneto",
    "veneto-romagnola": "veneto-romagnolo",
    "veneto-romagnole": "veneto-romagnolo",
    "veneto-romagnoli": "veneto-romagnolo",
    "veneziana": "veneziano",
    "veneziane": "veneziano",
    "veneziani": "veneziano",
    "venezuelana": "venezuelano",
    "venezuelane": "venezuelano",
    "venezuelani": "venezuelano",
    "venga": "venire",
    "vengan": "venire",
    "vengano": "venire",
    "vengo": "venire",
    "vengon": "venire",
    "vengono": "venire",
    "veni": "venare",
    "veniali": "veniale",
    "veniamo": "venire",
    "veniate": "venire",
    "veniente": "venire",
    "venienti": "venire",
    "venimmo": "venire",
    "venin": "venare",
    "venino": "venare",
    "venir": "venire",
    "venisse": "venire",
    "venisser": "venire",
    "venissero": "venire",
    "venissi": "venire",
    "venissimo": "venire",
    "veniste": "venire",
    "venisti": "venire",
    "venite": "venire",
    "veniva": "venire",
    "venivamo": "venire",
    "venivan": "venire",
    "venivano": "venire",
    "venivate": "venire",
    "venivi": "venire",
    "venivo": "venire",
    "venne": "venire",
    "venner": "venire",
    "vennero": "venire",
    "venni": "venire",
    "veno": "venare",
    "ventagli": "ventaglio",
    "ventate": "ventata",
    "ventennali": "ventennale",
    "ventenni": "ventennio",
    "ventesima": "ventesimo",
    "ventesime": "ventesimo",
    "ventesimi": "ventesimo",
    "venti": "vento",
    "venticelli": "venticello",
    "venticinquennali": "venticinquennale",
    "venticinquenni": "venticinquenne",
    "venticinquesima": "venticinquesimo",
    "venticinquesime": "venticinquesimo",
    "venticinquesimi": "venticinquesimo",
    "ventiduenni": "ventiduenne",
    "ventiduesima": "ventiduesimo",
    "ventiduesime": "ventiduesimo",
    "ventiduesimi": "ventiduesimo",
    "ventila": "ventilare",
    "ventilai": "ventilare",
    "ventilammo": "ventilare",
    "ventilan": "ventilare",
    "ventilando": "ventilare",
    "ventilano": "ventilare",
    "ventilante": "ventilare",
    "ventilanti": "ventilare",
    "ventilar": "ventilare",
    "ventilaron": "ventilare",
    "ventilarono": "ventilare",
    "ventilasse": "ventilare",
    "ventilasser": "ventilare",
    "ventilassero": "ventilare",
    "ventilassi": "ventilare",
    "ventilassimo": "ventilare",
    "ventilaste": "ventilare",
    "ventilasti": "ventilare",
    "ventilata": "ventilato",
    "ventilate": "ventilato",
    "ventilati": "ventilato",
    "ventilato": "ventilare",
    "ventilatori": "ventilatore",
    "ventilatrice": "ventilatore",
    "ventilatrici": "ventilatore",
    "ventilava": "ventilare",
    "ventilavamo": "ventilare",
    "ventilavan": "ventilare",
    "ventilavano": "ventilare",
    "ventilavate": "ventilare",
    "ventilavi": "ventilare",
    "ventilavo": "ventilare",
    "ventilazioni": "ventilazione",
    "ventilerai": "ventilare",
    "ventileran": "ventilare",
    "ventileranno": "ventilare",
    "ventilerebbe": "ventilare",
    "ventilerebber": "ventilare",
    "ventilerebbero": "ventilare",
    "ventilerei": "ventilare",
    "ventileremmo": "ventilare",
    "ventileremo": "ventilare",
    "ventilereste": "ventilare",
    "ventileresti": "ventilare",
    "ventilerete": "ventilare",
    "ventilerà": "ventilare",
    "ventilerò": "ventilare",
    "ventili": "ventilare",
    "ventiliamo": "ventilare",
    "ventiliate": "ventilare",
    "ventilin": "ventilare",
    "ventilino": "ventilare",
    "ventilo": "ventilare",
    "ventilò": "ventilare",
    "ventine": "ventina",
    "ventinovesima": "ventinovesimo",
    "ventinovesime": "ventinovesimo",
    "ventinovesimi": "ventinovesimo",
    "ventiquattresima": "ventiquattresimo",
    "ventiquattresime": "ventiquattresimo",
    "ventiquattresimi": "ventiquattresimo",
    "ventiseienni": "ventiseienne",
    "ventiseiesima": "ventiseiesimo",
    "ventiseiesime": "ventiseiesimo",
    "ventiseiesimi": "ventiseiesimo",
    "ventisettesima": "ventisettesimo",
    "ventisettesime": "ventisettesimo",
    "ventisettesimi": "ventisettesimo",
    "ventitreenni": "ventitreenne",
    "ventitreesima": "ventitreesimo",
    "ventitreesime": "ventitreesimo",
    "ventitreesimi": "ventitreesimo",
    "ventosa": "ventoso",
    "ventose": "ventoso",
    "ventosi": "ventoso",
    "ventottesima": "ventottesimo",
    "ventottesime": "ventottesimo",
    "ventottesimi": "ventottesimo",
    "ventrali": "ventrale",
    "ventri": "ventre",
    "ventricolari": "ventricolare",
    "ventricoli": "ventricolo",
    "ventunenni": "ventunenne",
    "ventunesima": "ventunesimo",
    "ventunesime": "ventunesimo",
    "ventunesimi": "ventunesimo",
    "ventura": "venturo",
    "venture": "venturo",
    "ventures": "venture",
    "venturi": "venturo",
    "venusiana": "venusiano",
    "venusiane": "venusiano",
    "venusiani": "venusiano",
    "venuta": "venuto",
    "venute": "venuto",
    "venuti": "venuto",
    "venuto": "venire",
    "venò": "venare",
    "vera": "vero",
    "veraci": "verace",
    "verande": "veranda",
    "verbali": "verbale",
    "verbalizza": "verbalizzare",
    "verbalizzai": "verbalizzare",
    "verbalizzammo": "verbalizzare",
    "verbalizzan": "verbalizzare",
    "verbalizzando": "verbalizzare",
    "verbalizzano": "verbalizzare",
    "verbalizzante": "verbalizzare",
    "verbalizzanti": "verbalizzare",
    "verbalizzar": "verbalizzare",
    "verbalizzaron": "verbalizzare",
    "verbalizzarono": "verbalizzare",
    "verbalizzasse": "verbalizzare",
    "verbalizzasser": "verbalizzare",
    "verbalizzassero": "verbalizzare",
    "verbalizzassi": "verbalizzare",
    "verbalizzassimo": "verbalizzare",
    "verbalizzaste": "verbalizzare",
    "verbalizzasti": "verbalizzare",
    "verbalizzata": "verbalizzare",
    "verbalizzate": "verbalizzare",
    "verbalizzati": "verbalizzare",
    "verbalizzato": "verbalizzare",
    "verbalizzava": "verbalizzare",
    "verbalizzavamo": "verbalizzare",
    "verbalizzavan": "verbalizzare",
    "verbalizzavano": "verbalizzare",
    "verbalizzavate": "verbalizzare",
    "verbalizzavi": "verbalizzare",
    "verbalizzavo": "verbalizzare",
    "verbalizzazioni": "verbalizzazione",
    "verbalizzerai": "verbalizzare",
    "verbalizzeran": "verbalizzare",
    "verbalizzeranno": "verbalizzare",
    "verbalizzerebbe": "verbalizzare",
    "verbalizzerebber": "verbalizzare",
    "verbalizzerebbero": "verbalizzare",
    "verbalizzerei": "verbalizzare",
    "verbalizzeremmo": "verbalizzare",
    "verbalizzeremo": "verbalizzare",
    "verbalizzereste": "verbalizzare",
    "verbalizzeresti": "verbalizzare",
    "verbalizzerete": "verbalizzare",
    "verbalizzerà": "verbalizzare",
    "verbalizzerò": "verbalizzare",
    "verbalizzi": "verbalizzare",
    "verbalizziamo": "verbalizzare",
    "verbalizziate": "verbalizzare",
    "verbalizzin": "verbalizzare",
    "verbalizzino": "verbalizzare",
    "verbalizzo": "verbalizzare",
    "verbalizzò": "verbalizzare",
    "verbi": "verbo",
    "verbosa": "verboso",
    "verbose": "verboso",
    "verbosi": "verboso",
    "vercellesi": "vercellese",
    "verdeazzurra": "verdeazzurro",
    "verdeazzurre": "verdeazzurro",
    "verdeazzurri": "verdeazzurro",
    "verdeggerai": "verdeggiare",
    "verdeggeran": "verdeggiare",
    "verdeggeranno": "verdeggiare",
    "verdeggerebbe": "verdeggiare",
    "verdeggerebber": "verdeggiare",
    "verdeggerebbero": "verdeggiare",
    "verdeggerei": "verdeggiare",
    "verdeggeremmo": "verdeggiare",
    "verdeggeremo": "verdeggiare",
    "verdeggereste": "verdeggiare",
    "verdeggeresti": "verdeggiare",
    "verdeggerete": "verdeggiare",
    "verdeggerà": "verdeggiare",
    "verdeggerò": "verdeggiare",
    "verdeggi": "verdeggiare",
    "verdeggia": "verdeggiare",
    "verdeggiai": "verdeggiare",
    "verdeggiammo": "verdeggiare",
    "verdeggiamo": "verdeggiare",
    "verdeggian": "verdeggiare",
    "verdeggiando": "verdeggiare",
    "verdeggiano": "verdeggiare",
    "verdeggiante": "verdeggiare",
    "verdeggianti": "verdeggiare",
    "verdeggiar": "verdeggiare",
    "verdeggiaron": "verdeggiare",
    "verdeggiarono": "verdeggiare",
    "verdeggiasse": "verdeggiare",
    "verdeggiasser": "verdeggiare",
    "verdeggiassero": "verdeggiare",
    "verdeggiassi": "verdeggiare",
    "verdeggiassimo": "verdeggiare",
    "verdeggiaste": "verdeggiare",
    "verdeggiasti": "verdeggiare",
    "verdeggiata": "verdeggiare",
    "verdeggiate": "verdeggiare",
    "verdeggiati": "verdeggiare",
    "verdeggiato": "verdeggiare",
    "verdeggiava": "verdeggiare",
    "verdeggiavamo": "verdeggiare",
    "verdeggiavan": "verdeggiare",
    "verdeggiavano": "verdeggiare",
    "verdeggiavate": "verdeggiare",
    "verdeggiavi": "verdeggiare",
    "verdeggiavo": "verdeggiare",
    "verdeggin": "verdeggiare",
    "verdeggino": "verdeggiare",
    "verdeggio": "verdeggiare",
    "verdeggiò": "verdeggiare",
    "verdegrigi": "verdegrigio",
    "verdegrigia": "verdegrigio",
    "verdegrigie": "verdegrigio",
    "verdetti": "verdetto",
    "verdi": "verde",
    "verdiana": "verdiano",
    "verdiane": "verdiano",
    "verdiani": "verdiano",
    "verdiglioniana": "verdiglioniano",
    "verdiglioniane": "verdiglioniano",
    "verdiglioniani": "verdiglioniano",
    "verdognola": "verdognolo",
    "verdognole": "verdognolo",
    "verdognoli": "verdognolo",
    "verdolina": "verdolino",
    "verdoline": "verdolino",
    "verdolini": "verdolino",
    "verdoni": "verdone",
    "verdure": "verdura",
    "vere": "vero",
    "verga": "vergare",
    "vergai": "vergare",
    "vergammo": "vergare",
    "vergan": "vergare",
    "vergando": "vergare",
    "vergano": "vergare",
    "vergante": "vergare",
    "verganti": "vergare",
    "vergar": "vergare",
    "vergaron": "vergare",
    "vergarono": "vergare",
    "vergasse": "vergare",
    "vergasser": "vergare",
    "vergassero": "vergare",
    "vergassi": "vergare",
    "vergassimo": "vergare",
    "vergaste": "vergare",
    "vergasti": "vergare",
    "vergata": "vergato",
    "vergate": "vergato",
    "vergati": "vergato",
    "vergato": "vergare",
    "vergava": "vergare",
    "vergavamo": "vergare",
    "vergavan": "vergare",
    "vergavano": "vergare",
    "vergavate": "vergare",
    "vergavi": "vergare",
    "vergavo": "vergare",
    "verghe": "verga",
    "vergherai": "vergare",
    "vergheran": "vergare",
    "vergheranno": "vergare",
    "vergherebbe": "vergare",
    "vergherebber": "vergare",
    "vergherebbero": "vergare",
    "vergherei": "vergare",
    "vergheremmo": "vergare",
    "vergheremo": "vergare",
    "verghereste": "vergare",
    "vergheresti": "vergare",
    "vergherete": "vergare",
    "vergherà": "vergare",
    "vergherò": "vergare",
    "verghi": "vergare",
    "verghiamo": "vergare",
    "verghiana": "verghiano",
    "verghiane": "verghiano",
    "verghiani": "verghiano",
    "verghiate": "vergare",
    "verghin": "vergare",
    "verghino": "vergare",
    "verginali": "verginale",
    "verginelle": "verginella",
    "vergini": "vergine",
    "vergo": "vergare",
    "vergogna": "vergognare",
    "vergognai": "vergognare",
    "vergognammo": "vergognare",
    "vergognan": "vergognare",
    "vergognando": "vergognare",
    "vergognano": "vergognare",
    "vergognar": "vergognare",
    "vergognaron": "vergognare",
    "vergognarono": "vergognare",
    "vergognasse": "vergognare",
    "vergognasser": "vergognare",
    "vergognassero": "vergognare",
    "vergognassi": "vergognare",
    "vergognassimo": "vergognare",
    "vergognaste": "vergognare",
    "vergognasti": "vergognare",
    "vergognata": "vergognare",
    "vergognate": "vergognare",
    "vergognati": "vergognare",
    "vergognato": "vergognare",
    "vergognava": "vergognare",
    "vergognavamo": "vergognare",
    "vergognavan": "vergognare",
    "vergognavano": "vergognare",
    "vergognavate": "vergognare",
    "vergognavi": "vergognare",
    "vergognavo": "vergognare",
    "vergogne": "vergogna",
    "vergognerai": "vergognare",
    "vergogneran": "vergognare",
    "vergogneranno": "vergognare",
    "vergognerebbe": "vergognare",
    "vergognerebber": "vergognare",
    "vergognerebbero": "vergognare",
    "vergognerei": "vergognare",
    "vergogneremmo": "vergognare",
    "vergogneremo": "vergognare",
    "vergognereste": "vergognare",
    "vergogneresti": "vergognare",
    "vergognerete": "vergognare",
    "vergognerà": "vergognare",
    "vergognerò": "vergognare",
    "vergogni": "vergognare",
    "vergogniamo": "vergognare",
    "vergogniate": "vergognare",
    "vergognin": "vergognare",
    "vergognino": "vergognare",
    "vergogno": "vergognare",
    "vergognosa": "vergognoso",
    "vergognose": "vergognoso",
    "vergognosi": "vergognoso",
    "vergognò": "vergognare",
    "vergò": "vergare",
    "veri": "vero",
    "veridica": "veridico",
    "veridiche": "veridico",
    "veridici": "veridico",
    "verifica": "verificare",
    "verificabili": "verificabile",
    "verificai": "verificare",
    "verificammo": "verificare",
    "verifican": "verificare",
    "verificando": "verificare",
    "verificano": "verificare",
    "verificante": "verificare",
    "verificanti": "verificare",
    "verificar": "verificare",
    "verificaron": "verificare",
    "verificarono": "verificare",
    "verificasse": "verificare",
    "verificasser": "verificare",
    "verificassero": "verificare",
    "verificassi": "verificare",
    "verificassimo": "verificare",
    "verificaste": "verificare",
    "verificasti": "verificare",
    "verificata": "verificare",
    "verificate": "verificare",
    "verificati": "verificare",
    "verificato": "verificare",
    "verificatori": "verificatore",
    "verificava": "verificare",
    "verificavamo": "verificare",
    "verificavan": "verificare",
    "verificavano": "verificare",
    "verificavate": "verificare",
    "verificavi": "verificare",
    "verificavo": "verificare",
    "verifiche": "verifica",
    "verificherai": "verificare",
    "verificheran": "verificare",
    "verificheranno": "verificare",
    "verificherebbe": "verificare",
    "verificherebber": "verificare",
    "verificherebbero": "verificare",
    "verificherei": "verificare",
    "verificheremmo": "verificare",
    "verificheremo": "verificare",
    "verifichereste": "verificare",
    "verificheresti": "verificare",
    "verificherete": "verificare",
    "verificherà": "verificare",
    "verificherò": "verificare",
    "verifichi": "verificare",
    "verifichiamo": "verificare",
    "verifichiate": "verificare",
    "verifichin": "verificare",
    "verifichino": "verificare",
    "verifico": "verificare",
    "verificò": "verificare",
    "verismi": "verismo",
    "veriste": "verista",
    "veristi": "verista",
    "veristica": "veristico",
    "veristiche": "veristico",
    "veristici": "veristico",
    "veritiera": "veritiero",
    "veritiere": "veritiero",
    "veritieri": "veritiero",
    "vermi": "verme",
    "vermigli": "vermiglio",
    "vermiglia": "vermiglio",
    "vermiglie": "vermiglio",
    "verminai": "verminaio",
    "vernacola": "vernacolo",
    "vernacole": "vernacolo",
    "vernacoli": "vernacolo",
    "vernicerai": "verniciare",
    "verniceran": "verniciare",
    "verniceranno": "verniciare",
    "vernicerebbe": "verniciare",
    "vernicerebber": "verniciare",
    "vernicerebbero": "verniciare",
    "vernicerei": "verniciare",
    "verniceremmo": "verniciare",
    "verniceremo": "verniciare",
    "vernicereste": "verniciare",
    "verniceresti": "verniciare",
    "vernicerete": "verniciare",
    "vernicerà": "verniciare",
    "vernicerò": "verniciare",
    "vernici": "verniciare",
    "vernicia": "verniciare",
    "verniciai": "verniciare",
    "verniciammo": "verniciare",
    "verniciamo": "verniciare",
    "vernician": "verniciare",
    "verniciando": "verniciare",
    "verniciano": "verniciare",
    "verniciante": "verniciare",
    "vernicianti": "verniciare",
    "verniciar": "verniciare",
    "verniciaron": "verniciare",
    "verniciarono": "verniciare",
    "verniciasse": "verniciare",
    "verniciasser": "verniciare",
    "verniciassero": "verniciare",
    "verniciassi": "verniciare",
    "verniciassimo": "verniciare",
    "verniciaste": "verniciare",
    "verniciasti": "verniciare",
    "verniciata": "verniciare",
    "verniciate": "verniciare",
    "verniciati": "verniciare",
    "verniciato": "verniciare",
    "verniciature": "verniciatura",
    "verniciava": "verniciare",
    "verniciavamo": "verniciare",
    "verniciavan": "verniciare",
    "verniciavano": "verniciare",
    "verniciavate": "verniciare",
    "verniciavi": "verniciare",
    "verniciavo": "verniciare",
    "vernicin": "verniciare",
    "vernicino": "verniciare",
    "vernicio": "verniciare",
    "verniciò": "verniciare",
    "veronelliana": "veronelliano",
    "veronelliane": "veronelliano",
    "veronelliani": "veronelliano",
    "veronesi": "veronese",
    "veroniche": "veronica",
    "verosimiglianze": "verosimiglianza",
    "verosimili": "verosimile",
    "verrai": "venire",
    "verran": "venire",
    "verranno": "venire",
    "verrebbe": "venire",
    "verrebber": "venire",
    "verrebbero": "venire",
    "verrei": "venire",
    "verremmo": "venire",
    "verremo": "venire",
    "verreste": "venire",
    "verresti": "venire",
    "verrete": "venire",
    "verricelli": "verricello",
    "verruche": "verruca",
    "verrà": "venire",
    "verrò": "venire",
    "versa": "verso",
    "versai": "versare",
    "versamenti": "versamento",
    "versammo": "versare",
    "versan": "versare",
    "versando": "versare",
    "versano": "versare",
    "versante": "versare",
    "versanti": "versare",
    "versar": "versare",
    "versaron": "versare",
    "versarono": "versare",
    "versasse": "versare",
    "versasser": "versare",
    "versassero": "versare",
    "versassi": "versare",
    "versassimo": "versare",
    "versaste": "versare",
    "versasti": "versare",
    "versata": "versato",
    "versate": "versato",
    "versati": "versato",
    "versatili": "versatile",
    "versato": "versare",
    "versava": "versare",
    "versavamo": "versare",
    "versavan": "versare",
    "versavano": "versare",
    "versavate": "versare",
    "versavi": "versare",
    "versavo": "versare",
    "verse": "verso",
    "verseggerai": "verseggiare",
    "verseggeran": "verseggiare",
    "verseggeranno": "verseggiare",
    "verseggerebbe": "verseggiare",
    "verseggerebber": "verseggiare",
    "verseggerebbero": "verseggiare",
    "verseggerei": "verseggiare",
    "verseggeremmo": "verseggiare",
    "verseggeremo": "verseggiare",
    "verseggereste": "verseggiare",
    "verseggeresti": "verseggiare",
    "verseggerete": "verseggiare",
    "verseggerà": "verseggiare",
    "verseggerò": "verseggiare",
    "verseggi": "verseggiare",
    "verseggia": "verseggiare",
    "verseggiai": "verseggiare",
    "verseggiammo": "verseggiare",
    "verseggiamo": "verseggiare",
    "verseggian": "verseggiare",
    "verseggiando": "verseggiare",
    "verseggiano": "verseggiare",
    "verseggiante": "verseggiare",
    "verseggianti": "verseggiare",
    "verseggiar": "verseggiare",
    "verseggiaron": "verseggiare",
    "verseggiarono": "verseggiare",
    "verseggiasse": "verseggiare",
    "verseggiasser": "verseggiare",
    "verseggiassero": "verseggiare",
    "verseggiassi": "verseggiare",
    "verseggiassimo": "verseggiare",
    "verseggiaste": "verseggiare",
    "verseggiasti": "verseggiare",
    "verseggiata": "verseggiare",
    "verseggiate": "verseggiare",
    "verseggiati": "verseggiare",
    "verseggiato": "verseggiare",
    "verseggiava": "verseggiare",
    "verseggiavamo": "verseggiare",
    "verseggiavan": "verseggiare",
    "verseggiavano": "verseggiare",
    "verseggiavate": "verseggiare",
    "verseggiavi": "verseggiare",
    "verseggiavo": "verseggiare",
    "verseggin": "verseggiare",
    "verseggino": "verseggiare",
    "verseggio": "verseggiare",
    "verseggiò": "verseggiare",
    "verserai": "versare",
    "verseran": "versare",
    "verseranno": "versare",
    "verserebbe": "versare",
    "verserebber": "versare",
    "verserebbero": "versare",
    "verserei": "versare",
    "verseremmo": "versare",
    "verseremo": "versare",
    "versereste": "versare",
    "verseresti": "versare",
    "verserete": "versare",
    "verserà": "versare",
    "verserò": "versare",
    "versetti": "versetto",
    "versi": "verso",
    "versiamo": "versare",
    "versiate": "versare",
    "versifica": "versificare",
    "versificai": "versificare",
    "versificammo": "versificare",
    "versifican": "versificare",
    "versificando": "versificare",
    "versificano": "versificare",
    "versificante": "versificare",
    "versificanti": "versificare",
    "versificar": "versificare",
    "versificaron": "versificare",
    "versificarono": "versificare",
    "versificasse": "versificare",
    "versificasser": "versificare",
    "versificassero": "versificare",
    "versificassi": "versificare",
    "versificassimo": "versificare",
    "versificaste": "versificare",
    "versificasti": "versificare",
    "versificata": "versificare",
    "versificate": "versificare",
    "versificati": "versificare",
    "versificato": "versificare",
    "versificava": "versificare",
    "versificavamo": "versificare",
    "versificavan": "versificare",
    "versificavano": "versificare",
    "versificavate": "versificare",
    "versificavi": "versificare",
    "versificavo": "versificare",
    "versificherai": "versificare",
    "versificheran": "versificare",
    "versificheranno": "versificare",
    "versificherebbe": "versificare",
    "versificherebber": "versificare",
    "versificherebbero": "versificare",
    "versificherei": "versificare",
    "versificheremmo": "versificare",
    "versificheremo": "versificare",
    "versifichereste": "versificare",
    "versificheresti": "versificare",
    "versificherete": "versificare",
    "versificherà": "versificare",
    "versificherò": "versificare",
    "versifichi": "versificare",
    "versifichiamo": "versificare",
    "versifichiate": "versificare",
    "versifichin": "versificare",
    "versifichino": "versificare",
    "versifico": "versificare",
    "versificò": "versificare",
    "versin": "versare",
    "versino": "versare",
    "versioni": "versione",
    "verso": "versare",
    "versò": "versare",
    "verta": "vertere",
    "vertan": "vertere",
    "vertano": "vertere",
    "verte": "vertere",
    "vertebrali": "vertebrale",
    "vertebre": "vertebra",
    "vertei": "vertere",
    "vertemmo": "vertere",
    "vertendo": "vertere",
    "vertente": "vertere",
    "vertenti": "vertere",
    "vertenze": "vertenza",
    "verter": "vertere",
    "verterai": "vertere",
    "verteran": "vertere",
    "verteranno": "vertere",
    "verterebbe": "vertere",
    "verterebber": "vertere",
    "verterebbero": "vertere",
    "verterei": "vertere",
    "verteremmo": "vertere",
    "verteremo": "vertere",
    "vertereste": "vertere",
    "verteresti": "vertere",
    "verterete": "vertere",
    "verteron": "vertere",
    "verterono": "vertere",
    "verterà": "vertere",
    "verterò": "vertere",
    "vertesse": "vertere",
    "vertesser": "vertere",
    "vertessero": "vertere",
    "vertessi": "vertere",
    "vertessimo": "vertere",
    "verteste": "vertere",
    "vertesti": "vertere",
    "vertete": "vertere",
    "verteva": "vertere",
    "vertevamo": "vertere",
    "vertevan": "vertere",
    "vertevano": "vertere",
    "vertevate": "vertere",
    "vertevi": "vertere",
    "vertevo": "vertere",
    "verti": "vertere",
    "vertiamo": "vertere",
    "vertiate": "vertere",
    "verticali": "verticale",
    "verticalizzazioni": "verticalizzazione",
    "vertici": "vertice",
    "vertigini": "vertigine",
    "vertiginosa": "vertiginoso",
    "vertiginose": "vertiginoso",
    "vertiginosi": "vertiginoso",
    "verto": "vertere",
    "verton": "vertere",
    "vertono": "vertere",
    "vertuta": "vertere",
    "vertute": "vertere",
    "vertuti": "vertere",
    "vertuto": "vertere",
    "vertè": "vertere",
    "vesciche": "vescica",
    "vescovi": "vescovo",
    "vescovili": "vescovile",
    "vespai": "vespaio",
    "vespasiani": "vespasiano",
    "vespe": "vespa",
    "vespertina": "vespertino",
    "vespertine": "vespertino",
    "vespertini": "vespertino",
    "vessa": "vessare",
    "vessai": "vessare",
    "vessammo": "vessare",
    "vessan": "vessare",
    "vessando": "vessare",
    "vessano": "vessare",
    "vessante": "vessare",
    "vessanti": "vessare",
    "vessar": "vessare",
    "vessaron": "vessare",
    "vessarono": "vessare",
    "vessasse": "vessare",
    "vessasser": "vessare",
    "vessassero": "vessare",
    "vessassi": "vessare",
    "vessassimo": "vessare",
    "vessaste": "vessare",
    "vessasti": "vessare",
    "vessata": "vessare",
    "vessate": "vessare",
    "vessati": "vessare",
    "vessato": "vessare",
    "vessatori": "vessatorio",
    "vessatoria": "vessatorio",
    "vessatorie": "vessatorio",
    "vessava": "vessare",
    "vessavamo": "vessare",
    "vessavan": "vessare",
    "vessavano": "vessare",
    "vessavate": "vessare",
    "vessavi": "vessare",
    "vessavo": "vessare",
    "vessazioni": "vessazione",
    "vesserai": "vessare",
    "vesseran": "vessare",
    "vesseranno": "vessare",
    "vesserebbe": "vessare",
    "vesserebber": "vessare",
    "vesserebbero": "vessare",
    "vesserei": "vessare",
    "vesseremmo": "vessare",
    "vesseremo": "vessare",
    "vessereste": "vessare",
    "vesseresti": "vessare",
    "vesserete": "vessare",
    "vesserà": "vessare",
    "vesserò": "vessare",
    "vessi": "vessare",
    "vessiamo": "vessare",
    "vessiate": "vessare",
    "vessilli": "vessillo",
    "vessilliferi": "vessillifero",
    "vessin": "vessare",
    "vessino": "vessare",
    "vesso": "vessare",
    "vessò": "vessare",
    "vesta": "vestire",
    "vestaglie": "vestaglia",
    "vestali": "vestale",
    "vestan": "vestire",
    "vestano": "vestire",
    "veste": "vestire",
    "vestendo": "vestire",
    "vestente": "vestire",
    "vestenti": "vestire",
    "vesti": "vestire",
    "vestiamo": "vestire",
    "vestiari": "vestiario",
    "vestiate": "vestire",
    "vestibola": "vestibolare",
    "vestibolai": "vestibolare",
    "vestibolammo": "vestibolare",
    "vestibolan": "vestibolare",
    "vestibolando": "vestibolare",
    "vestibolano": "vestibolare",
    "vestibolante": "vestibolare",
    "vestibolanti": "vestibolare",
    "vestibolar": "vestibolare",
    "vestibolaron": "vestibolare",
    "vestibolarono": "vestibolare",
    "vestibolasse": "vestibolare",
    "vestibolasser": "vestibolare",
    "vestibolassero": "vestibolare",
    "vestibolassi": "vestibolare",
    "vestibolassimo": "vestibolare",
    "vestibolaste": "vestibolare",
    "vestibolasti": "vestibolare",
    "vestibolata": "vestibolare",
    "vestibolate": "vestibolare",
    "vestibolati": "vestibolare",
    "vestibolato": "vestibolare",
    "vestibolava": "vestibolare",
    "vestibolavamo": "vestibolare",
    "vestibolavan": "vestibolare",
    "vestibolavano": "vestibolare",
    "vestibolavate": "vestibolare",
    "vestibolavi": "vestibolare",
    "vestibolavo": "vestibolare",
    "vestibolerai": "vestibolare",
    "vestiboleran": "vestibolare",
    "vestiboleranno": "vestibolare",
    "vestibolerebbe": "vestibolare",
    "vestibolerebber": "vestibolare",
    "vestibolerebbero": "vestibolare",
    "vestibolerei": "vestibolare",
    "vestiboleremmo": "vestibolare",
    "vestiboleremo": "vestibolare",
    "vestibolereste": "vestibolare",
    "vestiboleresti": "vestibolare",
    "vestibolerete": "vestibolare",
    "vestibolerà": "vestibolare",
    "vestibolerò": "vestibolare",
    "vestiboli": "vestibolo",
    "vestiboliamo": "vestibolare",
    "vestiboliate": "vestibolare",
    "vestibolin": "vestibolare",
    "vestibolino": "vestibolare",
    "vestibolo": "vestibolare",
    "vestibolò": "vestibolare",
    "vestii": "vestire",
    "vestimmo": "vestire",
    "vestir": "vestire",
    "vestirai": "vestire",
    "vestiran": "vestire",
    "vestiranno": "vestire",
    "vestirebbe": "vestire",
    "vestirebber": "vestire",
    "vestirebbero": "vestire",
    "vestirei": "vestire",
    "vestiremmo": "vestire",
    "vestiremo": "vestire",
    "vestireste": "vestire",
    "vestiresti": "vestire",
    "vestirete": "vestire",
    "vestiron": "vestire",
    "vestirono": "vestire",
    "vestirà": "vestire",
    "vestirò": "vestire",
    "vestisse": "vestire",
    "vestisser": "vestire",
    "vestissero": "vestire",
    "vestissi": "vestire",
    "vestissimo": "vestire",
    "vestiste": "vestire",
    "vestisti": "vestire",
    "vestita": "vestito",
    "vestite": "vestito",
    "vestiti": "vestito",
    "vestitini": "vestitino",
    "vestito": "vestire",
    "vestiva": "vestire",
    "vestivamo": "vestire",
    "vestivan": "vestire",
    "vestivano": "vestire",
    "vestivate": "vestire",
    "vestivi": "vestire",
    "vestivo": "vestire",
    "vestizioni": "vestizione",
    "vesto": "vestire",
    "veston": "vestire",
    "vestono": "vestire",
    "vestì": "vestire",
    "vesuviana": "vesuviano",
    "vesuviane": "vesuviano",
    "vesuviani": "vesuviano",
    "veterana": "veterano",
    "veterane": "veterano",
    "veterani": "veterano",
    "veterinari": "veterinario",
    "veterinaria": "veterinario",
    "veterinarie": "veterinario",
    "veterocomunista-bertinottiana": "veterocomunista-bertinottiano",
    "veterocomunista-bertinottiane": "veterocomunista-bertinottiano",
    "veterocomunista-bertinottiani": "veterocomunista-bertinottiano",
    "veti": "veto",
    "vetrari": "vetrario",
    "vetraria": "vetrario",
    "vetrarie": "vetrario",
    "vetrata": "vetrato",
    "vetrate": "vetrato",
    "vetrati": "vetrato",
    "vetrerie": "vetreria",
    "vetri": "vetro",
    "vetrifica": "vetrificare",
    "vetrificai": "vetrificare",
    "vetrificammo": "vetrificare",
    "vetrifican": "vetrificare",
    "vetrificando": "vetrificare",
    "vetrificano": "vetrificare",
    "vetrificante": "vetrificare",
    "vetrificanti": "vetrificare",
    "vetrificar": "vetrificare",
    "vetrificaron": "vetrificare",
    "vetrificarono": "vetrificare",
    "vetrificasse": "vetrificare",
    "vetrificasser": "vetrificare",
    "vetrificassero": "vetrificare",
    "vetrificassi": "vetrificare",
    "vetrificassimo": "vetrificare",
    "vetrificaste": "vetrificare",
    "vetrificasti": "vetrificare",
    "vetrificata": "vetrificare",
    "vetrificate": "vetrificare",
    "vetrificati": "vetrificare",
    "vetrificato": "vetrificare",
    "vetrificava": "vetrificare",
    "vetrificavamo": "vetrificare",
    "vetrificavan": "vetrificare",
    "vetrificavano": "vetrificare",
    "vetrificavate": "vetrificare",
    "vetrificavi": "vetrificare",
    "vetrificavo": "vetrificare",
    "vetrificherai": "vetrificare",
    "vetrificheran": "vetrificare",
    "vetrificheranno": "vetrificare",
    "vetrificherebbe": "vetrificare",
    "vetrificherebber": "vetrificare",
    "vetrificherebbero": "vetrificare",
    "vetrificherei": "vetrificare",
    "vetrificheremmo": "vetrificare",
    "vetrificheremo": "vetrificare",
    "vetrifichereste": "vetrificare",
    "vetrificheresti": "vetrificare",
    "vetrificherete": "vetrificare",
    "vetrificherà": "vetrificare",
    "vetrificherò": "vetrificare",
    "vetrifichi": "vetrificare",
    "vetrifichiamo": "vetrificare",
    "vetrifichiate": "vetrificare",
    "vetrifichin": "vetrificare",
    "vetrifichino": "vetrificare",
    "vetrifico": "vetrificare",
    "vetrificò": "vetrificare",
    "vetrina": "vetrino",
    "vetrine": "vetrino",
    "vetrinette": "vetrinetta",
    "vetrini": "vetrino",
    "vetrinisti": "vetrinista",
    "vetrioleggerai": "vetrioleggiare",
    "vetrioleggeran": "vetrioleggiare",
    "vetrioleggeranno": "vetrioleggiare",
    "vetrioleggerebbe": "vetrioleggiare",
    "vetrioleggerebber": "vetrioleggiare",
    "vetrioleggerebbero": "vetrioleggiare",
    "vetrioleggerei": "vetrioleggiare",
    "vetrioleggeremmo": "vetrioleggiare",
    "vetrioleggeremo": "vetrioleggiare",
    "vetrioleggereste": "vetrioleggiare",
    "vetrioleggeresti": "vetrioleggiare",
    "vetrioleggerete": "vetrioleggiare",
    "vetrioleggerà": "vetrioleggiare",
    "vetrioleggerò": "vetrioleggiare",
    "vetrioleggi": "vetrioleggiare",
    "vetrioleggia": "vetrioleggiare",
    "vetrioleggiai": "vetrioleggiare",
    "vetrioleggiammo": "vetrioleggiare",
    "vetrioleggiamo": "vetrioleggiare",
    "vetrioleggian": "vetrioleggiare",
    "vetrioleggiando": "vetrioleggiare",
    "vetrioleggiano": "vetrioleggiare",
    "vetrioleggiante": "vetrioleggiare",
    "vetrioleggianti": "vetrioleggiare",
    "vetrioleggiar": "vetrioleggiare",
    "vetrioleggiaron": "vetrioleggiare",
    "vetrioleggiarono": "vetrioleggiare",
    "vetrioleggiasse": "vetrioleggiare",
    "vetrioleggiasser": "vetrioleggiare",
    "vetrioleggiassero": "vetrioleggiare",
    "vetrioleggiassi": "vetrioleggiare",
    "vetrioleggiassimo": "vetrioleggiare",
    "vetrioleggiaste": "vetrioleggiare",
    "vetrioleggiasti": "vetrioleggiare",
    "vetrioleggiata": "vetrioleggiare",
    "vetrioleggiate": "vetrioleggiare",
    "vetrioleggiati": "vetrioleggiare",
    "vetrioleggiato": "vetrioleggiare",
    "vetrioleggiava": "vetrioleggiare",
    "vetrioleggiavamo": "vetrioleggiare",
    "vetrioleggiavan": "vetrioleggiare",
    "vetrioleggiavano": "vetrioleggiare",
    "vetrioleggiavate": "vetrioleggiare",
    "vetrioleggiavi": "vetrioleggiare",
    "vetrioleggiavo": "vetrioleggiare",
    "vetrioleggin": "vetrioleggiare",
    "vetrioleggino": "vetrioleggiare",
    "vetrioleggio": "vetrioleggiare",
    "vetrioleggiò": "vetrioleggiare",
    "vetrosa": "vetroso",
    "vetrose": "vetroso",
    "vetrosi": "vetroso",
    "vette": "vetta",
    "vettori": "vettore",
    "vettoriali": "vettoriale",
    "vettovagli": "vettovagliare",
    "vettovaglia": "vettovagliare",
    "vettovagliai": "vettovagliare",
    "vettovagliammo": "vettovagliare",
    "vettovagliamo": "vettovagliare",
    "vettovaglian": "vettovagliare",
    "vettovagliando": "vettovagliare",
    "vettovagliano": "vettovagliare",
    "vettovagliante": "vettovagliare",
    "vettovaglianti": "vettovagliare",
    "vettovagliar": "vettovagliare",
    "vettovagliaron": "vettovagliare",
    "vettovagliarono": "vettovagliare",
    "vettovagliasse": "vettovagliare",
    "vettovagliasser": "vettovagliare",
    "vettovagliassero": "vettovagliare",
    "vettovagliassi": "vettovagliare",
    "vettovagliassimo": "vettovagliare",
    "vettovagliaste": "vettovagliare",
    "vettovagliasti": "vettovagliare",
    "vettovagliata": "vettovagliare",
    "vettovagliate": "vettovagliare",
    "vettovagliati": "vettovagliare",
    "vettovagliato": "vettovagliare",
    "vettovagliava": "vettovagliare",
    "vettovagliavamo": "vettovagliare",
    "vettovagliavan": "vettovagliare",
    "vettovagliavano": "vettovagliare",
    "vettovagliavate": "vettovagliare",
    "vettovagliavi": "vettovagliare",
    "vettovagliavo": "vettovagliare",
    "vettovaglierai": "vettovagliare",
    "vettovaglieran": "vettovagliare",
    "vettovaglieranno": "vettovagliare",
    "vettovaglierebbe": "vettovagliare",
    "vettovaglierebber": "vettovagliare",
    "vettovaglierebbero": "vettovagliare",
    "vettovaglierei": "vettovagliare",
    "vettovaglieremmo": "vettovagliare",
    "vettovaglieremo": "vettovagliare",
    "vettovagliereste": "vettovagliare",
    "vettovaglieresti": "vettovagliare",
    "vettovaglierete": "vettovagliare",
    "vettovaglierà": "vettovagliare",
    "vettovaglierò": "vettovagliare",
    "vettovaglin": "vettovagliare",
    "vettovaglino": "vettovagliare",
    "vettovaglio": "vettovagliare",
    "vettovagliò": "vettovagliare",
    "vettrice": "vettore",
    "vettrici": "vettore",
    "vetture": "vettura",
    "vetturette": "vetturetta",
    "vetturini": "vetturino",
    "vetusta": "vetusto",
    "vetuste": "vetusto",
    "vetusti": "vetusto",
    "vezzeggerai": "vezzeggiare",
    "vezzeggeran": "vezzeggiare",
    "vezzeggeranno": "vezzeggiare",
    "vezzeggerebbe": "vezzeggiare",
    "vezzeggerebber": "vezzeggiare",
    "vezzeggerebbero": "vezzeggiare",
    "vezzeggerei": "vezzeggiare",
    "vezzeggeremmo": "vezzeggiare",
    "vezzeggeremo": "vezzeggiare",
    "vezzeggereste": "vezzeggiare",
    "vezzeggeresti": "vezzeggiare",
    "vezzeggerete": "vezzeggiare",
    "vezzeggerà": "vezzeggiare",
    "vezzeggerò": "vezzeggiare",
    "vezzeggi": "vezzeggiare",
    "vezzeggia": "vezzeggiare",
    "vezzeggiai": "vezzeggiare",
    "vezzeggiammo": "vezzeggiare",
    "vezzeggiamo": "vezzeggiare",
    "vezzeggian": "vezzeggiare",
    "vezzeggiando": "vezzeggiare",
    "vezzeggiano": "vezzeggiare",
    "vezzeggiante": "vezzeggiare",
    "vezzeggianti": "vezzeggiare",
    "vezzeggiar": "vezzeggiare",
    "vezzeggiaron": "vezzeggiare",
    "vezzeggiarono": "vezzeggiare",
    "vezzeggiasse": "vezzeggiare",
    "vezzeggiasser": "vezzeggiare",
    "vezzeggiassero": "vezzeggiare",
    "vezzeggiassi": "vezzeggiare",
    "vezzeggiassimo": "vezzeggiare",
    "vezzeggiaste": "vezzeggiare",
    "vezzeggiasti": "vezzeggiare",
    "vezzeggiata": "vezzeggiare",
    "vezzeggiate": "vezzeggiare",
    "vezzeggiati": "vezzeggiare",
    "vezzeggiativi": "vezzeggiativo",
    "vezzeggiato": "vezzeggiare",
    "vezzeggiava": "vezzeggiare",
    "vezzeggiavamo": "vezzeggiare",
    "vezzeggiavan": "vezzeggiare",
    "vezzeggiavano": "vezzeggiare",
    "vezzeggiavate": "vezzeggiare",
    "vezzeggiavi": "vezzeggiare",
    "vezzeggiavo": "vezzeggiare",
    "vezzeggin": "vezzeggiare",
    "vezzeggino": "vezzeggiare",
    "vezzeggio": "vezzeggiare",
    "vezzeggiò": "vezzeggiare",
    "vezzi": "vezzo",
    "vezzosa": "vezzoso",
    "vezzose": "vezzoso",
    "vezzosi": "vezzoso",
    "viadotti": "viadotto",
    "viaggerai": "viaggiare",
    "viaggeran": "viaggiare",
    "viaggeranno": "viaggiare",
    "viaggerebbe": "viaggiare",
    "viaggerebber": "viaggiare",
    "viaggerebbero": "viaggiare",
    "viaggerei": "viaggiare",
    "viaggeremmo": "viaggiare",
    "viaggeremo": "viaggiare",
    "viaggereste": "viaggiare",
    "viaggeresti": "viaggiare",
    "viaggerete": "viaggiare",
    "viaggerà": "viaggiare",
    "viaggerò": "viaggiare",
    "viaggetti": "viaggetto",
    "viaggi": "viaggo",
    "viaggia": "viaggiare",
    "viaggiai": "viaggiare",
    "viaggiammo": "viaggiare",
    "viaggiamo": "viaggiare",
    "viaggian": "viaggiare",
    "viaggiando": "viaggiare",
    "viaggiano": "viaggiare",
    "viaggiante": "viaggiare",
    "viaggianti": "viaggiare",
    "viaggiar": "viaggiare",
    "viaggiaron": "viaggiare",
    "viaggiarono": "viaggiare",
    "viaggiasse": "viaggiare",
    "viaggiasser": "viaggiare",
    "viaggiassero": "viaggiare",
    "viaggiassi": "viaggiare",
    "viaggiassimo": "viaggiare",
    "viaggiaste": "viaggiare",
    "viaggiasti": "viaggiare",
    "viaggiata": "viaggiare",
    "viaggiate": "viaggiare",
    "viaggiati": "viaggiare",
    "viaggiato": "viaggiare",
    "viaggiatori": "viaggiatore",
    "viaggiatrice": "viaggiatore",
    "viaggiatrici": "viaggiatrice",
    "viaggiava": "viaggiare",
    "viaggiavamo": "viaggiare",
    "viaggiavan": "viaggiare",
    "viaggiavano": "viaggiare",
    "viaggiavate": "viaggiare",
    "viaggiavi": "viaggiare",
    "viaggiavo": "viaggiare",
    "viaggii-lampo": "viaggio-lampo",
    "viaggin": "viaggiare",
    "viaggino": "viaggiare",
    "viaggio": "viaggiare",
    "viaggiò": "viaggiare",
    "vialetti": "vialetto",
    "viali": "viale",
    "vialoni": "vialone",
    "viandanti": "viandante",
    "viareggina": "viareggino",
    "viareggine": "viareggino",
    "viareggini": "viareggino",
    "viari": "viario",
    "viaria": "viario",
    "viarie": "viario",
    "vibra": "vibrare",
    "vibrai": "vibrare",
    "vibrammo": "vibrare",
    "vibran": "vibrare",
    "vibrando": "vibrare",
    "vibrano": "vibrare",
    "vibrante": "vibrare",
    "vibranti": "vibrare",
    "vibrar": "vibrare",
    "vibraron": "vibrare",
    "vibrarono": "vibrare",
    "vibrasse": "vibrare",
    "vibrasser": "vibrare",
    "vibrassero": "vibrare",
    "vibrassi": "vibrare",
    "vibrassimo": "vibrare",
    "vibraste": "vibrare",
    "vibrasti": "vibrare",
    "vibrata": "vibrato",
    "vibrate": "vibrato",
    "vibrati": "vibrato",
    "vibratili": "vibratile",
    "vibrato": "vibrare",
    "vibratori": "vibratorio",
    "vibratoria": "vibratorio",
    "vibratorie": "vibratorio",
    "vibratrice": "vibratore",
    "vibratrici": "vibratore",
    "vibrava": "vibrare",
    "vibravamo": "vibrare",
    "vibravan": "vibrare",
    "vibravano": "vibrare",
    "vibravate": "vibrare",
    "vibravi": "vibrare",
    "vibravo": "vibrare",
    "vibrazioni": "vibrazione",
    "vibrerai": "vibrare",
    "vibreran": "vibrare",
    "vibreranno": "vibrare",
    "vibrerebbe": "vibrare",
    "vibrerebber": "vibrare",
    "vibrerebbero": "vibrare",
    "vibrerei": "vibrare",
    "vibreremmo": "vibrare",
    "vibreremo": "vibrare",
    "vibrereste": "vibrare",
    "vibreresti": "vibrare",
    "vibrerete": "vibrare",
    "vibrerà": "vibrare",
    "vibrerò": "vibrare",
    "vibri": "vibrare",
    "vibriamo": "vibrare",
    "vibriate": "vibrare",
    "vibrin": "vibrare",
    "vibrino": "vibrare",
    "vibrioni": "vibrione",
    "vibro": "vibrare",
    "vibrò": "vibrare",
    "vicari": "vicario",
    "vicaria": "vicario",
    "vicarie": "vicario",
    "vice-capi": "vice-capo",
    "vice-direttori": "vice-direttore",
    "vice-ministri": "vice-ministro",
    "vice-presidenti": "vice-presidente",
    "vice-presidenze": "vice-presidenza",
    "vice-questori": "vice-questore",
    "vice-segretari": "vice-segretario",
    "vice-sindaci": "vice-sindaco",
    "vicebrigadieri": "vicebrigadiere",
    "vicecampioni": "vicecampione",
    "vicecancellieri": "vicecancelliere",
    "vicecapi": "vicecapo",
    "vicecapigruppo": "vicecapogruppo",
    "vicecommissari": "vicecommissario",
    "viceconsoli": "viceconsole",
    "vicedirettori": "vicedirettore",
    "vicedirezioni": "vicedirezione",
    "viceministri": "viceministro",
    "vicende": "vicenda",
    "vicentina": "vicentino",
    "vicentine": "vicentino",
    "vicentini": "vicentino",
    "viceprefetti": "viceprefetto",
    "vicepresidenti": "vicepresidente",
    "vicepresidenze": "vicepresidenza",
    "vicepresidenziali": "vicepresidenziale",
    "vicepretori": "vicepretore",
    "viceprocuratori": "viceprocuratore",
    "vicequestori": "vicequestore",
    "vicesegretari": "vicesegretario",
    "vicesegreterie": "vicesegreteria",
    "vicesindaci": "vicesindaco",
    "vichinga": "vichingo",
    "vichinghe": "vichingo",
    "vichinghi": "vichingo",
    "vicina": "vicino",
    "vicinanze": "vicinanza",
    "vicinati": "vicinato",
    "vicine": "vicino",
    "vicini": "vicino",
    "viciniana": "viciniano",
    "viciniane": "viciniano",
    "viciniani": "viciniano",
    "vicissitudini": "vicissitudine",
    "vicoletti": "vicoletto",
    "vicoli": "vicolo",
    "vide": "vedere",
    "videa": "video",
    "videe": "video",
    "videi": "video",
    "video-cassette": "video-cassetta",
    "video-giochi": "video-gioco",
    "videoamatori": "videoamatore",
    "videoartisti": "videoartista",
    "videoartistica": "videoartistico",
    "videoartistiche": "videoartistico",
    "videoartistici": "videoartistico",
    "videocamere": "videocamera",
    "videocassette": "videocassetta",
    "videoconferenze": "videoconferenza",
    "videocrazie": "videocrazia",
    "videodischi": "videodisco",
    "videogames": "videogame",
    "videogiochi": "videogioco",
    "videoinstallazioni": "videoinstallazione",
    "videonastri": "videonastro",
    "videoregistra": "videoregistrare",
    "videoregistrai": "videoregistrare",
    "videoregistrammo": "videoregistrare",
    "videoregistran": "videoregistrare",
    "videoregistrando": "videoregistrare",
    "videoregistrano": "videoregistrare",
    "videoregistrante": "videoregistrare",
    "videoregistranti": "videoregistrare",
    "videoregistrar": "videoregistrare",
    "videoregistraron": "videoregistrare",
    "videoregistrarono": "videoregistrare",
    "videoregistrasse": "videoregistrare",
    "videoregistrasser": "videoregistrare",
    "videoregistrassero": "videoregistrare",
    "videoregistrassi": "videoregistrare",
    "videoregistrassimo": "videoregistrare",
    "videoregistraste": "videoregistrare",
    "videoregistrasti": "videoregistrare",
    "videoregistrata": "videoregistrare",
    "videoregistrate": "videoregistrare",
    "videoregistrati": "videoregistrare",
    "videoregistrato": "videoregistrare",
    "videoregistratori": "videoregistratore",
    "videoregistrava": "videoregistrare",
    "videoregistravamo": "videoregistrare",
    "videoregistravan": "videoregistrare",
    "videoregistravano": "videoregistrare",
    "videoregistravate": "videoregistrare",
    "videoregistravi": "videoregistrare",
    "videoregistravo": "videoregistrare",
    "videoregistrazioni": "videoregistrazione",
    "videoregistrerai": "videoregistrare",
    "videoregistreran": "videoregistrare",
    "videoregistreranno": "videoregistrare",
    "videoregistrerebbe": "videoregistrare",
    "videoregistrerebber": "videoregistrare",
    "videoregistrerebbero": "videoregistrare",
    "videoregistrerei": "videoregistrare",
    "videoregistreremmo": "videoregistrare",
    "videoregistreremo": "videoregistrare",
    "videoregistrereste": "videoregistrare",
    "videoregistreresti": "videoregistrare",
    "videoregistrerete": "videoregistrare",
    "videoregistrerà": "videoregistrare",
    "videoregistrerò": "videoregistrare",
    "videoregistri": "videoregistrare",
    "videoregistriamo": "videoregistrare",
    "videoregistriate": "videoregistrare",
    "videoregistrin": "videoregistrare",
    "videoregistrino": "videoregistrare",
    "videoregistro": "videoregistrare",
    "videoregistrò": "videoregistrare",
    "videoteche": "videoteca",
    "videotelefoni": "videotelefono",
    "videoterminali": "videoterminale",
    "vider": "vedere",
    "videro": "vedere",
    "vidi": "vedere",
    "vidima": "vidimare",
    "vidimai": "vidimare",
    "vidimammo": "vidimare",
    "vidiman": "vidimare",
    "vidimando": "vidimare",
    "vidimano": "vidimare",
    "vidimante": "vidimare",
    "vidimanti": "vidimare",
    "vidimar": "vidimare",
    "vidimaron": "vidimare",
    "vidimarono": "vidimare",
    "vidimasse": "vidimare",
    "vidimasser": "vidimare",
    "vidimassero": "vidimare",
    "vidimassi": "vidimare",
    "vidimassimo": "vidimare",
    "vidimaste": "vidimare",
    "vidimasti": "vidimare",
    "vidimata": "vidimare",
    "vidimate": "vidimare",
    "vidimati": "vidimare",
    "vidimato": "vidimare",
    "vidimava": "vidimare",
    "vidimavamo": "vidimare",
    "vidimavan": "vidimare",
    "vidimavano": "vidimare",
    "vidimavate": "vidimare",
    "vidimavi": "vidimare",
    "vidimavo": "vidimare",
    "vidimerai": "vidimare",
    "vidimeran": "vidimare",
    "vidimeranno": "vidimare",
    "vidimerebbe": "vidimare",
    "vidimerebber": "vidimare",
    "vidimerebbero": "vidimare",
    "vidimerei": "vidimare",
    "vidimeremmo": "vidimare",
    "vidimeremo": "vidimare",
    "vidimereste": "vidimare",
    "vidimeresti": "vidimare",
    "vidimerete": "vidimare",
    "vidimerà": "vidimare",
    "vidimerò": "vidimare",
    "vidimi": "vidimare",
    "vidimiamo": "vidimare",
    "vidimiate": "vidimare",
    "vidimin": "vidimare",
    "vidimino": "vidimare",
    "vidimo": "vidimare",
    "vidimò": "vidimare",
    "vie": "via",
    "viene": "venire",
    "vieni": "venire",
    "viennesi": "viennese",
    "vieta": "vietare",
    "vietai": "vietare",
    "vietammo": "vietare",
    "vietan": "vietare",
    "vietando": "vietare",
    "vietano": "vietare",
    "vietante": "vietare",
    "vietanti": "vietare",
    "vietar": "vietare",
    "vietaron": "vietare",
    "vietarono": "vietare",
    "vietasse": "vietare",
    "vietasser": "vietare",
    "vietassero": "vietare",
    "vietassi": "vietare",
    "vietassimo": "vietare",
    "vietaste": "vietare",
    "vietasti": "vietare",
    "vietata": "vietato",
    "vietate": "vietato",
    "vietati": "vietato",
    "vietato": "vietare",
    "vietava": "vietare",
    "vietavamo": "vietare",
    "vietavan": "vietare",
    "vietavano": "vietare",
    "vietavate": "vietare",
    "vietavi": "vietare",
    "vietavo": "vietare",
    "vieterai": "vietare",
    "vieteran": "vietare",
    "vieteranno": "vietare",
    "vieterebbe": "vietare",
    "vieterebber": "vietare",
    "vieterebbero": "vietare",
    "vieterei": "vietare",
    "vieteremmo": "vietare",
    "vieteremo": "vietare",
    "vietereste": "vietare",
    "vieteresti": "vietare",
    "vieterete": "vietare",
    "vieterà": "vietare",
    "vieterò": "vietare",
    "vieti": "vietare",
    "vietiamo": "vietare",
    "vietiate": "vietare",
    "vietin": "vietare",
    "vietino": "vietare",
    "vietnamite": "vietnamita",
    "vietnamiti": "vietnamita",
    "vietnamizza": "vietnamizzare",
    "vietnamizzai": "vietnamizzare",
    "vietnamizzammo": "vietnamizzare",
    "vietnamizzan": "vietnamizzare",
    "vietnamizzando": "vietnamizzare",
    "vietnamizzano": "vietnamizzare",
    "vietnamizzante": "vietnamizzare",
    "vietnamizzanti": "vietnamizzare",
    "vietnamizzar": "vietnamizzare",
    "vietnamizzaron": "vietnamizzare",
    "vietnamizzarono": "vietnamizzare",
    "vietnamizzasse": "vietnamizzare",
    "vietnamizzasser": "vietnamizzare",
    "vietnamizzassero": "vietnamizzare",
    "vietnamizzassi": "vietnamizzare",
    "vietnamizzassimo": "vietnamizzare",
    "vietnamizzaste": "vietnamizzare",
    "vietnamizzasti": "vietnamizzare",
    "vietnamizzata": "vietnamizzare",
    "vietnamizzate": "vietnamizzare",
    "vietnamizzati": "vietnamizzare",
    "vietnamizzato": "vietnamizzare",
    "vietnamizzava": "vietnamizzare",
    "vietnamizzavamo": "vietnamizzare",
    "vietnamizzavan": "vietnamizzare",
    "vietnamizzavano": "vietnamizzare",
    "vietnamizzavate": "vietnamizzare",
    "vietnamizzavi": "vietnamizzare",
    "vietnamizzavo": "vietnamizzare",
    "vietnamizzerai": "vietnamizzare",
    "vietnamizzeran": "vietnamizzare",
    "vietnamizzeranno": "vietnamizzare",
    "vietnamizzerebbe": "vietnamizzare",
    "vietnamizzerebber": "vietnamizzare",
    "vietnamizzerebbero": "vietnamizzare",
    "vietnamizzerei": "vietnamizzare",
    "vietnamizzeremmo": "vietnamizzare",
    "vietnamizzeremo": "vietnamizzare",
    "vietnamizzereste": "vietnamizzare",
    "vietnamizzeresti": "vietnamizzare",
    "vietnamizzerete": "vietnamizzare",
    "vietnamizzerà": "vietnamizzare",
    "vietnamizzerò": "vietnamizzare",
    "vietnamizzi": "vietnamizzare",
    "vietnamizziamo": "vietnamizzare",
    "vietnamizziate": "vietnamizzare",
    "vietnamizzin": "vietnamizzare",
    "vietnamizzino": "vietnamizzare",
    "vietnamizzo": "vietnamizzare",
    "vietnamizzò": "vietnamizzare",
    "vieto": "vietare",
    "vietò": "vietare",
    "viga": "vigere",
    "vigan": "vigere",
    "vigano": "vigere",
    "vige": "vigere",
    "vigei": "vigere",
    "vigemmo": "vigere",
    "vigendo": "vigere",
    "vigente": "vigere",
    "vigenti": "vigere",
    "vigenze": "vigenza",
    "viger": "vigere",
    "vigerai": "vigere",
    "vigeran": "vigere",
    "vigeranno": "vigere",
    "vigerebbe": "vigere",
    "vigerebber": "vigere",
    "vigerebbero": "vigere",
    "vigerei": "vigere",
    "vigeremmo": "vigere",
    "vigeremo": "vigere",
    "vigereste": "vigere",
    "vigeresti": "vigere",
    "vigerete": "vigere",
    "vigeron": "vigere",
    "vigerono": "vigere",
    "vigerà": "vigere",
    "vigerò": "vigere",
    "vigesse": "vigere",
    "vigesser": "vigere",
    "vigessero": "vigere",
    "vigessi": "vigere",
    "vigessimo": "vigere",
    "vigeste": "vigere",
    "vigesti": "vigere",
    "vigete": "vigere",
    "vigeva": "vigere",
    "vigevamo": "vigere",
    "vigevan": "vigere",
    "vigevanesi": "vigevanese",
    "vigevano": "vigere",
    "vigevate": "vigere",
    "vigevi": "vigere",
    "vigevo": "vigere",
    "vigi": "vigere",
    "vigiamo": "vigere",
    "vigiate": "vigere",
    "vigila": "vigilare",
    "vigilai": "vigilare",
    "vigilammo": "vigilare",
    "vigilan": "vigilare",
    "vigilando": "vigilare",
    "vigilano": "vigilare",
    "vigilante": "vigilare",
    "vigilanti": "vigilare",
    "vigilanze": "vigilanza",
    "vigilar": "vigilare",
    "vigilaron": "vigilare",
    "vigilarono": "vigilare",
    "vigilasse": "vigilare",
    "vigilasser": "vigilare",
    "vigilassero": "vigilare",
    "vigilassi": "vigilare",
    "vigilassimo": "vigilare",
    "vigilaste": "vigilare",
    "vigilasti": "vigilare",
    "vigilata": "vigilato",
    "vigilate": "vigilato",
    "vigilati": "vigilato",
    "vigilato": "vigilare",
    "vigilatrici": "vigilatrice",
    "vigilava": "vigilare",
    "vigilavamo": "vigilare",
    "vigilavan": "vigilare",
    "vigilavano": "vigilare",
    "vigilavate": "vigilare",
    "vigilavi": "vigilare",
    "vigilavo": "vigilare",
    "vigilerai": "vigilare",
    "vigileran": "vigilare",
    "vigileranno": "vigilare",
    "vigilerebbe": "vigilare",
    "vigilerebber": "vigilare",
    "vigilerebbero": "vigilare",
    "vigilerei": "vigilare",
    "vigileremmo": "vigilare",
    "vigileremo": "vigilare",
    "vigilereste": "vigilare",
    "vigileresti": "vigilare",
    "vigilerete": "vigilare",
    "vigilerà": "vigilare",
    "vigilerò": "vigilare",
    "vigilesse": "vigilessa",
    "vigili": "vigile",
    "vigiliamo": "vigilare",
    "vigiliate": "vigilare",
    "vigilie": "vigilia",
    "vigilin": "vigilare",
    "vigilino": "vigilare",
    "vigilo": "vigilare",
    "vigilò": "vigilare",
    "vigiuta": "vigere",
    "vigiute": "vigere",
    "vigiuti": "vigere",
    "vigiuto": "vigere",
    "vigliacca": "vigliacco",
    "vigliacche": "vigliacco",
    "vigliaccherie": "vigliaccheria",
    "vigliacchi": "vigliacco",
    "vignaioli": "vignaiolo",
    "vigne": "vigna",
    "vigneti": "vigneto",
    "vignette": "vignetta",
    "vignettisti": "vignettista",
    "vigo": "vigere",
    "vigon": "vigere",
    "vigono": "vigere",
    "vigori": "vigore",
    "vigorie": "vigoria",
    "vigorosa": "vigoroso",
    "vigorose": "vigoroso",
    "vigorosi": "vigoroso",
    "vigè": "vigere",
    "vili": "vile",
    "vilipenda": "vilipendere",
    "vilipendan": "vilipendere",
    "vilipendano": "vilipendere",
    "vilipende": "vilipendere",
    "vilipendemmo": "vilipendere",
    "vilipendendo": "vilipendere",
    "vilipendente": "vilipendere",
    "vilipendenti": "vilipendere",
    "vilipender": "vilipendere",
    "vilipenderai": "vilipendere",
    "vilipenderan": "vilipendere",
    "vilipenderanno": "vilipendere",
    "vilipenderebbe": "vilipendere",
    "vilipenderebber": "vilipendere",
    "vilipenderebbero": "vilipendere",
    "vilipenderei": "vilipendere",
    "vilipenderemmo": "vilipendere",
    "vilipenderemo": "vilipendere",
    "vilipendereste": "vilipendere",
    "vilipenderesti": "vilipendere",
    "vilipenderete": "vilipendere",
    "vilipenderà": "vilipendere",
    "vilipenderò": "vilipendere",
    "vilipendesse": "vilipendere",
    "vilipendesser": "vilipendere",
    "vilipendessero": "vilipendere",
    "vilipendessi": "vilipendere",
    "vilipendessimo": "vilipendere",
    "vilipendeste": "vilipendere",
    "vilipendesti": "vilipendere",
    "vilipendete": "vilipendere",
    "vilipendeva": "vilipendere",
    "vilipendevamo": "vilipendere",
    "vilipendevan": "vilipendere",
    "vilipendevano": "vilipendere",
    "vilipendevate": "vilipendere",
    "vilipendevi": "vilipendere",
    "vilipendevo": "vilipendere",
    "vilipendi": "vilipendio",
    "vilipendiamo": "vilipendere",
    "vilipendiate": "vilipendere",
    "vilipendo": "vilipendere",
    "vilipendon": "vilipendere",
    "vilipendono": "vilipendere",
    "vilipesa": "vilipendere",
    "vilipese": "vilipendere",
    "vilipeser": "vilipendere",
    "vilipesero": "vilipendere",
    "vilipesi": "vilipendere",
    "vilipeso": "vilipendere",
    "vilipesè": "vilipendere",
    "villaggi": "villaggio",
    "villagi": "villagio",
    "villana": "villano",
    "villane": "villano",
    "villanelle": "villanella",
    "villani": "villano",
    "villanie": "villania",
    "ville": "villa",
    "villeggerai": "villeggiare",
    "villeggeran": "villeggiare",
    "villeggeranno": "villeggiare",
    "villeggerebbe": "villeggiare",
    "villeggerebber": "villeggiare",
    "villeggerebbero": "villeggiare",
    "villeggerei": "villeggiare",
    "villeggeremmo": "villeggiare",
    "villeggeremo": "villeggiare",
    "villeggereste": "villeggiare",
    "villeggeresti": "villeggiare",
    "villeggerete": "villeggiare",
    "villeggerà": "villeggiare",
    "villeggerò": "villeggiare",
    "villeggi": "villeggiare",
    "villeggia": "villeggiare",
    "villeggiai": "villeggiare",
    "villeggiammo": "villeggiare",
    "villeggiamo": "villeggiare",
    "villeggian": "villeggiare",
    "villeggiando": "villeggiare",
    "villeggiano": "villeggiare",
    "villeggiante": "villeggiare",
    "villeggianti": "villeggiare",
    "villeggiar": "villeggiare",
    "villeggiaron": "villeggiare",
    "villeggiarono": "villeggiare",
    "villeggiasse": "villeggiare",
    "villeggiasser": "villeggiare",
    "villeggiassero": "villeggiare",
    "villeggiassi": "villeggiare",
    "villeggiassimo": "villeggiare",
    "villeggiaste": "villeggiare",
    "villeggiasti": "villeggiare",
    "villeggiata": "villeggiare",
    "villeggiate": "villeggiare",
    "villeggiati": "villeggiare",
    "villeggiato": "villeggiare",
    "villeggiature": "villeggiatura",
    "villeggiava": "villeggiare",
    "villeggiavamo": "villeggiare",
    "villeggiavan": "villeggiare",
    "villeggiavano": "villeggiare",
    "villeggiavate": "villeggiare",
    "villeggiavi": "villeggiare",
    "villeggiavo": "villeggiare",
    "villeggin": "villeggiare",
    "villeggino": "villeggiare",
    "villeggio": "villeggiare",
    "villeggiò": "villeggiare",
    "villerecce": "villereccio",
    "villerecci": "villereccio",
    "villereccia": "villereccio",
    "villette": "villetta",
    "villici": "villico",
    "villini": "villino",
    "villone": "villona",
    "villoni": "villone",
    "villosa": "villoso",
    "villose": "villoso",
    "villosi": "villoso",
    "viluppi": "viluppo",
    "vinai": "vinaio",
    "vinca": "vincere",
    "vincan": "vincere",
    "vincano": "vincere",
    "vince": "vincere",
    "vincemmo": "vincere",
    "vincendo": "vincere",
    "vincente": "vincere",
    "vincenti": "vincere",
    "vincer": "vincere",
    "vincerai": "vincere",
    "vinceran": "vincere",
    "vinceranno": "vincere",
    "vincerebbe": "vincere",
    "vincerebber": "vincere",
    "vincerebbero": "vincere",
    "vincerei": "vincere",
    "vinceremmo": "vincere",
    "vinceremo": "vincere",
    "vincereste": "vincere",
    "vinceresti": "vincere",
    "vincerete": "vincere",
    "vincerà": "vincere",
    "vincerò": "vincere",
    "vincesse": "vincere",
    "vincesser": "vincere",
    "vincessero": "vincere",
    "vincessi": "vincere",
    "vincessimo": "vincere",
    "vinceste": "vincere",
    "vincesti": "vincere",
    "vincete": "vincere",
    "vinceva": "vincere",
    "vincevamo": "vincere",
    "vincevan": "vincere",
    "vincevano": "vincere",
    "vincevate": "vincere",
    "vincevi": "vincere",
    "vincevo": "vincere",
    "vinci": "vincere",
    "vinciamo": "vincere",
    "vinciate": "vincere",
    "vincite": "vincita",
    "vincitori": "vincitore",
    "vincitrice": "vincitore",
    "vincitrici": "vincitrice",
    "vinco": "vincere",
    "vincola": "vincolare",
    "vincolai": "vincolare",
    "vincolammo": "vincolare",
    "vincolan": "vincolare",
    "vincolando": "vincolare",
    "vincolano": "vincolare",
    "vincolante": "vincolare",
    "vincolanti": "vincolare",
    "vincolar": "vincolare",
    "vincolari": "vincolare",
    "vincolaron": "vincolare",
    "vincolarono": "vincolare",
    "vincolasse": "vincolare",
    "vincolasser": "vincolare",
    "vincolassero": "vincolare",
    "vincolassi": "vincolare",
    "vincolassimo": "vincolare",
    "vincolaste": "vincolare",
    "vincolasti": "vincolare",
    "vincolata": "vincolato",
    "vincolate": "vincolato",
    "vincolati": "vincolato",
    "vincolato": "vincolare",
    "vincolava": "vincolare",
    "vincolavamo": "vincolare",
    "vincolavan": "vincolare",
    "vincolavano": "vincolare",
    "vincolavate": "vincolare",
    "vincolavi": "vincolare",
    "vincolavo": "vincolare",
    "vincolerai": "vincolare",
    "vincoleran": "vincolare",
    "vincoleranno": "vincolare",
    "vincolerebbe": "vincolare",
    "vincolerebber": "vincolare",
    "vincolerebbero": "vincolare",
    "vincolerei": "vincolare",
    "vincoleremmo": "vincolare",
    "vincoleremo": "vincolare",
    "vincolereste": "vincolare",
    "vincoleresti": "vincolare",
    "vincolerete": "vincolare",
    "vincolerà": "vincolare",
    "vincolerò": "vincolare",
    "vincoli": "vincolo",
    "vincoliamo": "vincolare",
    "vincoliate": "vincolare",
    "vincolin": "vincolare",
    "vincolino": "vincolare",
    "vincolistica": "vincolistico",
    "vincolistiche": "vincolistico",
    "vincolistici": "vincolistico",
    "vincolo": "vincolare",
    "vincolò": "vincolare",
    "vincon": "vincere",
    "vincono": "vincere",
    "vini": "vino",
    "vinicola": "vinicolo",
    "vinicole": "vinicolo",
    "vinicoli": "vinicolo",
    "vinifica": "vinificare",
    "vinificai": "vinificare",
    "vinificammo": "vinificare",
    "vinifican": "vinificare",
    "vinificando": "vinificare",
    "vinificano": "vinificare",
    "vinificante": "vinificare",
    "vinificanti": "vinificare",
    "vinificar": "vinificare",
    "vinificaron": "vinificare",
    "vinificarono": "vinificare",
    "vinificasse": "vinificare",
    "vinificasser": "vinificare",
    "vinificassero": "vinificare",
    "vinificassi": "vinificare",
    "vinificassimo": "vinificare",
    "vinificaste": "vinificare",
    "vinificasti": "vinificare",
    "vinificata": "vinificare",
    "vinificate": "vinificare",
    "vinificati": "vinificare",
    "vinificato": "vinificare",
    "vinificatori": "vinificatore",
    "vinificava": "vinificare",
    "vinificavamo": "vinificare",
    "vinificavan": "vinificare",
    "vinificavano": "vinificare",
    "vinificavate": "vinificare",
    "vinificavi": "vinificare",
    "vinificavo": "vinificare",
    "vinificherai": "vinificare",
    "vinificheran": "vinificare",
    "vinificheranno": "vinificare",
    "vinificherebbe": "vinificare",
    "vinificherebber": "vinificare",
    "vinificherebbero": "vinificare",
    "vinificherei": "vinificare",
    "vinificheremmo": "vinificare",
    "vinificheremo": "vinificare",
    "vinifichereste": "vinificare",
    "vinificheresti": "vinificare",
    "vinificherete": "vinificare",
    "vinificherà": "vinificare",
    "vinificherò": "vinificare",
    "vinifichi": "vinificare",
    "vinifichiamo": "vinificare",
    "vinifichiate": "vinificare",
    "vinifichin": "vinificare",
    "vinifichino": "vinificare",
    "vinifico": "vinificare",
    "vinificò": "vinificare",
    "vinse": "vincere",
    "vinser": "vincere",
    "vinsero": "vincere",
    "vinsi": "vincere",
    "vinta": "vinto",
    "vinte": "vinto",
    "vinti": "vinto",
    "vinto": "vincere",
    "viola": "violare",
    "violacea": "violaceo",
    "violacee": "violaceo",
    "violacei": "violaceo",
    "violai": "violare",
    "violammo": "violare",
    "violan": "violare",
    "violando": "violare",
    "violano": "violare",
    "violante": "violare",
    "violanti": "violare",
    "violar": "violare",
    "violaron": "violare",
    "violarono": "violare",
    "violasse": "violare",
    "violasser": "violare",
    "violassero": "violare",
    "violassi": "violare",
    "violassimo": "violare",
    "violaste": "violare",
    "violasti": "violare",
    "violata": "violare",
    "violate": "violare",
    "violati": "violare",
    "violato": "violare",
    "violatori": "violatore",
    "violava": "violare",
    "violavamo": "violare",
    "violavan": "violare",
    "violavano": "violare",
    "violavate": "violare",
    "violavi": "violare",
    "violavo": "violare",
    "violazioni": "violazione",
    "viole": "viola",
    "violenta": "violento",
    "violentai": "violentare",
    "violentammo": "violentare",
    "violentan": "violentare",
    "violentando": "violentare",
    "violentano": "violentare",
    "violentante": "violentare",
    "violentanti": "violentare",
    "violentar": "violentare",
    "violentaron": "violentare",
    "violentarono": "violentare",
    "violentasse": "violentare",
    "violentasser": "violentare",
    "violentassero": "violentare",
    "violentassi": "violentare",
    "violentassimo": "violentare",
    "violentaste": "violentare",
    "violentasti": "violentare",
    "violentata": "violentare",
    "violentate": "violentare",
    "violentati": "violentare",
    "violentato": "violentare",
    "violentatori": "violentatore",
    "violentava": "violentare",
    "violentavamo": "violentare",
    "violentavan": "violentare",
    "violentavano": "violentare",
    "violentavate": "violentare",
    "violentavi": "violentare",
    "violentavo": "violentare",
    "violente": "violento",
    "violenterai": "violentare",
    "violenteran": "violentare",
    "violenteranno": "violentare",
    "violenterebbe": "violentare",
    "violenterebber": "violentare",
    "violenterebbero": "violentare",
    "violenterei": "violentare",
    "violenteremmo": "violentare",
    "violenteremo": "violentare",
    "violentereste": "violentare",
    "violenteresti": "violentare",
    "violenterete": "violentare",
    "violenterà": "violentare",
    "violenterò": "violentare",
    "violenti": "violento",
    "violentiamo": "violentare",
    "violentiate": "violentare",
    "violentin": "violentare",
    "violentino": "violentare",
    "violento": "violentare",
    "violentò": "violentare",
    "violenze": "violenza",
    "violerai": "violare",
    "violeran": "violare",
    "violeranno": "violare",
    "violerebbe": "violare",
    "violerebber": "violare",
    "violerebbero": "violare",
    "violerei": "violare",
    "violeremmo": "violare",
    "violeremo": "violare",
    "violereste": "violare",
    "violeresti": "violare",
    "violerete": "violare",
    "violerà": "violare",
    "violerò": "violare",
    "violetta": "violetto",
    "violette": "violetto",
    "violetti": "violetto",
    "violi": "violare",
    "violiamo": "violare",
    "violiate": "violare",
    "violin": "violare",
    "violini": "violino",
    "violiniste": "violinista",
    "violinisti": "violinista",
    "violinistica": "violinistico",
    "violinistiche": "violinistico",
    "violinistici": "violinistico",
    "violino": "violare",
    "violo": "violare",
    "violoncelli": "violoncello",
    "violoncellisti": "violoncellista",
    "violò": "violare",
    "viottoli": "viottolo",
    "vipere": "vipera",
    "viperina": "viperino",
    "viperine": "viperino",
    "viperini": "viperino",
    "vira": "virare",
    "virai": "virare",
    "virali": "virale",
    "virammo": "virare",
    "viran": "virare",
    "virando": "virare",
    "virano": "virare",
    "virante": "virare",
    "viranti": "virare",
    "virar": "virare",
    "viraron": "virare",
    "virarono": "virare",
    "virasse": "virare",
    "virasser": "virare",
    "virassero": "virare",
    "virassi": "virare",
    "virassimo": "virare",
    "viraste": "virare",
    "virasti": "virare",
    "virata": "virare",
    "virate": "virata",
    "virati": "virare",
    "virato": "virare",
    "virava": "virare",
    "viravamo": "virare",
    "viravan": "virare",
    "viravano": "virare",
    "viravate": "virare",
    "viravi": "virare",
    "viravo": "virare",
    "virerai": "virare",
    "vireran": "virare",
    "vireranno": "virare",
    "virerebbe": "virare",
    "virerebber": "virare",
    "virerebbero": "virare",
    "virerei": "virare",
    "vireremmo": "virare",
    "vireremo": "virare",
    "virereste": "virare",
    "vireresti": "virare",
    "virerete": "virare",
    "virerà": "virare",
    "virerò": "virare",
    "virginali": "virginale",
    "virgole": "virgola",
    "virgoletta": "virgolettare",
    "virgolettai": "virgolettare",
    "virgolettammo": "virgolettare",
    "virgolettan": "virgolettare",
    "virgolettando": "virgolettare",
    "virgolettano": "virgolettare",
    "virgolettante": "virgolettare",
    "virgolettanti": "virgolettare",
    "virgolettar": "virgolettare",
    "virgolettaron": "virgolettare",
    "virgolettarono": "virgolettare",
    "virgolettasse": "virgolettare",
    "virgolettasser": "virgolettare",
    "virgolettassero": "virgolettare",
    "virgolettassi": "virgolettare",
    "virgolettassimo": "virgolettare",
    "virgolettaste": "virgolettare",
    "virgolettasti": "virgolettare",
    "virgolettata": "virgolettare",
    "virgolettate": "virgolettare",
    "virgolettati": "virgolettato",
    "virgolettato": "virgolettare",
    "virgolettava": "virgolettare",
    "virgolettavamo": "virgolettare",
    "virgolettavan": "virgolettare",
    "virgolettavano": "virgolettare",
    "virgolettavate": "virgolettare",
    "virgolettavi": "virgolettare",
    "virgolettavo": "virgolettare",
    "virgolette": "virgoletta",
    "virgoletterai": "virgolettare",
    "virgoletteran": "virgolettare",
    "virgoletteranno": "virgolettare",
    "virgoletterebbe": "virgolettare",
    "virgoletterebber": "virgolettare",
    "virgoletterebbero": "virgolettare",
    "virgoletterei": "virgolettare",
    "virgoletteremmo": "virgolettare",
    "virgoletteremo": "virgolettare",
    "virgolettereste": "virgolettare",
    "virgoletteresti": "virgolettare",
    "virgoletterete": "virgolettare",
    "virgoletterà": "virgolettare",
    "virgoletterò": "virgolettare",
    "virgoletti": "virgolettare",
    "virgolettiamo": "virgolettare",
    "virgolettiate": "virgolettare",
    "virgolettin": "virgolettare",
    "virgolettino": "virgolettare",
    "virgoletto": "virgolettare",
    "virgolettò": "virgolettare",
    "virgulti": "virgulto",
    "viri": "virare",
    "viriamo": "virare",
    "viriate": "virare",
    "virili": "virile",
    "virilizza": "virilizzare",
    "virilizzai": "virilizzare",
    "virilizzammo": "virilizzare",
    "virilizzan": "virilizzare",
    "virilizzando": "virilizzare",
    "virilizzano": "virilizzare",
    "virilizzante": "virilizzare",
    "virilizzanti": "virilizzare",
    "virilizzar": "virilizzare",
    "virilizzaron": "virilizzare",
    "virilizzarono": "virilizzare",
    "virilizzasse": "virilizzare",
    "virilizzasser": "virilizzare",
    "virilizzassero": "virilizzare",
    "virilizzassi": "virilizzare",
    "virilizzassimo": "virilizzare",
    "virilizzaste": "virilizzare",
    "virilizzasti": "virilizzare",
    "virilizzata": "virilizzare",
    "virilizzate": "virilizzare",
    "virilizzati": "virilizzare",
    "virilizzato": "virilizzare",
    "virilizzava": "virilizzare",
    "virilizzavamo": "virilizzare",
    "virilizzavan": "virilizzare",
    "virilizzavano": "virilizzare",
    "virilizzavate": "virilizzare",
    "virilizzavi": "virilizzare",
    "virilizzavo": "virilizzare",
    "virilizzerai": "virilizzare",
    "virilizzeran": "virilizzare",
    "virilizzeranno": "virilizzare",
    "virilizzerebbe": "virilizzare",
    "virilizzerebber": "virilizzare",
    "virilizzerebbero": "virilizzare",
    "virilizzerei": "virilizzare",
    "virilizzeremmo": "virilizzare",
    "virilizzeremo": "virilizzare",
    "virilizzereste": "virilizzare",
    "virilizzeresti": "virilizzare",
    "virilizzerete": "virilizzare",
    "virilizzerà": "virilizzare",
    "virilizzerò": "virilizzare",
    "virilizzi": "virilizzare",
    "virilizziamo": "virilizzare",
    "virilizziate": "virilizzare",
    "virilizzin": "virilizzare",
    "virilizzino": "virilizzare",
    "virilizzo": "virilizzare",
    "virilizzò": "virilizzare",
    "virin": "virare",
    "virino": "virare",
    "viro": "virare",
    "virologi": "virologo",
    "virtuali": "virtuale",
    "virtuosa": "virtuoso",
    "virtuose": "virtuoso",
    "virtuosi": "virtuoso",
    "virtuosismi": "virtuosismo",
    "virulenta": "virulento",
    "virulente": "virulento",
    "virulenti": "virulento",
    "virò": "virare",
    "viscerali": "viscerale",
    "visceri": "viscere",
    "vischiosa": "vischioso",
    "vischiose": "vischioso",
    "vischiosi": "vischioso",
    "viscida": "viscido",
    "viscide": "viscido",
    "viscidi": "viscido",
    "viscontea": "visconteo",
    "viscontee": "visconteo",
    "viscontei": "visconteo",
    "visconti": "visconte",
    "viscontiana": "viscontiano",
    "viscontiane": "viscontiano",
    "viscontiani": "viscontiano",
    "viscosa": "viscoso",
    "viscose": "viscoso",
    "viscosi": "viscoso",
    "visentiniana": "visentiniano",
    "visentiniane": "visentiniano",
    "visentiniani": "visentiniano",
    "visetti": "visetto",
    "visi": "viso",
    "visibili": "visibile",
    "visiere": "visiera",
    "visini": "visino",
    "visiona": "visionare",
    "visionai": "visionare",
    "visionammo": "visionare",
    "visionan": "visionare",
    "visionando": "visionare",
    "visionano": "visionare",
    "visionante": "visionare",
    "visionanti": "visionare",
    "visionar": "visionare",
    "visionari": "visionario",
    "visionaria": "visionario",
    "visionarie": "visionario",
    "visionaron": "visionare",
    "visionarono": "visionare",
    "visionasse": "visionare",
    "visionasser": "visionare",
    "visionassero": "visionare",
    "visionassi": "visionare",
    "visionassimo": "visionare",
    "visionaste": "visionare",
    "visionasti": "visionare",
    "visionata": "visionare",
    "visionate": "visionare",
    "visionati": "visionare",
    "visionato": "visionare",
    "visionava": "visionare",
    "visionavamo": "visionare",
    "visionavan": "visionare",
    "visionavano": "visionare",
    "visionavate": "visionare",
    "visionavi": "visionare",
    "visionavo": "visionare",
    "visionerai": "visionare",
    "visioneran": "visionare",
    "visioneranno": "visionare",
    "visionerebbe": "visionare",
    "visionerebber": "visionare",
    "visionerebbero": "visionare",
    "visionerei": "visionare",
    "visioneremmo": "visionare",
    "visioneremo": "visionare",
    "visionereste": "visionare",
    "visioneresti": "visionare",
    "visionerete": "visionare",
    "visionerà": "visionare",
    "visionerò": "visionare",
    "visioni": "visione",
    "visioniamo": "visionare",
    "visioniate": "visionare",
    "visionin": "visionare",
    "visionino": "visionare",
    "visiono": "visionare",
    "visionò": "visionare",
    "visita": "visitare",
    "visitabili": "visitabile",
    "visitai": "visitare",
    "visitammo": "visitare",
    "visitan": "visitare",
    "visitando": "visitare",
    "visitano": "visitare",
    "visitante": "visitare",
    "visitanti": "visitare",
    "visitar": "visitare",
    "visitaron": "visitare",
    "visitarono": "visitare",
    "visitasse": "visitare",
    "visitasser": "visitare",
    "visitassero": "visitare",
    "visitassi": "visitare",
    "visitassimo": "visitare",
    "visitaste": "visitare",
    "visitasti": "visitare",
    "visitata": "visitare",
    "visitate": "visitare",
    "visitati": "visitare",
    "visitato": "visitare",
    "visitatori": "visitatore",
    "visitatrici": "visitatrice",
    "visitava": "visitare",
    "visitavamo": "visitare",
    "visitavan": "visitare",
    "visitavano": "visitare",
    "visitavate": "visitare",
    "visitavi": "visitare",
    "visitavo": "visitare",
    "visite": "visita",
    "visiterai": "visitare",
    "visiteran": "visitare",
    "visiteranno": "visitare",
    "visiterebbe": "visitare",
    "visiterebber": "visitare",
    "visiterebbero": "visitare",
    "visiterei": "visitare",
    "visiteremmo": "visitare",
    "visiteremo": "visitare",
    "visitereste": "visitare",
    "visiteresti": "visitare",
    "visiterete": "visitare",
    "visiterà": "visitare",
    "visiterò": "visitare",
    "visiti": "visitare",
    "visitiamo": "visitare",
    "visitiate": "visitare",
    "visitin": "visitare",
    "visitine": "visitina",
    "visitino": "visitare",
    "visito": "visitare",
    "visitò": "visitare",
    "visiva": "visivo",
    "visive": "visivo",
    "visivi": "visivo",
    "visoni": "visone",
    "visori": "visore",
    "vispa": "vispo",
    "vispe": "vispo",
    "vispi": "vispo",
    "visse": "vivere",
    "visser": "vivere",
    "vissero": "vivere",
    "vissi": "vivere",
    "vissuta": "vivere",
    "vissute": "vivere",
    "vissuti": "vivere",
    "vissuto": "vivere",
    "vista": "vistare",
    "vistai": "vistare",
    "vistammo": "vistare",
    "vistan": "vistare",
    "vistando": "vistare",
    "vistano": "vistare",
    "vistante": "vistare",
    "vistanti": "vistare",
    "vistar": "vistare",
    "vistaron": "vistare",
    "vistarono": "vistare",
    "vistasse": "vistare",
    "vistasser": "vistare",
    "vistassero": "vistare",
    "vistassi": "vistare",
    "vistassimo": "vistare",
    "vistaste": "vistare",
    "vistasti": "vistare",
    "vistata": "vistare",
    "vistate": "vistare",
    "vistati": "vistare",
    "vistato": "vistare",
    "vistava": "vistare",
    "vistavamo": "vistare",
    "vistavan": "vistare",
    "vistavano": "vistare",
    "vistavate": "vistare",
    "vistavi": "vistare",
    "vistavo": "vistare",
    "viste": "vista",
    "visterai": "vistare",
    "visteran": "vistare",
    "visteranno": "vistare",
    "visterebbe": "vistare",
    "visterebber": "vistare",
    "visterebbero": "vistare",
    "visterei": "vistare",
    "visteremmo": "vistare",
    "visteremo": "vistare",
    "vistereste": "vistare",
    "visteresti": "vistare",
    "visterete": "vistare",
    "visterà": "vistare",
    "visterò": "vistare",
    "visti": "vistare",
    "vistiamo": "vistare",
    "vistiate": "vistare",
    "vistin": "vistare",
    "vistino": "vistare",
    "visto": "vistare",
    "vistosa": "vistoso",
    "vistose": "vistoso",
    "vistosi": "vistoso",
    "vistò": "vistare",
    "visuali": "visuale",
    "visualizza": "visualizzare",
    "visualizzai": "visualizzare",
    "visualizzammo": "visualizzare",
    "visualizzan": "visualizzare",
    "visualizzando": "visualizzare",
    "visualizzano": "visualizzare",
    "visualizzante": "visualizzare",
    "visualizzanti": "visualizzare",
    "visualizzar": "visualizzare",
    "visualizzaron": "visualizzare",
    "visualizzarono": "visualizzare",
    "visualizzasse": "visualizzare",
    "visualizzasser": "visualizzare",
    "visualizzassero": "visualizzare",
    "visualizzassi": "visualizzare",
    "visualizzassimo": "visualizzare",
    "visualizzaste": "visualizzare",
    "visualizzasti": "visualizzare",
    "visualizzata": "visualizzare",
    "visualizzate": "visualizzare",
    "visualizzati": "visualizzare",
    "visualizzato": "visualizzare",
    "visualizzava": "visualizzare",
    "visualizzavamo": "visualizzare",
    "visualizzavan": "visualizzare",
    "visualizzavano": "visualizzare",
    "visualizzavate": "visualizzare",
    "visualizzavi": "visualizzare",
    "visualizzavo": "visualizzare",
    "visualizzazioni": "visualizzazione",
    "visualizzerai": "visualizzare",
    "visualizzeran": "visualizzare",
    "visualizzeranno": "visualizzare",
    "visualizzerebbe": "visualizzare",
    "visualizzerebber": "visualizzare",
    "visualizzerebbero": "visualizzare",
    "visualizzerei": "visualizzare",
    "visualizzeremmo": "visualizzare",
    "visualizzeremo": "visualizzare",
    "visualizzereste": "visualizzare",
    "visualizzeresti": "visualizzare",
    "visualizzerete": "visualizzare",
    "visualizzerà": "visualizzare",
    "visualizzerò": "visualizzare",
    "visualizzi": "visualizzare",
    "visualizziamo": "visualizzare",
    "visualizziate": "visualizzare",
    "visualizzin": "visualizzare",
    "visualizzino": "visualizzare",
    "visualizzo": "visualizzare",
    "visualizzò": "visualizzare",
    "visure": "visura",
    "vitali": "vitale",
    "vitalismi": "vitalismo",
    "vitalizi": "vitalizio",
    "vitalizia": "vitalizio",
    "vitalizie": "vitalizio",
    "vitamine": "vitamina",
    "vitaminica": "vitaminico",
    "vitaminiche": "vitaminico",
    "vitaminici": "vitaminico",
    "vitaminizza": "vitaminizzare",
    "vitaminizzai": "vitaminizzare",
    "vitaminizzammo": "vitaminizzare",
    "vitaminizzan": "vitaminizzare",
    "vitaminizzando": "vitaminizzare",
    "vitaminizzano": "vitaminizzare",
    "vitaminizzante": "vitaminizzare",
    "vitaminizzanti": "vitaminizzare",
    "vitaminizzar": "vitaminizzare",
    "vitaminizzaron": "vitaminizzare",
    "vitaminizzarono": "vitaminizzare",
    "vitaminizzasse": "vitaminizzare",
    "vitaminizzasser": "vitaminizzare",
    "vitaminizzassero": "vitaminizzare",
    "vitaminizzassi": "vitaminizzare",
    "vitaminizzassimo": "vitaminizzare",
    "vitaminizzaste": "vitaminizzare",
    "vitaminizzasti": "vitaminizzare",
    "vitaminizzata": "vitaminizzare",
    "vitaminizzate": "vitaminizzare",
    "vitaminizzati": "vitaminizzare",
    "vitaminizzato": "vitaminizzare",
    "vitaminizzava": "vitaminizzare",
    "vitaminizzavamo": "vitaminizzare",
    "vitaminizzavan": "vitaminizzare",
    "vitaminizzavano": "vitaminizzare",
    "vitaminizzavate": "vitaminizzare",
    "vitaminizzavi": "vitaminizzare",
    "vitaminizzavo": "vitaminizzare",
    "vitaminizzerai": "vitaminizzare",
    "vitaminizzeran": "vitaminizzare",
    "vitaminizzeranno": "vitaminizzare",
    "vitaminizzerebbe": "vitaminizzare",
    "vitaminizzerebber": "vitaminizzare",
    "vitaminizzerebbero": "vitaminizzare",
    "vitaminizzerei": "vitaminizzare",
    "vitaminizzeremmo": "vitaminizzare",
    "vitaminizzeremo": "vitaminizzare",
    "vitaminizzereste": "vitaminizzare",
    "vitaminizzeresti": "vitaminizzare",
    "vitaminizzerete": "vitaminizzare",
    "vitaminizzerà": "vitaminizzare",
    "vitaminizzerò": "vitaminizzare",
    "vitaminizzi": "vitaminizzare",
    "vitaminizziamo": "vitaminizzare",
    "vitaminizziate": "vitaminizzare",
    "vitaminizzin": "vitaminizzare",
    "vitaminizzino": "vitaminizzare",
    "vitaminizzo": "vitaminizzare",
    "vitaminizzò": "vitaminizzare",
    "vite": "vita",
    "vitelli": "vitello",
    "vitellina": "vitellino",
    "vitelline": "vitellino",
    "vitellini": "vitellino",
    "vitelloni": "vitellone",
    "viterbesi": "viterbese",
    "viti": "vite",
    "viticola": "viticolo",
    "viticole": "viticolo",
    "viticoli": "viticolo",
    "viticoltori": "viticoltore",
    "vitigni": "vitigno",
    "vitivinicola": "vitivinicolo",
    "vitivinicole": "vitivinicolo",
    "vitivinicoli": "vitivinicolo",
    "vitrea": "vitreo",
    "vitree": "vitreo",
    "vitrei": "vitreo",
    "vitti": "vitto",
    "vittime": "vittima",
    "vittimismi": "vittimismo",
    "vittimizza": "vittimizzare",
    "vittimizzai": "vittimizzare",
    "vittimizzammo": "vittimizzare",
    "vittimizzan": "vittimizzare",
    "vittimizzando": "vittimizzare",
    "vittimizzano": "vittimizzare",
    "vittimizzante": "vittimizzare",
    "vittimizzanti": "vittimizzare",
    "vittimizzar": "vittimizzare",
    "vittimizzaron": "vittimizzare",
    "vittimizzarono": "vittimizzare",
    "vittimizzasse": "vittimizzare",
    "vittimizzasser": "vittimizzare",
    "vittimizzassero": "vittimizzare",
    "vittimizzassi": "vittimizzare",
    "vittimizzassimo": "vittimizzare",
    "vittimizzaste": "vittimizzare",
    "vittimizzasti": "vittimizzare",
    "vittimizzata": "vittimizzare",
    "vittimizzate": "vittimizzare",
    "vittimizzati": "vittimizzare",
    "vittimizzato": "vittimizzare",
    "vittimizzava": "vittimizzare",
    "vittimizzavamo": "vittimizzare",
    "vittimizzavan": "vittimizzare",
    "vittimizzavano": "vittimizzare",
    "vittimizzavate": "vittimizzare",
    "vittimizzavi": "vittimizzare",
    "vittimizzavo": "vittimizzare",
    "vittimizzerai": "vittimizzare",
    "vittimizzeran": "vittimizzare",
    "vittimizzeranno": "vittimizzare",
    "vittimizzerebbe": "vittimizzare",
    "vittimizzerebber": "vittimizzare",
    "vittimizzerebbero": "vittimizzare",
    "vittimizzerei": "vittimizzare",
    "vittimizzeremmo": "vittimizzare",
    "vittimizzeremo": "vittimizzare",
    "vittimizzereste": "vittimizzare",
    "vittimizzeresti": "vittimizzare",
    "vittimizzerete": "vittimizzare",
    "vittimizzerà": "vittimizzare",
    "vittimizzerò": "vittimizzare",
    "vittimizzi": "vittimizzare",
    "vittimizziamo": "vittimizzare",
    "vittimizziate": "vittimizzare",
    "vittimizzin": "vittimizzare",
    "vittimizzino": "vittimizzare",
    "vittimizzo": "vittimizzare",
    "vittimizzò": "vittimizzare",
    "vittoriana": "vittoriano",
    "vittoriane": "vittoriano",
    "vittoriani": "vittoriano",
    "vittorie": "vittoria",
    "vittoriosa": "vittorioso",
    "vittoriose": "vittorioso",
    "vittoriosi": "vittorioso",
    "vitulanesi": "vitulanese",
    "vitupera": "vituperare",
    "vituperai": "vituperare",
    "vituperammo": "vituperare",
    "vituperan": "vituperare",
    "vituperando": "vituperare",
    "vituperano": "vituperare",
    "vituperante": "vituperare",
    "vituperanti": "vituperare",
    "vituperar": "vituperare",
    "vituperaron": "vituperare",
    "vituperarono": "vituperare",
    "vituperasse": "vituperare",
    "vituperasser": "vituperare",
    "vituperassero": "vituperare",
    "vituperassi": "vituperare",
    "vituperassimo": "vituperare",
    "vituperaste": "vituperare",
    "vituperasti": "vituperare",
    "vituperata": "vituperare",
    "vituperate": "vituperare",
    "vituperati": "vituperato",
    "vituperato": "vituperare",
    "vituperava": "vituperare",
    "vituperavamo": "vituperare",
    "vituperavan": "vituperare",
    "vituperavano": "vituperare",
    "vituperavate": "vituperare",
    "vituperavi": "vituperare",
    "vituperavo": "vituperare",
    "vitupererai": "vituperare",
    "vitupereran": "vituperare",
    "vitupereranno": "vituperare",
    "vitupererebbe": "vituperare",
    "vitupererebber": "vituperare",
    "vitupererebbero": "vituperare",
    "vitupererei": "vituperare",
    "vitupereremmo": "vituperare",
    "vitupereremo": "vituperare",
    "vituperereste": "vituperare",
    "vitupereresti": "vituperare",
    "vitupererete": "vituperare",
    "vitupererà": "vituperare",
    "vitupererò": "vituperare",
    "vituperi": "vituperio",
    "vituperiamo": "vituperare",
    "vituperiate": "vituperare",
    "vituperin": "vituperare",
    "vituperino": "vituperare",
    "vitupero": "vituperare",
    "vituperosa": "vituperoso",
    "vituperose": "vituperoso",
    "vituperosi": "vituperoso",
    "vituperò": "vituperare",
    "viuzze": "viuzza",
    "viva": "vivo",
    "vivacchi": "vivacchiare",
    "vivacchia": "vivacchiare",
    "vivacchiai": "vivacchiare",
    "vivacchiammo": "vivacchiare",
    "vivacchiamo": "vivacchiare",
    "vivacchian": "vivacchiare",
    "vivacchiando": "vivacchiare",
    "vivacchiano": "vivacchiare",
    "vivacchiante": "vivacchiare",
    "vivacchianti": "vivacchiare",
    "vivacchiar": "vivacchiare",
    "vivacchiaron": "vivacchiare",
    "vivacchiarono": "vivacchiare",
    "vivacchiasse": "vivacchiare",
    "vivacchiasser": "vivacchiare",
    "vivacchiassero": "vivacchiare",
    "vivacchiassi": "vivacchiare",
    "vivacchiassimo": "vivacchiare",
    "vivacchiaste": "vivacchiare",
    "vivacchiasti": "vivacchiare",
    "vivacchiata": "vivacchiare",
    "vivacchiate": "vivacchiare",
    "vivacchiati": "vivacchiare",
    "vivacchiato": "vivacchiare",
    "vivacchiava": "vivacchiare",
    "vivacchiavamo": "vivacchiare",
    "vivacchiavan": "vivacchiare",
    "vivacchiavano": "vivacchiare",
    "vivacchiavate": "vivacchiare",
    "vivacchiavi": "vivacchiare",
    "vivacchiavo": "vivacchiare",
    "vivacchierai": "vivacchiare",
    "vivacchieran": "vivacchiare",
    "vivacchieranno": "vivacchiare",
    "vivacchierebbe": "vivacchiare",
    "vivacchierebber": "vivacchiare",
    "vivacchierebbero": "vivacchiare",
    "vivacchierei": "vivacchiare",
    "vivacchieremmo": "vivacchiare",
    "vivacchieremo": "vivacchiare",
    "vivacchiereste": "vivacchiare",
    "vivacchieresti": "vivacchiare",
    "vivacchierete": "vivacchiare",
    "vivacchierà": "vivacchiare",
    "vivacchierò": "vivacchiare",
    "vivacchin": "vivacchiare",
    "vivacchino": "vivacchiare",
    "vivacchio": "vivacchiare",
    "vivacchiò": "vivacchiare",
    "vivaci": "vivace",
    "vivacizza": "vivacizzare",
    "vivacizzai": "vivacizzare",
    "vivacizzammo": "vivacizzare",
    "vivacizzan": "vivacizzare",
    "vivacizzando": "vivacizzare",
    "vivacizzano": "vivacizzare",
    "vivacizzante": "vivacizzare",
    "vivacizzanti": "vivacizzare",
    "vivacizzar": "vivacizzare",
    "vivacizzaron": "vivacizzare",
    "vivacizzarono": "vivacizzare",
    "vivacizzasse": "vivacizzare",
    "vivacizzasser": "vivacizzare",
    "vivacizzassero": "vivacizzare",
    "vivacizzassi": "vivacizzare",
    "vivacizzassimo": "vivacizzare",
    "vivacizzaste": "vivacizzare",
    "vivacizzasti": "vivacizzare",
    "vivacizzata": "vivacizzare",
    "vivacizzate": "vivacizzare",
    "vivacizzati": "vivacizzare",
    "vivacizzato": "vivacizzare",
    "vivacizzava": "vivacizzare",
    "vivacizzavamo": "vivacizzare",
    "vivacizzavan": "vivacizzare",
    "vivacizzavano": "vivacizzare",
    "vivacizzavate": "vivacizzare",
    "vivacizzavi": "vivacizzare",
    "vivacizzavo": "vivacizzare",
    "vivacizzerai": "vivacizzare",
    "vivacizzeran": "vivacizzare",
    "vivacizzeranno": "vivacizzare",
    "vivacizzerebbe": "vivacizzare",
    "vivacizzerebber": "vivacizzare",
    "vivacizzerebbero": "vivacizzare",
    "vivacizzerei": "vivacizzare",
    "vivacizzeremmo": "vivacizzare",
    "vivacizzeremo": "vivacizzare",
    "vivacizzereste": "vivacizzare",
    "vivacizzeresti": "vivacizzare",
    "vivacizzerete": "vivacizzare",
    "vivacizzerà": "vivacizzare",
    "vivacizzerò": "vivacizzare",
    "vivacizzi": "vivacizzare",
    "vivacizziamo": "vivacizzare",
    "vivacizziate": "vivacizzare",
    "vivacizzin": "vivacizzare",
    "vivacizzino": "vivacizzare",
    "vivacizzo": "vivacizzare",
    "vivacizzò": "vivacizzare",
    "vivai": "vivaio",
    "vivaisti": "vivaista",
    "vivaldiana": "vivaldiano",
    "vivaldiane": "vivaldiano",
    "vivaldiani": "vivaldiano",
    "vivan": "vivere",
    "vivande": "vivanda",
    "vivandiere": "vivandiera",
    "vivandieri": "vivandiere",
    "vivano": "vivere",
    "vive": "vivo",
    "vivemmo": "vivere",
    "vivendo": "vivere",
    "vivente": "vivere",
    "viventi": "vivere",
    "viver": "vivere",
    "viveri": "vivero",
    "vivesse": "vivere",
    "vivesser": "vivere",
    "vivessero": "vivere",
    "vivessi": "vivere",
    "vivessimo": "vivere",
    "viveste": "vivere",
    "vivesti": "vivere",
    "vivete": "vivere",
    "viveva": "vivere",
    "vivevamo": "vivere",
    "vivevan": "vivere",
    "vivevano": "vivere",
    "vivevate": "vivere",
    "vivevi": "vivere",
    "vivevo": "vivere",
    "vivi": "vivo",
    "viviamo": "vivere",
    "vivianesca": "vivianesco",
    "vivianesche": "vivianesco",
    "vivianeschi": "vivianesco",
    "viviate": "vivere",
    "vivibili": "vivibile",
    "vivida": "vivido",
    "vivide": "vivido",
    "vividi": "vivido",
    "vivifica": "vivificare",
    "vivificai": "vivificare",
    "vivificammo": "vivificare",
    "vivifican": "vivificare",
    "vivificando": "vivificare",
    "vivificano": "vivificare",
    "vivificante": "vivificare",
    "vivificanti": "vivificare",
    "vivificar": "vivificare",
    "vivificaron": "vivificare",
    "vivificarono": "vivificare",
    "vivificasse": "vivificare",
    "vivificasser": "vivificare",
    "vivificassero": "vivificare",
    "vivificassi": "vivificare",
    "vivificassimo": "vivificare",
    "vivificaste": "vivificare",
    "vivificasti": "vivificare",
    "vivificata": "vivificare",
    "vivificate": "vivificare",
    "vivificati": "vivificare",
    "vivificato": "vivificare",
    "vivificatori": "vivificatore",
    "vivificatrice": "vivificatore",
    "vivificatrici": "vivificatore",
    "vivificava": "vivificare",
    "vivificavamo": "vivificare",
    "vivificavan": "vivificare",
    "vivificavano": "vivificare",
    "vivificavate": "vivificare",
    "vivificavi": "vivificare",
    "vivificavo": "vivificare",
    "vivificherai": "vivificare",
    "vivificheran": "vivificare",
    "vivificheranno": "vivificare",
    "vivificherebbe": "vivificare",
    "vivificherebber": "vivificare",
    "vivificherebbero": "vivificare",
    "vivificherei": "vivificare",
    "vivificheremmo": "vivificare",
    "vivificheremo": "vivificare",
    "vivifichereste": "vivificare",
    "vivificheresti": "vivificare",
    "vivificherete": "vivificare",
    "vivificherà": "vivificare",
    "vivificherò": "vivificare",
    "vivifichi": "vivificare",
    "vivifichiamo": "vivificare",
    "vivifichiate": "vivificare",
    "vivifichin": "vivificare",
    "vivifichino": "vivificare",
    "vivifico": "vivificare",
    "vivificò": "vivificare",
    "viviseziona": "vivisezionare",
    "vivisezionai": "vivisezionare",
    "vivisezionammo": "vivisezionare",
    "vivisezionan": "vivisezionare",
    "vivisezionando": "vivisezionare",
    "vivisezionano": "vivisezionare",
    "vivisezionante": "vivisezionare",
    "vivisezionanti": "vivisezionare",
    "vivisezionar": "vivisezionare",
    "vivisezionaron": "vivisezionare",
    "vivisezionarono": "vivisezionare",
    "vivisezionasse": "vivisezionare",
    "vivisezionasser": "vivisezionare",
    "vivisezionassero": "vivisezionare",
    "vivisezionassi": "vivisezionare",
    "vivisezionassimo": "vivisezionare",
    "vivisezionaste": "vivisezionare",
    "vivisezionasti": "vivisezionare",
    "vivisezionata": "vivisezionare",
    "vivisezionate": "vivisezionare",
    "vivisezionati": "vivisezionare",
    "vivisezionato": "vivisezionare",
    "vivisezionava": "vivisezionare",
    "vivisezionavamo": "vivisezionare",
    "vivisezionavan": "vivisezionare",
    "vivisezionavano": "vivisezionare",
    "vivisezionavate": "vivisezionare",
    "vivisezionavi": "vivisezionare",
    "vivisezionavo": "vivisezionare",
    "vivisezionerai": "vivisezionare",
    "vivisezioneran": "vivisezionare",
    "vivisezioneranno": "vivisezionare",
    "vivisezionerebbe": "vivisezionare",
    "vivisezionerebber": "vivisezionare",
    "vivisezionerebbero": "vivisezionare",
    "vivisezionerei": "vivisezionare",
    "vivisezioneremmo": "vivisezionare",
    "vivisezioneremo": "vivisezionare",
    "vivisezionereste": "vivisezionare",
    "vivisezioneresti": "vivisezionare",
    "vivisezionerete": "vivisezionare",
    "vivisezionerà": "vivisezionare",
    "vivisezionerò": "vivisezionare",
    "vivisezioni": "vivisezione",
    "vivisezioniamo": "vivisezionare",
    "vivisezioniate": "vivisezionare",
    "vivisezionin": "vivisezionare",
    "vivisezionino": "vivisezionare",
    "viviseziono": "vivisezionare",
    "vivisezionò": "vivisezionare",
    "vivo": "vivere",
    "vivon": "vivere",
    "vivono": "vivere",
    "vivrai": "vivere",
    "vivran": "vivere",
    "vivranno": "vivere",
    "vivrebbe": "vivere",
    "vivrebber": "vivere",
    "vivrebbero": "vivere",
    "vivrei": "vivere",
    "vivremmo": "vivere",
    "vivremo": "vivere",
    "vivreste": "vivere",
    "vivresti": "vivere",
    "vivrete": "vivere",
    "vivrà": "vivere",
    "vivrò": "vivere",
    "vizi": "vizio",
    "vizia": "viziare",
    "viziai": "viziare",
    "viziammo": "viziare",
    "viziamo": "viziare",
    "vizian": "viziare",
    "viziando": "viziare",
    "viziano": "viziare",
    "viziante": "viziare",
    "vizianti": "viziare",
    "viziar": "viziare",
    "viziaron": "viziare",
    "viziarono": "viziare",
    "viziasse": "viziare",
    "viziasser": "viziare",
    "viziassero": "viziare",
    "viziassi": "viziare",
    "viziassimo": "viziare",
    "viziaste": "viziare",
    "viziasti": "viziare",
    "viziata": "viziato",
    "viziate": "viziato",
    "viziati": "viziato",
    "viziato": "viziare",
    "viziava": "viziare",
    "viziavamo": "viziare",
    "viziavan": "viziare",
    "viziavano": "viziare",
    "viziavate": "viziare",
    "viziavi": "viziare",
    "viziavo": "viziare",
    "vizierai": "viziare",
    "vizieran": "viziare",
    "vizieranno": "viziare",
    "vizierebbe": "viziare",
    "vizierebber": "viziare",
    "vizierebbero": "viziare",
    "vizierei": "viziare",
    "vizieremmo": "viziare",
    "vizieremo": "viziare",
    "viziereste": "viziare",
    "vizieresti": "viziare",
    "vizierete": "viziare",
    "vizierà": "viziare",
    "vizierò": "viziare",
    "vizietti": "vizietto",
    "vizin": "viziare",
    "vizino": "viziare",
    "vizio": "viziare",
    "viziosa": "vizioso",
    "viziose": "vizioso",
    "viziosi": "vizioso",
    "viziò": "viziare",
    "vizza": "vizzo",
    "vizze": "vizzo",
    "vizzi": "vizzo",
    "vocabolari": "vocabolario",
    "vocaboli": "vocabolo",
    "vocali": "vocale",
    "vocalica": "vocalico",
    "vocaliche": "vocalico",
    "vocalici": "vocalico",
    "vocaliste": "vocalista",
    "vocalisti": "vocalista",
    "vocalizza": "vocalizzare",
    "vocalizzai": "vocalizzare",
    "vocalizzammo": "vocalizzare",
    "vocalizzan": "vocalizzare",
    "vocalizzando": "vocalizzare",
    "vocalizzano": "vocalizzare",
    "vocalizzante": "vocalizzare",
    "vocalizzanti": "vocalizzare",
    "vocalizzar": "vocalizzare",
    "vocalizzaron": "vocalizzare",
    "vocalizzarono": "vocalizzare",
    "vocalizzasse": "vocalizzare",
    "vocalizzasser": "vocalizzare",
    "vocalizzassero": "vocalizzare",
    "vocalizzassi": "vocalizzare",
    "vocalizzassimo": "vocalizzare",
    "vocalizzaste": "vocalizzare",
    "vocalizzasti": "vocalizzare",
    "vocalizzata": "vocalizzare",
    "vocalizzate": "vocalizzare",
    "vocalizzati": "vocalizzare",
    "vocalizzato": "vocalizzare",
    "vocalizzava": "vocalizzare",
    "vocalizzavamo": "vocalizzare",
    "vocalizzavan": "vocalizzare",
    "vocalizzavano": "vocalizzare",
    "vocalizzavate": "vocalizzare",
    "vocalizzavi": "vocalizzare",
    "vocalizzavo": "vocalizzare",
    "vocalizzerai": "vocalizzare",
    "vocalizzeran": "vocalizzare",
    "vocalizzeranno": "vocalizzare",
    "vocalizzerebbe": "vocalizzare",
    "vocalizzerebber": "vocalizzare",
    "vocalizzerebbero": "vocalizzare",
    "vocalizzerei": "vocalizzare",
    "vocalizzeremmo": "vocalizzare",
    "vocalizzeremo": "vocalizzare",
    "vocalizzereste": "vocalizzare",
    "vocalizzeresti": "vocalizzare",
    "vocalizzerete": "vocalizzare",
    "vocalizzerà": "vocalizzare",
    "vocalizzerò": "vocalizzare",
    "vocalizzi": "vocalizzo",
    "vocalizziamo": "vocalizzare",
    "vocalizziate": "vocalizzare",
    "vocalizzin": "vocalizzare",
    "vocalizzino": "vocalizzare",
    "vocalizzo": "vocalizzare",
    "vocalizzò": "vocalizzare",
    "vocazioni": "vocazione",
    "vocerai": "vociare",
    "voceran": "vociare",
    "voceranno": "vociare",
    "vocerebbe": "vociare",
    "vocerebber": "vociare",
    "vocerebbero": "vociare",
    "vocerei": "vociare",
    "voceremmo": "vociare",
    "voceremo": "vociare",
    "vocereste": "vociare",
    "voceresti": "vociare",
    "vocerete": "vociare",
    "vocerà": "vociare",
    "vocerò": "vociare",
    "voci": "vociare",
    "vocia": "vociare",
    "vociai": "vociare",
    "vociammo": "vociare",
    "vociamo": "vociare",
    "vocian": "vociare",
    "vociando": "vociare",
    "vociano": "vociare",
    "vociante": "vociare",
    "vocianti": "vociare",
    "vociar": "vociare",
    "vociaron": "vociare",
    "vociarono": "vociare",
    "vociasse": "vociare",
    "vociasser": "vociare",
    "vociassero": "vociare",
    "vociassi": "vociare",
    "vociassimo": "vociare",
    "vociaste": "vociare",
    "vociasti": "vociare",
    "vociata": "vociare",
    "vociate": "vociare",
    "vociati": "vociare",
    "vociato": "vociare",
    "vociava": "vociare",
    "vociavamo": "vociare",
    "vociavan": "vociare",
    "vociavano": "vociare",
    "vociavate": "vociare",
    "vociavi": "vociare",
    "vociavo": "vociare",
    "vocifera": "vociferare",
    "vociferai": "vociferare",
    "vociferammo": "vociferare",
    "vociferan": "vociferare",
    "vociferando": "vociferare",
    "vociferano": "vociferare",
    "vociferante": "vociferare",
    "vociferanti": "vociferare",
    "vociferar": "vociferare",
    "vociferaron": "vociferare",
    "vociferarono": "vociferare",
    "vociferasse": "vociferare",
    "vociferasser": "vociferare",
    "vociferassero": "vociferare",
    "vociferassi": "vociferare",
    "vociferassimo": "vociferare",
    "vociferaste": "vociferare",
    "vociferasti": "vociferare",
    "vociferata": "vociferare",
    "vociferate": "vociferare",
    "vociferati": "vociferare",
    "vociferato": "vociferare",
    "vociferava": "vociferare",
    "vociferavamo": "vociferare",
    "vociferavan": "vociferare",
    "vociferavano": "vociferare",
    "vociferavate": "vociferare",
    "vociferavi": "vociferare",
    "vociferavo": "vociferare",
    "vociferazioni": "vociferazione",
    "vocifererai": "vociferare",
    "vocifereran": "vociferare",
    "vocifereranno": "vociferare",
    "vocifererebbe": "vociferare",
    "vocifererebber": "vociferare",
    "vocifererebbero": "vociferare",
    "vocifererei": "vociferare",
    "vocifereremmo": "vociferare",
    "vocifereremo": "vociferare",
    "vociferereste": "vociferare",
    "vocifereresti": "vociferare",
    "vocifererete": "vociferare",
    "vocifererà": "vociferare",
    "vocifererò": "vociferare",
    "vociferi": "vociferare",
    "vociferiamo": "vociferare",
    "vociferiate": "vociferare",
    "vociferin": "vociferare",
    "vociferino": "vociferare",
    "vocifero": "vociferare",
    "vociferò": "vociferare",
    "vocin": "vociare",
    "vocine": "vocina",
    "vocino": "vociare",
    "vocio": "vociare",
    "vocioni": "vocione",
    "vociò": "vociare",
    "vodke": "vodka",
    "voga": "vogare",
    "vogai": "vogare",
    "vogammo": "vogare",
    "vogan": "vogare",
    "vogando": "vogare",
    "vogano": "vogare",
    "vogante": "vogare",
    "voganti": "vogare",
    "vogar": "vogare",
    "vogaron": "vogare",
    "vogarono": "vogare",
    "vogasse": "vogare",
    "vogasser": "vogare",
    "vogassero": "vogare",
    "vogassi": "vogare",
    "vogassimo": "vogare",
    "vogaste": "vogare",
    "vogasti": "vogare",
    "vogata": "vogare",
    "vogate": "vogare",
    "vogati": "vogare",
    "vogato": "vogare",
    "vogatori": "vogatore",
    "vogava": "vogare",
    "vogavamo": "vogare",
    "vogavan": "vogare",
    "vogavano": "vogare",
    "vogavate": "vogare",
    "vogavi": "vogare",
    "vogavo": "vogare",
    "voghe": "voga",
    "vogherai": "vogare",
    "vogheran": "vogare",
    "vogheranno": "vogare",
    "vogherebbe": "vogare",
    "vogherebber": "vogare",
    "vogherebbero": "vogare",
    "vogherei": "vogare",
    "vogheremmo": "vogare",
    "vogheremo": "vogare",
    "vogheresi": "vogherese",
    "voghereste": "vogare",
    "vogheresti": "vogare",
    "vogherete": "vogare",
    "vogherà": "vogare",
    "vogherò": "vogare",
    "voghi": "vogare",
    "voghiamo": "vogare",
    "voghiate": "vogare",
    "voghin": "vogare",
    "voghino": "vogare",
    "voglia": "volere",
    "vogliamo": "volere",
    "voglian": "volere",
    "vogliano": "volere",
    "vogliate": "volere",
    "voglie": "voglia",
    "voglio": "volere",
    "voglion": "volere",
    "vogliono": "volere",
    "vogliosa": "voglioso",
    "vogliose": "voglioso",
    "vogliosi": "voglioso",
    "vogo": "vogare",
    "vogò": "vogare",
    "vola": "volare",
    "volai": "volare",
    "volammo": "volare",
    "volan": "volare",
    "volando": "volare",
    "volani": "volano",
    "volano": "volare",
    "volante": "volare",
    "volanti": "volare",
    "volantina": "volantinare",
    "volantinaggi": "volantinaggio",
    "volantinai": "volantinare",
    "volantinammo": "volantinare",
    "volantinan": "volantinare",
    "volantinando": "volantinare",
    "volantinano": "volantinare",
    "volantinante": "volantinare",
    "volantinanti": "volantinare",
    "volantinar": "volantinare",
    "volantinaron": "volantinare",
    "volantinarono": "volantinare",
    "volantinasse": "volantinare",
    "volantinasser": "volantinare",
    "volantinassero": "volantinare",
    "volantinassi": "volantinare",
    "volantinassimo": "volantinare",
    "volantinaste": "volantinare",
    "volantinasti": "volantinare",
    "volantinata": "volantinare",
    "volantinate": "volantinare",
    "volantinati": "volantinare",
    "volantinato": "volantinare",
    "volantinava": "volantinare",
    "volantinavamo": "volantinare",
    "volantinavan": "volantinare",
    "volantinavano": "volantinare",
    "volantinavate": "volantinare",
    "volantinavi": "volantinare",
    "volantinavo": "volantinare",
    "volantinerai": "volantinare",
    "volantineran": "volantinare",
    "volantineranno": "volantinare",
    "volantinerebbe": "volantinare",
    "volantinerebber": "volantinare",
    "volantinerebbero": "volantinare",
    "volantinerei": "volantinare",
    "volantineremmo": "volantinare",
    "volantineremo": "volantinare",
    "volantinereste": "volantinare",
    "volantineresti": "volantinare",
    "volantinerete": "volantinare",
    "volantinerà": "volantinare",
    "volantinerò": "volantinare",
    "volantini": "volantino",
    "volantiniamo": "volantinare",
    "volantiniate": "volantinare",
    "volantinin": "volantinare",
    "volantinino": "volantinare",
    "volantino": "volantinare",
    "volantinò": "volantinare",
    "volar": "volare",
    "volaron": "volare",
    "volarono": "volare",
    "volasse": "volare",
    "volasser": "volare",
    "volassero": "volare",
    "volassi": "volare",
    "volassimo": "volare",
    "volaste": "volare",
    "volasti": "volare",
    "volata": "volare",
    "volate": "volata",
    "volati": "volare",
    "volatili": "volatile",
    "volatilizza": "volatilizzare",
    "volatilizzai": "volatilizzare",
    "volatilizzammo": "volatilizzare",
    "volatilizzan": "volatilizzare",
    "volatilizzando": "volatilizzare",
    "volatilizzano": "volatilizzare",
    "volatilizzante": "volatilizzare",
    "volatilizzanti": "volatilizzare",
    "volatilizzar": "volatilizzare",
    "volatilizzaron": "volatilizzare",
    "volatilizzarono": "volatilizzare",
    "volatilizzasse": "volatilizzare",
    "volatilizzasser": "volatilizzare",
    "volatilizzassero": "volatilizzare",
    "volatilizzassi": "volatilizzare",
    "volatilizzassimo": "volatilizzare",
    "volatilizzaste": "volatilizzare",
    "volatilizzasti": "volatilizzare",
    "volatilizzata": "volatilizzare",
    "volatilizzate": "volatilizzare",
    "volatilizzati": "volatilizzare",
    "volatilizzato": "volatilizzare",
    "volatilizzava": "volatilizzare",
    "volatilizzavamo": "volatilizzare",
    "volatilizzavan": "volatilizzare",
    "volatilizzavano": "volatilizzare",
    "volatilizzavate": "volatilizzare",
    "volatilizzavi": "volatilizzare",
    "volatilizzavo": "volatilizzare",
    "volatilizzerai": "volatilizzare",
    "volatilizzeran": "volatilizzare",
    "volatilizzeranno": "volatilizzare",
    "volatilizzerebbe": "volatilizzare",
    "volatilizzerebber": "volatilizzare",
    "volatilizzerebbero": "volatilizzare",
    "volatilizzerei": "volatilizzare",
    "volatilizzeremmo": "volatilizzare",
    "volatilizzeremo": "volatilizzare",
    "volatilizzereste": "volatilizzare",
    "volatilizzeresti": "volatilizzare",
    "volatilizzerete": "volatilizzare",
    "volatilizzerà": "volatilizzare",
    "volatilizzerò": "volatilizzare",
    "volatilizzi": "volatilizzare",
    "volatilizziamo": "volatilizzare",
    "volatilizziate": "volatilizzare",
    "volatilizzin": "volatilizzare",
    "volatilizzino": "volatilizzare",
    "volatilizzo": "volatilizzare",
    "volatilizzò": "volatilizzare",
    "volato": "volare",
    "volava": "volare",
    "volavamo": "volare",
    "volavan": "volare",
    "volavano": "volare",
    "volavate": "volare",
    "volavi": "volare",
    "volavo": "volare",
    "volemmo": "volere",
    "volendo": "volere",
    "volente": "volere",
    "volenterosa": "volenteroso",
    "volenterose": "volenteroso",
    "volenterosi": "volenteroso",
    "volenti": "volere",
    "voler": "volere",
    "volerai": "volare",
    "voleran": "volare",
    "voleranno": "volare",
    "volerebbe": "volare",
    "volerebber": "volare",
    "volerebbero": "volare",
    "volerei": "volare",
    "voleremmo": "volare",
    "voleremo": "volare",
    "volereste": "volare",
    "voleresti": "volare",
    "volerete": "volare",
    "voleri": "volere",
    "volerà": "volare",
    "volerò": "volare",
    "volesse": "volere",
    "volesser": "volere",
    "volessero": "volere",
    "volessi": "volere",
    "volessimo": "volere",
    "voleste": "volere",
    "volesti": "volere",
    "volete": "volere",
    "voleva": "volere",
    "volevamo": "volere",
    "volevan": "volere",
    "volevano": "volere",
    "volevate": "volere",
    "volevi": "volere",
    "volevo": "volere",
    "volga": "volgere",
    "volgai": "volgare",
    "volgammo": "volgare",
    "volgan": "volgere",
    "volgando": "volgare",
    "volgano": "volgere",
    "volgante": "volgare",
    "volganti": "volgare",
    "volgar": "volgare",
    "volgari": "volgare",
    "volgarizza": "volgarizzare",
    "volgarizzai": "volgarizzare",
    "volgarizzammo": "volgarizzare",
    "volgarizzan": "volgarizzare",
    "volgarizzando": "volgarizzare",
    "volgarizzano": "volgarizzare",
    "volgarizzante": "volgarizzare",
    "volgarizzanti": "volgarizzare",
    "volgarizzar": "volgarizzare",
    "volgarizzaron": "volgarizzare",
    "volgarizzarono": "volgarizzare",
    "volgarizzasse": "volgarizzare",
    "volgarizzasser": "volgarizzare",
    "volgarizzassero": "volgarizzare",
    "volgarizzassi": "volgarizzare",
    "volgarizzassimo": "volgarizzare",
    "volgarizzaste": "volgarizzare",
    "volgarizzasti": "volgarizzare",
    "volgarizzata": "volgarizzare",
    "volgarizzate": "volgarizzare",
    "volgarizzati": "volgarizzare",
    "volgarizzato": "volgarizzare",
    "volgarizzava": "volgarizzare",
    "volgarizzavamo": "volgarizzare",
    "volgarizzavan": "volgarizzare",
    "volgarizzavano": "volgarizzare",
    "volgarizzavate": "volgarizzare",
    "volgarizzavi": "volgarizzare",
    "volgarizzavo": "volgarizzare",
    "volgarizzazioni": "volgarizzazione",
    "volgarizzerai": "volgarizzare",
    "volgarizzeran": "volgarizzare",
    "volgarizzeranno": "volgarizzare",
    "volgarizzerebbe": "volgarizzare",
    "volgarizzerebber": "volgarizzare",
    "volgarizzerebbero": "volgarizzare",
    "volgarizzerei": "volgarizzare",
    "volgarizzeremmo": "volgarizzare",
    "volgarizzeremo": "volgarizzare",
    "volgarizzereste": "volgarizzare",
    "volgarizzeresti": "volgarizzare",
    "volgarizzerete": "volgarizzare",
    "volgarizzerà": "volgarizzare",
    "volgarizzerò": "volgarizzare",
    "volgarizzi": "volgarizzare",
    "volgarizziamo": "volgarizzare",
    "volgarizziate": "volgarizzare",
    "volgarizzin": "volgarizzare",
    "volgarizzino": "volgarizzare",
    "volgarizzo": "volgarizzare",
    "volgarizzò": "volgarizzare",
    "volgaron": "volgare",
    "volgarono": "volgare",
    "volgasse": "volgare",
    "volgasser": "volgare",
    "volgassero": "volgare",
    "volgassi": "volgare",
    "volgassimo": "volgare",
    "volgaste": "volgare",
    "volgasti": "volgare",
    "volgata": "volgare",
    "volgate": "volgare",
    "volgati": "volgare",
    "volgato": "volgare",
    "volgava": "volgare",
    "volgavamo": "volgare",
    "volgavan": "volgare",
    "volgavano": "volgare",
    "volgavate": "volgare",
    "volgavi": "volgare",
    "volgavo": "volgare",
    "volge": "volgere",
    "volgemmo": "volgere",
    "volgendo": "volgere",
    "volgente": "volgere",
    "volgenti": "volgere",
    "volger": "volgere",
    "volgerai": "volgere",
    "volgeran": "volgere",
    "volgeranno": "volgere",
    "volgerebbe": "volgere",
    "volgerebber": "volgere",
    "volgerebbero": "volgere",
    "volgerei": "volgere",
    "volgeremmo": "volgere",
    "volgeremo": "volgere",
    "volgereste": "volgere",
    "volgeresti": "volgere",
    "volgerete": "volgere",
    "volgerà": "volgere",
    "volgerò": "volgere",
    "volgesse": "volgere",
    "volgesser": "volgere",
    "volgessero": "volgere",
    "volgessi": "volgere",
    "volgessimo": "volgere",
    "volgeste": "volgere",
    "volgesti": "volgere",
    "volgete": "volgere",
    "volgeva": "volgere",
    "volgevamo": "volgere",
    "volgevan": "volgere",
    "volgevano": "volgere",
    "volgevate": "volgere",
    "volgevi": "volgere",
    "volgevo": "volgere",
    "volgherai": "volgare",
    "volgheran": "volgare",
    "volgheranno": "volgare",
    "volgherebbe": "volgare",
    "volgherebber": "volgare",
    "volgherebbero": "volgare",
    "volgherei": "volgare",
    "volgheremmo": "volgare",
    "volgheremo": "volgare",
    "volghereste": "volgare",
    "volgheresti": "volgare",
    "volgherete": "volgare",
    "volgherà": "volgare",
    "volgherò": "volgare",
    "volghi": "volgo",
    "volghiamo": "volgare",
    "volghiate": "volgare",
    "volghin": "volgare",
    "volghino": "volgare",
    "volgi": "volgere",
    "volgiamo": "volgere",
    "volgiate": "volgere",
    "volgo": "volgere",
    "volgon": "volgere",
    "volgono": "volgere",
    "volgò": "volgare",
    "voli": "volo",
    "voliamo": "volare",
    "voliate": "volare",
    "voliere": "voliera",
    "volin": "volare",
    "volino": "volare",
    "volitiva": "volitivo",
    "volitive": "volitivo",
    "volitivi": "volitivo",
    "volle": "volere",
    "voller": "volere",
    "vollero": "volere",
    "volli": "volere",
    "volo": "volare",
    "volontari": "volontario",
    "volontaria": "volontario",
    "volontariati": "volontariato",
    "volontarie": "volontario",
    "volontarismi": "volontarismo",
    "volontaristica": "volontaristico",
    "volontaristiche": "volontaristico",
    "volontaristici": "volontaristico",
    "volonterosa": "volonteroso",
    "volonterose": "volonteroso",
    "volonterosi": "volonteroso",
    "volpi": "volpe",
    "volpina": "volpino",
    "volpine": "volpino",
    "volpini": "volpino",
    "volponi": "volpone",
    "volponiana": "volponiano",
    "volponiane": "volponiano",
    "volponiani": "volponiano",
    "volse": "volgere",
    "volser": "volgere",
    "volsero": "volgere",
    "volsi": "volgere",
    "volta": "volto",
    "voltai": "voltare",
    "voltairiana": "voltairiano",
    "voltairiane": "voltairiano",
    "voltairiani": "voltairiano",
    "voltammo": "voltare",
    "voltan": "voltare",
    "voltando": "voltare",
    "voltano": "voltare",
    "voltante": "voltare",
    "voltanti": "voltare",
    "voltar": "voltare",
    "voltaron": "voltare",
    "voltarono": "voltare",
    "voltasse": "voltare",
    "voltasser": "voltare",
    "voltassero": "voltare",
    "voltassi": "voltare",
    "voltassimo": "voltare",
    "voltaste": "voltare",
    "voltasti": "voltare",
    "voltata": "voltare",
    "voltate": "voltare",
    "voltati": "voltare",
    "voltato": "voltare",
    "voltava": "voltare",
    "voltavamo": "voltare",
    "voltavan": "voltare",
    "voltavano": "voltare",
    "voltavate": "voltare",
    "voltavi": "voltare",
    "voltavo": "voltare",
    "volte": "volto",
    "volteggerai": "volteggiare",
    "volteggeran": "volteggiare",
    "volteggeranno": "volteggiare",
    "volteggerebbe": "volteggiare",
    "volteggerebber": "volteggiare",
    "volteggerebbero": "volteggiare",
    "volteggerei": "volteggiare",
    "volteggeremmo": "volteggiare",
    "volteggeremo": "volteggiare",
    "volteggereste": "volteggiare",
    "volteggeresti": "volteggiare",
    "volteggerete": "volteggiare",
    "volteggerà": "volteggiare",
    "volteggerò": "volteggiare",
    "volteggi": "volteggio",
    "volteggia": "volteggiare",
    "volteggiai": "volteggiare",
    "volteggiammo": "volteggiare",
    "volteggiamo": "volteggiare",
    "volteggian": "volteggiare",
    "volteggiando": "volteggiare",
    "volteggiano": "volteggiare",
    "volteggiante": "volteggiare",
    "volteggianti": "volteggiare",
    "volteggiar": "volteggiare",
    "volteggiaron": "volteggiare",
    "volteggiarono": "volteggiare",
    "volteggiasse": "volteggiare",
    "volteggiasser": "volteggiare",
    "volteggiassero": "volteggiare",
    "volteggiassi": "volteggiare",
    "volteggiassimo": "volteggiare",
    "volteggiaste": "volteggiare",
    "volteggiasti": "volteggiare",
    "volteggiata": "volteggiare",
    "volteggiate": "volteggiare",
    "volteggiati": "volteggiare",
    "volteggiato": "volteggiare",
    "volteggiava": "volteggiare",
    "volteggiavamo": "volteggiare",
    "volteggiavan": "volteggiare",
    "volteggiavano": "volteggiare",
    "volteggiavate": "volteggiare",
    "volteggiavi": "volteggiare",
    "volteggiavo": "volteggiare",
    "volteggin": "volteggiare",
    "volteggino": "volteggiare",
    "volteggio": "volteggiare",
    "volteggiò": "volteggiare",
    "volterai": "voltare",
    "volteran": "voltare",
    "volteranno": "voltare",
    "volterebbe": "voltare",
    "volterebber": "voltare",
    "volterebbero": "voltare",
    "volterei": "voltare",
    "volteremmo": "voltare",
    "volteremo": "voltare",
    "voltereste": "voltare",
    "volteresti": "voltare",
    "volterete": "voltare",
    "volterà": "voltare",
    "volterò": "voltare",
    "volti": "volto",
    "voltiamo": "voltare",
    "voltiate": "voltare",
    "voltin": "voltare",
    "voltino": "voltare",
    "volto": "voltare",
    "voltola": "voltolare",
    "voltolai": "voltolare",
    "voltolammo": "voltolare",
    "voltolan": "voltolare",
    "voltolando": "voltolare",
    "voltolano": "voltolare",
    "voltolante": "voltolare",
    "voltolanti": "voltolare",
    "voltolar": "voltolare",
    "voltolaron": "voltolare",
    "voltolarono": "voltolare",
    "voltolasse": "voltolare",
    "voltolasser": "voltolare",
    "voltolassero": "voltolare",
    "voltolassi": "voltolare",
    "voltolassimo": "voltolare",
    "voltolaste": "voltolare",
    "voltolasti": "voltolare",
    "voltolata": "voltolare",
    "voltolate": "voltolare",
    "voltolati": "voltolare",
    "voltolato": "voltolare",
    "voltolava": "voltolare",
    "voltolavamo": "voltolare",
    "voltolavan": "voltolare",
    "voltolavano": "voltolare",
    "voltolavate": "voltolare",
    "voltolavi": "voltolare",
    "voltolavo": "voltolare",
    "voltolerai": "voltolare",
    "voltoleran": "voltolare",
    "voltoleranno": "voltolare",
    "voltolerebbe": "voltolare",
    "voltolerebber": "voltolare",
    "voltolerebbero": "voltolare",
    "voltolerei": "voltolare",
    "voltoleremmo": "voltolare",
    "voltoleremo": "voltolare",
    "voltolereste": "voltolare",
    "voltoleresti": "voltolare",
    "voltolerete": "voltolare",
    "voltolerà": "voltolare",
    "voltolerò": "voltolare",
    "voltoli": "voltolare",
    "voltoliamo": "voltolare",
    "voltoliate": "voltolare",
    "voltolin": "voltolare",
    "voltolino": "voltolare",
    "voltolo": "voltolare",
    "voltolò": "voltolare",
    "voltura": "volturare",
    "volturai": "volturare",
    "volturammo": "volturare",
    "volturan": "volturare",
    "volturando": "volturare",
    "volturano": "volturare",
    "volturante": "volturare",
    "volturanti": "volturare",
    "volturar": "volturare",
    "volturaron": "volturare",
    "volturarono": "volturare",
    "volturasse": "volturare",
    "volturasser": "volturare",
    "volturassero": "volturare",
    "volturassi": "volturare",
    "volturassimo": "volturare",
    "volturaste": "volturare",
    "volturasti": "volturare",
    "volturata": "volturare",
    "volturate": "volturare",
    "volturati": "volturare",
    "volturato": "volturare",
    "volturava": "volturare",
    "volturavamo": "volturare",
    "volturavan": "volturare",
    "volturavano": "volturare",
    "volturavate": "volturare",
    "volturavi": "volturare",
    "volturavo": "volturare",
    "volture": "voltura",
    "volturerai": "volturare",
    "voltureran": "volturare",
    "voltureranno": "volturare",
    "volturerebbe": "volturare",
    "volturerebber": "volturare",
    "volturerebbero": "volturare",
    "volturerei": "volturare",
    "voltureremmo": "volturare",
    "voltureremo": "volturare",
    "volturereste": "volturare",
    "voltureresti": "volturare",
    "volturerete": "volturare",
    "volturerà": "volturare",
    "volturerò": "volturare",
    "volturi": "volturare",
    "volturiamo": "volturare",
    "volturiate": "volturare",
    "volturin": "volturare",
    "volturino": "volturare",
    "volturo": "volturare",
    "volturò": "volturare",
    "voltò": "voltare",
    "volubili": "volubile",
    "volumetrica": "volumetrico",
    "volumetriche": "volumetrico",
    "volumetrici": "volumetrico",
    "volumetrie": "volumetria",
    "volumetti": "volumetto",
    "volumi": "volume",
    "voluminosa": "voluminoso",
    "voluminose": "voluminoso",
    "voluminosi": "voluminoso",
    "volumoni": "volumone",
    "voluta": "voluto",
    "volute": "voluto",
    "voluti": "voluto",
    "voluto": "volere",
    "voluttuari": "voluttuario",
    "voluttuaria": "voluttuario",
    "voluttuarie": "voluttuario",
    "voluttuosa": "voluttuoso",
    "voluttuose": "voluttuoso",
    "voluttuosi": "voluttuoso",
    "volées": "volée",
    "volò": "volare",
    "voma": "vomere",
    "voman": "vomere",
    "vomano": "vomere",
    "vome": "vomere",
    "vomei": "vomere",
    "vomemmo": "vomere",
    "vomendo": "vomere",
    "vomente": "vomere",
    "vomenti": "vomere",
    "vomer": "vomere",
    "vomerai": "vomere",
    "vomeran": "vomere",
    "vomeranno": "vomere",
    "vomerebbe": "vomere",
    "vomerebber": "vomere",
    "vomerebbero": "vomere",
    "vomerei": "vomere",
    "vomeremmo": "vomere",
    "vomeremo": "vomere",
    "vomereste": "vomere",
    "vomeresti": "vomere",
    "vomerete": "vomere",
    "vomeron": "vomere",
    "vomerono": "vomere",
    "vomerà": "vomere",
    "vomerò": "vomere",
    "vomesse": "vomere",
    "vomesser": "vomere",
    "vomessero": "vomere",
    "vomessi": "vomere",
    "vomessimo": "vomere",
    "vomeste": "vomere",
    "vomesti": "vomere",
    "vomete": "vomere",
    "vomeva": "vomere",
    "vomevamo": "vomere",
    "vomevan": "vomere",
    "vomevano": "vomere",
    "vomevate": "vomere",
    "vomevi": "vomere",
    "vomevo": "vomere",
    "vomi": "vomere",
    "vomiamo": "vomere",
    "vomiate": "vomere",
    "vomita": "vomitare",
    "vomitai": "vomitare",
    "vomitammo": "vomitare",
    "vomitan": "vomitare",
    "vomitando": "vomitare",
    "vomitano": "vomitare",
    "vomitante": "vomitare",
    "vomitanti": "vomitare",
    "vomitar": "vomitare",
    "vomitaron": "vomitare",
    "vomitarono": "vomitare",
    "vomitasse": "vomitare",
    "vomitasser": "vomitare",
    "vomitassero": "vomitare",
    "vomitassi": "vomitare",
    "vomitassimo": "vomitare",
    "vomitaste": "vomitare",
    "vomitasti": "vomitare",
    "vomitata": "vomitare",
    "vomitate": "vomitare",
    "vomitati": "vomitare",
    "vomitato": "vomitare",
    "vomitava": "vomitare",
    "vomitavamo": "vomitare",
    "vomitavan": "vomitare",
    "vomitavano": "vomitare",
    "vomitavate": "vomitare",
    "vomitavi": "vomitare",
    "vomitavo": "vomitare",
    "vomiterai": "vomitare",
    "vomiteran": "vomitare",
    "vomiteranno": "vomitare",
    "vomiterebbe": "vomitare",
    "vomiterebber": "vomitare",
    "vomiterebbero": "vomitare",
    "vomiterei": "vomitare",
    "vomiteremmo": "vomitare",
    "vomiteremo": "vomitare",
    "vomitereste": "vomitare",
    "vomiteresti": "vomitare",
    "vomiterete": "vomitare",
    "vomiterà": "vomitare",
    "vomiterò": "vomitare",
    "vomitevoli": "vomitevole",
    "vomiti": "vomito",
    "vomitiamo": "vomitare",
    "vomitiate": "vomitare",
    "vomitin": "vomitare",
    "vomitino": "vomitare",
    "vomito": "vomitare",
    "vomitò": "vomitare",
    "vomo": "vomere",
    "vomon": "vomere",
    "vomono": "vomere",
    "vomuta": "vomere",
    "vomute": "vomere",
    "vomuti": "vomere",
    "vomuto": "vomere",
    "vomè": "vomere",
    "vongole": "vongola",
    "voraci": "vorace",
    "voragini": "voragine",
    "voraginosa": "voraginoso",
    "voraginose": "voraginoso",
    "voraginosi": "voraginoso",
    "vorrai": "volere",
    "vorran": "volere",
    "vorranno": "volere",
    "vorrebbe": "volere",
    "vorrebber": "volere",
    "vorrebbero": "volere",
    "vorrei": "volere",
    "vorremmo": "volere",
    "vorremo": "volere",
    "vorreste": "volere",
    "vorresti": "volere",
    "vorrete": "volere",
    "vorrà": "volere",
    "vorrò": "volere",
    "vortica": "vorticare",
    "vorticai": "vorticare",
    "vorticammo": "vorticare",
    "vortican": "vorticare",
    "vorticando": "vorticare",
    "vorticano": "vorticare",
    "vorticante": "vorticare",
    "vorticanti": "vorticare",
    "vorticar": "vorticare",
    "vorticaron": "vorticare",
    "vorticarono": "vorticare",
    "vorticasse": "vorticare",
    "vorticasser": "vorticare",
    "vorticassero": "vorticare",
    "vorticassi": "vorticare",
    "vorticassimo": "vorticare",
    "vorticaste": "vorticare",
    "vorticasti": "vorticare",
    "vorticata": "vorticare",
    "vorticate": "vorticare",
    "vorticati": "vorticare",
    "vorticato": "vorticare",
    "vorticava": "vorticare",
    "vorticavamo": "vorticare",
    "vorticavan": "vorticare",
    "vorticavano": "vorticare",
    "vorticavate": "vorticare",
    "vorticavi": "vorticare",
    "vorticavo": "vorticare",
    "vorticherai": "vorticare",
    "vorticheran": "vorticare",
    "vorticheranno": "vorticare",
    "vorticherebbe": "vorticare",
    "vorticherebber": "vorticare",
    "vorticherebbero": "vorticare",
    "vorticherei": "vorticare",
    "vorticheremmo": "vorticare",
    "vorticheremo": "vorticare",
    "vortichereste": "vorticare",
    "vorticheresti": "vorticare",
    "vorticherete": "vorticare",
    "vorticherà": "vorticare",
    "vorticherò": "vorticare",
    "vortichi": "vorticare",
    "vortichiamo": "vorticare",
    "vortichiate": "vorticare",
    "vortichin": "vorticare",
    "vortichino": "vorticare",
    "vortici": "vortice",
    "vortico": "vorticare",
    "vorticosa": "vorticoso",
    "vorticose": "vorticoso",
    "vorticosi": "vorticoso",
    "vorticò": "vorticare",
    "vostra": "vostro",
    "vostre": "vostro",
    "vostri": "vostro",
    "vota": "votare",
    "votai": "votare",
    "votammo": "votare",
    "votan": "votare",
    "votando": "votare",
    "votano": "votare",
    "votante": "votare",
    "votanti": "votare",
    "votar": "votare",
    "votaron": "votare",
    "votarono": "votare",
    "votasse": "votare",
    "votasser": "votare",
    "votassero": "votare",
    "votassi": "votare",
    "votassimo": "votare",
    "votaste": "votare",
    "votasti": "votare",
    "votata": "votato",
    "votate": "votato",
    "votati": "votato",
    "votato": "votare",
    "votava": "votare",
    "votavamo": "votare",
    "votavan": "votare",
    "votavano": "votare",
    "votavate": "votare",
    "votavi": "votare",
    "votavo": "votare",
    "votazioni": "votazione",
    "voterai": "votare",
    "voteran": "votare",
    "voteranno": "votare",
    "voterebbe": "votare",
    "voterebber": "votare",
    "voterebbero": "votare",
    "voterei": "votare",
    "voteremmo": "votare",
    "voteremo": "votare",
    "votereste": "votare",
    "voteresti": "votare",
    "voterete": "votare",
    "voterà": "votare",
    "voterò": "votare",
    "voti": "voto",
    "votiamo": "votare",
    "votiate": "votare",
    "votin": "votare",
    "votino": "votare",
    "votiva": "votivo",
    "votive": "votivo",
    "votivi": "votivo",
    "voto": "votare",
    "votò": "votare",
    "voyeristica": "voyeristico",
    "voyeristiche": "voyeristico",
    "voyeristici": "voyeristico",
    "voyeurismi": "voyeurismo",
    "vulcani": "vulcano",
    "vulcanica": "vulcanico",
    "vulcaniche": "vulcanico",
    "vulcanici": "vulcanico",
    "vulcanizza": "vulcanizzare",
    "vulcanizzai": "vulcanizzare",
    "vulcanizzammo": "vulcanizzare",
    "vulcanizzan": "vulcanizzare",
    "vulcanizzando": "vulcanizzare",
    "vulcanizzano": "vulcanizzare",
    "vulcanizzante": "vulcanizzare",
    "vulcanizzanti": "vulcanizzare",
    "vulcanizzar": "vulcanizzare",
    "vulcanizzaron": "vulcanizzare",
    "vulcanizzarono": "vulcanizzare",
    "vulcanizzasse": "vulcanizzare",
    "vulcanizzasser": "vulcanizzare",
    "vulcanizzassero": "vulcanizzare",
    "vulcanizzassi": "vulcanizzare",
    "vulcanizzassimo": "vulcanizzare",
    "vulcanizzaste": "vulcanizzare",
    "vulcanizzasti": "vulcanizzare",
    "vulcanizzata": "vulcanizzare",
    "vulcanizzate": "vulcanizzare",
    "vulcanizzati": "vulcanizzare",
    "vulcanizzato": "vulcanizzare",
    "vulcanizzava": "vulcanizzare",
    "vulcanizzavamo": "vulcanizzare",
    "vulcanizzavan": "vulcanizzare",
    "vulcanizzavano": "vulcanizzare",
    "vulcanizzavate": "vulcanizzare",
    "vulcanizzavi": "vulcanizzare",
    "vulcanizzavo": "vulcanizzare",
    "vulcanizzerai": "vulcanizzare",
    "vulcanizzeran": "vulcanizzare",
    "vulcanizzeranno": "vulcanizzare",
    "vulcanizzerebbe": "vulcanizzare",
    "vulcanizzerebber": "vulcanizzare",
    "vulcanizzerebbero": "vulcanizzare",
    "vulcanizzerei": "vulcanizzare",
    "vulcanizzeremmo": "vulcanizzare",
    "vulcanizzeremo": "vulcanizzare",
    "vulcanizzereste": "vulcanizzare",
    "vulcanizzeresti": "vulcanizzare",
    "vulcanizzerete": "vulcanizzare",
    "vulcanizzerà": "vulcanizzare",
    "vulcanizzerò": "vulcanizzare",
    "vulcanizzi": "vulcanizzare",
    "vulcanizziamo": "vulcanizzare",
    "vulcanizziate": "vulcanizzare",
    "vulcanizzin": "vulcanizzare",
    "vulcanizzino": "vulcanizzare",
    "vulcanizzo": "vulcanizzare",
    "vulcanizzò": "vulcanizzare",
    "vulcanologi": "vulcanologo",
    "vulgate": "vulgata",
    "vulnera": "vulnus",
    "vulnerabili": "vulnerabile",
    "vulnerai": "vulnerare",
    "vulnerammo": "vulnerare",
    "vulneran": "vulnerare",
    "vulnerando": "vulnerare",
    "vulnerano": "vulnerare",
    "vulnerante": "vulnerare",
    "vulneranti": "vulnerare",
    "vulnerar": "vulnerare",
    "vulneraron": "vulnerare",
    "vulnerarono": "vulnerare",
    "vulnerasse": "vulnerare",
    "vulnerasser": "vulnerare",
    "vulnerassero": "vulnerare",
    "vulnerassi": "vulnerare",
    "vulnerassimo": "vulnerare",
    "vulneraste": "vulnerare",
    "vulnerasti": "vulnerare",
    "vulnerata": "vulnerare",
    "vulnerate": "vulnerare",
    "vulnerati": "vulnerare",
    "vulnerato": "vulnerare",
    "vulnerava": "vulnerare",
    "vulneravamo": "vulnerare",
    "vulneravan": "vulnerare",
    "vulneravano": "vulnerare",
    "vulneravate": "vulnerare",
    "vulneravi": "vulnerare",
    "vulneravo": "vulnerare",
    "vulnererai": "vulnerare",
    "vulnereran": "vulnerare",
    "vulnereranno": "vulnerare",
    "vulnererebbe": "vulnerare",
    "vulnererebber": "vulnerare",
    "vulnererebbero": "vulnerare",
    "vulnererei": "vulnerare",
    "vulnereremmo": "vulnerare",
    "vulnereremo": "vulnerare",
    "vulnerereste": "vulnerare",
    "vulnereresti": "vulnerare",
    "vulnererete": "vulnerare",
    "vulnererà": "vulnerare",
    "vulnererò": "vulnerare",
    "vulneri": "vulnerare",
    "vulneriamo": "vulnerare",
    "vulneriate": "vulnerare",
    "vulnerin": "vulnerare",
    "vulnerino": "vulnerare",
    "vulnero": "vulnerare",
    "vulnerò": "vulnerare",
    "vuoi": "volere",
    "vuole": "volere",
    "vuota": "vuoto",
    "vuotai": "vuotare",
    "vuotammo": "vuotare",
    "vuotan": "vuotare",
    "vuotando": "vuotare",
    "vuotano": "vuotare",
    "vuotante": "vuotare",
    "vuotanti": "vuotare",
    "vuotar": "vuotare",
    "vuotaron": "vuotare",
    "vuotarono": "vuotare",
    "vuotasse": "vuotare",
    "vuotasser": "vuotare",
    "vuotassero": "vuotare",
    "vuotassi": "vuotare",
    "vuotassimo": "vuotare",
    "vuotaste": "vuotare",
    "vuotasti": "vuotare",
    "vuotata": "vuotare",
    "vuotate": "vuotare",
    "vuotati": "vuotare",
    "vuotato": "vuotare",
    "vuotava": "vuotare",
    "vuotavamo": "vuotare",
    "vuotavan": "vuotare",
    "vuotavano": "vuotare",
    "vuotavate": "vuotare",
    "vuotavi": "vuotare",
    "vuotavo": "vuotare",
    "vuote": "vuoto",
    "vuoterai": "vuotare",
    "vuoteran": "vuotare",
    "vuoteranno": "vuotare",
    "vuoterebbe": "vuotare",
    "vuoterebber": "vuotare",
    "vuoterebbero": "vuotare",
    "vuoterei": "vuotare",
    "vuoteremmo": "vuotare",
    "vuoteremo": "vuotare",
    "vuotereste": "vuotare",
    "vuoteresti": "vuotare",
    "vuoterete": "vuotare",
    "vuoterà": "vuotare",
    "vuoterò": "vuotare",
    "vuoti": "vuoto",
    "vuotiamo": "vuotare",
    "vuotiate": "vuotare",
    "vuotin": "vuotare",
    "vuotino": "vuotare",
    "vuoto": "vuotare",
    "vuotò": "vuotare",
    "walseriana": "walseriano",
    "walseriane": "walseriano",
    "walseriani": "walseriano",
    "washingtoniana": "washingtoniano",
    "washingtoniane": "washingtoniano",
    "washingtoniani": "washingtoniano",
    "watussi": "watusso",
    "weberiana": "weberiano",
    "weberiane": "weberiano",
    "weberiani": "weberiano",
    "wellesiana": "wellesiano",
    "wellesiane": "wellesiano",
    "wellesiani": "wellesiano",
    "wendersiana": "wendersiano",
    "wendersiane": "wendersiano",
    "wendersiani": "wendersiano",
    "wertheriana": "wertheriano",
    "wertheriane": "wertheriano",
    "wertheriani": "wertheriano",
    "westinghouses": "westinghouse",
    "whitmaniana": "whitmaniano",
    "whitmaniane": "whitmaniano",
    "whitmaniani": "whitmaniano",
    "wojtyliana": "wojtyliano",
    "wojtyliane": "wojtyliano",
    "wojtyliani": "wojtyliano",
    "xenofoba": "xenofobo",
    "xenofobe": "xenofobo",
    "xenofobi": "xenofobo",
    "xenofobie": "xenofobia",
    "xenotrapianti": "xenotrapianto",
    "xilografie": "xilografia",
    "yankees": "yankee",
    "yemenita": "yemenito",
    "yemenite": "yemenito",
    "yemeniti": "yemenito",
    "yoga": "yogo",
    "yoghe": "yogo",
    "yoghi": "yogo",
    "yuppies": "yuppy",
    "yuppismi": "yuppismo",
    "yurte": "yurta",
    "zaccagniniana": "zaccagniniano",
    "zaccagniniane": "zaccagniniano",
    "zaccagniniani": "zaccagniniano",
    "zadanoviana": "zadanoviano",
    "zadanoviane": "zadanoviano",
    "zadanoviani": "zadanoviano",
    "zaffa": "zaffare",
    "zaffai": "zaffare",
    "zaffammo": "zaffare",
    "zaffan": "zaffare",
    "zaffando": "zaffare",
    "zaffano": "zaffare",
    "zaffante": "zaffare",
    "zaffanti": "zaffare",
    "zaffar": "zaffare",
    "zaffaron": "zaffare",
    "zaffarono": "zaffare",
    "zaffasse": "zaffare",
    "zaffasser": "zaffare",
    "zaffassero": "zaffare",
    "zaffassi": "zaffare",
    "zaffassimo": "zaffare",
    "zaffaste": "zaffare",
    "zaffasti": "zaffare",
    "zaffata": "zaffare",
    "zaffate": "zaffata",
    "zaffati": "zaffare",
    "zaffato": "zaffare",
    "zaffava": "zaffare",
    "zaffavamo": "zaffare",
    "zaffavan": "zaffare",
    "zaffavano": "zaffare",
    "zaffavate": "zaffare",
    "zaffavi": "zaffare",
    "zaffavo": "zaffare",
    "zafferai": "zaffare",
    "zafferan": "zaffare",
    "zafferanno": "zaffare",
    "zafferebbe": "zaffare",
    "zafferebber": "zaffare",
    "zafferebbero": "zaffare",
    "zafferei": "zaffare",
    "zafferemmo": "zaffare",
    "zafferemo": "zaffare",
    "zaffereste": "zaffare",
    "zafferesti": "zaffare",
    "zafferete": "zaffare",
    "zafferà": "zaffare",
    "zafferò": "zaffare",
    "zaffi": "zaffare",
    "zaffiamo": "zaffare",
    "zaffiate": "zaffare",
    "zaffin": "zaffare",
    "zaffino": "zaffare",
    "zaffiri": "zaffiro",
    "zaffo": "zaffare",
    "zaffò": "zaffare",
    "zainetti": "zainetto",
    "zaini": "zaino",
    "zairesi": "zairese",
    "zambiana": "zambiano",
    "zambiane": "zambiano",
    "zambiani": "zambiano",
    "zampa": "zampare",
    "zampai": "zampare",
    "zampammo": "zampare",
    "zampan": "zampare",
    "zampando": "zampare",
    "zampano": "zampare",
    "zampante": "zampare",
    "zampanti": "zampare",
    "zampar": "zampare",
    "zamparon": "zampare",
    "zamparono": "zampare",
    "zampasse": "zampare",
    "zampasser": "zampare",
    "zampassero": "zampare",
    "zampassi": "zampare",
    "zampassimo": "zampare",
    "zampaste": "zampare",
    "zampasti": "zampare",
    "zampata": "zampare",
    "zampate": "zampata",
    "zampati": "zampare",
    "zampato": "zampare",
    "zampava": "zampare",
    "zampavamo": "zampare",
    "zampavan": "zampare",
    "zampavano": "zampare",
    "zampavate": "zampare",
    "zampavi": "zampare",
    "zampavo": "zampare",
    "zampe": "zampa",
    "zamperai": "zampare",
    "zamperan": "zampare",
    "zamperanno": "zampare",
    "zamperebbe": "zampare",
    "zamperebber": "zampare",
    "zamperebbero": "zampare",
    "zamperei": "zampare",
    "zamperemmo": "zampare",
    "zamperemo": "zampare",
    "zampereste": "zampare",
    "zamperesti": "zampare",
    "zamperete": "zampare",
    "zamperà": "zampare",
    "zamperò": "zampare",
    "zampetta": "zampettare",
    "zampettai": "zampettare",
    "zampettammo": "zampettare",
    "zampettan": "zampettare",
    "zampettando": "zampettare",
    "zampettano": "zampettare",
    "zampettante": "zampettare",
    "zampettanti": "zampettare",
    "zampettar": "zampettare",
    "zampettaron": "zampettare",
    "zampettarono": "zampettare",
    "zampettasse": "zampettare",
    "zampettasser": "zampettare",
    "zampettassero": "zampettare",
    "zampettassi": "zampettare",
    "zampettassimo": "zampettare",
    "zampettaste": "zampettare",
    "zampettasti": "zampettare",
    "zampettata": "zampettare",
    "zampettate": "zampettare",
    "zampettati": "zampettare",
    "zampettato": "zampettare",
    "zampettava": "zampettare",
    "zampettavamo": "zampettare",
    "zampettavan": "zampettare",
    "zampettavano": "zampettare",
    "zampettavate": "zampettare",
    "zampettavi": "zampettare",
    "zampettavo": "zampettare",
    "zampetterai": "zampettare",
    "zampetteran": "zampettare",
    "zampetteranno": "zampettare",
    "zampetterebbe": "zampettare",
    "zampetterebber": "zampettare",
    "zampetterebbero": "zampettare",
    "zampetterei": "zampettare",
    "zampetteremmo": "zampettare",
    "zampetteremo": "zampettare",
    "zampettereste": "zampettare",
    "zampetteresti": "zampettare",
    "zampetterete": "zampettare",
    "zampetterà": "zampettare",
    "zampetterò": "zampettare",
    "zampetti": "zampettare",
    "zampettiamo": "zampettare",
    "zampettiate": "zampettare",
    "zampettin": "zampettare",
    "zampettino": "zampettare",
    "zampetto": "zampettare",
    "zampettò": "zampettare",
    "zampi": "zampare",
    "zampiamo": "zampare",
    "zampiate": "zampare",
    "zampilla": "zampillare",
    "zampillai": "zampillare",
    "zampillammo": "zampillare",
    "zampillan": "zampillare",
    "zampillando": "zampillare",
    "zampillano": "zampillare",
    "zampillante": "zampillare",
    "zampillanti": "zampillare",
    "zampillar": "zampillare",
    "zampillaron": "zampillare",
    "zampillarono": "zampillare",
    "zampillasse": "zampillare",
    "zampillasser": "zampillare",
    "zampillassero": "zampillare",
    "zampillassi": "zampillare",
    "zampillassimo": "zampillare",
    "zampillaste": "zampillare",
    "zampillasti": "zampillare",
    "zampillata": "zampillare",
    "zampillate": "zampillare",
    "zampillati": "zampillare",
    "zampillato": "zampillare",
    "zampillava": "zampillare",
    "zampillavamo": "zampillare",
    "zampillavan": "zampillare",
    "zampillavano": "zampillare",
    "zampillavate": "zampillare",
    "zampillavi": "zampillare",
    "zampillavo": "zampillare",
    "zampillerai": "zampillare",
    "zampilleran": "zampillare",
    "zampilleranno": "zampillare",
    "zampillerebbe": "zampillare",
    "zampillerebber": "zampillare",
    "zampillerebbero": "zampillare",
    "zampillerei": "zampillare",
    "zampilleremmo": "zampillare",
    "zampilleremo": "zampillare",
    "zampillereste": "zampillare",
    "zampilleresti": "zampillare",
    "zampillerete": "zampillare",
    "zampillerà": "zampillare",
    "zampillerò": "zampillare",
    "zampilli": "zampillo",
    "zampilliamo": "zampillare",
    "zampilliate": "zampillare",
    "zampillin": "zampillare",
    "zampillino": "zampillare",
    "zampillo": "zampillare",
    "zampillò": "zampillare",
    "zampin": "zampare",
    "zampini": "zampino",
    "zampino": "zampare",
    "zampo": "zampare",
    "zampò": "zampare",
    "zanardelliana": "zanardelliano",
    "zanardelliane": "zanardelliano",
    "zanardelliani": "zanardelliano",
    "zangheriana": "zangheriano",
    "zangheriane": "zangheriano",
    "zangheriani": "zangheriano",
    "zanne": "zanna",
    "zanzare": "zanzara",
    "zapatisti": "zapatista",
    "zappa": "zappare",
    "zappai": "zappare",
    "zappammo": "zappare",
    "zappan": "zappare",
    "zappando": "zappare",
    "zappano": "zappare",
    "zappante": "zappare",
    "zappanti": "zappare",
    "zappar": "zappare",
    "zapparon": "zappare",
    "zapparono": "zappare",
    "zappasse": "zappare",
    "zappasser": "zappare",
    "zappassero": "zappare",
    "zappassi": "zappare",
    "zappassimo": "zappare",
    "zappaste": "zappare",
    "zappasti": "zappare",
    "zappata": "zappare",
    "zappate": "zappare",
    "zappati": "zappare",
    "zappato": "zappare",
    "zappava": "zappare",
    "zappavamo": "zappare",
    "zappavan": "zappare",
    "zappavano": "zappare",
    "zappavate": "zappare",
    "zappavi": "zappare",
    "zappavo": "zappare",
    "zappe": "zappa",
    "zapperai": "zappare",
    "zapperan": "zappare",
    "zapperanno": "zappare",
    "zapperebbe": "zappare",
    "zapperebber": "zappare",
    "zapperebbero": "zappare",
    "zapperei": "zappare",
    "zapperemmo": "zappare",
    "zapperemo": "zappare",
    "zappereste": "zappare",
    "zapperesti": "zappare",
    "zapperete": "zappare",
    "zapperà": "zappare",
    "zapperò": "zappare",
    "zappetta": "zappettare",
    "zappettai": "zappettare",
    "zappettammo": "zappettare",
    "zappettan": "zappettare",
    "zappettando": "zappettare",
    "zappettano": "zappettare",
    "zappettante": "zappettare",
    "zappettanti": "zappettare",
    "zappettar": "zappettare",
    "zappettaron": "zappettare",
    "zappettarono": "zappettare",
    "zappettasse": "zappettare",
    "zappettasser": "zappettare",
    "zappettassero": "zappettare",
    "zappettassi": "zappettare",
    "zappettassimo": "zappettare",
    "zappettaste": "zappettare",
    "zappettasti": "zappettare",
    "zappettata": "zappettare",
    "zappettate": "zappettare",
    "zappettati": "zappettare",
    "zappettato": "zappettare",
    "zappettava": "zappettare",
    "zappettavamo": "zappettare",
    "zappettavan": "zappettare",
    "zappettavano": "zappettare",
    "zappettavate": "zappettare",
    "zappettavi": "zappettare",
    "zappettavo": "zappettare",
    "zappetterai": "zappettare",
    "zappetteran": "zappettare",
    "zappetteranno": "zappettare",
    "zappetterebbe": "zappettare",
    "zappetterebber": "zappettare",
    "zappetterebbero": "zappettare",
    "zappetterei": "zappettare",
    "zappetteremmo": "zappettare",
    "zappetteremo": "zappettare",
    "zappettereste": "zappettare",
    "zappetteresti": "zappettare",
    "zappetterete": "zappettare",
    "zappetterà": "zappettare",
    "zappetterò": "zappettare",
    "zappetti": "zappettare",
    "zappettiamo": "zappettare",
    "zappettiate": "zappettare",
    "zappettin": "zappettare",
    "zappettino": "zappettare",
    "zappetto": "zappettare",
    "zappettò": "zappettare",
    "zappi": "zappare",
    "zappiamo": "zappare",
    "zappiate": "zappare",
    "zappin": "zappare",
    "zappino": "zappare",
    "zappo": "zappare",
    "zappò": "zappare",
    "zarine": "zarina",
    "zarista": "zaristo",
    "zariste": "zaristo",
    "zaristi": "zaristo",
    "zattere": "zattera",
    "zatteroni": "zatterone",
    "zavattiniana": "zavattiniano",
    "zavattiniane": "zavattiniano",
    "zavattiniani": "zavattiniano",
    "zavorra": "zavorrare",
    "zavorrai": "zavorrare",
    "zavorrammo": "zavorrare",
    "zavorran": "zavorrare",
    "zavorrando": "zavorrare",
    "zavorrano": "zavorrare",
    "zavorrante": "zavorrare",
    "zavorranti": "zavorrare",
    "zavorrar": "zavorrare",
    "zavorraron": "zavorrare",
    "zavorrarono": "zavorrare",
    "zavorrasse": "zavorrare",
    "zavorrasser": "zavorrare",
    "zavorrassero": "zavorrare",
    "zavorrassi": "zavorrare",
    "zavorrassimo": "zavorrare",
    "zavorraste": "zavorrare",
    "zavorrasti": "zavorrare",
    "zavorrata": "zavorrare",
    "zavorrate": "zavorrare",
    "zavorrati": "zavorrare",
    "zavorrato": "zavorrare",
    "zavorrava": "zavorrare",
    "zavorravamo": "zavorrare",
    "zavorravan": "zavorrare",
    "zavorravano": "zavorrare",
    "zavorravate": "zavorrare",
    "zavorravi": "zavorrare",
    "zavorravo": "zavorrare",
    "zavorre": "zavorra",
    "zavorrerai": "zavorrare",
    "zavorreran": "zavorrare",
    "zavorreranno": "zavorrare",
    "zavorrerebbe": "zavorrare",
    "zavorrerebber": "zavorrare",
    "zavorrerebbero": "zavorrare",
    "zavorrerei": "zavorrare",
    "zavorreremmo": "zavorrare",
    "zavorreremo": "zavorrare",
    "zavorrereste": "zavorrare",
    "zavorreresti": "zavorrare",
    "zavorrerete": "zavorrare",
    "zavorrerà": "zavorrare",
    "zavorrerò": "zavorrare",
    "zavorri": "zavorrare",
    "zavorriamo": "zavorrare",
    "zavorriate": "zavorrare",
    "zavorrin": "zavorrare",
    "zavorrino": "zavorrare",
    "zavorro": "zavorrare",
    "zavorrò": "zavorrare",
    "zazzere": "zazzera",
    "zebrata": "zebrato",
    "zebrate": "zebrato",
    "zebrati": "zebrato",
    "zecche": "zecca",
    "zeffirelliana": "zeffirelliano",
    "zeffirelliane": "zeffirelliano",
    "zeffirelliani": "zeffirelliano",
    "zelanti": "zelante",
    "zeli": "zelo",
    "zeppa": "zeppo",
    "zeppe": "zeppo",
    "zeppi": "zeppo",
    "zera": "zero",
    "zere": "zero",
    "zeri": "zero",
    "zibellini": "zibellino",
    "zichiana": "zichiano",
    "zichiane": "zichiano",
    "zichiani": "zichiano",
    "zie": "zia",
    "ziga": "zigare",
    "zigai": "zigare",
    "zigammo": "zigare",
    "zigan": "zigare",
    "zigana": "zigano",
    "zigando": "zigare",
    "zigane": "zigano",
    "zigani": "zigano",
    "zigano": "zigare",
    "zigante": "zigare",
    "ziganti": "zigare",
    "zigar": "zigare",
    "zigaron": "zigare",
    "zigarono": "zigare",
    "zigasse": "zigare",
    "zigasser": "zigare",
    "zigassero": "zigare",
    "zigassi": "zigare",
    "zigassimo": "zigare",
    "zigaste": "zigare",
    "zigasti": "zigare",
    "zigata": "zigare",
    "zigate": "zigare",
    "zigati": "zigare",
    "zigato": "zigare",
    "zigava": "zigare",
    "zigavamo": "zigare",
    "zigavan": "zigare",
    "zigavano": "zigare",
    "zigavate": "zigare",
    "zigavi": "zigare",
    "zigavo": "zigare",
    "zigherai": "zigare",
    "zigheran": "zigare",
    "zigheranno": "zigare",
    "zigherebbe": "zigare",
    "zigherebber": "zigare",
    "zigherebbero": "zigare",
    "zigherei": "zigare",
    "zigheremmo": "zigare",
    "zigheremo": "zigare",
    "zighereste": "zigare",
    "zigheresti": "zigare",
    "zigherete": "zigare",
    "zigherà": "zigare",
    "zigherò": "zigare",
    "zighi": "zigare",
    "zighiamo": "zigare",
    "zighiate": "zigare",
    "zighin": "zigare",
    "zighino": "zigare",
    "zigo": "zigare",
    "zigomatica": "zigomatico",
    "zigomatiche": "zigomatico",
    "zigomatici": "zigomatico",
    "zigomi": "zigomo",
    "zigrina": "zigrinare",
    "zigrinai": "zigrinare",
    "zigrinammo": "zigrinare",
    "zigrinan": "zigrinare",
    "zigrinando": "zigrinare",
    "zigrinano": "zigrinare",
    "zigrinante": "zigrinare",
    "zigrinanti": "zigrinare",
    "zigrinar": "zigrinare",
    "zigrinaron": "zigrinare",
    "zigrinarono": "zigrinare",
    "zigrinasse": "zigrinare",
    "zigrinasser": "zigrinare",
    "zigrinassero": "zigrinare",
    "zigrinassi": "zigrinare",
    "zigrinassimo": "zigrinare",
    "zigrinaste": "zigrinare",
    "zigrinasti": "zigrinare",
    "zigrinata": "zigrinare",
    "zigrinate": "zigrinare",
    "zigrinati": "zigrinare",
    "zigrinato": "zigrinare",
    "zigrinava": "zigrinare",
    "zigrinavamo": "zigrinare",
    "zigrinavan": "zigrinare",
    "zigrinavano": "zigrinare",
    "zigrinavate": "zigrinare",
    "zigrinavi": "zigrinare",
    "zigrinavo": "zigrinare",
    "zigrinerai": "zigrinare",
    "zigrineran": "zigrinare",
    "zigrineranno": "zigrinare",
    "zigrinerebbe": "zigrinare",
    "zigrinerebber": "zigrinare",
    "zigrinerebbero": "zigrinare",
    "zigrinerei": "zigrinare",
    "zigrineremmo": "zigrinare",
    "zigrineremo": "zigrinare",
    "zigrinereste": "zigrinare",
    "zigrineresti": "zigrinare",
    "zigrinerete": "zigrinare",
    "zigrinerà": "zigrinare",
    "zigrinerò": "zigrinare",
    "zigrini": "zigrinare",
    "zigriniamo": "zigrinare",
    "zigriniate": "zigrinare",
    "zigrinin": "zigrinare",
    "zigrinino": "zigrinare",
    "zigrino": "zigrinare",
    "zigrinò": "zigrinare",
    "zigzaga": "zigzagare",
    "zigzagai": "zigzagare",
    "zigzagammo": "zigzagare",
    "zigzagan": "zigzagare",
    "zigzagando": "zigzagare",
    "zigzagano": "zigzagare",
    "zigzagante": "zigzagare",
    "zigzaganti": "zigzagare",
    "zigzagar": "zigzagare",
    "zigzagaron": "zigzagare",
    "zigzagarono": "zigzagare",
    "zigzagasse": "zigzagare",
    "zigzagasser": "zigzagare",
    "zigzagassero": "zigzagare",
    "zigzagassi": "zigzagare",
    "zigzagassimo": "zigzagare",
    "zigzagaste": "zigzagare",
    "zigzagasti": "zigzagare",
    "zigzagata": "zigzagare",
    "zigzagate": "zigzagare",
    "zigzagati": "zigzagare",
    "zigzagato": "zigzagare",
    "zigzagava": "zigzagare",
    "zigzagavamo": "zigzagare",
    "zigzagavan": "zigzagare",
    "zigzagavano": "zigzagare",
    "zigzagavate": "zigzagare",
    "zigzagavi": "zigzagare",
    "zigzagavo": "zigzagare",
    "zigzagherai": "zigzagare",
    "zigzagheran": "zigzagare",
    "zigzagheranno": "zigzagare",
    "zigzagherebbe": "zigzagare",
    "zigzagherebber": "zigzagare",
    "zigzagherebbero": "zigzagare",
    "zigzagherei": "zigzagare",
    "zigzagheremmo": "zigzagare",
    "zigzagheremo": "zigzagare",
    "zigzaghereste": "zigzagare",
    "zigzagheresti": "zigzagare",
    "zigzagherete": "zigzagare",
    "zigzagherà": "zigzagare",
    "zigzagherò": "zigzagare",
    "zigzaghi": "zigzagare",
    "zigzaghiamo": "zigzagare",
    "zigzaghiate": "zigzagare",
    "zigzaghin": "zigzagare",
    "zigzaghino": "zigzagare",
    "zigzago": "zigzagare",
    "zigzagò": "zigzagare",
    "zigò": "zigare",
    "zii": "zio",
    "zimbelli": "zimbello",
    "zinca": "zincare",
    "zincai": "zincare",
    "zincammo": "zincare",
    "zincan": "zincare",
    "zincando": "zincare",
    "zincano": "zincare",
    "zincante": "zincare",
    "zincanti": "zincare",
    "zincar": "zincare",
    "zincaron": "zincare",
    "zincarono": "zincare",
    "zincasse": "zincare",
    "zincasser": "zincare",
    "zincassero": "zincare",
    "zincassi": "zincare",
    "zincassimo": "zincare",
    "zincaste": "zincare",
    "zincasti": "zincare",
    "zincata": "zincare",
    "zincate": "zincare",
    "zincati": "zincare",
    "zincato": "zincare",
    "zincava": "zincare",
    "zincavamo": "zincare",
    "zincavan": "zincare",
    "zincavano": "zincare",
    "zincavate": "zincare",
    "zincavi": "zincare",
    "zincavo": "zincare",
    "zincherai": "zincare",
    "zincheran": "zincare",
    "zincheranno": "zincare",
    "zincherebbe": "zincare",
    "zincherebber": "zincare",
    "zincherebbero": "zincare",
    "zincherei": "zincare",
    "zincheremmo": "zincare",
    "zincheremo": "zincare",
    "zinchereste": "zincare",
    "zincheresti": "zincare",
    "zincherete": "zincare",
    "zincherà": "zincare",
    "zincherò": "zincare",
    "zinchi": "zincare",
    "zinchiamo": "zincare",
    "zinchiate": "zincare",
    "zinchin": "zincare",
    "zinchino": "zincare",
    "zinco": "zincare",
    "zincò": "zincare",
    "zingara": "zingaro",
    "zingare": "zingaro",
    "zingarelle": "zingarella",
    "zingarelli": "zingarello",
    "zingaresca": "zingaresco",
    "zingaresche": "zingaresco",
    "zingareschi": "zingaresco",
    "zingari": "zingaro",
    "zirla": "zirlare",
    "zirlai": "zirlare",
    "zirlammo": "zirlare",
    "zirlan": "zirlare",
    "zirlando": "zirlare",
    "zirlano": "zirlare",
    "zirlante": "zirlare",
    "zirlanti": "zirlare",
    "zirlar": "zirlare",
    "zirlaron": "zirlare",
    "zirlarono": "zirlare",
    "zirlasse": "zirlare",
    "zirlasser": "zirlare",
    "zirlassero": "zirlare",
    "zirlassi": "zirlare",
    "zirlassimo": "zirlare",
    "zirlaste": "zirlare",
    "zirlasti": "zirlare",
    "zirlata": "zirlare",
    "zirlate": "zirlare",
    "zirlati": "zirlare",
    "zirlato": "zirlare",
    "zirlava": "zirlare",
    "zirlavamo": "zirlare",
    "zirlavan": "zirlare",
    "zirlavano": "zirlare",
    "zirlavate": "zirlare",
    "zirlavi": "zirlare",
    "zirlavo": "zirlare",
    "zirlerai": "zirlare",
    "zirleran": "zirlare",
    "zirleranno": "zirlare",
    "zirlerebbe": "zirlare",
    "zirlerebber": "zirlare",
    "zirlerebbero": "zirlare",
    "zirlerei": "zirlare",
    "zirleremmo": "zirlare",
    "zirleremo": "zirlare",
    "zirlereste": "zirlare",
    "zirleresti": "zirlare",
    "zirlerete": "zirlare",
    "zirlerà": "zirlare",
    "zirlerò": "zirlare",
    "zirli": "zirlare",
    "zirliamo": "zirlare",
    "zirliate": "zirlare",
    "zirlin": "zirlare",
    "zirlino": "zirlare",
    "zirlo": "zirlare",
    "zirlò": "zirlare",
    "zitelle": "zitella",
    "zitta": "zitto",
    "zitte": "zitto",
    "zittendo": "zittire",
    "zittente": "zittire",
    "zittenti": "zittire",
    "zitti": "zitto",
    "zittiamo": "zittire",
    "zittiate": "zittire",
    "zittii": "zittire",
    "zittimmo": "zittire",
    "zittir": "zittire",
    "zittirai": "zittire",
    "zittiran": "zittire",
    "zittiranno": "zittire",
    "zittirebbe": "zittire",
    "zittirebber": "zittire",
    "zittirebbero": "zittire",
    "zittirei": "zittire",
    "zittiremmo": "zittire",
    "zittiremo": "zittire",
    "zittireste": "zittire",
    "zittiresti": "zittire",
    "zittirete": "zittire",
    "zittiron": "zittire",
    "zittirono": "zittire",
    "zittirà": "zittire",
    "zittirò": "zittire",
    "zittisca": "zittire",
    "zittiscan": "zittire",
    "zittiscano": "zittire",
    "zittisce": "zittire",
    "zittisci": "zittire",
    "zittisco": "zittire",
    "zittiscon": "zittire",
    "zittiscono": "zittire",
    "zittisse": "zittire",
    "zittisser": "zittire",
    "zittissero": "zittire",
    "zittissi": "zittire",
    "zittissimo": "zittire",
    "zittiste": "zittire",
    "zittisti": "zittire",
    "zittita": "zittire",
    "zittite": "zittire",
    "zittiti": "zittire",
    "zittito": "zittire",
    "zittiva": "zittire",
    "zittivamo": "zittire",
    "zittivan": "zittire",
    "zittivano": "zittire",
    "zittivate": "zittire",
    "zittivi": "zittire",
    "zittivo": "zittire",
    "zittì": "zittire",
    "zoccola": "zoccolare",
    "zoccolai": "zoccolare",
    "zoccolammo": "zoccolare",
    "zoccolan": "zoccolare",
    "zoccolando": "zoccolare",
    "zoccolano": "zoccolare",
    "zoccolante": "zoccolare",
    "zoccolanti": "zoccolare",
    "zoccolar": "zoccolare",
    "zoccolaron": "zoccolare",
    "zoccolarono": "zoccolare",
    "zoccolasse": "zoccolare",
    "zoccolasser": "zoccolare",
    "zoccolassero": "zoccolare",
    "zoccolassi": "zoccolare",
    "zoccolassimo": "zoccolare",
    "zoccolaste": "zoccolare",
    "zoccolasti": "zoccolare",
    "zoccolata": "zoccolare",
    "zoccolate": "zoccolare",
    "zoccolati": "zoccolare",
    "zoccolato": "zoccolare",
    "zoccolava": "zoccolare",
    "zoccolavamo": "zoccolare",
    "zoccolavan": "zoccolare",
    "zoccolavano": "zoccolare",
    "zoccolavate": "zoccolare",
    "zoccolavi": "zoccolare",
    "zoccolavo": "zoccolare",
    "zoccole": "zoccola",
    "zoccolerai": "zoccolare",
    "zoccoleran": "zoccolare",
    "zoccoleranno": "zoccolare",
    "zoccolerebbe": "zoccolare",
    "zoccolerebber": "zoccolare",
    "zoccolerebbero": "zoccolare",
    "zoccolerei": "zoccolare",
    "zoccoleremmo": "zoccolare",
    "zoccoleremo": "zoccolare",
    "zoccolereste": "zoccolare",
    "zoccoleresti": "zoccolare",
    "zoccolerete": "zoccolare",
    "zoccolerà": "zoccolare",
    "zoccolerò": "zoccolare",
    "zoccoli": "zoccolo",
    "zoccoliamo": "zoccolare",
    "zoccoliate": "zoccolare",
    "zoccolin": "zoccolare",
    "zoccolino": "zoccolare",
    "zoccolo": "zoccolare",
    "zoccolò": "zoccolare",
    "zodiacali": "zodiacale",
    "zolfi": "zolfo",
    "zolle": "zolla",
    "zompa": "zompare",
    "zompai": "zompare",
    "zompammo": "zompare",
    "zompan": "zompare",
    "zompando": "zompare",
    "zompano": "zompare",
    "zompante": "zompare",
    "zompanti": "zompare",
    "zompar": "zompare",
    "zomparon": "zompare",
    "zomparono": "zompare",
    "zompasse": "zompare",
    "zompasser": "zompare",
    "zompassero": "zompare",
    "zompassi": "zompare",
    "zompassimo": "zompare",
    "zompaste": "zompare",
    "zompasti": "zompare",
    "zompata": "zompare",
    "zompate": "zompare",
    "zompati": "zompare",
    "zompato": "zompare",
    "zompava": "zompare",
    "zompavamo": "zompare",
    "zompavan": "zompare",
    "zompavano": "zompare",
    "zompavate": "zompare",
    "zompavi": "zompare",
    "zompavo": "zompare",
    "zomperai": "zompare",
    "zomperan": "zompare",
    "zomperanno": "zompare",
    "zomperebbe": "zompare",
    "zomperebber": "zompare",
    "zomperebbero": "zompare",
    "zomperei": "zompare",
    "zomperemmo": "zompare",
    "zomperemo": "zompare",
    "zompereste": "zompare",
    "zomperesti": "zompare",
    "zomperete": "zompare",
    "zomperà": "zompare",
    "zomperò": "zompare",
    "zompetta": "zompettare",
    "zompettai": "zompettare",
    "zompettammo": "zompettare",
    "zompettan": "zompettare",
    "zompettando": "zompettare",
    "zompettano": "zompettare",
    "zompettante": "zompettare",
    "zompettanti": "zompettare",
    "zompettar": "zompettare",
    "zompettaron": "zompettare",
    "zompettarono": "zompettare",
    "zompettasse": "zompettare",
    "zompettasser": "zompettare",
    "zompettassero": "zompettare",
    "zompettassi": "zompettare",
    "zompettassimo": "zompettare",
    "zompettaste": "zompettare",
    "zompettasti": "zompettare",
    "zompettata": "zompettare",
    "zompettate": "zompettare",
    "zompettati": "zompettare",
    "zompettato": "zompettare",
    "zompettava": "zompettare",
    "zompettavamo": "zompettare",
    "zompettavan": "zompettare",
    "zompettavano": "zompettare",
    "zompettavate": "zompettare",
    "zompettavi": "zompettare",
    "zompettavo": "zompettare",
    "zompetterai": "zompettare",
    "zompetteran": "zompettare",
    "zompetteranno": "zompettare",
    "zompetterebbe": "zompettare",
    "zompetterebber": "zompettare",
    "zompetterebbero": "zompettare",
    "zompetterei": "zompettare",
    "zompetteremmo": "zompettare",
    "zompetteremo": "zompettare",
    "zompettereste": "zompettare",
    "zompetteresti": "zompettare",
    "zompetterete": "zompettare",
    "zompetterà": "zompettare",
    "zompetterò": "zompettare",
    "zompetti": "zompettare",
    "zompettiamo": "zompettare",
    "zompettiate": "zompettare",
    "zompettin": "zompettare",
    "zompettino": "zompettare",
    "zompetto": "zompettare",
    "zompettò": "zompettare",
    "zompi": "zompare",
    "zompiamo": "zompare",
    "zompiate": "zompare",
    "zompin": "zompare",
    "zompino": "zompare",
    "zompo": "zompare",
    "zompò": "zompare",
    "zonali": "zonale",
    "zone": "zona",
    "zonisti": "zonista",
    "zoologi": "zoologo",
    "zoologica": "zoologico",
    "zoologiche": "zoologico",
    "zoologici": "zoologico",
    "zoologie": "zoologia",
    "zooma": "zoomare",
    "zoomai": "zoomare",
    "zoomammo": "zoomare",
    "zooman": "zoomare",
    "zoomando": "zoomare",
    "zoomano": "zoomare",
    "zoomante": "zoomare",
    "zoomanti": "zoomare",
    "zoomar": "zoomare",
    "zoomaron": "zoomare",
    "zoomarono": "zoomare",
    "zoomasse": "zoomare",
    "zoomasser": "zoomare",
    "zoomassero": "zoomare",
    "zoomassi": "zoomare",
    "zoomassimo": "zoomare",
    "zoomaste": "zoomare",
    "zoomasti": "zoomare",
    "zoomata": "zoomare",
    "zoomate": "zoomata",
    "zoomati": "zoomare",
    "zoomato": "zoomare",
    "zoomava": "zoomare",
    "zoomavamo": "zoomare",
    "zoomavan": "zoomare",
    "zoomavano": "zoomare",
    "zoomavate": "zoomare",
    "zoomavi": "zoomare",
    "zoomavo": "zoomare",
    "zoomerai": "zoomare",
    "zoomeran": "zoomare",
    "zoomeranno": "zoomare",
    "zoomerebbe": "zoomare",
    "zoomerebber": "zoomare",
    "zoomerebbero": "zoomare",
    "zoomerei": "zoomare",
    "zoomeremmo": "zoomare",
    "zoomeremo": "zoomare",
    "zoomereste": "zoomare",
    "zoomeresti": "zoomare",
    "zoomerete": "zoomare",
    "zoomerà": "zoomare",
    "zoomerò": "zoomare",
    "zoomi": "zoomare",
    "zoomiamo": "zoomare",
    "zoomiate": "zoomare",
    "zoomin": "zoomare",
    "zoomino": "zoomare",
    "zoomo": "zoomare",
    "zoomorfa": "zoomorfo",
    "zoomorfe": "zoomorfo",
    "zoomorfi": "zoomorfo",
    "zoomorfica": "zoomorfico",
    "zoomorfiche": "zoomorfico",
    "zoomorfici": "zoomorfico",
    "zoomò": "zoomare",
    "zootecnica": "zootecnico",
    "zootecniche": "zootecnico",
    "zootecnici": "zootecnico",
    "zootecnie": "zootecnia",
    "zoppa": "zoppo",
    "zoppe": "zoppo",
    "zoppi": "zoppo",
    "zoppica": "zoppicare",
    "zoppicai": "zoppicare",
    "zoppicammo": "zoppicare",
    "zoppican": "zoppicare",
    "zoppicando": "zoppicare",
    "zoppicano": "zoppicare",
    "zoppicante": "zoppicare",
    "zoppicanti": "zoppicare",
    "zoppicar": "zoppicare",
    "zoppicaron": "zoppicare",
    "zoppicarono": "zoppicare",
    "zoppicasse": "zoppicare",
    "zoppicasser": "zoppicare",
    "zoppicassero": "zoppicare",
    "zoppicassi": "zoppicare",
    "zoppicassimo": "zoppicare",
    "zoppicaste": "zoppicare",
    "zoppicasti": "zoppicare",
    "zoppicata": "zoppicare",
    "zoppicate": "zoppicare",
    "zoppicati": "zoppicare",
    "zoppicato": "zoppicare",
    "zoppicava": "zoppicare",
    "zoppicavamo": "zoppicare",
    "zoppicavan": "zoppicare",
    "zoppicavano": "zoppicare",
    "zoppicavate": "zoppicare",
    "zoppicavi": "zoppicare",
    "zoppicavo": "zoppicare",
    "zoppicherai": "zoppicare",
    "zoppicheran": "zoppicare",
    "zoppicheranno": "zoppicare",
    "zoppicherebbe": "zoppicare",
    "zoppicherebber": "zoppicare",
    "zoppicherebbero": "zoppicare",
    "zoppicherei": "zoppicare",
    "zoppicheremmo": "zoppicare",
    "zoppicheremo": "zoppicare",
    "zoppichereste": "zoppicare",
    "zoppicheresti": "zoppicare",
    "zoppicherete": "zoppicare",
    "zoppicherà": "zoppicare",
    "zoppicherò": "zoppicare",
    "zoppichi": "zoppicare",
    "zoppichiamo": "zoppicare",
    "zoppichiate": "zoppicare",
    "zoppichin": "zoppicare",
    "zoppichino": "zoppicare",
    "zoppico": "zoppicare",
    "zoppicò": "zoppicare",
    "zoppie": "zoppia",
    "zoppìe": "zoppìa",
    "zuava": "zuavo",
    "zuave": "zuavo",
    "zuavi": "zuavo",
    "zucche": "zucca",
    "zucchera": "zuccherare",
    "zuccherai": "zuccherare",
    "zuccherammo": "zuccherare",
    "zuccheran": "zuccherare",
    "zuccherando": "zuccherare",
    "zuccherano": "zuccherare",
    "zuccherante": "zuccherare",
    "zuccheranti": "zuccherare",
    "zuccherar": "zuccherare",
    "zuccheraron": "zuccherare",
    "zuccherarono": "zuccherare",
    "zuccherasse": "zuccherare",
    "zuccherasser": "zuccherare",
    "zuccherassero": "zuccherare",
    "zuccherassi": "zuccherare",
    "zuccherassimo": "zuccherare",
    "zuccheraste": "zuccherare",
    "zuccherasti": "zuccherare",
    "zuccherata": "zuccherato",
    "zuccherate": "zuccherato",
    "zuccherati": "zuccherato",
    "zuccherato": "zuccherare",
    "zuccherava": "zuccherare",
    "zuccheravamo": "zuccherare",
    "zuccheravan": "zuccherare",
    "zuccheravano": "zuccherare",
    "zuccheravate": "zuccherare",
    "zuccheravi": "zuccherare",
    "zuccheravo": "zuccherare",
    "zucchererai": "zuccherare",
    "zucchereran": "zuccherare",
    "zucchereranno": "zuccherare",
    "zucchererebbe": "zuccherare",
    "zucchererebber": "zuccherare",
    "zucchererebbero": "zuccherare",
    "zucchererei": "zuccherare",
    "zucchereremmo": "zuccherare",
    "zucchereremo": "zuccherare",
    "zuccherereste": "zuccherare",
    "zucchereresti": "zuccherare",
    "zucchererete": "zuccherare",
    "zucchererà": "zuccherare",
    "zucchererò": "zuccherare",
    "zuccheri": "zucchero",
    "zuccheriamo": "zuccherare",
    "zuccheriate": "zuccherare",
    "zuccheriera": "zuccheriero",
    "zuccheriere": "zuccheriero",
    "zuccherieri": "zuccheriero",
    "zuccherifici": "zuccherificio",
    "zuccherin": "zuccherare",
    "zuccherina": "zuccherino",
    "zuccherine": "zuccherino",
    "zuccherini": "zuccherino",
    "zuccherino": "zuccherare",
    "zucchero": "zuccherare",
    "zuccherosa": "zuccheroso",
    "zuccherose": "zuccheroso",
    "zuccherosi": "zuccheroso",
    "zuccherò": "zuccherare",
    "zucconi": "zuccone",
    "zufola": "zufolare",
    "zufolai": "zufolare",
    "zufolammo": "zufolare",
    "zufolan": "zufolare",
    "zufolando": "zufolare",
    "zufolano": "zufolare",
    "zufolante": "zufolare",
    "zufolanti": "zufolare",
    "zufolar": "zufolare",
    "zufolaron": "zufolare",
    "zufolarono": "zufolare",
    "zufolasse": "zufolare",
    "zufolasser": "zufolare",
    "zufolassero": "zufolare",
    "zufolassi": "zufolare",
    "zufolassimo": "zufolare",
    "zufolaste": "zufolare",
    "zufolasti": "zufolare",
    "zufolata": "zufolare",
    "zufolate": "zufolare",
    "zufolati": "zufolare",
    "zufolato": "zufolare",
    "zufolava": "zufolare",
    "zufolavamo": "zufolare",
    "zufolavan": "zufolare",
    "zufolavano": "zufolare",
    "zufolavate": "zufolare",
    "zufolavi": "zufolare",
    "zufolavo": "zufolare",
    "zufolerai": "zufolare",
    "zufoleran": "zufolare",
    "zufoleranno": "zufolare",
    "zufolerebbe": "zufolare",
    "zufolerebber": "zufolare",
    "zufolerebbero": "zufolare",
    "zufolerei": "zufolare",
    "zufoleremmo": "zufolare",
    "zufoleremo": "zufolare",
    "zufolereste": "zufolare",
    "zufoleresti": "zufolare",
    "zufolerete": "zufolare",
    "zufolerà": "zufolare",
    "zufolerò": "zufolare",
    "zufoli": "zufolare",
    "zufoliamo": "zufolare",
    "zufoliate": "zufolare",
    "zufolin": "zufolare",
    "zufolino": "zufolare",
    "zufolo": "zufolare",
    "zufolò": "zufolare",
    "zuma": "zumare",
    "zumai": "zumare",
    "zumammo": "zumare",
    "zuman": "zumare",
    "zumando": "zumare",
    "zumano": "zumare",
    "zumante": "zumare",
    "zumanti": "zumare",
    "zumar": "zumare",
    "zumaron": "zumare",
    "zumarono": "zumare",
    "zumasse": "zumare",
    "zumasser": "zumare",
    "zumassero": "zumare",
    "zumassi": "zumare",
    "zumassimo": "zumare",
    "zumaste": "zumare",
    "zumasti": "zumare",
    "zumata": "zumare",
    "zumate": "zumare",
    "zumati": "zumare",
    "zumato": "zumare",
    "zumava": "zumare",
    "zumavamo": "zumare",
    "zumavan": "zumare",
    "zumavano": "zumare",
    "zumavate": "zumare",
    "zumavi": "zumare",
    "zumavo": "zumare",
    "zumerai": "zumare",
    "zumeran": "zumare",
    "zumeranno": "zumare",
    "zumerebbe": "zumare",
    "zumerebber": "zumare",
    "zumerebbero": "zumare",
    "zumerei": "zumare",
    "zumeremmo": "zumare",
    "zumeremo": "zumare",
    "zumereste": "zumare",
    "zumeresti": "zumare",
    "zumerete": "zumare",
    "zumerà": "zumare",
    "zumerò": "zumare",
    "zumi": "zumare",
    "zumiamo": "zumare",
    "zumiate": "zumare",
    "zumin": "zumare",
    "zumino": "zumare",
    "zumo": "zumare",
    "zumò": "zumare",
    "zuppa": "zuppo",
    "zuppe": "zuppo",
    "zuppi": "zuppo",
    "zurighesi": "zurighese",
    "zurliniana": "zurliniano",
    "zurliniane": "zurliniano",
    "zurliniani": "zurliniano",
    "àncore": "àncora",
    "sono": "essere",
    "è": "essere",
    "èlites": "èlite",
    "ère": "èra",
    "élites": "élite"
}
